# coding: utf8
from __future__ import unicode_literals

from .stop_words import STOP_WORDS
from .lex_attrs import LEX_ATTRS

from ..norm_exceptions import BASE_NORMS
from ...language import Language
from ...attrs import LANG


class HindiDefaults(Language.Defaults):
    lex_attr_getters = dict(Language.Defaults.lex_attr_getters)
    lex_attr_getters.update(LEX_ATTRS)
    lex_attr_getters[LANG] = lambda text: 'hi'
    stop_words = STOP_WORDS


class Hindi(Language):
    lang = 'hi'
    Defaults = HindiDefaults


__all__ = ['Hindi']
