# coding: utf8
from __future__ import unicode_literals


VERBS = set("""
aah abacinate abandon abase abash abate abbreviate abdicate abduce abduct
aberrate abet abhor abide abjure ablactate ablate abnegate abolish abominate
abort abound about-face abrade abrase abreact abridge abrogate abscise abscond
abseil absent absolve absorb absquatulate abstain abstract abuse abut aby abye
accede accelerate accent accentuate accept access accession acclaim acclimate
acclimatise acclimatize accommodate accompany accomplish accord accost account
accouter accoutre accredit accrete accrue acculturate accumulate accurse accuse
accustom ace acerbate acetify acetylate acetylise acetylize ache achieve
achromatise achromatize acid-wash acidify acidulate acknowledge acquaint
acquiesce acquire acquit act action activate actualise actualize actuate
acuminate ad-lib adapt add addict addle address adduce adduct adhere adjoin
adjourn adjudge adjudicate adjure adjust admeasure administer administrate
admire admit admix admonish adolesce adopt adore adorn adsorb adulate adulterate
adumbrate advance advantage advect adventure advert advertise advertize advise
advocate aerate aerify aerosolise aerosolize aestivate affect affiance affiliate
affirm affix afflict afford afforest affranchise affright affront age agenise
agenize agglomerate agglutinate aggrade aggrandise aggrandize aggravate
aggregate aggress aggrieve aggroup agitate agnise agnize agonise agonize agree
aid ail aim air air-condition air-cool air-drop air-freight air-ship air-slake
airbrush airfreight airlift airmail airt alarm alchemise alchemize alcoholise
alcoholize alert alibi alien alienate alight align aliment aline alkalify
alkalinise alkalinize alkalise alkalize allay allege allegorise allegorize
alleviate alligator alliterate allocate allot allow allowance alloy allude
allure ally alphabetise alphabetize alter altercate alternate aluminise
aluminize amalgamate amass amaze ambition amble ambulate ambuscade ambush
ameliorate amend amerce americanise americanize ammoniate ammonify amnesty
amortise amortize amount amplify amputate amuse anaesthetise anaesthetize
anagram anagrammatise anagrammatize analogise analogize analyse analyze
anastomose anathematise anathematize anathemise anathemize anatomise anatomize
anchor ancylose anele anesthetise anesthetize anger angle angle-park anglicise
anglicize anguish angulate animadvert animalise animalize animate animise
animize ankylose anneal annex annihilate annotate announce annoy annul
annunciate anodise anodize anoint answer antagonise antagonize ante antecede
antedate anthologise anthologize anthropomorphise anthropomorphize antic
anticipate antiquate antique antisepticize ape aphorise aphorize apologise
apologize apostatise apostatize apostrophise apostrophize apotheose apotheosise
apotheosize appal appall apparel appeal appear appease append apperceive
appertain applaud applique apply appoint apportion appose appraise appreciate
apprehend apprentice apprise apprize approach approbate appropriate approve
approximate aquaplane aquatint arbitrage arbitrate arborise arborize arc arch
archaise archaize archive argue argufy arise arm armor armour aromatise
aromatize arouse arraign arrange array arrest arrive arrogate arterialise
arterialize article articulate ascend ascertain ascribe ash ask asperse asphalt
asphyxiate aspirate aspire assail assassinate assault assay assemble assent
assert assess asseverate assibilate assign assimilate assist associate assoil
assonate assort assuage assume assure asterisk astonish astound astringe
astrogate atom-bomb atomise atomize atone atrophy attach attack attain attaint
attemper attempt attend attenuate attest attire attitudinise attitudinize attorn
attract attribute attune auction auctioneer audit audition augment augur aurify
auscultate auspicate authenticate author authorise authorize autoclave autograph
automate automatise automatize automobile autopsy autotomise autotomize avail
avalanche avenge aver average avert avianise avianize aviate avoid avouch avow
avulse await awake awaken award awe ax axe azure baa babbitt babble baby baby-
sit bach bachelor back backbite backcross backdate backfire background backhand
backlash backlog backpack backpedal backscatter backslap backslide backspace
backstitch backstop backstroke backtrack bacterise bacterize badge badger
badmouth baffle bag bail bait bake balance bald bale balk balkanise balkanize
ball ballast balloon ballot ballyhoo ballyrag bamboozle ban band bandage bandy
bang banish bank bankroll bankrupt banquet banter baptise baptize bar barb
barbarise barbarize barbecue barbeque barber bard barde bare barf bargain barge
bark barnstorm baronetise baronetize barrack barrage barrel barricade barricado
barter base bash basify bask basset bastardise bastardize baste bastinado bat
batch bate batfowl bath bathe batik batten batter battle baulk bawl bay bayonet
be beach beacon bead beak beam bean bear beard beat beatify beautify beaver
bebop becalm bechance becharm beckon becloud become bed bed-hop bedamn bedaub
bedaze bedazzle bedeck bedevil bedew bedhop bedight bedim bedizen bedraggle beef
beep beeswax beetle befall befit befog befool befoul befriend befuddle beg beget
beggar begild begin begrime begrudge beguile behave behead behold behoove behove
bejewel belabor belabour belay belch beleaguer belie believe belittle bell
bellow belly belly-flop belly-land bellyache bellylaugh belong belt bemire
bemoan bemock bemuse bench bend benday benefact benefice beneficiate benefit
benficiate benight benumb beplaster bequeath berate bereave berry berth beseech
beseem beset beshrew besiege besmear besmirch besot bespangle bespatter bespeak
bespeckle bespot besprinkle best bestialise bestialize bestir bestow bestrew
bestride bet bethink betide betoken betray betroth better bevel bewail beware
bewhisker bewilder bewitch bewray bias bib bicker bicycle bid bide biff
bifurcate bight bike bilge bilk bill billet billow bin bind binge bioassay
biodegrade birch bird bird-nest birdie birdlime birdnest birdwatch birl birle
birr birth bisect bitch bite bitt bitter bituminise bituminize bivouac blab
blabber black blackball blackberry blacken blackguard blackjack blacklead
blackleg blacklist blackmail blacktop blackwash blame blanch blandish blank
blanket blare blarney blaspheme blast blat blate blather blaze blazon bleach
blear bleat bleed bleep blemish blench blend bless blether blight blind
blindfold blindside blink blinker blister blither blitz blitzkrieg bloat blob
block blockade blog blood bloody bloom blossom blot blotch bloviate blow blow-
dry blub blubber bludgeon blue blue-pencil blueprint bluff blunder blunt blur
blurt blush bluster board boast boat boat-race bob bobble bobsled bode bodge
body body-surf bodypaint bog bogey boggle boil boldface bollix bollocks
bolshevise bolshevize bolster bolt bomb bombard bombilate bombinate bombproof
bond bonderise bonderize bone bong bonk bonnet boo boob boogie book boom
boomerang boondoggle boost boot bootleg bootlick bootstrap booze bop border bore
borrow bosom boss botanise botanize botch bother bottle bottlefeed bottleneck
bottom bounce bound bourgeon bouse bow bowdlerise bowdlerize bower bowl bowse
box boycott brabble brace brachiate bracket brad brag braid brail braille brain
brainstorm brainwash braise brake branch brand brandish brandmark brattice
brattle brave bravo brawl bray braze brazen breach bread break break-dance
breakfast bream breast breastfeed breaststroke breathalyse breathalyze breathe
brecciate breed breeze brevet brew bribe bridge bridle brief brigade brighten
brim brine bring brisk brisken bristle broach broadcast broaden broadside
brocade broider broil broker bromate brominate bronze brooch brood brook broom
browbeat brown brown-nose browse bruise bruit brunch brush brutalise brutalize
bubble buccaneer buck bucket buckle buckram bud budge budget buff buffalo buffer
buffet bug bugger bugle build bulge bulk bull bulldog bulldoze bulletin
bulletproof bullshit bully bullyrag bulwark bum bumble bump bunch bunco bundle
bung bungle bunk bunker bunt buoy bur burble burden burgeon burglarise
burglarize burgle burke burl burlesque burn burnish burp burr burrow burst
burthen bury bus bush bushel bushwhack busk buss bust bustle busy butcher butt
butt-weld butter butterfly button buttonhole buttress buttweld butylate buy buzz
by-bid bypass ca-ca cab cabal cabbage cabin cable cache cachinnate cackel cackle
caddie caddy cadge cage cajole cake cakewalk calcify calcimine calcine calculate
calendar calender calibrate caliper calk call calligraph calliper callous callus
calm calumniate calve camber camouflage camp campaign camphorate can canal
canalise canalize cancel candle candy cane canker cannibalise cannibalize cannon
cannonade cannulate cannulise cannulize canoe canonise canonize canoodle canopy
cant canter cantilever cantillate canton canulate canvas canvass cap capacitate
caparison caper capitalise capitalize capitulate caponise caponize capriole
capsize capsulate capsule capsulise capsulize captain caption captivate capture
caracole caramelise caramelize caravan carbonate carbonise carbonize carboxylate
carburet carburise carburize card care careen career caress caricature carjack
cark carmine carnalise carnalize carnify carol carom carouse carp carpenter
carpet carry cart cartoon cartwheel carve cascade case caseate cash cashier
casket cast castigate castle castrate cat catabolise catabolize catalog
catalogue catalyse catalyze catapult catcall catch catechise catechize
categorise categorize catenate catenulate cater caterwaul cathect catheterise
catheterize catholicise catholicize catnap caucus caulk cause causeway cauterise
cauterize caution cave cavern cavil cavort caw cease cede celebrate cement cense
censor censure census center centralise centralize centre centrifugate
centrifuge cere cerebrate certificate certify cha-cha chafe chaff chaffer
chagrin chain chain-smoke chair chairman chalk challenge chamber chamfer champ
champion chance chandelle change channel channel-surf channelise channelize
chant chap chaperon chaperone char character characterise characterize charcoal
charge chariot charleston charm chart charter chase chasse chasten chastise chat
chatter chauffeur chaw cheapen cheat check checker checkmate checkrow cheek
cheep cheer cheerlead cheese chelate chemisorb cheque chequer cherish chevvy
chevy chew chicane chicken-fight chickenfight chide child-proof childproof chill
chime chin chine chink chip chirk chiromance chirp chirr chirrup chisel chit-
chat chitchat chitter chivvy chivy chlorinate chloroform chock choir choke chomp
chondrify choose chop chord choreograph chortle chorus chouse christen
christianise christianize chrome chromium-plate chronicle chronologise
chronologize chuck chuckle chuff chug chunk church churn churr chute cicatrise
cicatrize cinch cinematise cinematize cipher circle circuit circularise
circularize circulate circumambulate circumcise circumfuse circumnavigate
circumscribe circumstantiate circumvallate circumvent circumvolute circumvolve
cite citify citrate civilise civilize clabber clack claim clam clamber clamor
clamour clamp clang clangor clangour clank clap clapboard clapperclaw claret
clarify clarion clash clasp class classicise classicize classify clatter claver
claw claxon clean cleanse clear clear-cut cleat cleave clench clerk clew click
climax climb clinch cling clink clinker clip clitter cloak clobber clock clog
cloister clomp clone clop close closet closure clot clothe cloture cloud clout
clown cloy club cluck clue clump clunk cluster clutch clutter co-author co-
educate co-occur co-opt co-sign co-star co-vary coach coact coagulate coal
coalesce coapt coarsen coast coat coax cobble cobblestone cocainise cocainize
cock cocker cockle coconspire cocoon cod coddle code codify coeducate coerce
coexist coffin cog coggle cogitate cognise cognize cohabit cohere coif coiffe
coiffure coil coin coincide coinsure coke cold-cream cold-shoulder coldcock
coldwork collaborate collapse collar collate collateralize collect collectivise
collectivize collide colligate collimate collocate collogue collude colly
colonise colonize color colorcast colorise colorize colour colourise colourize
comb combat combine combust come comfit comfort command commandeer commemorate
commence commend comment commentate commercialise commercialize comminate
commingle comminute commiserate commission commit commix commove communalise
communalize commune communicate communise communize commutate commute compact
companion company compare comparison-shop compart compartmentalise
compartmentalize compass compassionate compel compensate compere compete compile
complain complect complement complete complexify complexion complicate
compliment complot comply comport compose compost compound comprehend compress
comprise compromise compute computerise computerize con concatenate conceal
concede conceive concenter concentrate concentre conceptualise conceptualize
concern concert concertina concertise concertize conciliate conclude concoct
concord concrete concretise concretize concur concuss condemn condense
condescend condition condole condone conduce conduct cone confab confabulate
confect confection confederate confer confess confide configure confine confirm
confiscate conflagrate conflate conflict conform confound confront confuse
confute conga conge congeal congee congest conglobate conglobe conglomerate
conglutinate congratulate congregate conjecture conjoin conjugate conjure conk
conn connect connive connote conquer conscript consecrate consent conserve
consider consign consist consociate console consolidate consonate consort
conspire constellate consternate constipate constitute constitutionalise
constitutionalize constrain constrict constringe construct construe
consubstantiate consult consume consummate contact contain containerise
containerize contaminate contemn contemplate contemporise contemporize contend
content contest continue contort contour contract contradance contradict
contradistinguish contraindicate contrast contravene contredanse contribute
contrive control controvert contuse convalesce convect convene conventionalise
conventionalize converge converse convert convey convict convince convoke
convolute convolve convoy convulse coo cooccur cook cool cooper cooperate
coordinate cop cope copolymerise copolymerize copper copper-bottom copulate copy
copyedit copyread copyright coquet coquette corbel cord corduroy core cork
corkscrew corn corner cornice coronate corrade corral correct correlate
correspond corroborate corrode corrugate corrupt corset coruscate cosh cosign
cosponsor cosset cost costume cotton couch cough counsel count countenance
counter counter-drill counteract counterattack counterbalance counterchallenge
counterchange countercheck counterclaim counterfeit countermand countermarch
countermine counterplot counterpoint counterpoise counterpose countersign
countersink counterstrike countervail counterweight country-dance couple course
court court-martial covenant cover covet cow cower cowhide cowl cox cozen crab
crack crackle cradle craft cram cramp cranch crane crank crap crape crash crash-
dive crate craunch crave crawfish crawl crayon craze creak cream crease create
credit creep cremate crenel crenelate crenellate creolize creosote crepe
crepitate crescendo crest crew crib crick cricket criminalise criminalize
criminate crimp crimson cringe crinkle cripple crisp crispen crisscross
criticise criticize critique croak crochet crock cronk crook croon crop croquet
cross cross-check cross-dress cross-fertilise cross-fertilize cross-file cross-
index cross-link cross-pollinate cross-refer crossbreed crosscut crosshatch
crossruff crouch crow crowd crown crucify cruise crumb crumble crump crumple
crunch crusade crush crust cry crystalise crystalize crystallise crystallize cub
cube cuckold cuckoo cuddle cudgel cue cuff cull culminate cultivate culture
cumber cumulate cup curb curdle cure curl curry currycomb curse curtail curtain
curtsey curtsy curve curvet cushion cuss custom-make customise customize cut
cutinize cybernate cycle cyclostyle cypher dab dabble dado daisy-chain dally dam
damage damascene damn damp dampen dance dandify dandle dangle dapple dare darken
darn dart dash date date-mark dateline datemark daub daunt dawdle dawn daydream
daze dazzle de-access de-aerate de-emphasise de-emphasize de-energise de-
energize de-escalate de-ice de-iodinate de-ionate deaccession deactivate deaden
deaerate deaf deafen deal deaminate deaminize debar debark debase debate debauch
debilitate debit debone debouch debrief debug debunk debut decaffeinate
decalcify decamp decant decapitate decarbonate decarbonise decarbonize
decarboxylate decarburise decarburize decay decease deceive decelerate
decentralise decentralize decerebrate decertify dechlorinate decide decimalise
decimalize decimate decipher deck declaim declare declassify declaw decline
declutch decoct decode decoke decollate decolonise decolonize decolor decolorise
decolorize decolour decolourise decolourize decommission decompose decompress
deconcentrate deconsecrate deconstruct decontaminate decontrol decorate
decorticate decouple decoy decrease decree decrepitate decrescendo decriminalise
decriminalize decry decrypt decussate dedicate dedifferentiate deduce deduct
deem deep-dye deep-fat-fry deep-fry deep-six deepen deface defalcate defame
defang defat default defeat defecate defect defeminise defeminize defend
defenestrate defer defervesce defibrillate defibrinate defile define deflagrate
deflate deflect deflower defog defoliate deforest deform defraud defray defrock
defrost defuse defy degas degauss degenerate deglaze deglycerolise deglycerolize
degrade degrease degust dehisce dehorn dehumanise dehumanize dehumidify
dehydrate dehydrogenate deice deify deign deionize deject delay delegate delete
deliberate delight delimit delimitate delineate deliquesce delist deliver
delocalize delouse delude deluge delve demagnetise demagnetize demand demarcate
demasculinise demasculinize dematerialise dematerialize demean demilitarise
demilitarize demineralise demineralize demise demist demo demob demobilise
demobilize democratise democratize demodulate demolish demonetise demonetize
demonise demonize demonstrate demoralise demoralize demote demulsify demur
demyelinate demystify demythologise demythologize denationalise denationalize
denaturalise denaturalize denature denazify denigrate denitrify denominate
denote denounce dent denudate denude deny deodorise deodorize deodourise
deoxidise deoxidize deoxygenate depart depend depersonalise depersonalize depict
depilate deplane deplete deplore deploy deplumate deplume depolarise depolarize
depone depopulate deport depose deposit deprave deprecate depreciate depress
depressurise depressurize deprive depute deputise deputize deracinate derail
derange derate derecognise derecognize deregulate derequisition derestrict
deride derive derogate desacralize desalinate desalinise desalinize desalt
descale descant descend describe descry desecrate desegregate desensitise
desensitize desert deserve desex desexualise desexualize desiccate design
designate desire desist desolate desorb despair despatch despise despoil despond
desquamate destabilise destabilize destain destalinise destalinize destine
destress destroy destruct desulfurize desulphurize desynchronise desynchronize
detach detail detain detect deter deterge deteriorate determine detest dethaw
dethrone detick detonate detour detox detoxicate detoxify detract detrain
detransitivise detransitivize detribalise detribalize detusk devaluate devalue
devastate devein develop deviate devil devilise devilize devise devitalise
devitalize devitrify devoice devolve devote devour diabolise diabolize diagnose
diagonalise diagonalize diagram dial dialyse dialyze diazotize dibble dice
dichotomise dichotomize dicker dictate didder diddle die diet differ
differentiate diffract diffuse dig digest digitalise digitalize digitise
digitize dignify digress dike dilapidate dilate dilly-dally dillydally dilute
dim dimension diminish dimple din dine ding dingdong dinge dip diphthongise
diphthongize direct dirty disable disabuse disaccord disadvantage disaffect
disafforest disagree disallow disambiguate disappear disappoint disapprove
disarm disarrange disarray disarticulate disassemble disassociate disavow
disband disbar disbelieve disbud disburden disburse disc-jockey discard discase
discern discerp discharge discipline disclaim disclose disco discolor
discolorise discolorize discolour discolourise discombobulate discomfit
discommode discompose disconcert disconnect discontent discontinue discord
discount discountenance discourage discourse discover discredit discriminate
discuss disdain disembark disembarrass disembody disembowel disembroil disenable
disenchant disencumber disenfranchise disengage disentangle disestablish
disesteem disfavor disfavour disfigure disforest disfranchise disgorge disgrace
disgruntle disguise disgust dish disharmonize dishearten dishevel dishonor
dishonour disillusion disincarnate disincline disinfect disinfest disinherit
disintegrate disinter disinvest disinvolve disjoin disjoint disk disk-jockey
dislike dislocate dislodge dismantle dismay dismember dismiss dismount disobey
disoblige disorder disorganise disorganize disorient disorientate disown
disparage dispatch dispel dispense disperse dispirit displace display displease
displume disport dispose dispossess dispread disprove dispute disqualify
disquiet disregard disrespect disrobe disrupt diss dissatisfy dissect dissemble
disseminate dissent dissertate dissever dissimilate dissimulate dissipate
dissociate dissolve dissonate dissuade distance distemper distend distil distill
distinguish distort distract distrain distress distribute district distrust
disturb disunify disunite ditch dither ditto divagate divaricate dive dive-bomb
diverge diversify divert divest divide divine divorce divulge dizen dizzy dj do
dock docket doctor document dodder dodge doff dog dogfight dogmatise dogmatize
dogsled domesticate domesticise domesticize domicile domiciliate dominate
domineer don donate dong doodle doom dope dose doss dot dote double double-check
double-date double-glaze double-park double-space double-team doubt douche douse
dovetail dower down downgrade download downplay downsize dowse doze draft drag
draggle dragoon drain dramatise dramatize drape draught draw drawl dread dream
dredge drench dress dribble drift drill drink drip drip-dry drive drivel drizzle
drone drool droop drop drop-kick dropforge dropkick drown drowse drub drudge
drug drum dry dry-dock dry-nurse dry-rot dry-wall drydock dub duck duel dulcify
dulcorate dull dumbfound dummy dump dun dung dunk dupe duplex duplicate dusk
dust dwarf dwell dwindle dye dyke dynamise dynamite dynamize e-mail eagle
earmark earn earth ease eat eavesdrop ebb ebonise ebonize echo eclipse economise
economize eddy edge edify edit editorialise editorialize educate educe
edulcorate eff efface effect effectuate effeminise effeminize effervesce
effloresce effuse egest egg egotrip egress ejaculate eject elaborate elapse
elate elbow elect electioneer electrify electrocute electroplate elegise elegize
elevate elicit elide eliminate elocute elongate elope elucidate elude elute
emaciate email emanate emancipate emasculate embalm embank embargo embark
embarrass embattle embed embellish embezzle embitter emblazon embody embolden
emboss embower embrace embrangle embrittle embrocate embroider embroil embrown
emcee emend emerge emigrate emit emote empale empanel empathise empathize
emphasise emphasize emplace emplane employ empower empty empurple emulate
emulsify enable enact enamel enamor enamour encamp encapsulate encase enchain
enchant encipher encircle enclose enclothe encode encompass encore encounter
encourage encrimson encroach encrust encrypt encumber end endanger endear
endeavor endeavour endorse endow endue endure energise energize enervate
enfeeble enfeoff enfilade enfold enforce enfranchise engage engender engild
engineer englut engorge engraft engrave engross engulf enhance enjoin enjoy
enkindle enlace enlarge enlighten enlist enliven enmesh ennoble enounce enplane
enquire enrage enrapture enrich enrobe enrol enroll ensconce enshrine enshroud
ensile ensky enslave ensnare ensnarl ensue ensure entail entangle enter
entertain enthral enthrall enthrone enthuse entice entitle entomb entrain
entrance entrap entreat entrench entrust entwine enucleate enumerate enunciate
envelop envenom environ envisage envision envy enwrap epilate epitomise
epitomize epoxy equal equalise equalize equate equilibrate equilibrise
equilibrize equip equivocate eradicate erase erect erode eroticize err eruct
erupt escalade escalate escallop escape eschew escort espouse espy essay
establish esteem esterify estimate estivate estrange etch eternalise eternalize
eternise eternize etherealize etherialise etherify etherise etherize etiolate
etymologise etymologize eulogise eulogize euphemise euphemize europeanise
europeanize evacuate evade evaluate evanesce evangelise evangelize evaporate
even eventuate evert evict evidence evince eviscerate evoke evolve exacerbate
exact exaggerate exalt examine exasperate excavate exceed excel except excerpt
exchange excise excite exclaim exclude excogitate excommunicate excoriate
excrete excruciate exculpate excuse execrate execute exemplify exempt exenterate
exercise exert exfoliate exhale exhaust exhibit exhilarate exhort exhume exile
exist exit exonerate exorcise exorcize expand expatiate expatriate expect
expectorate expedite expel expend expense experience experiment expiate expire
explain explicate explode exploit explore export expose exposit expostulate
expound express express-mail expropriate expunge expurgate exsert exsiccate
extemporise extemporize extend extenuate exteriorise exteriorize exterminate
externalise externalize extinguish extirpate extol extort extract extradite
extrapolate extravasate extricate extrude exuberate exudate exude exult exuviate
eye eyeball eyewitness fabricate face face-harden face-lift facilitate facsimile
factor factorise factorize fade fag faggot fagot fail faint fair fake falcon
fall falsify falter familiarise familiarize famish fan fancify fancy fantasise
fantasize fantasy farce fare farm farrow fart fascinate fashion fast fasten fat
fate father fathom fatigue fatten fault favor favour fawn fax faze fear feast
feather featherbed feature fecundate federalise federalize federate fee fee-tail
feed feel feign feint felicitate fell fellate felt feminise feminize fence fend
ferment ferret ferry fertilise fertilize fester festinate festoon fetch fete
fetishize fetter fettle feud feudalize fib fibrillate fictionalise fictionalize
fiddle fidget field field-test fight figure filch file filet filiate filibuster
filigree fill fillet film film-make filter filtrate fin finagle finalise
finalize finance financier find fine fine-tune finedraw finger finger-paint
finger-spell fingerprint fingerspell finish fink fire firebomb fireproof firm
fish fishtail fissure fistfight fit fix fixate fizz fizzle flabbergast flag
flagellate flail flake flambe flame flank flap flare flash flash-freeze flat-hat
flatten flatter flaunt flavor flavour flaw flay fleck fledge flee fleece fleer
fleet flense flesh flex flick flicker flight flim-flam flinch fling flip flip-
flop flirt flit flitter float flocculate flock flog flood floodlight floor flop
floss flounce flounder flour flourish flout flow flower flub fluctuate fluff
flummox flump flunk fluoresce fluoridate fluoridise fluoridize flurry flush
fluster flute flutter flux fly fly-fish flyfish foal foam fob focalise focalize
focus fodder fog foil foist fold foliate follow foment fondle fool foolproof
foot footle footnote footslog forage foray forbear forbid force force-feed
force-land ford forearm forebode forecast foreclose foredate foredoom forefend
foregather forego foreground foreknow foreordain foresee foreshadow foreshorten
foreshow forest forestall foreswear foretell forewarn forfeit forfend forgather
forge forget forgive forgo fork form formalise formalize format formicate
formularise formularize formulate fornicate forsake forswear fort fortify
forward fossilise fossilize foster foul found founder fowl fox foxhunt foxtrot
fraction fractionate fracture fragment fragmentise fragmentize frame franchise
frank frap fraternise fraternize fray frazzle freak freckle free free-associate
free-base freelance freeload freewheel freeze freeze-dry freight french french-
fry frenchify frequent fresco freshen fress fret fricassee fright frighten
fringe frisk fritter frivol frizz frizzle frock frog frogmarch frolic front
frost froth frown fructify fruit frustrate fry ftp fuck fuddle fudge fuel fulfil
fulfill full fullback fulminate fumble fume fumigate function fund fund-raise
fundraise funk funnel furbish furcate furl furlough furnish furrow further fuse
fusillade fuss fustigate g.i. gab gabble gad gag gage gaggle gain gainsay gall
gallivant gallop galumph galvanise galvanize gamble gambol game gang gang-rape
gangrene gaol gap gape garage garb garble garden gargle garland garment garner
garnish garnishee garotte garrison garrote garrotte garter gas gasconade gash
gasify gasp gate gate-crash gather gauffer gauge gawk gawp gaze gazette gazump
gear gee gel gelatinise gelatinize geld geminate general generalise generalize
generate gentle gentrify genuflect germinate gerrymander gestate gesticulate
gesture get geyser ghettoise ghettoize ghost ghostwrite gi gibber gibbet gibe
gift gift-wrap giggle gild gimp gin ginger gip gird girdle girth give glaciate
gladden glamorise glamorize glamour glamourise glamourize glance glare glass
glaze gleam glean glide glide-bomb glimmer glimpse glint glissade glisten
glitter gloat globalise globalize globe-trot glom glorify glory gloss glow
glower glue glug glut gluttonise gluttonize glycerolise glycerolize gnarl gnash
gnaw go goad gobble goffer goggle gold-plate goldbrick goldplate golf gong goof
goof-proof goofproof google goose gore gorge gormandise gormandize gossip gouge
gourmandize govern gown grab grace gradate grade graduate graft grain grandstand
grant granulate graph grapple grasp grass grate gratify grave gravel gravitate
gray graze grease green greet grey griddle grieve grill grimace grime grin grind
grip gripe grit grizzle groak groan groin grok groom groove grope gross grouch
ground group grouse grout grovel grow growl grub grubstake grudge grumble grunt
grunt-hoot gruntle guarantee guard guess guesstimate guffaw guggle guide
guillotine gull gulp gum gun gurgle gush gut gutter guttle guy guzzle gybe gyp
gyrate habilitate habit habituate hack hackle haemagglutinate haggle hail hale
halloo hallow hallucinate halt halter halve ham hammer hamper hamstring hand
hand-build hand-dye hand-pick hand-wash handbuild handcolor handcolour handcraft
handcuff handicap handle handstamp handwash handwrite hang hanker hap happen
harangue harass harbinger harbor harbour harden hare hark harken harlequin harm
harmonise harmonize harness harp harpoon harrow harry harshen harvest hash hasp
hassle hasten hat hatch hatchel hate haul haunt have haw hawk hay hazard haze
head headbutt headline headquarter heal heap hear hearken hearten heat heave
heckle hectograph hector hedge hedgehop hee-haw heed heel heft heighten heist
heliograph helm help hem hemagglutinate hemorrhage hemstitch hen-peck henna
herald herd hero-worship hesitate heterodyne hew hex hibachi hibernate hiccough
hiccup hide hie higgle high-tail highjack highlight hightail hijack hike hill
hinder hinge hint hire hiss hit hitch hitchhike hive hoard hoax hob hobble
hobnail hobnob hock hoe hog hog-tie hoist hold hole holiday holler hollo hollow
holystone home home-school homer homestead homogenise homogenize homologise
homologize hone honey honeycomb honeymoon honk honor honour hood hoodoo hoodwink
hoof hook hoop hoot hoover hop hop-skip hope hopple horn hornswoggle horrify
horripilate horse horse-race horse-trade horseshoe horsewhip hose hospitalise
hospitalize host hot-dog hot-wire hot-work hotfoot hound house house-train
housebreak houseclean housekeep hover howl huckster huddle hue huff hug hulk
hull hum humanise humanize humble humbug humidify humify humiliate humor humour
hump hunch hunger hunker hunt hurdle hurl hurrah hurry hurt hurtle husband hush
husk hustle hybridise hybridize hydrate hydrogen-bomb hydrogenate hydrolise
hydrolize hydrolyse hydrolyze hydroplane hygienise hygienize hymn hype
hyperbolise hyperbolize hyperextend hypertrophy hyperventilate hyphen hyphenate
hypnotise hypnotize hypophysectomise hypophysectomize hypostatise hypostatize
hypothecate hypothesise hypothesize ice idealise idealize ideate identify idle
idolise idolize ignite ignore ill-treat ill-use illegalise illegalize illume
illuminate illumine illustrate image imagine imbed imbibe imbricate imbrue imbue
imitate immaterialise immaterialize immerse immigrate immingle immix immobilise
immobilize immolate immortalise immortalize immunise immunize immure impact
impair impale impanel impart impeach impede impel impend imperil impersonate
impinge implant implement implicate implode implore imply import importune
impose impound impoverish imprecate impregnate impress imprint imprison improve
improvise improvize impugn impulse-buy impute inactivate inaugurate incandesce
incapacitate incarcerate incarnadine incarnate incase incense inch incinerate
incise incite incline inclose include incommode inconvenience incorporate
increase incriminate incrust incubate inculcate inculpate incur incurvate
indemnify indent indenture index indicate indict indispose indite individualise
individualize individuate indoctrinate indorse induce induct indue indulge
indurate industrialise industrialize indwell inebriate infatuate infect infer
infest infiltrate infix inflame inflate inflect inflict influence inform infract
infringe infuriate infuscate infuse ingeminate ingest ingraft ingrain ingratiate
ingurgitate inhabit inhale inhere inherit inhibit inhume initial initialise
initialize initiate inject injure ink inlay inmarry innervate innovate inoculate
inosculate input inquire inscribe inseminate insert inset insinuate insist
insolate inspan inspect inspire inspirit inspissate instal install instance
instantiate instigate instil instill institute institutionalise institutionalize
instruct instrument instrumentate insufflate insulate insult insure integrate
intend intensify inter interact interbreed intercalate intercede intercept
interchange intercommunicate interconnect interdepend interdict interest
interfere interiorise interiorize interject interlace interlard interleave
interlink interlock interlope interlude intermarry intermediate intermingle
intermit intermix intern internalise internalize internationalise
internationalize interpellate interpenetrate interpolate interpose interpret
interrelate interrogate interrupt intersect intersperse interstratify intertwine
intervene interview interweave intimate intimidate intonate intone intoxicate
intransitivise intransitivize intrench intrigue introduce introject intromit
introspect introvert intrude intrust intubate intuit intumesce intussuscept
inunct inundate inure invade invaginate invalid invalidate inveigh inveigle
invent inventory invert invest investigate invigilate invigorate invite invoice
invoke involve inweave iodinate iodise iodize ionate ionise ionize iridesce irk
iron irradiate irrigate irritate irrupt islamise islamize isolate isomerise
isomerize issue italicise italicize itch itemise itemize iterate itinerate jab
jabber jack jacket jackknife jacklight jackrabbit jactitate jade jag jail jam
jampack jangle japan jar jaundice jaunt jaw jawbone jaywalk jazz jeer jell
jellify jelly jeopardise jeopardize jerk jest jet jettison jewel jib jibe jig
jiggle jilt jimmy jingle jingle-jangle jinx jitterbug jive job jockey jog joggle
join joint joke jollify jolly jolt josh jostle jot jounce journey joust joy
joyride jubilate judder judge jug juggle julienne jumble jump jump-start
jumpstart junk junket junketeer justify jut juxtapose kayak kayo keel keen keep
kennel keratinise keratinize kern key keynote kibbitz kibitz kibosh kick kick-
start kid kidnap kill kindle kink kip kiss kit kite kitten knap knead kneecap
kneel knell knife knight knit knock knot know knuckle kotow kowtow kvetch label
labialise labialize labor labour lace lacerate lack lacquer lactate ladder lade
laden ladle lag laicise laicize lallygag lam lamb lambast lambaste lame lament
laminate lampoon lance land landscape languish lap lapidate lapidify lapse lard
lark larn larrup lash lasso last latch lateralize lather latinise latinize laud
laugh launch launder lave lavish lay layer laze leach lead leaf league leak lean
leap leapfrog learn lease leash leather leave leaven lecture leech leer legalise
legalize legislate legitimate legitimatise legitimatize legitimise legitimize
lend lengthen lenify lessen let letter levant level lever leverage levitate levy
lexicalise lexicalize liaise libel liberalise liberalize liberate librate
licence license lick lie lifehack lift ligate light lighten lighter lignify like
liken lilt limber lime limit limn limp line linearise linearize linger link
lionise lionize lip-read lip-sync lip-synch lipread lipstick liquefy liquidate
liquidise liquidize liquify lisp list listen literalise literalize lithograph
litigate litter live liven load loaf loan loathe lob lobby localise localize
locate lock locomote lodge loft log log-in logroll loiter loll lollop lollygag
long look loom loop loose loosen loot lop lope lord lose lot louden lounge lour
love low lowball lower lube lubricate lucubrate luff lug luge lull lumber
luminesce lump lunch lunge lurch lure lurk lust lustrate luxate luxuriate lynch
lyophilise lyophilize lyric lysogenize macadamise macadamize macerate
machicolate machinate machine machine-wash macrame maculate madden madder
madrigal magnetise magnetize magnify mail maim mainline maintain major make
maledict malfunction malign malinger malnourish malt maltreat malversate mambo
man manacle manage mandate manducate maneuver mangle manhandle manicure manifest
manifold manipulate manoeuver manoeuvre mantle manufacture manumit manure map
mapquest mar maraud marble marbleise marbleize marcel march marginalise
marginalize marinade marinate mark market maroon marry marshal martyr martyrise
martyrize marvel masculinise masculinize mash mask masquerade mass mass-produce
massacre massage master mastermind masticate masturbate mat match mate
materialise materialize matriculate matt-up matte matter maturate mature maul
maunder maximise maximize mean meander measure mechanise mechanize meddle
mediate medicate medicine meditate meet melanise melanize meld meliorate mellow
melodise melodize melt memorialise memorialize memorise memorize menace mend
menstruate mensurate mention mentor meow mercerise mercerize merchandise merge
merit mesh mesmerise mesmerize mess message metabolise metabolize metal metalize
metallize metamorphose metastasise metastasize meter metricate metricise
metricize metrify mew mewl miaou miaow micro-cook microcopy microfilm microwave
micturate middle miff migrate mildew militarise militarize militate milk mill
mime mimeo mimeograph mimic mince mind mine mineralize mingle miniate
miniaturise miniaturize minify minimise minimize minister minstrel mint mire
mirror misaddress misadvise misalign misally misapply misapprehend
misappropriate misbehave misbelieve miscalculate miscall miscarry miscast
miscegenate misconceive misconduct misconstrue miscount miscreate misdate
misdeal misdeliver misdemean misdirect misdo misestimate misfire misfunction
misgauge misgive misgovern misguide mishandle misidentify misinform misinterpret
misjudge mislay mislead mismanage mismarry mismatch mismate misname misperceive
misplace misplay misprint mispronounce misquote misread misremember misrepresent
miss misspeak misspell misspend misstate mist mistake mistime mistranslate
mistreat mistrust misunderstand misuse miter mitigate mix mizzle moan mob
mobilise mobilize mock model moderate modernise modernize modify modulate moil
moisten moisturise moisturize mold molder molest mollify mollycoddle molt
monetise monetize monger mongrelise mongrelize monish monitor monkey monologuise
monologuize monopolise monopolize monumentalise monumentalize moo mooch moon
moonlight moonshine moor moot mop mope moralise moralize morph mortar mortgage
mortice mortify mortise mosey mosh mothball mother mothproof motion motivate
motley motor motorbike motorboat motorcycle motorise motorize mottle mould
moulder moult mound mount mountaineer mourn mouse mousse mouth move mow muck
muckrake mud mud-wrestle muddle muddy mudwrestle muff muffle mug mulch mulct
mull multiply mumble mummify munch munition murder murk murmur muscle muse mush
mushroom muss mussitate muster mutate mute mutilate mutiny mutter muzzle mystify
mythicise mythicize mythologise mythologize nab nag nail name namedrop nap
narcotise narcotize nark narrate narrow nasale nasalise nasalize nationalise
nationalize natter naturalise naturalize nauseate navigate nazify near neaten
necessitate neck necrose need needle negate negative neglect negociate negotiate
neigh neighbor neighbour nerve nest nestle net netmail nett nettle network
neuter neutralise neutralize nibble nick nickel nickel-and-dime nicker nickname
nictate nictitate niggle nigrify nip nitpick nitrate nitrify nitrogenise
nitrogenize nix nobble nock nod noise nol.pros. nominate nonplus noose normalise
normalize nose nosedive nosh notarise notarize notate notch note notice notify
nourish novate novelise novelize nucleate nudge nuke nullify numb number
numerate nurse nurture nut nutate nutrify nuzzle o.d. o.k. obey obfuscate object
objectify objurgate obligate oblige obliterate obnubilate obscure observe obsess
obsolesce obstinate obstipate obstruct obtain obtrude obtund obturate obviate
occasion occidentalise occidentalize occlude occult occupy occur odorize
odourise off offend offer officer officialise officialize officiate offload
offsaddle offset ogle oil oink okay omen omit one-step ooh ooze opacify opalesce
opalise opalize open operate opine oppose oppress oppugn opsonize opt optimise
optimize orate orb orbit orchestrate ordain order ordinate organise organize
orient orientalise orientalize orientate originate ornament orphan oscillate
osculate ossify ostentate ostracise ostracize oust out out-herod outbalance
outbid outbrave outcall outclass outcrop outcry outdistance outdo outdraw
outface outfight outfit outflank outfox outgeneral outgo outgrow outguess
outlast outlaw outline outlive outmaneuver outmanoeuvre outmarch outmatch
outmode outnumber outpace outperform outplay outpoint output outrage outrange
outrank outride outrival outroar outrun outsail outscore outsell outshine
outshout outsmart outsource outspan outstare outstay outstrip outvie outvote
outwear outweigh outwit ovenbake over-correct over-refine overachieve overact
overarch overawe overbalance overbear overbid overboil overburden overcapitalise
overcapitalize overcast overcharge overclothe overcloud overcome overcompensate
overcook overcrop overcrowd overcultivate overdo overdose overdramatise
overdramatize overdraw overdress overdrive overeat overemphasise overemphasize
overestimate overexert overexploit overexpose overextend overfatigue overfeed
overfill overflow overfly overgeneralise overgeneralize overgorge overgrow
overhang overhaul overhear overheat overindulge overjoy overlap overlay overleap
overlie overload overlook overmaster overpay overplay overpopulate overpower
overpraise overprice overprint overproduce overprotect overrate overreach
overreact overrefine override overrule overrun oversee oversew overshadow
overshoot oversimplify oversleep overspecialise overspecialize overspend
overspread overstate overstay overstep overstock overstrain overstress
overstretch overstuff oversupply overtake overtax overthrow overtire overtop
overtrump overturn overuse overvalue overweary overwhelm overwinter overwork
overwrite ovulate owe own oxidate oxidise oxidize oxygenate oxygenise oxygenize
oyster ozonise ozonize pace pacify pack package pad paddle padlock paganise
paganize page paginate pain paint pair pal palatalise palatalize palaver pale
palisade pall palliate palm palpate palpebrate palpitate palsy palter pamper pan
pan-broil pan-fry pander panel panhandle panic pant pant-hoot pantomime paper
par parachute parade paragraph parallel parallel-park parallelize paralyse
paralyze paraphrase parboil parcel parch pardon pare parent parget park parlay
parley parody parole parrot parry parse part partake parti-color participate
particularise particularize partition partner party pass paste pasteurise
pasteurize pasture pat patch patent patinate patinise patinize patrol patronage
patronise patronize patter pattern pattern-bomb pauperise pauperize pause pave
paw pawn pay peach peak peal pearl peck peculate pedal peddle pedicure pee pee-
pee peek peel peep peer peeve peg pelt pen penalise penalize pencil penetrate
penny-pinch pension people pepper peptise peptize perambulate perceive perch
percolate percuss peregrinate perennate perfect perforate perform perfume
perfuse peril perish perjure perk perm permeate permit permute perorate peroxide
perpetrate perpetuate perplex persecute perseverate persevere persist
personalise personalize personate personify perspire persuade pertain perturb
peruse pervade pervaporate pervert pester pestle pet petition petrify pettifog
phase philander philosophise philosophize phlebotomise phlebotomize phonate
phone phosphoresce photocopy photograph photosensitise photosensitize photostat
phrase pick picket pickle picnic picture piddle piece piece-dye pierce piffle
pig pigeonhole piggyback pigment pile pilfer pillage pillory pillow pilot pimp
pin pinch pine ping pinion pink pinkify pinnacle pinpoint pioneer pip pipe pipe-
clay pique pirate pirouette piss pistol-whip pit pitch pitchfork pith pitter-
patter pity pivot placard placate place place-kick plagiarise plagiarize plague
plain plait plan plane plank plant plash plaster plasticise plasticize
plastinate plat plate platinize platitudinize play playact plea-bargain pleach
plead please pleat pledge plicate plight plod plonk plop plot plough plow pluck
plug plumb plume plummet plump plunder plunge plunk pluralise pluralize ply
poach pock pocket pockmark pod podcast poetise poetize point poise poison poke
polarise polarize pole poleax poleaxe polemicise polemicize polemise polemize
police polish politicise politicize politick polka poll pollard pollenate
pollinate pollute polychrome polychromise polychromize polymerise polymerize
pomade pommel pompadour ponder poniard pontificate pooch pooh-pooh pool pop
popularise popularize populate porcelainize pore port portend porter portion
portray pose posit position possess post postdate postmark postpone postpose
postulate posture pot potentiate pother potter pouch poultice pounce pound pour
pout powder powderise powderize power power-dive powerwash powwow practice
practise praise prance prang prank prate prattle prawn pray preach preachify
preamble prearrange preassemble precede precess precipitate precis preclude
preconceive precondition precook predate predecease predestinate predestine
predetermine predicate predict predigest predispose predominate preempt preen
preexist prefabricate preface prefer prefigure prefix preform preheat prehend
preisolate prejudge prejudice prelude premeditate premier premiere premise
premiss preoccupy preordain prepare prepay preponderate prepose prepossess
prerecord presage prescribe present preserve preside press pressure pressure-
cook pressure-wash pressurise pressurize presume presuppose pretend pretermit
prettify prevail prevaricate prevent preview previse prey price prick prickle
pride prim prime primp prink print prioritise prioritize prise privatise
privatize privilege prize prizefight probate probe proceed process proclaim
procrastinate procreate proctor procure prod produce profane profess
professionalise professionalize proffer profile profit profiteer prognosticate
program programme progress prohibit project prolapse proliferate prologise
prologize prologuize prolong promenade promise promote prompt promulgate pronate
pronk pronounce proof proofread prop propagandise propagandize propagate propel
prophesy propitiate proportion propose proposition propound prorate prorogue
proscribe prosecute proselytise proselytize prospect prosper prostitute
prostrate protect protest protract protrude protuberate prove provide provision
provoke prowl prune pry psalm psychoanalyse psychoanalyze ptyalise ptyalize pub-
crawl publicise publicize publish pucker puddle puff puke pule pull pullulate
pulp pulsate pulse pulverise pulverize pumice pummel pump pun punch punctuate
puncture punish punt pup pupate purchase puree purge purify purl purloin purple
purport purpose purpurate purr purse pursue purvey push pussyfoot put putrefy
putt putter putty puzzle pyramid quack quadruple quadruplicate quaff quail quake
qualify quantify quantise quantize quarantine quarrel quarry quarter quarterback
quash quaver queen queer quell quench query quest question quetch queue quibble
quick-freeze quicken quickstep quiesce quiet quieten quilt quintuple quip quirk
quit quiver quiz quote rabbet rabbit race rack racket racketeer raddle radiate
radicalize radio radiolocate raffle raft rafter rag rage raid rail railroad
raiment rain raise rake rally ram ramble ramify ramp rampage ranch randomise
randomize range rank rankle ransack ransom rant rap rape rappel rarefy rarify
rase rasp rasterize rat ratchet rate ratify ratiocinate ration rationalise
rationalize rattle ravage rave ravel raven ravish ray raze razor razz re-address
re-afforest re-argue re-arm re-assume re-create re-emerge re-emphasise re-
emphasize re-enter re-equip re-examine re-explain re-explore re-incorporate re-
introduce re-start reabsorb reach reacquaint react reactivate read readapt
readjust readmit ready reaffirm realign realine realise realize reallocate
reallot ream reanimate reap reappear reapportion reappraise rear rear-end rearm
rearrange reason reassail reassemble reassert reassess reassign reassure
reattribute reave reawaken rebate rebel rebind reboot rebound rebroadcast rebuff
rebuild rebuke rebury rebut recalcitrate recalculate recall recant recap
recapitulate recapture recast recede receipt receive recess recharge recidivate
reciprocate recite reckon reclaim reclassify recline recode recognise recognize
recoil recollect recombine recommence recommend recommit recompense reconcile
recondition reconfirm reconnoiter reconnoitre reconquer reconsecrate reconsider
reconstitute reconstruct reconvene reconvert reconvict recopy record recount
recoup recover recreate recriminate recrudesce recruit rectify recumb recuperate
recur recurve recuse recycle red-eye red-ink redact redden rede redecorate
rededicate redeem redefine redeploy redeposit redesign redetermine redevelop
redirect rediscover redispose redistribute redline redo redouble redound redress
reduce reduplicate reecho reef reek reel reelect reenact reenforce reestablish
reevaluate reeve reexamine reface refashion refer referee reference refill
refinance refine refinish refit reflate reflect reflectorise reflectorize
refloat refocus reforest reforge reform reformulate refract refracture refrain
refresh refreshen refrigerate refuel refund refurbish refurnish refuse refute
regain regale regard regenerate regiment register regorge regress regret regroup
regrow regularise regularize regulate regurgitate rehabilitate reharmonise
reharmonize rehash rehear rehearse reheat reheel rehouse reify reign reignite
reimburse reimpose rein reincarnate reinforce reinstall reinstate reinsure
reintegrate reinterpret reintroduce reinvent reinvigorate reissue reiterate
reject rejig rejoice rejoin rejuvenate rekindle relace relapse relate relativise
relativize relax relay relearn release relegate relent relieve reline relinquish
relish relive reload relocate rely relyric remain remainder remake remand remark
remarry remediate remedy remember remilitarise remilitarize remind reminisce
remit remodel remold remonstrate remould remount remove remunerate rename rend
render render-set rendezvous renegade renege renegociate renegotiate renew
renormalise renormalize renounce renovate rent reopen reorder reorganise
reorganize reorient reorientate repaint repair repatriate repay repeal repeat
repel repent repercuss rephrase repine replace replant replay replenish replete
replicate reply repoint report repose reposit reposition repossess repot
reprehend represent repress reprieve reprimand reprint reprise reprize reproach
reprobate reprocess reproduce reproof reprove republish repudiate repugn repulse
repurchase repute request require requisition requite reread rerun rescale
reschedule rescind rescue reseal research reseat resect reseed resell resemble
resent reserve reset resettle resew reshape reship reshoot reshuffle reside
resift resign resile resinate resist resize resmudge resole resolve resonate
resorb resort resound respect respire respite resplend respond rest restart
restate restitute restock restore restrain restrengthen restrict restructure
resublime resubmit result resume resurface resurge resurrect resuscitate
resuspend ret retail retain retake retaliate retard retch retell rethink retick
reticulate retie retire retool retort retouch retrace retract retrain
retranslate retransmit retread retreat retrench retrieve retrofit retroflex
retrograde retrogress retrospect retrovert retry return reunify reunite reuse
rev revalue revamp reveal revel revenge reverberate revere reverence reverse
revert revet review revile revise revisit revitalise revitalize revive revivify
revoke revolt revolutionise revolutionize revolve reward rewire reword rework
rewrite rhapsodise rhapsodize rhumba rhyme rib rice rick ricochet rid riddle
ride ridge ridicule riff riffle rifle rig right rigidify rile rim rime ring
rinse riot rip ripen riposte ripple rise risk ritualise ritualize rival rive
rivet roach roam roar roast rob robe rock rocket roil roister roleplay roll
rollerblade rollick romance romanise romanize romanticise romanticize romp roneo
roof rook room roost root rootle rope rosin rot rotate rouge rough rough-dry
rough-hew rough-house rough-sand roughcast roughen roughhouse round rouse rout
route rove row rub rubber rubberise rubberize rubberneck rubberstamp rubbish
rubify rubric rubricate ruck ruckle ruddle rue ruff ruffle ruggedise ruggedize
ruin rule rumba rumble ruminate rummage rumor rumour rumple rumpus run rupture
rush rust rusticate rustle rut saber sabotage sabre saccharify sack sacrifice
sadden saddle safeguard sag sail sailplane saint salaam salinate salivate sallow
salt saltate salute salvage salve samba sample sanctify sanction sand sandbag
sandblast sandpaper sandwich sanitate sanitise sanitize sap saponify sashay sass
sate satellite satiate satirise satirize satisfice satisfise satisfy saturate
sauce saunter saute savage save savor savour savvy saw say scab scaffold scald
scale scallop scalp scam scamp scamper scan scandalise scandalize scant scar
scare scarf scarify scarper scat scatter scavenge scend scent schedule
schematise schematize scheme schlep schmoose schmooze schnorr school schuss
scintillate scissor sclaff scoff scold scollop scoop scoot scorch score scorn
scotch scour scourge scout scowl scrabble scrag scram scramble scranch scrap
scrape scratch scraunch scrawl screak scream screech screen screw scribble
scribe scrimmage scrimp scrimshank script scroll scrounge scrub scrunch scruple
scrutinise scrutinize scry scud scuff scuffle scull sculpt sculpture scum
scupper scurry scuttle scythe seal seam seaplane sear search season seat secede
secern secernate seclude second second-guess secrete section sectionalise
sectionalize secularise secularize secure sedate sediment seduce see seed seek
seel seem seep seesaw seethe segment segregate segue seine seize select self-
destroy self-destruct sell sellotape semaphore semi-automatise semi-automatize
send senesce sense sensibilise sensibilize sensify sensitise sensitize
sensualise sensualize sentence sentimentalise sentimentalize sentimentise
sentimentize separate sequence sequester sequestrate serenade serialise
serialize sermonise sermonize serrate serve service set settle sever severalise
severalize sew sex sexualise sexualize shack shackle shade shadow shadowbox
shaft shag shake shallow sham shamanise shamanize shamble shame shampoo shanghai
shank shape share shark sharpen sharpshoot shatter shave she-bop shear sheathe
shed sheer sheet shell shellac shellack shelter shelve shepherd shew shield
shift shill shillyshally shimmer shimmy shin shine shingle shinny ship shipwreck
shirk shirr shirt shit shiver shlep shmoose shmooze shnorr shoal shock shoe
shoehorn shoetree shoo shoot shop shoplift shore short short-change short-
circuit shorten shortlist shoulder shout shove shovel show shower shred shriek
shrill shrimp shrine shrink shrinkwrap shrive shrivel shroud shrug shuck shudder
shuffle shun shunt shush shut shutter shuttle shuttlecock shy sibilate sic sick
sicken side side-slip sideline sidestep sideswipe sidetrack sidle sieve sift
sigh sight sight-read sight-sing sightread sightsee sightsing sign signal
signalise signalize signify signpost silence silhouette silkscreen silt silver
silver-plate silverplate simmer simonise simonize simper simplify simulate sin
sing singe single single-foot singsong singularise singularize sink sinter sip
siphon sire siss sit site situate size sizz sizzle skank skate skateboard
skedaddle sketch skew skewer ski skid skim skimcoat skimp skin skin-dive skinny-
dip skip skip-bomb skipper skirl skirmish skirt skitter skittle skive skreak
skreigh skulk skunk sky skydive skyjack skylark skyrocket slabber slack slacken
slag slake slalom slam slam-dunk slander slang slant slap slash slat slate
slather slaughter slave slaver slay sled sledge sledgehammer sleek sleep
sleepwalk sleet sleigh slenderise slenderize sleuth slew slice slick slide
slight slim slime sling slink slip slit slither sliver slobber slog sloganeer
slop slope slosh slot slouch slough slow slue slug sluice slum slumber slump
slur slurp slush smack smart smash smatter smear smell smelt smile smirch smirk
smite smock smoke smolder smooch smooth smoothen smother smoulder smudge smuggle
smut smutch snack snaffle snafu snag snail snake snap snare snarf snarl snatch
sneak sneer sneeze snick snicker sniff sniffle snigger snip snipe snitch snivel
snog snooker snoop snooze snore snorkel snort snow snow-blind snowball snowboard
snowmobile snowshoe snub snuff snuffle snuggle soak soap soar sob sober
socialise socialize sock sod sodomise sodomize soft-pedal soft-soap soft-solder
soften soil sojourn solace solarise solarize solder soldier sole solemnise
solemnize solicit solidify soliloquise soliloquize solmizate solo solvate solve
somersault somnambulate sonnet soot soothe sop sophisticate sorb sorcerise
sorcerize sorrow sort sough sound soundproof soup sour source souse sovietise
sovietize sow space spacewalk spade spam span spang spangle spank spar spare
sparge spark sparkle spat spatchcock spatter spawn spay speak spear spearhead
specialise specialize speciate specify speck speckle spectate speculate speech-
read speechify speed spell spellbind spelunk spend spew sphacelate spice spiel
spike spill spin spin-dry spiral spirit spiritise spiritize spiritualise
spiritualize spirt spit spite splash splat splatter splay splice splint splinter
split splosh splotch splurge splutter spoil spondaise spondaize sponge sponsor
spoof spook spool spoon spoonfeed sport sportscast sporulate spot spot-check
spot-weld spotlight spotweld spout sprain sprawl spray spray-dry spread spread-
eagle spreadeagle spree spring spring-clean sprinkle sprint spritz sprout spruce
spud spue spume spur spurn spurt sputter spy squabble squall squander square
squash squat squawk squeak squeal squeegee squeeze squelch squinch squint squire
squirm squirt squish stab stabilise stabilize stable stack staff stag stage
stagger stagnate stain stake stale stalemate stalinise stalinize stalk stall
stammer stamp stampede stanch stand standardise standardize staple star
starboard starch stare stargaze start startle starve stash state station staunch
stave stay steady steal steam steam-heat steamer steamroll steamroller steel
steep steepen steer stem stencil stenograph step stereotype sterilise sterilize
stet stew stick stickle stiffen stifle stigmatise stigmatize still still-fish
still-hunt stimulate sting stink stint stipple stipulate stir stitch stock
stock-take stockade stockpile stoke stomach stomp stone stone-wash stonewall
stonewash stooge stool stoop stop stopper stopple store storm stow straddle
strafe straggle straighten strain straiten strand strangle strangulate strap
stratify straw stray streak stream streamline street-walk streetwalk strengthen
stress stretch strew striate strickle stride stridulate strike string strip
strip-search stripe strive stroke stroll strong-arm strop structure struggle
strum strut stub stucco stud study stuff stultify stumble stump stun stunt
stupefy stutter style stylise stylize stymie stymy sub subcontract subdivide
subdue subedit subject subjoin subjugate sublease sublet sublimate sublime
subluxate submarine submerge submerse submit subordinate suborn subpoena
subrogate subscribe subserve subside subsidise subsidize subsist substantiate
substitute subsume subtend subtilise subtilize subtitle subtract suburbanise
suburbanize subvent subvention subvert subvocalise subvocalize succeed succor
succour succumb succuss suck suckle suction sudate suds sue suffer suffice
suffix suffocate suffuse sugar sugarcoat suggest suit sulfate sulfur sulfurette
sulk sully sulphur sulphurette sum summarise summarize summate summer summerise
summerize summit summon summons sun sunbathe sunburn sunder suntan sup
superannuate supercede supercharge superfetate superimpose superinfect
superintend superordinate superpose superscribe supersede supervene supervise
supinate supplant supple supplement supplicate supply support suppose suppress
suppurate surcharge surf surface surface-mine surfboard surfeit surge surmise
surmount surpass surprise surrender surround surtax surveil survey survive
suspect suspend suspire sustain susurrate suture swab swaddle swag swage swagger
swallow swamp swan swank swap swarm swash swat swathe swatter sway swear sweat
sweep sweet-talk sweeten swell swelter swerve swig swill swim swindle swing
swinge swipe swirl swish switch switch-hit swivel swob swoon swoop swoosh swop
swosh swot syllabicate syllabify syllabise syllabize syllogise syllogize
symbolise symbolize symmetrise symmetrize sympathise sympathize symphonise
symphonize sync synchronise synchronize syncopate syncretise syncretize
syndicate synthesise synthesize syphon syringe systematise systematize systemise
systemize table taboo tabularise tabularize tabulate tack tackle tag tail
tailgate tailor tailor-make taint take talc talk tally tame tamp tamper tampon
tan tangle tango tank tantalise tantalize tap tapdance tape taper tar tar-and-
feather target tariff tarmac tarnish tarry task taste tat tattle tattoo taunt
tauten tax taxi teach team tear teargas tease tee teem teeter teeter-totter
teetertotter teethe teetotal telecast telecommunicate telefax telegraph
telepathise telepathize telephone teleport telescope televise telex tell temper
temporise temporize tempt tenant tend tender tenderise tenderize tense tent
tenure tergiversate term terminate terrace terrasse terrify territorialise
territorialize terrorise terrorize tessellate test testify tether thank thatch
thaw theme theologise theologize theorise theorize thermostat thicken thieve
thin think thirst thoriate thrash thread threaten thresh thrill thrive throb
thrombose throne throng throttle throw thrum thrust thud thumb thumbtack thump
thunder thurify thwack thwart tick ticket tickle ticktack ticktock tide tidy tie
tie-dye tighten tile till tiller tilt time tin tinct tincture ting tinge tingle
tink tinker tinkle tinsel tint tintinnabulate tip tipple tippytoe tiptoe tire
tissue tithe titillate titivate title titrate titter tittivate tittle-tattle
tittup toady toast toboggan toddle toe toenail tog toggle toil toilet-train
tolerate toll tomahawk tone tongue tongue-tie tonsure tool toot tootle top
topdress tope topicalize topple torch torment torpedo torture toss tot total
totalise totalize tote totter touch touch-type toughen tour tourney tousle tout
tow towel tower toy trace track trade trademark traduce traffic trail train
traipse tram trammel tramp trample trance tranquilize tranquillise tranquillize
transact transaminate transcend transcribe transduce transect transfer
transfigure transfix transform transfuse transgress transistorise transistorize
transit transition transitivise transitivize translate transliterate translocate
transmigrate transmit transmogrify transmute transpirate transpire transplant
transport transpose transship transubstantiate transude trap trash traumatise
traumatize travail travel traverse travesty trawl tread treadle treasure treat
treble tree trek trellis tremble tremor trench trend trepan trephine trespass
triangulate tribulate trice trick trickle trifle trifurcate trigger trill trim
trip triple triple-space triple-tongue triplicate trisect triumph trivialise
trivialize troat troll troop trot trouble trouble-shoot troubleshoot trounce
trowel truck truckle trudge true trump trumpet truncate trundle truss trust try
tsk tube tuck tucker tug tumble tumefy tumesce tune tunnel turf turn turtle tusk
tussle tut tut-tut tutor twaddle twang tweak tweedle tweet tweeze twiddle twig
twill twin twine twinge twinkle twirl twirp twist twit twitch twitter two-step
two-time type typecast typeset typewrite typify tyrannise tyrannize uglify
ulcerate ultracentrifuge ululate umpire unarm unbalance unbar unbelt unbend
unbind unblock unbolt unbosom unbox unbrace unbraid unbridle unbuckle unburden
unbutton uncase unchain unchurch unclasp unclip uncloak unclog unclothe
unclutter uncoil uncompress uncork uncouple uncover uncrate uncross uncurl
undeceive underachieve underact underbid undercharge undercoat undercut
underdevelop underdress underestimate underexpose undergird undergo undergrow
underlay underlie underline undermine undernourish underpay underperform
underpin underplay underprice underproduce underquote underrate underscore
undersell undershoot undersign underspend understand understate understock
understudy undertake undervalue underwrite undo undock undrape undress undulate
unearth unfasten unfit unfold unfreeze unfrock unfurl unhallow unhand unharness
unhinge unhitch unhook unhorse unicycle uniform uniformise uniformize unify
unionise unionize unite unitise unitize universalise universalize unknot unlace
unlade unlash unlax unlearn unleash unlive unload unlock unloose unloosen unmake
unman unmask unmuzzle unnerve unpack unpick unpin unplug unravel unreel unroll
unsaddle unsanctify unsay unscramble unscrew unseal unseat unsettle unsex
unsheathe unsnarl unsolder unspell unstaple unstrain unstrap unstring unstuff
unsubstantialise unsubstantialize untangle unteach unthaw untie untune untwine
untwist unveil unweave unwind unwire unwrap unyoke unzip up upbraid upchuck
update upend upgrade upheave uphold upholster uplift upload upraise uprise
uproot upset upstage urbanise urbanize urge urinate urticate use usher usurp
utilise utilize utter vacate vacation vaccinate vacillate vacuum vacuum-clean
vagabond valet validate valuate value vamoose vamp vandalise vandalize vanish
vanquish vaporise vaporize variegate varnish vary vascularise vascularize
vasectomise vasectomize vaticinate vault vaunt veer vegetate veil vein velcro
vellicate vend veneer venerate venesect vent ventilate venture verbalise
verbalize verbify verdigris verge verify vermiculate vermilion verse versify
vesicate vesiculate vest vesture vet veto vex vibrate victimise victimize
victual videotape vie view vilify vilipend vindicate vinify violate virilise
virilize visa visit visualise visualize vitalise vitalize vitaminise vitaminize
vitiate vitrify vitriol vituperate vivify vivisect vocalise vocalize vociferate
voice void volatilise volatilize volley volunteer vomit voodoo vote vouch
vouchsafe vow vowelise vowelize voyage vroom vulcanise vulcanize vulgarise
vulgarize wad waddle wade waffle waft wag wage wager waggle wail wait waitress
waive wake waken walk wall wallop wallow wallpaper waltz wamble wan wander wane
wangle wank want wanton war warble ward ware warehouse warm warn warp warrant
wash wassail waste watch water water-wash watercolor watercolour waterproof
wattle waul wave waver wawl wax waylay weaken wean weaponize wear weary weather
weatherproof weatherstrip weave web wed wedel wedge wee wee-wee weed weekend
weep weigh weight weight-lift weightlift welch welcome weld well welsh welt
welter wench wend westernise westernize wet wet-nurse whack whale wham whang
whap wharf wheedle wheel wheelbarrow wheeze whelk whelm whelp whet whicker whiff
whimper whine whinny whip whipsaw whir whirl whirligig whirlpool whirr whish
whisk whisker whisper whistle whistlestop white white-out whiten whiteout
whitewash whittle whiz whizz wholesale whomp whoop whoosh whop whore widen widow
wield wiggle wigwag will wilt win wince winch wind window-dress window-shop
windsurf wine wing wink winkle winnow winter winterise winterize wipe wire
wiretap wisecrack wish witch withdraw wither withhold withstand witness wive
wobble wolf wolf-whistle womanise womanize wonder woo woolgather woosh word work
worm worry worsen worship worst wound wow wrack wrangle wrap wrawl wreak wreathe
wreck wrench wrest wrestle wrick wriggle wring wrinkle write writhe wrong x-ray
xerox yacht yack yak yammer yank yap yarn yarn-dye yaup yaw yawl yawn yawp yearn
yell yellow yelp yen yield yip yodel yoke yowl zap zero zest zigzag zinc zip
zipper zone zoom
""".split())
