#  tests for spacy-2.0.11-py36h6440ff4_2 (this is a generated file);
print('===== testing package: spacy-2.0.11-py36h6440ff4_2 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import sys
import pytest
import spacy

PACKAGE_DIR = os.path.abspath(os.path.dirname((spacy.__file__)))
sys.exit(pytest.main([PACKAGE_DIR]))
#  --- run_test.py (end) ---

print('===== spacy-2.0.11-py36h6440ff4_2 OK =====');
print("import: 'spacy'")
import spacy

