# coding: utf8
from __future__ import unicode_literals


LOOKUP = {
    "Ap.": "après",
    "Apr.": "après",
    "Auxerroises": "Auxerrois",
    "Av.": "avenue",
    "Ave.": "avenue",
    "Avr.": "avril",
    "Bd.": "boulevard",
    "Boliviennes": "Bolivien",
    "Canadiennes": "Canadien",
    "Cannoises": "Cannois",
    "Cantonaises": "Cantonais",
    "Colombiennes": "Colombien",
    "Costaricaines": "Costaricain",
    "Costaricienne": "Costaricien",
    "Costariciens": "Costaricien",
    "Dr.": "docteur",
    "Erinyes": "Erinye",
    "Fêtes-Dieu": "Fête-Dieu",
    "Haïtiennes": "Haïtien",
    "Honduriennes": "Hondurien",
    "Indonésiennes": "Indonésien",
    "Jordaniennes": "Jordanien",
    "Khmères": "Khmer",
    "Laotiennes": "Laotien",
    "Libyennes": "Libyen",
    "Libériennes": "Libérien",
    "M.": "monsieur",
    "Mauritaniennes": "Mauritanien",
    "Messrs.": "messieurs",
    "Mlle.": "mademoiselle",
    "Mm.": "messieurs",
    "Mme.": "madame",
    "Mr.": "monsieur",
    "Mrs.": "messieurs",
    "Ms.": "messieurs",
    "Néo-zélandaises": "Néo-zélandais",
    "ONGs": "ONG",
    "Palestiniennes": "Palestinien",
    "Pr.": "professeur",
    "Salvadoriennes": "Salvadorien",
    "Soudanaises": "Soudanais",
    "St.": "saint",
    "Ste.": "sainte",
    "Vol.": "volume",
    "a": "avoir",
    "a jeun": "à jeun",
    "abaissa": "abaisser",
    "abaissai": "abaisser",
    "abaissaient": "abaisser",
    "abaissais": "abaisser",
    "abaissait": "abaisser",
    "abaissant": "abaisser",
    "abaissante": "abaissant",
    "abaissas": "abaisser",
    "abaissasse": "abaisser",
    "abaissassent": "abaisser",
    "abaissasses": "abaisser",
    "abaissassiez": "abaisser",
    "abaissassions": "abaisser",
    "abaisse": "abaisser",
    "abaissements": "abaissement",
    "abaissent": "abaisser",
    "abaissera": "abaisser",
    "abaisserai": "abaisser",
    "abaisseraient": "abaisser",
    "abaisserais": "abaisser",
    "abaisserait": "abaisser",
    "abaisseras": "abaisser",
    "abaisserez": "abaisser",
    "abaisseriez": "abaisser",
    "abaisserions": "abaisser",
    "abaisserons": "abaisser",
    "abaisseront": "abaisser",
    "abaisses": "abaisser",
    "abaissez": "abaisser",
    "abaissiez": "abaisser",
    "abaissions": "abaisser",
    "abaissons": "abaisser",
    "abaissâmes": "abaisser",
    "abaissât": "abaisser",
    "abaissâtes": "abaisser",
    "abaissèrent": "abaisser",
    "abaissé": "abaisser",
    "abaissée": "abaisser",
    "abaissées": "abaisser",
    "abaissés": "abaisser",
    "abalones": "abalone",
    "abandonna": "abandonner",
    "abandonnai": "abandonner",
    "abandonnaient": "abandonner",
    "abandonnais": "abandonner",
    "abandonnait": "abandonner",
    "abandonnant": "abandonner",
    "abandonnas": "abandonner",
    "abandonnasse": "abandonner",
    "abandonnassent": "abandonner",
    "abandonnasses": "abandonner",
    "abandonnassiez": "abandonner",
    "abandonnassions": "abandonner",
    "abandonne": "abandonner",
    "abandonnent": "abandonner",
    "abandonner": "avoir",
    "abandonnera": "abandonner",
    "abandonnerai": "abandonner",
    "abandonneraient": "abandonner",
    "abandonnerais": "abandonner",
    "abandonnerait": "abandonner",
    "abandonneras": "abandonner",
    "abandonnerez": "abandonner",
    "abandonneriez": "abandonner",
    "abandonnerions": "abandonner",
    "abandonnerons": "abandonner",
    "abandonneront": "abandonner",
    "abandonnes": "abandonner",
    "abandonneurs": "abandonneur",
    "abandonnez": "abandonner",
    "abandonniez": "abandonner",
    "abandonnions": "abandonner",
    "abandonnons": "abandonner",
    "abandonnâmes": "abandonner",
    "abandonnât": "abandonner",
    "abandonnâtes": "abandonner",
    "abandonnèrent": "abandonner",
    "abandonné": "abandonner",
    "abandonnée": "abandonner",
    "abandonnées": "abandonner",
    "abandonnés": "abandonner",
    "abandons": "abandon",
    "abaques": "abaque",
    "abasourdi": "abasourdir",
    "abasourdie": "abasourdir",
    "abasourdies": "abasourdir",
    "abasourdira": "abasourdir",
    "abasourdirai": "abasourdir",
    "abasourdiraient": "abasourdir",
    "abasourdirais": "abasourdir",
    "abasourdirait": "abasourdir",
    "abasourdiras": "abasourdir",
    "abasourdirent": "abasourdir",
    "abasourdirez": "abasourdir",
    "abasourdiriez": "abasourdir",
    "abasourdirions": "abasourdir",
    "abasourdirons": "abasourdir",
    "abasourdiront": "abasourdir",
    "abasourdis": "abasourdir",
    "abasourdissaient": "abasourdir",
    "abasourdissais": "abasourdir",
    "abasourdissait": "abasourdir",
    "abasourdissant": "abasourdir",
    "abasourdissants": "abasourdissant",
    "abasourdisse": "abasourdir",
    "abasourdissent": "abasourdir",
    "abasourdisses": "abasourdir",
    "abasourdissez": "abasourdir",
    "abasourdissiez": "abasourdir",
    "abasourdissions": "abasourdir",
    "abasourdissons": "abasourdir",
    "abasourdit": "abasourdir",
    "abasourdîmes": "abasourdir",
    "abasourdît": "abasourdir",
    "abasourdîtes": "abasourdir",
    "abat": "abattre",
    "abats": "abattre",
    "abattages": "abattage",
    "abattaient": "abattre",
    "abattais": "abattre",
    "abattait": "abattre",
    "abattant": "abattre",
    "abattants": "abattant",
    "abatte": "abattre",
    "abattements": "abattement",
    "abattent": "abattre",
    "abattes": "abattre",
    "abatteurs": "abatteur",
    "abattez": "abattre",
    "abattiez": "abattre",
    "abattions": "abattre",
    "abattirent": "abattre",
    "abattis": "abattre",
    "abattisse": "abattre",
    "abattissent": "abattre",
    "abattisses": "abattre",
    "abattissiez": "abattre",
    "abattissions": "abattre",
    "abattit": "abattre",
    "abattoirs": "abattoir",
    "abattons": "abattre",
    "abattra": "abattre",
    "abattrai": "abattre",
    "abattraient": "abattre",
    "abattrais": "abattre",
    "abattrait": "abattre",
    "abattras": "abattre",
    "abattrez": "abattre",
    "abattriez": "abattre",
    "abattrions": "abattre",
    "abattrons": "abattre",
    "abattront": "abattre",
    "abattu": "abattre",
    "abattue": "abattu",
    "abattues": "abattu",
    "abattures": "abatture",
    "abattus": "abattu",
    "abattîmes": "abattre",
    "abattît": "abattre",
    "abattîtes": "abattre",
    "abbatiale": "abbatial",
    "abbatiales": "abbatial",
    "abbatiaux": "abbatial",
    "abbayes": "abbaye",
    "abbesse": "abbé",
    "abbesses": "abbé",
    "abbés": "abbé",
    "abcède": "abcéder",
    "abcèdent": "abcéder",
    "abcèdes": "abcéder",
    "abcéda": "abcéder",
    "abcédai": "abcéder",
    "abcédaient": "abcéder",
    "abcédais": "abcéder",
    "abcédait": "abcéder",
    "abcédant": "abcéder",
    "abcédas": "abcéder",
    "abcédasse": "abcéder",
    "abcédassent": "abcéder",
    "abcédasses": "abcéder",
    "abcédassiez": "abcéder",
    "abcédassions": "abcéder",
    "abcédera": "abcéder",
    "abcéderai": "abcéder",
    "abcéderaient": "abcéder",
    "abcéderais": "abcéder",
    "abcéderait": "abcéder",
    "abcéderas": "abcéder",
    "abcéderez": "abcéder",
    "abcéderiez": "abcéder",
    "abcéderions": "abcéder",
    "abcéderons": "abcéder",
    "abcéderont": "abcéder",
    "abcédez": "abcéder",
    "abcédiez": "abcéder",
    "abcédions": "abcéder",
    "abcédons": "abcéder",
    "abcédâmes": "abcéder",
    "abcédât": "abcéder",
    "abcédâtes": "abcéder",
    "abcédèrent": "abcéder",
    "abcédé": "abcéder",
    "abcédée": "abcéder",
    "abcédées": "abcéder",
    "abcédés": "abcéder",
    "abdications": "abdication",
    "abdiqua": "abdiquer",
    "abdiquai": "abdiquer",
    "abdiquaient": "abdiquer",
    "abdiquais": "abdiquer",
    "abdiquait": "abdiquer",
    "abdiquant": "abdiquer",
    "abdiquas": "abdiquer",
    "abdiquasse": "abdiquer",
    "abdiquassent": "abdiquer",
    "abdiquasses": "abdiquer",
    "abdiquassiez": "abdiquer",
    "abdiquassions": "abdiquer",
    "abdique": "abdiquer",
    "abdiquent": "abdiquer",
    "abdiquera": "abdiquer",
    "abdiquerai": "abdiquer",
    "abdiqueraient": "abdiquer",
    "abdiquerais": "abdiquer",
    "abdiquerait": "abdiquer",
    "abdiqueras": "abdiquer",
    "abdiquerez": "abdiquer",
    "abdiqueriez": "abdiquer",
    "abdiquerions": "abdiquer",
    "abdiquerons": "abdiquer",
    "abdiqueront": "abdiquer",
    "abdiques": "abdiquer",
    "abdiquez": "abdiquer",
    "abdiquiez": "abdiquer",
    "abdiquions": "abdiquer",
    "abdiquons": "abdiquer",
    "abdiquâmes": "abdiquer",
    "abdiquât": "abdiquer",
    "abdiquâtes": "abdiquer",
    "abdiquèrent": "abdiquer",
    "abdiqué": "abdiquer",
    "abdiquée": "abdiquer",
    "abdiquées": "abdiquer",
    "abdiqués": "abdiquer",
    "abdomens": "abdomen",
    "abdominale": "abdominal",
    "abdominales": "abdominal",
    "abdominaux": "abdominal",
    "abeilles": "abeille",
    "aberrant": "aberrer",
    "aberrante": "aberrant",
    "aberrantes": "aberrant",
    "aberrants": "aberrant",
    "aberrations": "aberration",
    "abhorra": "abhorrer",
    "abhorrai": "abhorrer",
    "abhorraient": "abhorrer",
    "abhorrais": "abhorrer",
    "abhorrait": "abhorrer",
    "abhorrant": "abhorrer",
    "abhorras": "abhorrer",
    "abhorrasse": "abhorrer",
    "abhorrassent": "abhorrer",
    "abhorrasses": "abhorrer",
    "abhorrassiez": "abhorrer",
    "abhorrassions": "abhorrer",
    "abhorre": "abhorrer",
    "abhorrent": "abhorrer",
    "abhorrera": "abhorrer",
    "abhorrerai": "abhorrer",
    "abhorreraient": "abhorrer",
    "abhorrerais": "abhorrer",
    "abhorrerait": "abhorrer",
    "abhorreras": "abhorrer",
    "abhorrerez": "abhorrer",
    "abhorreriez": "abhorrer",
    "abhorrerions": "abhorrer",
    "abhorrerons": "abhorrer",
    "abhorreront": "abhorrer",
    "abhorres": "abhorrer",
    "abhorrez": "abhorrer",
    "abhorriez": "abhorrer",
    "abhorrions": "abhorrer",
    "abhorrons": "abhorrer",
    "abhorrâmes": "abhorrer",
    "abhorrât": "abhorrer",
    "abhorrâtes": "abhorrer",
    "abhorrèrent": "abhorrer",
    "abhorré": "abhorrer",
    "abhorrée": "abhorrer",
    "abhorrées": "abhorrer",
    "abhorrés": "abhorrer",
    "abjecte": "abject",
    "abjectes": "abject",
    "abjections": "abjection",
    "abjects": "abject",
    "abjura": "abjurer",
    "abjurai": "abjurer",
    "abjuraient": "abjurer",
    "abjurais": "abjurer",
    "abjurait": "abjurer",
    "abjurant": "abjurer",
    "abjuras": "abjurer",
    "abjurasse": "abjurer",
    "abjurassent": "abjurer",
    "abjurasses": "abjurer",
    "abjurassiez": "abjurer",
    "abjurassions": "abjurer",
    "abjurations": "abjuration",
    "abjure": "abjurer",
    "abjurent": "abjurer",
    "abjurera": "abjurer",
    "abjurerai": "abjurer",
    "abjureraient": "abjurer",
    "abjurerais": "abjurer",
    "abjurerait": "abjurer",
    "abjureras": "abjurer",
    "abjurerez": "abjurer",
    "abjureriez": "abjurer",
    "abjurerions": "abjurer",
    "abjurerons": "abjurer",
    "abjureront": "abjurer",
    "abjures": "abjurer",
    "abjurez": "abjurer",
    "abjuriez": "abjurer",
    "abjurions": "abjurer",
    "abjurons": "abjurer",
    "abjurâmes": "abjurer",
    "abjurât": "abjurer",
    "abjurâtes": "abjurer",
    "abjurèrent": "abjurer",
    "abjuré": "abjurer",
    "abjurée": "abjurer",
    "abjurées": "abjurer",
    "abjurés": "abjurer",
    "ablations": "ablation",
    "ablettes": "ablette",
    "ablutions": "ablution",
    "abnégations": "abnégation",
    "aboie": "aboyer",
    "aboiements": "aboiement",
    "aboient": "aboyer",
    "aboiera": "aboyer",
    "aboierai": "aboyer",
    "aboieraient": "aboyer",
    "aboierais": "aboyer",
    "aboierait": "aboyer",
    "aboieras": "aboyer",
    "aboierez": "aboyer",
    "aboieriez": "aboyer",
    "aboierions": "aboyer",
    "aboierons": "aboyer",
    "aboieront": "aboyer",
    "aboies": "aboyer",
    "abois": "aboi",
    "aboli": "abolir",
    "abolie": "abolir",
    "abolies": "abolir",
    "abolira": "abolir",
    "abolirai": "abolir",
    "aboliraient": "abolir",
    "abolirais": "abolir",
    "abolirait": "abolir",
    "aboliras": "abolir",
    "abolirent": "abolir",
    "abolirez": "abolir",
    "aboliriez": "abolir",
    "abolirions": "abolir",
    "abolirons": "abolir",
    "aboliront": "abolir",
    "abolis": "abolir",
    "abolissaient": "abolir",
    "abolissais": "abolir",
    "abolissait": "abolir",
    "abolissant": "abolir",
    "abolisse": "abolir",
    "abolissent": "abolir",
    "abolisses": "abolir",
    "abolissez": "abolir",
    "abolissiez": "abolir",
    "abolissions": "abolir",
    "abolissons": "abolir",
    "abolit": "abolir",
    "abolitionnismes": "abolitionnisme",
    "abolitionnistes": "abolitionniste",
    "abolitions": "abolition",
    "abolîmes": "abolir",
    "abolît": "abolir",
    "abolîtes": "abolir",
    "abominables": "abominable",
    "abominaient": "abominer",
    "abominations": "abomination",
    "abomine": "abominer",
    "abonda": "abonder",
    "abondai": "abonder",
    "abondaient": "abonder",
    "abondais": "abonder",
    "abondait": "abonder",
    "abondances": "abondance",
    "abondant": "abonder",
    "abondante": "abondant",
    "abondantes": "abondant",
    "abondants": "abondant",
    "abondas": "abonder",
    "abondasse": "abonder",
    "abondassent": "abonder",
    "abondasses": "abonder",
    "abondassiez": "abonder",
    "abondassions": "abonder",
    "abonde": "abonder",
    "abondent": "abonder",
    "abondera": "abonder",
    "abonderai": "abonder",
    "abonderaient": "abonder",
    "abonderais": "abonder",
    "abonderait": "abonder",
    "abonderas": "abonder",
    "abonderez": "abonder",
    "abonderiez": "abonder",
    "abonderions": "abonder",
    "abonderons": "abonder",
    "abonderont": "abonder",
    "abondes": "abonder",
    "abondez": "abonder",
    "abondiez": "abonder",
    "abondions": "abonder",
    "abondons": "abonder",
    "abondâmes": "abonder",
    "abondât": "abonder",
    "abondâtes": "abonder",
    "abondèrent": "abonder",
    "abondé": "abonder",
    "abonna": "abonner",
    "abonnai": "abonner",
    "abonnaient": "abonner",
    "abonnais": "abonner",
    "abonnait": "abonner",
    "abonnant": "abonner",
    "abonnas": "abonner",
    "abonnasse": "abonner",
    "abonnassent": "abonner",
    "abonnasses": "abonner",
    "abonnassiez": "abonner",
    "abonnassions": "abonner",
    "abonne": "abonner",
    "abonnements": "abonnement",
    "abonnent": "abonner",
    "abonnera": "abonner",
    "abonnerai": "abonner",
    "abonneraient": "abonner",
    "abonnerais": "abonner",
    "abonnerait": "abonner",
    "abonneras": "abonner",
    "abonnerez": "abonner",
    "abonneriez": "abonner",
    "abonnerions": "abonner",
    "abonnerons": "abonner",
    "abonneront": "abonner",
    "abonnes": "abonner",
    "abonnez": "abonner",
    "abonni": "abonnir",
    "abonnie": "abonnir",
    "abonnies": "abonnir",
    "abonniez": "abonner",
    "abonnions": "abonner",
    "abonnira": "abonnir",
    "abonnirai": "abonnir",
    "abonniraient": "abonnir",
    "abonnirais": "abonnir",
    "abonnirait": "abonnir",
    "abonniras": "abonnir",
    "abonnirent": "abonnir",
    "abonnirez": "abonnir",
    "abonniriez": "abonnir",
    "abonnirions": "abonnir",
    "abonnirons": "abonnir",
    "abonniront": "abonnir",
    "abonnis": "abonnir",
    "abonnissaient": "abonnir",
    "abonnissais": "abonnir",
    "abonnissait": "abonnir",
    "abonnissant": "abonnir",
    "abonnisse": "abonnir",
    "abonnissent": "abonnir",
    "abonnisses": "abonnir",
    "abonnissez": "abonnir",
    "abonnissiez": "abonnir",
    "abonnissions": "abonnir",
    "abonnissons": "abonnir",
    "abonnit": "abonnir",
    "abonnons": "abonner",
    "abonnâmes": "abonner",
    "abonnât": "abonner",
    "abonnâtes": "abonner",
    "abonnèrent": "abonner",
    "abonné": "abonner",
    "abonnée": "abonner",
    "abonnées": "abonner",
    "abonnés": "abonner",
    "abonnîmes": "abonnir",
    "abonnît": "abonnir",
    "abonnîtes": "abonnir",
    "aborda": "aborder",
    "abordables": "abordable",
    "abordages": "abordage",
    "abordai": "aborder",
    "abordaient": "aborder",
    "abordais": "aborder",
    "abordait": "aborder",
    "abordant": "aborder",
    "abordas": "aborder",
    "abordasse": "aborder",
    "abordassent": "aborder",
    "abordasses": "aborder",
    "abordassiez": "aborder",
    "abordassions": "aborder",
    "aborde": "aborder",
    "abordent": "aborder",
    "abordera": "aborder",
    "aborderai": "aborder",
    "aborderaient": "aborder",
    "aborderais": "aborder",
    "aborderait": "aborder",
    "aborderas": "aborder",
    "aborderez": "aborder",
    "aborderiez": "aborder",
    "aborderions": "aborder",
    "aborderons": "aborder",
    "aborderont": "aborder",
    "abordes": "aborder",
    "abordez": "aborder",
    "abordiez": "aborder",
    "abordions": "aborder",
    "abordons": "aborder",
    "abords": "abord",
    "abordâmes": "aborder",
    "abordât": "aborder",
    "abordâtes": "aborder",
    "abordèrent": "aborder",
    "abordé": "aborder",
    "abordée": "aborder",
    "abordées": "aborder",
    "abordés": "aborder",
    "aborigènes": "aborigène",
    "abortifs": "abortif",
    "abortive": "abortif",
    "abortives": "abortif",
    "aboucha": "aboucher",
    "abouchai": "aboucher",
    "abouchaient": "aboucher",
    "abouchais": "aboucher",
    "abouchait": "aboucher",
    "abouchant": "aboucher",
    "abouchas": "aboucher",
    "abouchasse": "aboucher",
    "abouchassent": "aboucher",
    "abouchasses": "aboucher",
    "abouchassiez": "aboucher",
    "abouchassions": "aboucher",
    "abouche": "aboucher",
    "abouchements": "abouchement",
    "abouchent": "aboucher",
    "abouchera": "aboucher",
    "aboucherai": "aboucher",
    "aboucheraient": "aboucher",
    "aboucherais": "aboucher",
    "aboucherait": "aboucher",
    "aboucheras": "aboucher",
    "aboucherez": "aboucher",
    "aboucheriez": "aboucher",
    "aboucherions": "aboucher",
    "aboucherons": "aboucher",
    "aboucheront": "aboucher",
    "abouches": "aboucher",
    "abouchez": "aboucher",
    "abouchiez": "aboucher",
    "abouchions": "aboucher",
    "abouchons": "aboucher",
    "abouchâmes": "aboucher",
    "abouchât": "aboucher",
    "abouchâtes": "aboucher",
    "abouchèrent": "aboucher",
    "abouché": "aboucher",
    "abouchée": "aboucher",
    "abouchées": "aboucher",
    "abouchés": "aboucher",
    "aboule": "abouler",
    "aboules": "abouler",
    "aboulez": "abouler",
    "aboulies": "aboulie",
    "abouliques": "aboulique",
    "abounas": "abouna",
    "aboutait": "abouter",
    "abouti": "aboutir",
    "aboutie": "aboutir",
    "aboutira": "aboutir",
    "aboutirai": "aboutir",
    "aboutiraient": "aboutir",
    "aboutirais": "aboutir",
    "aboutirait": "aboutir",
    "aboutiras": "aboutir",
    "aboutirent": "aboutir",
    "aboutirez": "aboutir",
    "aboutiriez": "aboutir",
    "aboutirions": "aboutir",
    "aboutirons": "aboutir",
    "aboutiront": "aboutir",
    "aboutis": "aboutir",
    "aboutissaient": "aboutir",
    "aboutissais": "aboutir",
    "aboutissait": "aboutir",
    "aboutissant": "aboutir",
    "aboutissants": "aboutissant",
    "aboutisse": "aboutir",
    "aboutissements": "aboutissement",
    "aboutissent": "aboutir",
    "aboutisses": "aboutir",
    "aboutissez": "aboutir",
    "aboutissiez": "aboutir",
    "aboutissions": "aboutir",
    "aboutissons": "aboutir",
    "aboutit": "aboutir",
    "aboutonnai": "aboutonner",
    "aboutons": "abouter",
    "abouts": "about",
    "aboutîmes": "aboutir",
    "aboutît": "aboutir",
    "aboutîtes": "aboutir",
    "aboya": "aboyer",
    "aboyai": "aboyer",
    "aboyaient": "aboyer",
    "aboyais": "aboyer",
    "aboyait": "aboyer",
    "aboyant": "aboyer",
    "aboyante": "aboyant",
    "aboyas": "aboyer",
    "aboyasse": "aboyer",
    "aboyassent": "aboyer",
    "aboyasses": "aboyer",
    "aboyassiez": "aboyer",
    "aboyassions": "aboyer",
    "aboyeurs": "aboyeur",
    "aboyez": "aboyer",
    "aboyiez": "aboyer",
    "aboyions": "aboyer",
    "aboyons": "aboyer",
    "aboyâmes": "aboyer",
    "aboyât": "aboyer",
    "aboyâtes": "aboyer",
    "aboyèrent": "aboyer",
    "aboyé": "aboyer",
    "aboyée": "aboyer",
    "aboyées": "aboyer",
    "aboyés": "aboyer",
    "abracadabrante": "abracadabrant",
    "abracadabrantes": "abracadabrant",
    "abracadabrants": "abracadabrant",
    "abracadabré": "abracadabrer",
    "abrasifs": "abrasif",
    "abrasive": "abrasif",
    "abrasives": "abrasif",
    "abrasé": "abraser",
    "abreuva": "abreuver",
    "abreuvai": "abreuver",
    "abreuvaient": "abreuver",
    "abreuvais": "abreuver",
    "abreuvait": "abreuver",
    "abreuvant": "abreuver",
    "abreuvas": "abreuver",
    "abreuvasse": "abreuver",
    "abreuvassent": "abreuver",
    "abreuvasses": "abreuver",
    "abreuvassiez": "abreuver",
    "abreuvassions": "abreuver",
    "abreuve": "abreuver",
    "abreuvent": "abreuver",
    "abreuvera": "abreuver",
    "abreuverai": "abreuver",
    "abreuveraient": "abreuver",
    "abreuverais": "abreuver",
    "abreuverait": "abreuver",
    "abreuveras": "abreuver",
    "abreuverez": "abreuver",
    "abreuveriez": "abreuver",
    "abreuverions": "abreuver",
    "abreuverons": "abreuver",
    "abreuveront": "abreuver",
    "abreuves": "abreuver",
    "abreuvez": "abreuver",
    "abreuviez": "abreuver",
    "abreuvions": "abreuver",
    "abreuvoirs": "abreuvoir",
    "abreuvons": "abreuver",
    "abreuvâmes": "abreuver",
    "abreuvât": "abreuver",
    "abreuvâtes": "abreuver",
    "abreuvèrent": "abreuver",
    "abreuvé": "abreuver",
    "abreuvée": "abreuver",
    "abreuvées": "abreuver",
    "abreuvés": "abreuver",
    "abricotez": "abricoter",
    "abricotiers": "abricotier",
    "abricots": "abricot",
    "abris": "abri",
    "abris-sous-roche": "abri-sous-roche",
    "abrita": "abriter",
    "abritai": "abriter",
    "abritaient": "abriter",
    "abritais": "abriter",
    "abritait": "abriter",
    "abritant": "abriter",
    "abritas": "abriter",
    "abritasse": "abriter",
    "abritassent": "abriter",
    "abritasses": "abriter",
    "abritassiez": "abriter",
    "abritassions": "abriter",
    "abrite": "abriter",
    "abritent": "abriter",
    "abritera": "abriter",
    "abriterai": "abriter",
    "abriteraient": "abriter",
    "abriterais": "abriter",
    "abriterait": "abriter",
    "abriteras": "abriter",
    "abriterez": "abriter",
    "abriteriez": "abriter",
    "abriterions": "abriter",
    "abriterons": "abriter",
    "abriteront": "abriter",
    "abrites": "abriter",
    "abritez": "abriter",
    "abritiez": "abriter",
    "abritions": "abriter",
    "abritons": "abriter",
    "abritâmes": "abriter",
    "abritât": "abriter",
    "abritâtes": "abriter",
    "abritèrent": "abriter",
    "abrité": "abriter",
    "abritée": "abriter",
    "abritées": "abriter",
    "abrités": "abriter",
    "abrogations": "abrogation",
    "abroge": "abroger",
    "abrogea": "abroger",
    "abrogeables": "abrogeable",
    "abrogeai": "abroger",
    "abrogeaient": "abroger",
    "abrogeais": "abroger",
    "abrogeait": "abroger",
    "abrogeant": "abroger",
    "abrogeas": "abroger",
    "abrogeasse": "abroger",
    "abrogeassent": "abroger",
    "abrogeasses": "abroger",
    "abrogeassiez": "abroger",
    "abrogeassions": "abroger",
    "abrogent": "abroger",
    "abrogeons": "abroger",
    "abrogera": "abroger",
    "abrogerai": "abroger",
    "abrogeraient": "abroger",
    "abrogerais": "abroger",
    "abrogerait": "abroger",
    "abrogeras": "abroger",
    "abrogerez": "abroger",
    "abrogeriez": "abroger",
    "abrogerions": "abroger",
    "abrogerons": "abroger",
    "abrogeront": "abroger",
    "abroges": "abroger",
    "abrogez": "abroger",
    "abrogeâmes": "abroger",
    "abrogeât": "abroger",
    "abrogeâtes": "abroger",
    "abrogiez": "abroger",
    "abrogions": "abroger",
    "abrogèrent": "abroger",
    "abrogé": "abroger",
    "abrogée": "abroger",
    "abrogées": "abroger",
    "abrogés": "abroger",
    "abrupte": "abrupt",
    "abruptes": "abrupt",
    "abrupts": "abrupt",
    "abruti": "abrutir",
    "abrutie": "abrutir",
    "abruties": "abrutir",
    "abrutira": "abrutir",
    "abrutirai": "abrutir",
    "abrutiraient": "abrutir",
    "abrutirais": "abrutir",
    "abrutirait": "abrutir",
    "abrutiras": "abrutir",
    "abrutirent": "abrutir",
    "abrutirez": "abrutir",
    "abrutiriez": "abrutir",
    "abrutirions": "abrutir",
    "abrutirons": "abrutir",
    "abrutiront": "abrutir",
    "abrutis": "abrutir",
    "abrutissaient": "abrutir",
    "abrutissais": "abrutir",
    "abrutissait": "abrutir",
    "abrutissant": "abrutir",
    "abrutissante": "abrutissant",
    "abrutissantes": "abrutissant",
    "abrutissants": "abrutissant",
    "abrutisse": "abrutir",
    "abrutissements": "abrutissement",
    "abrutissent": "abrutir",
    "abrutisses": "abrutir",
    "abrutissez": "abrutir",
    "abrutissiez": "abrutir",
    "abrutissions": "abrutir",
    "abrutissons": "abrutir",
    "abrutit": "abrutir",
    "abrutîmes": "abrutir",
    "abrutît": "abrutir",
    "abrutîtes": "abrutir",
    "abrège": "abréger",
    "abrègements": "abrègement",
    "abrègent": "abréger",
    "abrèges": "abréger",
    "abrégea": "abréger",
    "abrégeai": "abréger",
    "abrégeaient": "abréger",
    "abrégeais": "abréger",
    "abrégeait": "abréger",
    "abrégeant": "abréger",
    "abrégeas": "abréger",
    "abrégeasse": "abréger",
    "abrégeassent": "abréger",
    "abrégeasses": "abréger",
    "abrégeassiez": "abréger",
    "abrégeassions": "abréger",
    "abrégeons": "abréger",
    "abrégera": "abréger",
    "abrégerai": "abréger",
    "abrégeraient": "abréger",
    "abrégerais": "abréger",
    "abrégerait": "abréger",
    "abrégeras": "abréger",
    "abrégerez": "abréger",
    "abrégeriez": "abréger",
    "abrégerions": "abréger",
    "abrégerons": "abréger",
    "abrégeront": "abréger",
    "abrégez": "abréger",
    "abrégeâmes": "abréger",
    "abrégeât": "abréger",
    "abrégeâtes": "abréger",
    "abrégiez": "abréger",
    "abrégions": "abréger",
    "abrégèrent": "abréger",
    "abrégé": "abréger",
    "abrégée": "abréger",
    "abrégées": "abréger",
    "abrégés": "abréger",
    "abréviations": "abréviation",
    "abscisses": "abscisse",
    "absconse": "abscons",
    "absconses": "abscons",
    "absences": "absence",
    "absenta": "absenter",
    "absentai": "absenter",
    "absentaient": "absenter",
    "absentais": "absenter",
    "absentait": "absenter",
    "absentant": "absenter",
    "absentas": "absenter",
    "absentasse": "absenter",
    "absentassent": "absenter",
    "absentasses": "absenter",
    "absentassiez": "absenter",
    "absentassions": "absenter",
    "absente": "absenter",
    "absentent": "absenter",
    "absentera": "absenter",
    "absenterai": "absenter",
    "absenteraient": "absenter",
    "absenterais": "absenter",
    "absenterait": "absenter",
    "absenteras": "absenter",
    "absenterez": "absenter",
    "absenteriez": "absenter",
    "absenterions": "absenter",
    "absenterons": "absenter",
    "absenteront": "absenter",
    "absentes": "absenter",
    "absentez": "absenter",
    "absentiez": "absenter",
    "absentions": "absenter",
    "absentons": "absenter",
    "absents": "absent",
    "absentâmes": "absenter",
    "absentât": "absenter",
    "absentâtes": "absenter",
    "absentèrent": "absenter",
    "absenté": "absenter",
    "absentée": "absenter",
    "absentées": "absenter",
    "absentéismes": "absentéisme",
    "absentés": "absenter",
    "absides": "abside",
    "absidiales": "absidial",
    "absinthant": "absinther",
    "absinthes": "absinthe",
    "absolue": "absolu",
    "absolues": "absolu",
    "absolus": "absolu",
    "absolutions": "absolution",
    "absolutismes": "absolutisme",
    "absolvaient": "absoudre",
    "absolvais": "absoudre",
    "absolvait": "absoudre",
    "absolvant": "absoudre",
    "absolve": "absoudre",
    "absolvent": "absoudre",
    "absolves": "absoudre",
    "absolvez": "absoudre",
    "absolviez": "absoudre",
    "absolvions": "absoudre",
    "absolvons": "absoudre",
    "absorba": "absorber",
    "absorbables": "absorbable",
    "absorbai": "absorber",
    "absorbaient": "absorber",
    "absorbais": "absorber",
    "absorbait": "absorber",
    "absorbant": "absorber",
    "absorbante": "absorbant",
    "absorbantes": "absorbant",
    "absorbants": "absorbant",
    "absorbas": "absorber",
    "absorbasse": "absorber",
    "absorbassent": "absorber",
    "absorbasses": "absorber",
    "absorbassiez": "absorber",
    "absorbassions": "absorber",
    "absorbe": "absorber",
    "absorbent": "absorber",
    "absorbera": "absorber",
    "absorberai": "absorber",
    "absorberaient": "absorber",
    "absorberais": "absorber",
    "absorberait": "absorber",
    "absorberas": "absorber",
    "absorberez": "absorber",
    "absorberiez": "absorber",
    "absorberions": "absorber",
    "absorberons": "absorber",
    "absorberont": "absorber",
    "absorbes": "absorber",
    "absorbez": "absorber",
    "absorbiez": "absorber",
    "absorbions": "absorber",
    "absorbons": "absorber",
    "absorbâmes": "absorber",
    "absorbât": "absorber",
    "absorbâtes": "absorber",
    "absorbèrent": "absorber",
    "absorbé": "absorber",
    "absorbée": "absorber",
    "absorbées": "absorber",
    "absorbés": "absorber",
    "absorptions": "absorption",
    "absorptivités": "absorptivité",
    "absoudra": "absoudre",
    "absoudrai": "absoudre",
    "absoudraient": "absoudre",
    "absoudrais": "absoudre",
    "absoudrait": "absoudre",
    "absoudras": "absoudre",
    "absoudrez": "absoudre",
    "absoudriez": "absoudre",
    "absoudrions": "absoudre",
    "absoudrons": "absoudre",
    "absoudront": "absoudre",
    "absous": "absoudre",
    "absout": "absoudre",
    "absoute": "absoudre",
    "absoutes": "absoudre",
    "abstenaient": "abstenir",
    "abstenais": "abstenir",
    "abstenait": "abstenir",
    "abstenant": "abstenir",
    "abstenez": "abstenir",
    "absteniez": "abstenir",
    "abstenions": "abstenir",
    "abstenons": "abstenir",
    "abstentionnismes": "abstentionnisme",
    "abstentionnistes": "abstentionniste",
    "abstentions": "abstention",
    "abstenu": "abstenir",
    "abstenue": "abstenu",
    "abstenues": "abstenir",
    "abstenus": "abstenir",
    "abstiendra": "abstenir",
    "abstiendrai": "abstenir",
    "abstiendraient": "abstenir",
    "abstiendrais": "abstenir",
    "abstiendrait": "abstenir",
    "abstiendras": "abstenir",
    "abstiendrez": "abstenir",
    "abstiendriez": "abstenir",
    "abstiendrions": "abstenir",
    "abstiendrons": "abstenir",
    "abstiendront": "abstenir",
    "abstienne": "abstenir",
    "abstiennent": "abstenir",
    "abstiennes": "abstenir",
    "abstiens": "abstenir",
    "abstient": "abstenir",
    "abstinences": "abstinence",
    "abstinente": "abstinent",
    "abstinentes": "abstinent",
    "abstinents": "abstinent",
    "abstinrent": "abstenir",
    "abstins": "abstenir",
    "abstinsse": "abstenir",
    "abstinssent": "abstenir",
    "abstinsses": "abstenir",
    "abstinssiez": "abstenir",
    "abstinssions": "abstenir",
    "abstint": "abstenir",
    "abstractions": "abstraction",
    "abstraie": "abstraire",
    "abstraient": "abstraire",
    "abstraies": "abstraire",
    "abstraira": "abstraire",
    "abstrairai": "abstraire",
    "abstrairaient": "abstraire",
    "abstrairais": "abstraire",
    "abstrairait": "abstraire",
    "abstrairas": "abstraire",
    "abstrairez": "abstraire",
    "abstrairiez": "abstraire",
    "abstrairions": "abstraire",
    "abstrairons": "abstraire",
    "abstrairont": "abstraire",
    "abstrais": "abstraire",
    "abstrait": "abstraire",
    "abstraite": "abstrait",
    "abstraites": "abstrait",
    "abstraits": "abstrait",
    "abstrayaient": "abstraire",
    "abstrayais": "abstraire",
    "abstrayait": "abstraire",
    "abstrayant": "abstraire",
    "abstrayez": "abstraire",
    "abstrayiez": "abstraire",
    "abstrayions": "abstraire",
    "abstrayons": "abstraire",
    "abstruse": "abstrus",
    "abstruses": "abstrus",
    "abstînmes": "abstenir",
    "abstînt": "abstenir",
    "abstîntes": "abstenir",
    "absurdes": "absurde",
    "absurdistes": "absurdiste",
    "absurdités": "absurdité",
    "abusa": "abuser",
    "abusai": "abuser",
    "abusaient": "abuser",
    "abusais": "abuser",
    "abusait": "abuser",
    "abusant": "abuser",
    "abusas": "abuser",
    "abusasse": "abuser",
    "abusassent": "abuser",
    "abusasses": "abuser",
    "abusassiez": "abuser",
    "abusassions": "abuser",
    "abuse": "abuser",
    "abusent": "abuser",
    "abusera": "abuser",
    "abuserai": "abuser",
    "abuseraient": "abuser",
    "abuserais": "abuser",
    "abuserait": "abuser",
    "abuseras": "abuser",
    "abuserez": "abuser",
    "abuseriez": "abuser",
    "abuserions": "abuser",
    "abuserons": "abuser",
    "abuseront": "abuser",
    "abuses": "abuser",
    "abusez": "abuser",
    "abusiez": "abuser",
    "abusifs": "abusif",
    "abusions": "abuser",
    "abusive": "abusif",
    "abusives": "abusif",
    "abusons": "abuser",
    "abusâmes": "abuser",
    "abusât": "abuser",
    "abusâtes": "abuser",
    "abusèrent": "abuser",
    "abusé": "abuser",
    "abusée": "abuser",
    "abusées": "abuser",
    "abusés": "abuser",
    "abyssale": "abyssal",
    "abyssales": "abyssal",
    "abyssaux": "abyssal",
    "abysses": "abysse",
    "abyssinienne": "abyssinien",
    "abyssins": "abyssin",
    "abâtardi": "abâtardir",
    "abâtardie": "abâtardir",
    "abâtardies": "abâtardir",
    "abâtardira": "abâtardir",
    "abâtardirai": "abâtardir",
    "abâtardiraient": "abâtardir",
    "abâtardirais": "abâtardir",
    "abâtardirait": "abâtardir",
    "abâtardiras": "abâtardir",
    "abâtardirent": "abâtardir",
    "abâtardirez": "abâtardir",
    "abâtardiriez": "abâtardir",
    "abâtardirions": "abâtardir",
    "abâtardirons": "abâtardir",
    "abâtardiront": "abâtardir",
    "abâtardis": "abâtardir",
    "abâtardissaient": "abâtardir",
    "abâtardissais": "abâtardir",
    "abâtardissait": "abâtardir",
    "abâtardissant": "abâtardir",
    "abâtardisse": "abâtardir",
    "abâtardissent": "abâtardir",
    "abâtardisses": "abâtardir",
    "abâtardissez": "abâtardir",
    "abâtardissiez": "abâtardir",
    "abâtardissions": "abâtardir",
    "abâtardissons": "abâtardir",
    "abâtardit": "abâtardir",
    "abâtardîmes": "abâtardir",
    "abâtardît": "abâtardir",
    "abâtardîtes": "abâtardir",
    "abécédaires": "abécédaire",
    "abêti": "abêtir",
    "abêtie": "abêtir",
    "abêties": "abêtir",
    "abêtira": "abêtir",
    "abêtirai": "abêtir",
    "abêtiraient": "abêtir",
    "abêtirais": "abêtir",
    "abêtirait": "abêtir",
    "abêtiras": "abêtir",
    "abêtirent": "abêtir",
    "abêtirez": "abêtir",
    "abêtiriez": "abêtir",
    "abêtirions": "abêtir",
    "abêtirons": "abêtir",
    "abêtiront": "abêtir",
    "abêtis": "abêtir",
    "abêtissaient": "abêtir",
    "abêtissais": "abêtir",
    "abêtissait": "abêtir",
    "abêtissant": "abêtir",
    "abêtisse": "abêtir",
    "abêtissent": "abêtir",
    "abêtisses": "abêtir",
    "abêtissez": "abêtir",
    "abêtissiez": "abêtir",
    "abêtissions": "abêtir",
    "abêtissons": "abêtir",
    "abêtit": "abêtir",
    "abêtîmes": "abêtir",
    "abêtît": "abêtir",
    "abêtîtes": "abêtir",
    "abîma": "abîmer",
    "abîmai": "abîmer",
    "abîmaient": "abîmer",
    "abîmais": "abîmer",
    "abîmait": "abîmer",
    "abîmant": "abîmer",
    "abîmas": "abîmer",
    "abîmasse": "abîmer",
    "abîmassent": "abîmer",
    "abîmasses": "abîmer",
    "abîmassiez": "abîmer",
    "abîmassions": "abîmer",
    "abîme": "abîmer",
    "abîment": "abîmer",
    "abîmera": "abîmer",
    "abîmerai": "abîmer",
    "abîmeraient": "abîmer",
    "abîmerais": "abîmer",
    "abîmerait": "abîmer",
    "abîmeras": "abîmer",
    "abîmerez": "abîmer",
    "abîmeriez": "abîmer",
    "abîmerions": "abîmer",
    "abîmerons": "abîmer",
    "abîmeront": "abîmer",
    "abîmes": "abîmer",
    "abîmez": "abîmer",
    "abîmiez": "abîmer",
    "abîmions": "abîmer",
    "abîmons": "abîmer",
    "abîmâmes": "abîmer",
    "abîmât": "abîmer",
    "abîmâtes": "abîmer",
    "abîmèrent": "abîmer",
    "abîmé": "abîmer",
    "abîmée": "abîmer",
    "abîmées": "abîmer",
    "abîmés": "abîmer",
    "acabits": "acabit",
    "acacias": "acacia",
    "acadiens": "acadien",
    "académicienne": "académicien",
    "académiciennes": "académicien",
    "académiciens": "académicien",
    "académies": "académie",
    "académiques": "académique",
    "académisé": "académiser",
    "acagnardai": "acagnarder",
    "acagnardait": "acagnarder",
    "acagnardé": "acagnarder",
    "acagnardée": "acagnarder",
    "acajous": "acajou",
    "acanthes": "acanthe",
    "acariens": "acarien",
    "acariâtres": "acariâtre",
    "accabla": "accabler",
    "accablai": "accabler",
    "accablaient": "accabler",
    "accablais": "accabler",
    "accablait": "accabler",
    "accablant": "accabler",
    "accablante": "accablant",
    "accablantes": "accablant",
    "accablants": "accablant",
    "accablas": "accabler",
    "accablasse": "accabler",
    "accablassent": "accabler",
    "accablasses": "accabler",
    "accablassiez": "accabler",
    "accablassions": "accabler",
    "accable": "accabler",
    "accablements": "accablement",
    "accablent": "accabler",
    "accablera": "accabler",
    "accablerai": "accabler",
    "accableraient": "accabler",
    "accablerais": "accabler",
    "accablerait": "accabler",
    "accableras": "accabler",
    "accablerez": "accabler",
    "accableriez": "accabler",
    "accablerions": "accabler",
    "accablerons": "accabler",
    "accableront": "accabler",
    "accables": "accabler",
    "accablez": "accabler",
    "accabliez": "accabler",
    "accablions": "accabler",
    "accablons": "accabler",
    "accablâmes": "accabler",
    "accablât": "accabler",
    "accablâtes": "accabler",
    "accablèrent": "accabler",
    "accablé": "accabler",
    "accablée": "accabler",
    "accablées": "accabler",
    "accablés": "accabler",
    "accalmies": "accalmie",
    "accalmit": "accalmir",
    "accapara": "accaparer",
    "accaparai": "accaparer",
    "accaparaient": "accaparer",
    "accaparais": "accaparer",
    "accaparait": "accaparer",
    "accaparant": "accaparer",
    "accaparante": "accaparant",
    "accaparas": "accaparer",
    "accaparasse": "accaparer",
    "accaparassent": "accaparer",
    "accaparasses": "accaparer",
    "accaparassiez": "accaparer",
    "accaparassions": "accaparer",
    "accapare": "accaparer",
    "accaparements": "accaparement",
    "accaparent": "accaparer",
    "accaparera": "accaparer",
    "accaparerai": "accaparer",
    "accapareraient": "accaparer",
    "accaparerais": "accaparer",
    "accaparerait": "accaparer",
    "accapareras": "accaparer",
    "accaparerez": "accaparer",
    "accapareriez": "accaparer",
    "accaparerions": "accaparer",
    "accaparerons": "accaparer",
    "accapareront": "accaparer",
    "accapares": "accaparer",
    "accaparez": "accaparer",
    "accapariez": "accaparer",
    "accaparions": "accaparer",
    "accaparons": "accaparer",
    "accaparâmes": "accaparer",
    "accaparât": "accaparer",
    "accaparâtes": "accaparer",
    "accaparèrent": "accaparer",
    "accaparé": "accaparer",
    "accaparée": "accaparer",
    "accaparées": "accaparer",
    "accaparés": "accaparer",
    "accastillages": "accastillage",
    "accents": "accent",
    "accentua": "accentuer",
    "accentuai": "accentuer",
    "accentuaient": "accentuer",
    "accentuais": "accentuer",
    "accentuait": "accentuer",
    "accentuant": "accentuer",
    "accentuas": "accentuer",
    "accentuasse": "accentuer",
    "accentuassent": "accentuer",
    "accentuasses": "accentuer",
    "accentuassiez": "accentuer",
    "accentuassions": "accentuer",
    "accentuations": "accentuation",
    "accentue": "accentuer",
    "accentuent": "accentuer",
    "accentuera": "accentuer",
    "accentuerai": "accentuer",
    "accentueraient": "accentuer",
    "accentuerais": "accentuer",
    "accentuerait": "accentuer",
    "accentueras": "accentuer",
    "accentuerez": "accentuer",
    "accentueriez": "accentuer",
    "accentuerions": "accentuer",
    "accentuerons": "accentuer",
    "accentueront": "accentuer",
    "accentues": "accentuer",
    "accentuez": "accentuer",
    "accentuiez": "accentuer",
    "accentuions": "accentuer",
    "accentuons": "accentuer",
    "accentuâmes": "accentuer",
    "accentuât": "accentuer",
    "accentuâtes": "accentuer",
    "accentuèrent": "accentuer",
    "accentué": "accentuer",
    "accentuée": "accentuer",
    "accentuées": "accentuer",
    "accentués": "accentuer",
    "accepta": "accepter",
    "acceptabilités": "acceptabilité",
    "acceptables": "acceptable",
    "acceptai": "accepter",
    "acceptaient": "accepter",
    "acceptais": "accepter",
    "acceptait": "accepter",
    "acceptant": "accepter",
    "acceptas": "accepter",
    "acceptasse": "accepter",
    "acceptassent": "accepter",
    "acceptasses": "accepter",
    "acceptassiez": "accepter",
    "acceptassions": "accepter",
    "acceptations": "acceptation",
    "accepte": "accepter",
    "acceptent": "accepter",
    "acceptera": "accepter",
    "accepterai": "accepter",
    "accepteraient": "accepter",
    "accepterais": "accepter",
    "accepterait": "accepter",
    "accepteras": "accepter",
    "accepterez": "accepter",
    "accepteriez": "accepter",
    "accepterions": "accepter",
    "accepterons": "accepter",
    "accepteront": "accepter",
    "acceptes": "accepter",
    "acceptez": "accepter",
    "acceptiez": "accepter",
    "acceptions": "acception",
    "acceptons": "accepter",
    "acceptâmes": "accepter",
    "acceptât": "accepter",
    "acceptâtes": "accepter",
    "acceptèrent": "accepter",
    "accepté": "accepter",
    "acceptée": "accepter",
    "acceptées": "accepter",
    "acceptés": "accepter",
    "accesseurs": "accesseur",
    "accessibilités": "accessibilité",
    "accessibles": "accessible",
    "accessions": "accession",
    "accessits": "accessit",
    "accessoires": "accessoire",
    "accessoirise": "accessoiriser",
    "accessoiristes": "accessoiriste",
    "accidenta": "accidenter",
    "accidentai": "accidenter",
    "accidentaient": "accidenter",
    "accidentais": "accidenter",
    "accidentait": "accidenter",
    "accidentant": "accidenter",
    "accidentas": "accidenter",
    "accidentasse": "accidenter",
    "accidentassent": "accidenter",
    "accidentasses": "accidenter",
    "accidentassiez": "accidenter",
    "accidentassions": "accidenter",
    "accidente": "accidenter",
    "accidentelle": "accidentel",
    "accidentelles": "accidentel",
    "accidentels": "accidentel",
    "accidentent": "accidenter",
    "accidentera": "accidenter",
    "accidenterai": "accidenter",
    "accidenteraient": "accidenter",
    "accidenterais": "accidenter",
    "accidenterait": "accidenter",
    "accidenteras": "accidenter",
    "accidenterez": "accidenter",
    "accidenteriez": "accidenter",
    "accidenterions": "accidenter",
    "accidenterons": "accidenter",
    "accidenteront": "accidenter",
    "accidentes": "accidenter",
    "accidentez": "accidenter",
    "accidentiez": "accidenter",
    "accidentions": "accidenter",
    "accidentons": "accidenter",
    "accidents": "accident",
    "accidentâmes": "accidenter",
    "accidentât": "accidenter",
    "accidentâtes": "accidenter",
    "accidentèrent": "accidenter",
    "accidenté": "accidenter",
    "accidentée": "accidenter",
    "accidentées": "accidenter",
    "accidentés": "accidenter",
    "accises": "accise",
    "acclama": "acclamer",
    "acclamai": "acclamer",
    "acclamaient": "acclamer",
    "acclamais": "acclamer",
    "acclamait": "acclamer",
    "acclamant": "acclamer",
    "acclamas": "acclamer",
    "acclamasse": "acclamer",
    "acclamassent": "acclamer",
    "acclamasses": "acclamer",
    "acclamassiez": "acclamer",
    "acclamassions": "acclamer",
    "acclamations": "acclamation",
    "acclame": "acclamer",
    "acclament": "acclamer",
    "acclamera": "acclamer",
    "acclamerai": "acclamer",
    "acclameraient": "acclamer",
    "acclamerais": "acclamer",
    "acclamerait": "acclamer",
    "acclameras": "acclamer",
    "acclamerez": "acclamer",
    "acclameriez": "acclamer",
    "acclamerions": "acclamer",
    "acclamerons": "acclamer",
    "acclameront": "acclamer",
    "acclames": "acclamer",
    "acclamez": "acclamer",
    "acclamiez": "acclamer",
    "acclamions": "acclamer",
    "acclamons": "acclamer",
    "acclamâmes": "acclamer",
    "acclamât": "acclamer",
    "acclamâtes": "acclamer",
    "acclamèrent": "acclamer",
    "acclamé": "acclamer",
    "acclamée": "acclamer",
    "acclamées": "acclamer",
    "acclamés": "acclamer",
    "acclimata": "acclimater",
    "acclimatai": "acclimater",
    "acclimataient": "acclimater",
    "acclimatais": "acclimater",
    "acclimatait": "acclimater",
    "acclimatant": "acclimater",
    "acclimatas": "acclimater",
    "acclimatasse": "acclimater",
    "acclimatassent": "acclimater",
    "acclimatasses": "acclimater",
    "acclimatassiez": "acclimater",
    "acclimatassions": "acclimater",
    "acclimatations": "acclimatation",
    "acclimate": "acclimater",
    "acclimatent": "acclimater",
    "acclimatera": "acclimater",
    "acclimaterai": "acclimater",
    "acclimateraient": "acclimater",
    "acclimaterais": "acclimater",
    "acclimaterait": "acclimater",
    "acclimateras": "acclimater",
    "acclimaterez": "acclimater",
    "acclimateriez": "acclimater",
    "acclimaterions": "acclimater",
    "acclimaterons": "acclimater",
    "acclimateront": "acclimater",
    "acclimates": "acclimater",
    "acclimatez": "acclimater",
    "acclimatiez": "acclimater",
    "acclimations": "acclimater",
    "acclimatons": "acclimater",
    "acclimatâmes": "acclimater",
    "acclimatât": "acclimater",
    "acclimatâtes": "acclimater",
    "acclimatèrent": "acclimater",
    "acclimaté": "acclimater",
    "acclimatée": "acclimater",
    "acclimatées": "acclimater",
    "acclimatés": "acclimater",
    "accointa": "accointer",
    "accointai": "accointer",
    "accointaient": "accointer",
    "accointais": "accointer",
    "accointait": "accointer",
    "accointances": "accointance",
    "accointant": "accointer",
    "accointas": "accointer",
    "accointasse": "accointer",
    "accointassent": "accointer",
    "accointasses": "accointer",
    "accointassiez": "accointer",
    "accointassions": "accointer",
    "accointe": "accointer",
    "accointent": "accointer",
    "accointera": "accointer",
    "accointerai": "accointer",
    "accointeraient": "accointer",
    "accointerais": "accointer",
    "accointerait": "accointer",
    "accointeras": "accointer",
    "accointerez": "accointer",
    "accointeriez": "accointer",
    "accointerions": "accointer",
    "accointerons": "accointer",
    "accointeront": "accointer",
    "accointes": "accointer",
    "accointez": "accointer",
    "accointiez": "accointer",
    "accointions": "accointer",
    "accointons": "accointer",
    "accointâmes": "accointer",
    "accointât": "accointer",
    "accointâtes": "accointer",
    "accointèrent": "accointer",
    "accointé": "accointer",
    "accointée": "accointer",
    "accointées": "accointer",
    "accointés": "accointer",
    "accola": "accoler",
    "accolades": "accolade",
    "accolai": "accoler",
    "accolaient": "accoler",
    "accolais": "accoler",
    "accolait": "accoler",
    "accolant": "accoler",
    "accolas": "accoler",
    "accolasse": "accoler",
    "accolassent": "accoler",
    "accolasses": "accoler",
    "accolassiez": "accoler",
    "accolassions": "accoler",
    "accole": "accoler",
    "accolent": "accoler",
    "accolera": "accoler",
    "accolerai": "accoler",
    "accoleraient": "accoler",
    "accolerais": "accoler",
    "accolerait": "accoler",
    "accoleras": "accoler",
    "accolerez": "accoler",
    "accoleriez": "accoler",
    "accolerions": "accoler",
    "accolerons": "accoler",
    "accoleront": "accoler",
    "accoles": "accoler",
    "accolez": "accoler",
    "accoliez": "accoler",
    "accolions": "accoler",
    "accolons": "accoler",
    "accolâmes": "accoler",
    "accolât": "accoler",
    "accolâtes": "accoler",
    "accolèrent": "accoler",
    "accolé": "accoler",
    "accolée": "accoler",
    "accolées": "accoler",
    "accolés": "accoler",
    "accommoda": "accommoder",
    "accommodai": "accommoder",
    "accommodaient": "accommoder",
    "accommodais": "accommoder",
    "accommodait": "accommoder",
    "accommodant": "accommoder",
    "accommodante": "accommodant",
    "accommodantes": "accommodant",
    "accommodants": "accommodant",
    "accommodas": "accommoder",
    "accommodasse": "accommoder",
    "accommodassent": "accommoder",
    "accommodasses": "accommoder",
    "accommodassiez": "accommoder",
    "accommodassions": "accommoder",
    "accommodatrices": "accommodateur",
    "accommode": "accommoder",
    "accommodements": "accommodement",
    "accommodent": "accommoder",
    "accommodera": "accommoder",
    "accommoderai": "accommoder",
    "accommoderaient": "accommoder",
    "accommoderais": "accommoder",
    "accommoderait": "accommoder",
    "accommoderas": "accommoder",
    "accommoderez": "accommoder",
    "accommoderiez": "accommoder",
    "accommoderions": "accommoder",
    "accommoderons": "accommoder",
    "accommoderont": "accommoder",
    "accommodes": "accommoder",
    "accommodez": "accommoder",
    "accommodiez": "accommoder",
    "accommodions": "accommoder",
    "accommodons": "accommoder",
    "accommodâmes": "accommoder",
    "accommodât": "accommoder",
    "accommodâtes": "accommoder",
    "accommodèrent": "accommoder",
    "accommodé": "accommoder",
    "accommodée": "accommoder",
    "accommodées": "accommoder",
    "accommodés": "accommoder",
    "accompagna": "accompagner",
    "accompagnai": "accompagner",
    "accompagnaient": "accompagner",
    "accompagnais": "accompagner",
    "accompagnait": "accompagner",
    "accompagnant": "accompagner",
    "accompagnas": "accompagner",
    "accompagnasse": "accompagner",
    "accompagnassent": "accompagner",
    "accompagnasses": "accompagner",
    "accompagnassiez": "accompagner",
    "accompagnassions": "accompagner",
    "accompagnateurs": "accompagnateur",
    "accompagnatrice": "accompagnateur",
    "accompagnatrices": "accompagnateur",
    "accompagne": "accompagner",
    "accompagnements": "accompagnement",
    "accompagnent": "accompagner",
    "accompagnera": "accompagner",
    "accompagnerai": "accompagner",
    "accompagneraient": "accompagner",
    "accompagnerais": "accompagner",
    "accompagnerait": "accompagner",
    "accompagneras": "accompagner",
    "accompagnerez": "accompagner",
    "accompagneriez": "accompagner",
    "accompagnerions": "accompagner",
    "accompagnerons": "accompagner",
    "accompagneront": "accompagner",
    "accompagnes": "accompagner",
    "accompagnez": "accompagner",
    "accompagniez": "accompagner",
    "accompagnions": "accompagner",
    "accompagnons": "accompagner",
    "accompagnâmes": "accompagner",
    "accompagnât": "accompagner",
    "accompagnâtes": "accompagner",
    "accompagnèrent": "accompagner",
    "accompagné": "accompagner",
    "accompagnée": "accompagner",
    "accompagnées": "accompagner",
    "accompagnés": "accompagner",
    "accompli": "accomplir",
    "accomplie": "accomplir",
    "accomplies": "accomplir",
    "accomplira": "accomplir",
    "accomplirai": "accomplir",
    "accompliraient": "accomplir",
    "accomplirais": "accomplir",
    "accomplirait": "accomplir",
    "accompliras": "accomplir",
    "accomplirent": "accomplir",
    "accomplirez": "accomplir",
    "accompliriez": "accomplir",
    "accomplirions": "accomplir",
    "accomplirons": "accomplir",
    "accompliront": "accomplir",
    "accomplis": "accomplir",
    "accomplissaient": "accomplir",
    "accomplissais": "accomplir",
    "accomplissait": "accomplir",
    "accomplissant": "accomplir",
    "accomplisse": "accomplir",
    "accomplissements": "accomplissement",
    "accomplissent": "accomplir",
    "accomplisses": "accomplir",
    "accomplissez": "accomplir",
    "accomplissiez": "accomplir",
    "accomplissions": "accomplir",
    "accomplissons": "accomplir",
    "accomplit": "accomplir",
    "accomplîmes": "accomplir",
    "accomplît": "accomplir",
    "accomplîtes": "accomplir",
    "accorda": "accorder",
    "accordai": "accorder",
    "accordaient": "accorder",
    "accordais": "accorder",
    "accordait": "accorder",
    "accordant": "accorder",
    "accordas": "accorder",
    "accordasse": "accorder",
    "accordassent": "accorder",
    "accordasses": "accorder",
    "accordassiez": "accorder",
    "accordassions": "accorder",
    "accorde": "accorder",
    "accordent": "accorder",
    "accordera": "accorder",
    "accorderai": "accorder",
    "accorderaient": "accorder",
    "accorderais": "accorder",
    "accorderait": "accorder",
    "accorderas": "accorder",
    "accorderez": "accorder",
    "accorderiez": "accorder",
    "accorderions": "accorder",
    "accorderons": "accorder",
    "accorderont": "accorder",
    "accordes": "accorder",
    "accordeurs": "accordeur",
    "accordez": "accorder",
    "accordiez": "accorder",
    "accordions": "accorder",
    "accordons": "accorder",
    "accords": "accord",
    "accordâmes": "accorder",
    "accordât": "accorder",
    "accordâtes": "accorder",
    "accordèrent": "accorder",
    "accordé": "accorder",
    "accordée": "accorder",
    "accordées": "accorder",
    "accordéonistes": "accordéoniste",
    "accordéons": "accordéon",
    "accordés": "accorder",
    "accores": "accore",
    "accorte": "accort",
    "accortes": "accort",
    "accorts": "accort",
    "accosta": "accoster",
    "accostages": "accostage",
    "accostai": "accoster",
    "accostaient": "accoster",
    "accostais": "accoster",
    "accostait": "accoster",
    "accostant": "accoster",
    "accostas": "accoster",
    "accostasse": "accoster",
    "accostassent": "accoster",
    "accostasses": "accoster",
    "accostassiez": "accoster",
    "accostassions": "accoster",
    "accoste": "accoster",
    "accostent": "accoster",
    "accostera": "accoster",
    "accosterai": "accoster",
    "accosteraient": "accoster",
    "accosterais": "accoster",
    "accosterait": "accoster",
    "accosteras": "accoster",
    "accosterez": "accoster",
    "accosteriez": "accoster",
    "accosterions": "accoster",
    "accosterons": "accoster",
    "accosteront": "accoster",
    "accostes": "accoster",
    "accostez": "accoster",
    "accostiez": "accoster",
    "accostions": "accoster",
    "accostons": "accoster",
    "accostâmes": "accoster",
    "accostât": "accoster",
    "accostâtes": "accoster",
    "accostèrent": "accoster",
    "accosté": "accoster",
    "accostée": "accoster",
    "accostées": "accoster",
    "accostés": "accoster",
    "accota": "accoter",
    "accotai": "accoter",
    "accotaient": "accoter",
    "accotais": "accoter",
    "accotait": "accoter",
    "accotant": "accoter",
    "accotas": "accoter",
    "accotasse": "accoter",
    "accotassent": "accoter",
    "accotasses": "accoter",
    "accotassiez": "accoter",
    "accotassions": "accoter",
    "accote": "accoter",
    "accotements": "accotement",
    "accotent": "accoter",
    "accotera": "accoter",
    "accoterai": "accoter",
    "accoteraient": "accoter",
    "accoterais": "accoter",
    "accoterait": "accoter",
    "accoteras": "accoter",
    "accoterez": "accoter",
    "accoteriez": "accoter",
    "accoterions": "accoter",
    "accoterons": "accoter",
    "accoteront": "accoter",
    "accotes": "accoter",
    "accotez": "accoter",
    "accotiez": "accoter",
    "accotions": "accoter",
    "accotoirs": "accotoir",
    "accotons": "accoter",
    "accotâmes": "accoter",
    "accotât": "accoter",
    "accotâtes": "accoter",
    "accotèrent": "accoter",
    "accoté": "accoter",
    "accotée": "accoter",
    "accotées": "accoter",
    "accotés": "accoter",
    "accoucha": "accoucher",
    "accouchai": "accoucher",
    "accouchaient": "accoucher",
    "accouchais": "accoucher",
    "accouchait": "accoucher",
    "accouchant": "accoucher",
    "accouchas": "accoucher",
    "accouchasse": "accoucher",
    "accouchassent": "accoucher",
    "accouchasses": "accoucher",
    "accouchassiez": "accoucher",
    "accouchassions": "accoucher",
    "accouche": "accoucher",
    "accouchements": "accouchement",
    "accouchent": "accoucher",
    "accouchera": "accoucher",
    "accoucherai": "accoucher",
    "accoucheraient": "accoucher",
    "accoucherais": "accoucher",
    "accoucherait": "accoucher",
    "accoucheras": "accoucher",
    "accoucherez": "accoucher",
    "accoucheriez": "accoucher",
    "accoucherions": "accoucher",
    "accoucherons": "accoucher",
    "accoucheront": "accoucher",
    "accouches": "accoucher",
    "accoucheurs": "accoucheur",
    "accoucheuse": "accoucheur",
    "accoucheuses": "accoucheur",
    "accouchez": "accoucher",
    "accouchiez": "accoucher",
    "accouchions": "accoucher",
    "accouchons": "accoucher",
    "accouchâmes": "accoucher",
    "accouchât": "accoucher",
    "accouchâtes": "accoucher",
    "accouchèrent": "accoucher",
    "accouché": "accoucher",
    "accouchée": "accoucher",
    "accouchées": "accoucher",
    "accouchés": "accoucher",
    "accouda": "accouder",
    "accoudai": "accouder",
    "accoudaient": "accouder",
    "accoudais": "accouder",
    "accoudait": "accouder",
    "accoudant": "accouder",
    "accoudas": "accouder",
    "accoudasse": "accouder",
    "accoudassent": "accouder",
    "accoudasses": "accouder",
    "accoudassiez": "accouder",
    "accoudassions": "accouder",
    "accoude": "accouder",
    "accoudent": "accouder",
    "accoudera": "accouder",
    "accouderai": "accouder",
    "accouderaient": "accouder",
    "accouderais": "accouder",
    "accouderait": "accouder",
    "accouderas": "accouder",
    "accouderez": "accouder",
    "accouderiez": "accouder",
    "accouderions": "accouder",
    "accouderons": "accouder",
    "accouderont": "accouder",
    "accoudes": "accouder",
    "accoudez": "accouder",
    "accoudiez": "accouder",
    "accoudions": "accouder",
    "accoudoirs": "accoudoir",
    "accoudons": "accouder",
    "accoudâmes": "accouder",
    "accoudât": "accouder",
    "accoudâtes": "accouder",
    "accoudèrent": "accouder",
    "accoudé": "accouder",
    "accoudée": "accouder",
    "accoudées": "accouder",
    "accoudés": "accouder",
    "accoupla": "accoupler",
    "accouplai": "accoupler",
    "accouplaient": "accoupler",
    "accouplais": "accoupler",
    "accouplait": "accoupler",
    "accouplant": "accoupler",
    "accouplas": "accoupler",
    "accouplasse": "accoupler",
    "accouplassent": "accoupler",
    "accouplasses": "accoupler",
    "accouplassiez": "accoupler",
    "accouplassions": "accoupler",
    "accouple": "accoupler",
    "accouplements": "accouplement",
    "accouplent": "accoupler",
    "accouplera": "accoupler",
    "accouplerai": "accoupler",
    "accoupleraient": "accoupler",
    "accouplerais": "accoupler",
    "accouplerait": "accoupler",
    "accoupleras": "accoupler",
    "accouplerez": "accoupler",
    "accoupleriez": "accoupler",
    "accouplerions": "accoupler",
    "accouplerons": "accoupler",
    "accoupleront": "accoupler",
    "accouples": "accoupler",
    "accouplez": "accoupler",
    "accoupliez": "accoupler",
    "accouplions": "accoupler",
    "accouplons": "accoupler",
    "accouplâmes": "accoupler",
    "accouplât": "accoupler",
    "accouplâtes": "accoupler",
    "accouplèrent": "accoupler",
    "accouplé": "accoupler",
    "accouplée": "accoupler",
    "accouplées": "accoupler",
    "accouplés": "accoupler",
    "accouraient": "accourir",
    "accourais": "accourir",
    "accourait": "accourir",
    "accourant": "accourir",
    "accourci": "accourcir",
    "accourcie": "accourcir",
    "accourcies": "accourcir",
    "accourcira": "accourcir",
    "accourcirai": "accourcir",
    "accourciraient": "accourcir",
    "accourcirais": "accourcir",
    "accourcirait": "accourcir",
    "accourciras": "accourcir",
    "accourcirent": "accourcir",
    "accourcirez": "accourcir",
    "accourciriez": "accourcir",
    "accourcirions": "accourcir",
    "accourcirons": "accourcir",
    "accourciront": "accourcir",
    "accourcis": "accourcir",
    "accourcissaient": "accourcir",
    "accourcissais": "accourcir",
    "accourcissait": "accourcir",
    "accourcissant": "accourcir",
    "accourcisse": "accourcir",
    "accourcissent": "accourcir",
    "accourcisses": "accourcir",
    "accourcissez": "accourcir",
    "accourcissiez": "accourcir",
    "accourcissions": "accourcir",
    "accourcissons": "accourcir",
    "accourcit": "accourcir",
    "accourcîmes": "accourcir",
    "accourcît": "accourcir",
    "accourcîtes": "accourcir",
    "accoure": "accourir",
    "accourent": "accourir",
    "accoures": "accourir",
    "accourez": "accourir",
    "accouriez": "accourir",
    "accourions": "accourir",
    "accourons": "accourir",
    "accourra": "accourir",
    "accourrai": "accourir",
    "accourraient": "accourir",
    "accourrais": "accourir",
    "accourrait": "accourir",
    "accourras": "accourir",
    "accourrez": "accourir",
    "accourriez": "accourir",
    "accourrions": "accourir",
    "accourrons": "accourir",
    "accourront": "accourir",
    "accours": "accourir",
    "accourt": "accourir",
    "accouru": "accourir",
    "accourue": "accourir",
    "accourues": "accourir",
    "accoururent": "accourir",
    "accourus": "accourir",
    "accourusse": "accourir",
    "accourussent": "accourir",
    "accourusses": "accourir",
    "accourussiez": "accourir",
    "accourussions": "accourir",
    "accourut": "accourir",
    "accourûmes": "accourir",
    "accourût": "accourir",
    "accourûtes": "accourir",
    "accoutra": "accoutrer",
    "accoutrai": "accoutrer",
    "accoutraient": "accoutrer",
    "accoutrais": "accoutrer",
    "accoutrait": "accoutrer",
    "accoutrant": "accoutrer",
    "accoutras": "accoutrer",
    "accoutrasse": "accoutrer",
    "accoutrassent": "accoutrer",
    "accoutrasses": "accoutrer",
    "accoutrassiez": "accoutrer",
    "accoutrassions": "accoutrer",
    "accoutre": "accoutrer",
    "accoutrements": "accoutrement",
    "accoutrent": "accoutrer",
    "accoutrera": "accoutrer",
    "accoutrerai": "accoutrer",
    "accoutreraient": "accoutrer",
    "accoutrerais": "accoutrer",
    "accoutrerait": "accoutrer",
    "accoutreras": "accoutrer",
    "accoutrerez": "accoutrer",
    "accoutreriez": "accoutrer",
    "accoutrerions": "accoutrer",
    "accoutrerons": "accoutrer",
    "accoutreront": "accoutrer",
    "accoutres": "accoutrer",
    "accoutrez": "accoutrer",
    "accoutriez": "accoutrer",
    "accoutrions": "accoutrer",
    "accoutrons": "accoutrer",
    "accoutrâmes": "accoutrer",
    "accoutrât": "accoutrer",
    "accoutrâtes": "accoutrer",
    "accoutrèrent": "accoutrer",
    "accoutré": "accoutrer",
    "accoutrée": "accoutrer",
    "accoutrées": "accoutrer",
    "accoutrés": "accoutrer",
    "accoutuma": "accoutumer",
    "accoutumai": "accoutumer",
    "accoutumaient": "accoutumer",
    "accoutumais": "accoutumer",
    "accoutumait": "accoutumer",
    "accoutumances": "accoutumance",
    "accoutumant": "accoutumer",
    "accoutumas": "accoutumer",
    "accoutumasse": "accoutumer",
    "accoutumassent": "accoutumer",
    "accoutumasses": "accoutumer",
    "accoutumassiez": "accoutumer",
    "accoutumassions": "accoutumer",
    "accoutume": "accoutumer",
    "accoutument": "accoutumer",
    "accoutumera": "accoutumer",
    "accoutumerai": "accoutumer",
    "accoutumeraient": "accoutumer",
    "accoutumerais": "accoutumer",
    "accoutumerait": "accoutumer",
    "accoutumeras": "accoutumer",
    "accoutumerez": "accoutumer",
    "accoutumeriez": "accoutumer",
    "accoutumerions": "accoutumer",
    "accoutumerons": "accoutumer",
    "accoutumeront": "accoutumer",
    "accoutumes": "accoutumer",
    "accoutumez": "accoutumer",
    "accoutumiez": "accoutumer",
    "accoutumions": "accoutumer",
    "accoutumons": "accoutumer",
    "accoutumâmes": "accoutumer",
    "accoutumât": "accoutumer",
    "accoutumâtes": "accoutumer",
    "accoutumèrent": "accoutumer",
    "accoutumé": "accoutumer",
    "accoutumée": "accoutumer",
    "accoutumées": "accoutumer",
    "accoutumés": "accoutumer",
    "accouvée": "accouver",
    "accras": "accra",
    "accrocha": "accrocher",
    "accrochages": "accrochage",
    "accrochai": "accrocher",
    "accrochaient": "accrocher",
    "accrochais": "accrocher",
    "accrochait": "accrocher",
    "accrochant": "accrocher",
    "accrochas": "accrocher",
    "accrochasse": "accrocher",
    "accrochassent": "accrocher",
    "accrochasses": "accrocher",
    "accrochassiez": "accrocher",
    "accrochassions": "accrocher",
    "accroche": "accrocher",
    "accroche-coeurs": "accroche-coeur",
    "accroche-plats": "accroche-plat",
    "accrochent": "accrocher",
    "accrochera": "accrocher",
    "accrocherai": "accrocher",
    "accrocheraient": "accrocher",
    "accrocherais": "accrocher",
    "accrocherait": "accrocher",
    "accrocheras": "accrocher",
    "accrocherez": "accrocher",
    "accrocheriez": "accrocher",
    "accrocherions": "accrocher",
    "accrocherons": "accrocher",
    "accrocheront": "accrocher",
    "accroches": "accrocher",
    "accrocheurs": "accrocheur",
    "accrocheuse": "accrocheur",
    "accrocheuses": "accrocheur",
    "accrochez": "accrocher",
    "accrochiez": "accrocher",
    "accrochions": "accrocher",
    "accrochons": "accrocher",
    "accrochâmes": "accrocher",
    "accrochât": "accrocher",
    "accrochâtes": "accrocher",
    "accrochèrent": "accrocher",
    "accroché": "accrocher",
    "accrochée": "accrocher",
    "accrochées": "accrocher",
    "accrochés": "accrocher",
    "accrocs": "accroc",
    "accrois": "accroître",
    "accroissaient": "accroître",
    "accroissais": "accroître",
    "accroissait": "accroître",
    "accroissant": "accroître",
    "accroisse": "accroître",
    "accroissements": "accroissement",
    "accroissent": "accroître",
    "accroisses": "accroître",
    "accroissez": "accroître",
    "accroissiez": "accroître",
    "accroissions": "accroître",
    "accroissons": "accroître",
    "accros": "accro",
    "accroupi": "accroupir",
    "accroupie": "accroupir",
    "accroupies": "accroupir",
    "accroupira": "accroupir",
    "accroupirai": "accroupir",
    "accroupiraient": "accroupir",
    "accroupirais": "accroupir",
    "accroupirait": "accroupir",
    "accroupiras": "accroupir",
    "accroupirent": "accroupir",
    "accroupirez": "accroupir",
    "accroupiriez": "accroupir",
    "accroupirions": "accroupir",
    "accroupirons": "accroupir",
    "accroupiront": "accroupir",
    "accroupis": "accroupir",
    "accroupissaient": "accroupir",
    "accroupissais": "accroupir",
    "accroupissait": "accroupir",
    "accroupissant": "accroupir",
    "accroupisse": "accroupir",
    "accroupissent": "accroupir",
    "accroupisses": "accroupir",
    "accroupissez": "accroupir",
    "accroupissiez": "accroupir",
    "accroupissions": "accroupir",
    "accroupissons": "accroupir",
    "accroupit": "accroupir",
    "accroupîmes": "accroupir",
    "accroupît": "accroupir",
    "accroupîtes": "accroupir",
    "accroît": "accroître",
    "accroîtra": "accroître",
    "accroîtrai": "accroître",
    "accroîtraient": "accroître",
    "accroîtrais": "accroître",
    "accroîtrait": "accroître",
    "accroîtras": "accroître",
    "accroîtrez": "accroître",
    "accroîtriez": "accroître",
    "accroîtrions": "accroître",
    "accroîtrons": "accroître",
    "accroîtront": "accroître",
    "accru": "accroître",
    "accrue": "accru",
    "accrues": "accru",
    "accrurent": "accroître",
    "accrus": "accru",
    "accrusse": "accroître",
    "accrussent": "accroître",
    "accrusses": "accroître",
    "accrussiez": "accroître",
    "accrussions": "accroître",
    "accrut": "accroître",
    "accrédita": "accréditer",
    "accréditai": "accréditer",
    "accréditaient": "accréditer",
    "accréditais": "accréditer",
    "accréditait": "accréditer",
    "accréditant": "accréditer",
    "accréditas": "accréditer",
    "accréditasse": "accréditer",
    "accréditassent": "accréditer",
    "accréditasses": "accréditer",
    "accréditassiez": "accréditer",
    "accréditassions": "accréditer",
    "accréditations": "accréditation",
    "accrédite": "accréditer",
    "accréditent": "accréditer",
    "accréditera": "accréditer",
    "accréditerai": "accréditer",
    "accréditeraient": "accréditer",
    "accréditerais": "accréditer",
    "accréditerait": "accréditer",
    "accréditeras": "accréditer",
    "accréditerez": "accréditer",
    "accréditeriez": "accréditer",
    "accréditerions": "accréditer",
    "accréditerons": "accréditer",
    "accréditeront": "accréditer",
    "accrédites": "accréditer",
    "accréditez": "accréditer",
    "accréditiez": "accréditer",
    "accréditions": "accréditer",
    "accréditons": "accréditer",
    "accréditâmes": "accréditer",
    "accréditât": "accréditer",
    "accréditâtes": "accréditer",
    "accréditèrent": "accréditer",
    "accrédité": "accréditer",
    "accréditée": "accréditer",
    "accréditées": "accréditer",
    "accrédités": "accréditer",
    "accrûmes": "accroître",
    "accrût": "accroître",
    "accrûtes": "accroître",
    "accueillaient": "accueillir",
    "accueillais": "accueillir",
    "accueillait": "accueillir",
    "accueillant": "accueillir",
    "accueillante": "accueillant",
    "accueillantes": "accueillant",
    "accueillants": "accueillant",
    "accueille": "accueillir",
    "accueillent": "accueillir",
    "accueillera": "accueillir",
    "accueillerai": "accueillir",
    "accueilleraient": "accueillir",
    "accueillerais": "accueillir",
    "accueillerait": "accueillir",
    "accueilleras": "accueillir",
    "accueillerez": "accueillir",
    "accueilleriez": "accueillir",
    "accueillerions": "accueillir",
    "accueillerons": "accueillir",
    "accueilleront": "accueillir",
    "accueilles": "accueillir",
    "accueillez": "accueillir",
    "accueilli": "accueillir",
    "accueillie": "accueillir",
    "accueillies": "accueillir",
    "accueilliez": "accueillir",
    "accueillions": "accueillir",
    "accueillirent": "accueillir",
    "accueillis": "accueillir",
    "accueillisse": "accueillir",
    "accueillissent": "accueillir",
    "accueillisses": "accueillir",
    "accueillissiez": "accueillir",
    "accueillissions": "accueillir",
    "accueillit": "accueillir",
    "accueillons": "accueillir",
    "accueillîmes": "accueillir",
    "accueillît": "accueillir",
    "accueillîtes": "accueillir",
    "accueils": "accueil",
    "accula": "acculer",
    "acculai": "acculer",
    "acculaient": "acculer",
    "acculais": "acculer",
    "acculait": "acculer",
    "acculant": "acculer",
    "acculas": "acculer",
    "acculasse": "acculer",
    "acculassent": "acculer",
    "acculasses": "acculer",
    "acculassiez": "acculer",
    "acculassions": "acculer",
    "accule": "acculer",
    "acculent": "acculer",
    "acculera": "acculer",
    "acculerai": "acculer",
    "acculeraient": "acculer",
    "acculerais": "acculer",
    "acculerait": "acculer",
    "acculeras": "acculer",
    "acculerez": "acculer",
    "acculeriez": "acculer",
    "acculerions": "acculer",
    "acculerons": "acculer",
    "acculeront": "acculer",
    "accules": "acculer",
    "acculez": "acculer",
    "acculiez": "acculer",
    "acculions": "acculer",
    "acculons": "acculer",
    "acculâmes": "acculer",
    "acculât": "acculer",
    "acculâtes": "acculer",
    "acculèrent": "acculer",
    "acculé": "acculer",
    "acculée": "acculer",
    "acculées": "acculer",
    "acculés": "acculer",
    "accumula": "accumuler",
    "accumulai": "accumuler",
    "accumulaient": "accumuler",
    "accumulais": "accumuler",
    "accumulait": "accumuler",
    "accumulant": "accumuler",
    "accumulas": "accumuler",
    "accumulasse": "accumuler",
    "accumulassent": "accumuler",
    "accumulasses": "accumuler",
    "accumulassiez": "accumuler",
    "accumulassions": "accumuler",
    "accumulateurs": "accumulateur",
    "accumulations": "accumulation",
    "accumule": "accumuler",
    "accumulent": "accumuler",
    "accumulera": "accumuler",
    "accumulerai": "accumuler",
    "accumuleraient": "accumuler",
    "accumulerais": "accumuler",
    "accumulerait": "accumuler",
    "accumuleras": "accumuler",
    "accumulerez": "accumuler",
    "accumuleriez": "accumuler",
    "accumulerions": "accumuler",
    "accumulerons": "accumuler",
    "accumuleront": "accumuler",
    "accumules": "accumuler",
    "accumulez": "accumuler",
    "accumuliez": "accumuler",
    "accumulions": "accumuler",
    "accumulons": "accumuler",
    "accumulâmes": "accumuler",
    "accumulât": "accumuler",
    "accumulâtes": "accumuler",
    "accumulèrent": "accumuler",
    "accumulé": "accumuler",
    "accumulée": "accumuler",
    "accumulées": "accumuler",
    "accumulés": "accumuler",
    "accus": "accu",
    "accusa": "accuser",
    "accusai": "accuser",
    "accusaient": "accuser",
    "accusais": "accuser",
    "accusait": "accuser",
    "accusant": "accuser",
    "accusas": "accuser",
    "accusasse": "accuser",
    "accusassent": "accuser",
    "accusasses": "accuser",
    "accusassiez": "accuser",
    "accusassions": "accuser",
    "accusateurs": "accusateur",
    "accusations": "accusation",
    "accusatrice": "accusateur",
    "accusatrices": "accusateur",
    "accuse": "accuser",
    "accusent": "accuser",
    "accusera": "accuser",
    "accuserai": "accuser",
    "accuseraient": "accuser",
    "accuserais": "accuser",
    "accuserait": "accuser",
    "accuseras": "accuser",
    "accuserez": "accuser",
    "accuseriez": "accuser",
    "accuserions": "accuser",
    "accuserons": "accuser",
    "accuseront": "accuser",
    "accuses": "accuser",
    "accusez": "accuser",
    "accusiez": "accuser",
    "accusions": "accuser",
    "accusons": "accuser",
    "accusâmes": "accuser",
    "accusât": "accuser",
    "accusâtes": "accuser",
    "accusèrent": "accuser",
    "accusé": "accuser",
    "accusée": "accuser",
    "accusées": "accuser",
    "accusés": "accuser",
    "accède": "accéder",
    "accèdent": "accéder",
    "accèdes": "accéder",
    "accéda": "accéder",
    "accédai": "accéder",
    "accédaient": "accéder",
    "accédais": "accéder",
    "accédait": "accéder",
    "accédant": "accéder",
    "accédante": "accédant",
    "accédants": "accédant",
    "accédas": "accéder",
    "accédasse": "accéder",
    "accédassent": "accéder",
    "accédasses": "accéder",
    "accédassiez": "accéder",
    "accédassions": "accéder",
    "accédera": "accéder",
    "accéderai": "accéder",
    "accéderaient": "accéder",
    "accéderais": "accéder",
    "accéderait": "accéder",
    "accéderas": "accéder",
    "accéderez": "accéder",
    "accéderiez": "accéder",
    "accéderions": "accéder",
    "accéderons": "accéder",
    "accéderont": "accéder",
    "accédez": "accéder",
    "accédiez": "accéder",
    "accédions": "accéder",
    "accédons": "accéder",
    "accédâmes": "accéder",
    "accédât": "accéder",
    "accédâtes": "accéder",
    "accédèrent": "accéder",
    "accédé": "accéder",
    "accélère": "accélérer",
    "accélèrent": "accélérer",
    "accélères": "accélérer",
    "accéléra": "accélérer",
    "accélérai": "accélérer",
    "accéléraient": "accélérer",
    "accélérais": "accélérer",
    "accélérait": "accélérer",
    "accélérant": "accélérer",
    "accélérants": "accélérant",
    "accéléras": "accélérer",
    "accélérasse": "accélérer",
    "accélérassent": "accélérer",
    "accélérasses": "accélérer",
    "accélérassiez": "accélérer",
    "accélérassions": "accélérer",
    "accélérateurs": "accélérateur",
    "accélérations": "accélération",
    "accélératrice": "accélérateur",
    "accélérera": "accélérer",
    "accélérerai": "accélérer",
    "accéléreraient": "accélérer",
    "accélérerais": "accélérer",
    "accélérerait": "accélérer",
    "accéléreras": "accélérer",
    "accélérerez": "accélérer",
    "accéléreriez": "accélérer",
    "accélérerions": "accélérer",
    "accélérerons": "accélérer",
    "accéléreront": "accélérer",
    "accélérez": "accélérer",
    "accélériez": "accélérer",
    "accélérions": "accélérer",
    "accélérons": "accélérer",
    "accélérâmes": "accélérer",
    "accélérât": "accélérer",
    "accélérâtes": "accélérer",
    "accélérèrent": "accélérer",
    "accéléré": "accélérer",
    "accélérée": "accélérer",
    "accélérées": "accélérer",
    "accélérés": "accélérer",
    "acerbes": "acerbe",
    "achalandaient": "achalander",
    "achalandée": "achalandé",
    "achalandées": "achalandé",
    "achalandés": "achalander",
    "acharna": "acharner",
    "acharnai": "acharner",
    "acharnaient": "acharner",
    "acharnais": "acharner",
    "acharnait": "acharner",
    "acharnant": "acharner",
    "acharnas": "acharner",
    "acharnasse": "acharner",
    "acharnassent": "acharner",
    "acharnasses": "acharner",
    "acharnassiez": "acharner",
    "acharnassions": "acharner",
    "acharne": "acharner",
    "acharnements": "acharnement",
    "acharnent": "acharner",
    "acharnera": "acharner",
    "acharnerai": "acharner",
    "acharneraient": "acharner",
    "acharnerais": "acharner",
    "acharnerait": "acharner",
    "acharneras": "acharner",
    "acharnerez": "acharner",
    "acharneriez": "acharner",
    "acharnerions": "acharner",
    "acharnerons": "acharner",
    "acharneront": "acharner",
    "acharnes": "acharner",
    "acharnez": "acharner",
    "acharniez": "acharner",
    "acharnions": "acharner",
    "acharnons": "acharner",
    "acharnâmes": "acharner",
    "acharnât": "acharner",
    "acharnâtes": "acharner",
    "acharnèrent": "acharner",
    "acharné": "acharner",
    "acharnée": "acharner",
    "acharnées": "acharner",
    "acharnés": "acharner",
    "achats": "achat",
    "achemina": "acheminer",
    "acheminai": "acheminer",
    "acheminaient": "acheminer",
    "acheminais": "acheminer",
    "acheminait": "acheminer",
    "acheminant": "acheminer",
    "acheminas": "acheminer",
    "acheminasse": "acheminer",
    "acheminassent": "acheminer",
    "acheminasses": "acheminer",
    "acheminassiez": "acheminer",
    "acheminassions": "acheminer",
    "achemine": "acheminer",
    "acheminements": "acheminement",
    "acheminent": "acheminer",
    "acheminera": "acheminer",
    "acheminerai": "acheminer",
    "achemineraient": "acheminer",
    "acheminerais": "acheminer",
    "acheminerait": "acheminer",
    "achemineras": "acheminer",
    "acheminerez": "acheminer",
    "achemineriez": "acheminer",
    "acheminerions": "acheminer",
    "acheminerons": "acheminer",
    "achemineront": "acheminer",
    "achemines": "acheminer",
    "acheminez": "acheminer",
    "acheminiez": "acheminer",
    "acheminions": "acheminer",
    "acheminons": "acheminer",
    "acheminâmes": "acheminer",
    "acheminât": "acheminer",
    "acheminâtes": "acheminer",
    "acheminèrent": "acheminer",
    "acheminé": "acheminer",
    "acheminée": "acheminer",
    "acheminées": "acheminer",
    "acheminés": "acheminer",
    "aches": "ache",
    "acheta": "acheter",
    "achetai": "acheter",
    "achetaient": "acheter",
    "achetais": "acheter",
    "achetait": "acheter",
    "achetant": "acheter",
    "achetas": "acheter",
    "achetasse": "acheter",
    "achetassent": "acheter",
    "achetasses": "acheter",
    "achetassiez": "acheter",
    "achetassions": "acheter",
    "acheteurs": "acheteur",
    "acheteuse": "acheteur",
    "acheteuses": "acheteur",
    "achetez": "acheter",
    "achetiez": "acheter",
    "achetions": "acheter",
    "achetons": "acheter",
    "achetâmes": "acheter",
    "achetât": "acheter",
    "achetâtes": "acheter",
    "achetèrent": "acheter",
    "acheté": "acheter",
    "achetée": "acheter",
    "achetées": "acheter",
    "achetés": "acheter",
    "acheva": "achever",
    "achevai": "achever",
    "achevaient": "achever",
    "achevais": "achever",
    "achevait": "achever",
    "achevant": "achever",
    "achevas": "achever",
    "achevasse": "achever",
    "achevassent": "achever",
    "achevasses": "achever",
    "achevassiez": "achever",
    "achevassions": "achever",
    "achevez": "achever",
    "acheviez": "achever",
    "achevions": "achever",
    "achevons": "achever",
    "achevâmes": "achever",
    "achevât": "achever",
    "achevâtes": "achever",
    "achevèrent": "achever",
    "achevé": "achever",
    "achevée": "achever",
    "achevées": "achever",
    "achevés": "achever",
    "achondroplasies": "achondroplasie",
    "achoppa": "achopper",
    "achoppai": "achopper",
    "achoppaient": "achopper",
    "achoppais": "achopper",
    "achoppait": "achopper",
    "achoppant": "achopper",
    "achoppas": "achopper",
    "achoppasse": "achopper",
    "achoppassent": "achopper",
    "achoppasses": "achopper",
    "achoppassiez": "achopper",
    "achoppassions": "achopper",
    "achoppe": "achopper",
    "achoppements": "achoppement",
    "achoppent": "achopper",
    "achoppera": "achopper",
    "achopperai": "achopper",
    "achopperaient": "achopper",
    "achopperais": "achopper",
    "achopperait": "achopper",
    "achopperas": "achopper",
    "achopperez": "achopper",
    "achopperiez": "achopper",
    "achopperions": "achopper",
    "achopperons": "achopper",
    "achopperont": "achopper",
    "achoppes": "achopper",
    "achoppez": "achopper",
    "achoppiez": "achopper",
    "achoppions": "achopper",
    "achoppons": "achopper",
    "achoppâmes": "achopper",
    "achoppât": "achopper",
    "achoppâtes": "achopper",
    "achoppèrent": "achopper",
    "achoppé": "achopper",
    "achoppée": "achopper",
    "achète": "acheter",
    "achètent": "acheter",
    "achètera": "acheter",
    "achèterai": "acheter",
    "achèteraient": "acheter",
    "achèterais": "acheter",
    "achèterait": "acheter",
    "achèteras": "acheter",
    "achèterez": "acheter",
    "achèteriez": "acheter",
    "achèterions": "acheter",
    "achèterons": "acheter",
    "achèteront": "acheter",
    "achètes": "acheter",
    "achève": "achever",
    "achèvements": "achèvement",
    "achèvent": "achever",
    "achèvera": "achever",
    "achèverai": "achever",
    "achèveraient": "achever",
    "achèverais": "achever",
    "achèverait": "achever",
    "achèveras": "achever",
    "achèverez": "achever",
    "achèveriez": "achever",
    "achèverions": "achever",
    "achèverons": "achever",
    "achèveront": "achever",
    "achèves": "achever",
    "achélèmes": "achélème",
    "acides": "acide",
    "acidifia": "acidifier",
    "acidifiai": "acidifier",
    "acidifiaient": "acidifier",
    "acidifiais": "acidifier",
    "acidifiait": "acidifier",
    "acidifiant": "acidifier",
    "acidifias": "acidifier",
    "acidifiasse": "acidifier",
    "acidifiassent": "acidifier",
    "acidifiasses": "acidifier",
    "acidifiassiez": "acidifier",
    "acidifiassions": "acidifier",
    "acidifications": "acidification",
    "acidifie": "acidifier",
    "acidifient": "acidifier",
    "acidifiera": "acidifier",
    "acidifierai": "acidifier",
    "acidifieraient": "acidifier",
    "acidifierais": "acidifier",
    "acidifierait": "acidifier",
    "acidifieras": "acidifier",
    "acidifierez": "acidifier",
    "acidifieriez": "acidifier",
    "acidifierions": "acidifier",
    "acidifierons": "acidifier",
    "acidifieront": "acidifier",
    "acidifies": "acidifier",
    "acidifiez": "acidifier",
    "acidifiiez": "acidifier",
    "acidifiions": "acidifier",
    "acidifions": "acidifier",
    "acidifiâmes": "acidifier",
    "acidifiât": "acidifier",
    "acidifiâtes": "acidifier",
    "acidifièrent": "acidifier",
    "acidifié": "acidifier",
    "acidifiée": "acidifier",
    "acidifiées": "acidifier",
    "acidifiés": "acidifier",
    "acidités": "acidité",
    "acidulé": "aciduler",
    "acidulée": "aciduler",
    "acidulées": "aciduler",
    "acidulés": "aciduler",
    "aciers": "acier",
    "acière": "aciérer",
    "acièrent": "aciérer",
    "acières": "aciérer",
    "aciéra": "aciérer",
    "aciérai": "aciérer",
    "aciéraient": "aciérer",
    "aciérais": "aciérer",
    "aciérait": "aciérer",
    "aciérant": "aciérer",
    "aciéras": "aciérer",
    "aciérasse": "aciérer",
    "aciérassent": "aciérer",
    "aciérasses": "aciérer",
    "aciérassiez": "aciérer",
    "aciérassions": "aciérer",
    "aciérera": "aciérer",
    "aciérerai": "aciérer",
    "aciéreraient": "aciérer",
    "aciérerais": "aciérer",
    "aciérerait": "aciérer",
    "aciéreras": "aciérer",
    "aciérerez": "aciérer",
    "aciéreriez": "aciérer",
    "aciérerions": "aciérer",
    "aciérerons": "aciérer",
    "aciéreront": "aciérer",
    "aciérez": "aciérer",
    "aciéries": "aciérie",
    "aciériez": "aciérer",
    "aciérions": "aciérer",
    "aciérons": "aciérer",
    "aciérâmes": "aciérer",
    "aciérât": "aciérer",
    "aciérâtes": "aciérer",
    "aciérèrent": "aciérer",
    "aciéré": "aciérer",
    "aciérée": "aciérer",
    "aciérées": "aciérer",
    "aciérés": "aciérer",
    "acnéiques": "acnéique",
    "acnés": "acné",
    "acolytes": "acolyte",
    "acomptes": "acompte",
    "aconiers": "aconier",
    "acoquina": "acoquiner",
    "acoquinai": "acoquiner",
    "acoquinaient": "acoquiner",
    "acoquinais": "acoquiner",
    "acoquinait": "acoquiner",
    "acoquinant": "acoquiner",
    "acoquinas": "acoquiner",
    "acoquinasse": "acoquiner",
    "acoquinassent": "acoquiner",
    "acoquinasses": "acoquiner",
    "acoquinassiez": "acoquiner",
    "acoquinassions": "acoquiner",
    "acoquine": "acoquiner",
    "acoquinent": "acoquiner",
    "acoquinera": "acoquiner",
    "acoquinerai": "acoquiner",
    "acoquineraient": "acoquiner",
    "acoquinerais": "acoquiner",
    "acoquinerait": "acoquiner",
    "acoquineras": "acoquiner",
    "acoquinerez": "acoquiner",
    "acoquineriez": "acoquiner",
    "acoquinerions": "acoquiner",
    "acoquinerons": "acoquiner",
    "acoquineront": "acoquiner",
    "acoquines": "acoquiner",
    "acoquinez": "acoquiner",
    "acoquiniez": "acoquiner",
    "acoquinions": "acoquiner",
    "acoquinons": "acoquiner",
    "acoquinâmes": "acoquiner",
    "acoquinât": "acoquiner",
    "acoquinâtes": "acoquiner",
    "acoquinèrent": "acoquiner",
    "acoquiné": "acoquiner",
    "acoquinée": "acoquiner",
    "acoquinées": "acoquiner",
    "acoquinés": "acoquiner",
    "acoustiques": "acoustique",
    "acqueducs": "acqueduc",
    "acquerra": "acquérir",
    "acquerrai": "acquérir",
    "acquerraient": "acquérir",
    "acquerrais": "acquérir",
    "acquerrait": "acquérir",
    "acquerras": "acquérir",
    "acquerrez": "acquérir",
    "acquerriez": "acquérir",
    "acquerrions": "acquérir",
    "acquerrons": "acquérir",
    "acquerront": "acquérir",
    "acquiers": "acquérir",
    "acquiert": "acquérir",
    "acquiesce": "acquiescer",
    "acquiescements": "acquiescement",
    "acquiescent": "acquiescer",
    "acquiescera": "acquiescer",
    "acquiescerai": "acquiescer",
    "acquiesceraient": "acquiescer",
    "acquiescerais": "acquiescer",
    "acquiescerait": "acquiescer",
    "acquiesceras": "acquiescer",
    "acquiescerez": "acquiescer",
    "acquiesceriez": "acquiescer",
    "acquiescerions": "acquiescer",
    "acquiescerons": "acquiescer",
    "acquiesceront": "acquiescer",
    "acquiesces": "acquiescer",
    "acquiescez": "acquiescer",
    "acquiesciez": "acquiescer",
    "acquiescions": "acquiescer",
    "acquiescèrent": "acquiescer",
    "acquiescé": "acquiescer",
    "acquiesça": "acquiescer",
    "acquiesçai": "acquiescer",
    "acquiesçaient": "acquiescer",
    "acquiesçais": "acquiescer",
    "acquiesçait": "acquiescer",
    "acquiesçant": "acquiescer",
    "acquiesças": "acquiescer",
    "acquiesçasse": "acquiescer",
    "acquiesçassent": "acquiescer",
    "acquiesçasses": "acquiescer",
    "acquiesçassiez": "acquiescer",
    "acquiesçassions": "acquiescer",
    "acquiesçons": "acquiescer",
    "acquiesçâmes": "acquiescer",
    "acquiesçât": "acquiescer",
    "acquiesçâtes": "acquiescer",
    "acquirent": "acquérir",
    "acquis": "acquérir",
    "acquise": "acquis",
    "acquises": "acquis",
    "acquisitions": "acquisition",
    "acquisse": "acquérir",
    "acquissent": "acquérir",
    "acquisses": "acquérir",
    "acquissiez": "acquérir",
    "acquissions": "acquérir",
    "acquit": "acquérir",
    "acquits": "acquit",
    "acquitta": "acquitter",
    "acquittai": "acquitter",
    "acquittaient": "acquitter",
    "acquittais": "acquitter",
    "acquittait": "acquitter",
    "acquittant": "acquitter",
    "acquittas": "acquitter",
    "acquittasse": "acquitter",
    "acquittassent": "acquitter",
    "acquittasses": "acquitter",
    "acquittassiez": "acquitter",
    "acquittassions": "acquitter",
    "acquitte": "acquitter",
    "acquittements": "acquittement",
    "acquittent": "acquitter",
    "acquittera": "acquitter",
    "acquitterai": "acquitter",
    "acquitteraient": "acquitter",
    "acquitterais": "acquitter",
    "acquitterait": "acquitter",
    "acquitteras": "acquitter",
    "acquitterez": "acquitter",
    "acquitteriez": "acquitter",
    "acquitterions": "acquitter",
    "acquitterons": "acquitter",
    "acquitteront": "acquitter",
    "acquittes": "acquitter",
    "acquittez": "acquitter",
    "acquittiez": "acquitter",
    "acquittions": "acquitter",
    "acquittons": "acquitter",
    "acquittâmes": "acquitter",
    "acquittât": "acquitter",
    "acquittâtes": "acquitter",
    "acquittèrent": "acquitter",
    "acquitté": "acquitter",
    "acquittée": "acquitter",
    "acquittées": "acquitter",
    "acquittés": "acquitter",
    "acquière": "acquérir",
    "acquièrent": "acquérir",
    "acquières": "acquérir",
    "acquéraient": "acquérir",
    "acquérais": "acquérir",
    "acquérait": "acquérir",
    "acquérant": "acquérir",
    "acquéreurs": "acquéreur",
    "acquérez": "acquérir",
    "acquériez": "acquérir",
    "acquérions": "acquérir",
    "acquérons": "acquérir",
    "acquêts": "acquêt",
    "acquîmes": "acquérir",
    "acquît": "acquérir",
    "acquîtes": "acquérir",
    "acres": "acre",
    "acrimonies": "acrimonie",
    "acrimonieuse": "acrimonieux",
    "acrimonieuses": "acrimonieux",
    "acrobates": "acrobate",
    "acrobaties": "acrobatie",
    "acrobatiques": "acrobatique",
    "acropoles": "acropole",
    "acrostiches": "acrostiche",
    "acryliques": "acrylique",
    "acta": "acter",
    "actes": "acte",
    "acteurs": "acteur",
    "actifs": "actif",
    "actinides": "actinide",
    "actinies": "actinie",
    "actionna": "actionner",
    "actionnai": "actionner",
    "actionnaient": "actionner",
    "actionnaires": "actionnaire",
    "actionnais": "actionner",
    "actionnait": "actionner",
    "actionnant": "actionner",
    "actionnariats": "actionnariat",
    "actionnas": "actionner",
    "actionnasse": "actionner",
    "actionnassent": "actionner",
    "actionnasses": "actionner",
    "actionnassiez": "actionner",
    "actionnassions": "actionner",
    "actionne": "actionner",
    "actionnent": "actionner",
    "actionnera": "actionner",
    "actionnerai": "actionner",
    "actionneraient": "actionner",
    "actionnerais": "actionner",
    "actionnerait": "actionner",
    "actionneras": "actionner",
    "actionnerez": "actionner",
    "actionneriez": "actionner",
    "actionnerions": "actionner",
    "actionnerons": "actionner",
    "actionneront": "actionner",
    "actionnes": "actionner",
    "actionneurs": "actionneur",
    "actionnez": "actionner",
    "actionniez": "actionner",
    "actionnions": "actionner",
    "actionnons": "actionner",
    "actionnâmes": "actionner",
    "actionnât": "actionner",
    "actionnâtes": "actionner",
    "actionnèrent": "actionner",
    "actionné": "actionner",
    "actionnée": "actionner",
    "actionnées": "actionner",
    "actionnés": "actionner",
    "actions": "action",
    "activa": "activer",
    "activai": "activer",
    "activaient": "activer",
    "activais": "activer",
    "activait": "activer",
    "activant": "activer",
    "activas": "activer",
    "activasse": "activer",
    "activassent": "activer",
    "activasses": "activer",
    "activassiez": "activer",
    "activassions": "activer",
    "activations": "activation",
    "active": "activer",
    "activent": "activer",
    "activera": "activer",
    "activerai": "activer",
    "activeraient": "activer",
    "activerais": "activer",
    "activerait": "activer",
    "activeras": "activer",
    "activerez": "activer",
    "activeriez": "activer",
    "activerions": "activer",
    "activerons": "activer",
    "activeront": "activer",
    "actives": "activer",
    "activez": "activer",
    "activiez": "activer",
    "activions": "activer",
    "activismes": "activisme",
    "activistes": "activiste",
    "activités": "activité",
    "activons": "activer",
    "activâmes": "activer",
    "activât": "activer",
    "activâtes": "activer",
    "activèrent": "activer",
    "activé": "activer",
    "activée": "activer",
    "activées": "activer",
    "activés": "activer",
    "actrice": "acteur",
    "actrices": "acteur",
    "actualisa": "actualiser",
    "actualisai": "actualiser",
    "actualisaient": "actualiser",
    "actualisais": "actualiser",
    "actualisait": "actualiser",
    "actualisant": "actualiser",
    "actualisas": "actualiser",
    "actualisasse": "actualiser",
    "actualisassent": "actualiser",
    "actualisasses": "actualiser",
    "actualisassiez": "actualiser",
    "actualisassions": "actualiser",
    "actualisations": "actualisation",
    "actualise": "actualiser",
    "actualisent": "actualiser",
    "actualisera": "actualiser",
    "actualiserai": "actualiser",
    "actualiseraient": "actualiser",
    "actualiserais": "actualiser",
    "actualiserait": "actualiser",
    "actualiseras": "actualiser",
    "actualiserez": "actualiser",
    "actualiseriez": "actualiser",
    "actualiserions": "actualiser",
    "actualiserons": "actualiser",
    "actualiseront": "actualiser",
    "actualises": "actualiser",
    "actualisez": "actualiser",
    "actualisiez": "actualiser",
    "actualisions": "actualiser",
    "actualisons": "actualiser",
    "actualisâmes": "actualiser",
    "actualisât": "actualiser",
    "actualisâtes": "actualiser",
    "actualisèrent": "actualiser",
    "actualisé": "actualiser",
    "actualisée": "actualiser",
    "actualisées": "actualiser",
    "actualisés": "actualiser",
    "actualités": "actualité",
    "actuarielle": "actuariel",
    "actuarielles": "actuariel",
    "actuariels": "actuariel",
    "actuelle": "actuel",
    "actuelles": "actuel",
    "actuels": "actuel",
    "acuités": "acuité",
    "acuponctures": "acuponcture",
    "acupunctures": "acupuncture",
    "acéphales": "acéphale",
    "acéré": "acérer",
    "acérée": "acéré",
    "acérées": "acérer",
    "acérés": "acérer",
    "acétals": "acétal",
    "acétylènes": "acétylène",
    "adages": "adage",
    "adagios": "adagio",
    "adamantine": "adamantin",
    "adapta": "adapter",
    "adaptabilités": "adaptabilité",
    "adaptables": "adaptable",
    "adaptai": "adapter",
    "adaptaient": "adapter",
    "adaptais": "adapter",
    "adaptait": "adapter",
    "adaptant": "adapter",
    "adaptas": "adapter",
    "adaptasse": "adapter",
    "adaptassent": "adapter",
    "adaptasses": "adapter",
    "adaptassiez": "adapter",
    "adaptassions": "adapter",
    "adaptateurs": "adaptateur",
    "adaptatifs": "adaptatif",
    "adaptations": "adaptation",
    "adapte": "adapter",
    "adaptent": "adapter",
    "adaptera": "adapter",
    "adapterai": "adapter",
    "adapteraient": "adapter",
    "adapterais": "adapter",
    "adapterait": "adapter",
    "adapteras": "adapter",
    "adapterez": "adapter",
    "adapteriez": "adapter",
    "adapterions": "adapter",
    "adapterons": "adapter",
    "adapteront": "adapter",
    "adaptes": "adapter",
    "adaptez": "adapter",
    "adaptiez": "adapter",
    "adaptions": "adapter",
    "adaptons": "adapter",
    "adaptâmes": "adapter",
    "adaptât": "adapter",
    "adaptâtes": "adapter",
    "adaptèrent": "adapter",
    "adapté": "adapter",
    "adaptée": "adapter",
    "adaptées": "adapter",
    "adaptés": "adapter",
    "addenda": "addendum",
    "additifs": "additif",
    "additionna": "additionner",
    "additionnai": "additionner",
    "additionnaient": "additionner",
    "additionnais": "additionner",
    "additionnait": "additionner",
    "additionnant": "additionner",
    "additionnas": "additionner",
    "additionnasse": "additionner",
    "additionnassent": "additionner",
    "additionnasses": "additionner",
    "additionnassiez": "additionner",
    "additionnassions": "additionner",
    "additionne": "additionner",
    "additionnelle": "additionnel",
    "additionnelles": "additionnel",
    "additionnels": "additionnel",
    "additionnent": "additionner",
    "additionnera": "additionner",
    "additionnerai": "additionner",
    "additionneraient": "additionner",
    "additionnerais": "additionner",
    "additionnerait": "additionner",
    "additionneras": "additionner",
    "additionnerez": "additionner",
    "additionneriez": "additionner",
    "additionnerions": "additionner",
    "additionnerons": "additionner",
    "additionneront": "additionner",
    "additionnes": "additionner",
    "additionnez": "additionner",
    "additionniez": "additionner",
    "additionnions": "additionner",
    "additionnons": "additionner",
    "additionnâmes": "additionner",
    "additionnât": "additionner",
    "additionnâtes": "additionner",
    "additionnèrent": "additionner",
    "additionné": "additionner",
    "additionnée": "additionner",
    "additionnées": "additionner",
    "additionnés": "additionner",
    "additions": "addition",
    "additives": "additif",
    "adducteurs": "adducteur",
    "adductions": "adduction",
    "adeptes": "adepte",
    "adhère": "adhérer",
    "adhèrent": "adhérer",
    "adhères": "adhérer",
    "adhéra": "adhérer",
    "adhérai": "adhérer",
    "adhéraient": "adhérer",
    "adhérais": "adhérer",
    "adhérait": "adhérer",
    "adhérant": "adhérer",
    "adhéras": "adhérer",
    "adhérasse": "adhérer",
    "adhérassent": "adhérer",
    "adhérasses": "adhérer",
    "adhérassiez": "adhérer",
    "adhérassions": "adhérer",
    "adhérences": "adhérence",
    "adhérente": "adhérent",
    "adhérentes": "adhérent",
    "adhérents": "adhérent",
    "adhérera": "adhérer",
    "adhérerai": "adhérer",
    "adhéreraient": "adhérer",
    "adhérerais": "adhérer",
    "adhérerait": "adhérer",
    "adhéreras": "adhérer",
    "adhérerez": "adhérer",
    "adhéreriez": "adhérer",
    "adhérerions": "adhérer",
    "adhérerons": "adhérer",
    "adhéreront": "adhérer",
    "adhérez": "adhérer",
    "adhériez": "adhérer",
    "adhérions": "adhérer",
    "adhérons": "adhérer",
    "adhérâmes": "adhérer",
    "adhérât": "adhérer",
    "adhérâtes": "adhérer",
    "adhérèrent": "adhérer",
    "adhéré": "adhérer",
    "adhérée": "adhérer",
    "adhérées": "adhérer",
    "adhérés": "adhérer",
    "adhésifs": "adhésif",
    "adhésions": "adhésion",
    "adhésive": "adhésif",
    "adhésives": "adhésif",
    "adieux": "adieu",
    "adipeuse": "adipeux",
    "adipeuses": "adipeux",
    "adira": "adire",
    "adjacente": "adjacent",
    "adjacentes": "adjacent",
    "adjacents": "adjacent",
    "adjas": "adja",
    "adjectifs": "adjectif",
    "adjectivale": "adjectival",
    "adjectivales": "adjectival",
    "adjectivaux": "adjectival",
    "adjective": "adjectif",
    "adjectives": "adjectif",
    "adjoignaient": "adjoindre",
    "adjoignais": "adjoindre",
    "adjoignait": "adjoindre",
    "adjoignant": "adjoindre",
    "adjoigne": "adjoindre",
    "adjoignent": "adjoindre",
    "adjoignes": "adjoindre",
    "adjoignez": "adjoindre",
    "adjoigniez": "adjoindre",
    "adjoignions": "adjoindre",
    "adjoignirent": "adjoindre",
    "adjoignis": "adjoindre",
    "adjoignisse": "adjoindre",
    "adjoignissent": "adjoindre",
    "adjoignisses": "adjoindre",
    "adjoignissiez": "adjoindre",
    "adjoignissions": "adjoindre",
    "adjoignit": "adjoindre",
    "adjoignons": "adjoindre",
    "adjoignîmes": "adjoindre",
    "adjoignît": "adjoindre",
    "adjoignîtes": "adjoindre",
    "adjoindra": "adjoindre",
    "adjoindrai": "adjoindre",
    "adjoindraient": "adjoindre",
    "adjoindrais": "adjoindre",
    "adjoindrait": "adjoindre",
    "adjoindras": "adjoindre",
    "adjoindrez": "adjoindre",
    "adjoindriez": "adjoindre",
    "adjoindrions": "adjoindre",
    "adjoindrons": "adjoindre",
    "adjoindront": "adjoindre",
    "adjoins": "adjoindre",
    "adjoint": "adjoindre",
    "adjointe": "adjoint",
    "adjointes": "adjoint",
    "adjoints": "adjoint",
    "adjonctions": "adjonction",
    "adjudants": "adjudant",
    "adjudants-chefs": "adjudant-chef",
    "adjudicataires": "adjudicataire",
    "adjudicateurs": "adjudicateur",
    "adjudications": "adjudication",
    "adjudicatrice": "adjudicateur",
    "adjudicatrices": "adjudicateur",
    "adjuge": "adjuger",
    "adjugea": "adjuger",
    "adjugeai": "adjuger",
    "adjugeaient": "adjuger",
    "adjugeais": "adjuger",
    "adjugeait": "adjuger",
    "adjugeant": "adjuger",
    "adjugeas": "adjuger",
    "adjugeasse": "adjuger",
    "adjugeassent": "adjuger",
    "adjugeasses": "adjuger",
    "adjugeassiez": "adjuger",
    "adjugeassions": "adjuger",
    "adjugent": "adjuger",
    "adjugeons": "adjuger",
    "adjugera": "adjuger",
    "adjugerai": "adjuger",
    "adjugeraient": "adjuger",
    "adjugerais": "adjuger",
    "adjugerait": "adjuger",
    "adjugeras": "adjuger",
    "adjugerez": "adjuger",
    "adjugeriez": "adjuger",
    "adjugerions": "adjuger",
    "adjugerons": "adjuger",
    "adjugeront": "adjuger",
    "adjuges": "adjuger",
    "adjugez": "adjuger",
    "adjugeâmes": "adjuger",
    "adjugeât": "adjuger",
    "adjugeâtes": "adjuger",
    "adjugiez": "adjuger",
    "adjugions": "adjuger",
    "adjugèrent": "adjuger",
    "adjugé": "adjuger",
    "adjugée": "adjuger",
    "adjugées": "adjuger",
    "adjugés": "adjuger",
    "adjupètes": "adjupète",
    "adjura": "adjurer",
    "adjurai": "adjurer",
    "adjuraient": "adjurer",
    "adjurais": "adjurer",
    "adjurait": "adjurer",
    "adjurant": "adjurer",
    "adjuras": "adjurer",
    "adjurasse": "adjurer",
    "adjurassent": "adjurer",
    "adjurasses": "adjurer",
    "adjurassiez": "adjurer",
    "adjurassions": "adjurer",
    "adjurations": "adjuration",
    "adjure": "adjurer",
    "adjurent": "adjurer",
    "adjurera": "adjurer",
    "adjurerai": "adjurer",
    "adjureraient": "adjurer",
    "adjurerais": "adjurer",
    "adjurerait": "adjurer",
    "adjureras": "adjurer",
    "adjurerez": "adjurer",
    "adjureriez": "adjurer",
    "adjurerions": "adjurer",
    "adjurerons": "adjurer",
    "adjureront": "adjurer",
    "adjures": "adjurer",
    "adjurez": "adjurer",
    "adjuriez": "adjurer",
    "adjurions": "adjurer",
    "adjurons": "adjurer",
    "adjurâmes": "adjurer",
    "adjurât": "adjurer",
    "adjurâtes": "adjurer",
    "adjurèrent": "adjurer",
    "adjuré": "adjurer",
    "adjurée": "adjurer",
    "adjurées": "adjurer",
    "adjurés": "adjurer",
    "adjuvants": "adjuvant",
    "admet": "admettre",
    "admets": "admettre",
    "admettaient": "admettre",
    "admettais": "admettre",
    "admettait": "admettre",
    "admettant": "admettre",
    "admette": "admettre",
    "admettent": "admettre",
    "admettes": "admettre",
    "admettez": "admettre",
    "admettiez": "admettre",
    "admettions": "admettre",
    "admettons": "admettre",
    "admettra": "admettre",
    "admettrai": "admettre",
    "admettraient": "admettre",
    "admettrais": "admettre",
    "admettrait": "admettre",
    "admettras": "admettre",
    "admettrez": "admettre",
    "admettriez": "admettre",
    "admettrions": "admettre",
    "admettrons": "admettre",
    "admettront": "admettre",
    "administra": "administrer",
    "administrai": "administrer",
    "administraient": "administrer",
    "administrais": "administrer",
    "administrait": "administrer",
    "administrant": "administrer",
    "administras": "administrer",
    "administrasse": "administrer",
    "administrassent": "administrer",
    "administrasses": "administrer",
    "administrassiez": "administrer",
    "administrassions": "administrer",
    "administrateurs": "administrateur",
    "administratifs": "administratif",
    "administrations": "administration",
    "administrative": "administratif",
    "administratives": "administratif",
    "administratrice": "administrateur",
    "administratrices": "administrateur",
    "administre": "administrer",
    "administrent": "administrer",
    "administrera": "administrer",
    "administrerai": "administrer",
    "administreraient": "administrer",
    "administrerais": "administrer",
    "administrerait": "administrer",
    "administreras": "administrer",
    "administrerez": "administrer",
    "administreriez": "administrer",
    "administrerions": "administrer",
    "administrerons": "administrer",
    "administreront": "administrer",
    "administres": "administrer",
    "administrez": "administrer",
    "administriez": "administrer",
    "administrions": "administrer",
    "administrons": "administrer",
    "administrâmes": "administrer",
    "administrât": "administrer",
    "administrâtes": "administrer",
    "administrèrent": "administrer",
    "administré": "administrer",
    "administrée": "administrer",
    "administrées": "administrer",
    "administrés": "administrer",
    "admira": "admirer",
    "admirables": "admirable",
    "admirai": "admirer",
    "admiraient": "admirer",
    "admirais": "admirer",
    "admirait": "admirer",
    "admirant": "admirer",
    "admiras": "admirer",
    "admirasse": "admirer",
    "admirassent": "admirer",
    "admirasses": "admirer",
    "admirassiez": "admirer",
    "admirassions": "admirer",
    "admirateurs": "admirateur",
    "admiratifs": "admiratif",
    "admirations": "admiration",
    "admirative": "admiratif",
    "admiratives": "admiratif",
    "admiratrice": "admirateur",
    "admiratrices": "admirateur",
    "admire": "admirer",
    "admirent": "admirer",
    "admirera": "admirer",
    "admirerai": "admirer",
    "admireraient": "admirer",
    "admirerais": "admirer",
    "admirerait": "admirer",
    "admireras": "admirer",
    "admirerez": "admirer",
    "admireriez": "admirer",
    "admirerions": "admirer",
    "admirerons": "admirer",
    "admireront": "admirer",
    "admires": "admirer",
    "admirez": "admirer",
    "admiriez": "admirer",
    "admirions": "admirer",
    "admirons": "admirer",
    "admirâmes": "admirer",
    "admirât": "admirer",
    "admirâtes": "admirer",
    "admirèrent": "admirer",
    "admiré": "admirer",
    "admirée": "admirer",
    "admirées": "admirer",
    "admirés": "admirer",
    "admis": "admettre",
    "admise": "admis",
    "admises": "admis",
    "admisse": "admettre",
    "admissent": "admettre",
    "admisses": "admettre",
    "admissibles": "admissible",
    "admissiez": "admettre",
    "admissions": "admission",
    "admit": "admettre",
    "admonesta": "admonester",
    "admonestai": "admonester",
    "admonestaient": "admonester",
    "admonestais": "admonester",
    "admonestait": "admonester",
    "admonestant": "admonester",
    "admonestas": "admonester",
    "admonestasse": "admonester",
    "admonestassent": "admonester",
    "admonestasses": "admonester",
    "admonestassiez": "admonester",
    "admonestassions": "admonester",
    "admonestations": "admonestation",
    "admoneste": "admonester",
    "admonestent": "admonester",
    "admonestera": "admonester",
    "admonesterai": "admonester",
    "admonesteraient": "admonester",
    "admonesterais": "admonester",
    "admonesterait": "admonester",
    "admonesteras": "admonester",
    "admonesterez": "admonester",
    "admonesteriez": "admonester",
    "admonesterions": "admonester",
    "admonesterons": "admonester",
    "admonesteront": "admonester",
    "admonestes": "admonester",
    "admonestez": "admonester",
    "admonestiez": "admonester",
    "admonestions": "admonester",
    "admonestons": "admonester",
    "admonestâmes": "admonester",
    "admonestât": "admonester",
    "admonestâtes": "admonester",
    "admonestèrent": "admonester",
    "admonesté": "admonester",
    "admonestée": "admonester",
    "admonestées": "admonester",
    "admonestés": "admonester",
    "admonitions": "admonition",
    "admîmes": "admettre",
    "admît": "admettre",
    "admîtes": "admettre",
    "adolescences": "adolescence",
    "adolescente": "adolescent",
    "adolescentes": "adolescent",
    "adolescents": "adolescent",
    "adonisant": "adoniser",
    "adonna": "adonner",
    "adonnai": "adonner",
    "adonnaient": "adonner",
    "adonnais": "adonner",
    "adonnait": "adonner",
    "adonnant": "adonner",
    "adonnas": "adonner",
    "adonnasse": "adonner",
    "adonnassent": "adonner",
    "adonnasses": "adonner",
    "adonnassiez": "adonner",
    "adonnassions": "adonner",
    "adonne": "adonner",
    "adonnent": "adonner",
    "adonnera": "adonner",
    "adonnerai": "adonner",
    "adonneraient": "adonner",
    "adonnerais": "adonner",
    "adonnerait": "adonner",
    "adonneras": "adonner",
    "adonnerez": "adonner",
    "adonneriez": "adonner",
    "adonnerions": "adonner",
    "adonnerons": "adonner",
    "adonneront": "adonner",
    "adonnes": "adonner",
    "adonnez": "adonner",
    "adonniez": "adonner",
    "adonnions": "adonner",
    "adonnons": "adonner",
    "adonnâmes": "adonner",
    "adonnât": "adonner",
    "adonnâtes": "adonner",
    "adonnèrent": "adonner",
    "adonné": "adonner",
    "adonnée": "adonner",
    "adonnées": "adonner",
    "adonnés": "adonner",
    "adopta": "adopter",
    "adoptables": "adoptable",
    "adoptai": "adopter",
    "adoptaient": "adopter",
    "adoptais": "adopter",
    "adoptait": "adopter",
    "adoptant": "adopter",
    "adoptas": "adopter",
    "adoptasse": "adopter",
    "adoptassent": "adopter",
    "adoptasses": "adopter",
    "adoptassiez": "adopter",
    "adoptassions": "adopter",
    "adopte": "adopter",
    "adoptent": "adopter",
    "adoptera": "adopter",
    "adopterai": "adopter",
    "adopteraient": "adopter",
    "adopterais": "adopter",
    "adopterait": "adopter",
    "adopteras": "adopter",
    "adopterez": "adopter",
    "adopteriez": "adopter",
    "adopterions": "adopter",
    "adopterons": "adopter",
    "adopteront": "adopter",
    "adoptes": "adopter",
    "adoptez": "adopter",
    "adoptiez": "adopter",
    "adoptifs": "adoptif",
    "adoptions": "adoption",
    "adoptive": "adoptif",
    "adoptives": "adoptif",
    "adoptons": "adopter",
    "adoptâmes": "adopter",
    "adoptât": "adopter",
    "adoptâtes": "adopter",
    "adoptèrent": "adopter",
    "adopté": "adopter",
    "adoptée": "adopter",
    "adoptées": "adopter",
    "adoptés": "adopter",
    "adora": "adorer",
    "adorables": "adorable",
    "adorai": "adorer",
    "adoraient": "adorer",
    "adorais": "adorer",
    "adorait": "adorer",
    "adorant": "adorer",
    "adorante": "adorant",
    "adorants": "adorant",
    "adoras": "adorer",
    "adorasse": "adorer",
    "adorassent": "adorer",
    "adorasses": "adorer",
    "adorassiez": "adorer",
    "adorassions": "adorer",
    "adorateurs": "adorateur",
    "adorations": "adoration",
    "adoratrice": "adorateur",
    "adoratrices": "adorateur",
    "adore": "adorer",
    "adorent": "adorer",
    "adorera": "adorer",
    "adorerai": "adorer",
    "adoreraient": "adorer",
    "adorerais": "adorer",
    "adorerait": "adorer",
    "adoreras": "adorer",
    "adorerez": "adorer",
    "adoreriez": "adorer",
    "adorerions": "adorer",
    "adorerons": "adorer",
    "adoreront": "adorer",
    "adores": "adorer",
    "adorez": "adorer",
    "adoriez": "adorer",
    "adorions": "adorer",
    "adornaient": "adorner",
    "adornait": "adorner",
    "adorne": "adorner",
    "adorné": "adorner",
    "adorons": "adorer",
    "adorâmes": "adorer",
    "adorât": "adorer",
    "adorâtes": "adorer",
    "adorèrent": "adorer",
    "adoré": "adorer",
    "adorée": "adorer",
    "adorées": "adorer",
    "adorés": "adorer",
    "adossa": "adosser",
    "adossai": "adosser",
    "adossaient": "adosser",
    "adossais": "adosser",
    "adossait": "adosser",
    "adossant": "adosser",
    "adossas": "adosser",
    "adossasse": "adosser",
    "adossassent": "adosser",
    "adossasses": "adosser",
    "adossassiez": "adosser",
    "adossassions": "adosser",
    "adosse": "adosser",
    "adossent": "adosser",
    "adossera": "adosser",
    "adosserai": "adosser",
    "adosseraient": "adosser",
    "adosserais": "adosser",
    "adosserait": "adosser",
    "adosseras": "adosser",
    "adosserez": "adosser",
    "adosseriez": "adosser",
    "adosserions": "adosser",
    "adosserons": "adosser",
    "adosseront": "adosser",
    "adosses": "adosser",
    "adossez": "adosser",
    "adossiez": "adosser",
    "adossions": "adosser",
    "adossons": "adosser",
    "adossâmes": "adosser",
    "adossât": "adosser",
    "adossâtes": "adosser",
    "adossèrent": "adosser",
    "adossé": "adosser",
    "adossée": "adosser",
    "adossées": "adosser",
    "adossés": "adosser",
    "adouba": "adouber",
    "adoubai": "adouber",
    "adoubaient": "adouber",
    "adoubais": "adouber",
    "adoubait": "adouber",
    "adoubant": "adouber",
    "adoubas": "adouber",
    "adoubasse": "adouber",
    "adoubassent": "adouber",
    "adoubasses": "adouber",
    "adoubassiez": "adouber",
    "adoubassions": "adouber",
    "adoube": "adouber",
    "adoubent": "adouber",
    "adoubera": "adouber",
    "adouberai": "adouber",
    "adouberaient": "adouber",
    "adouberais": "adouber",
    "adouberait": "adouber",
    "adouberas": "adouber",
    "adouberez": "adouber",
    "adouberiez": "adouber",
    "adouberions": "adouber",
    "adouberons": "adouber",
    "adouberont": "adouber",
    "adoubes": "adouber",
    "adoubez": "adouber",
    "adoubiez": "adouber",
    "adoubions": "adouber",
    "adoubons": "adouber",
    "adoubâmes": "adouber",
    "adoubât": "adouber",
    "adoubâtes": "adouber",
    "adoubèrent": "adouber",
    "adoubé": "adouber",
    "adoubée": "adouber",
    "adoubées": "adouber",
    "adoubés": "adouber",
    "adouci": "adoucir",
    "adoucie": "adoucir",
    "adoucies": "adoucir",
    "adoucira": "adoucir",
    "adoucirai": "adoucir",
    "adouciraient": "adoucir",
    "adoucirais": "adoucir",
    "adoucirait": "adoucir",
    "adouciras": "adoucir",
    "adoucirent": "adoucir",
    "adoucirez": "adoucir",
    "adouciriez": "adoucir",
    "adoucirions": "adoucir",
    "adoucirons": "adoucir",
    "adouciront": "adoucir",
    "adoucis": "adoucir",
    "adoucissaient": "adoucir",
    "adoucissais": "adoucir",
    "adoucissait": "adoucir",
    "adoucissant": "adoucir",
    "adoucissante": "adoucissant",
    "adoucissantes": "adoucissant",
    "adoucissants": "adoucissant",
    "adoucisse": "adoucir",
    "adoucissements": "adoucissement",
    "adoucissent": "adoucir",
    "adoucisses": "adoucir",
    "adoucisseurs": "adoucisseur",
    "adoucissez": "adoucir",
    "adoucissiez": "adoucir",
    "adoucissions": "adoucir",
    "adoucissons": "adoucir",
    "adoucit": "adoucir",
    "adoucîmes": "adoucir",
    "adoucît": "adoucir",
    "adoucîtes": "adoucir",
    "adragante": "adragant",
    "adragantes": "adragante",
    "adressa": "adresser",
    "adressai": "adresser",
    "adressaient": "adresser",
    "adressais": "adresser",
    "adressait": "adresser",
    "adressant": "adresser",
    "adressas": "adresser",
    "adressasse": "adresser",
    "adressassent": "adresser",
    "adressasses": "adresser",
    "adressassiez": "adresser",
    "adressassions": "adresser",
    "adresse": "adresser",
    "adressent": "adresser",
    "adressera": "adresser",
    "adresserai": "adresser",
    "adresseraient": "adresser",
    "adresserais": "adresser",
    "adresserait": "adresser",
    "adresseras": "adresser",
    "adresserez": "adresser",
    "adresseriez": "adresser",
    "adresserions": "adresser",
    "adresserons": "adresser",
    "adresseront": "adresser",
    "adresses": "adresser",
    "adressez": "adresser",
    "adressiez": "adresser",
    "adressions": "adresser",
    "adressons": "adresser",
    "adressâmes": "adresser",
    "adressât": "adresser",
    "adressâtes": "adresser",
    "adressèrent": "adresser",
    "adressé": "adresser",
    "adressée": "adresser",
    "adressées": "adresser",
    "adressés": "adresser",
    "adriatiques": "adriatique",
    "adroite": "adroit",
    "adroites": "adroit",
    "adroits": "adroit",
    "adrénalines": "adrénaline",
    "adula": "aduler",
    "adulai": "aduler",
    "adulaient": "aduler",
    "adulais": "aduler",
    "adulait": "aduler",
    "adulant": "aduler",
    "adulas": "aduler",
    "adulasse": "aduler",
    "adulassent": "aduler",
    "adulasses": "aduler",
    "adulassiez": "aduler",
    "adulassions": "aduler",
    "adulations": "adulation",
    "adule": "aduler",
    "adulent": "aduler",
    "adulera": "aduler",
    "adulerai": "aduler",
    "aduleraient": "aduler",
    "adulerais": "aduler",
    "adulerait": "aduler",
    "aduleras": "aduler",
    "adulerez": "aduler",
    "aduleriez": "aduler",
    "adulerions": "aduler",
    "adulerons": "aduler",
    "aduleront": "aduler",
    "adules": "aduler",
    "adulez": "aduler",
    "aduliez": "aduler",
    "adulions": "aduler",
    "adulons": "aduler",
    "adultes": "adulte",
    "adultères": "adultère",
    "adultéraient": "adultérer",
    "adultérine": "adultérin",
    "adultérines": "adultérin",
    "adultérins": "adultérin",
    "adultéré": "adultérer",
    "adultérées": "adultérer",
    "adulâmes": "aduler",
    "adulât": "aduler",
    "adulâtes": "aduler",
    "adulèrent": "aduler",
    "adulé": "aduler",
    "adulée": "aduler",
    "adulées": "aduler",
    "adulés": "aduler",
    "advenaient": "advenir",
    "advenait": "advenir",
    "advenant": "advenir",
    "adventices": "adventice",
    "advenu": "advenir",
    "advenue": "advenu",
    "advenues": "advenir",
    "advenus": "advenir",
    "adverbes": "adverbe",
    "adverbiale": "adverbial",
    "adverbiales": "adverbial",
    "adverbiaux": "adverbial",
    "adversaires": "adversaire",
    "adverses": "adverse",
    "adversités": "adversité",
    "adviendra": "advenir",
    "adviendraient": "advenir",
    "adviendrait": "advenir",
    "adviendront": "advenir",
    "advienne": "advenir",
    "adviennent": "advenir",
    "advient": "advenir",
    "advinrent": "advenir",
    "advinssent": "advenir",
    "advint": "advenir",
    "advînt": "advenir",
    "adéquate": "adéquat",
    "adéquates": "adéquat",
    "adéquations": "adéquation",
    "adéquats": "adéquat",
    "aegipans": "aegipan",
    "affabilités": "affabilité",
    "affables": "affable",
    "affabula": "affabuler",
    "affabulai": "affabuler",
    "affabulaient": "affabuler",
    "affabulais": "affabuler",
    "affabulait": "affabuler",
    "affabulant": "affabuler",
    "affabulas": "affabuler",
    "affabulasse": "affabuler",
    "affabulassent": "affabuler",
    "affabulasses": "affabuler",
    "affabulassiez": "affabuler",
    "affabulassions": "affabuler",
    "affabulations": "affabulation",
    "affabulatrice": "affabulateur",
    "affabule": "affabuler",
    "affabulent": "affabuler",
    "affabulera": "affabuler",
    "affabulerai": "affabuler",
    "affabuleraient": "affabuler",
    "affabulerais": "affabuler",
    "affabulerait": "affabuler",
    "affabuleras": "affabuler",
    "affabulerez": "affabuler",
    "affabuleriez": "affabuler",
    "affabulerions": "affabuler",
    "affabulerons": "affabuler",
    "affabuleront": "affabuler",
    "affabules": "affabuler",
    "affabulez": "affabuler",
    "affabuliez": "affabuler",
    "affabulions": "affabuler",
    "affabulons": "affabuler",
    "affabulâmes": "affabuler",
    "affabulât": "affabuler",
    "affabulâtes": "affabuler",
    "affabulèrent": "affabuler",
    "affabulé": "affabuler",
    "affabulée": "affabuler",
    "affabulées": "affabuler",
    "affabulés": "affabuler",
    "affadi": "affadir",
    "affadie": "affadir",
    "affadies": "affadir",
    "affadira": "affadir",
    "affadirai": "affadir",
    "affadiraient": "affadir",
    "affadirais": "affadir",
    "affadirait": "affadir",
    "affadiras": "affadir",
    "affadirent": "affadir",
    "affadirez": "affadir",
    "affadiriez": "affadir",
    "affadirions": "affadir",
    "affadirons": "affadir",
    "affadiront": "affadir",
    "affadis": "affadir",
    "affadissaient": "affadir",
    "affadissais": "affadir",
    "affadissait": "affadir",
    "affadissant": "affadir",
    "affadisse": "affadir",
    "affadissent": "affadir",
    "affadisses": "affadir",
    "affadissez": "affadir",
    "affadissiez": "affadir",
    "affadissions": "affadir",
    "affadissons": "affadir",
    "affadit": "affadir",
    "affadîmes": "affadir",
    "affadît": "affadir",
    "affadîtes": "affadir",
    "affaibli": "affaiblir",
    "affaiblie": "affaiblir",
    "affaiblies": "affaiblir",
    "affaiblira": "affaiblir",
    "affaiblirai": "affaiblir",
    "affaibliraient": "affaiblir",
    "affaiblirais": "affaiblir",
    "affaiblirait": "affaiblir",
    "affaibliras": "affaiblir",
    "affaiblirent": "affaiblir",
    "affaiblirez": "affaiblir",
    "affaibliriez": "affaiblir",
    "affaiblirions": "affaiblir",
    "affaiblirons": "affaiblir",
    "affaibliront": "affaiblir",
    "affaiblis": "affaiblir",
    "affaiblissaient": "affaiblir",
    "affaiblissais": "affaiblir",
    "affaiblissait": "affaiblir",
    "affaiblissant": "affaiblir",
    "affaiblisse": "affaiblir",
    "affaiblissements": "affaiblissement",
    "affaiblissent": "affaiblir",
    "affaiblisses": "affaiblir",
    "affaiblissez": "affaiblir",
    "affaiblissiez": "affaiblir",
    "affaiblissions": "affaiblir",
    "affaiblissons": "affaiblir",
    "affaiblit": "affaiblir",
    "affaiblîmes": "affaiblir",
    "affaiblît": "affaiblir",
    "affaiblîtes": "affaiblir",
    "affaira": "affairer",
    "affairai": "affairer",
    "affairaient": "affairer",
    "affairais": "affairer",
    "affairait": "affairer",
    "affairant": "affairer",
    "affairas": "affairer",
    "affairasse": "affairer",
    "affairassent": "affairer",
    "affairasses": "affairer",
    "affairassiez": "affairer",
    "affairassions": "affairer",
    "affaire": "affairer",
    "affairements": "affairement",
    "affairent": "affairer",
    "affairera": "affairer",
    "affairerai": "affairer",
    "affaireraient": "affairer",
    "affairerais": "affairer",
    "affairerait": "affairer",
    "affaireras": "affairer",
    "affairerez": "affairer",
    "affaireriez": "affairer",
    "affairerions": "affairer",
    "affairerons": "affairer",
    "affaireront": "affairer",
    "affaires": "affairer",
    "affairez": "affairer",
    "affairiez": "affairer",
    "affairions": "affairer",
    "affairismes": "affairisme",
    "affairistes": "affairiste",
    "affairons": "affairer",
    "affairâmes": "affairer",
    "affairât": "affairer",
    "affairâtes": "affairer",
    "affairèrent": "affairer",
    "affairé": "affairer",
    "affairée": "affairer",
    "affairées": "affairer",
    "affairés": "affairer",
    "affaissa": "affaisser",
    "affaissai": "affaisser",
    "affaissaient": "affaisser",
    "affaissais": "affaisser",
    "affaissait": "affaisser",
    "affaissant": "affaisser",
    "affaissas": "affaisser",
    "affaissasse": "affaisser",
    "affaissassent": "affaisser",
    "affaissasses": "affaisser",
    "affaissassiez": "affaisser",
    "affaissassions": "affaisser",
    "affaisse": "affaisser",
    "affaissements": "affaissement",
    "affaissent": "affaisser",
    "affaissera": "affaisser",
    "affaisserai": "affaisser",
    "affaisseraient": "affaisser",
    "affaisserais": "affaisser",
    "affaisserait": "affaisser",
    "affaisseras": "affaisser",
    "affaisserez": "affaisser",
    "affaisseriez": "affaisser",
    "affaisserions": "affaisser",
    "affaisserons": "affaisser",
    "affaisseront": "affaisser",
    "affaisses": "affaisser",
    "affaissez": "affaisser",
    "affaissiez": "affaisser",
    "affaissions": "affaisser",
    "affaissons": "affaisser",
    "affaissâmes": "affaisser",
    "affaissât": "affaisser",
    "affaissâtes": "affaisser",
    "affaissèrent": "affaisser",
    "affaissé": "affaisser",
    "affaissée": "affaisser",
    "affaissées": "affaisser",
    "affaissés": "affaisser",
    "affala": "affaler",
    "affalai": "affaler",
    "affalaient": "affaler",
    "affalais": "affaler",
    "affalait": "affaler",
    "affalant": "affaler",
    "affalas": "affaler",
    "affalasse": "affaler",
    "affalassent": "affaler",
    "affalasses": "affaler",
    "affalassiez": "affaler",
    "affalassions": "affaler",
    "affale": "affaler",
    "affalements": "affalement",
    "affalent": "affaler",
    "affalera": "affaler",
    "affalerai": "affaler",
    "affaleraient": "affaler",
    "affalerais": "affaler",
    "affalerait": "affaler",
    "affaleras": "affaler",
    "affalerez": "affaler",
    "affaleriez": "affaler",
    "affalerions": "affaler",
    "affalerons": "affaler",
    "affaleront": "affaler",
    "affales": "affaler",
    "affalez": "affaler",
    "affaliez": "affaler",
    "affalions": "affaler",
    "affalons": "affaler",
    "affalâmes": "affaler",
    "affalât": "affaler",
    "affalâtes": "affaler",
    "affalèrent": "affaler",
    "affalé": "affaler",
    "affalée": "affaler",
    "affalées": "affaler",
    "affalés": "affaler",
    "affama": "affamer",
    "affamai": "affamer",
    "affamaient": "affamer",
    "affamais": "affamer",
    "affamait": "affamer",
    "affamant": "affamer",
    "affamantes": "affamant",
    "affamas": "affamer",
    "affamasse": "affamer",
    "affamassent": "affamer",
    "affamasses": "affamer",
    "affamassiez": "affamer",
    "affamassions": "affamer",
    "affame": "affamer",
    "affament": "affamer",
    "affamera": "affamer",
    "affamerai": "affamer",
    "affameraient": "affamer",
    "affamerais": "affamer",
    "affamerait": "affamer",
    "affameras": "affamer",
    "affamerez": "affamer",
    "affameriez": "affamer",
    "affamerions": "affamer",
    "affamerons": "affamer",
    "affameront": "affamer",
    "affames": "affamer",
    "affamez": "affamer",
    "affamiez": "affamer",
    "affamions": "affamer",
    "affamons": "affamer",
    "affamâmes": "affamer",
    "affamât": "affamer",
    "affamâtes": "affamer",
    "affamèrent": "affamer",
    "affamé": "affamer",
    "affamée": "affamer",
    "affamées": "affamer",
    "affamés": "affamer",
    "affecta": "affecter",
    "affectai": "affecter",
    "affectaient": "affecter",
    "affectais": "affecter",
    "affectait": "affecter",
    "affectant": "affecter",
    "affectas": "affecter",
    "affectasse": "affecter",
    "affectassent": "affecter",
    "affectasses": "affecter",
    "affectassiez": "affecter",
    "affectassions": "affecter",
    "affectations": "affectation",
    "affecte": "affecter",
    "affectent": "affecter",
    "affecter": "avoir",
    "affectera": "affecter",
    "affecterai": "affecter",
    "affecteraient": "affecter",
    "affecterais": "affecter",
    "affecterait": "affecter",
    "affecteras": "affecter",
    "affecterez": "affecter",
    "affecteriez": "affecter",
    "affecterions": "affecter",
    "affecterons": "affecter",
    "affecteront": "affecter",
    "affectes": "affecter",
    "affectez": "affecter",
    "affectiez": "affecter",
    "affectifs": "affectif",
    "affectionna": "affectionner",
    "affectionnai": "affectionner",
    "affectionnaient": "affectionner",
    "affectionnais": "affectionner",
    "affectionnait": "affectionner",
    "affectionnant": "affectionner",
    "affectionnas": "affectionner",
    "affectionnasse": "affectionner",
    "affectionnassent": "affectionner",
    "affectionnasses": "affectionner",
    "affectionnassiez": "affectionner",
    "affectionnassions": "affectionner",
    "affectionne": "affectionner",
    "affectionnent": "affectionner",
    "affectionnera": "affectionner",
    "affectionnerai": "affectionner",
    "affectionneraient": "affectionner",
    "affectionnerais": "affectionner",
    "affectionnerait": "affectionner",
    "affectionneras": "affectionner",
    "affectionnerez": "affectionner",
    "affectionneriez": "affectionner",
    "affectionnerions": "affectionner",
    "affectionnerons": "affectionner",
    "affectionneront": "affectionner",
    "affectionnes": "affectionner",
    "affectionnez": "affectionner",
    "affectionniez": "affectionner",
    "affectionnions": "affectionner",
    "affectionnons": "affectionner",
    "affectionnâmes": "affectionner",
    "affectionnât": "affectionner",
    "affectionnâtes": "affectionner",
    "affectionnèrent": "affectionner",
    "affectionné": "affectionner",
    "affectionnée": "affectionner",
    "affectionnées": "affectionner",
    "affectionnés": "affectionner",
    "affections": "affection",
    "affective": "affectif",
    "affectives": "affectif",
    "affectivités": "affectivité",
    "affectons": "affecter",
    "affects": "affect",
    "affectueuse": "affectueux",
    "affectueuses": "affectueux",
    "affectâmes": "affecter",
    "affectât": "affecter",
    "affectâtes": "affecter",
    "affectèrent": "affecter",
    "affecté": "affecter",
    "affectée": "affecter",
    "affectées": "affecter",
    "affectés": "affecter",
    "afferma": "affermer",
    "affermai": "affermer",
    "affermaient": "affermer",
    "affermais": "affermer",
    "affermait": "affermer",
    "affermant": "affermer",
    "affermas": "affermer",
    "affermasse": "affermer",
    "affermassent": "affermer",
    "affermasses": "affermer",
    "affermassiez": "affermer",
    "affermassions": "affermer",
    "afferme": "affermer",
    "afferment": "affermer",
    "affermera": "affermer",
    "affermerai": "affermer",
    "affermeraient": "affermer",
    "affermerais": "affermer",
    "affermerait": "affermer",
    "affermeras": "affermer",
    "affermerez": "affermer",
    "affermeriez": "affermer",
    "affermerions": "affermer",
    "affermerons": "affermer",
    "affermeront": "affermer",
    "affermes": "affermer",
    "affermez": "affermer",
    "affermi": "affermir",
    "affermie": "affermir",
    "affermies": "affermir",
    "affermiez": "affermer",
    "affermions": "affermer",
    "affermira": "affermir",
    "affermirai": "affermir",
    "affermiraient": "affermir",
    "affermirais": "affermir",
    "affermirait": "affermir",
    "affermiras": "affermir",
    "affermirent": "affermir",
    "affermirez": "affermir",
    "affermiriez": "affermir",
    "affermirions": "affermir",
    "affermirons": "affermir",
    "affermiront": "affermir",
    "affermis": "affermir",
    "affermissaient": "affermir",
    "affermissais": "affermir",
    "affermissait": "affermir",
    "affermissant": "affermir",
    "affermisse": "affermir",
    "affermissent": "affermir",
    "affermisses": "affermir",
    "affermissez": "affermir",
    "affermissiez": "affermir",
    "affermissions": "affermir",
    "affermissons": "affermir",
    "affermit": "affermir",
    "affermons": "affermer",
    "affermâmes": "affermer",
    "affermât": "affermer",
    "affermâtes": "affermer",
    "affermèrent": "affermer",
    "affermé": "affermer",
    "affermée": "affermer",
    "affermées": "affermer",
    "affermés": "affermer",
    "affermîmes": "affermir",
    "affermît": "affermir",
    "affermîtes": "affermir",
    "afficha": "afficher",
    "affichages": "affichage",
    "affichai": "afficher",
    "affichaient": "afficher",
    "affichais": "afficher",
    "affichait": "afficher",
    "affichant": "afficher",
    "affichas": "afficher",
    "affichasse": "afficher",
    "affichassent": "afficher",
    "affichasses": "afficher",
    "affichassiez": "afficher",
    "affichassions": "afficher",
    "affiche": "afficher",
    "affichent": "afficher",
    "affichera": "afficher",
    "afficherai": "afficher",
    "afficheraient": "afficher",
    "afficherais": "afficher",
    "afficherait": "afficher",
    "afficheras": "afficher",
    "afficherez": "afficher",
    "afficheriez": "afficher",
    "afficherions": "afficher",
    "afficherons": "afficher",
    "afficheront": "afficher",
    "affiches": "afficher",
    "affichettes": "affichette",
    "afficheurs": "afficheur",
    "affichez": "afficher",
    "affichiez": "afficher",
    "affichions": "afficher",
    "affichistes": "affichiste",
    "affichons": "afficher",
    "affichâmes": "afficher",
    "affichât": "afficher",
    "affichâtes": "afficher",
    "affichèrent": "afficher",
    "affiché": "afficher",
    "affichée": "afficher",
    "affichées": "afficher",
    "affichés": "afficher",
    "affidavits": "affidavit",
    "affidée": "affidé",
    "affidées": "affidé",
    "affidés": "affidé",
    "affile": "affiler",
    "affilia": "affilier",
    "affiliai": "affilier",
    "affiliaient": "affilier",
    "affiliais": "affilier",
    "affiliait": "affilier",
    "affiliant": "affilier",
    "affilias": "affilier",
    "affiliasse": "affilier",
    "affiliassent": "affilier",
    "affiliasses": "affilier",
    "affiliassiez": "affilier",
    "affiliassions": "affilier",
    "affiliations": "affiliation",
    "affilie": "affilier",
    "affilient": "affilier",
    "affiliera": "affilier",
    "affilierai": "affilier",
    "affilieraient": "affilier",
    "affilierais": "affilier",
    "affilierait": "affilier",
    "affilieras": "affilier",
    "affilierez": "affilier",
    "affilieriez": "affilier",
    "affilierions": "affilier",
    "affilierons": "affilier",
    "affilieront": "affilier",
    "affilies": "affilier",
    "affiliez": "affilier",
    "affiliiez": "affilier",
    "affiliions": "affilier",
    "affilions": "affilier",
    "affiliâmes": "affilier",
    "affiliât": "affilier",
    "affiliâtes": "affilier",
    "affilièrent": "affilier",
    "affilié": "affilier",
    "affiliée": "affilier",
    "affiliées": "affilier",
    "affiliés": "affilier",
    "affilée": "affiler",
    "affilées": "affilé",
    "affilés": "affilé",
    "affina": "affiner",
    "affinages": "affinage",
    "affinai": "affiner",
    "affinaient": "affiner",
    "affinais": "affiner",
    "affinait": "affiner",
    "affinant": "affiner",
    "affinas": "affiner",
    "affinasse": "affiner",
    "affinassent": "affiner",
    "affinasses": "affiner",
    "affinassiez": "affiner",
    "affinassions": "affiner",
    "affine": "affiner",
    "affinent": "affiner",
    "affinera": "affiner",
    "affinerai": "affiner",
    "affineraient": "affiner",
    "affinerais": "affiner",
    "affinerait": "affiner",
    "affineras": "affiner",
    "affinerez": "affiner",
    "affineriez": "affiner",
    "affinerions": "affiner",
    "affinerons": "affiner",
    "affineront": "affiner",
    "affines": "affiner",
    "affineurs": "affineur",
    "affinez": "affiner",
    "affiniez": "affiner",
    "affinions": "affiner",
    "affinités": "affinité",
    "affinons": "affiner",
    "affinâmes": "affiner",
    "affinât": "affiner",
    "affinâtes": "affiner",
    "affinèrent": "affiner",
    "affiné": "affiner",
    "affinée": "affiner",
    "affinées": "affiner",
    "affinés": "affiner",
    "affiquets": "affiquet",
    "affirma": "affirmer",
    "affirmai": "affirmer",
    "affirmaient": "affirmer",
    "affirmais": "affirmer",
    "affirmait": "affirmer",
    "affirmant": "affirmer",
    "affirmas": "affirmer",
    "affirmasse": "affirmer",
    "affirmassent": "affirmer",
    "affirmasses": "affirmer",
    "affirmassiez": "affirmer",
    "affirmassions": "affirmer",
    "affirmatifs": "affirmatif",
    "affirmations": "affirmation",
    "affirmative": "affirmatif",
    "affirmatives": "affirmative",
    "affirme": "affirmer",
    "affirment": "affirmer",
    "affirmera": "affirmer",
    "affirmerai": "affirmer",
    "affirmeraient": "affirmer",
    "affirmerais": "affirmer",
    "affirmerait": "affirmer",
    "affirmeras": "affirmer",
    "affirmerez": "affirmer",
    "affirmeriez": "affirmer",
    "affirmerions": "affirmer",
    "affirmerons": "affirmer",
    "affirmeront": "affirmer",
    "affirmes": "affirmer",
    "affirmez": "affirmer",
    "affirmiez": "affirmer",
    "affirmions": "affirmer",
    "affirmons": "affirmer",
    "affirmâmes": "affirmer",
    "affirmât": "affirmer",
    "affirmâtes": "affirmer",
    "affirmèrent": "affirmer",
    "affirmé": "affirmer",
    "affirmée": "affirmer",
    "affirmées": "affirmer",
    "affirmés": "affirmer",
    "affixale": "affixal",
    "affixales": "affixal",
    "affixaux": "affixal",
    "affixes": "affixe",
    "afflanqué": "afflanquer",
    "affleura": "affleurer",
    "affleurai": "affleurer",
    "affleuraient": "affleurer",
    "affleurais": "affleurer",
    "affleurait": "affleurer",
    "affleurant": "affleurer",
    "affleuras": "affleurer",
    "affleurasse": "affleurer",
    "affleurassent": "affleurer",
    "affleurasses": "affleurer",
    "affleurassiez": "affleurer",
    "affleurassions": "affleurer",
    "affleure": "affleurer",
    "affleurements": "affleurement",
    "affleurent": "affleurer",
    "affleurera": "affleurer",
    "affleurerai": "affleurer",
    "affleureraient": "affleurer",
    "affleurerais": "affleurer",
    "affleurerait": "affleurer",
    "affleureras": "affleurer",
    "affleurerez": "affleurer",
    "affleureriez": "affleurer",
    "affleurerions": "affleurer",
    "affleurerons": "affleurer",
    "affleureront": "affleurer",
    "affleures": "affleurer",
    "affleurez": "affleurer",
    "affleuriez": "affleurer",
    "affleurions": "affleurer",
    "affleurons": "affleurer",
    "affleurâmes": "affleurer",
    "affleurât": "affleurer",
    "affleurâtes": "affleurer",
    "affleurèrent": "affleurer",
    "affleuré": "affleurer",
    "affleurée": "affleurer",
    "affleurées": "affleurer",
    "affleurés": "affleurer",
    "afflictions": "affliction",
    "afflige": "affliger",
    "affligea": "affliger",
    "affligeai": "affliger",
    "affligeaient": "affliger",
    "affligeais": "affliger",
    "affligeait": "affliger",
    "affligeant": "affliger",
    "affligeante": "affligeant",
    "affligeantes": "affligeant",
    "affligeants": "affligeant",
    "affligeas": "affliger",
    "affligeasse": "affliger",
    "affligeassent": "affliger",
    "affligeasses": "affliger",
    "affligeassiez": "affliger",
    "affligeassions": "affliger",
    "affligent": "affliger",
    "affligeons": "affliger",
    "affligera": "affliger",
    "affligerai": "affliger",
    "affligeraient": "affliger",
    "affligerais": "affliger",
    "affligerait": "affliger",
    "affligeras": "affliger",
    "affligerez": "affliger",
    "affligeriez": "affliger",
    "affligerions": "affliger",
    "affligerons": "affliger",
    "affligeront": "affliger",
    "affliges": "affliger",
    "affligez": "affliger",
    "affligeâmes": "affliger",
    "affligeât": "affliger",
    "affligeâtes": "affliger",
    "affligiez": "affliger",
    "affligions": "affliger",
    "affligèrent": "affliger",
    "affligé": "affliger",
    "affligée": "affliger",
    "affligées": "affliger",
    "affligés": "affliger",
    "affloua": "afflouer",
    "afflouai": "afflouer",
    "afflouaient": "afflouer",
    "afflouais": "afflouer",
    "afflouait": "afflouer",
    "afflouant": "afflouer",
    "afflouas": "afflouer",
    "afflouasse": "afflouer",
    "afflouassent": "afflouer",
    "afflouasses": "afflouer",
    "afflouassiez": "afflouer",
    "afflouassions": "afflouer",
    "affloue": "afflouer",
    "afflouent": "afflouer",
    "afflouera": "afflouer",
    "afflouerai": "afflouer",
    "affloueraient": "afflouer",
    "afflouerais": "afflouer",
    "afflouerait": "afflouer",
    "affloueras": "afflouer",
    "afflouerez": "afflouer",
    "affloueriez": "afflouer",
    "afflouerions": "afflouer",
    "afflouerons": "afflouer",
    "affloueront": "afflouer",
    "affloues": "afflouer",
    "afflouez": "afflouer",
    "afflouiez": "afflouer",
    "afflouions": "afflouer",
    "afflouons": "afflouer",
    "afflouâmes": "afflouer",
    "afflouât": "afflouer",
    "afflouâtes": "afflouer",
    "afflouèrent": "afflouer",
    "affloué": "afflouer",
    "afflouée": "afflouer",
    "afflouées": "afflouer",
    "affloués": "afflouer",
    "afflua": "affluer",
    "affluai": "affluer",
    "affluaient": "affluer",
    "affluais": "affluer",
    "affluait": "affluer",
    "affluant": "affluer",
    "affluas": "affluer",
    "affluasse": "affluer",
    "affluassent": "affluer",
    "affluasses": "affluer",
    "affluassiez": "affluer",
    "affluassions": "affluer",
    "afflue": "affluer",
    "affluences": "affluence",
    "affluent": "affluer",
    "affluentes": "affluent",
    "affluents": "affluent",
    "affluera": "affluer",
    "affluerai": "affluer",
    "afflueraient": "affluer",
    "affluerais": "affluer",
    "affluerait": "affluer",
    "afflueras": "affluer",
    "affluerez": "affluer",
    "afflueriez": "affluer",
    "affluerions": "affluer",
    "affluerons": "affluer",
    "afflueront": "affluer",
    "afflues": "affluer",
    "affluez": "affluer",
    "affluiez": "affluer",
    "affluions": "affluer",
    "affluons": "affluer",
    "affluâmes": "affluer",
    "affluât": "affluer",
    "affluâtes": "affluer",
    "affluèrent": "affluer",
    "afflué": "affluer",
    "affola": "affoler",
    "affolai": "affoler",
    "affolaient": "affoler",
    "affolais": "affoler",
    "affolait": "affoler",
    "affolant": "affoler",
    "affolante": "affolant",
    "affolantes": "affolant",
    "affolants": "affolant",
    "affolas": "affoler",
    "affolasse": "affoler",
    "affolassent": "affoler",
    "affolasses": "affoler",
    "affolassiez": "affoler",
    "affolassions": "affoler",
    "affole": "affoler",
    "affolements": "affolement",
    "affolent": "affoler",
    "affolera": "affoler",
    "affolerai": "affoler",
    "affoleraient": "affoler",
    "affolerais": "affoler",
    "affolerait": "affoler",
    "affoleras": "affoler",
    "affolerez": "affoler",
    "affoleriez": "affoler",
    "affolerions": "affoler",
    "affolerons": "affoler",
    "affoleront": "affoler",
    "affoles": "affoler",
    "affolez": "affoler",
    "affoliez": "affoler",
    "affolions": "affoler",
    "affolons": "affoler",
    "affolâmes": "affoler",
    "affolât": "affoler",
    "affolâtes": "affoler",
    "affolèrent": "affoler",
    "affolé": "affoler",
    "affolée": "affoler",
    "affolées": "affoler",
    "affolés": "affoler",
    "affouages": "affouage",
    "affouillait": "affouiller",
    "affouillements": "affouillement",
    "affouillé": "affouiller",
    "affranchi": "affranchir",
    "affranchie": "affranchir",
    "affranchies": "affranchir",
    "affranchira": "affranchir",
    "affranchirai": "affranchir",
    "affranchiraient": "affranchir",
    "affranchirais": "affranchir",
    "affranchirait": "affranchir",
    "affranchiras": "affranchir",
    "affranchirent": "affranchir",
    "affranchirez": "affranchir",
    "affranchiriez": "affranchir",
    "affranchirions": "affranchir",
    "affranchirons": "affranchir",
    "affranchiront": "affranchir",
    "affranchis": "affranchir",
    "affranchissaient": "affranchir",
    "affranchissais": "affranchir",
    "affranchissait": "affranchir",
    "affranchissant": "affranchir",
    "affranchisse": "affranchir",
    "affranchissements": "affranchissement",
    "affranchissent": "affranchir",
    "affranchisses": "affranchir",
    "affranchissez": "affranchir",
    "affranchissiez": "affranchir",
    "affranchissions": "affranchir",
    "affranchissons": "affranchir",
    "affranchit": "affranchir",
    "affranchîmes": "affranchir",
    "affranchît": "affranchir",
    "affranchîtes": "affranchir",
    "affres": "affre",
    "affreuse": "affreux",
    "affreuses": "affreux",
    "affrianda": "affriander",
    "affriandai": "affriander",
    "affriandaient": "affriander",
    "affriandais": "affriander",
    "affriandait": "affriander",
    "affriandant": "affriander",
    "affriandas": "affriander",
    "affriandasse": "affriander",
    "affriandassent": "affriander",
    "affriandasses": "affriander",
    "affriandassiez": "affriander",
    "affriandassions": "affriander",
    "affriande": "affriander",
    "affriandent": "affriander",
    "affriandera": "affriander",
    "affrianderai": "affriander",
    "affrianderaient": "affriander",
    "affrianderais": "affriander",
    "affrianderait": "affriander",
    "affrianderas": "affriander",
    "affrianderez": "affriander",
    "affrianderiez": "affriander",
    "affrianderions": "affriander",
    "affrianderons": "affriander",
    "affrianderont": "affriander",
    "affriandes": "affriander",
    "affriandez": "affriander",
    "affriandiez": "affriander",
    "affriandions": "affriander",
    "affriandons": "affriander",
    "affriandâmes": "affriander",
    "affriandât": "affriander",
    "affriandâtes": "affriander",
    "affriandèrent": "affriander",
    "affriandé": "affriander",
    "affriandée": "affriander",
    "affriandées": "affriander",
    "affriandés": "affriander",
    "affriola": "affrioler",
    "affriolai": "affrioler",
    "affriolaient": "affrioler",
    "affriolais": "affrioler",
    "affriolait": "affrioler",
    "affriolant": "affrioler",
    "affriolante": "affriolant",
    "affriolantes": "affriolant",
    "affriolants": "affriolant",
    "affriolas": "affrioler",
    "affriolasse": "affrioler",
    "affriolassent": "affrioler",
    "affriolasses": "affrioler",
    "affriolassiez": "affrioler",
    "affriolassions": "affrioler",
    "affriole": "affrioler",
    "affriolent": "affrioler",
    "affriolera": "affrioler",
    "affriolerai": "affrioler",
    "affrioleraient": "affrioler",
    "affriolerais": "affrioler",
    "affriolerait": "affrioler",
    "affrioleras": "affrioler",
    "affriolerez": "affrioler",
    "affrioleriez": "affrioler",
    "affriolerions": "affrioler",
    "affriolerons": "affrioler",
    "affrioleront": "affrioler",
    "affrioles": "affrioler",
    "affriolez": "affrioler",
    "affrioliez": "affrioler",
    "affriolions": "affrioler",
    "affriolons": "affrioler",
    "affriolâmes": "affrioler",
    "affriolât": "affrioler",
    "affriolâtes": "affrioler",
    "affriolèrent": "affrioler",
    "affriolé": "affrioler",
    "affriolée": "affrioler",
    "affriolées": "affrioler",
    "affriolés": "affrioler",
    "affronta": "affronter",
    "affrontai": "affronter",
    "affrontaient": "affronter",
    "affrontais": "affronter",
    "affrontait": "affronter",
    "affrontant": "affronter",
    "affrontas": "affronter",
    "affrontasse": "affronter",
    "affrontassent": "affronter",
    "affrontasses": "affronter",
    "affrontassiez": "affronter",
    "affrontassions": "affronter",
    "affronte": "affronter",
    "affrontements": "affrontement",
    "affrontent": "affronter",
    "affrontera": "affronter",
    "affronterai": "affronter",
    "affronteraient": "affronter",
    "affronterais": "affronter",
    "affronterait": "affronter",
    "affronteras": "affronter",
    "affronterez": "affronter",
    "affronteriez": "affronter",
    "affronterions": "affronter",
    "affronterons": "affronter",
    "affronteront": "affronter",
    "affrontes": "affronter",
    "affrontez": "affronter",
    "affrontiez": "affronter",
    "affrontions": "affronter",
    "affrontons": "affronter",
    "affronts": "affront",
    "affrontâmes": "affronter",
    "affrontât": "affronter",
    "affrontâtes": "affronter",
    "affrontèrent": "affronter",
    "affronté": "affronter",
    "affrontée": "affronter",
    "affrontées": "affronter",
    "affrontés": "affronter",
    "affrète": "affréter",
    "affrètements": "affrètement",
    "affrètent": "affréter",
    "affrètes": "affréter",
    "affréta": "affréter",
    "affrétai": "affréter",
    "affrétaient": "affréter",
    "affrétais": "affréter",
    "affrétait": "affréter",
    "affrétant": "affréter",
    "affrétas": "affréter",
    "affrétasse": "affréter",
    "affrétassent": "affréter",
    "affrétasses": "affréter",
    "affrétassiez": "affréter",
    "affrétassions": "affréter",
    "affrétera": "affréter",
    "affréterai": "affréter",
    "affréteraient": "affréter",
    "affréterais": "affréter",
    "affréterait": "affréter",
    "affréteras": "affréter",
    "affréterez": "affréter",
    "affréteriez": "affréter",
    "affréterions": "affréter",
    "affréterons": "affréter",
    "affréteront": "affréter",
    "affrétez": "affréter",
    "affrétiez": "affréter",
    "affrétions": "affréter",
    "affrétons": "affréter",
    "affrétâmes": "affréter",
    "affrétât": "affréter",
    "affrétâtes": "affréter",
    "affrétèrent": "affréter",
    "affrété": "affréter",
    "affrétée": "affréter",
    "affrétées": "affréter",
    "affrétés": "affréter",
    "affubla": "affubler",
    "affublai": "affubler",
    "affublaient": "affubler",
    "affublais": "affubler",
    "affublait": "affubler",
    "affublant": "affubler",
    "affublas": "affubler",
    "affublasse": "affubler",
    "affublassent": "affubler",
    "affublasses": "affubler",
    "affublassiez": "affubler",
    "affublassions": "affubler",
    "affuble": "affubler",
    "affublent": "affubler",
    "affublera": "affubler",
    "affublerai": "affubler",
    "affubleraient": "affubler",
    "affublerais": "affubler",
    "affublerait": "affubler",
    "affubleras": "affubler",
    "affublerez": "affubler",
    "affubleriez": "affubler",
    "affublerions": "affubler",
    "affublerons": "affubler",
    "affubleront": "affubler",
    "affubles": "affubler",
    "affublez": "affubler",
    "affubliez": "affubler",
    "affublions": "affubler",
    "affublons": "affubler",
    "affublâmes": "affubler",
    "affublât": "affubler",
    "affublâtes": "affubler",
    "affublèrent": "affubler",
    "affublé": "affubler",
    "affublée": "affubler",
    "affublées": "affubler",
    "affublés": "affubler",
    "affurait": "affurer",
    "affure": "affurer",
    "affures": "affurer",
    "affuré": "affurer",
    "affurée": "affurer",
    "affusions": "affusion",
    "afférente": "afférent",
    "afférentes": "afférent",
    "afférents": "afférent",
    "afféteries": "afféterie",
    "affétées": "affété",
    "affûta": "affûter",
    "affûtai": "affûter",
    "affûtaient": "affûter",
    "affûtais": "affûter",
    "affûtait": "affûter",
    "affûtant": "affûter",
    "affûtas": "affûter",
    "affûtasse": "affûter",
    "affûtassent": "affûter",
    "affûtasses": "affûter",
    "affûtassiez": "affûter",
    "affûtassions": "affûter",
    "affûte": "affûter",
    "affûtent": "affûter",
    "affûtera": "affûter",
    "affûterai": "affûter",
    "affûteraient": "affûter",
    "affûterais": "affûter",
    "affûterait": "affûter",
    "affûteras": "affûter",
    "affûterez": "affûter",
    "affûteriez": "affûter",
    "affûterions": "affûter",
    "affûterons": "affûter",
    "affûteront": "affûter",
    "affûtes": "affûter",
    "affûtez": "affûter",
    "affûtiez": "affûter",
    "affûtions": "affûter",
    "affûtons": "affûter",
    "affûts": "affût",
    "affûtâmes": "affûter",
    "affûtât": "affûter",
    "affûtâtes": "affûter",
    "affûtèrent": "affûter",
    "affûté": "affûter",
    "affûtée": "affûter",
    "affûtées": "affûter",
    "affûtés": "affûter",
    "afghane": "afghan",
    "afghanes": "afghan",
    "afghans": "afghan",
    "aficionados": "aficionado",
    "aflatoxines": "aflatoxine",
    "afocale": "afocal",
    "afocales": "afocal",
    "afocaux": "afocal",
    "africaine": "africain",
    "africaines": "africain",
    "africains": "africain",
    "africanisations": "africanisation",
    "afrikaners": "afrikaner",
    "afro-américaine": "afro-américain",
    "afro-américains": "afro-américain",
    "afro-brésilienne": "afro-brésilien",
    "afro-cubaine": "afro-cubain",
    "afro-cubains": "afro-cubain",
    "after shave": "after-shave",
    "agace": "agacer",
    "agacements": "agacement",
    "agacent": "agacer",
    "agacera": "agacer",
    "agacerai": "agacer",
    "agaceraient": "agacer",
    "agacerais": "agacer",
    "agacerait": "agacer",
    "agaceras": "agacer",
    "agacerez": "agacer",
    "agaceries": "agacerie",
    "agaceriez": "agacer",
    "agacerions": "agacer",
    "agacerons": "agacer",
    "agaceront": "agacer",
    "agaces": "agacer",
    "agacez": "agacer",
    "agaciez": "agacer",
    "agacions": "agacer",
    "agacèrent": "agacer",
    "agacé": "agacer",
    "agacée": "agacer",
    "agacées": "agacer",
    "agacés": "agacer",
    "agames": "agame",
    "agamis": "agami",
    "agapanthes": "agapanthe",
    "agapes": "agape",
    "agarics": "agaric",
    "agars-agars": "agar-agar",
    "agas": "aga",
    "agasses": "agasse",
    "agates": "agate",
    "agaves": "agave",
    "agavés": "agavé",
    "agaça": "agacer",
    "agaçai": "agacer",
    "agaçaient": "agacer",
    "agaçais": "agacer",
    "agaçait": "agacer",
    "agaçant": "agacer",
    "agaçante": "agaçant",
    "agaçantes": "agaçant",
    "agaçants": "agaçant",
    "agaças": "agacer",
    "agaçasse": "agacer",
    "agaçassent": "agacer",
    "agaçasses": "agacer",
    "agaçassiez": "agacer",
    "agaçassions": "agacer",
    "agaçons": "agacer",
    "agaçâmes": "agacer",
    "agaçât": "agacer",
    "agaçâtes": "agacer",
    "agence": "agencer",
    "agencements": "agencement",
    "agencent": "agencer",
    "agencera": "agencer",
    "agencerai": "agencer",
    "agenceraient": "agencer",
    "agencerais": "agencer",
    "agencerait": "agencer",
    "agenceras": "agencer",
    "agencerez": "agencer",
    "agenceriez": "agencer",
    "agencerions": "agencer",
    "agencerons": "agencer",
    "agenceront": "agencer",
    "agences": "agencer",
    "agencez": "agencer",
    "agenciez": "agencer",
    "agencions": "agencer",
    "agencèrent": "agencer",
    "agencé": "agencer",
    "agencée": "agencer",
    "agencées": "agencer",
    "agencés": "agencer",
    "agendas": "agenda",
    "agenouilla": "agenouiller",
    "agenouillai": "agenouiller",
    "agenouillaient": "agenouiller",
    "agenouillais": "agenouiller",
    "agenouillait": "agenouiller",
    "agenouillant": "agenouiller",
    "agenouillas": "agenouiller",
    "agenouillasse": "agenouiller",
    "agenouillassent": "agenouiller",
    "agenouillasses": "agenouiller",
    "agenouillassiez": "agenouiller",
    "agenouillassions": "agenouiller",
    "agenouille": "agenouiller",
    "agenouillent": "agenouiller",
    "agenouillera": "agenouiller",
    "agenouillerai": "agenouiller",
    "agenouilleraient": "agenouiller",
    "agenouillerais": "agenouiller",
    "agenouillerait": "agenouiller",
    "agenouilleras": "agenouiller",
    "agenouillerez": "agenouiller",
    "agenouilleriez": "agenouiller",
    "agenouillerions": "agenouiller",
    "agenouillerons": "agenouiller",
    "agenouilleront": "agenouiller",
    "agenouilles": "agenouiller",
    "agenouillez": "agenouiller",
    "agenouilliez": "agenouiller",
    "agenouillions": "agenouiller",
    "agenouillons": "agenouiller",
    "agenouillâmes": "agenouiller",
    "agenouillât": "agenouiller",
    "agenouillâtes": "agenouiller",
    "agenouillèrent": "agenouiller",
    "agenouillé": "agenouiller",
    "agenouillée": "agenouiller",
    "agenouillées": "agenouiller",
    "agenouillés": "agenouiller",
    "agente": "agent",
    "agents": "agent",
    "agença": "agencer",
    "agençai": "agencer",
    "agençaient": "agencer",
    "agençais": "agencer",
    "agençait": "agencer",
    "agençant": "agencer",
    "agenças": "agencer",
    "agençasse": "agencer",
    "agençassent": "agencer",
    "agençasses": "agencer",
    "agençassiez": "agencer",
    "agençassions": "agencer",
    "agençons": "agencer",
    "agençâmes": "agencer",
    "agençât": "agencer",
    "agençâtes": "agencer",
    "ages": "age",
    "aggiornamentos": "aggiornamento",
    "agglomère": "agglomérer",
    "agglomèrent": "agglomérer",
    "agglomères": "agglomérer",
    "aggloméra": "agglomérer",
    "agglomérai": "agglomérer",
    "aggloméraient": "agglomérer",
    "agglomérais": "agglomérer",
    "agglomérait": "agglomérer",
    "agglomérant": "agglomérer",
    "aggloméras": "agglomérer",
    "agglomérasse": "agglomérer",
    "agglomérassent": "agglomérer",
    "agglomérasses": "agglomérer",
    "agglomérassiez": "agglomérer",
    "agglomérassions": "agglomérer",
    "agglomérations": "agglomération",
    "agglomérats": "agglomérat",
    "agglomérera": "agglomérer",
    "agglomérerai": "agglomérer",
    "aggloméreraient": "agglomérer",
    "agglomérerais": "agglomérer",
    "agglomérerait": "agglomérer",
    "aggloméreras": "agglomérer",
    "agglomérerez": "agglomérer",
    "aggloméreriez": "agglomérer",
    "agglomérerions": "agglomérer",
    "agglomérerons": "agglomérer",
    "aggloméreront": "agglomérer",
    "agglomérez": "agglomérer",
    "agglomériez": "agglomérer",
    "agglomérions": "agglomérer",
    "agglomérons": "agglomérer",
    "agglomérâmes": "agglomérer",
    "agglomérât": "agglomérer",
    "agglomérâtes": "agglomérer",
    "agglomérèrent": "agglomérer",
    "aggloméré": "agglomérer",
    "agglomérée": "agglomérer",
    "agglomérées": "agglomérer",
    "agglomérés": "agglomérer",
    "agglutina": "agglutiner",
    "agglutinai": "agglutiner",
    "agglutinaient": "agglutiner",
    "agglutinais": "agglutiner",
    "agglutinait": "agglutiner",
    "agglutinant": "agglutiner",
    "agglutinas": "agglutiner",
    "agglutinasse": "agglutiner",
    "agglutinassent": "agglutiner",
    "agglutinasses": "agglutiner",
    "agglutinassiez": "agglutiner",
    "agglutinassions": "agglutiner",
    "agglutine": "agglutiner",
    "agglutinent": "agglutiner",
    "agglutinera": "agglutiner",
    "agglutinerai": "agglutiner",
    "agglutineraient": "agglutiner",
    "agglutinerais": "agglutiner",
    "agglutinerait": "agglutiner",
    "agglutineras": "agglutiner",
    "agglutinerez": "agglutiner",
    "agglutineriez": "agglutiner",
    "agglutinerions": "agglutiner",
    "agglutinerons": "agglutiner",
    "agglutineront": "agglutiner",
    "agglutines": "agglutiner",
    "agglutinez": "agglutiner",
    "agglutiniez": "agglutiner",
    "agglutinions": "agglutiner",
    "agglutinons": "agglutiner",
    "agglutinâmes": "agglutiner",
    "agglutinât": "agglutiner",
    "agglutinâtes": "agglutiner",
    "agglutinèrent": "agglutiner",
    "agglutiné": "agglutiner",
    "agglutinée": "agglutiner",
    "agglutinées": "agglutiner",
    "agglutinés": "agglutiner",
    "aggrava": "aggraver",
    "aggravai": "aggraver",
    "aggravaient": "aggraver",
    "aggravais": "aggraver",
    "aggravait": "aggraver",
    "aggravant": "aggraver",
    "aggravante": "aggravant",
    "aggravantes": "aggravant",
    "aggravants": "aggravant",
    "aggravas": "aggraver",
    "aggravasse": "aggraver",
    "aggravassent": "aggraver",
    "aggravasses": "aggraver",
    "aggravassiez": "aggraver",
    "aggravassions": "aggraver",
    "aggravations": "aggravation",
    "aggrave": "aggraver",
    "aggravent": "aggraver",
    "aggravera": "aggraver",
    "aggraverai": "aggraver",
    "aggraveraient": "aggraver",
    "aggraverais": "aggraver",
    "aggraverait": "aggraver",
    "aggraveras": "aggraver",
    "aggraverez": "aggraver",
    "aggraveriez": "aggraver",
    "aggraverions": "aggraver",
    "aggraverons": "aggraver",
    "aggraveront": "aggraver",
    "aggraves": "aggraver",
    "aggravez": "aggraver",
    "aggraviez": "aggraver",
    "aggravions": "aggraver",
    "aggravons": "aggraver",
    "aggravâmes": "aggraver",
    "aggravât": "aggraver",
    "aggravâtes": "aggraver",
    "aggravèrent": "aggraver",
    "aggravé": "aggraver",
    "aggravée": "aggraver",
    "aggravées": "aggraver",
    "aggravés": "aggraver",
    "aghas": "agha",
    "agi": "agir",
    "agie": "agir",
    "agiles": "agile",
    "agilités": "agilité",
    "agios": "agio",
    "agira": "agir",
    "agirai": "agir",
    "agiraient": "agir",
    "agirais": "agir",
    "agirait": "agir",
    "agiras": "agir",
    "agirent": "agir",
    "agirez": "agir",
    "agiriez": "agir",
    "agirions": "agir",
    "agirons": "agir",
    "agiront": "agir",
    "agis": "agir",
    "agissaient": "agir",
    "agissais": "agir",
    "agissait": "agir",
    "agissant": "agir",
    "agissante": "agissant",
    "agissantes": "agissant",
    "agissants": "agissant",
    "agisse": "agir",
    "agissements": "agissement",
    "agissent": "agir",
    "agisses": "agir",
    "agissez": "agir",
    "agissiez": "agir",
    "agissions": "agir",
    "agissons": "agir",
    "agit": "agir",
    "agita": "agiter",
    "agitai": "agiter",
    "agitaient": "agiter",
    "agitais": "agiter",
    "agitait": "agiter",
    "agitant": "agiter",
    "agitas": "agiter",
    "agitasse": "agiter",
    "agitassent": "agiter",
    "agitasses": "agiter",
    "agitassiez": "agiter",
    "agitassions": "agiter",
    "agitateurs": "agitateur",
    "agitations": "agitation",
    "agitatrice": "agitateur",
    "agite": "agiter",
    "agitent": "agiter",
    "agitera": "agiter",
    "agiterai": "agiter",
    "agiteraient": "agiter",
    "agiterais": "agiter",
    "agiterait": "agiter",
    "agiteras": "agiter",
    "agiterez": "agiter",
    "agiteriez": "agiter",
    "agiterions": "agiter",
    "agiterons": "agiter",
    "agiteront": "agiter",
    "agites": "agiter",
    "agitez": "agiter",
    "agitiez": "agiter",
    "agitions": "agiter",
    "agitons": "agiter",
    "agitâmes": "agiter",
    "agitât": "agiter",
    "agitâtes": "agiter",
    "agitèrent": "agiter",
    "agité": "agiter",
    "agitée": "agiter",
    "agitées": "agiter",
    "agités": "agiter",
    "agnathes": "agnathe",
    "agneaux": "agneau",
    "agnela": "agneler",
    "agnelai": "agneler",
    "agnelaient": "agneler",
    "agnelais": "agneler",
    "agnelait": "agneler",
    "agnelant": "agneler",
    "agnelas": "agneler",
    "agnelasse": "agneler",
    "agnelassent": "agneler",
    "agnelasses": "agneler",
    "agnelassiez": "agneler",
    "agnelassions": "agneler",
    "agnelets": "agnelet",
    "agnelez": "agneler",
    "agneliez": "agneler",
    "agnelions": "agneler",
    "agnelle": "agneler",
    "agnellent": "agneler",
    "agnellera": "agneler",
    "agnellerai": "agneler",
    "agnelleraient": "agneler",
    "agnellerais": "agneler",
    "agnellerait": "agneler",
    "agnelleras": "agneler",
    "agnellerez": "agneler",
    "agnelleriez": "agneler",
    "agnellerions": "agneler",
    "agnellerons": "agneler",
    "agnelleront": "agneler",
    "agnelles": "agneler",
    "agnelons": "agneler",
    "agnelâmes": "agneler",
    "agnelât": "agneler",
    "agnelâtes": "agneler",
    "agnelèrent": "agneler",
    "agnelé": "agneler",
    "agnosies": "agnosie",
    "agnostiques": "agnostique",
    "agoni": "agonir",
    "agonie": "agonir",
    "agonies": "agonir",
    "agoniques": "agonique",
    "agonira": "agonir",
    "agonirai": "agonir",
    "agoniraient": "agonir",
    "agonirais": "agonir",
    "agonirait": "agonir",
    "agoniras": "agonir",
    "agonirent": "agonir",
    "agonirez": "agonir",
    "agoniriez": "agonir",
    "agonirions": "agonir",
    "agonirons": "agonir",
    "agoniront": "agonir",
    "agonis": "agonir",
    "agonisa": "agoniser",
    "agonisai": "agoniser",
    "agonisaient": "agoniser",
    "agonisais": "agoniser",
    "agonisait": "agoniser",
    "agonisant": "agoniser",
    "agonisante": "agonisant",
    "agonisantes": "agonisant",
    "agonisants": "agonisant",
    "agonisas": "agoniser",
    "agonisasse": "agoniser",
    "agonisassent": "agoniser",
    "agonisasses": "agoniser",
    "agonisassiez": "agoniser",
    "agonisassions": "agoniser",
    "agonise": "agoniser",
    "agonisent": "agoniser",
    "agonisera": "agoniser",
    "agoniserai": "agoniser",
    "agoniseraient": "agoniser",
    "agoniserais": "agoniser",
    "agoniserait": "agoniser",
    "agoniseras": "agoniser",
    "agoniserez": "agoniser",
    "agoniseriez": "agoniser",
    "agoniserions": "agoniser",
    "agoniserons": "agoniser",
    "agoniseront": "agoniser",
    "agonises": "agoniser",
    "agonisez": "agoniser",
    "agonisiez": "agoniser",
    "agonisions": "agoniser",
    "agonisons": "agoniser",
    "agonissaient": "agonir",
    "agonissais": "agonir",
    "agonissait": "agonir",
    "agonissant": "agonir",
    "agonisse": "agonir",
    "agonissent": "agonir",
    "agonisses": "agonir",
    "agonissez": "agonir",
    "agonissiez": "agonir",
    "agonissions": "agonir",
    "agonissons": "agonir",
    "agonisâmes": "agoniser",
    "agonisât": "agoniser",
    "agonisâtes": "agoniser",
    "agonisèrent": "agoniser",
    "agonisé": "agoniser",
    "agonit": "agonir",
    "agonîmes": "agonir",
    "agonît": "agonir",
    "agonîtes": "agonir",
    "agoraphobes": "agoraphobe",
    "agoras": "agora",
    "agoutis": "agouti",
    "agoyates": "agoyate",
    "agrafa": "agrafer",
    "agrafages": "agrafage",
    "agrafai": "agrafer",
    "agrafaient": "agrafer",
    "agrafais": "agrafer",
    "agrafait": "agrafer",
    "agrafant": "agrafer",
    "agrafas": "agrafer",
    "agrafasse": "agrafer",
    "agrafassent": "agrafer",
    "agrafasses": "agrafer",
    "agrafassiez": "agrafer",
    "agrafassions": "agrafer",
    "agrafe": "agrafer",
    "agrafent": "agrafer",
    "agrafera": "agrafer",
    "agraferai": "agrafer",
    "agraferaient": "agrafer",
    "agraferais": "agrafer",
    "agraferait": "agrafer",
    "agraferas": "agrafer",
    "agraferez": "agrafer",
    "agraferiez": "agrafer",
    "agraferions": "agrafer",
    "agraferons": "agrafer",
    "agraferont": "agrafer",
    "agrafes": "agrafer",
    "agrafeuses": "agrafeuse",
    "agrafez": "agrafer",
    "agrafiez": "agrafer",
    "agrafions": "agrafer",
    "agrafons": "agrafer",
    "agrafâmes": "agrafer",
    "agrafât": "agrafer",
    "agrafâtes": "agrafer",
    "agrafèrent": "agrafer",
    "agrafé": "agrafer",
    "agrafée": "agrafer",
    "agrafées": "agrafer",
    "agrafés": "agrafer",
    "agraires": "agraire",
    "agrammaticale": "agrammatical",
    "agrammaticales": "agrammatical",
    "agrammaticaux": "agrammatical",
    "agrandi": "agrandir",
    "agrandie": "agrandir",
    "agrandies": "agrandir",
    "agrandira": "agrandir",
    "agrandirai": "agrandir",
    "agrandiraient": "agrandir",
    "agrandirais": "agrandir",
    "agrandirait": "agrandir",
    "agrandiras": "agrandir",
    "agrandirent": "agrandir",
    "agrandirez": "agrandir",
    "agrandiriez": "agrandir",
    "agrandirions": "agrandir",
    "agrandirons": "agrandir",
    "agrandiront": "agrandir",
    "agrandis": "agrandir",
    "agrandissaient": "agrandir",
    "agrandissais": "agrandir",
    "agrandissait": "agrandir",
    "agrandissant": "agrandir",
    "agrandisse": "agrandir",
    "agrandissements": "agrandissement",
    "agrandissent": "agrandir",
    "agrandisses": "agrandir",
    "agrandisseurs": "agrandisseur",
    "agrandissez": "agrandir",
    "agrandissiez": "agrandir",
    "agrandissions": "agrandir",
    "agrandissons": "agrandir",
    "agrandit": "agrandir",
    "agrandîmes": "agrandir",
    "agrandît": "agrandir",
    "agrandîtes": "agrandir",
    "agrarienne": "agrarien",
    "agrariennes": "agrarien",
    "agrariens": "agrarien",
    "agressa": "agresser",
    "agressai": "agresser",
    "agressaient": "agresser",
    "agressais": "agresser",
    "agressait": "agresser",
    "agressant": "agresser",
    "agressas": "agresser",
    "agressasse": "agresser",
    "agressassent": "agresser",
    "agressasses": "agresser",
    "agressassiez": "agresser",
    "agressassions": "agresser",
    "agresse": "agresser",
    "agressent": "agresser",
    "agressera": "agresser",
    "agresserai": "agresser",
    "agresseraient": "agresser",
    "agresserais": "agresser",
    "agresserait": "agresser",
    "agresseras": "agresser",
    "agresserez": "agresser",
    "agresseriez": "agresser",
    "agresserions": "agresser",
    "agresserons": "agresser",
    "agresseront": "agresser",
    "agresses": "agresser",
    "agresseurs": "agresseur",
    "agressez": "agresser",
    "agressiez": "agresser",
    "agressifs": "agressif",
    "agressions": "agression",
    "agressive": "agressif",
    "agressives": "agressif",
    "agressivités": "agressivité",
    "agressons": "agresser",
    "agressâmes": "agresser",
    "agressât": "agresser",
    "agressâtes": "agresser",
    "agressèrent": "agresser",
    "agressé": "agresser",
    "agressée": "agresser",
    "agressées": "agresser",
    "agressés": "agresser",
    "agrestes": "agreste",
    "agriche": "agricher",
    "agriches": "agricher",
    "agricoles": "agricole",
    "agriculteurs": "agriculteur",
    "agricultrice": "agriculteur",
    "agricultrices": "agriculteur",
    "agricultures": "agriculture",
    "agriffa": "agriffer",
    "agriffai": "agriffer",
    "agriffaient": "agriffer",
    "agriffais": "agriffer",
    "agriffait": "agriffer",
    "agriffant": "agriffer",
    "agriffas": "agriffer",
    "agriffasse": "agriffer",
    "agriffassent": "agriffer",
    "agriffasses": "agriffer",
    "agriffassiez": "agriffer",
    "agriffassions": "agriffer",
    "agriffe": "agriffer",
    "agriffent": "agriffer",
    "agriffera": "agriffer",
    "agrifferai": "agriffer",
    "agrifferaient": "agriffer",
    "agrifferais": "agriffer",
    "agrifferait": "agriffer",
    "agrifferas": "agriffer",
    "agrifferez": "agriffer",
    "agrifferiez": "agriffer",
    "agrifferions": "agriffer",
    "agrifferons": "agriffer",
    "agrifferont": "agriffer",
    "agriffes": "agriffer",
    "agriffez": "agriffer",
    "agriffiez": "agriffer",
    "agriffions": "agriffer",
    "agriffons": "agriffer",
    "agriffâmes": "agriffer",
    "agriffât": "agriffer",
    "agriffâtes": "agriffer",
    "agriffèrent": "agriffer",
    "agriffé": "agriffer",
    "agriffée": "agriffer",
    "agriffées": "agriffer",
    "agriffés": "agriffer",
    "agrippa": "agripper",
    "agrippai": "agripper",
    "agrippaient": "agripper",
    "agrippais": "agripper",
    "agrippait": "agripper",
    "agrippant": "agripper",
    "agrippants": "agrippant",
    "agrippas": "agripper",
    "agrippasse": "agripper",
    "agrippassent": "agripper",
    "agrippasses": "agripper",
    "agrippassiez": "agripper",
    "agrippassions": "agripper",
    "agrippe": "agripper",
    "agrippent": "agripper",
    "agrippera": "agripper",
    "agripperai": "agripper",
    "agripperaient": "agripper",
    "agripperais": "agripper",
    "agripperait": "agripper",
    "agripperas": "agripper",
    "agripperez": "agripper",
    "agripperiez": "agripper",
    "agripperions": "agripper",
    "agripperons": "agripper",
    "agripperont": "agripper",
    "agrippes": "agripper",
    "agrippez": "agripper",
    "agrippiez": "agripper",
    "agrippions": "agripper",
    "agrippons": "agripper",
    "agrippâmes": "agripper",
    "agrippât": "agripper",
    "agrippâtes": "agripper",
    "agrippèrent": "agripper",
    "agrippé": "agripper",
    "agrippée": "agripper",
    "agrippées": "agripper",
    "agrippés": "agripper",
    "agro-alimentaires": "agro-alimentaire",
    "agro-environnementale": "agro-environnemental",
    "agro-environnementales": "agro-environnemental",
    "agro-environnementaux": "agro-environnemental",
    "agro-industries": "agro-industrie",
    "agro-pastorale": "agro-pastoral",
    "agro-pastorales": "agro-pastoral",
    "agro-pastoraux": "agro-pastoral",
    "agro-tourismes": "agro-tourisme",
    "agro-touristiques": "agro-touristique",
    "agroalimentaires": "agroalimentaire",
    "agrochimies": "agrochimie",
    "agroforesteries": "agroforesterie",
    "agronomes": "agronome",
    "agronomies": "agronomie",
    "agronomiques": "agronomique",
    "agrotourismes": "agrotourisme",
    "agrovilles": "agroville",
    "agrumes": "agrume",
    "agrumiculteurs": "agrumiculteur",
    "agrumicultrice": "agrumiculteur",
    "agrumicultrices": "agrumiculteur",
    "agrumicultures": "agrumiculture",
    "agrège": "agréger",
    "agrègent": "agréger",
    "agrèges": "agréger",
    "agréa": "agréer",
    "agréables": "agréable",
    "agréai": "agréer",
    "agréaient": "agréer",
    "agréais": "agréer",
    "agréait": "agréer",
    "agréant": "agréer",
    "agréas": "agréer",
    "agréasse": "agréer",
    "agréassent": "agréer",
    "agréasses": "agréer",
    "agréassiez": "agréer",
    "agréassions": "agréer",
    "agrée": "agréer",
    "agréent": "agréer",
    "agréera": "agréer",
    "agréerai": "agréer",
    "agréeraient": "agréer",
    "agréerais": "agréer",
    "agréerait": "agréer",
    "agréeras": "agréer",
    "agréerez": "agréer",
    "agréeriez": "agréer",
    "agréerions": "agréer",
    "agréerons": "agréer",
    "agréeront": "agréer",
    "agrées": "agréer",
    "agréez": "agréer",
    "agrégatifs": "agrégatif",
    "agrégations": "agrégation",
    "agrégats": "agrégat",
    "agrégea": "agréger",
    "agrégeai": "agréger",
    "agrégeaient": "agréger",
    "agrégeais": "agréger",
    "agrégeait": "agréger",
    "agrégeant": "agréger",
    "agrégeas": "agréger",
    "agrégeasse": "agréger",
    "agrégeassent": "agréger",
    "agrégeasses": "agréger",
    "agrégeassiez": "agréger",
    "agrégeassions": "agréger",
    "agrégeons": "agréger",
    "agrégera": "agréger",
    "agrégerai": "agréger",
    "agrégeraient": "agréger",
    "agrégerais": "agréger",
    "agrégerait": "agréger",
    "agrégeras": "agréger",
    "agrégerez": "agréger",
    "agrégeriez": "agréger",
    "agrégerions": "agréger",
    "agrégerons": "agréger",
    "agrégeront": "agréger",
    "agrégez": "agréger",
    "agrégeâmes": "agréger",
    "agrégeât": "agréger",
    "agrégeâtes": "agréger",
    "agrégiez": "agréger",
    "agrégions": "agréger",
    "agrégèrent": "agréger",
    "agrégé": "agréger",
    "agrégée": "agréger",
    "agrégées": "agréger",
    "agrégés": "agréger",
    "agréiez": "agréer",
    "agréions": "agréer",
    "agrémenta": "agrémenter",
    "agrémentai": "agrémenter",
    "agrémentaient": "agrémenter",
    "agrémentais": "agrémenter",
    "agrémentait": "agrémenter",
    "agrémentant": "agrémenter",
    "agrémentas": "agrémenter",
    "agrémentasse": "agrémenter",
    "agrémentassent": "agrémenter",
    "agrémentasses": "agrémenter",
    "agrémentassiez": "agrémenter",
    "agrémentassions": "agrémenter",
    "agrémente": "agrémenter",
    "agrémentent": "agrémenter",
    "agrémentera": "agrémenter",
    "agrémenterai": "agrémenter",
    "agrémenteraient": "agrémenter",
    "agrémenterais": "agrémenter",
    "agrémenterait": "agrémenter",
    "agrémenteras": "agrémenter",
    "agrémenterez": "agrémenter",
    "agrémenteriez": "agrémenter",
    "agrémenterions": "agrémenter",
    "agrémenterons": "agrémenter",
    "agrémenteront": "agrémenter",
    "agrémentes": "agrémenter",
    "agrémentez": "agrémenter",
    "agrémentiez": "agrémenter",
    "agrémentions": "agrémenter",
    "agrémentons": "agrémenter",
    "agréments": "agrément",
    "agrémentâmes": "agrémenter",
    "agrémentât": "agrémenter",
    "agrémentâtes": "agrémenter",
    "agrémentèrent": "agrémenter",
    "agrémenté": "agrémenter",
    "agrémentée": "agrémenter",
    "agrémentées": "agrémenter",
    "agrémentés": "agrémenter",
    "agréons": "agréer",
    "agréâmes": "agréer",
    "agréât": "agréer",
    "agréâtes": "agréer",
    "agréèrent": "agréer",
    "agréé": "agréer",
    "agréée": "agréer",
    "agréées": "agréer",
    "agréés": "agréer",
    "aguerri": "aguerrir",
    "aguerrie": "aguerrir",
    "aguerries": "aguerrir",
    "aguerrira": "aguerrir",
    "aguerrirai": "aguerrir",
    "aguerriraient": "aguerrir",
    "aguerrirais": "aguerrir",
    "aguerrirait": "aguerrir",
    "aguerriras": "aguerrir",
    "aguerrirent": "aguerrir",
    "aguerrirez": "aguerrir",
    "aguerririez": "aguerrir",
    "aguerririons": "aguerrir",
    "aguerrirons": "aguerrir",
    "aguerriront": "aguerrir",
    "aguerris": "aguerrir",
    "aguerrissaient": "aguerrir",
    "aguerrissais": "aguerrir",
    "aguerrissait": "aguerrir",
    "aguerrissant": "aguerrir",
    "aguerrisse": "aguerrir",
    "aguerrissent": "aguerrir",
    "aguerrisses": "aguerrir",
    "aguerrissez": "aguerrir",
    "aguerrissiez": "aguerrir",
    "aguerrissions": "aguerrir",
    "aguerrissons": "aguerrir",
    "aguerrit": "aguerrir",
    "aguerrîmes": "aguerrir",
    "aguerrît": "aguerrir",
    "aguerrîtes": "aguerrir",
    "aguicha": "aguicher",
    "aguichai": "aguicher",
    "aguichaient": "aguicher",
    "aguichais": "aguicher",
    "aguichait": "aguicher",
    "aguichant": "aguicher",
    "aguichante": "aguichant",
    "aguichantes": "aguichant",
    "aguichas": "aguicher",
    "aguichasse": "aguicher",
    "aguichassent": "aguicher",
    "aguichasses": "aguicher",
    "aguichassiez": "aguicher",
    "aguichassions": "aguicher",
    "aguiche": "aguicher",
    "aguichent": "aguicher",
    "aguichera": "aguicher",
    "aguicherai": "aguicher",
    "aguicheraient": "aguicher",
    "aguicherais": "aguicher",
    "aguicherait": "aguicher",
    "aguicheras": "aguicher",
    "aguicherez": "aguicher",
    "aguicheriez": "aguicher",
    "aguicherions": "aguicher",
    "aguicherons": "aguicher",
    "aguicheront": "aguicher",
    "aguiches": "aguicher",
    "aguicheurs": "aguicheur",
    "aguicheuse": "aguicheur",
    "aguicheuses": "aguicheur",
    "aguichez": "aguicher",
    "aguichiez": "aguicher",
    "aguichions": "aguicher",
    "aguichons": "aguicher",
    "aguichâmes": "aguicher",
    "aguichât": "aguicher",
    "aguichâtes": "aguicher",
    "aguichèrent": "aguicher",
    "aguiché": "aguicher",
    "aguichée": "aguicher",
    "aguichées": "aguicher",
    "aguichés": "aguicher",
    "aguillera": "aguiller",
    "agîmes": "agir",
    "agît": "agir",
    "agîtes": "agir",
    "ahana": "ahaner",
    "ahanai": "ahaner",
    "ahanaient": "ahaner",
    "ahanais": "ahaner",
    "ahanait": "ahaner",
    "ahanant": "ahaner",
    "ahanante": "ahanant",
    "ahanas": "ahaner",
    "ahanasse": "ahaner",
    "ahanassent": "ahaner",
    "ahanasses": "ahaner",
    "ahanassiez": "ahaner",
    "ahanassions": "ahaner",
    "ahane": "ahaner",
    "ahanements": "ahanement",
    "ahanent": "ahaner",
    "ahanera": "ahaner",
    "ahanerai": "ahaner",
    "ahaneraient": "ahaner",
    "ahanerais": "ahaner",
    "ahanerait": "ahaner",
    "ahaneras": "ahaner",
    "ahanerez": "ahaner",
    "ahaneriez": "ahaner",
    "ahanerions": "ahaner",
    "ahanerons": "ahaner",
    "ahaneront": "ahaner",
    "ahanes": "ahaner",
    "ahanez": "ahaner",
    "ahaniez": "ahaner",
    "ahanions": "ahaner",
    "ahanons": "ahaner",
    "ahans": "ahan",
    "ahanâmes": "ahaner",
    "ahanât": "ahaner",
    "ahanâtes": "ahaner",
    "ahanèrent": "ahaner",
    "ahané": "ahaner",
    "ahanée": "ahaner",
    "ahanées": "ahaner",
    "ahanés": "ahaner",
    "ahuri": "ahurir",
    "ahurie": "ahurir",
    "ahuries": "ahurir",
    "ahurira": "ahurir",
    "ahurirai": "ahurir",
    "ahuriraient": "ahurir",
    "ahurirais": "ahurir",
    "ahurirait": "ahurir",
    "ahuriras": "ahurir",
    "ahurirent": "ahurir",
    "ahurirez": "ahurir",
    "ahuririez": "ahurir",
    "ahuririons": "ahurir",
    "ahurirons": "ahurir",
    "ahuriront": "ahurir",
    "ahuris": "ahurir",
    "ahurissaient": "ahurir",
    "ahurissais": "ahurir",
    "ahurissait": "ahurir",
    "ahurissant": "ahurir",
    "ahurissante": "ahurissant",
    "ahurissantes": "ahurissant",
    "ahurissants": "ahurissant",
    "ahurisse": "ahurir",
    "ahurissements": "ahurissement",
    "ahurissent": "ahurir",
    "ahurisses": "ahurir",
    "ahurissez": "ahurir",
    "ahurissiez": "ahurir",
    "ahurissions": "ahurir",
    "ahurissons": "ahurir",
    "ahurit": "ahurir",
    "ahurîmes": "ahurir",
    "ahurît": "ahurir",
    "ahurîtes": "ahurir",
    "ai": "avoir",
    "aida": "aider",
    "aidai": "aider",
    "aidaient": "aider",
    "aidais": "aider",
    "aidait": "aider",
    "aidant": "aider",
    "aidas": "aider",
    "aidasse": "aider",
    "aidassent": "aider",
    "aidasses": "aider",
    "aidassiez": "aider",
    "aidassions": "aider",
    "aide": "aider",
    "aide-soignante": "aide-soignant",
    "aident": "aider",
    "aidera": "aider",
    "aiderai": "aider",
    "aideraient": "aider",
    "aiderais": "aider",
    "aiderait": "aider",
    "aideras": "aider",
    "aiderez": "aider",
    "aideriez": "aider",
    "aiderions": "aider",
    "aiderons": "aider",
    "aideront": "aider",
    "aides": "aider",
    "aides-comptables": "aide-comptable",
    "aides-soignantes": "aide-soignant",
    "aides-soignants": "aide-soignant",
    "aidez": "aider",
    "aidiez": "aider",
    "aidions": "aider",
    "aidons": "aider",
    "aidâmes": "aider",
    "aidât": "aider",
    "aidâtes": "aider",
    "aidèrent": "aider",
    "aidé": "aider",
    "aidée": "aider",
    "aidées": "aider",
    "aidés": "aider",
    "aie": "avoir",
    "aient": "avoir",
    "aies": "avoir",
    "aiglefins": "aiglefin",
    "aigles": "aigle",
    "aiglons": "aiglon",
    "aigre-douce": "aigre-doux",
    "aigrelets": "aigrelet",
    "aigrelette": "aigrelet",
    "aigrelettes": "aigrelet",
    "aigres": "aigre",
    "aigres-douces": "aigre-doux",
    "aigres-doux": "aigre-doux",
    "aigrette": "aigret",
    "aigrettes": "aigrette",
    "aigreurs": "aigreur",
    "aigri": "aigrir",
    "aigrie": "aigrir",
    "aigries": "aigrir",
    "aigrira": "aigrir",
    "aigrirai": "aigrir",
    "aigriraient": "aigrir",
    "aigrirais": "aigrir",
    "aigrirait": "aigrir",
    "aigriras": "aigrir",
    "aigrirent": "aigrir",
    "aigrirez": "aigrir",
    "aigririez": "aigrir",
    "aigririons": "aigrir",
    "aigrirons": "aigrir",
    "aigriront": "aigrir",
    "aigris": "aigrir",
    "aigrissaient": "aigrir",
    "aigrissais": "aigrir",
    "aigrissait": "aigrir",
    "aigrissant": "aigrir",
    "aigrisse": "aigrir",
    "aigrissent": "aigrir",
    "aigrisses": "aigrir",
    "aigrissez": "aigrir",
    "aigrissiez": "aigrir",
    "aigrissions": "aigrir",
    "aigrissons": "aigrir",
    "aigrit": "aigrir",
    "aigrîmes": "aigrir",
    "aigrît": "aigrir",
    "aigrîtes": "aigrir",
    "aiguails": "aiguail",
    "aigue": "aiguer",
    "aigues-marines": "aigue-marine",
    "aiguilla": "aiguiller",
    "aiguillages": "aiguillage",
    "aiguillai": "aiguiller",
    "aiguillaient": "aiguiller",
    "aiguillais": "aiguiller",
    "aiguillait": "aiguiller",
    "aiguillant": "aiguiller",
    "aiguillas": "aiguiller",
    "aiguillasse": "aiguiller",
    "aiguillassent": "aiguiller",
    "aiguillasses": "aiguiller",
    "aiguillassiez": "aiguiller",
    "aiguillassions": "aiguiller",
    "aiguille": "aiguiller",
    "aiguillent": "aiguiller",
    "aiguillera": "aiguiller",
    "aiguillerai": "aiguiller",
    "aiguilleraient": "aiguiller",
    "aiguillerais": "aiguiller",
    "aiguillerait": "aiguiller",
    "aiguilleras": "aiguiller",
    "aiguillerez": "aiguiller",
    "aiguilleriez": "aiguiller",
    "aiguillerions": "aiguiller",
    "aiguillerons": "aiguiller",
    "aiguilleront": "aiguiller",
    "aiguilles": "aiguiller",
    "aiguillettes": "aiguillette",
    "aiguilleurs": "aiguilleur",
    "aiguillez": "aiguiller",
    "aiguilliez": "aiguiller",
    "aiguillions": "aiguiller",
    "aiguillonna": "aiguillonner",
    "aiguillonnai": "aiguillonner",
    "aiguillonnaient": "aiguillonner",
    "aiguillonnais": "aiguillonner",
    "aiguillonnait": "aiguillonner",
    "aiguillonnant": "aiguillonner",
    "aiguillonnante": "aiguillonnant",
    "aiguillonnas": "aiguillonner",
    "aiguillonnasse": "aiguillonner",
    "aiguillonnassent": "aiguillonner",
    "aiguillonnasses": "aiguillonner",
    "aiguillonnassiez": "aiguillonner",
    "aiguillonnassions": "aiguillonner",
    "aiguillonne": "aiguillonner",
    "aiguillonnent": "aiguillonner",
    "aiguillonnera": "aiguillonner",
    "aiguillonnerai": "aiguillonner",
    "aiguillonneraient": "aiguillonner",
    "aiguillonnerais": "aiguillonner",
    "aiguillonnerait": "aiguillonner",
    "aiguillonneras": "aiguillonner",
    "aiguillonnerez": "aiguillonner",
    "aiguillonneriez": "aiguillonner",
    "aiguillonnerions": "aiguillonner",
    "aiguillonnerons": "aiguillonner",
    "aiguillonneront": "aiguillonner",
    "aiguillonnes": "aiguillonner",
    "aiguillonnez": "aiguillonner",
    "aiguillonniez": "aiguillonner",
    "aiguillonnions": "aiguillonner",
    "aiguillonnons": "aiguillonner",
    "aiguillonnâmes": "aiguillonner",
    "aiguillonnât": "aiguillonner",
    "aiguillonnâtes": "aiguillonner",
    "aiguillonnèrent": "aiguillonner",
    "aiguillonné": "aiguillonner",
    "aiguillonnée": "aiguillonner",
    "aiguillonnées": "aiguillonner",
    "aiguillonnés": "aiguillonner",
    "aiguillons": "aiguillon",
    "aiguillâmes": "aiguiller",
    "aiguillât": "aiguiller",
    "aiguillâtes": "aiguiller",
    "aiguillèrent": "aiguiller",
    "aiguillé": "aiguiller",
    "aiguillée": "aiguiller",
    "aiguillées": "aiguiller",
    "aiguillés": "aiguiller",
    "aiguisa": "aiguiser",
    "aiguisai": "aiguiser",
    "aiguisaient": "aiguiser",
    "aiguisais": "aiguiser",
    "aiguisait": "aiguiser",
    "aiguisant": "aiguiser",
    "aiguisas": "aiguiser",
    "aiguisasse": "aiguiser",
    "aiguisassent": "aiguiser",
    "aiguisasses": "aiguiser",
    "aiguisassiez": "aiguiser",
    "aiguisassions": "aiguiser",
    "aiguise": "aiguiser",
    "aiguisent": "aiguiser",
    "aiguisera": "aiguiser",
    "aiguiserai": "aiguiser",
    "aiguiseraient": "aiguiser",
    "aiguiserais": "aiguiser",
    "aiguiserait": "aiguiser",
    "aiguiseras": "aiguiser",
    "aiguiserez": "aiguiser",
    "aiguiseriez": "aiguiser",
    "aiguiserions": "aiguiser",
    "aiguiserons": "aiguiser",
    "aiguiseront": "aiguiser",
    "aiguises": "aiguiser",
    "aiguisez": "aiguiser",
    "aiguisiez": "aiguiser",
    "aiguisions": "aiguiser",
    "aiguisons": "aiguiser",
    "aiguisâmes": "aiguiser",
    "aiguisât": "aiguiser",
    "aiguisâtes": "aiguiser",
    "aiguisèrent": "aiguiser",
    "aiguisé": "aiguiser",
    "aiguisée": "aiguiser",
    "aiguisées": "aiguiser",
    "aiguisés": "aiguiser",
    "aigus": "aigu",
    "aiguë": "aigu",
    "aiguës": "aigu",
    "ailerons": "aileron",
    "ailes": "aile",
    "ailettes": "ailette",
    "ailiers": "ailier",
    "aillais": "ailler",
    "aille": "aller",
    "aillent": "aller",
    "ailles": "aller",
    "aillions": "ailler",
    "aillolis": "ailloli",
    "aillons": "ailler",
    "aillé": "ailler",
    "aillée": "ailler",
    "aillés": "ailler",
    "ails": "ail",
    "ailé": "ailer",
    "ailée": "ailer",
    "ailées": "ailer",
    "ailés": "ailer",
    "aima": "aimer",
    "aimables": "aimable",
    "aimai": "aimer",
    "aimaient": "aimer",
    "aimais": "aimer",
    "aimait": "aimer",
    "aimant": "aimer",
    "aimanta": "aimanter",
    "aimantai": "aimanter",
    "aimantaient": "aimanter",
    "aimantais": "aimanter",
    "aimantait": "aimanter",
    "aimantant": "aimanter",
    "aimantas": "aimanter",
    "aimantasse": "aimanter",
    "aimantassent": "aimanter",
    "aimantasses": "aimanter",
    "aimantassiez": "aimanter",
    "aimantassions": "aimanter",
    "aimante": "aimanter",
    "aimantent": "aimanter",
    "aimantera": "aimanter",
    "aimanterai": "aimanter",
    "aimanteraient": "aimanter",
    "aimanterais": "aimanter",
    "aimanterait": "aimanter",
    "aimanteras": "aimanter",
    "aimanterez": "aimanter",
    "aimanteriez": "aimanter",
    "aimanterions": "aimanter",
    "aimanterons": "aimanter",
    "aimanteront": "aimanter",
    "aimantes": "aimanter",
    "aimantez": "aimanter",
    "aimantiez": "aimanter",
    "aimantions": "aimanter",
    "aimantons": "aimanter",
    "aimants": "aimant",
    "aimantâmes": "aimanter",
    "aimantât": "aimanter",
    "aimantâtes": "aimanter",
    "aimantèrent": "aimanter",
    "aimanté": "aimanter",
    "aimantée": "aimanter",
    "aimantées": "aimanter",
    "aimantés": "aimanter",
    "aimas": "aimer",
    "aimasse": "aimer",
    "aimassent": "aimer",
    "aimasses": "aimer",
    "aimassiez": "aimer",
    "aimassions": "aimer",
    "aime": "aimer",
    "aiment": "aimer",
    "aimera": "aimer",
    "aimerai": "aimer",
    "aimeraient": "aimer",
    "aimerais": "aimer",
    "aimerait": "aimer",
    "aimeras": "aimer",
    "aimerez": "aimer",
    "aimeriez": "aimer",
    "aimerions": "aimer",
    "aimerons": "aimer",
    "aimeront": "aimer",
    "aimes": "aimer",
    "aimeuse": "aimeur",
    "aimez": "aimer",
    "aimiez": "aimer",
    "aimions": "aimer",
    "aimons": "aimer",
    "aimâmes": "aimer",
    "aimât": "aimer",
    "aimâtes": "aimer",
    "aimèrent": "aimer",
    "aimé": "aimer",
    "aimée": "aimer",
    "aimées": "aimer",
    "aimés": "aimer",
    "aine": "ain",
    "aines": "aine",
    "airains": "airain",
    "airbags": "airbag",
    "airelles": "airelle",
    "aires": "aire",
    "airs": "air",
    "aisances": "aisance",
    "aises": "aise",
    "aisselles": "aisselle",
    "aisée": "aisé",
    "aisées": "aisé",
    "aisés": "aisé",
    "ait": "avoir",
    "ajistes": "ajiste",
    "ajointée": "ajointer",
    "ajoncs": "ajonc",
    "ajoura": "ajourer",
    "ajourai": "ajourer",
    "ajouraient": "ajourer",
    "ajourais": "ajourer",
    "ajourait": "ajourer",
    "ajourant": "ajourer",
    "ajouras": "ajourer",
    "ajourasse": "ajourer",
    "ajourassent": "ajourer",
    "ajourasses": "ajourer",
    "ajourassiez": "ajourer",
    "ajourassions": "ajourer",
    "ajoure": "ajourer",
    "ajourent": "ajourer",
    "ajourera": "ajourer",
    "ajourerai": "ajourer",
    "ajoureraient": "ajourer",
    "ajourerais": "ajourer",
    "ajourerait": "ajourer",
    "ajoureras": "ajourer",
    "ajourerez": "ajourer",
    "ajoureriez": "ajourer",
    "ajourerions": "ajourer",
    "ajourerons": "ajourer",
    "ajoureront": "ajourer",
    "ajoures": "ajourer",
    "ajourez": "ajourer",
    "ajouriez": "ajourer",
    "ajourions": "ajourer",
    "ajourna": "ajourner",
    "ajournai": "ajourner",
    "ajournaient": "ajourner",
    "ajournais": "ajourner",
    "ajournait": "ajourner",
    "ajournant": "ajourner",
    "ajournas": "ajourner",
    "ajournasse": "ajourner",
    "ajournassent": "ajourner",
    "ajournasses": "ajourner",
    "ajournassiez": "ajourner",
    "ajournassions": "ajourner",
    "ajourne": "ajourner",
    "ajournements": "ajournement",
    "ajournent": "ajourner",
    "ajournera": "ajourner",
    "ajournerai": "ajourner",
    "ajourneraient": "ajourner",
    "ajournerais": "ajourner",
    "ajournerait": "ajourner",
    "ajourneras": "ajourner",
    "ajournerez": "ajourner",
    "ajourneriez": "ajourner",
    "ajournerions": "ajourner",
    "ajournerons": "ajourner",
    "ajourneront": "ajourner",
    "ajournes": "ajourner",
    "ajournez": "ajourner",
    "ajourniez": "ajourner",
    "ajournions": "ajourner",
    "ajournons": "ajourner",
    "ajournâmes": "ajourner",
    "ajournât": "ajourner",
    "ajournâtes": "ajourner",
    "ajournèrent": "ajourner",
    "ajourné": "ajourner",
    "ajournée": "ajourner",
    "ajournées": "ajourner",
    "ajournés": "ajourner",
    "ajourons": "ajourer",
    "ajours": "ajour",
    "ajourâmes": "ajourer",
    "ajourât": "ajourer",
    "ajourâtes": "ajourer",
    "ajourèrent": "ajourer",
    "ajouré": "ajourer",
    "ajourée": "ajourer",
    "ajourées": "ajourer",
    "ajourés": "ajourer",
    "ajouta": "ajouter",
    "ajoutai": "ajouter",
    "ajoutaient": "ajouter",
    "ajoutais": "ajouter",
    "ajoutait": "ajouter",
    "ajoutant": "ajouter",
    "ajoutas": "ajouter",
    "ajoutasse": "ajouter",
    "ajoutassent": "ajouter",
    "ajoutasses": "ajouter",
    "ajoutassiez": "ajouter",
    "ajoutassions": "ajouter",
    "ajoute": "ajouter",
    "ajoutent": "ajouter",
    "ajoutera": "ajouter",
    "ajouterai": "ajouter",
    "ajouteraient": "ajouter",
    "ajouterais": "ajouter",
    "ajouterait": "ajouter",
    "ajouteras": "ajouter",
    "ajouterez": "ajouter",
    "ajouteriez": "ajouter",
    "ajouterions": "ajouter",
    "ajouterons": "ajouter",
    "ajouteront": "ajouter",
    "ajoutes": "ajouter",
    "ajoutez": "ajouter",
    "ajoutiez": "ajouter",
    "ajoutions": "ajouter",
    "ajoutons": "ajouter",
    "ajouts": "ajout",
    "ajoutâmes": "ajouter",
    "ajoutât": "ajouter",
    "ajoutâtes": "ajouter",
    "ajoutèrent": "ajouter",
    "ajouté": "ajouter",
    "ajoutée": "ajouter",
    "ajoutées": "ajouter",
    "ajoutés": "ajouter",
    "ajusta": "ajuster",
    "ajustables": "ajustable",
    "ajustai": "ajuster",
    "ajustaient": "ajuster",
    "ajustais": "ajuster",
    "ajustait": "ajuster",
    "ajustant": "ajuster",
    "ajustas": "ajuster",
    "ajustasse": "ajuster",
    "ajustassent": "ajuster",
    "ajustasses": "ajuster",
    "ajustassiez": "ajuster",
    "ajustassions": "ajuster",
    "ajuste": "ajuster",
    "ajustements": "ajustement",
    "ajustent": "ajuster",
    "ajustera": "ajuster",
    "ajusterai": "ajuster",
    "ajusteraient": "ajuster",
    "ajusterais": "ajuster",
    "ajusterait": "ajuster",
    "ajusteras": "ajuster",
    "ajusterez": "ajuster",
    "ajusteriez": "ajuster",
    "ajusterions": "ajuster",
    "ajusterons": "ajuster",
    "ajusteront": "ajuster",
    "ajustes": "ajuster",
    "ajusteurs": "ajusteur",
    "ajustez": "ajuster",
    "ajustiez": "ajuster",
    "ajustions": "ajuster",
    "ajustons": "ajuster",
    "ajustâmes": "ajuster",
    "ajustât": "ajuster",
    "ajustâtes": "ajuster",
    "ajustèrent": "ajuster",
    "ajusté": "ajuster",
    "ajustée": "ajuster",
    "ajustées": "ajuster",
    "ajustés": "ajuster",
    "alabandines": "alabandine",
    "alacrités": "alacrité",
    "alaises": "alaise",
    "alambics": "alambic",
    "alambiqué": "alambiquer",
    "alambiquée": "alambiquer",
    "alambiquées": "alambiqué",
    "alambiqués": "alambiqué",
    "alangui": "alanguir",
    "alanguie": "alanguir",
    "alanguies": "alanguir",
    "alanguira": "alanguir",
    "alanguirai": "alanguir",
    "alanguiraient": "alanguir",
    "alanguirais": "alanguir",
    "alanguirait": "alanguir",
    "alanguiras": "alanguir",
    "alanguirent": "alanguir",
    "alanguirez": "alanguir",
    "alanguiriez": "alanguir",
    "alanguirions": "alanguir",
    "alanguirons": "alanguir",
    "alanguiront": "alanguir",
    "alanguis": "alanguir",
    "alanguissaient": "alanguir",
    "alanguissais": "alanguir",
    "alanguissait": "alanguir",
    "alanguissant": "alanguir",
    "alanguissante": "alanguissant",
    "alanguisse": "alanguir",
    "alanguissements": "alanguissement",
    "alanguissent": "alanguir",
    "alanguisses": "alanguir",
    "alanguissez": "alanguir",
    "alanguissiez": "alanguir",
    "alanguissions": "alanguir",
    "alanguissons": "alanguir",
    "alanguit": "alanguir",
    "alanguîmes": "alanguir",
    "alanguît": "alanguir",
    "alanguîtes": "alanguir",
    "alarma": "alarmer",
    "alarmai": "alarmer",
    "alarmaient": "alarmer",
    "alarmais": "alarmer",
    "alarmait": "alarmer",
    "alarmant": "alarmer",
    "alarmante": "alarmant",
    "alarmantes": "alarmant",
    "alarmants": "alarmant",
    "alarmas": "alarmer",
    "alarmasse": "alarmer",
    "alarmassent": "alarmer",
    "alarmasses": "alarmer",
    "alarmassiez": "alarmer",
    "alarmassions": "alarmer",
    "alarme": "alarmer",
    "alarment": "alarmer",
    "alarmera": "alarmer",
    "alarmerai": "alarmer",
    "alarmeraient": "alarmer",
    "alarmerais": "alarmer",
    "alarmerait": "alarmer",
    "alarmeras": "alarmer",
    "alarmerez": "alarmer",
    "alarmeriez": "alarmer",
    "alarmerions": "alarmer",
    "alarmerons": "alarmer",
    "alarmeront": "alarmer",
    "alarmes": "alarmer",
    "alarmez": "alarmer",
    "alarmiez": "alarmer",
    "alarmions": "alarmer",
    "alarmistes": "alarmiste",
    "alarmons": "alarmer",
    "alarmâmes": "alarmer",
    "alarmât": "alarmer",
    "alarmâtes": "alarmer",
    "alarmèrent": "alarmer",
    "alarmé": "alarmer",
    "alarmée": "alarmer",
    "alarmées": "alarmer",
    "alarmés": "alarmer",
    "albanaise": "albanais",
    "albanaises": "albanais",
    "alberges": "alberge",
    "albumens": "albumen",
    "albumines": "albumine",
    "albumineuse": "albumineux",
    "albuminuries": "albuminurie",
    "albums": "album",
    "albâtres": "albâtre",
    "alcades": "alcade",
    "alcaline": "alcalin",
    "alcalines": "alcalin",
    "alcalins": "alcalin",
    "alcalis": "alcali",
    "alchimies": "alchimie",
    "alchimiques": "alchimique",
    "alchimistes": "alchimiste",
    "alcooliques": "alcoolique",
    "alcoolisa": "alcooliser",
    "alcoolisai": "alcooliser",
    "alcoolisaient": "alcooliser",
    "alcoolisais": "alcooliser",
    "alcoolisait": "alcooliser",
    "alcoolisant": "alcooliser",
    "alcoolisas": "alcooliser",
    "alcoolisasse": "alcooliser",
    "alcoolisassent": "alcooliser",
    "alcoolisasses": "alcooliser",
    "alcoolisassiez": "alcooliser",
    "alcoolisassions": "alcooliser",
    "alcoolisations": "alcoolisation",
    "alcoolise": "alcooliser",
    "alcoolisent": "alcooliser",
    "alcoolisera": "alcooliser",
    "alcooliserai": "alcooliser",
    "alcooliseraient": "alcooliser",
    "alcooliserais": "alcooliser",
    "alcooliserait": "alcooliser",
    "alcooliseras": "alcooliser",
    "alcooliserez": "alcooliser",
    "alcooliseriez": "alcooliser",
    "alcooliserions": "alcooliser",
    "alcooliserons": "alcooliser",
    "alcooliseront": "alcooliser",
    "alcoolises": "alcooliser",
    "alcoolisez": "alcooliser",
    "alcoolisiez": "alcooliser",
    "alcoolisions": "alcooliser",
    "alcoolismes": "alcoolisme",
    "alcoolisons": "alcooliser",
    "alcoolisâmes": "alcooliser",
    "alcoolisât": "alcooliser",
    "alcoolisâtes": "alcooliser",
    "alcoolisèrent": "alcooliser",
    "alcoolisé": "alcooliser",
    "alcoolisée": "alcooliser",
    "alcoolisées": "alcooliser",
    "alcoolisés": "alcooliser",
    "alcoolos": "alcoolo",
    "alcools": "alcool",
    "alcoométriques": "alcoométrique",
    "alcyons": "alcyon",
    "alcées": "alcée",
    "alcôves": "alcôve",
    "aldéhydes": "aldéhyde",
    "alenti": "alentir",
    "alentie": "alentir",
    "alenties": "alentir",
    "alentis": "alentir",
    "alentours": "alentour",
    "alençonnaise": "alençonnais",
    "alerta": "alerter",
    "alertai": "alerter",
    "alertaient": "alerter",
    "alertais": "alerter",
    "alertait": "alerter",
    "alertant": "alerter",
    "alertas": "alerter",
    "alertasse": "alerter",
    "alertassent": "alerter",
    "alertasses": "alerter",
    "alertassiez": "alerter",
    "alertassions": "alerter",
    "alerte": "alerter",
    "alertent": "alerter",
    "alertera": "alerter",
    "alerterai": "alerter",
    "alerteraient": "alerter",
    "alerterais": "alerter",
    "alerterait": "alerter",
    "alerteras": "alerter",
    "alerterez": "alerter",
    "alerteriez": "alerter",
    "alerterions": "alerter",
    "alerterons": "alerter",
    "alerteront": "alerter",
    "alertes": "alerter",
    "alertez": "alerter",
    "alertiez": "alerter",
    "alertions": "alerter",
    "alertons": "alerter",
    "alertâmes": "alerter",
    "alertât": "alerter",
    "alertâtes": "alerter",
    "alertèrent": "alerter",
    "alerté": "alerter",
    "alertée": "alerter",
    "alertées": "alerter",
    "alertés": "alerter",
    "alevins": "alevin",
    "alexandrine": "alexandrin",
    "alexandrines": "alexandrin",
    "alexandrins": "alexandrin",
    "alezane": "alezan",
    "alezanes": "alezan",
    "alezans": "alezan",
    "alfanges": "alfange",
    "alfas": "alfa",
    "alfénides": "alfénide",
    "algarades": "algarade",
    "algonquines": "algonquin",
    "algorithmes": "algorithme",
    "alguazils": "alguazil",
    "algues": "algue",
    "algèbres": "algèbre",
    "algébriques": "algébrique",
    "algébristes": "algébriste",
    "algérienne": "algérien",
    "algériennes": "algérien",
    "algériens": "algérien",
    "algéroise": "algérois",
    "alibis": "alibi",
    "alidades": "alidade",
    "aligna": "aligner",
    "alignai": "aligner",
    "alignaient": "aligner",
    "alignais": "aligner",
    "alignait": "aligner",
    "alignant": "aligner",
    "alignas": "aligner",
    "alignasse": "aligner",
    "alignassent": "aligner",
    "alignasses": "aligner",
    "alignassiez": "aligner",
    "alignassions": "aligner",
    "aligne": "aligner",
    "alignements": "alignement",
    "alignent": "aligner",
    "alignera": "aligner",
    "alignerai": "aligner",
    "aligneraient": "aligner",
    "alignerais": "aligner",
    "alignerait": "aligner",
    "aligneras": "aligner",
    "alignerez": "aligner",
    "aligneriez": "aligner",
    "alignerions": "aligner",
    "alignerons": "aligner",
    "aligneront": "aligner",
    "alignes": "aligner",
    "alignez": "aligner",
    "aligniez": "aligner",
    "alignions": "aligner",
    "alignons": "aligner",
    "alignâmes": "aligner",
    "alignât": "aligner",
    "alignâtes": "aligner",
    "alignèrent": "aligner",
    "aligné": "aligner",
    "alignée": "aligner",
    "alignées": "aligner",
    "alignés": "aligner",
    "alimenta": "alimenter",
    "alimentai": "alimenter",
    "alimentaient": "alimenter",
    "alimentaires": "alimentaire",
    "alimentais": "alimenter",
    "alimentait": "alimenter",
    "alimentant": "alimenter",
    "alimentas": "alimenter",
    "alimentasse": "alimenter",
    "alimentassent": "alimenter",
    "alimentasses": "alimenter",
    "alimentassiez": "alimenter",
    "alimentassions": "alimenter",
    "alimentations": "alimentation",
    "alimente": "alimenter",
    "alimentent": "alimenter",
    "alimentera": "alimenter",
    "alimenterai": "alimenter",
    "alimenteraient": "alimenter",
    "alimenterais": "alimenter",
    "alimenterait": "alimenter",
    "alimenteras": "alimenter",
    "alimenterez": "alimenter",
    "alimenteriez": "alimenter",
    "alimenterions": "alimenter",
    "alimenterons": "alimenter",
    "alimenteront": "alimenter",
    "alimentes": "alimenter",
    "alimentez": "alimenter",
    "alimentiez": "alimenter",
    "alimentions": "alimenter",
    "alimentons": "alimenter",
    "aliments": "aliment",
    "alimentâmes": "alimenter",
    "alimentât": "alimenter",
    "alimentâtes": "alimenter",
    "alimentèrent": "alimenter",
    "alimenté": "alimenter",
    "alimentée": "alimenter",
    "alimentées": "alimenter",
    "alimentés": "alimenter",
    "alinéas": "alinéa",
    "alises": "alise",
    "alita": "aliter",
    "alitai": "aliter",
    "alitaient": "aliter",
    "alitais": "aliter",
    "alitait": "aliter",
    "alitant": "aliter",
    "alitas": "aliter",
    "alitasse": "aliter",
    "alitassent": "aliter",
    "alitasses": "aliter",
    "alitassiez": "aliter",
    "alitassions": "aliter",
    "alite": "aliter",
    "alitent": "aliter",
    "alitera": "aliter",
    "aliterai": "aliter",
    "aliteraient": "aliter",
    "aliterais": "aliter",
    "aliterait": "aliter",
    "aliteras": "aliter",
    "aliterez": "aliter",
    "aliteriez": "aliter",
    "aliterions": "aliter",
    "aliterons": "aliter",
    "aliteront": "aliter",
    "alites": "aliter",
    "alitez": "aliter",
    "alitiez": "aliter",
    "alitions": "aliter",
    "alitons": "aliter",
    "alitâmes": "aliter",
    "alitât": "aliter",
    "alitâtes": "aliter",
    "alitèrent": "aliter",
    "alité": "aliter",
    "alitée": "aliter",
    "alitées": "aliter",
    "alités": "aliter",
    "alizés": "alizé",
    "aliène": "aliéner",
    "aliènent": "aliéner",
    "aliènes": "aliéner",
    "aliéna": "aliéner",
    "aliénai": "aliéner",
    "aliénaient": "aliéner",
    "aliénais": "aliéner",
    "aliénait": "aliéner",
    "aliénant": "aliéner",
    "aliénante": "aliénant",
    "aliénas": "aliéner",
    "aliénasse": "aliéner",
    "aliénassent": "aliéner",
    "aliénasses": "aliéner",
    "aliénassiez": "aliéner",
    "aliénassions": "aliéner",
    "aliénations": "aliénation",
    "aliénera": "aliéner",
    "aliénerai": "aliéner",
    "aliéneraient": "aliéner",
    "aliénerais": "aliéner",
    "aliénerait": "aliéner",
    "aliéneras": "aliéner",
    "aliénerez": "aliéner",
    "aliéneriez": "aliéner",
    "aliénerions": "aliéner",
    "aliénerons": "aliéner",
    "aliéneront": "aliéner",
    "aliénez": "aliéner",
    "aliéniez": "aliéner",
    "aliénions": "aliéner",
    "aliénons": "aliéner",
    "aliénâmes": "aliéner",
    "aliénât": "aliéner",
    "aliénâtes": "aliéner",
    "aliénèrent": "aliéner",
    "aliéné": "aliéner",
    "aliénée": "aliéner",
    "aliénées": "aliéner",
    "aliénés": "aliéner",
    "alla": "aller",
    "allai": "aller",
    "allaient": "aller",
    "allais": "aller",
    "allait": "aller",
    "allaita": "allaiter",
    "allaitai": "allaiter",
    "allaitaient": "allaiter",
    "allaitais": "allaiter",
    "allaitait": "allaiter",
    "allaitant": "allaiter",
    "allaitante": "allaitant",
    "allaitantes": "allaitant",
    "allaitants": "allaitant",
    "allaitas": "allaiter",
    "allaitasse": "allaiter",
    "allaitassent": "allaiter",
    "allaitasses": "allaiter",
    "allaitassiez": "allaiter",
    "allaitassions": "allaiter",
    "allaite": "allaiter",
    "allaitent": "allaiter",
    "allaitera": "allaiter",
    "allaiterai": "allaiter",
    "allaiteraient": "allaiter",
    "allaiterais": "allaiter",
    "allaiterait": "allaiter",
    "allaiteras": "allaiter",
    "allaiterez": "allaiter",
    "allaiteriez": "allaiter",
    "allaiterions": "allaiter",
    "allaiterons": "allaiter",
    "allaiteront": "allaiter",
    "allaites": "allaiter",
    "allaitez": "allaiter",
    "allaitiez": "allaiter",
    "allaitions": "allaiter",
    "allaitons": "allaiter",
    "allaitâmes": "allaiter",
    "allaitât": "allaiter",
    "allaitâtes": "allaiter",
    "allaitèrent": "allaiter",
    "allaité": "allaiter",
    "allaitée": "allaiter",
    "allaitées": "allaiter",
    "allaités": "allaiter",
    "allant": "aller",
    "allante": "allant",
    "allants": "allant",
    "allas": "aller",
    "allasse": "aller",
    "allassent": "aller",
    "allasses": "aller",
    "allassiez": "aller",
    "allassions": "aller",
    "allemande": "allemand",
    "allemandes": "allemand",
    "allemands": "allemand",
    "allergies": "allergie",
    "allergiques": "allergique",
    "allergènes": "allergène",
    "allers": "aller",
    "allers-retours": "aller-retour",
    "alleux": "alleu",
    "allez": "aller",
    "allia": "allier",
    "alliacée": "alliacé",
    "alliacées": "alliacé",
    "alliacés": "alliacé",
    "alliages": "alliage",
    "alliai": "allier",
    "alliaient": "allier",
    "alliais": "allier",
    "alliait": "allier",
    "alliances": "alliance",
    "alliant": "allier",
    "allias": "allier",
    "alliasse": "allier",
    "alliassent": "allier",
    "alliasses": "allier",
    "alliassiez": "allier",
    "alliassions": "allier",
    "allie": "allier",
    "allient": "allier",
    "allier": "aller",
    "alliera": "allier",
    "allierai": "allier",
    "allieraient": "allier",
    "allierais": "allier",
    "allierait": "allier",
    "allieras": "allier",
    "allierez": "allier",
    "allieriez": "allier",
    "allierions": "allier",
    "allierons": "allier",
    "allieront": "allier",
    "allies": "allier",
    "alliez": "allier",
    "alligators": "alligator",
    "alliiez": "allier",
    "alliions": "allier",
    "allions": "allier",
    "allitérations": "allitération",
    "alliâmes": "allier",
    "alliât": "allier",
    "alliâtes": "allier",
    "allièrent": "allier",
    "allié": "allier",
    "alliée": "allier",
    "alliées": "allier",
    "alliés": "allier",
    "allobroges": "allobroge",
    "allocataires": "allocataire",
    "allocations": "allocation",
    "allocs": "alloc",
    "allocutions": "allocution",
    "allogènes": "allogène",
    "allonge": "allonger",
    "allongea": "allonger",
    "allongeai": "allonger",
    "allongeaient": "allonger",
    "allongeais": "allonger",
    "allongeait": "allonger",
    "allongeant": "allonger",
    "allongeas": "allonger",
    "allongeasse": "allonger",
    "allongeassent": "allonger",
    "allongeasses": "allonger",
    "allongeassiez": "allonger",
    "allongeassions": "allonger",
    "allongements": "allongement",
    "allongent": "allonger",
    "allongeons": "allonger",
    "allongera": "allonger",
    "allongerai": "allonger",
    "allongeraient": "allonger",
    "allongerais": "allonger",
    "allongerait": "allonger",
    "allongeras": "allonger",
    "allongerez": "allonger",
    "allongeriez": "allonger",
    "allongerions": "allonger",
    "allongerons": "allonger",
    "allongeront": "allonger",
    "allonges": "allonger",
    "allongez": "allonger",
    "allongeâmes": "allonger",
    "allongeât": "allonger",
    "allongeâtes": "allonger",
    "allongiez": "allonger",
    "allongions": "allonger",
    "allongèrent": "allonger",
    "allongé": "allonger",
    "allongée": "allonger",
    "allongées": "allonger",
    "allongés": "allonger",
    "allons": "aller",
    "alloua": "allouer",
    "allouai": "allouer",
    "allouaient": "allouer",
    "allouais": "allouer",
    "allouait": "allouer",
    "allouant": "allouer",
    "allouas": "allouer",
    "allouasse": "allouer",
    "allouassent": "allouer",
    "allouasses": "allouer",
    "allouassiez": "allouer",
    "allouassions": "allouer",
    "alloue": "allouer",
    "allouent": "allouer",
    "allouera": "allouer",
    "allouerai": "allouer",
    "alloueraient": "allouer",
    "allouerais": "allouer",
    "allouerait": "allouer",
    "alloueras": "allouer",
    "allouerez": "allouer",
    "alloueriez": "allouer",
    "allouerions": "allouer",
    "allouerons": "allouer",
    "alloueront": "allouer",
    "alloues": "allouer",
    "allouez": "allouer",
    "allouiez": "allouer",
    "allouions": "allouer",
    "allouons": "allouer",
    "allouâmes": "allouer",
    "allouât": "allouer",
    "allouâtes": "allouer",
    "allouèrent": "allouer",
    "alloué": "allouer",
    "allouée": "allouer",
    "allouées": "allouer",
    "alloués": "allouer",
    "alluma": "allumer",
    "allumages": "allumage",
    "allumai": "allumer",
    "allumaient": "allumer",
    "allumais": "allumer",
    "allumait": "allumer",
    "allumant": "allumer",
    "allumas": "allumer",
    "allumasse": "allumer",
    "allumassent": "allumer",
    "allumasses": "allumer",
    "allumassiez": "allumer",
    "allumassions": "allumer",
    "allume": "allumer",
    "allument": "allumer",
    "allumera": "allumer",
    "allumerai": "allumer",
    "allumeraient": "allumer",
    "allumerais": "allumer",
    "allumerait": "allumer",
    "allumeras": "allumer",
    "allumerez": "allumer",
    "allumeriez": "allumer",
    "allumerions": "allumer",
    "allumerons": "allumer",
    "allumeront": "allumer",
    "allumes": "allumer",
    "allumettes": "allumette",
    "allumeurs": "allumeur",
    "allumeuse": "allumeur",
    "allumeuses": "allumeur",
    "allumez": "allumer",
    "allumiez": "allumer",
    "allumions": "allumer",
    "allumons": "allumer",
    "allumâmes": "allumer",
    "allumât": "allumer",
    "allumâtes": "allumer",
    "allumèrent": "allumer",
    "allumé": "allumer",
    "allumée": "allumer",
    "allumées": "allumer",
    "allumés": "allumer",
    "allures": "allure",
    "allusifs": "allusif",
    "allusionne": "allusionner",
    "allusions": "allusion",
    "allusive": "allusif",
    "allusives": "allusif",
    "alluviale": "alluvial",
    "alluviales": "alluvial",
    "alluviaux": "alluvial",
    "alluvions": "alluvion",
    "allâmes": "aller",
    "allât": "aller",
    "allâtes": "aller",
    "allèche": "allécher",
    "allèchent": "allécher",
    "allèches": "allécher",
    "allège": "alléger",
    "allègements": "allègement",
    "allègent": "alléger",
    "allèges": "alléger",
    "allègres": "allègre",
    "allègue": "alléguer",
    "allèguent": "alléguer",
    "allègues": "alléguer",
    "allènes": "allène",
    "allèrent": "aller",
    "allé": "aller",
    "allécha": "allécher",
    "alléchai": "allécher",
    "alléchaient": "allécher",
    "alléchais": "allécher",
    "alléchait": "allécher",
    "alléchant": "allécher",
    "alléchante": "alléchant",
    "alléchantes": "alléchant",
    "alléchants": "alléchant",
    "alléchas": "allécher",
    "alléchasse": "allécher",
    "alléchassent": "allécher",
    "alléchasses": "allécher",
    "alléchassiez": "allécher",
    "alléchassions": "allécher",
    "alléchera": "allécher",
    "allécherai": "allécher",
    "allécheraient": "allécher",
    "allécherais": "allécher",
    "allécherait": "allécher",
    "allécheras": "allécher",
    "allécherez": "allécher",
    "allécheriez": "allécher",
    "allécherions": "allécher",
    "allécherons": "allécher",
    "allécheront": "allécher",
    "alléchez": "allécher",
    "alléchiez": "allécher",
    "alléchions": "allécher",
    "alléchons": "allécher",
    "alléchâmes": "allécher",
    "alléchât": "allécher",
    "alléchâtes": "allécher",
    "alléchèrent": "allécher",
    "alléché": "allécher",
    "alléchée": "allécher",
    "alléchées": "allécher",
    "alléchés": "allécher",
    "allée": "aller",
    "allées": "aller",
    "allégations": "allégation",
    "allégea": "alléger",
    "allégeai": "alléger",
    "allégeaient": "alléger",
    "allégeais": "alléger",
    "allégeait": "alléger",
    "allégeances": "allégeance",
    "allégeant": "alléger",
    "allégeas": "alléger",
    "allégeasse": "alléger",
    "allégeassent": "alléger",
    "allégeasses": "alléger",
    "allégeassiez": "alléger",
    "allégeassions": "alléger",
    "allégements": "allégement",
    "allégeons": "alléger",
    "allégera": "alléger",
    "allégerai": "alléger",
    "allégeraient": "alléger",
    "allégerais": "alléger",
    "allégerait": "alléger",
    "allégeras": "alléger",
    "allégerez": "alléger",
    "allégeriez": "alléger",
    "allégerions": "alléger",
    "allégerons": "alléger",
    "allégeront": "alléger",
    "allégez": "alléger",
    "allégeâmes": "alléger",
    "allégeât": "alléger",
    "allégeâtes": "alléger",
    "allégi": "allégir",
    "allégie": "allégir",
    "allégies": "allégir",
    "allégiez": "alléger",
    "allégions": "alléger",
    "allégira": "allégir",
    "allégirai": "allégir",
    "allégiraient": "allégir",
    "allégirais": "allégir",
    "allégirait": "allégir",
    "allégiras": "allégir",
    "allégirent": "allégir",
    "allégirez": "allégir",
    "allégiriez": "allégir",
    "allégirions": "allégir",
    "allégirons": "allégir",
    "allégiront": "allégir",
    "allégis": "allégir",
    "allégissaient": "allégir",
    "allégissais": "allégir",
    "allégissait": "allégir",
    "allégissant": "allégir",
    "allégisse": "allégir",
    "allégissent": "allégir",
    "allégisses": "allégir",
    "allégissez": "allégir",
    "allégissiez": "allégir",
    "allégissions": "allégir",
    "allégissons": "allégir",
    "allégit": "allégir",
    "allégories": "allégorie",
    "allégoriques": "allégorique",
    "allégorisé": "allégoriser",
    "allégresses": "allégresse",
    "allégrettos": "allégretto",
    "allégros": "allégro",
    "allégua": "alléguer",
    "alléguai": "alléguer",
    "alléguaient": "alléguer",
    "alléguais": "alléguer",
    "alléguait": "alléguer",
    "alléguant": "alléguer",
    "alléguas": "alléguer",
    "alléguasse": "alléguer",
    "alléguassent": "alléguer",
    "alléguasses": "alléguer",
    "alléguassiez": "alléguer",
    "alléguassions": "alléguer",
    "alléguera": "alléguer",
    "alléguerai": "alléguer",
    "allégueraient": "alléguer",
    "alléguerais": "alléguer",
    "alléguerait": "alléguer",
    "allégueras": "alléguer",
    "alléguerez": "alléguer",
    "allégueriez": "alléguer",
    "alléguerions": "alléguer",
    "alléguerons": "alléguer",
    "allégueront": "alléguer",
    "alléguez": "alléguer",
    "alléguiez": "alléguer",
    "alléguions": "alléguer",
    "alléguons": "alléguer",
    "alléguâmes": "alléguer",
    "alléguât": "alléguer",
    "alléguâtes": "alléguer",
    "alléguèrent": "alléguer",
    "allégué": "alléguer",
    "alléguée": "alléguer",
    "alléguées": "alléguer",
    "allégués": "alléguer",
    "allégèrent": "alléger",
    "allégé": "alléger",
    "allégée": "alléger",
    "allégées": "alléger",
    "allégés": "alléger",
    "allégîmes": "allégir",
    "allégît": "allégir",
    "allégîtes": "allégir",
    "alléluias": "alléluia",
    "allés": "aller",
    "almanachs": "almanach",
    "almeydistes": "almeydiste",
    "almohades": "almohade",
    "almées": "almée",
    "alois": "aloi",
    "alopécies": "alopécie",
    "aloses": "alose",
    "alouates": "alouate",
    "alouettes": "alouette",
    "alourdi": "alourdir",
    "alourdie": "alourdir",
    "alourdies": "alourdir",
    "alourdira": "alourdir",
    "alourdirai": "alourdir",
    "alourdiraient": "alourdir",
    "alourdirais": "alourdir",
    "alourdirait": "alourdir",
    "alourdiras": "alourdir",
    "alourdirent": "alourdir",
    "alourdirez": "alourdir",
    "alourdiriez": "alourdir",
    "alourdirions": "alourdir",
    "alourdirons": "alourdir",
    "alourdiront": "alourdir",
    "alourdis": "alourdir",
    "alourdissaient": "alourdir",
    "alourdissais": "alourdir",
    "alourdissait": "alourdir",
    "alourdissant": "alourdir",
    "alourdisse": "alourdir",
    "alourdissements": "alourdissement",
    "alourdissent": "alourdir",
    "alourdisses": "alourdir",
    "alourdissez": "alourdir",
    "alourdissiez": "alourdir",
    "alourdissions": "alourdir",
    "alourdissons": "alourdir",
    "alourdit": "alourdir",
    "alourdîmes": "alourdir",
    "alourdît": "alourdir",
    "alourdîtes": "alourdir",
    "aloyaux": "aloyau",
    "alpa": "alper",
    "alpagas": "alpaga",
    "alpages": "alpage",
    "alpaguait": "alpaguer",
    "alpague": "alpaguer",
    "alpaguent": "alpaguer",
    "alpaguerait": "alpaguer",
    "alpagué": "alpaguer",
    "alpaguée": "alpaguer",
    "alpagués": "alpaguer",
    "alpes": "alpe",
    "alpestres": "alpestre",
    "alphabets": "alphabet",
    "alphabétiques": "alphabétique",
    "alphabétisa": "alphabétiser",
    "alphabétisai": "alphabétiser",
    "alphabétisaient": "alphabétiser",
    "alphabétisais": "alphabétiser",
    "alphabétisait": "alphabétiser",
    "alphabétisant": "alphabétiser",
    "alphabétisas": "alphabétiser",
    "alphabétisasse": "alphabétiser",
    "alphabétisassent": "alphabétiser",
    "alphabétisasses": "alphabétiser",
    "alphabétisassiez": "alphabétiser",
    "alphabétisassions": "alphabétiser",
    "alphabétisations": "alphabétisation",
    "alphabétise": "alphabétiser",
    "alphabétisent": "alphabétiser",
    "alphabétisera": "alphabétiser",
    "alphabétiserai": "alphabétiser",
    "alphabétiseraient": "alphabétiser",
    "alphabétiserais": "alphabétiser",
    "alphabétiserait": "alphabétiser",
    "alphabétiseras": "alphabétiser",
    "alphabétiserez": "alphabétiser",
    "alphabétiseriez": "alphabétiser",
    "alphabétiserions": "alphabétiser",
    "alphabétiserons": "alphabétiser",
    "alphabétiseront": "alphabétiser",
    "alphabétises": "alphabétiser",
    "alphabétisez": "alphabétiser",
    "alphabétisiez": "alphabétiser",
    "alphabétisions": "alphabétiser",
    "alphabétisons": "alphabétiser",
    "alphabétisâmes": "alphabétiser",
    "alphabétisât": "alphabétiser",
    "alphabétisâtes": "alphabétiser",
    "alphabétisèrent": "alphabétiser",
    "alphabétisé": "alphabétiser",
    "alphabétisée": "alphabétiser",
    "alphabétisées": "alphabétiser",
    "alphabétisés": "alphabétiser",
    "alphas": "alpha",
    "alpine": "alpin",
    "alpines": "alpin",
    "alpinismes": "alpinisme",
    "alpinistes": "alpiniste",
    "alpins": "alpin",
    "alpistes": "alpiste",
    "alsacienne": "alsacien",
    "alsaciennes": "alsacien",
    "alsaciens": "alsacien",
    "altercations": "altercation",
    "alterna": "alterner",
    "alternai": "alterner",
    "alternaient": "alterner",
    "alternais": "alterner",
    "alternait": "alterner",
    "alternances": "alternance",
    "alternant": "alterner",
    "alternas": "alterner",
    "alternasse": "alterner",
    "alternassent": "alterner",
    "alternasses": "alterner",
    "alternassiez": "alterner",
    "alternassions": "alterner",
    "alternateurs": "alternateur",
    "alternatifs": "alternatif",
    "alternative": "alternatif",
    "alternatives": "alternative",
    "alterne": "alterner",
    "alternent": "alterner",
    "alternera": "alterner",
    "alternerai": "alterner",
    "alterneraient": "alterner",
    "alternerais": "alterner",
    "alternerait": "alterner",
    "alterneras": "alterner",
    "alternerez": "alterner",
    "alterneriez": "alterner",
    "alternerions": "alterner",
    "alternerons": "alterner",
    "alterneront": "alterner",
    "alternes": "alterner",
    "alternez": "alterner",
    "alterniez": "alterner",
    "alternions": "alterner",
    "alternons": "alterner",
    "alternâmes": "alterner",
    "alternât": "alterner",
    "alternâtes": "alterner",
    "alternèrent": "alterner",
    "alterné": "alterner",
    "alternée": "alterner",
    "alternées": "alterner",
    "alternés": "alterner",
    "altesses": "altesse",
    "altiers": "altier",
    "altimètres": "altimètre",
    "altises": "altise",
    "altitudes": "altitude",
    "altière": "altier",
    "altières": "altier",
    "altos": "alto",
    "altruismes": "altruisme",
    "altruistes": "altruiste",
    "altère": "altérer",
    "altèrent": "altérer",
    "altères": "altérer",
    "altéra": "altérer",
    "altérai": "altérer",
    "altéraient": "altérer",
    "altérais": "altérer",
    "altérait": "altérer",
    "altérant": "altérer",
    "altéras": "altérer",
    "altérasse": "altérer",
    "altérassent": "altérer",
    "altérasses": "altérer",
    "altérassiez": "altérer",
    "altérassions": "altérer",
    "altérations": "altération",
    "altérera": "altérer",
    "altérerai": "altérer",
    "altéreraient": "altérer",
    "altérerais": "altérer",
    "altérerait": "altérer",
    "altéreras": "altérer",
    "altérerez": "altérer",
    "altéreriez": "altérer",
    "altérerions": "altérer",
    "altérerons": "altérer",
    "altéreront": "altérer",
    "altérez": "altérer",
    "altériez": "altérer",
    "altérions": "altérer",
    "altérités": "altérité",
    "altérons": "altérer",
    "altérâmes": "altérer",
    "altérât": "altérer",
    "altérâtes": "altérer",
    "altérèrent": "altérer",
    "altéré": "altérer",
    "altérée": "altérer",
    "altérées": "altérer",
    "altérés": "altérer",
    "aludes": "alude",
    "alumines": "alumine",
    "aluminiums": "aluminium",
    "aluni": "alunir",
    "alunie": "alunir",
    "alunies": "alunir",
    "alunira": "alunir",
    "alunirai": "alunir",
    "aluniraient": "alunir",
    "alunirais": "alunir",
    "alunirait": "alunir",
    "aluniras": "alunir",
    "alunirent": "alunir",
    "alunirez": "alunir",
    "aluniriez": "alunir",
    "alunirions": "alunir",
    "alunirons": "alunir",
    "aluniront": "alunir",
    "alunis": "alunir",
    "alunissages": "alunissage",
    "alunissaient": "alunir",
    "alunissais": "alunir",
    "alunissait": "alunir",
    "alunissant": "alunir",
    "alunisse": "alunir",
    "alunissent": "alunir",
    "alunisses": "alunir",
    "alunissez": "alunir",
    "alunissiez": "alunir",
    "alunissions": "alunir",
    "alunissons": "alunir",
    "alunit": "alunir",
    "aluns": "alun",
    "alunîmes": "alunir",
    "alunît": "alunir",
    "alunîtes": "alunir",
    "alvéoles": "alvéole",
    "alvéolée": "alvéolé",
    "alvéolées": "alvéolé",
    "alvéolés": "alvéolé",
    "alèse": "aléser",
    "alèsent": "aléser",
    "alèses": "aléser",
    "aléas": "aléa",
    "aléatoires": "aléatoire",
    "alémaniques": "alémanique",
    "alésa": "aléser",
    "alésai": "aléser",
    "alésaient": "aléser",
    "alésais": "aléser",
    "alésait": "aléser",
    "alésant": "aléser",
    "alésas": "aléser",
    "alésasse": "aléser",
    "alésassent": "aléser",
    "alésasses": "aléser",
    "alésassiez": "aléser",
    "alésassions": "aléser",
    "alésera": "aléser",
    "aléserai": "aléser",
    "aléseraient": "aléser",
    "aléserais": "aléser",
    "aléserait": "aléser",
    "aléseras": "aléser",
    "aléserez": "aléser",
    "aléseriez": "aléser",
    "aléserions": "aléser",
    "aléserons": "aléser",
    "aléseront": "aléser",
    "alésez": "aléser",
    "alésiez": "aléser",
    "alésions": "aléser",
    "alésons": "aléser",
    "alésâmes": "aléser",
    "alésât": "aléser",
    "alésâtes": "aléser",
    "alésèrent": "aléser",
    "alésé": "aléser",
    "alésée": "aléser",
    "alésées": "aléser",
    "alésés": "aléser",
    "alênes": "alêne",
    "amabilités": "amabilité",
    "amadoua": "amadouer",
    "amadouai": "amadouer",
    "amadouaient": "amadouer",
    "amadouais": "amadouer",
    "amadouait": "amadouer",
    "amadouant": "amadouer",
    "amadouas": "amadouer",
    "amadouasse": "amadouer",
    "amadouassent": "amadouer",
    "amadouasses": "amadouer",
    "amadouassiez": "amadouer",
    "amadouassions": "amadouer",
    "amadoue": "amadouer",
    "amadouent": "amadouer",
    "amadouera": "amadouer",
    "amadouerai": "amadouer",
    "amadoueraient": "amadouer",
    "amadouerais": "amadouer",
    "amadouerait": "amadouer",
    "amadoueras": "amadouer",
    "amadouerez": "amadouer",
    "amadoueriez": "amadouer",
    "amadouerions": "amadouer",
    "amadouerons": "amadouer",
    "amadoueront": "amadouer",
    "amadoues": "amadouer",
    "amadouez": "amadouer",
    "amadouiez": "amadouer",
    "amadouions": "amadouer",
    "amadouons": "amadouer",
    "amadous": "amadou",
    "amadouviers": "amadouvier",
    "amadouâmes": "amadouer",
    "amadouât": "amadouer",
    "amadouâtes": "amadouer",
    "amadouèrent": "amadouer",
    "amadoué": "amadouer",
    "amadouée": "amadouer",
    "amadouées": "amadouer",
    "amadoués": "amadouer",
    "amaigri": "amaigrir",
    "amaigrie": "amaigrir",
    "amaigries": "amaigrir",
    "amaigrira": "amaigrir",
    "amaigrirai": "amaigrir",
    "amaigriraient": "amaigrir",
    "amaigrirais": "amaigrir",
    "amaigrirait": "amaigrir",
    "amaigriras": "amaigrir",
    "amaigrirent": "amaigrir",
    "amaigrirez": "amaigrir",
    "amaigririez": "amaigrir",
    "amaigririons": "amaigrir",
    "amaigrirons": "amaigrir",
    "amaigriront": "amaigrir",
    "amaigris": "amaigrir",
    "amaigrissaient": "amaigrir",
    "amaigrissais": "amaigrir",
    "amaigrissait": "amaigrir",
    "amaigrissant": "amaigrir",
    "amaigrissante": "amaigrissant",
    "amaigrissantes": "amaigrissant",
    "amaigrissants": "amaigrissant",
    "amaigrisse": "amaigrir",
    "amaigrissements": "amaigrissement",
    "amaigrissent": "amaigrir",
    "amaigrisses": "amaigrir",
    "amaigrissez": "amaigrir",
    "amaigrissiez": "amaigrir",
    "amaigrissions": "amaigrir",
    "amaigrissons": "amaigrir",
    "amaigrit": "amaigrir",
    "amaigrîmes": "amaigrir",
    "amaigrît": "amaigrir",
    "amaigrîtes": "amaigrir",
    "amalfitaine": "amalfitain",
    "amalgamaient": "amalgamer",
    "amalgamais": "amalgamer",
    "amalgamait": "amalgamer",
    "amalgamant": "amalgamer",
    "amalgame": "amalgamer",
    "amalgames": "amalgame",
    "amalgamez": "amalgamer",
    "amalgamé": "amalgamer",
    "amalgamée": "amalgamer",
    "amalgamées": "amalgamer",
    "amalgamés": "amalgamer",
    "amandes": "amande",
    "amandiers": "amandier",
    "amandines": "amandine",
    "amanites": "amanite",
    "amans": "aman",
    "amante": "amant",
    "amantes": "amante",
    "amants": "amant",
    "amarantes": "amarante",
    "amarile": "amaril",
    "amariles": "amaril",
    "amarils": "amaril",
    "amarra": "amarrer",
    "amarrages": "amarrage",
    "amarrai": "amarrer",
    "amarraient": "amarrer",
    "amarrais": "amarrer",
    "amarrait": "amarrer",
    "amarrant": "amarrer",
    "amarras": "amarrer",
    "amarrasse": "amarrer",
    "amarrassent": "amarrer",
    "amarrasses": "amarrer",
    "amarrassiez": "amarrer",
    "amarrassions": "amarrer",
    "amarre": "amarrer",
    "amarrent": "amarrer",
    "amarrera": "amarrer",
    "amarrerai": "amarrer",
    "amarreraient": "amarrer",
    "amarrerais": "amarrer",
    "amarrerait": "amarrer",
    "amarreras": "amarrer",
    "amarrerez": "amarrer",
    "amarreriez": "amarrer",
    "amarrerions": "amarrer",
    "amarrerons": "amarrer",
    "amarreront": "amarrer",
    "amarres": "amarrer",
    "amarrez": "amarrer",
    "amarriez": "amarrer",
    "amarrions": "amarrer",
    "amarrons": "amarrer",
    "amarrâmes": "amarrer",
    "amarrât": "amarrer",
    "amarrâtes": "amarrer",
    "amarrèrent": "amarrer",
    "amarré": "amarrer",
    "amarrée": "amarrer",
    "amarrées": "amarrer",
    "amarrés": "amarrer",
    "amassa": "amasser",
    "amassai": "amasser",
    "amassaient": "amasser",
    "amassais": "amasser",
    "amassait": "amasser",
    "amassant": "amasser",
    "amassas": "amasser",
    "amassasse": "amasser",
    "amassassent": "amasser",
    "amassasses": "amasser",
    "amassassiez": "amasser",
    "amassassions": "amasser",
    "amasse": "amasser",
    "amassent": "amasser",
    "amassera": "amasser",
    "amasserai": "amasser",
    "amasseraient": "amasser",
    "amasserais": "amasser",
    "amasserait": "amasser",
    "amasseras": "amasser",
    "amasserez": "amasser",
    "amasseriez": "amasser",
    "amasserions": "amasser",
    "amasserons": "amasser",
    "amasseront": "amasser",
    "amasses": "amasser",
    "amassez": "amasser",
    "amassiez": "amasser",
    "amassions": "amasser",
    "amassons": "amasser",
    "amassâmes": "amasser",
    "amassât": "amasser",
    "amassâtes": "amasser",
    "amassèrent": "amasser",
    "amassé": "amasser",
    "amassée": "amasser",
    "amassées": "amasser",
    "amassés": "amasser",
    "amateurismes": "amateurisme",
    "amateurs": "amateur",
    "amati": "amatir",
    "amatie": "amatir",
    "amaties": "amatir",
    "amatira": "amatir",
    "amatirai": "amatir",
    "amatiraient": "amatir",
    "amatirais": "amatir",
    "amatirait": "amatir",
    "amatiras": "amatir",
    "amatirent": "amatir",
    "amatirez": "amatir",
    "amatiriez": "amatir",
    "amatirions": "amatir",
    "amatirons": "amatir",
    "amatiront": "amatir",
    "amatis": "amatir",
    "amatissaient": "amatir",
    "amatissais": "amatir",
    "amatissait": "amatir",
    "amatissant": "amatir",
    "amatisse": "amatir",
    "amatissent": "amatir",
    "amatisses": "amatir",
    "amatissez": "amatir",
    "amatissiez": "amatir",
    "amatissions": "amatir",
    "amatissons": "amatir",
    "amatit": "amatir",
    "amatrice": "amateur",
    "amatrices": "amateur",
    "amatîmes": "amatir",
    "amatît": "amatir",
    "amatîtes": "amatir",
    "amazones": "amazone",
    "amazonienne": "amazonien",
    "amazoniennes": "amazonien",
    "amazoniens": "amazonien",
    "ambassades": "ambassade",
    "ambassadeurs": "ambassadeur",
    "ambassadrice": "ambassadeur",
    "ambassadrices": "ambassadeur",
    "ambiances": "ambiance",
    "ambiante": "ambiant",
    "ambiantes": "ambiant",
    "ambiants": "ambiant",
    "ambidextres": "ambidextre",
    "ambigus": "ambigu",
    "ambiguë": "ambigu",
    "ambiguës": "ambigu",
    "ambiguïtés": "ambiguïté",
    "ambitieuse": "ambitieux",
    "ambitieuses": "ambitieux",
    "ambitionna": "ambitionner",
    "ambitionnai": "ambitionner",
    "ambitionnaient": "ambitionner",
    "ambitionnais": "ambitionner",
    "ambitionnait": "ambitionner",
    "ambitionnant": "ambitionner",
    "ambitionnas": "ambitionner",
    "ambitionnasse": "ambitionner",
    "ambitionnassent": "ambitionner",
    "ambitionnasses": "ambitionner",
    "ambitionnassiez": "ambitionner",
    "ambitionnassions": "ambitionner",
    "ambitionne": "ambitionner",
    "ambitionnent": "ambitionner",
    "ambitionnera": "ambitionner",
    "ambitionnerai": "ambitionner",
    "ambitionneraient": "ambitionner",
    "ambitionnerais": "ambitionner",
    "ambitionnerait": "ambitionner",
    "ambitionneras": "ambitionner",
    "ambitionnerez": "ambitionner",
    "ambitionneriez": "ambitionner",
    "ambitionnerions": "ambitionner",
    "ambitionnerons": "ambitionner",
    "ambitionneront": "ambitionner",
    "ambitionnes": "ambitionner",
    "ambitionnez": "ambitionner",
    "ambitionniez": "ambitionner",
    "ambitionnions": "ambitionner",
    "ambitionnons": "ambitionner",
    "ambitionnâmes": "ambitionner",
    "ambitionnât": "ambitionner",
    "ambitionnâtes": "ambitionner",
    "ambitionnèrent": "ambitionner",
    "ambitionné": "ambitionner",
    "ambitionnée": "ambitionner",
    "ambitionnées": "ambitionner",
    "ambitionnés": "ambitionner",
    "ambitions": "ambition",
    "ambivalences": "ambivalence",
    "ambivalente": "ambivalent",
    "ambivalentes": "ambivalent",
    "ambivalents": "ambivalent",
    "ambles": "amble",
    "amblyopes": "amblyope",
    "ambras": "ambrer",
    "ambres": "ambre",
    "ambroisies": "ambroisie",
    "ambré": "ambrer",
    "ambrée": "ambrer",
    "ambrées": "ambrer",
    "ambrés": "ambrer",
    "ambulacres": "ambulacre",
    "ambulances": "ambulance",
    "ambulanciers": "ambulancier",
    "ambulancière": "ambulancier",
    "ambulancières": "ambulancier",
    "ambulante": "ambulant",
    "ambulantes": "ambulant",
    "ambulants": "ambulant",
    "ambulatoires": "ambulatoire",
    "amena": "amener",
    "amenai": "amener",
    "amenaient": "amener",
    "amenais": "amener",
    "amenait": "amener",
    "amenant": "amener",
    "amenas": "amener",
    "amenasse": "amener",
    "amenassent": "amener",
    "amenasses": "amener",
    "amenassiez": "amener",
    "amenassions": "amener",
    "amenda": "amender",
    "amendai": "amender",
    "amendaient": "amender",
    "amendais": "amender",
    "amendait": "amender",
    "amendant": "amender",
    "amendas": "amender",
    "amendasse": "amender",
    "amendassent": "amender",
    "amendasses": "amender",
    "amendassiez": "amender",
    "amendassions": "amender",
    "amende": "amender",
    "amendements": "amendement",
    "amendent": "amender",
    "amendera": "amender",
    "amenderai": "amender",
    "amenderaient": "amender",
    "amenderais": "amender",
    "amenderait": "amender",
    "amenderas": "amender",
    "amenderez": "amender",
    "amenderiez": "amender",
    "amenderions": "amender",
    "amenderons": "amender",
    "amenderont": "amender",
    "amendes": "amender",
    "amendez": "amender",
    "amendiez": "amender",
    "amendions": "amender",
    "amendons": "amender",
    "amendâmes": "amender",
    "amendât": "amender",
    "amendâtes": "amender",
    "amendèrent": "amender",
    "amendé": "amender",
    "amendée": "amender",
    "amendées": "amender",
    "amendés": "amender",
    "amenez": "amener",
    "ameniez": "amener",
    "amenions": "amener",
    "amenons": "amener",
    "amensale": "amensal",
    "amensales": "amensal",
    "amensaux": "amensal",
    "amenuisa": "amenuiser",
    "amenuisai": "amenuiser",
    "amenuisaient": "amenuiser",
    "amenuisais": "amenuiser",
    "amenuisait": "amenuiser",
    "amenuisant": "amenuiser",
    "amenuisas": "amenuiser",
    "amenuisasse": "amenuiser",
    "amenuisassent": "amenuiser",
    "amenuisasses": "amenuiser",
    "amenuisassiez": "amenuiser",
    "amenuisassions": "amenuiser",
    "amenuise": "amenuiser",
    "amenuisent": "amenuiser",
    "amenuisera": "amenuiser",
    "amenuiserai": "amenuiser",
    "amenuiseraient": "amenuiser",
    "amenuiserais": "amenuiser",
    "amenuiserait": "amenuiser",
    "amenuiseras": "amenuiser",
    "amenuiserez": "amenuiser",
    "amenuiseriez": "amenuiser",
    "amenuiserions": "amenuiser",
    "amenuiserons": "amenuiser",
    "amenuiseront": "amenuiser",
    "amenuises": "amenuiser",
    "amenuisez": "amenuiser",
    "amenuisiez": "amenuiser",
    "amenuisions": "amenuiser",
    "amenuisons": "amenuiser",
    "amenuisâmes": "amenuiser",
    "amenuisât": "amenuiser",
    "amenuisâtes": "amenuiser",
    "amenuisèrent": "amenuiser",
    "amenuisé": "amenuiser",
    "amenuisée": "amenuiser",
    "amenuisées": "amenuiser",
    "amenuisés": "amenuiser",
    "amenâmes": "amener",
    "amenât": "amener",
    "amenâtes": "amener",
    "amenèrent": "amener",
    "amené": "amener",
    "amenée": "amener",
    "amenées": "amener",
    "amenés": "amener",
    "amerloques": "amerloque",
    "amerlos": "amerlo",
    "amerri": "amerrir",
    "amerrie": "amerrir",
    "amerries": "amerrir",
    "amerrira": "amerrir",
    "amerrirai": "amerrir",
    "amerriraient": "amerrir",
    "amerrirais": "amerrir",
    "amerrirait": "amerrir",
    "amerriras": "amerrir",
    "amerrirent": "amerrir",
    "amerrirez": "amerrir",
    "amerririez": "amerrir",
    "amerririons": "amerrir",
    "amerrirons": "amerrir",
    "amerriront": "amerrir",
    "amerris": "amerrir",
    "amerrissaient": "amerrir",
    "amerrissais": "amerrir",
    "amerrissait": "amerrir",
    "amerrissant": "amerrir",
    "amerrisse": "amerrir",
    "amerrissent": "amerrir",
    "amerrisses": "amerrir",
    "amerrissez": "amerrir",
    "amerrissiez": "amerrir",
    "amerrissions": "amerrir",
    "amerrissons": "amerrir",
    "amerrit": "amerrir",
    "amerrîmes": "amerrir",
    "amerrît": "amerrir",
    "amerrîtes": "amerrir",
    "amers": "amer",
    "amertumes": "amertume",
    "ameublements": "ameublement",
    "ameubli": "ameublir",
    "ameublie": "ameublir",
    "ameublies": "ameublir",
    "ameublira": "ameublir",
    "ameublirai": "ameublir",
    "ameubliraient": "ameublir",
    "ameublirais": "ameublir",
    "ameublirait": "ameublir",
    "ameubliras": "ameublir",
    "ameublirent": "ameublir",
    "ameublirez": "ameublir",
    "ameubliriez": "ameublir",
    "ameublirions": "ameublir",
    "ameublirons": "ameublir",
    "ameubliront": "ameublir",
    "ameublis": "ameublir",
    "ameublissaient": "ameublir",
    "ameublissais": "ameublir",
    "ameublissait": "ameublir",
    "ameublissant": "ameublir",
    "ameublisse": "ameublir",
    "ameublissent": "ameublir",
    "ameublisses": "ameublir",
    "ameublissez": "ameublir",
    "ameublissiez": "ameublir",
    "ameublissions": "ameublir",
    "ameublissons": "ameublir",
    "ameublit": "ameublir",
    "ameublîmes": "ameublir",
    "ameublît": "ameublir",
    "ameublîtes": "ameublir",
    "ameuta": "ameuter",
    "ameutai": "ameuter",
    "ameutaient": "ameuter",
    "ameutais": "ameuter",
    "ameutait": "ameuter",
    "ameutant": "ameuter",
    "ameutas": "ameuter",
    "ameutasse": "ameuter",
    "ameutassent": "ameuter",
    "ameutasses": "ameuter",
    "ameutassiez": "ameuter",
    "ameutassions": "ameuter",
    "ameute": "ameuter",
    "ameutent": "ameuter",
    "ameutera": "ameuter",
    "ameuterai": "ameuter",
    "ameuteraient": "ameuter",
    "ameuterais": "ameuter",
    "ameuterait": "ameuter",
    "ameuteras": "ameuter",
    "ameuterez": "ameuter",
    "ameuteriez": "ameuter",
    "ameuterions": "ameuter",
    "ameuterons": "ameuter",
    "ameuteront": "ameuter",
    "ameutes": "ameuter",
    "ameutez": "ameuter",
    "ameutiez": "ameuter",
    "ameutions": "ameuter",
    "ameutons": "ameuter",
    "ameutâmes": "ameuter",
    "ameutât": "ameuter",
    "ameutâtes": "ameuter",
    "ameutèrent": "ameuter",
    "ameuté": "ameuter",
    "ameutée": "ameuter",
    "ameutées": "ameuter",
    "ameutés": "ameuter",
    "amiables": "amiable",
    "amiantes": "amiante",
    "amiantes-ciments": "amiante-ciment",
    "amibes": "amibe",
    "amibienne": "amibien",
    "amicale": "amical",
    "amicales": "amicale",
    "amicalités": "amicalité",
    "amicaux": "amical",
    "amides": "amide",
    "amidonna": "amidonner",
    "amidonnai": "amidonner",
    "amidonnaient": "amidonner",
    "amidonnais": "amidonner",
    "amidonnait": "amidonner",
    "amidonnant": "amidonner",
    "amidonnas": "amidonner",
    "amidonnasse": "amidonner",
    "amidonnassent": "amidonner",
    "amidonnasses": "amidonner",
    "amidonnassiez": "amidonner",
    "amidonnassions": "amidonner",
    "amidonne": "amidonner",
    "amidonnent": "amidonner",
    "amidonnera": "amidonner",
    "amidonnerai": "amidonner",
    "amidonneraient": "amidonner",
    "amidonnerais": "amidonner",
    "amidonnerait": "amidonner",
    "amidonneras": "amidonner",
    "amidonnerez": "amidonner",
    "amidonneriez": "amidonner",
    "amidonnerions": "amidonner",
    "amidonnerons": "amidonner",
    "amidonneront": "amidonner",
    "amidonnes": "amidonner",
    "amidonnez": "amidonner",
    "amidonniez": "amidonner",
    "amidonnions": "amidonner",
    "amidonnons": "amidonner",
    "amidonnâmes": "amidonner",
    "amidonnât": "amidonner",
    "amidonnâtes": "amidonner",
    "amidonnèrent": "amidonner",
    "amidonné": "amidonner",
    "amidonnée": "amidonner",
    "amidonnées": "amidonner",
    "amidonnés": "amidonner",
    "amidons": "amidon",
    "amie": "ami",
    "amies": "ami",
    "amigos": "amigo",
    "aminci": "amincir",
    "amincie": "amincir",
    "amincies": "amincir",
    "amincira": "amincir",
    "amincirai": "amincir",
    "aminciraient": "amincir",
    "amincirais": "amincir",
    "amincirait": "amincir",
    "aminciras": "amincir",
    "amincirent": "amincir",
    "amincirez": "amincir",
    "aminciriez": "amincir",
    "amincirions": "amincir",
    "amincirons": "amincir",
    "aminciront": "amincir",
    "amincis": "amincir",
    "amincissaient": "amincir",
    "amincissais": "amincir",
    "amincissait": "amincir",
    "amincissant": "amincir",
    "amincissante": "amincissant",
    "amincissantes": "amincissant",
    "amincissants": "amincissant",
    "amincisse": "amincir",
    "amincissent": "amincir",
    "amincisses": "amincir",
    "amincissez": "amincir",
    "amincissiez": "amincir",
    "amincissions": "amincir",
    "amincissons": "amincir",
    "amincit": "amincir",
    "amincîmes": "amincir",
    "amincît": "amincir",
    "amincîtes": "amincir",
    "aminoacides": "aminoacide",
    "aminées": "aminé",
    "aminés": "aminé",
    "amirale": "amiral",
    "amirautés": "amirauté",
    "amiraux": "amiral",
    "amis": "ami",
    "amitieuse": "amitieux",
    "amitiés": "amitié",
    "ammonals": "ammonal",
    "ammoniacale": "ammoniacal",
    "ammoniacales": "ammoniacal",
    "ammoniacaux": "ammoniacal",
    "ammoniacs": "ammoniac",
    "ammoniaques": "ammoniaque",
    "ammoniaquée": "ammoniaqué",
    "ammoniaquées": "ammoniaqué",
    "ammoniums": "ammonium",
    "amnistiante": "amnistiant",
    "amnistie": "amnistier",
    "amnistierons": "amnistier",
    "amnisties": "amnistie",
    "amnistié": "amnistier",
    "amnistiée": "amnistier",
    "amnistiées": "amnistié",
    "amnistiés": "amnistier",
    "amnésies": "amnésie",
    "amnésiques": "amnésique",
    "amochait": "amocher",
    "amoche": "amocher",
    "amochez": "amocher",
    "amochie": "amochir",
    "amoché": "amocher",
    "amochée": "amocher",
    "amochés": "amocher",
    "amodia": "amodier",
    "amodiai": "amodier",
    "amodiaient": "amodier",
    "amodiais": "amodier",
    "amodiait": "amodier",
    "amodiant": "amodier",
    "amodias": "amodier",
    "amodiasse": "amodier",
    "amodiassent": "amodier",
    "amodiasses": "amodier",
    "amodiassiez": "amodier",
    "amodiassions": "amodier",
    "amodie": "amodier",
    "amodient": "amodier",
    "amodiera": "amodier",
    "amodierai": "amodier",
    "amodieraient": "amodier",
    "amodierais": "amodier",
    "amodierait": "amodier",
    "amodieras": "amodier",
    "amodierez": "amodier",
    "amodieriez": "amodier",
    "amodierions": "amodier",
    "amodierons": "amodier",
    "amodieront": "amodier",
    "amodies": "amodier",
    "amodiez": "amodier",
    "amodiiez": "amodier",
    "amodiions": "amodier",
    "amodions": "amodier",
    "amodiâmes": "amodier",
    "amodiât": "amodier",
    "amodiâtes": "amodier",
    "amodièrent": "amodier",
    "amodié": "amodier",
    "amodiée": "amodier",
    "amodiées": "amodier",
    "amodiés": "amodier",
    "amoindri": "amoindrir",
    "amoindrie": "amoindrir",
    "amoindries": "amoindrir",
    "amoindrira": "amoindrir",
    "amoindrirai": "amoindrir",
    "amoindriraient": "amoindrir",
    "amoindrirais": "amoindrir",
    "amoindrirait": "amoindrir",
    "amoindriras": "amoindrir",
    "amoindrirent": "amoindrir",
    "amoindrirez": "amoindrir",
    "amoindririez": "amoindrir",
    "amoindririons": "amoindrir",
    "amoindrirons": "amoindrir",
    "amoindriront": "amoindrir",
    "amoindris": "amoindrir",
    "amoindrissaient": "amoindrir",
    "amoindrissais": "amoindrir",
    "amoindrissait": "amoindrir",
    "amoindrissant": "amoindrir",
    "amoindrisse": "amoindrir",
    "amoindrissements": "amoindrissement",
    "amoindrissent": "amoindrir",
    "amoindrisses": "amoindrir",
    "amoindrissez": "amoindrir",
    "amoindrissiez": "amoindrir",
    "amoindrissions": "amoindrir",
    "amoindrissons": "amoindrir",
    "amoindrit": "amoindrir",
    "amoindrîmes": "amoindrir",
    "amoindrît": "amoindrir",
    "amoindrîtes": "amoindrir",
    "amoks": "amok",
    "amolli": "amollir",
    "amollie": "amollir",
    "amollies": "amollir",
    "amollira": "amollir",
    "amollirai": "amollir",
    "amolliraient": "amollir",
    "amollirais": "amollir",
    "amollirait": "amollir",
    "amolliras": "amollir",
    "amollirent": "amollir",
    "amollirez": "amollir",
    "amolliriez": "amollir",
    "amollirions": "amollir",
    "amollirons": "amollir",
    "amolliront": "amollir",
    "amollis": "amollir",
    "amollissaient": "amollir",
    "amollissais": "amollir",
    "amollissait": "amollir",
    "amollissant": "amollir",
    "amollisse": "amollir",
    "amollissent": "amollir",
    "amollisses": "amollir",
    "amollissez": "amollir",
    "amollissiez": "amollir",
    "amollissions": "amollir",
    "amollissons": "amollir",
    "amollit": "amollir",
    "amollîmes": "amollir",
    "amollît": "amollir",
    "amollîtes": "amollir",
    "amoncela": "amonceler",
    "amoncelai": "amonceler",
    "amoncelaient": "amonceler",
    "amoncelais": "amonceler",
    "amoncelait": "amonceler",
    "amoncelant": "amonceler",
    "amoncelas": "amonceler",
    "amoncelasse": "amonceler",
    "amoncelassent": "amonceler",
    "amoncelasses": "amonceler",
    "amoncelassiez": "amonceler",
    "amoncelassions": "amonceler",
    "amoncelez": "amonceler",
    "amonceliez": "amonceler",
    "amoncelions": "amonceler",
    "amoncelle": "amonceler",
    "amoncellements": "amoncellement",
    "amoncellent": "amonceler",
    "amoncellera": "amonceler",
    "amoncellerai": "amonceler",
    "amoncelleraient": "amonceler",
    "amoncellerais": "amonceler",
    "amoncellerait": "amonceler",
    "amoncelleras": "amonceler",
    "amoncellerez": "amonceler",
    "amoncelleriez": "amonceler",
    "amoncellerions": "amonceler",
    "amoncellerons": "amonceler",
    "amoncelleront": "amonceler",
    "amoncelles": "amonceler",
    "amoncelons": "amonceler",
    "amoncelâmes": "amonceler",
    "amoncelât": "amonceler",
    "amoncelâtes": "amonceler",
    "amoncelèrent": "amonceler",
    "amoncelé": "amonceler",
    "amoncelée": "amonceler",
    "amoncelées": "amonceler",
    "amoncelés": "amonceler",
    "amonts": "amont",
    "amorale": "amoral",
    "amorales": "amoral",
    "amoraux": "amoral",
    "amorce": "amorcer",
    "amorcent": "amorcer",
    "amorcera": "amorcer",
    "amorcerai": "amorcer",
    "amorceraient": "amorcer",
    "amorcerais": "amorcer",
    "amorcerait": "amorcer",
    "amorceras": "amorcer",
    "amorcerez": "amorcer",
    "amorceriez": "amorcer",
    "amorcerions": "amorcer",
    "amorcerons": "amorcer",
    "amorceront": "amorcer",
    "amorces": "amorcer",
    "amorcez": "amorcer",
    "amorciez": "amorcer",
    "amorcions": "amorcer",
    "amorcèrent": "amorcer",
    "amorcé": "amorcer",
    "amorcée": "amorcer",
    "amorcées": "amorcer",
    "amorcés": "amorcer",
    "amorphes": "amorphe",
    "amorti": "amortir",
    "amortie": "amortir",
    "amorties": "amortir",
    "amortira": "amortir",
    "amortirai": "amortir",
    "amortiraient": "amortir",
    "amortirais": "amortir",
    "amortirait": "amortir",
    "amortiras": "amortir",
    "amortirent": "amortir",
    "amortirez": "amortir",
    "amortiriez": "amortir",
    "amortirions": "amortir",
    "amortirons": "amortir",
    "amortiront": "amortir",
    "amortis": "amortir",
    "amortissaient": "amortir",
    "amortissais": "amortir",
    "amortissait": "amortir",
    "amortissant": "amortir",
    "amortisse": "amortir",
    "amortissements": "amortissement",
    "amortissent": "amortir",
    "amortisses": "amortir",
    "amortisseurs": "amortisseur",
    "amortissez": "amortir",
    "amortissiez": "amortir",
    "amortissions": "amortir",
    "amortissons": "amortir",
    "amortit": "amortir",
    "amortîmes": "amortir",
    "amortît": "amortir",
    "amortîtes": "amortir",
    "amorça": "amorcer",
    "amorçages": "amorçage",
    "amorçai": "amorcer",
    "amorçaient": "amorcer",
    "amorçais": "amorcer",
    "amorçait": "amorcer",
    "amorçant": "amorcer",
    "amorças": "amorcer",
    "amorçasse": "amorcer",
    "amorçassent": "amorcer",
    "amorçasses": "amorcer",
    "amorçassiez": "amorcer",
    "amorçassions": "amorcer",
    "amorçons": "amorcer",
    "amorçâmes": "amorcer",
    "amorçât": "amorcer",
    "amorçâtes": "amorcer",
    "amouracha": "amouracher",
    "amourache": "amouracher",
    "amourachent": "amouracher",
    "amourachera": "amouracher",
    "amouraches": "amouracher",
    "amouraché": "amouracher",
    "amourachée": "amouracher",
    "amourettes": "amourette",
    "amoureuse": "amoureux",
    "amoureuses": "amoureux",
    "amours": "amour",
    "amours-propres": "amour-propre",
    "amovibles": "amovible",
    "amphibiens": "amphibien",
    "amphibies": "amphibie",
    "amphiboles": "amphibole",
    "amphibologies": "amphibologie",
    "amphigouriques": "amphigourique",
    "amphigouris": "amphigouri",
    "amphis": "amphi",
    "amphithéâtres": "amphithéâtre",
    "amphitryons": "amphitryon",
    "amphores": "amphore",
    "amphés": "amphé",
    "amphétamines": "amphétamine",
    "amples": "ample",
    "ampleurs": "ampleur",
    "amplifia": "amplifier",
    "amplifiai": "amplifier",
    "amplifiaient": "amplifier",
    "amplifiais": "amplifier",
    "amplifiait": "amplifier",
    "amplifiant": "amplifier",
    "amplifias": "amplifier",
    "amplifiasse": "amplifier",
    "amplifiassent": "amplifier",
    "amplifiasses": "amplifier",
    "amplifiassiez": "amplifier",
    "amplifiassions": "amplifier",
    "amplificateurs": "amplificateur",
    "amplifications": "amplification",
    "amplifie": "amplifier",
    "amplifient": "amplifier",
    "amplifiera": "amplifier",
    "amplifierai": "amplifier",
    "amplifieraient": "amplifier",
    "amplifierais": "amplifier",
    "amplifierait": "amplifier",
    "amplifieras": "amplifier",
    "amplifierez": "amplifier",
    "amplifieriez": "amplifier",
    "amplifierions": "amplifier",
    "amplifierons": "amplifier",
    "amplifieront": "amplifier",
    "amplifies": "amplifier",
    "amplifiez": "amplifier",
    "amplifiiez": "amplifier",
    "amplifiions": "amplifier",
    "amplifions": "amplifier",
    "amplifiâmes": "amplifier",
    "amplifiât": "amplifier",
    "amplifiâtes": "amplifier",
    "amplifièrent": "amplifier",
    "amplifié": "amplifier",
    "amplifiée": "amplifier",
    "amplifiées": "amplifier",
    "amplifiés": "amplifier",
    "amplis": "ampli",
    "amplis-tuners": "ampli-tuner",
    "amplitudes": "amplitude",
    "ampoules": "ampoule",
    "ampoulée": "ampoulé",
    "ampoulées": "ampoulé",
    "ampoulés": "ampoulé",
    "amputa": "amputer",
    "amputai": "amputer",
    "amputaient": "amputer",
    "amputais": "amputer",
    "amputait": "amputer",
    "amputant": "amputer",
    "amputas": "amputer",
    "amputasse": "amputer",
    "amputassent": "amputer",
    "amputasses": "amputer",
    "amputassiez": "amputer",
    "amputassions": "amputer",
    "amputations": "amputation",
    "ampute": "amputer",
    "amputent": "amputer",
    "amputera": "amputer",
    "amputerai": "amputer",
    "amputeraient": "amputer",
    "amputerais": "amputer",
    "amputerait": "amputer",
    "amputeras": "amputer",
    "amputerez": "amputer",
    "amputeriez": "amputer",
    "amputerions": "amputer",
    "amputerons": "amputer",
    "amputeront": "amputer",
    "amputes": "amputer",
    "amputez": "amputer",
    "amputiez": "amputer",
    "amputions": "amputer",
    "amputons": "amputer",
    "amputâmes": "amputer",
    "amputât": "amputer",
    "amputâtes": "amputer",
    "amputèrent": "amputer",
    "amputé": "amputer",
    "amputée": "amputer",
    "amputées": "amputer",
    "amputés": "amputer",
    "ampères": "ampère",
    "amulettes": "amulette",
    "amura": "amurer",
    "amures": "amure",
    "amusa": "amuser",
    "amusai": "amuser",
    "amusaient": "amuser",
    "amusais": "amuser",
    "amusait": "amuser",
    "amusant": "amuser",
    "amusante": "amusant",
    "amusantes": "amusant",
    "amusants": "amusant",
    "amusas": "amuser",
    "amusasse": "amuser",
    "amusassent": "amuser",
    "amusasses": "amuser",
    "amusassiez": "amuser",
    "amusassions": "amuser",
    "amuse": "amuser",
    "amuse-bouches": "amuse-bouche",
    "amuse-gueules": "amuse-gueule",
    "amusements": "amusement",
    "amusent": "amuser",
    "amusera": "amuser",
    "amuserai": "amuser",
    "amuseraient": "amuser",
    "amuserais": "amuser",
    "amuserait": "amuser",
    "amuseras": "amuser",
    "amuserez": "amuser",
    "amuseriez": "amuser",
    "amuserions": "amuser",
    "amuserons": "amuser",
    "amuseront": "amuser",
    "amuses": "amuser",
    "amusettes": "amusette",
    "amuseurs": "amuseur",
    "amusez": "amuser",
    "amusiez": "amuser",
    "amusions": "amuser",
    "amusons": "amuser",
    "amusâmes": "amuser",
    "amusât": "amuser",
    "amusâtes": "amuser",
    "amusèrent": "amuser",
    "amusé": "amuser",
    "amusée": "amuser",
    "amusées": "amuser",
    "amusés": "amuser",
    "amuîmes": "amuïr",
    "amuît": "amuïr",
    "amuîtes": "amuïr",
    "amuï": "amuïr",
    "amuïe": "amuïr",
    "amuïes": "amuïr",
    "amuïra": "amuïr",
    "amuïrai": "amuïr",
    "amuïraient": "amuïr",
    "amuïrais": "amuïr",
    "amuïrait": "amuïr",
    "amuïras": "amuïr",
    "amuïrent": "amuïr",
    "amuïrez": "amuïr",
    "amuïriez": "amuïr",
    "amuïrions": "amuïr",
    "amuïrons": "amuïr",
    "amuïront": "amuïr",
    "amuïs": "amuïr",
    "amuïssaient": "amuïr",
    "amuïssais": "amuïr",
    "amuïssait": "amuïr",
    "amuïssant": "amuïr",
    "amuïsse": "amuïr",
    "amuïssements": "amuïssement",
    "amuïssent": "amuïr",
    "amuïsses": "amuïr",
    "amuïssez": "amuïr",
    "amuïssiez": "amuïr",
    "amuïssions": "amuïr",
    "amuïssons": "amuïr",
    "amuït": "amuïr",
    "amygdalectomies": "amygdalectomie",
    "amygdales": "amygdale",
    "amylènes": "amylène",
    "amène": "amener",
    "amènent": "amener",
    "amènera": "amener",
    "amènerai": "amener",
    "amèneraient": "amener",
    "amènerais": "amener",
    "amènerait": "amener",
    "amèneras": "amener",
    "amènerez": "amener",
    "amèneriez": "amener",
    "amènerions": "amener",
    "amènerons": "amener",
    "amèneront": "amener",
    "amènes": "amener",
    "amère": "amer",
    "amères": "amer",
    "améliora": "améliorer",
    "améliorai": "améliorer",
    "amélioraient": "améliorer",
    "améliorais": "améliorer",
    "améliorait": "améliorer",
    "améliorant": "améliorer",
    "amélioras": "améliorer",
    "améliorasse": "améliorer",
    "améliorassent": "améliorer",
    "améliorasses": "améliorer",
    "améliorassiez": "améliorer",
    "améliorassions": "améliorer",
    "améliorations": "amélioration",
    "améliore": "améliorer",
    "améliorent": "améliorer",
    "améliorera": "améliorer",
    "améliorerai": "améliorer",
    "amélioreraient": "améliorer",
    "améliorerais": "améliorer",
    "améliorerait": "améliorer",
    "amélioreras": "améliorer",
    "améliorerez": "améliorer",
    "amélioreriez": "améliorer",
    "améliorerions": "améliorer",
    "améliorerons": "améliorer",
    "amélioreront": "améliorer",
    "améliores": "améliorer",
    "améliorez": "améliorer",
    "amélioriez": "améliorer",
    "améliorions": "améliorer",
    "améliorons": "améliorer",
    "améliorâmes": "améliorer",
    "améliorât": "améliorer",
    "améliorâtes": "améliorer",
    "améliorèrent": "améliorer",
    "amélioré": "améliorer",
    "améliorée": "améliorer",
    "améliorées": "améliorer",
    "améliorés": "améliorer",
    "aménage": "aménager",
    "aménagea": "aménager",
    "aménageai": "aménager",
    "aménageaient": "aménager",
    "aménageais": "aménager",
    "aménageait": "aménager",
    "aménageant": "aménager",
    "aménageas": "aménager",
    "aménageasse": "aménager",
    "aménageassent": "aménager",
    "aménageasses": "aménager",
    "aménageassiez": "aménager",
    "aménageassions": "aménager",
    "aménagements": "aménagement",
    "aménagent": "aménager",
    "aménageons": "aménager",
    "aménagera": "aménager",
    "aménagerai": "aménager",
    "aménageraient": "aménager",
    "aménagerais": "aménager",
    "aménagerait": "aménager",
    "aménageras": "aménager",
    "aménagerez": "aménager",
    "aménageriez": "aménager",
    "aménagerions": "aménager",
    "aménagerons": "aménager",
    "aménageront": "aménager",
    "aménages": "aménager",
    "aménageurs": "aménageur",
    "aménagez": "aménager",
    "aménageâmes": "aménager",
    "aménageât": "aménager",
    "aménageâtes": "aménager",
    "aménagiez": "aménager",
    "aménagions": "aménager",
    "aménagèrent": "aménager",
    "aménagé": "aménager",
    "aménagée": "aménager",
    "aménagées": "aménager",
    "aménagés": "aménager",
    "aménités": "aménité",
    "américaine": "américain",
    "américaines": "américain",
    "américains": "américain",
    "américanisa": "américaniser",
    "américanisai": "américaniser",
    "américanisaient": "américaniser",
    "américanisais": "américaniser",
    "américanisait": "américaniser",
    "américanisant": "américaniser",
    "américanisas": "américaniser",
    "américanisasse": "américaniser",
    "américanisassent": "américaniser",
    "américanisasses": "américaniser",
    "américanisassiez": "américaniser",
    "américanisassions": "américaniser",
    "américanise": "américaniser",
    "américanisent": "américaniser",
    "américanisera": "américaniser",
    "américaniserai": "américaniser",
    "américaniseraient": "américaniser",
    "américaniserais": "américaniser",
    "américaniserait": "américaniser",
    "américaniseras": "américaniser",
    "américaniserez": "américaniser",
    "américaniseriez": "américaniser",
    "américaniserions": "américaniser",
    "américaniserons": "américaniser",
    "américaniseront": "américaniser",
    "américanises": "américaniser",
    "américanisez": "américaniser",
    "américanisiez": "américaniser",
    "américanisions": "américaniser",
    "américanismes": "américanisme",
    "américanisons": "américaniser",
    "américanisâmes": "américaniser",
    "américanisât": "américaniser",
    "américanisâtes": "américaniser",
    "américanisèrent": "américaniser",
    "américanisé": "américaniser",
    "américanisée": "américaniser",
    "américanisées": "américaniser",
    "américanisés": "américaniser",
    "américano-japonaise": "américano-japonais",
    "américano-suédoise": "américano-suédois",
    "américanophiles": "américanophile",
    "américanos": "américano",
    "amérindienne": "amérindien",
    "amérindiennes": "amérindien",
    "amérindiens": "amérindien",
    "améthystes": "améthyste",
    "anabaptistes": "anabaptiste",
    "anabolisants": "anabolisant",
    "anachorètes": "anachorète",
    "anachroniques": "anachronique",
    "anachronismes": "anachronisme",
    "anacoluthes": "anacoluthe",
    "anacondas": "anaconda",
    "anaglyphes": "anaglyphe",
    "anagrammes": "anagramme",
    "anale": "anal",
    "analeptiques": "analeptique",
    "anales": "anal",
    "analgésies": "analgésie",
    "analgésiques": "analgésique",
    "analogies": "analogie",
    "analogiques": "analogique",
    "analogues": "analogue",
    "analphabètes": "analphabète",
    "analphabétismes": "analphabétisme",
    "analysa": "analyser",
    "analysai": "analyser",
    "analysaient": "analyser",
    "analysais": "analyser",
    "analysait": "analyser",
    "analysant": "analyser",
    "analysants": "analysant",
    "analysas": "analyser",
    "analysasse": "analyser",
    "analysassent": "analyser",
    "analysasses": "analyser",
    "analysassiez": "analyser",
    "analysassions": "analyser",
    "analyse": "analyser",
    "analysent": "analyser",
    "analysera": "analyser",
    "analyserai": "analyser",
    "analyseraient": "analyser",
    "analyserais": "analyser",
    "analyserait": "analyser",
    "analyseras": "analyser",
    "analyserez": "analyser",
    "analyseriez": "analyser",
    "analyserions": "analyser",
    "analyserons": "analyser",
    "analyseront": "analyser",
    "analyses": "analyser",
    "analyseurs": "analyseur",
    "analysez": "analyser",
    "analysiez": "analyser",
    "analysions": "analyser",
    "analysons": "analyser",
    "analystes": "analyste",
    "analysâmes": "analyser",
    "analysât": "analyser",
    "analysâtes": "analyser",
    "analysèrent": "analyser",
    "analysé": "analyser",
    "analysée": "analyser",
    "analysées": "analyser",
    "analysés": "analyser",
    "analytiques": "analytique",
    "anamorphoses": "anamorphose",
    "anapestes": "anapeste",
    "anarchies": "anarchie",
    "anarchiques": "anarchique",
    "anarchismes": "anarchisme",
    "anarchistes": "anarchiste",
    "anarcho-syndicalistes": "anarcho-syndicaliste",
    "anars": "anar",
    "anas": "ana",
    "anastomoses": "anastomose",
    "anathèmes": "anathème",
    "anathématisa": "anathématiser",
    "anathématisai": "anathématiser",
    "anathématisaient": "anathématiser",
    "anathématisais": "anathématiser",
    "anathématisait": "anathématiser",
    "anathématisant": "anathématiser",
    "anathématisas": "anathématiser",
    "anathématisasse": "anathématiser",
    "anathématisassent": "anathématiser",
    "anathématisasses": "anathématiser",
    "anathématisassiez": "anathématiser",
    "anathématisassions": "anathématiser",
    "anathématise": "anathématiser",
    "anathématisent": "anathématiser",
    "anathématisera": "anathématiser",
    "anathématiserai": "anathématiser",
    "anathématiseraient": "anathématiser",
    "anathématiserais": "anathématiser",
    "anathématiserait": "anathématiser",
    "anathématiseras": "anathématiser",
    "anathématiserez": "anathématiser",
    "anathématiseriez": "anathématiser",
    "anathématiserions": "anathématiser",
    "anathématiserons": "anathématiser",
    "anathématiseront": "anathématiser",
    "anathématises": "anathématiser",
    "anathématisez": "anathématiser",
    "anathématisiez": "anathématiser",
    "anathématisions": "anathématiser",
    "anathématisons": "anathématiser",
    "anathématisâmes": "anathématiser",
    "anathématisât": "anathématiser",
    "anathématisâtes": "anathématiser",
    "anathématisèrent": "anathématiser",
    "anathématisé": "anathématiser",
    "anathématisée": "anathématiser",
    "anathématisées": "anathématiser",
    "anathématisés": "anathématiser",
    "anatidés": "anatidé",
    "anatifes": "anatife",
    "anatomies": "anatomie",
    "anatomiques": "anatomique",
    "anatomistes": "anatomiste",
    "anaux": "anal",
    "anaérobioses": "anaérobiose",
    "ancestrale": "ancestral",
    "ancestrales": "ancestral",
    "ancestraux": "ancestral",
    "anches": "anche",
    "ancienne": "ancien",
    "anciennes": "ancien",
    "anciennetés": "ancienneté",
    "anciens": "ancien",
    "ancillaires": "ancillaire",
    "ancra": "ancrer",
    "ancrages": "ancrage",
    "ancrai": "ancrer",
    "ancraient": "ancrer",
    "ancrais": "ancrer",
    "ancrait": "ancrer",
    "ancrant": "ancrer",
    "ancras": "ancrer",
    "ancrasse": "ancrer",
    "ancrassent": "ancrer",
    "ancrasses": "ancrer",
    "ancrassiez": "ancrer",
    "ancrassions": "ancrer",
    "ancre": "ancrer",
    "ancrent": "ancrer",
    "ancrera": "ancrer",
    "ancrerai": "ancrer",
    "ancreraient": "ancrer",
    "ancrerais": "ancrer",
    "ancrerait": "ancrer",
    "ancreras": "ancrer",
    "ancrerez": "ancrer",
    "ancreriez": "ancrer",
    "ancrerions": "ancrer",
    "ancrerons": "ancrer",
    "ancreront": "ancrer",
    "ancres": "ancrer",
    "ancrez": "ancrer",
    "ancriez": "ancrer",
    "ancrions": "ancrer",
    "ancrons": "ancrer",
    "ancrâmes": "ancrer",
    "ancrât": "ancrer",
    "ancrâtes": "ancrer",
    "ancrèrent": "ancrer",
    "ancré": "ancrer",
    "ancrée": "ancrer",
    "ancrées": "ancrer",
    "ancrés": "ancrer",
    "ancêtres": "ancêtre",
    "andains": "andain",
    "andalous": "andalou",
    "andalouse": "andalou",
    "andalouses": "andalou",
    "andantes": "andante",
    "andantinos": "andantino",
    "andine": "andin",
    "andines": "andin",
    "andins": "andin",
    "andorranes": "andorran",
    "andouillers": "andouiller",
    "andouilles": "andouille",
    "andouillettes": "andouillette",
    "androcées": "androcée",
    "androgynes": "androgyne",
    "androgènes": "androgène",
    "androïdes": "androïde",
    "andéens": "andéen",
    "anecdotes": "anecdote",
    "anecdotiques": "anecdotique",
    "anesthésia": "anesthésier",
    "anesthésiaient": "anesthésier",
    "anesthésiait": "anesthésier",
    "anesthésiant": "anesthésier",
    "anesthésiante": "anesthésiant",
    "anesthésiantes": "anesthésiant",
    "anesthésiants": "anesthésiant",
    "anesthésie": "anesthésier",
    "anesthésient": "anesthésier",
    "anesthésierai": "anesthésier",
    "anesthésies": "anesthésier",
    "anesthésiez": "anesthésier",
    "anesthésions": "anesthésier",
    "anesthésiques": "anesthésique",
    "anesthésistes": "anesthésiste",
    "anesthésié": "anesthésier",
    "anesthésiée": "anesthésier",
    "anesthésiées": "anesthésier",
    "anesthésiés": "anesthésier",
    "aneths": "aneth",
    "anfractuosités": "anfractuosité",
    "angelots": "angelot",
    "anges": "ange",
    "angevine": "angevin",
    "angevins": "angevin",
    "angines": "angine",
    "angiospermes": "angiosperme",
    "anglais": "angler",
    "anglaise": "anglais",
    "anglaises": "anglais",
    "angles": "angle",
    "anglicane": "anglican",
    "anglicanes": "anglican",
    "anglicans": "anglican",
    "angliches": "angliche",
    "anglicismes": "anglicisme",
    "anglicisé": "angliciser",
    "anglo-américaine": "anglo-américain",
    "anglo-américaines": "anglo-américain",
    "anglo-américains": "anglo-américain",
    "anglo-arabes": "anglo-arabe",
    "anglo-française": "anglo-français",
    "anglo-normande": "anglo-normand",
    "anglo-normandes": "anglo-normand",
    "anglo-russes": "anglo-russe",
    "anglo-saxonne": "anglo-saxon",
    "anglo-saxonnes": "anglo-saxon",
    "anglo-saxons": "anglo-saxon",
    "anglo-égyptienne": "anglo-égyptien",
    "anglomanes": "anglomane",
    "anglophiles": "anglophile",
    "anglophobes": "anglophobe",
    "anglophones": "anglophone",
    "angoissa": "angoisser",
    "angoissai": "angoisser",
    "angoissaient": "angoisser",
    "angoissais": "angoisser",
    "angoissait": "angoisser",
    "angoissant": "angoisser",
    "angoissante": "angoissant",
    "angoissantes": "angoissant",
    "angoissants": "angoissant",
    "angoissas": "angoisser",
    "angoissasse": "angoisser",
    "angoissassent": "angoisser",
    "angoissasses": "angoisser",
    "angoissassiez": "angoisser",
    "angoissassions": "angoisser",
    "angoisse": "angoisser",
    "angoissent": "angoisser",
    "angoissera": "angoisser",
    "angoisserai": "angoisser",
    "angoisseraient": "angoisser",
    "angoisserais": "angoisser",
    "angoisserait": "angoisser",
    "angoisseras": "angoisser",
    "angoisserez": "angoisser",
    "angoisseriez": "angoisser",
    "angoisserions": "angoisser",
    "angoisserons": "angoisser",
    "angoisseront": "angoisser",
    "angoisses": "angoisser",
    "angoissez": "angoisser",
    "angoissiez": "angoisser",
    "angoissions": "angoisser",
    "angoissons": "angoisser",
    "angoissâmes": "angoisser",
    "angoissât": "angoisser",
    "angoissâtes": "angoisser",
    "angoissèrent": "angoisser",
    "angoissé": "angoisser",
    "angoissée": "angoisser",
    "angoissées": "angoisser",
    "angoissés": "angoisser",
    "angolaise": "angolais",
    "angolaises": "angolais",
    "angoras": "angora",
    "anguilles": "anguille",
    "anguillules": "anguillule",
    "angulaires": "angulaire",
    "anguleuse": "anguleux",
    "anguleuses": "anguleux",
    "angéliques": "angélique",
    "angélismes": "angélisme",
    "anhydrides": "anhydride",
    "anhèle": "anhéler",
    "anhélations": "anhélation",
    "anicroches": "anicroche",
    "anilines": "aniline",
    "anima": "animer",
    "animai": "animer",
    "animaient": "animer",
    "animais": "animer",
    "animait": "animer",
    "animalcules": "animalcule",
    "animale": "animal",
    "animales": "animal",
    "animaliers": "animalier",
    "animalisait": "animaliser",
    "animalise": "animaliser",
    "animalière": "animalier",
    "animalières": "animalier",
    "animant": "animer",
    "animas": "animer",
    "animasse": "animer",
    "animassent": "animer",
    "animasses": "animer",
    "animassiez": "animer",
    "animassions": "animer",
    "animateurs": "animateur",
    "animations": "animation",
    "animatrice": "animateur",
    "animatrices": "animateur",
    "animaux": "animal",
    "anime": "animer",
    "animent": "animer",
    "animera": "animer",
    "animerai": "animer",
    "animeraient": "animer",
    "animerais": "animer",
    "animerait": "animer",
    "animeras": "animer",
    "animerez": "animer",
    "animeriez": "animer",
    "animerions": "animer",
    "animerons": "animer",
    "animeront": "animer",
    "animes": "animer",
    "animez": "animer",
    "animiez": "animer",
    "animions": "animer",
    "animismes": "animisme",
    "animistes": "animiste",
    "animons": "animer",
    "animosités": "animosité",
    "animâmes": "animer",
    "animât": "animer",
    "animâtes": "animer",
    "animèrent": "animer",
    "animé": "animer",
    "animée": "animer",
    "animées": "animer",
    "animés": "animer",
    "anise": "aniser",
    "anisettes": "anisette",
    "anisé": "aniser",
    "anisée": "aniser",
    "anisées": "aniser",
    "ankylosait": "ankyloser",
    "ankyloses": "ankylose",
    "ankylosé": "ankyloser",
    "ankylosée": "ankyloser",
    "ankylosées": "ankyloser",
    "ankylosés": "ankyloser",
    "annamites": "annamite",
    "anneaux": "anneau",
    "annela": "anneler",
    "annelai": "anneler",
    "annelaient": "anneler",
    "annelais": "anneler",
    "annelait": "anneler",
    "annelant": "anneler",
    "annelas": "anneler",
    "annelasse": "anneler",
    "annelassent": "anneler",
    "annelasses": "anneler",
    "annelassiez": "anneler",
    "annelassions": "anneler",
    "annelets": "annelet",
    "annelez": "anneler",
    "anneliez": "anneler",
    "annelions": "anneler",
    "annelle": "anneler",
    "annellent": "anneler",
    "annellera": "anneler",
    "annellerai": "anneler",
    "annelleraient": "anneler",
    "annellerais": "anneler",
    "annellerait": "anneler",
    "annelleras": "anneler",
    "annellerez": "anneler",
    "annelleriez": "anneler",
    "annellerions": "anneler",
    "annellerons": "anneler",
    "annelleront": "anneler",
    "annelles": "anneler",
    "annelons": "anneler",
    "annelures": "annelure",
    "annelâmes": "anneler",
    "annelât": "anneler",
    "annelâtes": "anneler",
    "annelèrent": "anneler",
    "annelé": "anneler",
    "annelée": "anneler",
    "annelées": "anneler",
    "annelés": "anneler",
    "annexa": "annexer",
    "annexai": "annexer",
    "annexaient": "annexer",
    "annexais": "annexer",
    "annexait": "annexer",
    "annexant": "annexer",
    "annexas": "annexer",
    "annexasse": "annexer",
    "annexassent": "annexer",
    "annexasses": "annexer",
    "annexassiez": "annexer",
    "annexassions": "annexer",
    "annexe": "annexer",
    "annexent": "annexer",
    "annexera": "annexer",
    "annexerai": "annexer",
    "annexeraient": "annexer",
    "annexerais": "annexer",
    "annexerait": "annexer",
    "annexeras": "annexer",
    "annexerez": "annexer",
    "annexeriez": "annexer",
    "annexerions": "annexer",
    "annexerons": "annexer",
    "annexeront": "annexer",
    "annexes": "annexer",
    "annexez": "annexer",
    "annexiez": "annexer",
    "annexionnismes": "annexionnisme",
    "annexions": "annexion",
    "annexons": "annexer",
    "annexâmes": "annexer",
    "annexât": "annexer",
    "annexâtes": "annexer",
    "annexèrent": "annexer",
    "annexé": "annexer",
    "annexée": "annexer",
    "annexées": "annexer",
    "annexés": "annexer",
    "annihila": "annihiler",
    "annihilai": "annihiler",
    "annihilaient": "annihiler",
    "annihilais": "annihiler",
    "annihilait": "annihiler",
    "annihilant": "annihiler",
    "annihilante": "annihilant",
    "annihilas": "annihiler",
    "annihilasse": "annihiler",
    "annihilassent": "annihiler",
    "annihilasses": "annihiler",
    "annihilassiez": "annihiler",
    "annihilassions": "annihiler",
    "annihile": "annihiler",
    "annihilent": "annihiler",
    "annihilera": "annihiler",
    "annihilerai": "annihiler",
    "annihileraient": "annihiler",
    "annihilerais": "annihiler",
    "annihilerait": "annihiler",
    "annihileras": "annihiler",
    "annihilerez": "annihiler",
    "annihileriez": "annihiler",
    "annihilerions": "annihiler",
    "annihilerons": "annihiler",
    "annihileront": "annihiler",
    "annihiles": "annihiler",
    "annihilez": "annihiler",
    "annihiliez": "annihiler",
    "annihilions": "annihiler",
    "annihilons": "annihiler",
    "annihilâmes": "annihiler",
    "annihilât": "annihiler",
    "annihilâtes": "annihiler",
    "annihilèrent": "annihiler",
    "annihilé": "annihiler",
    "annihilée": "annihiler",
    "annihilées": "annihiler",
    "annihilés": "annihiler",
    "anniversaires": "anniversaire",
    "annonce": "annoncer",
    "annoncent": "annoncer",
    "annoncera": "annoncer",
    "annoncerai": "annoncer",
    "annonceraient": "annoncer",
    "annoncerais": "annoncer",
    "annoncerait": "annoncer",
    "annonceras": "annoncer",
    "annoncerez": "annoncer",
    "annonceriez": "annoncer",
    "annoncerions": "annoncer",
    "annoncerons": "annoncer",
    "annonceront": "annoncer",
    "annonces": "annoncer",
    "annonceurs": "annonceur",
    "annonceuse": "annonceur",
    "annoncez": "annoncer",
    "annonciateurs": "annonciateur",
    "annonciations": "annonciation",
    "annonciatrice": "annonciateur",
    "annonciatrices": "annonciateur",
    "annonciez": "annoncer",
    "annoncions": "annoncer",
    "annoncèrent": "annoncer",
    "annoncé": "annoncer",
    "annoncée": "annoncer",
    "annoncées": "annoncer",
    "annoncés": "annoncer",
    "annonça": "annoncer",
    "annonçai": "annoncer",
    "annonçaient": "annoncer",
    "annonçais": "annoncer",
    "annonçait": "annoncer",
    "annonçant": "annoncer",
    "annonças": "annoncer",
    "annonçasse": "annoncer",
    "annonçassent": "annoncer",
    "annonçasses": "annoncer",
    "annonçassiez": "annoncer",
    "annonçassions": "annoncer",
    "annonçons": "annoncer",
    "annonçâmes": "annoncer",
    "annonçât": "annoncer",
    "annonçâtes": "annoncer",
    "annota": "annoter",
    "annotai": "annoter",
    "annotaient": "annoter",
    "annotais": "annoter",
    "annotait": "annoter",
    "annotant": "annoter",
    "annotas": "annoter",
    "annotasse": "annoter",
    "annotassent": "annoter",
    "annotasses": "annoter",
    "annotassiez": "annoter",
    "annotassions": "annoter",
    "annotations": "annotation",
    "annote": "annoter",
    "annotent": "annoter",
    "annotera": "annoter",
    "annoterai": "annoter",
    "annoteraient": "annoter",
    "annoterais": "annoter",
    "annoterait": "annoter",
    "annoteras": "annoter",
    "annoterez": "annoter",
    "annoteriez": "annoter",
    "annoterions": "annoter",
    "annoterons": "annoter",
    "annoteront": "annoter",
    "annotes": "annoter",
    "annotez": "annoter",
    "annotiez": "annoter",
    "annotions": "annoter",
    "annotons": "annoter",
    "annotâmes": "annoter",
    "annotât": "annoter",
    "annotâtes": "annoter",
    "annotèrent": "annoter",
    "annoté": "annoter",
    "annotée": "annoter",
    "annotées": "annoter",
    "annotés": "annoter",
    "annuaires": "annuaire",
    "annuelle": "annuel",
    "annuelles": "annuel",
    "annuels": "annuel",
    "annuités": "annuité",
    "annula": "annuler",
    "annulai": "annuler",
    "annulaient": "annuler",
    "annulaires": "annulaire",
    "annulais": "annuler",
    "annulait": "annuler",
    "annulant": "annuler",
    "annulas": "annuler",
    "annulasse": "annuler",
    "annulassent": "annuler",
    "annulasses": "annuler",
    "annulassiez": "annuler",
    "annulassions": "annuler",
    "annulations": "annulation",
    "annule": "annuler",
    "annulent": "annuler",
    "annulera": "annuler",
    "annulerai": "annuler",
    "annuleraient": "annuler",
    "annulerais": "annuler",
    "annulerait": "annuler",
    "annuleras": "annuler",
    "annulerez": "annuler",
    "annuleriez": "annuler",
    "annulerions": "annuler",
    "annulerons": "annuler",
    "annuleront": "annuler",
    "annules": "annuler",
    "annulez": "annuler",
    "annuliez": "annuler",
    "annulions": "annuler",
    "annulons": "annuler",
    "annulâmes": "annuler",
    "annulât": "annuler",
    "annulâtes": "annuler",
    "annulèrent": "annuler",
    "annulé": "annuler",
    "annulée": "annuler",
    "annulées": "annuler",
    "annulés": "annuler",
    "années": "année",
    "années-homme": "année-homme",
    "années-lumière": "année-lumière",
    "anobli": "anoblir",
    "anoblie": "anoblir",
    "anoblies": "anoblir",
    "anoblira": "anoblir",
    "anoblirai": "anoblir",
    "anobliraient": "anoblir",
    "anoblirais": "anoblir",
    "anoblirait": "anoblir",
    "anobliras": "anoblir",
    "anoblirent": "anoblir",
    "anoblirez": "anoblir",
    "anobliriez": "anoblir",
    "anoblirions": "anoblir",
    "anoblirons": "anoblir",
    "anobliront": "anoblir",
    "anoblis": "anoblir",
    "anoblissaient": "anoblir",
    "anoblissais": "anoblir",
    "anoblissait": "anoblir",
    "anoblissant": "anoblir",
    "anoblissante": "anoblissant",
    "anoblisse": "anoblir",
    "anoblissent": "anoblir",
    "anoblisses": "anoblir",
    "anoblissez": "anoblir",
    "anoblissiez": "anoblir",
    "anoblissions": "anoblir",
    "anoblissons": "anoblir",
    "anoblit": "anoblir",
    "anoblîmes": "anoblir",
    "anoblît": "anoblir",
    "anoblîtes": "anoblir",
    "anodes": "anode",
    "anodine": "anodin",
    "anodines": "anodin",
    "anodins": "anodin",
    "anodisé": "anodiser",
    "anomale": "anomal",
    "anomales": "anomal",
    "anomalies": "anomalie",
    "anomaux": "anomal",
    "anonymats": "anonymat",
    "anonymes": "anonyme",
    "anoraks": "anorak",
    "anordi": "anordir",
    "anordie": "anordir",
    "anordies": "anordir",
    "anordira": "anordir",
    "anordirai": "anordir",
    "anordiraient": "anordir",
    "anordirais": "anordir",
    "anordirait": "anordir",
    "anordiras": "anordir",
    "anordirent": "anordir",
    "anordirez": "anordir",
    "anordiriez": "anordir",
    "anordirions": "anordir",
    "anordirons": "anordir",
    "anordiront": "anordir",
    "anordis": "anordir",
    "anordissaient": "anordir",
    "anordissais": "anordir",
    "anordissait": "anordir",
    "anordissant": "anordir",
    "anordisse": "anordir",
    "anordissent": "anordir",
    "anordisses": "anordir",
    "anordissez": "anordir",
    "anordissiez": "anordir",
    "anordissions": "anordir",
    "anordissons": "anordir",
    "anordit": "anordir",
    "anordîmes": "anordir",
    "anordît": "anordir",
    "anordîtes": "anordir",
    "anorexies": "anorexie",
    "anorexiques": "anorexique",
    "anormale": "anormal",
    "anormales": "anormal",
    "anormaux": "anormal",
    "ans": "an",
    "anses": "anse",
    "ansée": "ansé",
    "ansées": "ansé",
    "antagonismes": "antagonisme",
    "antagonistes": "antagoniste",
    "antalgiques": "antalgique",
    "antarctiques": "antarctique",
    "antennes": "antenne",
    "anthologies": "anthologie",
    "anthracites": "anthracite",
    "anthropiques": "anthropique",
    "anthropisations": "anthropisation",
    "anthropocentriques": "anthropocentrique",
    "anthropologies": "anthropologie",
    "anthropologiques": "anthropologique",
    "anthropologues": "anthropologue",
    "anthropomorphes": "anthropomorphe",
    "anthropométries": "anthropométrie",
    "anthropométriques": "anthropométrique",
    "anthropophages": "anthropophage",
    "anthropophagiques": "anthropophagique",
    "anthropopithèques": "anthropopithèque",
    "anthropoïdes": "anthropoïde",
    "anthères": "anthère",
    "anti-atomiques": "anti-atomique",
    "anti-aérienne": "anti-aérien",
    "anti-aériens": "anti-aérien",
    "anti-bombes": "anti-bombe",
    "anti-bosons": "anti-boson",
    "anti-calciques": "anti-calcique",
    "anti-castristes": "anti-castriste",
    "anti-chambres": "anti-chambre",
    "anti-chars": "anti-char",
    "anti-chiens": "anti-chien",
    "anti-cocos": "anti-coco",
    "anti-célibataires": "anti-célibataire",
    "anti-dauphins": "anti-dauphin",
    "anti-douleurs": "anti-douleur",
    "anti-drogues": "anti-drogue",
    "anti-démocratiques": "anti-démocratique",
    "anti-espionnes": "anti-espionne",
    "anti-fantômes": "anti-fantôme",
    "anti-fusées": "anti-fusée",
    "anti-grimaces": "anti-grimace",
    "anti-hannetons": "anti-hanneton",
    "anti-immigrés": "anti-immigré",
    "anti-insectes": "anti-insecte",
    "anti-matières": "anti-matière",
    "anti-mecs": "anti-mec",
    "anti-missiles": "anti-missile",
    "anti-mites": "anti-mite",
    "anti-monstres": "anti-monstre",
    "anti-moustiques": "anti-moustique",
    "anti-médicaments": "anti-médicament",
    "anti-météorites": "anti-météorite",
    "anti-nucléaires": "anti-nucléaire",
    "anti-odeurs": "anti-odeur",
    "anti-odorants": "anti-odorant",
    "anti-progressistes": "anti-progressiste",
    "anti-puces": "anti-puce",
    "anti-pédérastiques": "anti-pédérastique",
    "anti-radiations": "anti-radiation",
    "anti-reflets": "anti-reflet",
    "anti-rides": "anti-ride",
    "anti-socialistes": "anti-socialiste",
    "anti-sous-marine": "anti-sous-marin",
    "anti-sous-marines": "anti-sous-marin",
    "anti-sous-marins": "anti-sous-marin",
    "anti-sèches": "anti-sèche",
    "anti-sémites": "anti-sémite",
    "anti-taches": "anti-tache",
    "anti-tornades": "anti-tornade",
    "anti-trusts": "anti-trust",
    "anti-vols": "anti-vol",
    "anti-émeutes": "anti-émeute",
    "antiacides": "antiacide",
    "antiallemands": "antiallemand",
    "antiaméricaine": "antiaméricain",
    "antiaméricaines": "antiaméricain",
    "antiaérienne": "antiaérien",
    "antiaériennes": "antiaérien",
    "antiaériens": "antiaérien",
    "antibiotiques": "antibiotique",
    "antibolcheviques": "antibolchevique",
    "antibrouillards": "antibrouillard",
    "anticastristes": "anticastriste",
    "anticatalyseurs": "anticatalyseur",
    "antichambres": "antichambre",
    "antichars": "antichar",
    "antichrétienne": "antichrétien",
    "anticipa": "anticiper",
    "anticipai": "anticiper",
    "anticipaient": "anticiper",
    "anticipais": "anticiper",
    "anticipait": "anticiper",
    "anticipant": "anticiper",
    "anticipas": "anticiper",
    "anticipasse": "anticiper",
    "anticipassent": "anticiper",
    "anticipasses": "anticiper",
    "anticipassiez": "anticiper",
    "anticipassions": "anticiper",
    "anticipations": "anticipation",
    "anticipatrice": "anticipateur",
    "anticipe": "anticiper",
    "anticipent": "anticiper",
    "anticipera": "anticiper",
    "anticiperai": "anticiper",
    "anticiperaient": "anticiper",
    "anticiperais": "anticiper",
    "anticiperait": "anticiper",
    "anticiperas": "anticiper",
    "anticiperez": "anticiper",
    "anticiperiez": "anticiper",
    "anticiperions": "anticiper",
    "anticiperons": "anticiper",
    "anticiperont": "anticiper",
    "anticipes": "anticiper",
    "anticipez": "anticiper",
    "anticipiez": "anticiper",
    "anticipions": "anticiper",
    "anticipons": "anticiper",
    "anticipâmes": "anticiper",
    "anticipât": "anticiper",
    "anticipâtes": "anticiper",
    "anticipèrent": "anticiper",
    "anticipé": "anticiper",
    "anticipée": "anticiper",
    "anticipées": "anticiper",
    "anticipés": "anticiper",
    "anticlinale": "anticlinal",
    "anticlinales": "anticlinal",
    "anticlinaux": "anticlinal",
    "anticléricale": "anticlérical",
    "anticléricales": "anticlérical",
    "anticléricaux": "anticlérical",
    "anticoagulants": "anticoagulant",
    "anticoccidienne": "anticoccidien",
    "anticoccidiennes": "anticoccidien",
    "anticoccidiens": "anticoccidien",
    "anticommunismes": "anticommunisme",
    "anticommunistes": "anticommuniste",
    "anticonceptionnelle": "anticonceptionnel",
    "anticonceptionnelles": "anticonceptionnel",
    "anticonceptionnels": "anticonceptionnel",
    "anticoncurrentielle": "anticoncurrentiel",
    "anticoncurrentielles": "anticoncurrentiel",
    "anticoncurrentiels": "anticoncurrentiel",
    "anticonformismes": "anticonformisme",
    "anticonstitutionnelle": "anticonstitutionnel",
    "anticonstitutionnelles": "anticonstitutionnel",
    "anticonstitutionnels": "anticonstitutionnel",
    "anticyclonale": "anticyclonal",
    "anticyclonales": "anticyclonal",
    "anticyclonaux": "anticyclonal",
    "anticyclones": "anticyclone",
    "anticycloniques": "anticyclonique",
    "antidata": "antidater",
    "antidatai": "antidater",
    "antidataient": "antidater",
    "antidatais": "antidater",
    "antidatait": "antidater",
    "antidatant": "antidater",
    "antidatas": "antidater",
    "antidatasse": "antidater",
    "antidatassent": "antidater",
    "antidatasses": "antidater",
    "antidatassiez": "antidater",
    "antidatassions": "antidater",
    "antidate": "antidater",
    "antidatent": "antidater",
    "antidatera": "antidater",
    "antidaterai": "antidater",
    "antidateraient": "antidater",
    "antidaterais": "antidater",
    "antidaterait": "antidater",
    "antidateras": "antidater",
    "antidaterez": "antidater",
    "antidateriez": "antidater",
    "antidaterions": "antidater",
    "antidaterons": "antidater",
    "antidateront": "antidater",
    "antidates": "antidater",
    "antidatez": "antidater",
    "antidatiez": "antidater",
    "antidations": "antidater",
    "antidatons": "antidater",
    "antidatâmes": "antidater",
    "antidatât": "antidater",
    "antidatâtes": "antidater",
    "antidatèrent": "antidater",
    "antidaté": "antidater",
    "antidatée": "antidater",
    "antidatées": "antidater",
    "antidatés": "antidater",
    "antidictatoriaux": "antidictatorial",
    "antidopages": "antidopage",
    "antidotes": "antidote",
    "antidreyfusarde": "antidreyfusard",
    "antidreyfusards": "antidreyfusard",
    "antidémocratiques": "antidémocratique",
    "antidépresseurs": "antidépresseur",
    "antidérapante": "antidérapant",
    "antidérapantes": "antidérapant",
    "antidérapants": "antidérapant",
    "antiennes": "antienne",
    "antifascistes": "antifasciste",
    "antifrançaise": "antifrançais",
    "antifrançaises": "antifrançais",
    "antigangs": "antigang",
    "antigaullistes": "antigaulliste",
    "antigouvernementale": "antigouvernemental",
    "antigouvernementales": "antigouvernemental",
    "antigouvernementaux": "antigouvernemental",
    "antigènes": "antigène",
    "antihalos": "antihalo",
    "antihistaminiques": "antihistaminique",
    "antihémorragiques": "antihémorragique",
    "antillaise": "antillais",
    "antillaises": "antillais",
    "antilopes": "antilope",
    "antimarxistes": "antimarxiste",
    "antimatières": "antimatière",
    "antimaçonniques": "antimaçonnique",
    "antimilitaristes": "antimilitariste",
    "antimissiles": "antimissile",
    "antimites": "antimite",
    "antimitotiques": "antimitotique",
    "antimoines": "antimoine",
    "antinationale": "antinational",
    "antinationales": "antinational",
    "antinationalistes": "antinationaliste",
    "antinationaux": "antinational",
    "antinaturelle": "antinaturel",
    "antinazie": "antinazi",
    "antinazis": "antinazi",
    "antinomies": "antinomie",
    "antinomiques": "antinomique",
    "antinucléaires": "antinucléaire",
    "antioxydants": "antioxydant",
    "antipapes": "antipape",
    "antiparasitaires": "antiparasitaire",
    "antiparasites": "antiparasite",
    "antipathies": "antipathie",
    "antipathiques": "antipathique",
    "antipatriotiques": "antipatriotique",
    "antipersonnelle": "antipersonnel",
    "antipersonnelles": "antipersonnel",
    "antiphonaires": "antiphonaire",
    "antiphrases": "antiphrase",
    "antiphysiques": "antiphysique",
    "antipodes": "antipode",
    "antipodistes": "antipodiste",
    "antipoisons": "antipoison",
    "antiprotons": "antiproton",
    "antipsychotiques": "antipsychotique",
    "antiquailleries": "antiquaillerie",
    "antiquailles": "antiquaille",
    "antiquaires": "antiquaire",
    "antiques": "antique",
    "antiquités": "antiquité",
    "antirabiques": "antirabique",
    "antiracismes": "antiracisme",
    "antiracistes": "antiraciste",
    "antireligieuse": "antireligieux",
    "antirocardienne": "antirocardien",
    "antirocardiennes": "antirocardien",
    "antirocardiens": "antirocardien",
    "antirouilles": "antirouille",
    "antisandinistes": "antisandiniste",
    "antisepsies": "antisepsie",
    "antiseptiques": "antiseptique",
    "antisexistes": "antisexiste",
    "antisionistes": "antisioniste",
    "antisociale": "antisocial",
    "antisociales": "antisocial",
    "antisocialistes": "antisocialiste",
    "antisociaux": "antisocial",
    "antisolaires": "antisolaire",
    "antisoviétiques": "antisoviétique",
    "antistaliniens": "antistalinien",
    "antistatiques": "antistatique",
    "antisyndicale": "antisyndical",
    "antisyndicales": "antisyndical",
    "antisyndicaux": "antisyndical",
    "antisèches": "antisèche",
    "antisémites": "antisémite",
    "antisémitismes": "antisémitisme",
    "antiterrorismes": "antiterrorisme",
    "antiterroristes": "antiterroriste",
    "antithèses": "antithèse",
    "antithétiques": "antithétique",
    "antitussives": "antitussif",
    "antiviraux": "antiviral",
    "antivols": "antivol",
    "antonymes": "antonyme",
    "antres": "antre",
    "anté": "anter",
    "antéchrists": "antéchrist",
    "antécédente": "antécédent",
    "antécédentes": "antécédent",
    "antécédents": "antécédent",
    "antédiluvienne": "antédiluvien",
    "antédiluviennes": "antédiluvien",
    "antédiluviens": "antédiluvien",
    "antépénultièmes": "antépénultième",
    "antérieure": "antérieur",
    "antérieures": "antérieur",
    "antérieurs": "antérieur",
    "antériorités": "antériorité",
    "anuité": "anuiter",
    "anuitées": "anuiter",
    "anversoise": "anversois",
    "anversoises": "anversois",
    "anxieuse": "anxieux",
    "anxieuses": "anxieux",
    "anxiolytiques": "anxiolytique",
    "anxiétés": "anxiété",
    "anéanti": "anéantir",
    "anéantie": "anéantir",
    "anéanties": "anéantir",
    "anéantira": "anéantir",
    "anéantirai": "anéantir",
    "anéantiraient": "anéantir",
    "anéantirais": "anéantir",
    "anéantirait": "anéantir",
    "anéantiras": "anéantir",
    "anéantirent": "anéantir",
    "anéantirez": "anéantir",
    "anéantiriez": "anéantir",
    "anéantirions": "anéantir",
    "anéantirons": "anéantir",
    "anéantiront": "anéantir",
    "anéantis": "anéantir",
    "anéantissaient": "anéantir",
    "anéantissais": "anéantir",
    "anéantissait": "anéantir",
    "anéantissant": "anéantir",
    "anéantissante": "anéantissant",
    "anéantissantes": "anéantissant",
    "anéantisse": "anéantir",
    "anéantissements": "anéantissement",
    "anéantissent": "anéantir",
    "anéantisses": "anéantir",
    "anéantissez": "anéantir",
    "anéantissiez": "anéantir",
    "anéantissions": "anéantir",
    "anéantissons": "anéantir",
    "anéantit": "anéantir",
    "anéantîmes": "anéantir",
    "anéantît": "anéantir",
    "anéantîtes": "anéantir",
    "anémiais": "anémier",
    "anémiante": "anémiant",
    "anémie": "anémier",
    "anémies": "anémie",
    "anémiques": "anémique",
    "anémié": "anémier",
    "anémiée": "anémier",
    "anémiés": "anémié",
    "anémones": "anémone",
    "anévrismes": "anévrisme",
    "anévrysmes": "anévrysme",
    "aortes": "aorte",
    "aortiques": "aortique",
    "aouls": "aoul",
    "aounistes": "aouniste",
    "aoûtats": "aoûtat",
    "aoûtienne": "aoûtien",
    "aoûtiennes": "aoûtien",
    "aoûtiens": "aoûtien",
    "aoûts": "août",
    "apaches": "apache",
    "apaisa": "apaiser",
    "apaisai": "apaiser",
    "apaisaient": "apaiser",
    "apaisais": "apaiser",
    "apaisait": "apaiser",
    "apaisant": "apaiser",
    "apaisante": "apaisant",
    "apaisantes": "apaisant",
    "apaisants": "apaisant",
    "apaisas": "apaiser",
    "apaisasse": "apaiser",
    "apaisassent": "apaiser",
    "apaisasses": "apaiser",
    "apaisassiez": "apaiser",
    "apaisassions": "apaiser",
    "apaise": "apaiser",
    "apaisements": "apaisement",
    "apaisent": "apaiser",
    "apaisera": "apaiser",
    "apaiserai": "apaiser",
    "apaiseraient": "apaiser",
    "apaiserais": "apaiser",
    "apaiserait": "apaiser",
    "apaiseras": "apaiser",
    "apaiserez": "apaiser",
    "apaiseriez": "apaiser",
    "apaiserions": "apaiser",
    "apaiserons": "apaiser",
    "apaiseront": "apaiser",
    "apaises": "apaiser",
    "apaisez": "apaiser",
    "apaisiez": "apaiser",
    "apaisions": "apaiser",
    "apaisons": "apaiser",
    "apaisâmes": "apaiser",
    "apaisât": "apaiser",
    "apaisâtes": "apaiser",
    "apaisèrent": "apaiser",
    "apaisé": "apaiser",
    "apaisée": "apaiser",
    "apaisées": "apaiser",
    "apaisés": "apaiser",
    "apanages": "apanage",
    "apartheids": "apartheid",
    "apartés": "aparté",
    "apathies": "apathie",
    "apathiques": "apathique",
    "apatites": "apatite",
    "apatrides": "apatride",
    "apauvrissements": "apauvrissement",
    "aperceptions": "aperception",
    "apercevaient": "apercevoir",
    "apercevais": "apercevoir",
    "apercevait": "apercevoir",
    "apercevant": "apercevoir",
    "apercevez": "apercevoir",
    "aperceviez": "apercevoir",
    "apercevions": "apercevoir",
    "apercevons": "apercevoir",
    "apercevra": "apercevoir",
    "apercevrai": "apercevoir",
    "apercevraient": "apercevoir",
    "apercevrais": "apercevoir",
    "apercevrait": "apercevoir",
    "apercevras": "apercevoir",
    "apercevrez": "apercevoir",
    "apercevriez": "apercevoir",
    "apercevrions": "apercevoir",
    "apercevrons": "apercevoir",
    "apercevront": "apercevoir",
    "aperçois": "apercevoir",
    "aperçoit": "apercevoir",
    "aperçoive": "apercevoir",
    "aperçoivent": "apercevoir",
    "aperçoives": "apercevoir",
    "aperçu": "apercevoir",
    "aperçue": "apercevoir",
    "aperçues": "apercevoir",
    "aperçurent": "apercevoir",
    "aperçus": "aperçu",
    "aperçusse": "apercevoir",
    "aperçussent": "apercevoir",
    "aperçusses": "apercevoir",
    "aperçussiez": "apercevoir",
    "aperçussions": "apercevoir",
    "aperçut": "apercevoir",
    "aperçûmes": "apercevoir",
    "aperçût": "apercevoir",
    "aperçûtes": "apercevoir",
    "apes": "ape",
    "apesanteurs": "apesanteur",
    "apeura": "apeurer",
    "apeurai": "apeurer",
    "apeuraient": "apeurer",
    "apeurais": "apeurer",
    "apeurait": "apeurer",
    "apeurant": "apeurer",
    "apeuras": "apeurer",
    "apeurasse": "apeurer",
    "apeurassent": "apeurer",
    "apeurasses": "apeurer",
    "apeurassiez": "apeurer",
    "apeurassions": "apeurer",
    "apeure": "apeurer",
    "apeurent": "apeurer",
    "apeurera": "apeurer",
    "apeurerai": "apeurer",
    "apeureraient": "apeurer",
    "apeurerais": "apeurer",
    "apeurerait": "apeurer",
    "apeureras": "apeurer",
    "apeurerez": "apeurer",
    "apeureriez": "apeurer",
    "apeurerions": "apeurer",
    "apeurerons": "apeurer",
    "apeureront": "apeurer",
    "apeures": "apeurer",
    "apeurez": "apeurer",
    "apeuriez": "apeurer",
    "apeurions": "apeurer",
    "apeurons": "apeurer",
    "apeurâmes": "apeurer",
    "apeurât": "apeurer",
    "apeurâtes": "apeurer",
    "apeurèrent": "apeurer",
    "apeuré": "apeurer",
    "apeurée": "apeurer",
    "apeurées": "apeurer",
    "apeurés": "apeurer",
    "aphaniptères": "aphaniptère",
    "aphasies": "aphasie",
    "aphasiques": "aphasique",
    "aphones": "aphone",
    "aphorismes": "aphorisme",
    "aphrodisiaques": "aphrodisiaque",
    "aphtes": "aphte",
    "aphteuse": "aphteux",
    "aphteuses": "aphteux",
    "aphélies": "aphélie",
    "aphérèses": "aphérèse",
    "apicale": "apical",
    "apicales": "apical",
    "apicaux": "apical",
    "apicoles": "apicole",
    "apiculteurs": "apiculteur",
    "apicultrice": "apiculteur",
    "apicultrices": "apiculteur",
    "apicultures": "apiculture",
    "apiqua": "apiquer",
    "apiquai": "apiquer",
    "apiquaient": "apiquer",
    "apiquais": "apiquer",
    "apiquait": "apiquer",
    "apiquant": "apiquer",
    "apiquas": "apiquer",
    "apiquasse": "apiquer",
    "apiquassent": "apiquer",
    "apiquasses": "apiquer",
    "apiquassiez": "apiquer",
    "apiquassions": "apiquer",
    "apique": "apiquer",
    "apiquent": "apiquer",
    "apiquera": "apiquer",
    "apiquerai": "apiquer",
    "apiqueraient": "apiquer",
    "apiquerais": "apiquer",
    "apiquerait": "apiquer",
    "apiqueras": "apiquer",
    "apiquerez": "apiquer",
    "apiqueriez": "apiquer",
    "apiquerions": "apiquer",
    "apiquerons": "apiquer",
    "apiqueront": "apiquer",
    "apiques": "apiquer",
    "apiquez": "apiquer",
    "apiquiez": "apiquer",
    "apiquions": "apiquer",
    "apiquons": "apiquer",
    "apiquâmes": "apiquer",
    "apiquât": "apiquer",
    "apiquâtes": "apiquer",
    "apiquèrent": "apiquer",
    "apiqué": "apiquer",
    "apiquée": "apiquer",
    "apiquées": "apiquer",
    "apiqués": "apiquer",
    "apis": "api",
    "apitoie": "apitoyer",
    "apitoiements": "apitoiement",
    "apitoient": "apitoyer",
    "apitoiera": "apitoyer",
    "apitoierai": "apitoyer",
    "apitoieraient": "apitoyer",
    "apitoierais": "apitoyer",
    "apitoierait": "apitoyer",
    "apitoieras": "apitoyer",
    "apitoierez": "apitoyer",
    "apitoieriez": "apitoyer",
    "apitoierions": "apitoyer",
    "apitoierons": "apitoyer",
    "apitoieront": "apitoyer",
    "apitoies": "apitoyer",
    "apitoya": "apitoyer",
    "apitoyai": "apitoyer",
    "apitoyaient": "apitoyer",
    "apitoyais": "apitoyer",
    "apitoyait": "apitoyer",
    "apitoyant": "apitoyer",
    "apitoyas": "apitoyer",
    "apitoyasse": "apitoyer",
    "apitoyassent": "apitoyer",
    "apitoyasses": "apitoyer",
    "apitoyassiez": "apitoyer",
    "apitoyassions": "apitoyer",
    "apitoyez": "apitoyer",
    "apitoyiez": "apitoyer",
    "apitoyions": "apitoyer",
    "apitoyons": "apitoyer",
    "apitoyâmes": "apitoyer",
    "apitoyât": "apitoyer",
    "apitoyâtes": "apitoyer",
    "apitoyèrent": "apitoyer",
    "apitoyé": "apitoyer",
    "apitoyée": "apitoyer",
    "apitoyées": "apitoyer",
    "apitoyés": "apitoyer",
    "aplani": "aplanir",
    "aplanie": "aplanir",
    "aplanies": "aplanir",
    "aplanira": "aplanir",
    "aplanirai": "aplanir",
    "aplaniraient": "aplanir",
    "aplanirais": "aplanir",
    "aplanirait": "aplanir",
    "aplaniras": "aplanir",
    "aplanirent": "aplanir",
    "aplanirez": "aplanir",
    "aplaniriez": "aplanir",
    "aplanirions": "aplanir",
    "aplanirons": "aplanir",
    "aplaniront": "aplanir",
    "aplanis": "aplanir",
    "aplanissaient": "aplanir",
    "aplanissais": "aplanir",
    "aplanissait": "aplanir",
    "aplanissant": "aplanir",
    "aplanisse": "aplanir",
    "aplanissent": "aplanir",
    "aplanisses": "aplanir",
    "aplanissez": "aplanir",
    "aplanissiez": "aplanir",
    "aplanissions": "aplanir",
    "aplanissons": "aplanir",
    "aplanit": "aplanir",
    "aplanîmes": "aplanir",
    "aplanît": "aplanir",
    "aplanîtes": "aplanir",
    "aplati": "aplatir",
    "aplatie": "aplatir",
    "aplaties": "aplatir",
    "aplatira": "aplatir",
    "aplatirai": "aplatir",
    "aplatiraient": "aplatir",
    "aplatirais": "aplatir",
    "aplatirait": "aplatir",
    "aplatiras": "aplatir",
    "aplatirent": "aplatir",
    "aplatirez": "aplatir",
    "aplatiriez": "aplatir",
    "aplatirions": "aplatir",
    "aplatirons": "aplatir",
    "aplatiront": "aplatir",
    "aplatis": "aplatir",
    "aplatissaient": "aplatir",
    "aplatissais": "aplatir",
    "aplatissait": "aplatir",
    "aplatissant": "aplatir",
    "aplatisse": "aplatir",
    "aplatissements": "aplatissement",
    "aplatissent": "aplatir",
    "aplatisses": "aplatir",
    "aplatissez": "aplatir",
    "aplatissiez": "aplatir",
    "aplatissions": "aplatir",
    "aplatissons": "aplatir",
    "aplatit": "aplatir",
    "aplats": "aplat",
    "aplatîmes": "aplatir",
    "aplatît": "aplatir",
    "aplatîtes": "aplatir",
    "aplombs": "aplomb",
    "apocalypses": "apocalypse",
    "apocalyptiques": "apocalyptique",
    "apocopes": "apocope",
    "apocryphes": "apocryphe",
    "apodoses": "apodose",
    "apogées": "apogée",
    "apolitiques": "apolitique",
    "apollons": "apollon",
    "apologies": "apologie",
    "apologistes": "apologiste",
    "apologues": "apologue",
    "apologétiques": "apologétique",
    "aponévroses": "aponévrose",
    "apophtegmes": "apophtegme",
    "apophyses": "apophyse",
    "apoplectiques": "apoplectique",
    "apoplexies": "apoplexie",
    "aposta": "aposter",
    "apostai": "aposter",
    "apostaient": "aposter",
    "apostais": "aposter",
    "apostait": "aposter",
    "apostant": "aposter",
    "apostas": "aposter",
    "apostasia": "apostasier",
    "apostasiai": "apostasier",
    "apostasiaient": "apostasier",
    "apostasiais": "apostasier",
    "apostasiait": "apostasier",
    "apostasiant": "apostasier",
    "apostasias": "apostasier",
    "apostasiasse": "apostasier",
    "apostasiassent": "apostasier",
    "apostasiasses": "apostasier",
    "apostasiassiez": "apostasier",
    "apostasiassions": "apostasier",
    "apostasie": "apostasier",
    "apostasient": "apostasier",
    "apostasiera": "apostasier",
    "apostasierai": "apostasier",
    "apostasieraient": "apostasier",
    "apostasierais": "apostasier",
    "apostasierait": "apostasier",
    "apostasieras": "apostasier",
    "apostasierez": "apostasier",
    "apostasieriez": "apostasier",
    "apostasierions": "apostasier",
    "apostasierons": "apostasier",
    "apostasieront": "apostasier",
    "apostasies": "apostasier",
    "apostasiez": "apostasier",
    "apostasiiez": "apostasier",
    "apostasiions": "apostasier",
    "apostasions": "apostasier",
    "apostasiâmes": "apostasier",
    "apostasiât": "apostasier",
    "apostasiâtes": "apostasier",
    "apostasièrent": "apostasier",
    "apostasié": "apostasier",
    "apostasiée": "apostasier",
    "apostasiées": "apostasier",
    "apostasiés": "apostasier",
    "apostasse": "aposter",
    "apostassent": "aposter",
    "apostasses": "aposter",
    "apostassiez": "aposter",
    "apostassions": "aposter",
    "apostate": "apostat",
    "apostates": "apostat",
    "apostats": "apostat",
    "aposte": "aposter",
    "apostent": "aposter",
    "apostera": "aposter",
    "aposterai": "aposter",
    "aposteraient": "aposter",
    "aposterais": "aposter",
    "aposterait": "aposter",
    "aposteras": "aposter",
    "aposterez": "aposter",
    "aposteriez": "aposter",
    "aposterions": "aposter",
    "aposterons": "aposter",
    "aposteront": "aposter",
    "apostes": "aposter",
    "apostez": "aposter",
    "apostiez": "aposter",
    "apostilles": "apostille",
    "apostillée": "apostiller",
    "apostions": "aposter",
    "apostolats": "apostolat",
    "apostoliques": "apostolique",
    "apostons": "aposter",
    "apostropha": "apostropher",
    "apostrophaient": "apostropher",
    "apostrophait": "apostropher",
    "apostrophant": "apostropher",
    "apostrophe": "apostropher",
    "apostrophent": "apostropher",
    "apostrophes": "apostropher",
    "apostrophèrent": "apostropher",
    "apostrophé": "apostropher",
    "apostrophée": "apostropher",
    "apostâmes": "aposter",
    "apostât": "aposter",
    "apostâtes": "aposter",
    "apostèrent": "aposter",
    "aposté": "aposter",
    "apostée": "aposter",
    "apostées": "aposter",
    "apostés": "aposter",
    "apothicaires": "apothicaire",
    "apothèmes": "apothème",
    "apothéoses": "apothéose",
    "apparais": "apparaître",
    "apparaissaient": "apparaître",
    "apparaissais": "apparaître",
    "apparaissait": "apparaître",
    "apparaissant": "apparaître",
    "apparaisse": "apparaître",
    "apparaissent": "apparaître",
    "apparaisses": "apparaître",
    "apparaissez": "apparaître",
    "apparaissiez": "apparaître",
    "apparaissions": "apparaître",
    "apparaissons": "apparaître",
    "apparatchiks": "apparatchik",
    "apparats": "apparat",
    "apparaît": "apparaître",
    "apparaîtra": "apparaître",
    "apparaîtrai": "apparaître",
    "apparaîtraient": "apparaître",
    "apparaîtrais": "apparaître",
    "apparaîtrait": "apparaître",
    "apparaîtras": "apparaître",
    "apparaîtrez": "apparaître",
    "apparaîtriez": "apparaître",
    "apparaîtrions": "apparaître",
    "apparaîtrons": "apparaître",
    "apparaîtront": "apparaître",
    "appareilla": "appareiller",
    "appareillages": "appareillage",
    "appareillai": "appareiller",
    "appareillaient": "appareiller",
    "appareillais": "appareiller",
    "appareillait": "appareiller",
    "appareillant": "appareiller",
    "appareillas": "appareiller",
    "appareillasse": "appareiller",
    "appareillassent": "appareiller",
    "appareillasses": "appareiller",
    "appareillassiez": "appareiller",
    "appareillassions": "appareiller",
    "appareille": "appareiller",
    "appareillent": "appareiller",
    "appareillera": "appareiller",
    "appareillerai": "appareiller",
    "appareilleraient": "appareiller",
    "appareillerais": "appareiller",
    "appareillerait": "appareiller",
    "appareilleras": "appareiller",
    "appareillerez": "appareiller",
    "appareilleriez": "appareiller",
    "appareillerions": "appareiller",
    "appareillerons": "appareiller",
    "appareilleront": "appareiller",
    "appareilles": "appareiller",
    "appareillez": "appareiller",
    "appareilliez": "appareiller",
    "appareillions": "appareiller",
    "appareillons": "appareiller",
    "appareillâmes": "appareiller",
    "appareillât": "appareiller",
    "appareillâtes": "appareiller",
    "appareillèrent": "appareiller",
    "appareillé": "appareiller",
    "appareillée": "appareiller",
    "appareillées": "appareiller",
    "appareillés": "appareiller",
    "appareils": "appareil",
    "apparences": "apparence",
    "apparenta": "apparenter",
    "apparentai": "apparenter",
    "apparentaient": "apparenter",
    "apparentais": "apparenter",
    "apparentait": "apparenter",
    "apparentant": "apparenter",
    "apparentas": "apparenter",
    "apparentasse": "apparenter",
    "apparentassent": "apparenter",
    "apparentasses": "apparenter",
    "apparentassiez": "apparenter",
    "apparentassions": "apparenter",
    "apparente": "apparenter",
    "apparentent": "apparenter",
    "apparentera": "apparenter",
    "apparenterai": "apparenter",
    "apparenteraient": "apparenter",
    "apparenterais": "apparenter",
    "apparenterait": "apparenter",
    "apparenteras": "apparenter",
    "apparenterez": "apparenter",
    "apparenteriez": "apparenter",
    "apparenterions": "apparenter",
    "apparenterons": "apparenter",
    "apparenteront": "apparenter",
    "apparentes": "apparenter",
    "apparentez": "apparenter",
    "apparentiez": "apparenter",
    "apparentions": "apparenter",
    "apparentons": "apparenter",
    "apparents": "apparent",
    "apparentâmes": "apparenter",
    "apparentât": "apparenter",
    "apparentâtes": "apparenter",
    "apparentèrent": "apparenter",
    "apparenté": "apparenter",
    "apparentée": "apparenter",
    "apparentées": "apparenter",
    "apparentés": "apparenter",
    "apparia": "apparier",
    "appariai": "apparier",
    "appariaient": "apparier",
    "appariais": "apparier",
    "appariait": "apparier",
    "appariant": "apparier",
    "apparias": "apparier",
    "appariasse": "apparier",
    "appariassent": "apparier",
    "appariasses": "apparier",
    "appariassiez": "apparier",
    "appariassions": "apparier",
    "apparie": "apparier",
    "appariements": "appariement",
    "apparient": "apparier",
    "appariera": "apparier",
    "apparierai": "apparier",
    "apparieraient": "apparier",
    "apparierais": "apparier",
    "apparierait": "apparier",
    "apparieras": "apparier",
    "apparierez": "apparier",
    "apparieriez": "apparier",
    "apparierions": "apparier",
    "apparierons": "apparier",
    "apparieront": "apparier",
    "apparies": "apparier",
    "appariez": "apparier",
    "appariiez": "apparier",
    "appariions": "apparier",
    "apparions": "apparier",
    "appariteurs": "appariteur",
    "apparitions": "apparition",
    "appariâmes": "apparier",
    "appariât": "apparier",
    "appariâtes": "apparier",
    "apparièrent": "apparier",
    "apparié": "apparier",
    "appariée": "apparier",
    "appariées": "apparier",
    "appariés": "apparier",
    "appartements": "appartement",
    "appartenaient": "appartenir",
    "appartenais": "appartenir",
    "appartenait": "appartenir",
    "appartenances": "appartenance",
    "appartenant": "appartenir",
    "appartenez": "appartenir",
    "apparteniez": "appartenir",
    "appartenions": "appartenir",
    "appartenons": "appartenir",
    "appartenu": "appartenir",
    "appartenues": "appartenir",
    "appartiendra": "appartenir",
    "appartiendrai": "appartenir",
    "appartiendraient": "appartenir",
    "appartiendrais": "appartenir",
    "appartiendrait": "appartenir",
    "appartiendras": "appartenir",
    "appartiendrez": "appartenir",
    "appartiendriez": "appartenir",
    "appartiendrions": "appartenir",
    "appartiendrons": "appartenir",
    "appartiendront": "appartenir",
    "appartienne": "appartenir",
    "appartiennent": "appartenir",
    "appartiennes": "appartenir",
    "appartiens": "appartenir",
    "appartient": "appartenir",
    "appartinrent": "appartenir",
    "appartins": "appartenir",
    "appartinsse": "appartenir",
    "appartinssent": "appartenir",
    "appartinsses": "appartenir",
    "appartinssiez": "appartenir",
    "appartinssions": "appartenir",
    "appartint": "appartenir",
    "apparts": "appart",
    "appartînmes": "appartenir",
    "appartînt": "appartenir",
    "appartîntes": "appartenir",
    "apparu": "apparaître",
    "apparue": "apparaître",
    "apparues": "apparaître",
    "apparurent": "apparaître",
    "apparus": "apparaître",
    "apparusse": "apparaître",
    "apparussent": "apparaître",
    "apparusses": "apparaître",
    "apparussiez": "apparaître",
    "apparussions": "apparaître",
    "apparut": "apparaître",
    "apparûmes": "apparaître",
    "apparût": "apparaître",
    "apparûtes": "apparaître",
    "appauvri": "appauvrir",
    "appauvrie": "appauvrir",
    "appauvries": "appauvrir",
    "appauvrira": "appauvrir",
    "appauvrirai": "appauvrir",
    "appauvriraient": "appauvrir",
    "appauvrirais": "appauvrir",
    "appauvrirait": "appauvrir",
    "appauvriras": "appauvrir",
    "appauvrirent": "appauvrir",
    "appauvrirez": "appauvrir",
    "appauvririez": "appauvrir",
    "appauvririons": "appauvrir",
    "appauvrirons": "appauvrir",
    "appauvriront": "appauvrir",
    "appauvris": "appauvrir",
    "appauvrissaient": "appauvrir",
    "appauvrissais": "appauvrir",
    "appauvrissait": "appauvrir",
    "appauvrissant": "appauvrir",
    "appauvrissante": "appauvrissant",
    "appauvrissantes": "appauvrissant",
    "appauvrissants": "appauvrissant",
    "appauvrisse": "appauvrir",
    "appauvrissements": "appauvrissement",
    "appauvrissent": "appauvrir",
    "appauvrisses": "appauvrir",
    "appauvrissez": "appauvrir",
    "appauvrissiez": "appauvrir",
    "appauvrissions": "appauvrir",
    "appauvrissons": "appauvrir",
    "appauvrit": "appauvrir",
    "appauvrîmes": "appauvrir",
    "appauvrît": "appauvrir",
    "appauvrîtes": "appauvrir",
    "appeaux": "appeau",
    "appela": "appeler",
    "appelai": "appeler",
    "appelaient": "appeler",
    "appelais": "appeler",
    "appelait": "appeler",
    "appelant": "appeler",
    "appelants": "appelant",
    "appelas": "appeler",
    "appelasse": "appeler",
    "appelassent": "appeler",
    "appelasses": "appeler",
    "appelassiez": "appeler",
    "appelassions": "appeler",
    "appelations": "appelation",
    "appelez": "appeler",
    "appeliez": "appeler",
    "appelions": "appeler",
    "appellatifs": "appellatif",
    "appellations": "appellation",
    "appellative": "appellatif",
    "appellatives": "appellatif",
    "appelle": "appeler",
    "appellent": "appeler",
    "appellera": "appeler",
    "appellerai": "appeler",
    "appelleraient": "appeler",
    "appellerais": "appeler",
    "appellerait": "appeler",
    "appelleras": "appeler",
    "appellerez": "appeler",
    "appelleriez": "appeler",
    "appellerions": "appeler",
    "appellerons": "appeler",
    "appelleront": "appeler",
    "appelles": "appeler",
    "appelons": "appeler",
    "appels": "appel",
    "appelâmes": "appeler",
    "appelât": "appeler",
    "appelâtes": "appeler",
    "appelèrent": "appeler",
    "appelé": "appeler",
    "appelée": "appeler",
    "appelées": "appeler",
    "appelés": "appeler",
    "appencices": "appencice",
    "append": "appendre",
    "appendaient": "appendre",
    "appendais": "appendre",
    "appendait": "appendre",
    "appendant": "appendre",
    "appende": "appendre",
    "appendent": "appendre",
    "appendes": "appendre",
    "appendez": "appendre",
    "appendices": "appendice",
    "appendiez": "appendre",
    "appendions": "appendre",
    "appendirent": "appendre",
    "appendis": "appendre",
    "appendisse": "appendre",
    "appendissent": "appendre",
    "appendisses": "appendre",
    "appendissiez": "appendre",
    "appendissions": "appendre",
    "appendit": "appendre",
    "appendons": "appendre",
    "appendra": "appendre",
    "appendrai": "appendre",
    "appendraient": "appendre",
    "appendrais": "appendre",
    "appendrait": "appendre",
    "appendras": "appendre",
    "appendrez": "appendre",
    "appendriez": "appendre",
    "appendrions": "appendre",
    "appendrons": "appendre",
    "appendront": "appendre",
    "appends": "appendre",
    "appendu": "appendre",
    "appendue": "appendre",
    "appendues": "appendre",
    "appendus": "appendre",
    "appendîmes": "appendre",
    "appendît": "appendre",
    "appendîtes": "appendre",
    "appesanti": "appesantir",
    "appesantie": "appesantir",
    "appesanties": "appesantir",
    "appesantira": "appesantir",
    "appesantirai": "appesantir",
    "appesantiraient": "appesantir",
    "appesantirais": "appesantir",
    "appesantirait": "appesantir",
    "appesantiras": "appesantir",
    "appesantirent": "appesantir",
    "appesantirez": "appesantir",
    "appesantiriez": "appesantir",
    "appesantirions": "appesantir",
    "appesantirons": "appesantir",
    "appesantiront": "appesantir",
    "appesantis": "appesantir",
    "appesantissaient": "appesantir",
    "appesantissais": "appesantir",
    "appesantissait": "appesantir",
    "appesantissant": "appesantir",
    "appesantisse": "appesantir",
    "appesantissent": "appesantir",
    "appesantisses": "appesantir",
    "appesantissez": "appesantir",
    "appesantissiez": "appesantir",
    "appesantissions": "appesantir",
    "appesantissons": "appesantir",
    "appesantit": "appesantir",
    "appesantîmes": "appesantir",
    "appesantît": "appesantir",
    "appesantîtes": "appesantir",
    "applaudi": "applaudir",
    "applaudie": "applaudir",
    "applaudies": "applaudir",
    "applaudira": "applaudir",
    "applaudirai": "applaudir",
    "applaudiraient": "applaudir",
    "applaudirais": "applaudir",
    "applaudirait": "applaudir",
    "applaudiras": "applaudir",
    "applaudirent": "applaudir",
    "applaudirez": "applaudir",
    "applaudiriez": "applaudir",
    "applaudirions": "applaudir",
    "applaudirons": "applaudir",
    "applaudiront": "applaudir",
    "applaudis": "applaudir",
    "applaudissaient": "applaudir",
    "applaudissais": "applaudir",
    "applaudissait": "applaudir",
    "applaudissant": "applaudir",
    "applaudisse": "applaudir",
    "applaudissements": "applaudissement",
    "applaudissent": "applaudir",
    "applaudisses": "applaudir",
    "applaudissez": "applaudir",
    "applaudissiez": "applaudir",
    "applaudissions": "applaudir",
    "applaudissons": "applaudir",
    "applaudit": "applaudir",
    "applaudîmes": "applaudir",
    "applaudît": "applaudir",
    "applaudîtes": "applaudir",
    "applicabilités": "applicabilité",
    "applicables": "applicable",
    "applications": "application",
    "appliqua": "appliquer",
    "appliquai": "appliquer",
    "appliquaient": "appliquer",
    "appliquais": "appliquer",
    "appliquait": "appliquer",
    "appliquant": "appliquer",
    "appliquas": "appliquer",
    "appliquasse": "appliquer",
    "appliquassent": "appliquer",
    "appliquasses": "appliquer",
    "appliquassiez": "appliquer",
    "appliquassions": "appliquer",
    "applique": "appliquer",
    "appliquent": "appliquer",
    "appliquera": "appliquer",
    "appliquerai": "appliquer",
    "appliqueraient": "appliquer",
    "appliquerais": "appliquer",
    "appliquerait": "appliquer",
    "appliqueras": "appliquer",
    "appliquerez": "appliquer",
    "appliqueriez": "appliquer",
    "appliquerions": "appliquer",
    "appliquerons": "appliquer",
    "appliqueront": "appliquer",
    "appliques": "appliquer",
    "appliquez": "appliquer",
    "appliquiez": "appliquer",
    "appliquions": "appliquer",
    "appliquons": "appliquer",
    "appliquâmes": "appliquer",
    "appliquât": "appliquer",
    "appliquâtes": "appliquer",
    "appliquèrent": "appliquer",
    "appliqué": "appliquer",
    "appliquée": "appliquer",
    "appliquées": "appliquer",
    "appliqués": "appliquer",
    "appoggiatures": "appoggiature",
    "appointa": "appointer",
    "appointai": "appointer",
    "appointaient": "appointer",
    "appointais": "appointer",
    "appointait": "appointer",
    "appointant": "appointer",
    "appointas": "appointer",
    "appointasse": "appointer",
    "appointassent": "appointer",
    "appointasses": "appointer",
    "appointassiez": "appointer",
    "appointassions": "appointer",
    "appointe": "appointer",
    "appointements": "appointement",
    "appointent": "appointer",
    "appointera": "appointer",
    "appointerai": "appointer",
    "appointeraient": "appointer",
    "appointerais": "appointer",
    "appointerait": "appointer",
    "appointeras": "appointer",
    "appointerez": "appointer",
    "appointeriez": "appointer",
    "appointerions": "appointer",
    "appointerons": "appointer",
    "appointeront": "appointer",
    "appointes": "appointer",
    "appointez": "appointer",
    "appointi": "appointir",
    "appointie": "appointir",
    "appointies": "appointir",
    "appointiez": "appointer",
    "appointions": "appointer",
    "appointira": "appointir",
    "appointirai": "appointir",
    "appointiraient": "appointir",
    "appointirais": "appointir",
    "appointirait": "appointir",
    "appointiras": "appointir",
    "appointirent": "appointir",
    "appointirez": "appointir",
    "appointiriez": "appointir",
    "appointirions": "appointir",
    "appointirons": "appointir",
    "appointiront": "appointir",
    "appointis": "appointir",
    "appointissaient": "appointir",
    "appointissais": "appointir",
    "appointissait": "appointir",
    "appointissant": "appointir",
    "appointisse": "appointir",
    "appointissent": "appointir",
    "appointisses": "appointir",
    "appointissez": "appointir",
    "appointissiez": "appointir",
    "appointissions": "appointir",
    "appointissons": "appointir",
    "appointit": "appointir",
    "appointons": "appointer",
    "appoints": "appoint",
    "appointâmes": "appointer",
    "appointât": "appointer",
    "appointâtes": "appointer",
    "appointèrent": "appointer",
    "appointé": "appointer",
    "appointée": "appointer",
    "appointées": "appointer",
    "appointés": "appointer",
    "appointîmes": "appointir",
    "appointît": "appointir",
    "appointîtes": "appointir",
    "apponta": "apponter",
    "appontai": "apponter",
    "appontaient": "apponter",
    "appontais": "apponter",
    "appontait": "apponter",
    "appontant": "apponter",
    "appontas": "apponter",
    "appontasse": "apponter",
    "appontassent": "apponter",
    "appontasses": "apponter",
    "appontassiez": "apponter",
    "appontassions": "apponter",
    "apponte": "apponter",
    "appontements": "appontement",
    "appontent": "apponter",
    "appontera": "apponter",
    "apponterai": "apponter",
    "apponteraient": "apponter",
    "apponterais": "apponter",
    "apponterait": "apponter",
    "apponteras": "apponter",
    "apponterez": "apponter",
    "apponteriez": "apponter",
    "apponterions": "apponter",
    "apponterons": "apponter",
    "apponteront": "apponter",
    "appontes": "apponter",
    "appontez": "apponter",
    "appontiez": "apponter",
    "appontions": "apponter",
    "appontons": "apponter",
    "appontâmes": "apponter",
    "appontât": "apponter",
    "appontâtes": "apponter",
    "appontèrent": "apponter",
    "apponté": "apponter",
    "appontée": "apponter",
    "appontées": "apponter",
    "appontés": "apponter",
    "apporta": "apporter",
    "apportai": "apporter",
    "apportaient": "apporter",
    "apportais": "apporter",
    "apportait": "apporter",
    "apportant": "apporter",
    "apportas": "apporter",
    "apportasse": "apporter",
    "apportassent": "apporter",
    "apportasses": "apporter",
    "apportassiez": "apporter",
    "apportassions": "apporter",
    "apporte": "apporter",
    "apportent": "apporter",
    "apportera": "apporter",
    "apporterai": "apporter",
    "apporteraient": "apporter",
    "apporterais": "apporter",
    "apporterait": "apporter",
    "apporteras": "apporter",
    "apporterez": "apporter",
    "apporteriez": "apporter",
    "apporterions": "apporter",
    "apporterons": "apporter",
    "apporteront": "apporter",
    "apportes": "apporter",
    "apportez": "apporter",
    "apportiez": "apporter",
    "apportions": "apporter",
    "apportons": "apporter",
    "apports": "apport",
    "apportâmes": "apporter",
    "apportât": "apporter",
    "apportâtes": "apporter",
    "apportèrent": "apporter",
    "apporté": "apporter",
    "apportée": "apporter",
    "apportées": "apporter",
    "apportés": "apporter",
    "apposa": "apposer",
    "apposai": "apposer",
    "apposaient": "apposer",
    "apposais": "apposer",
    "apposait": "apposer",
    "apposant": "apposer",
    "apposas": "apposer",
    "apposasse": "apposer",
    "apposassent": "apposer",
    "apposasses": "apposer",
    "apposassiez": "apposer",
    "apposassions": "apposer",
    "appose": "apposer",
    "apposent": "apposer",
    "apposera": "apposer",
    "apposerai": "apposer",
    "apposeraient": "apposer",
    "apposerais": "apposer",
    "apposerait": "apposer",
    "apposeras": "apposer",
    "apposerez": "apposer",
    "apposeriez": "apposer",
    "apposerions": "apposer",
    "apposerons": "apposer",
    "apposeront": "apposer",
    "apposes": "apposer",
    "apposez": "apposer",
    "apposiez": "apposer",
    "apposions": "apposer",
    "appositions": "apposition",
    "apposons": "apposer",
    "apposâmes": "apposer",
    "apposât": "apposer",
    "apposâtes": "apposer",
    "apposèrent": "apposer",
    "apposé": "apposer",
    "apposée": "apposer",
    "apposées": "apposer",
    "apposés": "apposer",
    "apprenaient": "apprendre",
    "apprenais": "apprendre",
    "apprenait": "apprendre",
    "apprenant": "apprendre",
    "apprend": "apprendre",
    "apprendra": "apprendre",
    "apprendrai": "apprendre",
    "apprendraient": "apprendre",
    "apprendrais": "apprendre",
    "apprendrait": "apprendre",
    "apprendras": "apprendre",
    "apprendre": "avoir",
    "apprendrez": "apprendre",
    "apprendriez": "apprendre",
    "apprendrions": "apprendre",
    "apprendrons": "apprendre",
    "apprendront": "apprendre",
    "apprends": "apprendre",
    "apprenez": "apprendre",
    "appreniez": "apprendre",
    "apprenions": "apprendre",
    "apprenne": "apprendre",
    "apprennent": "apprendre",
    "apprennes": "apprendre",
    "apprenons": "apprendre",
    "apprentie": "apprenti",
    "apprenties": "apprenti",
    "apprentis": "apprenti",
    "apprentissages": "apprentissage",
    "apprirent": "apprendre",
    "appris": "apprendre",
    "apprise": "appris",
    "apprises": "appris",
    "apprisse": "apprendre",
    "apprissent": "apprendre",
    "apprisses": "apprendre",
    "apprissiez": "apprendre",
    "apprissions": "apprendre",
    "apprit": "apprendre",
    "apprivoisa": "apprivoiser",
    "apprivoisai": "apprivoiser",
    "apprivoisaient": "apprivoiser",
    "apprivoisais": "apprivoiser",
    "apprivoisait": "apprivoiser",
    "apprivoisant": "apprivoiser",
    "apprivoisas": "apprivoiser",
    "apprivoisasse": "apprivoiser",
    "apprivoisassent": "apprivoiser",
    "apprivoisasses": "apprivoiser",
    "apprivoisassiez": "apprivoiser",
    "apprivoisassions": "apprivoiser",
    "apprivoise": "apprivoiser",
    "apprivoisent": "apprivoiser",
    "apprivoisera": "apprivoiser",
    "apprivoiserai": "apprivoiser",
    "apprivoiseraient": "apprivoiser",
    "apprivoiserais": "apprivoiser",
    "apprivoiserait": "apprivoiser",
    "apprivoiseras": "apprivoiser",
    "apprivoiserez": "apprivoiser",
    "apprivoiseriez": "apprivoiser",
    "apprivoiserions": "apprivoiser",
    "apprivoiserons": "apprivoiser",
    "apprivoiseront": "apprivoiser",
    "apprivoises": "apprivoiser",
    "apprivoisez": "apprivoiser",
    "apprivoisiez": "apprivoiser",
    "apprivoisions": "apprivoiser",
    "apprivoisons": "apprivoiser",
    "apprivoisâmes": "apprivoiser",
    "apprivoisât": "apprivoiser",
    "apprivoisâtes": "apprivoiser",
    "apprivoisèrent": "apprivoiser",
    "apprivoisé": "apprivoiser",
    "apprivoisée": "apprivoiser",
    "apprivoisées": "apprivoiser",
    "apprivoisés": "apprivoiser",
    "approbateurs": "approbateur",
    "approbations": "approbation",
    "approbatrice": "approbateur",
    "approbatrices": "approbateur",
    "approcha": "approcher",
    "approchai": "approcher",
    "approchaient": "approcher",
    "approchais": "approcher",
    "approchait": "approcher",
    "approchant": "approcher",
    "approchants": "approchant",
    "approchas": "approcher",
    "approchasse": "approcher",
    "approchassent": "approcher",
    "approchasses": "approcher",
    "approchassiez": "approcher",
    "approchassions": "approcher",
    "approche": "approcher",
    "approchent": "approcher",
    "approchera": "approcher",
    "approcherai": "approcher",
    "approcheraient": "approcher",
    "approcherais": "approcher",
    "approcherait": "approcher",
    "approcheras": "approcher",
    "approcherez": "approcher",
    "approcheriez": "approcher",
    "approcherions": "approcher",
    "approcherons": "approcher",
    "approcheront": "approcher",
    "approches": "approcher",
    "approchez": "approcher",
    "approchiez": "approcher",
    "approchions": "approcher",
    "approchons": "approcher",
    "approchâmes": "approcher",
    "approchât": "approcher",
    "approchâtes": "approcher",
    "approchèrent": "approcher",
    "approché": "approcher",
    "approchée": "approcher",
    "approchées": "approcher",
    "approchés": "approcher",
    "approfondi": "approfondir",
    "approfondie": "approfondir",
    "approfondies": "approfondir",
    "approfondira": "approfondir",
    "approfondirai": "approfondir",
    "approfondiraient": "approfondir",
    "approfondirais": "approfondir",
    "approfondirait": "approfondir",
    "approfondiras": "approfondir",
    "approfondirent": "approfondir",
    "approfondirez": "approfondir",
    "approfondiriez": "approfondir",
    "approfondirions": "approfondir",
    "approfondirons": "approfondir",
    "approfondiront": "approfondir",
    "approfondis": "approfondir",
    "approfondissaient": "approfondir",
    "approfondissais": "approfondir",
    "approfondissait": "approfondir",
    "approfondissant": "approfondir",
    "approfondisse": "approfondir",
    "approfondissements": "approfondissement",
    "approfondissent": "approfondir",
    "approfondisses": "approfondir",
    "approfondissez": "approfondir",
    "approfondissiez": "approfondir",
    "approfondissions": "approfondir",
    "approfondissons": "approfondir",
    "approfondit": "approfondir",
    "approfondîmes": "approfondir",
    "approfondît": "approfondir",
    "approfondîtes": "approfondir",
    "appropria": "approprier",
    "appropriai": "approprier",
    "appropriaient": "approprier",
    "appropriais": "approprier",
    "appropriait": "approprier",
    "appropriant": "approprier",
    "approprias": "approprier",
    "appropriasse": "approprier",
    "appropriassent": "approprier",
    "appropriasses": "approprier",
    "appropriassiez": "approprier",
    "appropriassions": "approprier",
    "appropriations": "appropriation",
    "approprie": "approprier",
    "approprient": "approprier",
    "appropriera": "approprier",
    "approprierai": "approprier",
    "approprieraient": "approprier",
    "approprierais": "approprier",
    "approprierait": "approprier",
    "approprieras": "approprier",
    "approprierez": "approprier",
    "approprieriez": "approprier",
    "approprierions": "approprier",
    "approprierons": "approprier",
    "approprieront": "approprier",
    "appropries": "approprier",
    "appropriez": "approprier",
    "appropriiez": "approprier",
    "appropriions": "approprier",
    "approprions": "approprier",
    "appropriâmes": "approprier",
    "appropriât": "approprier",
    "appropriâtes": "approprier",
    "approprièrent": "approprier",
    "approprié": "approprier",
    "appropriée": "approprier",
    "appropriées": "approprier",
    "appropriés": "approprier",
    "approuva": "approuver",
    "approuvai": "approuver",
    "approuvaient": "approuver",
    "approuvais": "approuver",
    "approuvait": "approuver",
    "approuvant": "approuver",
    "approuvas": "approuver",
    "approuvasse": "approuver",
    "approuvassent": "approuver",
    "approuvasses": "approuver",
    "approuvassiez": "approuver",
    "approuvassions": "approuver",
    "approuve": "approuver",
    "approuvent": "approuver",
    "approuvera": "approuver",
    "approuverai": "approuver",
    "approuveraient": "approuver",
    "approuverais": "approuver",
    "approuverait": "approuver",
    "approuveras": "approuver",
    "approuverez": "approuver",
    "approuveriez": "approuver",
    "approuverions": "approuver",
    "approuverons": "approuver",
    "approuveront": "approuver",
    "approuves": "approuver",
    "approuvez": "approuver",
    "approuviez": "approuver",
    "approuvions": "approuver",
    "approuvons": "approuver",
    "approuvâmes": "approuver",
    "approuvât": "approuver",
    "approuvâtes": "approuver",
    "approuvèrent": "approuver",
    "approuvé": "approuver",
    "approuvée": "approuver",
    "approuvées": "approuver",
    "approuvés": "approuver",
    "approvisionna": "approvisionner",
    "approvisionnai": "approvisionner",
    "approvisionnaient": "approvisionner",
    "approvisionnais": "approvisionner",
    "approvisionnait": "approvisionner",
    "approvisionnant": "approvisionner",
    "approvisionnas": "approvisionner",
    "approvisionnasse": "approvisionner",
    "approvisionnassent": "approvisionner",
    "approvisionnasses": "approvisionner",
    "approvisionnassiez": "approvisionner",
    "approvisionnassions": "approvisionner",
    "approvisionne": "approvisionner",
    "approvisionnements": "approvisionnement",
    "approvisionnent": "approvisionner",
    "approvisionnera": "approvisionner",
    "approvisionnerai": "approvisionner",
    "approvisionneraient": "approvisionner",
    "approvisionnerais": "approvisionner",
    "approvisionnerait": "approvisionner",
    "approvisionneras": "approvisionner",
    "approvisionnerez": "approvisionner",
    "approvisionneriez": "approvisionner",
    "approvisionnerions": "approvisionner",
    "approvisionnerons": "approvisionner",
    "approvisionneront": "approvisionner",
    "approvisionnes": "approvisionner",
    "approvisionnez": "approvisionner",
    "approvisionniez": "approvisionner",
    "approvisionnions": "approvisionner",
    "approvisionnons": "approvisionner",
    "approvisionnâmes": "approvisionner",
    "approvisionnât": "approvisionner",
    "approvisionnâtes": "approvisionner",
    "approvisionnèrent": "approvisionner",
    "approvisionné": "approvisionner",
    "approvisionnée": "approvisionner",
    "approvisionnées": "approvisionner",
    "approvisionnés": "approvisionner",
    "approximatifs": "approximatif",
    "approximations": "approximation",
    "approximative": "approximatif",
    "approximatives": "approximatif",
    "apprécia": "apprécier",
    "appréciables": "appréciable",
    "appréciai": "apprécier",
    "appréciaient": "apprécier",
    "appréciais": "apprécier",
    "appréciait": "apprécier",
    "appréciant": "apprécier",
    "apprécias": "apprécier",
    "appréciasse": "apprécier",
    "appréciassent": "apprécier",
    "appréciasses": "apprécier",
    "appréciassiez": "apprécier",
    "appréciassions": "apprécier",
    "appréciations": "appréciation",
    "appréciatrice": "appréciateur",
    "apprécie": "apprécier",
    "apprécient": "apprécier",
    "appréciera": "apprécier",
    "apprécierai": "apprécier",
    "apprécieraient": "apprécier",
    "apprécierais": "apprécier",
    "apprécierait": "apprécier",
    "apprécieras": "apprécier",
    "apprécierez": "apprécier",
    "apprécieriez": "apprécier",
    "apprécierions": "apprécier",
    "apprécierons": "apprécier",
    "apprécieront": "apprécier",
    "apprécies": "apprécier",
    "appréciez": "apprécier",
    "appréciiez": "apprécier",
    "appréciions": "apprécier",
    "apprécions": "apprécier",
    "appréciâmes": "apprécier",
    "appréciât": "apprécier",
    "appréciâtes": "apprécier",
    "apprécièrent": "apprécier",
    "apprécié": "apprécier",
    "appréciée": "apprécier",
    "appréciées": "apprécier",
    "appréciés": "apprécier",
    "appréhenda": "appréhender",
    "appréhendai": "appréhender",
    "appréhendaient": "appréhender",
    "appréhendais": "appréhender",
    "appréhendait": "appréhender",
    "appréhendant": "appréhender",
    "appréhendas": "appréhender",
    "appréhendasse": "appréhender",
    "appréhendassent": "appréhender",
    "appréhendasses": "appréhender",
    "appréhendassiez": "appréhender",
    "appréhendassions": "appréhender",
    "appréhende": "appréhender",
    "appréhendent": "appréhender",
    "appréhendera": "appréhender",
    "appréhenderai": "appréhender",
    "appréhenderaient": "appréhender",
    "appréhenderais": "appréhender",
    "appréhenderait": "appréhender",
    "appréhenderas": "appréhender",
    "appréhenderez": "appréhender",
    "appréhenderiez": "appréhender",
    "appréhenderions": "appréhender",
    "appréhenderons": "appréhender",
    "appréhenderont": "appréhender",
    "appréhendes": "appréhender",
    "appréhendez": "appréhender",
    "appréhendiez": "appréhender",
    "appréhendions": "appréhender",
    "appréhendons": "appréhender",
    "appréhendâmes": "appréhender",
    "appréhendât": "appréhender",
    "appréhendâtes": "appréhender",
    "appréhendèrent": "appréhender",
    "appréhendé": "appréhender",
    "appréhendée": "appréhender",
    "appréhendées": "appréhender",
    "appréhendés": "appréhender",
    "appréhensions": "appréhension",
    "apprêta": "apprêter",
    "apprêtai": "apprêter",
    "apprêtaient": "apprêter",
    "apprêtais": "apprêter",
    "apprêtait": "apprêter",
    "apprêtant": "apprêter",
    "apprêtas": "apprêter",
    "apprêtasse": "apprêter",
    "apprêtassent": "apprêter",
    "apprêtasses": "apprêter",
    "apprêtassiez": "apprêter",
    "apprêtassions": "apprêter",
    "apprête": "apprêter",
    "apprêtent": "apprêter",
    "apprêtera": "apprêter",
    "apprêterai": "apprêter",
    "apprêteraient": "apprêter",
    "apprêterais": "apprêter",
    "apprêterait": "apprêter",
    "apprêteras": "apprêter",
    "apprêterez": "apprêter",
    "apprêteriez": "apprêter",
    "apprêterions": "apprêter",
    "apprêterons": "apprêter",
    "apprêteront": "apprêter",
    "apprêtes": "apprêter",
    "apprêtez": "apprêter",
    "apprêtiez": "apprêter",
    "apprêtions": "apprêter",
    "apprêtons": "apprêter",
    "apprêts": "apprêt",
    "apprêtâmes": "apprêter",
    "apprêtât": "apprêter",
    "apprêtâtes": "apprêter",
    "apprêtèrent": "apprêter",
    "apprêté": "apprêter",
    "apprêtée": "apprêter",
    "apprêtées": "apprêter",
    "apprêtés": "apprêter",
    "apprîmes": "apprendre",
    "apprît": "apprendre",
    "apprîtes": "apprendre",
    "appuie": "appuyer",
    "appuient": "appuyer",
    "appuiera": "appuyer",
    "appuierai": "appuyer",
    "appuieraient": "appuyer",
    "appuierais": "appuyer",
    "appuierait": "appuyer",
    "appuieras": "appuyer",
    "appuierez": "appuyer",
    "appuieriez": "appuyer",
    "appuierions": "appuyer",
    "appuierons": "appuyer",
    "appuieront": "appuyer",
    "appuies": "appuyer",
    "appuis": "appui",
    "appuis-bras": "appui-bras",
    "appuis-livres": "appui-livres",
    "appuis-têtes": "appui-têtes",
    "appuya": "appuyer",
    "appuyai": "appuyer",
    "appuyaient": "appuyer",
    "appuyais": "appuyer",
    "appuyait": "appuyer",
    "appuyant": "appuyer",
    "appuyas": "appuyer",
    "appuyasse": "appuyer",
    "appuyassent": "appuyer",
    "appuyasses": "appuyer",
    "appuyassiez": "appuyer",
    "appuyassions": "appuyer",
    "appuyer": "avoir",
    "appuyez": "appuyer",
    "appuyiez": "appuyer",
    "appuyions": "appuyer",
    "appuyons": "appuyer",
    "appuyâmes": "appuyer",
    "appuyât": "appuyer",
    "appuyâtes": "appuyer",
    "appuyèrent": "appuyer",
    "appuyé": "appuyer",
    "appuyée": "appuyer",
    "appuyées": "appuyer",
    "appuyés": "appuyer",
    "appâtais": "appâter",
    "appâtant": "appâter",
    "appâte": "appâter",
    "appâtent": "appâter",
    "appâtera": "appâter",
    "appâterait": "appâter",
    "appâtes": "appâter",
    "appâtez": "appâter",
    "appâtons": "appâter",
    "appâts": "appât",
    "appâté": "appâter",
    "appâtée": "appâter",
    "appâtées": "appâter",
    "appâtés": "appâter",
    "appétences": "appétence",
    "appétissante": "appétissant",
    "appétissantes": "appétissant",
    "appétissants": "appétissant",
    "appétits": "appétit",
    "aprème": "aprèm",
    "après-dîners": "après-dîner",
    "après-guerres": "après-guerre",
    "après-midis": "après-midi",
    "après-skis": "après-ski",
    "apsides": "apside",
    "aptes": "apte",
    "aptitudes": "aptitude",
    "aptères": "aptère",
    "apura": "apurer",
    "apurai": "apurer",
    "apuraient": "apurer",
    "apurais": "apurer",
    "apurait": "apurer",
    "apurant": "apurer",
    "apuras": "apurer",
    "apurasse": "apurer",
    "apurassent": "apurer",
    "apurasses": "apurer",
    "apurassiez": "apurer",
    "apurassions": "apurer",
    "apure": "apurer",
    "apurements": "apurement",
    "apurent": "apurer",
    "apurera": "apurer",
    "apurerai": "apurer",
    "apureraient": "apurer",
    "apurerais": "apurer",
    "apurerait": "apurer",
    "apureras": "apurer",
    "apurerez": "apurer",
    "apureriez": "apurer",
    "apurerions": "apurer",
    "apurerons": "apurer",
    "apureront": "apurer",
    "apures": "apurer",
    "apurez": "apurer",
    "apuriez": "apurer",
    "apurions": "apurer",
    "apurons": "apurer",
    "apurâmes": "apurer",
    "apurât": "apurer",
    "apurâtes": "apurer",
    "apurèrent": "apurer",
    "apuré": "apurer",
    "apurée": "apurer",
    "apurées": "apurer",
    "apurés": "apurer",
    "apâli": "apâlir",
    "apâlis": "apâlir",
    "apéritifs": "apéritif",
    "apéritive": "apéritif",
    "apéritives": "apéritif",
    "apéros": "apéro",
    "apôtres": "apôtre",
    "aquacoles": "aquacole",
    "aquacultures": "aquaculture",
    "aquafortistes": "aquafortiste",
    "aquaplanes": "aquaplane",
    "aquarellait": "aquareller",
    "aquarelles": "aquarelle",
    "aquarellistes": "aquarelliste",
    "aquarellés": "aquarellé",
    "aquariums": "aquarium",
    "aquatiques": "aquatique",
    "aqueducs": "aqueduc",
    "aqueuse": "aqueux",
    "aqueuses": "aqueux",
    "aquifères": "aquifère",
    "aquilins": "aquilin",
    "aquilons": "aquilon",
    "arabes": "arabe",
    "arabesques": "arabesque",
    "arabicas": "arabica",
    "arabisant": "arabiser",
    "arabisants": "arabisant",
    "arabisé": "arabiser",
    "arables": "arable",
    "arabophones": "arabophone",
    "arachides": "arachide",
    "arachnides": "arachnide",
    "arachnoïdes": "arachnoïde",
    "arachnéenne": "arachnéen",
    "arachnéennes": "arachnéen",
    "arachnéens": "arachnéen",
    "aragonaise": "aragonais",
    "aragonaises": "aragonais",
    "araignées": "araignée",
    "araires": "araire",
    "araks": "arak",
    "araméenne": "araméen",
    "aranéeuse": "aranéeux",
    "arapèdes": "arapède",
    "aras": "ara",
    "arasa": "araser",
    "arasai": "araser",
    "arasaient": "araser",
    "arasais": "araser",
    "arasait": "araser",
    "arasant": "araser",
    "arasas": "araser",
    "arasasse": "araser",
    "arasassent": "araser",
    "arasasses": "araser",
    "arasassiez": "araser",
    "arasassions": "araser",
    "arase": "araser",
    "arasent": "araser",
    "arasera": "araser",
    "araserai": "araser",
    "araseraient": "araser",
    "araserais": "araser",
    "araserait": "araser",
    "araseras": "araser",
    "araserez": "araser",
    "araseriez": "araser",
    "araserions": "araser",
    "araserons": "araser",
    "araseront": "araser",
    "arases": "araser",
    "arasez": "araser",
    "arasiez": "araser",
    "arasions": "araser",
    "arasons": "araser",
    "arasâmes": "araser",
    "arasât": "araser",
    "arasâtes": "araser",
    "arasèrent": "araser",
    "arasé": "araser",
    "arasée": "araser",
    "arasées": "araser",
    "arasés": "araser",
    "aratoires": "aratoire",
    "araucaniennes": "araucanien",
    "araucaniens": "araucanien",
    "araucarias": "araucaria",
    "arbalètes": "arbalète",
    "arbalétriers": "arbalétrier",
    "arbis": "arbi",
    "arbitra": "arbitrer",
    "arbitrages": "arbitrage",
    "arbitrai": "arbitrer",
    "arbitraient": "arbitrer",
    "arbitraires": "arbitraire",
    "arbitrais": "arbitrer",
    "arbitrait": "arbitrer",
    "arbitrale": "arbitral",
    "arbitrales": "arbitral",
    "arbitrant": "arbitrer",
    "arbitras": "arbitrer",
    "arbitrasse": "arbitrer",
    "arbitrassent": "arbitrer",
    "arbitrasses": "arbitrer",
    "arbitrassiez": "arbitrer",
    "arbitrassions": "arbitrer",
    "arbitraux": "arbitral",
    "arbitre": "arbitrer",
    "arbitrent": "arbitrer",
    "arbitrera": "arbitrer",
    "arbitrerai": "arbitrer",
    "arbitreraient": "arbitrer",
    "arbitrerais": "arbitrer",
    "arbitrerait": "arbitrer",
    "arbitreras": "arbitrer",
    "arbitrerez": "arbitrer",
    "arbitreriez": "arbitrer",
    "arbitrerions": "arbitrer",
    "arbitrerons": "arbitrer",
    "arbitreront": "arbitrer",
    "arbitres": "arbitrer",
    "arbitrez": "arbitrer",
    "arbitriez": "arbitrer",
    "arbitrions": "arbitrer",
    "arbitrons": "arbitrer",
    "arbitrâmes": "arbitrer",
    "arbitrât": "arbitrer",
    "arbitrâtes": "arbitrer",
    "arbitrèrent": "arbitrer",
    "arbitré": "arbitrer",
    "arbitrée": "arbitrer",
    "arbitrées": "arbitrer",
    "arbitrés": "arbitrer",
    "arbora": "arborer",
    "arborai": "arborer",
    "arboraient": "arborer",
    "arborais": "arborer",
    "arborait": "arborer",
    "arborant": "arborer",
    "arboras": "arborer",
    "arborasse": "arborer",
    "arborassent": "arborer",
    "arborasses": "arborer",
    "arborassiez": "arborer",
    "arborassions": "arborer",
    "arbore": "arborer",
    "arborent": "arborer",
    "arborera": "arborer",
    "arborerai": "arborer",
    "arboreraient": "arborer",
    "arborerais": "arborer",
    "arborerait": "arborer",
    "arboreras": "arborer",
    "arborerez": "arborer",
    "arboreriez": "arborer",
    "arborerions": "arborer",
    "arborerons": "arborer",
    "arboreront": "arborer",
    "arbores": "arborer",
    "arborescences": "arborescence",
    "arborescente": "arborescent",
    "arborescentes": "arborescent",
    "arborescents": "arborescent",
    "arborez": "arborer",
    "arboricoles": "arboricole",
    "arboriez": "arborer",
    "arborions": "arborer",
    "arborisations": "arborisation",
    "arborons": "arborer",
    "arborâmes": "arborer",
    "arborât": "arborer",
    "arborâtes": "arborer",
    "arborèrent": "arborer",
    "arboré": "arborer",
    "arborée": "arborer",
    "arborées": "arborer",
    "arborés": "arborer",
    "arbouses": "arbouse",
    "arbousiers": "arbousier",
    "arbres": "arbre",
    "arbres-refuges": "arbres-refuge",
    "arbrisseaux": "arbrisseau",
    "arbustes": "arbuste",
    "arc-bouta": "arc-bouter",
    "arc-boutai": "arc-bouter",
    "arc-boutaient": "arc-bouter",
    "arc-boutais": "arc-bouter",
    "arc-boutait": "arc-bouter",
    "arc-boutant": "arc-bouter",
    "arc-boutants": "arc-boutant",
    "arc-boutas": "arc-bouter",
    "arc-boutasse": "arc-bouter",
    "arc-boutassent": "arc-bouter",
    "arc-boutasses": "arc-bouter",
    "arc-boutassiez": "arc-bouter",
    "arc-boutassions": "arc-bouter",
    "arc-boute": "arc-bouter",
    "arc-boutent": "arc-bouter",
    "arc-boutera": "arc-bouter",
    "arc-bouterai": "arc-bouter",
    "arc-bouteraient": "arc-bouter",
    "arc-bouterais": "arc-bouter",
    "arc-bouterait": "arc-bouter",
    "arc-bouteras": "arc-bouter",
    "arc-bouterez": "arc-bouter",
    "arc-bouteriez": "arc-bouter",
    "arc-bouterions": "arc-bouter",
    "arc-bouterons": "arc-bouter",
    "arc-bouteront": "arc-bouter",
    "arc-boutes": "arc-bouter",
    "arc-boutez": "arc-bouter",
    "arc-boutiez": "arc-bouter",
    "arc-boutions": "arc-bouter",
    "arc-boutons": "arc-bouter",
    "arc-boutâmes": "arc-bouter",
    "arc-boutât": "arc-bouter",
    "arc-boutâtes": "arc-bouter",
    "arc-boutèrent": "arc-bouter",
    "arc-bouté": "arc-bouter",
    "arc-boutée": "arc-bouter",
    "arc-boutées": "arc-bouter",
    "arc-boutés": "arc-bouter",
    "arcades": "arcade",
    "arcadienne": "arcadien",
    "arcadiens": "arcadien",
    "arcanes": "arcane",
    "arcans": "arcan",
    "arcatures": "arcature",
    "arceaux": "arceau",
    "archanges": "archange",
    "archaïques": "archaïque",
    "archaïsmes": "archaïsme",
    "archers": "archer",
    "arches": "arche",
    "archets": "archet",
    "archevêchés": "archevêché",
    "archevêques": "archevêque",
    "archi-chiants": "archi-chiant",
    "archi-connus": "archi-connu",
    "archi-duchesse": "archiduc",
    "archi-morts": "archi-mort",
    "archi-sophistiquée": "archi-sophistiqué",
    "archi-sèches": "archi-sèche",
    "archicombles": "archicomble",
    "archidiacres": "archidiacre",
    "archiduchesse": "archiduc",
    "archiduchesses": "archiduc",
    "archiducs": "archiduc",
    "archie": "archi-e",
    "archinulles": "archinul",
    "archipels": "archipel",
    "architectes": "architecte",
    "architectoniques": "architectonique",
    "architecturale": "architectural",
    "architecturales": "architectural",
    "architecturant": "architecturer",
    "architecturaux": "architectural",
    "architecture": "architecturer",
    "architecturent": "architecturer",
    "architectures": "architecture",
    "architecturées": "architecturer",
    "architraves": "architrave",
    "archiva": "archiver",
    "archivages": "archivage",
    "archivai": "archiver",
    "archivaient": "archiver",
    "archivais": "archiver",
    "archivait": "archiver",
    "archivant": "archiver",
    "archivas": "archiver",
    "archivasse": "archiver",
    "archivassent": "archiver",
    "archivasses": "archiver",
    "archivassiez": "archiver",
    "archivassions": "archiver",
    "archive": "archiver",
    "archivent": "archiver",
    "archivera": "archiver",
    "archiverai": "archiver",
    "archiveraient": "archiver",
    "archiverais": "archiver",
    "archiverait": "archiver",
    "archiveras": "archiver",
    "archiverez": "archiver",
    "archiveriez": "archiver",
    "archiverions": "archiver",
    "archiverons": "archiver",
    "archiveront": "archiver",
    "archives": "archiver",
    "archivez": "archiver",
    "archiviez": "archiver",
    "archivions": "archiver",
    "archivistes": "archiviste",
    "archivistes-paléographes": "archiviste-paléographe",
    "archivoltes": "archivolte",
    "archivons": "archiver",
    "archivâmes": "archiver",
    "archivât": "archiver",
    "archivâtes": "archiver",
    "archivèrent": "archiver",
    "archivé": "archiver",
    "archivée": "archiver",
    "archivées": "archiver",
    "archivés": "archiver",
    "archontes": "archonte",
    "archères": "archer",
    "archéologies": "archéologie",
    "archéologiques": "archéologique",
    "archéologues": "archéologue",
    "archétypale": "archétypal",
    "archétypaux": "archétypal",
    "archétypes": "archétype",
    "arcs": "arc",
    "arcs-boutants": "arc-boutant",
    "arcs-doubleaux": "arc-doubleau",
    "arcs-en-ciel": "arc-en-ciel",
    "arctiques": "arctique",
    "ardais": "arder",
    "ardait": "arder",
    "ardant": "arder",
    "arde": "arder",
    "ardennaise": "ardennais",
    "ardente": "ardent",
    "ardentes": "ardent",
    "ardents": "ardent",
    "ardeurs": "ardeur",
    "ardillons": "ardillon",
    "ardoises": "ardoise",
    "ardoisière": "ardoisier",
    "ardoisée": "ardoisé",
    "ardoisées": "ardoiser",
    "ardoisés": "ardoisé",
    "ardue": "ardu",
    "ardues": "ardu",
    "ardus": "ardu",
    "ardé": "arder",
    "ardéchoise": "ardéchois",
    "ardéchoises": "ardéchois",
    "arecs": "arec",
    "ares": "are",
    "arganiers": "arganier",
    "argans": "argan",
    "argenta": "argenter",
    "argentai": "argenter",
    "argentaient": "argenter",
    "argentais": "argenter",
    "argentait": "argenter",
    "argentant": "argenter",
    "argentas": "argenter",
    "argentasse": "argenter",
    "argentassent": "argenter",
    "argentasses": "argenter",
    "argentassiez": "argenter",
    "argentassions": "argenter",
    "argente": "argenter",
    "argentent": "argenter",
    "argentera": "argenter",
    "argenterai": "argenter",
    "argenteraient": "argenter",
    "argenterais": "argenter",
    "argenterait": "argenter",
    "argenteras": "argenter",
    "argenterez": "argenter",
    "argenteries": "argenterie",
    "argenteriez": "argenter",
    "argenterions": "argenter",
    "argenterons": "argenter",
    "argenteront": "argenter",
    "argentes": "argenter",
    "argentez": "argenter",
    "argentiers": "argentier",
    "argentiez": "argenter",
    "argentifères": "argentifère",
    "argentine": "argentin",
    "argentines": "argentin",
    "argentins": "argentin",
    "argentions": "argenter",
    "argentière": "argentier",
    "argentières": "argentier",
    "argentons": "argenter",
    "argents": "argent",
    "argentâmes": "argenter",
    "argentât": "argenter",
    "argentâtes": "argenter",
    "argentèrent": "argenter",
    "argenté": "argenter",
    "argentée": "argenter",
    "argentées": "argenter",
    "argentés": "argenter",
    "argiles": "argile",
    "argileuse": "argileux",
    "argileuses": "argileux",
    "argotiques": "argotique",
    "argots": "argot",
    "argougnasses": "argougner",
    "argougne": "argougner",
    "argousins": "argousin",
    "argua": "arguer",
    "arguai": "arguer",
    "arguaient": "arguer",
    "arguais": "arguer",
    "arguait": "arguer",
    "arguant": "arguer",
    "arguas": "arguer",
    "arguasse": "arguer",
    "arguassent": "arguer",
    "arguasses": "arguer",
    "arguassiez": "arguer",
    "arguassions": "arguer",
    "argue": "arguer",
    "arguent": "arguer",
    "arguera": "arguer",
    "arguerai": "arguer",
    "argueraient": "arguer",
    "arguerais": "arguer",
    "arguerait": "arguer",
    "argueras": "arguer",
    "arguerez": "arguer",
    "argueriez": "arguer",
    "arguerions": "arguer",
    "arguerons": "arguer",
    "argueront": "arguer",
    "argues": "arguer",
    "arguez": "arguer",
    "arguiez": "arguer",
    "arguions": "arguer",
    "argumenta": "argumenter",
    "argumentai": "argumenter",
    "argumentaient": "argumenter",
    "argumentaires": "argumentaire",
    "argumentais": "argumenter",
    "argumentait": "argumenter",
    "argumentant": "argumenter",
    "argumentas": "argumenter",
    "argumentasse": "argumenter",
    "argumentassent": "argumenter",
    "argumentasses": "argumenter",
    "argumentassiez": "argumenter",
    "argumentassions": "argumenter",
    "argumentations": "argumentation",
    "argumente": "argumenter",
    "argumentent": "argumenter",
    "argumentera": "argumenter",
    "argumenterai": "argumenter",
    "argumenteraient": "argumenter",
    "argumenterais": "argumenter",
    "argumenterait": "argumenter",
    "argumenteras": "argumenter",
    "argumenterez": "argumenter",
    "argumenteriez": "argumenter",
    "argumenterions": "argumenter",
    "argumenterons": "argumenter",
    "argumenteront": "argumenter",
    "argumentes": "argumenter",
    "argumentez": "argumenter",
    "argumentiez": "argumenter",
    "argumentions": "argumenter",
    "argumentons": "argumenter",
    "arguments": "argument",
    "argumentâmes": "argumenter",
    "argumentât": "argumenter",
    "argumentâtes": "argumenter",
    "argumentèrent": "argumenter",
    "argumenté": "argumenter",
    "argumentée": "argumenter",
    "argumentées": "argumenter",
    "argumentés": "argumenter",
    "arguons": "arguer",
    "arguties": "argutie",
    "arguâmes": "arguer",
    "arguât": "arguer",
    "arguâtes": "arguer",
    "arguèrent": "arguer",
    "argué": "arguer",
    "arguée": "arguer",
    "arguées": "arguer",
    "argués": "arguer",
    "arias": "aria",
    "arides": "aride",
    "arienne": "arien",
    "ariens": "arien",
    "ariettes": "ariette",
    "ariosos": "arioso",
    "arisa": "ariser",
    "arisai": "ariser",
    "arisaient": "ariser",
    "arisais": "ariser",
    "arisait": "ariser",
    "arisant": "ariser",
    "arisas": "ariser",
    "arisasse": "ariser",
    "arisassent": "ariser",
    "arisasses": "ariser",
    "arisassiez": "ariser",
    "arisassions": "ariser",
    "arise": "ariser",
    "arisent": "ariser",
    "arisera": "ariser",
    "ariserai": "ariser",
    "ariseraient": "ariser",
    "ariserais": "ariser",
    "ariserait": "ariser",
    "ariseras": "ariser",
    "ariserez": "ariser",
    "ariseriez": "ariser",
    "ariserions": "ariser",
    "ariserons": "ariser",
    "ariseront": "ariser",
    "arises": "ariser",
    "arisez": "ariser",
    "arisiez": "ariser",
    "arisions": "ariser",
    "arisons": "ariser",
    "aristarques": "aristarque",
    "aristocrates": "aristocrate",
    "aristocraties": "aristocratie",
    "aristocratiques": "aristocratique",
    "aristoloches": "aristoloche",
    "aristos": "aristo",
    "aristotélicienne": "aristotélicien",
    "arisâmes": "ariser",
    "arisât": "ariser",
    "arisâtes": "ariser",
    "arisèrent": "ariser",
    "arisé": "ariser",
    "arisée": "ariser",
    "arisées": "ariser",
    "arisés": "ariser",
    "arithmétiques": "arithmétique",
    "ariégeoise": "ariégeois",
    "arlequins": "arlequin",
    "arlésienne": "arlésien",
    "arlésiennes": "arlésien",
    "arlésiens": "arlésien",
    "arma": "armer",
    "armadas": "armada",
    "armagnacs": "armagnac",
    "armai": "armer",
    "armaient": "armer",
    "armais": "armer",
    "armait": "armer",
    "armant": "armer",
    "armas": "armer",
    "armasse": "armer",
    "armassent": "armer",
    "armasses": "armer",
    "armassiez": "armer",
    "armassions": "armer",
    "armateurs": "armateur",
    "armaturent": "armaturer",
    "armatures": "armature",
    "arme": "armer",
    "armements": "armement",
    "arment": "armer",
    "armera": "armer",
    "armerai": "armer",
    "armeraient": "armer",
    "armerais": "armer",
    "armerait": "armer",
    "armeras": "armer",
    "armerez": "armer",
    "armeriez": "armer",
    "armerions": "armer",
    "armerons": "armer",
    "armeront": "armer",
    "armes": "armer",
    "armez": "armer",
    "armiez": "armer",
    "armions": "armer",
    "armistices": "armistice",
    "armoires": "armoire",
    "armoiries": "armoirie",
    "armoises": "armoise",
    "armons": "armer",
    "armoriale": "armorial",
    "armoriales": "armorial",
    "armoriaux": "armorial",
    "armoricaine": "armoricain",
    "armorié": "armorier",
    "armoriée": "armorier",
    "armoriées": "armorier",
    "armoriés": "armorier",
    "armureries": "armurerie",
    "armures": "armure",
    "armuriers": "armurier",
    "armâmes": "armer",
    "armât": "armer",
    "armâtes": "armer",
    "armèrent": "armer",
    "armé": "armer",
    "armée": "armer",
    "armées": "armer",
    "arménienne": "arménien",
    "arméniennes": "arménien",
    "arméniens": "arménien",
    "armérias": "arméria",
    "armés": "armer",
    "arnaquait": "arnaquer",
    "arnaquant": "arnaquer",
    "arnaque": "arnaquer",
    "arnaquent": "arnaquer",
    "arnaquera": "arnaquer",
    "arnaques": "arnaquer",
    "arnaqueurs": "arnaqueur",
    "arnaqueuse": "arnaqueur",
    "arnaquez": "arnaquer",
    "arnaqué": "arnaquer",
    "arnaquée": "arnaquer",
    "arnaqués": "arnaquer",
    "arnicas": "arnica",
    "aromates": "aromate",
    "aromatiques": "aromatique",
    "aromatisa": "aromatiser",
    "aromatisai": "aromatiser",
    "aromatisaient": "aromatiser",
    "aromatisais": "aromatiser",
    "aromatisait": "aromatiser",
    "aromatisant": "aromatiser",
    "aromatisas": "aromatiser",
    "aromatisasse": "aromatiser",
    "aromatisassent": "aromatiser",
    "aromatisasses": "aromatiser",
    "aromatisassiez": "aromatiser",
    "aromatisassions": "aromatiser",
    "aromatise": "aromatiser",
    "aromatisent": "aromatiser",
    "aromatisera": "aromatiser",
    "aromatiserai": "aromatiser",
    "aromatiseraient": "aromatiser",
    "aromatiserais": "aromatiser",
    "aromatiserait": "aromatiser",
    "aromatiseras": "aromatiser",
    "aromatiserez": "aromatiser",
    "aromatiseriez": "aromatiser",
    "aromatiserions": "aromatiser",
    "aromatiserons": "aromatiser",
    "aromatiseront": "aromatiser",
    "aromatises": "aromatiser",
    "aromatisez": "aromatiser",
    "aromatisiez": "aromatiser",
    "aromatisions": "aromatiser",
    "aromatisons": "aromatiser",
    "aromatisâmes": "aromatiser",
    "aromatisât": "aromatiser",
    "aromatisâtes": "aromatiser",
    "aromatisèrent": "aromatiser",
    "aromatisé": "aromatiser",
    "aromatisée": "aromatiser",
    "aromatisées": "aromatiser",
    "aromatisés": "aromatiser",
    "arondes": "aronde",
    "arpenta": "arpenter",
    "arpentages": "arpentage",
    "arpentai": "arpenter",
    "arpentaient": "arpenter",
    "arpentais": "arpenter",
    "arpentait": "arpenter",
    "arpentant": "arpenter",
    "arpentas": "arpenter",
    "arpentasse": "arpenter",
    "arpentassent": "arpenter",
    "arpentasses": "arpenter",
    "arpentassiez": "arpenter",
    "arpentassions": "arpenter",
    "arpente": "arpenter",
    "arpentent": "arpenter",
    "arpentera": "arpenter",
    "arpenterai": "arpenter",
    "arpenteraient": "arpenter",
    "arpenterais": "arpenter",
    "arpenterait": "arpenter",
    "arpenteras": "arpenter",
    "arpenterez": "arpenter",
    "arpenteriez": "arpenter",
    "arpenterions": "arpenter",
    "arpenterons": "arpenter",
    "arpenteront": "arpenter",
    "arpentes": "arpenter",
    "arpenteurs": "arpenteur",
    "arpentez": "arpenter",
    "arpentiez": "arpenter",
    "arpentions": "arpenter",
    "arpentons": "arpenter",
    "arpents": "arpent",
    "arpentâmes": "arpenter",
    "arpentât": "arpenter",
    "arpentâtes": "arpenter",
    "arpentèrent": "arpenter",
    "arpenté": "arpenter",
    "arpentée": "arpenter",
    "arpentées": "arpenter",
    "arpentés": "arpenter",
    "arpions": "arpion",
    "arpège": "arpéger",
    "arpègent": "arpéger",
    "arpèges": "arpéger",
    "arpètes": "arpète",
    "arpégea": "arpéger",
    "arpégeai": "arpéger",
    "arpégeaient": "arpéger",
    "arpégeais": "arpéger",
    "arpégeait": "arpéger",
    "arpégeant": "arpéger",
    "arpégeas": "arpéger",
    "arpégeasse": "arpéger",
    "arpégeassent": "arpéger",
    "arpégeasses": "arpéger",
    "arpégeassiez": "arpéger",
    "arpégeassions": "arpéger",
    "arpégeons": "arpéger",
    "arpégera": "arpéger",
    "arpégerai": "arpéger",
    "arpégeraient": "arpéger",
    "arpégerais": "arpéger",
    "arpégerait": "arpéger",
    "arpégeras": "arpéger",
    "arpégerez": "arpéger",
    "arpégeriez": "arpéger",
    "arpégerions": "arpéger",
    "arpégerons": "arpéger",
    "arpégeront": "arpéger",
    "arpégez": "arpéger",
    "arpégeâmes": "arpéger",
    "arpégeât": "arpéger",
    "arpégeâtes": "arpéger",
    "arpégiez": "arpéger",
    "arpégions": "arpéger",
    "arpégèrent": "arpéger",
    "arpégé": "arpéger",
    "arpégée": "arpéger",
    "arpégées": "arpéger",
    "arpégés": "arpéger",
    "arqua": "arquer",
    "arquaient": "arquer",
    "arquait": "arquer",
    "arquant": "arquer",
    "arque": "arquer",
    "arquebuses": "arquebuse",
    "arquebusiers": "arquebusier",
    "arquebusât": "arquebuser",
    "arquent": "arquer",
    "arquepince": "arquepincer",
    "arqué": "arquer",
    "arquée": "arquer",
    "arquées": "arquer",
    "arqués": "arquer",
    "arracha": "arracher",
    "arrachages": "arrachage",
    "arrachai": "arracher",
    "arrachaient": "arracher",
    "arrachais": "arracher",
    "arrachait": "arracher",
    "arrachant": "arracher",
    "arrachas": "arracher",
    "arrachasse": "arracher",
    "arrachassent": "arracher",
    "arrachasses": "arracher",
    "arrachassiez": "arracher",
    "arrachassions": "arracher",
    "arrache": "arracher",
    "arrache-clous": "arrache-clou",
    "arrachements": "arrachement",
    "arrachent": "arracher",
    "arrachera": "arracher",
    "arracherai": "arracher",
    "arracheraient": "arracher",
    "arracherais": "arracher",
    "arracherait": "arracher",
    "arracheras": "arracher",
    "arracherez": "arracher",
    "arracheriez": "arracher",
    "arracherions": "arracher",
    "arracherons": "arracher",
    "arracheront": "arracher",
    "arraches": "arracher",
    "arracheurs": "arracheur",
    "arracheuse": "arracheur",
    "arracheuses": "arracheur",
    "arrachez": "arracher",
    "arrachiez": "arracher",
    "arrachions": "arracher",
    "arrachons": "arracher",
    "arrachures": "arrachure",
    "arrachâmes": "arracher",
    "arrachât": "arracher",
    "arrachâtes": "arracher",
    "arrachèrent": "arracher",
    "arraché": "arracher",
    "arrachée": "arracher",
    "arrachées": "arracher",
    "arrachés": "arracher",
    "arraisonna": "arraisonner",
    "arraisonnai": "arraisonner",
    "arraisonnaient": "arraisonner",
    "arraisonnais": "arraisonner",
    "arraisonnait": "arraisonner",
    "arraisonnant": "arraisonner",
    "arraisonnas": "arraisonner",
    "arraisonnasse": "arraisonner",
    "arraisonnassent": "arraisonner",
    "arraisonnasses": "arraisonner",
    "arraisonnassiez": "arraisonner",
    "arraisonnassions": "arraisonner",
    "arraisonne": "arraisonner",
    "arraisonnements": "arraisonnement",
    "arraisonnent": "arraisonner",
    "arraisonnera": "arraisonner",
    "arraisonnerai": "arraisonner",
    "arraisonneraient": "arraisonner",
    "arraisonnerais": "arraisonner",
    "arraisonnerait": "arraisonner",
    "arraisonneras": "arraisonner",
    "arraisonnerez": "arraisonner",
    "arraisonneriez": "arraisonner",
    "arraisonnerions": "arraisonner",
    "arraisonnerons": "arraisonner",
    "arraisonneront": "arraisonner",
    "arraisonnes": "arraisonner",
    "arraisonnez": "arraisonner",
    "arraisonniez": "arraisonner",
    "arraisonnions": "arraisonner",
    "arraisonnons": "arraisonner",
    "arraisonnâmes": "arraisonner",
    "arraisonnât": "arraisonner",
    "arraisonnâtes": "arraisonner",
    "arraisonnèrent": "arraisonner",
    "arraisonné": "arraisonner",
    "arraisonnée": "arraisonner",
    "arraisonnées": "arraisonner",
    "arraisonnés": "arraisonner",
    "arrange": "arranger",
    "arrangea": "arranger",
    "arrangeai": "arranger",
    "arrangeaient": "arranger",
    "arrangeais": "arranger",
    "arrangeait": "arranger",
    "arrangeant": "arranger",
    "arrangeante": "arrangeant",
    "arrangeantes": "arrangeant",
    "arrangeants": "arrangeant",
    "arrangeas": "arranger",
    "arrangeasse": "arranger",
    "arrangeassent": "arranger",
    "arrangeasses": "arranger",
    "arrangeassiez": "arranger",
    "arrangeassions": "arranger",
    "arrangements": "arrangement",
    "arrangent": "arranger",
    "arrangeons": "arranger",
    "arrangera": "arranger",
    "arrangerai": "arranger",
    "arrangeraient": "arranger",
    "arrangerais": "arranger",
    "arrangerait": "arranger",
    "arrangeras": "arranger",
    "arrangerez": "arranger",
    "arrangeriez": "arranger",
    "arrangerions": "arranger",
    "arrangerons": "arranger",
    "arrangeront": "arranger",
    "arranges": "arranger",
    "arrangeurs": "arrangeur",
    "arrangez": "arranger",
    "arrangeâmes": "arranger",
    "arrangeât": "arranger",
    "arrangeâtes": "arranger",
    "arrangiez": "arranger",
    "arrangions": "arranger",
    "arrangèrent": "arranger",
    "arrangé": "arranger",
    "arrangée": "arranger",
    "arrangées": "arranger",
    "arrangés": "arranger",
    "arrestations": "arrestation",
    "arrhes": "arrhe",
    "arrima": "arrimer",
    "arrimages": "arrimage",
    "arrimai": "arrimer",
    "arrimaient": "arrimer",
    "arrimais": "arrimer",
    "arrimait": "arrimer",
    "arrimant": "arrimer",
    "arrimas": "arrimer",
    "arrimasse": "arrimer",
    "arrimassent": "arrimer",
    "arrimasses": "arrimer",
    "arrimassiez": "arrimer",
    "arrimassions": "arrimer",
    "arrime": "arrimer",
    "arriment": "arrimer",
    "arrimera": "arrimer",
    "arrimerai": "arrimer",
    "arrimeraient": "arrimer",
    "arrimerais": "arrimer",
    "arrimerait": "arrimer",
    "arrimeras": "arrimer",
    "arrimerez": "arrimer",
    "arrimeriez": "arrimer",
    "arrimerions": "arrimer",
    "arrimerons": "arrimer",
    "arrimeront": "arrimer",
    "arrimes": "arrimer",
    "arrimez": "arrimer",
    "arrimiez": "arrimer",
    "arrimions": "arrimer",
    "arrimons": "arrimer",
    "arrimâmes": "arrimer",
    "arrimât": "arrimer",
    "arrimâtes": "arrimer",
    "arrimèrent": "arrimer",
    "arrimé": "arrimer",
    "arrimée": "arrimer",
    "arrimées": "arrimer",
    "arrimés": "arrimer",
    "arrisa": "arriser",
    "arrisai": "arriser",
    "arrisaient": "arriser",
    "arrisais": "arriser",
    "arrisait": "arriser",
    "arrisant": "arriser",
    "arrisas": "arriser",
    "arrisasse": "arriser",
    "arrisassent": "arriser",
    "arrisasses": "arriser",
    "arrisassiez": "arriser",
    "arrisassions": "arriser",
    "arrise": "arriser",
    "arrisent": "arriser",
    "arrisera": "arriser",
    "arriserai": "arriser",
    "arriseraient": "arriser",
    "arriserais": "arriser",
    "arriserait": "arriser",
    "arriseras": "arriser",
    "arriserez": "arriser",
    "arriseriez": "arriser",
    "arriserions": "arriser",
    "arriserons": "arriser",
    "arriseront": "arriser",
    "arrises": "arriser",
    "arrisez": "arriser",
    "arrisiez": "arriser",
    "arrisions": "arriser",
    "arrisons": "arriser",
    "arrisâmes": "arriser",
    "arrisât": "arriser",
    "arrisâtes": "arriser",
    "arrisèrent": "arriser",
    "arrisé": "arriser",
    "arrisée": "arriser",
    "arrisées": "arriser",
    "arrisés": "arriser",
    "arriva": "arriver",
    "arrivages": "arrivage",
    "arrivai": "arriver",
    "arrivaient": "arriver",
    "arrivais": "arriver",
    "arrivait": "arriver",
    "arrivant": "arriver",
    "arrivante": "arrivant",
    "arrivantes": "arrivant",
    "arrivants": "arrivant",
    "arrivas": "arriver",
    "arrivasse": "arriver",
    "arrivassent": "arriver",
    "arrivasses": "arriver",
    "arrivassiez": "arriver",
    "arrivassions": "arriver",
    "arrive": "arriver",
    "arrivent": "arriver",
    "arriver": "avoir",
    "arrivera": "arriver",
    "arriverai": "arriver",
    "arriveraient": "arriver",
    "arriverais": "arriver",
    "arriverait": "arriver",
    "arriveras": "arriver",
    "arriverez": "arriver",
    "arriveriez": "arriver",
    "arriverions": "arriver",
    "arriverons": "arriver",
    "arriveront": "arriver",
    "arrives": "arriver",
    "arrivez": "arriver",
    "arriviez": "arriver",
    "arrivions": "arriver",
    "arrivistes": "arriviste",
    "arrivons": "arriver",
    "arrivâmes": "arriver",
    "arrivât": "arriver",
    "arrivâtes": "arriver",
    "arrivèrent": "arriver",
    "arrivé": "arriver",
    "arrivée": "arriver",
    "arrivées": "arriver",
    "arrivés": "arriver",
    "arrière": "arriérer",
    "arrière-bans": "arrière-ban",
    "arrière-bouches": "arrière-bouche",
    "arrière-boutiques": "arrière-boutique",
    "arrière-cabinets": "arrière-cabinet",
    "arrière-cours": "arrière-cour",
    "arrière-cuisines": "arrière-cuisine",
    "arrière-gardes": "arrière-garde",
    "arrière-gorges": "arrière-gorge",
    "arrière-goûts": "arrière-goût",
    "arrière-grand-mères": "arrière-grand-mère",
    "arrière-grand-tantes": "arrière-grand-tante",
    "arrière-grands-mères": "arrière-grand-mère",
    "arrière-grands-oncles": "arrière-grand-oncle",
    "arrière-grands-parents": "arrière-grand-parent",
    "arrière-grands-pères": "arrière-grand-père",
    "arrière-mains": "arrière-main",
    "arrière-neveux": "arrière-neveu",
    "arrière-pensées": "arrière-pensée",
    "arrière-petites-filles": "arrière-petite-fille",
    "arrière-petites-nièces": "arrière-petite-nièce",
    "arrière-petits-enfants": "arrière-petit-enfant",
    "arrière-petits-fils": "arrière-petit-fils",
    "arrière-plans": "arrière-plan",
    "arrière-saisons": "arrière-saison",
    "arrière-salles": "arrière-salle",
    "arrière-trains": "arrière-train",
    "arrière-vassaux": "arrière-vassal",
    "arrièrent": "arriérer",
    "arrières": "arriérer",
    "arriéra": "arriérer",
    "arriérai": "arriérer",
    "arriéraient": "arriérer",
    "arriérais": "arriérer",
    "arriérait": "arriérer",
    "arriérant": "arriérer",
    "arriéras": "arriérer",
    "arriérasse": "arriérer",
    "arriérassent": "arriérer",
    "arriérasses": "arriérer",
    "arriérassiez": "arriérer",
    "arriérassions": "arriérer",
    "arriérera": "arriérer",
    "arriérerai": "arriérer",
    "arriéreraient": "arriérer",
    "arriérerais": "arriérer",
    "arriérerait": "arriérer",
    "arriéreras": "arriérer",
    "arriérerez": "arriérer",
    "arriéreriez": "arriérer",
    "arriérerions": "arriérer",
    "arriérerons": "arriérer",
    "arriéreront": "arriérer",
    "arriérez": "arriérer",
    "arriériez": "arriérer",
    "arriérions": "arriérer",
    "arriérons": "arriérer",
    "arriérâmes": "arriérer",
    "arriérât": "arriérer",
    "arriérâtes": "arriérer",
    "arriérèrent": "arriérer",
    "arriéré": "arriérer",
    "arriérée": "arriérer",
    "arriérées": "arriérer",
    "arriérés": "arriérer",
    "arroches": "arroche",
    "arrogances": "arrogance",
    "arrogante": "arrogant",
    "arrogantes": "arrogant",
    "arrogants": "arrogant",
    "arroge": "arroger",
    "arrogea": "arroger",
    "arrogeai": "arroger",
    "arrogeaient": "arroger",
    "arrogeais": "arroger",
    "arrogeait": "arroger",
    "arrogeant": "arroger",
    "arrogeas": "arroger",
    "arrogeasse": "arroger",
    "arrogeassent": "arroger",
    "arrogeasses": "arroger",
    "arrogeassiez": "arroger",
    "arrogeassions": "arroger",
    "arrogent": "arroger",
    "arrogeons": "arroger",
    "arrogera": "arroger",
    "arrogerai": "arroger",
    "arrogeraient": "arroger",
    "arrogerais": "arroger",
    "arrogerait": "arroger",
    "arrogeras": "arroger",
    "arrogerez": "arroger",
    "arrogeriez": "arroger",
    "arrogerions": "arroger",
    "arrogerons": "arroger",
    "arrogeront": "arroger",
    "arroges": "arroger",
    "arrogez": "arroger",
    "arrogeâmes": "arroger",
    "arrogeât": "arroger",
    "arrogeâtes": "arroger",
    "arrogiez": "arroger",
    "arrogions": "arroger",
    "arrogèrent": "arroger",
    "arrogé": "arroger",
    "arrogée": "arroger",
    "arrogées": "arroger",
    "arrogés": "arroger",
    "arrondi": "arrondir",
    "arrondie": "arrondir",
    "arrondies": "arrondir",
    "arrondira": "arrondir",
    "arrondirai": "arrondir",
    "arrondiraient": "arrondir",
    "arrondirais": "arrondir",
    "arrondirait": "arrondir",
    "arrondiras": "arrondir",
    "arrondirent": "arrondir",
    "arrondirez": "arrondir",
    "arrondiriez": "arrondir",
    "arrondirions": "arrondir",
    "arrondirons": "arrondir",
    "arrondiront": "arrondir",
    "arrondis": "arrondir",
    "arrondissaient": "arrondir",
    "arrondissais": "arrondir",
    "arrondissait": "arrondir",
    "arrondissant": "arrondir",
    "arrondisse": "arrondir",
    "arrondissements": "arrondissement",
    "arrondissent": "arrondir",
    "arrondisses": "arrondir",
    "arrondissez": "arrondir",
    "arrondissiez": "arrondir",
    "arrondissions": "arrondir",
    "arrondissons": "arrondir",
    "arrondit": "arrondir",
    "arrondîmes": "arrondir",
    "arrondît": "arrondir",
    "arrondîtes": "arrondir",
    "arrosa": "arroser",
    "arrosages": "arrosage",
    "arrosai": "arroser",
    "arrosaient": "arroser",
    "arrosais": "arroser",
    "arrosait": "arroser",
    "arrosant": "arroser",
    "arrosas": "arroser",
    "arrosasse": "arroser",
    "arrosassent": "arroser",
    "arrosasses": "arroser",
    "arrosassiez": "arroser",
    "arrosassions": "arroser",
    "arrose": "arroser",
    "arrosent": "arroser",
    "arrosera": "arroser",
    "arroserai": "arroser",
    "arroseraient": "arroser",
    "arroserais": "arroser",
    "arroserait": "arroser",
    "arroseras": "arroser",
    "arroserez": "arroser",
    "arroseriez": "arroser",
    "arroserions": "arroser",
    "arroserons": "arroser",
    "arroseront": "arroser",
    "arroses": "arroser",
    "arroseurs": "arroseur",
    "arroseuse": "arroseur",
    "arroseuses": "arroseur",
    "arrosez": "arroser",
    "arrosiez": "arroser",
    "arrosions": "arroser",
    "arrosoirs": "arrosoir",
    "arrosons": "arroser",
    "arrosâmes": "arroser",
    "arrosât": "arroser",
    "arrosâtes": "arroser",
    "arrosèrent": "arroser",
    "arrosé": "arroser",
    "arrosée": "arroser",
    "arrosées": "arroser",
    "arrosés": "arroser",
    "arrow-roots": "arrow-root",
    "arroyos": "arroyo",
    "arrérages": "arrérage",
    "arrêta": "arrêter",
    "arrêtai": "arrêter",
    "arrêtaient": "arrêter",
    "arrêtais": "arrêter",
    "arrêtait": "arrêter",
    "arrêtant": "arrêter",
    "arrêtas": "arrêter",
    "arrêtasse": "arrêter",
    "arrêtassent": "arrêter",
    "arrêtasses": "arrêter",
    "arrêtassiez": "arrêter",
    "arrêtassions": "arrêter",
    "arrête": "arrêter",
    "arrêtent": "arrêter",
    "arrêtera": "arrêter",
    "arrêterai": "arrêter",
    "arrêteraient": "arrêter",
    "arrêterais": "arrêter",
    "arrêterait": "arrêter",
    "arrêteras": "arrêter",
    "arrêterez": "arrêter",
    "arrêteriez": "arrêter",
    "arrêterions": "arrêter",
    "arrêterons": "arrêter",
    "arrêteront": "arrêter",
    "arrêtes": "arrêter",
    "arrêtez": "arrêter",
    "arrêtiez": "arrêter",
    "arrêtions": "arrêter",
    "arrêtons": "arrêter",
    "arrêts": "arrêt",
    "arrêts-buffet": "arrêt-buffet",
    "arrêtâmes": "arrêter",
    "arrêtât": "arrêter",
    "arrêtâtes": "arrêter",
    "arrêtèrent": "arrêter",
    "arrêté": "arrêter",
    "arrêtée": "arrêter",
    "arrêtées": "arrêter",
    "arrêtés": "arrêter",
    "arsenaux": "arsenal",
    "arsenicales": "arsenical",
    "arsenics": "arsenic",
    "arsouilles": "arsouille",
    "artefacts": "artefact",
    "arthrites": "arthrite",
    "arthritiques": "arthritique",
    "arthropodes": "arthropode",
    "arthroses": "arthrose",
    "arthurienne": "arthurien",
    "arthuriens": "arthurien",
    "artichauts": "artichaut",
    "articles": "article",
    "articula": "articuler",
    "articulai": "articuler",
    "articulaient": "articuler",
    "articulaires": "articulaire",
    "articulais": "articuler",
    "articulait": "articuler",
    "articulant": "articuler",
    "articulas": "articuler",
    "articulasse": "articuler",
    "articulassent": "articuler",
    "articulasses": "articuler",
    "articulassiez": "articuler",
    "articulassions": "articuler",
    "articulations": "articulation",
    "articule": "articuler",
    "articulent": "articuler",
    "articulera": "articuler",
    "articulerai": "articuler",
    "articuleraient": "articuler",
    "articulerais": "articuler",
    "articulerait": "articuler",
    "articuleras": "articuler",
    "articulerez": "articuler",
    "articuleriez": "articuler",
    "articulerions": "articuler",
    "articulerons": "articuler",
    "articuleront": "articuler",
    "articules": "articuler",
    "articulez": "articuler",
    "articuliez": "articuler",
    "articulions": "articuler",
    "articulons": "articuler",
    "articulâmes": "articuler",
    "articulât": "articuler",
    "articulâtes": "articuler",
    "articulèrent": "articuler",
    "articulé": "articuler",
    "articulée": "articuler",
    "articulées": "articuler",
    "articulés": "articuler",
    "artifices": "artifice",
    "artificielle": "artificiel",
    "artificielles": "artificiel",
    "artificiels": "artificiel",
    "artificiers": "artificier",
    "artificieuse": "artificieux",
    "artificieuses": "artificieux",
    "artiflots": "artiflot",
    "artilleries": "artillerie",
    "artilleurs": "artilleur",
    "artimons": "artimon",
    "artisanale": "artisanal",
    "artisanales": "artisanal",
    "artisanats": "artisanat",
    "artisanaux": "artisanal",
    "artisane": "artisan",
    "artisanes": "artisan",
    "artisans": "artisan",
    "artistes": "artiste",
    "artistiques": "artistique",
    "arts": "art",
    "artères": "artère",
    "artérielle": "artériel",
    "artérielles": "artériel",
    "artériels": "artériel",
    "artérioles": "artériole",
    "arums": "arum",
    "aruspices": "aruspice",
    "arvernes": "arverne",
    "aryenne": "aryen",
    "aryennes": "aryenne",
    "aryens": "aryen",
    "arzels": "arzel",
    "arçons": "arçon",
    "arènes": "arène",
    "aréoles": "aréole",
    "aréopages": "aréopage",
    "aréquiers": "aréquier",
    "arêtes": "arête",
    "arômes": "arôme",
    "as": "avoir",
    "asbestes": "asbeste",
    "ascendances": "ascendance",
    "ascendante": "ascendant",
    "ascendantes": "ascendant",
    "ascendants": "ascendant",
    "ascendu": "ascendre",
    "ascenseurs": "ascenseur",
    "ascensionne": "ascensionner",
    "ascensionnelle": "ascensionnel",
    "ascensionnelles": "ascensionnel",
    "ascensionnels": "ascensionnel",
    "ascensions": "ascension",
    "asclépiades": "asclépiade",
    "ascospheras": "ascosphera",
    "ascèses": "ascèse",
    "ascètes": "ascète",
    "ascétiques": "ascétique",
    "ascétismes": "ascétisme",
    "ase": "as",
    "asepsies": "asepsie",
    "aseptiques": "aseptique",
    "aseptisant": "aseptiser",
    "aseptisé": "aseptiser",
    "aseptisée": "aseptiser",
    "aseptisées": "aseptisé",
    "aseptisés": "aseptisé",
    "asexuelle": "asexuel",
    "asexuée": "asexué",
    "asexuées": "asexué",
    "asexués": "asexué",
    "ashkénazes": "ashkénaze",
    "asiatiques": "asiatique",
    "asiatisé": "asiatiser",
    "asiles": "asile",
    "asociale": "asocial",
    "asociales": "asocial",
    "asociaux": "asocial",
    "aspects": "aspect",
    "asperge": "asperger",
    "aspergea": "asperger",
    "aspergeai": "asperger",
    "aspergeaient": "asperger",
    "aspergeais": "asperger",
    "aspergeait": "asperger",
    "aspergeant": "asperger",
    "aspergeas": "asperger",
    "aspergeasse": "asperger",
    "aspergeassent": "asperger",
    "aspergeasses": "asperger",
    "aspergeassiez": "asperger",
    "aspergeassions": "asperger",
    "aspergent": "asperger",
    "aspergeons": "asperger",
    "aspergera": "asperger",
    "aspergerai": "asperger",
    "aspergeraient": "asperger",
    "aspergerais": "asperger",
    "aspergerait": "asperger",
    "aspergeras": "asperger",
    "aspergerez": "asperger",
    "aspergeriez": "asperger",
    "aspergerions": "asperger",
    "aspergerons": "asperger",
    "aspergeront": "asperger",
    "asperges": "asperger",
    "aspergez": "asperger",
    "aspergeâmes": "asperger",
    "aspergeât": "asperger",
    "aspergeâtes": "asperger",
    "aspergiez": "asperger",
    "aspergions": "asperger",
    "aspergèrent": "asperger",
    "aspergé": "asperger",
    "aspergée": "asperger",
    "aspergées": "asperger",
    "aspergés": "asperger",
    "aspersions": "aspersion",
    "asphaltages": "asphaltage",
    "asphalte": "asphalter",
    "asphaltes": "asphalte",
    "asphalté": "asphalter",
    "asphaltée": "asphalter",
    "asphaltées": "asphalter",
    "asphaltés": "asphalter",
    "asphodèles": "asphodèle",
    "asphyxia": "asphyxier",
    "asphyxiai": "asphyxier",
    "asphyxiaient": "asphyxier",
    "asphyxiais": "asphyxier",
    "asphyxiait": "asphyxier",
    "asphyxiant": "asphyxier",
    "asphyxiante": "asphyxiant",
    "asphyxiantes": "asphyxiant",
    "asphyxiants": "asphyxiant",
    "asphyxias": "asphyxier",
    "asphyxiasse": "asphyxier",
    "asphyxiassent": "asphyxier",
    "asphyxiasses": "asphyxier",
    "asphyxiassiez": "asphyxier",
    "asphyxiassions": "asphyxier",
    "asphyxie": "asphyxier",
    "asphyxient": "asphyxier",
    "asphyxiera": "asphyxier",
    "asphyxierai": "asphyxier",
    "asphyxieraient": "asphyxier",
    "asphyxierais": "asphyxier",
    "asphyxierait": "asphyxier",
    "asphyxieras": "asphyxier",
    "asphyxierez": "asphyxier",
    "asphyxieriez": "asphyxier",
    "asphyxierions": "asphyxier",
    "asphyxierons": "asphyxier",
    "asphyxieront": "asphyxier",
    "asphyxies": "asphyxier",
    "asphyxiez": "asphyxier",
    "asphyxiiez": "asphyxier",
    "asphyxiions": "asphyxier",
    "asphyxions": "asphyxier",
    "asphyxiâmes": "asphyxier",
    "asphyxiât": "asphyxier",
    "asphyxiâtes": "asphyxier",
    "asphyxièrent": "asphyxier",
    "asphyxié": "asphyxier",
    "asphyxiée": "asphyxier",
    "asphyxiées": "asphyxier",
    "asphyxiés": "asphyxier",
    "aspics": "aspic",
    "aspidistras": "aspidistra",
    "aspira": "aspirer",
    "aspirai": "aspirer",
    "aspiraient": "aspirer",
    "aspirais": "aspirer",
    "aspirait": "aspirer",
    "aspirant": "aspirer",
    "aspirante": "aspirant",
    "aspirantes": "aspirant",
    "aspirants": "aspirant",
    "aspiras": "aspirer",
    "aspirasse": "aspirer",
    "aspirassent": "aspirer",
    "aspirasses": "aspirer",
    "aspirassiez": "aspirer",
    "aspirassions": "aspirer",
    "aspirateurs": "aspirateur",
    "aspirations": "aspiration",
    "aspiratrice": "aspirateur",
    "aspiratrices": "aspirateur",
    "aspire": "aspirer",
    "aspirent": "aspirer",
    "aspirera": "aspirer",
    "aspirerai": "aspirer",
    "aspireraient": "aspirer",
    "aspirerais": "aspirer",
    "aspirerait": "aspirer",
    "aspireras": "aspirer",
    "aspirerez": "aspirer",
    "aspireriez": "aspirer",
    "aspirerions": "aspirer",
    "aspirerons": "aspirer",
    "aspireront": "aspirer",
    "aspires": "aspirer",
    "aspirez": "aspirer",
    "aspiriez": "aspirer",
    "aspirines": "aspirine",
    "aspirions": "aspirer",
    "aspirons": "aspirer",
    "aspirâmes": "aspirer",
    "aspirât": "aspirer",
    "aspirâtes": "aspirer",
    "aspirèrent": "aspirer",
    "aspiré": "aspirer",
    "aspirée": "aspirer",
    "aspirées": "aspirer",
    "aspirés": "aspirer",
    "aspis": "aspi",
    "aspérités": "aspérité",
    "assagi": "assagir",
    "assagie": "assagir",
    "assagies": "assagir",
    "assagira": "assagir",
    "assagirai": "assagir",
    "assagiraient": "assagir",
    "assagirais": "assagir",
    "assagirait": "assagir",
    "assagiras": "assagir",
    "assagirent": "assagir",
    "assagirez": "assagir",
    "assagiriez": "assagir",
    "assagirions": "assagir",
    "assagirons": "assagir",
    "assagiront": "assagir",
    "assagis": "assagir",
    "assagissaient": "assagir",
    "assagissais": "assagir",
    "assagissait": "assagir",
    "assagissant": "assagir",
    "assagisse": "assagir",
    "assagissent": "assagir",
    "assagisses": "assagir",
    "assagissez": "assagir",
    "assagissiez": "assagir",
    "assagissions": "assagir",
    "assagissons": "assagir",
    "assagit": "assagir",
    "assagîmes": "assagir",
    "assagît": "assagir",
    "assagîtes": "assagir",
    "assaillaient": "assaillir",
    "assaillais": "assaillir",
    "assaillait": "assaillir",
    "assaillant": "assaillir",
    "assaillante": "assaillant",
    "assaillantes": "assaillant",
    "assaillants": "assaillant",
    "assaille": "assaillir",
    "assaillent": "assaillir",
    "assailles": "assaillir",
    "assaillez": "assaillir",
    "assailli": "assaillir",
    "assaillie": "assaillir",
    "assaillies": "assaillir",
    "assailliez": "assaillir",
    "assaillions": "assaillir",
    "assaillira": "assaillir",
    "assaillirai": "assaillir",
    "assailliraient": "assaillir",
    "assaillirais": "assaillir",
    "assaillirait": "assaillir",
    "assailliras": "assaillir",
    "assaillirent": "assaillir",
    "assaillirez": "assaillir",
    "assailliriez": "assaillir",
    "assaillirions": "assaillir",
    "assaillirons": "assaillir",
    "assailliront": "assaillir",
    "assaillis": "assaillir",
    "assaillisse": "assaillir",
    "assaillissent": "assaillir",
    "assaillisses": "assaillir",
    "assaillissiez": "assaillir",
    "assaillissions": "assaillir",
    "assaillit": "assaillir",
    "assaillons": "assaillir",
    "assaillîmes": "assaillir",
    "assaillît": "assaillir",
    "assaillîtes": "assaillir",
    "assaini": "assainir",
    "assainie": "assainir",
    "assainies": "assainir",
    "assainira": "assainir",
    "assainirai": "assainir",
    "assainiraient": "assainir",
    "assainirais": "assainir",
    "assainirait": "assainir",
    "assainiras": "assainir",
    "assainirent": "assainir",
    "assainirez": "assainir",
    "assainiriez": "assainir",
    "assainirions": "assainir",
    "assainirons": "assainir",
    "assainiront": "assainir",
    "assainis": "assainir",
    "assainissaient": "assainir",
    "assainissais": "assainir",
    "assainissait": "assainir",
    "assainissant": "assainir",
    "assainisse": "assainir",
    "assainissements": "assainissement",
    "assainissent": "assainir",
    "assainisses": "assainir",
    "assainissez": "assainir",
    "assainissiez": "assainir",
    "assainissions": "assainir",
    "assainissons": "assainir",
    "assainit": "assainir",
    "assainîmes": "assainir",
    "assainît": "assainir",
    "assainîtes": "assainir",
    "assaisonna": "assaisonner",
    "assaisonnai": "assaisonner",
    "assaisonnaient": "assaisonner",
    "assaisonnais": "assaisonner",
    "assaisonnait": "assaisonner",
    "assaisonnant": "assaisonner",
    "assaisonnas": "assaisonner",
    "assaisonnasse": "assaisonner",
    "assaisonnassent": "assaisonner",
    "assaisonnasses": "assaisonner",
    "assaisonnassiez": "assaisonner",
    "assaisonnassions": "assaisonner",
    "assaisonne": "assaisonner",
    "assaisonnements": "assaisonnement",
    "assaisonnent": "assaisonner",
    "assaisonnera": "assaisonner",
    "assaisonnerai": "assaisonner",
    "assaisonneraient": "assaisonner",
    "assaisonnerais": "assaisonner",
    "assaisonnerait": "assaisonner",
    "assaisonneras": "assaisonner",
    "assaisonnerez": "assaisonner",
    "assaisonneriez": "assaisonner",
    "assaisonnerions": "assaisonner",
    "assaisonnerons": "assaisonner",
    "assaisonneront": "assaisonner",
    "assaisonnes": "assaisonner",
    "assaisonnez": "assaisonner",
    "assaisonniez": "assaisonner",
    "assaisonnions": "assaisonner",
    "assaisonnons": "assaisonner",
    "assaisonnâmes": "assaisonner",
    "assaisonnât": "assaisonner",
    "assaisonnâtes": "assaisonner",
    "assaisonnèrent": "assaisonner",
    "assaisonné": "assaisonner",
    "assaisonnée": "assaisonner",
    "assaisonnées": "assaisonner",
    "assaisonnés": "assaisonner",
    "assassina": "assassiner",
    "assassinai": "assassiner",
    "assassinaient": "assassiner",
    "assassinais": "assassiner",
    "assassinait": "assassiner",
    "assassinant": "assassiner",
    "assassinas": "assassiner",
    "assassinasse": "assassiner",
    "assassinassent": "assassiner",
    "assassinasses": "assassiner",
    "assassinassiez": "assassiner",
    "assassinassions": "assassiner",
    "assassinats": "assassinat",
    "assassine": "assassiner",
    "assassinent": "assassiner",
    "assassinera": "assassiner",
    "assassinerai": "assassiner",
    "assassineraient": "assassiner",
    "assassinerais": "assassiner",
    "assassinerait": "assassiner",
    "assassineras": "assassiner",
    "assassinerez": "assassiner",
    "assassineriez": "assassiner",
    "assassinerions": "assassiner",
    "assassinerons": "assassiner",
    "assassineront": "assassiner",
    "assassines": "assassiner",
    "assassinez": "assassiner",
    "assassiniez": "assassiner",
    "assassinions": "assassiner",
    "assassinons": "assassiner",
    "assassins": "assassin",
    "assassinâmes": "assassiner",
    "assassinât": "assassiner",
    "assassinâtes": "assassiner",
    "assassinèrent": "assassiner",
    "assassiné": "assassiner",
    "assassinée": "assassiner",
    "assassinées": "assassiner",
    "assassinés": "assassiner",
    "assauts": "assaut",
    "assembla": "assembler",
    "assemblages": "assemblage",
    "assemblai": "assembler",
    "assemblaient": "assembler",
    "assemblais": "assembler",
    "assemblait": "assembler",
    "assemblant": "assembler",
    "assemblas": "assembler",
    "assemblasse": "assembler",
    "assemblassent": "assembler",
    "assemblasses": "assembler",
    "assemblassiez": "assembler",
    "assemblassions": "assembler",
    "assemble": "assembler",
    "assemblent": "assembler",
    "assemblera": "assembler",
    "assemblerai": "assembler",
    "assembleraient": "assembler",
    "assemblerais": "assembler",
    "assemblerait": "assembler",
    "assembleras": "assembler",
    "assemblerez": "assembler",
    "assembleriez": "assembler",
    "assemblerions": "assembler",
    "assemblerons": "assembler",
    "assembleront": "assembler",
    "assembles": "assembler",
    "assembleurs": "assembleur",
    "assemblez": "assembler",
    "assembliez": "assembler",
    "assemblions": "assembler",
    "assemblons": "assembler",
    "assemblâmes": "assembler",
    "assemblât": "assembler",
    "assemblâtes": "assembler",
    "assemblèrent": "assembler",
    "assemblé": "assembler",
    "assemblée": "assembler",
    "assemblées": "assembler",
    "assemblés": "assembler",
    "assena": "assener",
    "assenai": "assener",
    "assenaient": "assener",
    "assenais": "assener",
    "assenait": "assener",
    "assenant": "assener",
    "assenas": "assener",
    "assenasse": "assener",
    "assenassent": "assener",
    "assenasses": "assener",
    "assenassiez": "assener",
    "assenassions": "assener",
    "assenez": "assener",
    "asseniez": "assener",
    "assenions": "assener",
    "assenons": "assener",
    "assentiments": "assentiment",
    "assenâmes": "assener",
    "assenât": "assener",
    "assenâtes": "assener",
    "assenèrent": "assener",
    "assené": "assener",
    "assenée": "assener",
    "assenées": "assener",
    "assenés": "assener",
    "assermenta": "assermenter",
    "assermentai": "assermenter",
    "assermentaient": "assermenter",
    "assermentais": "assermenter",
    "assermentait": "assermenter",
    "assermentant": "assermenter",
    "assermentas": "assermenter",
    "assermentasse": "assermenter",
    "assermentassent": "assermenter",
    "assermentasses": "assermenter",
    "assermentassiez": "assermenter",
    "assermentassions": "assermenter",
    "assermente": "assermenter",
    "assermentent": "assermenter",
    "assermentera": "assermenter",
    "assermenterai": "assermenter",
    "assermenteraient": "assermenter",
    "assermenterais": "assermenter",
    "assermenterait": "assermenter",
    "assermenteras": "assermenter",
    "assermenterez": "assermenter",
    "assermenteriez": "assermenter",
    "assermenterions": "assermenter",
    "assermenterons": "assermenter",
    "assermenteront": "assermenter",
    "assermentes": "assermenter",
    "assermentez": "assermenter",
    "assermentiez": "assermenter",
    "assermentions": "assermenter",
    "assermentons": "assermenter",
    "assermentâmes": "assermenter",
    "assermentât": "assermenter",
    "assermentâtes": "assermenter",
    "assermentèrent": "assermenter",
    "assermenté": "assermenter",
    "assermentée": "assermenter",
    "assermentées": "assermenter",
    "assermentés": "assermenter",
    "assertations": "assertation",
    "assertions": "assertion",
    "asservi": "asservir",
    "asservie": "asservir",
    "asservies": "asservir",
    "asservira": "asservir",
    "asservirai": "asservir",
    "asserviraient": "asservir",
    "asservirais": "asservir",
    "asservirait": "asservir",
    "asserviras": "asservir",
    "asservirent": "asservir",
    "asservirez": "asservir",
    "asserviriez": "asservir",
    "asservirions": "asservir",
    "asservirons": "asservir",
    "asserviront": "asservir",
    "asservis": "asservir",
    "asservissaient": "asservir",
    "asservissais": "asservir",
    "asservissait": "asservir",
    "asservissant": "asservir",
    "asservisse": "asservir",
    "asservissements": "asservissement",
    "asservissent": "asservir",
    "asservisses": "asservir",
    "asservissez": "asservir",
    "asservissiez": "asservir",
    "asservissions": "asservir",
    "asservissons": "asservir",
    "asservit": "asservir",
    "asservîmes": "asservir",
    "asservît": "asservir",
    "asservîtes": "asservir",
    "assesseurs": "assesseur",
    "asseyaient": "asseoir",
    "asseyais": "asseoir",
    "asseyait": "asseoir",
    "asseyant": "asseoir",
    "asseye": "asseoir",
    "asseyent": "asseoir",
    "asseyes": "asseoir",
    "asseyez": "asseoir",
    "asseyiez": "asseoir",
    "asseyions": "asseoir",
    "asseyons": "asseoir",
    "assidue": "assidu",
    "assidues": "assidu",
    "assiduités": "assiduité",
    "assidus": "assidu",
    "assied": "asseoir",
    "assieds": "asseoir",
    "assiettes": "assiette",
    "assiettées": "assiettée",
    "assigna": "assigner",
    "assignai": "assigner",
    "assignaient": "assigner",
    "assignais": "assigner",
    "assignait": "assigner",
    "assignant": "assigner",
    "assignas": "assigner",
    "assignasse": "assigner",
    "assignassent": "assigner",
    "assignasses": "assigner",
    "assignassiez": "assigner",
    "assignassions": "assigner",
    "assignations": "assignation",
    "assignats": "assignat",
    "assigne": "assigner",
    "assignent": "assigner",
    "assignera": "assigner",
    "assignerai": "assigner",
    "assigneraient": "assigner",
    "assignerais": "assigner",
    "assignerait": "assigner",
    "assigneras": "assigner",
    "assignerez": "assigner",
    "assigneriez": "assigner",
    "assignerions": "assigner",
    "assignerons": "assigner",
    "assigneront": "assigner",
    "assignes": "assigner",
    "assignez": "assigner",
    "assigniez": "assigner",
    "assignions": "assigner",
    "assignons": "assigner",
    "assignâmes": "assigner",
    "assignât": "assigner",
    "assignâtes": "assigner",
    "assignèrent": "assigner",
    "assigné": "assigner",
    "assignée": "assigner",
    "assignées": "assigner",
    "assignés": "assigner",
    "assimila": "assimiler",
    "assimilables": "assimilable",
    "assimilai": "assimiler",
    "assimilaient": "assimiler",
    "assimilais": "assimiler",
    "assimilait": "assimiler",
    "assimilant": "assimiler",
    "assimilas": "assimiler",
    "assimilasse": "assimiler",
    "assimilassent": "assimiler",
    "assimilasses": "assimiler",
    "assimilassiez": "assimiler",
    "assimilassions": "assimiler",
    "assimilateurs": "assimilateur",
    "assimilations": "assimilation",
    "assimile": "assimiler",
    "assimilent": "assimiler",
    "assimilera": "assimiler",
    "assimilerai": "assimiler",
    "assimileraient": "assimiler",
    "assimilerais": "assimiler",
    "assimilerait": "assimiler",
    "assimileras": "assimiler",
    "assimilerez": "assimiler",
    "assimileriez": "assimiler",
    "assimilerions": "assimiler",
    "assimilerons": "assimiler",
    "assimileront": "assimiler",
    "assimiles": "assimiler",
    "assimilez": "assimiler",
    "assimiliations": "assimiliation",
    "assimiliez": "assimiler",
    "assimilions": "assimiler",
    "assimilons": "assimiler",
    "assimilâmes": "assimiler",
    "assimilât": "assimiler",
    "assimilâtes": "assimiler",
    "assimilèrent": "assimiler",
    "assimilé": "assimiler",
    "assimilée": "assimiler",
    "assimilées": "assimiler",
    "assimilés": "assimiler",
    "assirent": "asseoir",
    "assis": "asseoir",
    "assise": "assis",
    "assises": "assise",
    "assisse": "asseoir",
    "assissent": "asseoir",
    "assisses": "asseoir",
    "assissiez": "asseoir",
    "assissions": "asseoir",
    "assista": "assister",
    "assistai": "assister",
    "assistaient": "assister",
    "assistais": "assister",
    "assistait": "assister",
    "assistances": "assistance",
    "assistant": "assister",
    "assistante": "assistant",
    "assistantes": "assistant",
    "assistants": "assistant",
    "assistas": "assister",
    "assistasse": "assister",
    "assistassent": "assister",
    "assistasses": "assister",
    "assistassiez": "assister",
    "assistassions": "assister",
    "assiste": "assister",
    "assistent": "assister",
    "assistera": "assister",
    "assisterai": "assister",
    "assisteraient": "assister",
    "assisterais": "assister",
    "assisterait": "assister",
    "assisteras": "assister",
    "assisterez": "assister",
    "assisteriez": "assister",
    "assisterions": "assister",
    "assisterons": "assister",
    "assisteront": "assister",
    "assistes": "assister",
    "assistez": "assister",
    "assistiez": "assister",
    "assistions": "assister",
    "assistons": "assister",
    "assistâmes": "assister",
    "assistât": "assister",
    "assistâtes": "assister",
    "assistèrent": "assister",
    "assisté": "assister",
    "assistée": "assister",
    "assistées": "assister",
    "assistés": "assister",
    "assit": "asseoir",
    "assiège": "assiéger",
    "assiègent": "assiéger",
    "assièges": "assiéger",
    "assiégea": "assiéger",
    "assiégeai": "assiéger",
    "assiégeaient": "assiéger",
    "assiégeais": "assiéger",
    "assiégeait": "assiéger",
    "assiégeant": "assiéger",
    "assiégeantes": "assiégeant",
    "assiégeants": "assiégeant",
    "assiégeas": "assiéger",
    "assiégeasse": "assiéger",
    "assiégeassent": "assiéger",
    "assiégeasses": "assiéger",
    "assiégeassiez": "assiéger",
    "assiégeassions": "assiéger",
    "assiégeons": "assiéger",
    "assiégera": "assiéger",
    "assiégerai": "assiéger",
    "assiégeraient": "assiéger",
    "assiégerais": "assiéger",
    "assiégerait": "assiéger",
    "assiégeras": "assiéger",
    "assiégerez": "assiéger",
    "assiégeriez": "assiéger",
    "assiégerions": "assiéger",
    "assiégerons": "assiéger",
    "assiégeront": "assiéger",
    "assiégez": "assiéger",
    "assiégeâmes": "assiéger",
    "assiégeât": "assiéger",
    "assiégeâtes": "assiéger",
    "assiégiez": "assiéger",
    "assiégions": "assiéger",
    "assiégèrent": "assiéger",
    "assiégé": "assiéger",
    "assiégée": "assiéger",
    "assiégées": "assiéger",
    "assiégés": "assiéger",
    "assiéra": "asseoir",
    "assiérai": "asseoir",
    "assiéraient": "asseoir",
    "assiérais": "asseoir",
    "assiérait": "asseoir",
    "assiéras": "asseoir",
    "assiérez": "asseoir",
    "assiériez": "asseoir",
    "assiérions": "asseoir",
    "assiérons": "asseoir",
    "assiéront": "asseoir",
    "associa": "associer",
    "associai": "associer",
    "associaient": "associer",
    "associais": "associer",
    "associait": "associer",
    "associant": "associer",
    "associas": "associer",
    "associasse": "associer",
    "associassent": "associer",
    "associasses": "associer",
    "associassiez": "associer",
    "associassions": "associer",
    "associatifs": "associatif",
    "associations": "association",
    "associative": "associatif",
    "associatives": "associatif",
    "associe": "associer",
    "associent": "associer",
    "associera": "associer",
    "associerai": "associer",
    "associeraient": "associer",
    "associerais": "associer",
    "associerait": "associer",
    "associeras": "associer",
    "associerez": "associer",
    "associeriez": "associer",
    "associerions": "associer",
    "associerons": "associer",
    "associeront": "associer",
    "associes": "associer",
    "associez": "associer",
    "associiez": "associer",
    "associions": "associer",
    "associons": "associer",
    "associâmes": "associer",
    "associât": "associer",
    "associâtes": "associer",
    "associèrent": "associer",
    "associé": "associer",
    "associée": "associer",
    "associées": "associer",
    "associés": "associer",
    "assoie": "asseoir",
    "assoient": "asseoir",
    "assoies": "asseoir",
    "assoiffa": "assoiffer",
    "assoiffai": "assoiffer",
    "assoiffaient": "assoiffer",
    "assoiffais": "assoiffer",
    "assoiffait": "assoiffer",
    "assoiffant": "assoiffer",
    "assoiffas": "assoiffer",
    "assoiffasse": "assoiffer",
    "assoiffassent": "assoiffer",
    "assoiffasses": "assoiffer",
    "assoiffassiez": "assoiffer",
    "assoiffassions": "assoiffer",
    "assoiffe": "assoiffer",
    "assoiffent": "assoiffer",
    "assoiffera": "assoiffer",
    "assoifferai": "assoiffer",
    "assoifferaient": "assoiffer",
    "assoifferais": "assoiffer",
    "assoifferait": "assoiffer",
    "assoifferas": "assoiffer",
    "assoifferez": "assoiffer",
    "assoifferiez": "assoiffer",
    "assoifferions": "assoiffer",
    "assoifferons": "assoiffer",
    "assoifferont": "assoiffer",
    "assoiffes": "assoiffer",
    "assoiffez": "assoiffer",
    "assoiffiez": "assoiffer",
    "assoiffions": "assoiffer",
    "assoiffons": "assoiffer",
    "assoiffâmes": "assoiffer",
    "assoiffât": "assoiffer",
    "assoiffâtes": "assoiffer",
    "assoiffèrent": "assoiffer",
    "assoiffé": "assoiffer",
    "assoiffée": "assoiffer",
    "assoiffées": "assoiffer",
    "assoiffés": "assoiffer",
    "assoira": "asseoir",
    "assoirai": "asseoir",
    "assoiraient": "asseoir",
    "assoirais": "asseoir",
    "assoirait": "asseoir",
    "assoiras": "asseoir",
    "assoirez": "asseoir",
    "assoiriez": "asseoir",
    "assoirions": "asseoir",
    "assoirons": "asseoir",
    "assoiront": "asseoir",
    "assois": "asseoir",
    "assoit": "asseoir",
    "assola": "assoler",
    "assolai": "assoler",
    "assolaient": "assoler",
    "assolais": "assoler",
    "assolait": "assoler",
    "assolant": "assoler",
    "assolas": "assoler",
    "assolasse": "assoler",
    "assolassent": "assoler",
    "assolasses": "assoler",
    "assolassiez": "assoler",
    "assolassions": "assoler",
    "assole": "assoler",
    "assolent": "assoler",
    "assolera": "assoler",
    "assolerai": "assoler",
    "assoleraient": "assoler",
    "assolerais": "assoler",
    "assolerait": "assoler",
    "assoleras": "assoler",
    "assolerez": "assoler",
    "assoleriez": "assoler",
    "assolerions": "assoler",
    "assolerons": "assoler",
    "assoleront": "assoler",
    "assoles": "assoler",
    "assolez": "assoler",
    "assoliez": "assoler",
    "assolions": "assoler",
    "assolons": "assoler",
    "assolâmes": "assoler",
    "assolât": "assoler",
    "assolâtes": "assoler",
    "assolèrent": "assoler",
    "assolé": "assoler",
    "assolée": "assoler",
    "assolées": "assoler",
    "assolés": "assoler",
    "assombri": "assombrir",
    "assombrie": "assombrir",
    "assombries": "assombrir",
    "assombrira": "assombrir",
    "assombrirai": "assombrir",
    "assombriraient": "assombrir",
    "assombrirais": "assombrir",
    "assombrirait": "assombrir",
    "assombriras": "assombrir",
    "assombrirent": "assombrir",
    "assombrirez": "assombrir",
    "assombririez": "assombrir",
    "assombririons": "assombrir",
    "assombrirons": "assombrir",
    "assombriront": "assombrir",
    "assombris": "assombrir",
    "assombrissaient": "assombrir",
    "assombrissais": "assombrir",
    "assombrissait": "assombrir",
    "assombrissant": "assombrir",
    "assombrisse": "assombrir",
    "assombrissent": "assombrir",
    "assombrisses": "assombrir",
    "assombrissez": "assombrir",
    "assombrissiez": "assombrir",
    "assombrissions": "assombrir",
    "assombrissons": "assombrir",
    "assombrit": "assombrir",
    "assombrîmes": "assombrir",
    "assombrît": "assombrir",
    "assombrîtes": "assombrir",
    "assomma": "assommer",
    "assommai": "assommer",
    "assommaient": "assommer",
    "assommais": "assommer",
    "assommait": "assommer",
    "assommant": "assommer",
    "assommante": "assommant",
    "assommantes": "assommant",
    "assommants": "assommant",
    "assommas": "assommer",
    "assommasse": "assommer",
    "assommassent": "assommer",
    "assommasses": "assommer",
    "assommassiez": "assommer",
    "assommassions": "assommer",
    "assomme": "assommer",
    "assomment": "assommer",
    "assommera": "assommer",
    "assommerai": "assommer",
    "assommeraient": "assommer",
    "assommerais": "assommer",
    "assommerait": "assommer",
    "assommeras": "assommer",
    "assommerez": "assommer",
    "assommeriez": "assommer",
    "assommerions": "assommer",
    "assommerons": "assommer",
    "assommeront": "assommer",
    "assommes": "assommer",
    "assommez": "assommer",
    "assommiez": "assommer",
    "assommions": "assommer",
    "assommoirs": "assommoir",
    "assommons": "assommer",
    "assommâmes": "assommer",
    "assommât": "assommer",
    "assommâtes": "assommer",
    "assommèrent": "assommer",
    "assommé": "assommer",
    "assommée": "assommer",
    "assommées": "assommer",
    "assommés": "assommer",
    "assomptions": "assomption",
    "assonances": "assonance",
    "assonante": "assonant",
    "assonantes": "assonant",
    "assonants": "assonant",
    "assorti": "assortir",
    "assortie": "assortir",
    "assorties": "assortir",
    "assortiments": "assortiment",
    "assortira": "assortir",
    "assortirai": "assortir",
    "assortiraient": "assortir",
    "assortirais": "assortir",
    "assortirait": "assortir",
    "assortiras": "assortir",
    "assortirent": "assortir",
    "assortirez": "assortir",
    "assortiriez": "assortir",
    "assortirions": "assortir",
    "assortirons": "assortir",
    "assortiront": "assortir",
    "assortis": "assortir",
    "assortissaient": "assortir",
    "assortissais": "assortir",
    "assortissait": "assortir",
    "assortissant": "assortir",
    "assortisse": "assortir",
    "assortissent": "assortir",
    "assortisses": "assortir",
    "assortissez": "assortir",
    "assortissiez": "assortir",
    "assortissions": "assortir",
    "assortissons": "assortir",
    "assortit": "assortir",
    "assortîmes": "assortir",
    "assortît": "assortir",
    "assortîtes": "assortir",
    "assoté": "assoter",
    "assotés": "assoter",
    "assoupi": "assoupir",
    "assoupie": "assoupir",
    "assoupies": "assoupir",
    "assoupira": "assoupir",
    "assoupirai": "assoupir",
    "assoupiraient": "assoupir",
    "assoupirais": "assoupir",
    "assoupirait": "assoupir",
    "assoupiras": "assoupir",
    "assoupirent": "assoupir",
    "assoupirez": "assoupir",
    "assoupiriez": "assoupir",
    "assoupirions": "assoupir",
    "assoupirons": "assoupir",
    "assoupiront": "assoupir",
    "assoupis": "assoupir",
    "assoupissaient": "assoupir",
    "assoupissais": "assoupir",
    "assoupissait": "assoupir",
    "assoupissant": "assoupir",
    "assoupisse": "assoupir",
    "assoupissements": "assoupissement",
    "assoupissent": "assoupir",
    "assoupisses": "assoupir",
    "assoupissez": "assoupir",
    "assoupissiez": "assoupir",
    "assoupissions": "assoupir",
    "assoupissons": "assoupir",
    "assoupit": "assoupir",
    "assoupli": "assouplir",
    "assouplie": "assouplir",
    "assouplies": "assouplir",
    "assouplira": "assouplir",
    "assouplirai": "assouplir",
    "assoupliraient": "assouplir",
    "assouplirais": "assouplir",
    "assouplirait": "assouplir",
    "assoupliras": "assouplir",
    "assouplirent": "assouplir",
    "assouplirez": "assouplir",
    "assoupliriez": "assouplir",
    "assouplirions": "assouplir",
    "assouplirons": "assouplir",
    "assoupliront": "assouplir",
    "assouplis": "assouplir",
    "assouplissaient": "assouplir",
    "assouplissais": "assouplir",
    "assouplissait": "assouplir",
    "assouplissant": "assouplir",
    "assouplisse": "assouplir",
    "assouplissements": "assouplissement",
    "assouplissent": "assouplir",
    "assouplisses": "assouplir",
    "assouplissez": "assouplir",
    "assouplissiez": "assouplir",
    "assouplissions": "assouplir",
    "assouplissons": "assouplir",
    "assouplit": "assouplir",
    "assouplîmes": "assouplir",
    "assouplît": "assouplir",
    "assouplîtes": "assouplir",
    "assoupîmes": "assoupir",
    "assoupît": "assoupir",
    "assoupîtes": "assoupir",
    "assourdi": "assourdir",
    "assourdie": "assourdir",
    "assourdies": "assourdir",
    "assourdira": "assourdir",
    "assourdirai": "assourdir",
    "assourdiraient": "assourdir",
    "assourdirais": "assourdir",
    "assourdirait": "assourdir",
    "assourdiras": "assourdir",
    "assourdirent": "assourdir",
    "assourdirez": "assourdir",
    "assourdiriez": "assourdir",
    "assourdirions": "assourdir",
    "assourdirons": "assourdir",
    "assourdiront": "assourdir",
    "assourdis": "assourdir",
    "assourdissaient": "assourdir",
    "assourdissais": "assourdir",
    "assourdissait": "assourdir",
    "assourdissant": "assourdir",
    "assourdissante": "assourdissant",
    "assourdissantes": "assourdissant",
    "assourdissants": "assourdissant",
    "assourdisse": "assourdir",
    "assourdissent": "assourdir",
    "assourdisses": "assourdir",
    "assourdissez": "assourdir",
    "assourdissiez": "assourdir",
    "assourdissions": "assourdir",
    "assourdissons": "assourdir",
    "assourdit": "assourdir",
    "assourdîmes": "assourdir",
    "assourdît": "assourdir",
    "assourdîtes": "assourdir",
    "assouvi": "assouvir",
    "assouvie": "assouvir",
    "assouvies": "assouvir",
    "assouvira": "assouvir",
    "assouvirai": "assouvir",
    "assouviraient": "assouvir",
    "assouvirais": "assouvir",
    "assouvirait": "assouvir",
    "assouviras": "assouvir",
    "assouvirent": "assouvir",
    "assouvirez": "assouvir",
    "assouviriez": "assouvir",
    "assouvirions": "assouvir",
    "assouvirons": "assouvir",
    "assouviront": "assouvir",
    "assouvis": "assouvir",
    "assouvissaient": "assouvir",
    "assouvissais": "assouvir",
    "assouvissait": "assouvir",
    "assouvissant": "assouvir",
    "assouvisse": "assouvir",
    "assouvissements": "assouvissement",
    "assouvissent": "assouvir",
    "assouvisses": "assouvir",
    "assouvissez": "assouvir",
    "assouvissiez": "assouvir",
    "assouvissions": "assouvir",
    "assouvissons": "assouvir",
    "assouvit": "assouvir",
    "assouvîmes": "assouvir",
    "assouvît": "assouvir",
    "assouvîtes": "assouvir",
    "assoyaient": "asseoir",
    "assoyais": "asseoir",
    "assoyait": "asseoir",
    "assoyant": "asseoir",
    "assoyez": "asseoir",
    "assoyiez": "asseoir",
    "assoyions": "asseoir",
    "assoyons": "asseoir",
    "assujetti": "assujettir",
    "assujettie": "assujettir",
    "assujetties": "assujettir",
    "assujettira": "assujettir",
    "assujettirai": "assujettir",
    "assujettiraient": "assujettir",
    "assujettirais": "assujettir",
    "assujettirait": "assujettir",
    "assujettiras": "assujettir",
    "assujettirent": "assujettir",
    "assujettirez": "assujettir",
    "assujettiriez": "assujettir",
    "assujettirions": "assujettir",
    "assujettirons": "assujettir",
    "assujettiront": "assujettir",
    "assujettis": "assujettir",
    "assujettissaient": "assujettir",
    "assujettissais": "assujettir",
    "assujettissait": "assujettir",
    "assujettissant": "assujettir",
    "assujettisse": "assujettir",
    "assujettissements": "assujettissement",
    "assujettissent": "assujettir",
    "assujettisses": "assujettir",
    "assujettissez": "assujettir",
    "assujettissiez": "assujettir",
    "assujettissions": "assujettir",
    "assujettissons": "assujettir",
    "assujettit": "assujettir",
    "assujettîmes": "assujettir",
    "assujettît": "assujettir",
    "assujettîtes": "assujettir",
    "assuma": "assumer",
    "assumai": "assumer",
    "assumaient": "assumer",
    "assumais": "assumer",
    "assumait": "assumer",
    "assumant": "assumer",
    "assumas": "assumer",
    "assumasse": "assumer",
    "assumassent": "assumer",
    "assumasses": "assumer",
    "assumassiez": "assumer",
    "assumassions": "assumer",
    "assume": "assumer",
    "assument": "assumer",
    "assumera": "assumer",
    "assumerai": "assumer",
    "assumeraient": "assumer",
    "assumerais": "assumer",
    "assumerait": "assumer",
    "assumeras": "assumer",
    "assumerez": "assumer",
    "assumeriez": "assumer",
    "assumerions": "assumer",
    "assumerons": "assumer",
    "assumeront": "assumer",
    "assumes": "assumer",
    "assumez": "assumer",
    "assumiez": "assumer",
    "assumions": "assumer",
    "assumons": "assumer",
    "assumâmes": "assumer",
    "assumât": "assumer",
    "assumâtes": "assumer",
    "assumèrent": "assumer",
    "assumé": "assumer",
    "assumée": "assumer",
    "assumées": "assumer",
    "assumés": "assumer",
    "assura": "assurer",
    "assurai": "assurer",
    "assuraient": "assurer",
    "assurais": "assurer",
    "assurait": "assurer",
    "assurances": "assurance",
    "assurances-maladie": "assurance-maladie",
    "assurances-vie": "assurance-vie",
    "assurant": "assurer",
    "assuras": "assurer",
    "assurasse": "assurer",
    "assurassent": "assurer",
    "assurasses": "assurer",
    "assurassiez": "assurer",
    "assurassions": "assurer",
    "assure": "assurer",
    "assurent": "assurer",
    "assurer": "avoir",
    "assurera": "assurer",
    "assurerai": "assurer",
    "assureraient": "assurer",
    "assurerais": "assurer",
    "assurerait": "assurer",
    "assureras": "assurer",
    "assurerez": "assurer",
    "assureriez": "assurer",
    "assurerions": "assurer",
    "assurerons": "assurer",
    "assureront": "assurer",
    "assures": "assurer",
    "assureurs": "assureur",
    "assurez": "assurer",
    "assuriez": "assurer",
    "assurions": "assurer",
    "assurons": "assurer",
    "assurâmes": "assurer",
    "assurât": "assurer",
    "assurâtes": "assurer",
    "assurèrent": "assurer",
    "assuré": "assurer",
    "assurée": "assurer",
    "assurées": "assurer",
    "assurés": "assurer",
    "assyrienne": "assyrien",
    "assyriennes": "assyrien",
    "assyriens": "assyrien",
    "assèche": "assécher",
    "assèchements": "assèchement",
    "assèchent": "assécher",
    "assèches": "assécher",
    "assène": "asséner",
    "assènent": "asséner",
    "assènera": "assener",
    "assènerai": "assener",
    "assèneraient": "assener",
    "assènerais": "assener",
    "assènerait": "assener",
    "assèneras": "assener",
    "assènerez": "assener",
    "assèneriez": "assener",
    "assènerions": "assener",
    "assènerons": "assener",
    "assèneront": "assener",
    "assènes": "asséner",
    "assécha": "assécher",
    "asséchai": "assécher",
    "asséchaient": "assécher",
    "asséchais": "assécher",
    "asséchait": "assécher",
    "asséchant": "assécher",
    "asséchas": "assécher",
    "asséchasse": "assécher",
    "asséchassent": "assécher",
    "asséchasses": "assécher",
    "asséchassiez": "assécher",
    "asséchassions": "assécher",
    "asséchera": "assécher",
    "assécherai": "assécher",
    "assécheraient": "assécher",
    "assécherais": "assécher",
    "assécherait": "assécher",
    "assécheras": "assécher",
    "assécherez": "assécher",
    "assécheriez": "assécher",
    "assécherions": "assécher",
    "assécherons": "assécher",
    "assécheront": "assécher",
    "asséchez": "assécher",
    "asséchiez": "assécher",
    "asséchions": "assécher",
    "asséchons": "assécher",
    "asséchâmes": "assécher",
    "asséchât": "assécher",
    "asséchâtes": "assécher",
    "asséchèrent": "assécher",
    "asséché": "assécher",
    "asséchée": "assécher",
    "asséchées": "assécher",
    "asséchés": "assécher",
    "asséna": "asséner",
    "assénai": "asséner",
    "assénaient": "asséner",
    "assénais": "asséner",
    "assénait": "asséner",
    "assénant": "asséner",
    "assénas": "asséner",
    "assénasse": "asséner",
    "assénassent": "asséner",
    "assénasses": "asséner",
    "assénassiez": "asséner",
    "assénassions": "asséner",
    "assénera": "asséner",
    "assénerai": "asséner",
    "asséneraient": "asséner",
    "assénerais": "asséner",
    "assénerait": "asséner",
    "asséneras": "asséner",
    "assénerez": "asséner",
    "asséneriez": "asséner",
    "assénerions": "asséner",
    "assénerons": "asséner",
    "asséneront": "asséner",
    "assénez": "asséner",
    "asséniez": "asséner",
    "assénions": "asséner",
    "assénons": "asséner",
    "assénâmes": "asséner",
    "assénât": "asséner",
    "assénâtes": "asséner",
    "assénèrent": "asséner",
    "asséné": "asséner",
    "assénée": "asséner",
    "assénées": "asséner",
    "assénés": "asséner",
    "assîmes": "asseoir",
    "assît": "asseoir",
    "assîtes": "asseoir",
    "asters": "aster",
    "asthmatiques": "asthmatique",
    "asthmes": "asthme",
    "asthénies": "asthénie",
    "asticota": "asticoter",
    "asticotages": "asticotage",
    "asticotai": "asticoter",
    "asticotaient": "asticoter",
    "asticotais": "asticoter",
    "asticotait": "asticoter",
    "asticotant": "asticoter",
    "asticotas": "asticoter",
    "asticotasse": "asticoter",
    "asticotassent": "asticoter",
    "asticotasses": "asticoter",
    "asticotassiez": "asticoter",
    "asticotassions": "asticoter",
    "asticote": "asticoter",
    "asticotent": "asticoter",
    "asticotera": "asticoter",
    "asticoterai": "asticoter",
    "asticoteraient": "asticoter",
    "asticoterais": "asticoter",
    "asticoterait": "asticoter",
    "asticoteras": "asticoter",
    "asticoterez": "asticoter",
    "asticoteriez": "asticoter",
    "asticoterions": "asticoter",
    "asticoterons": "asticoter",
    "asticoteront": "asticoter",
    "asticotes": "asticoter",
    "asticotez": "asticoter",
    "asticotiez": "asticoter",
    "asticotions": "asticoter",
    "asticotons": "asticoter",
    "asticots": "asticot",
    "asticotâmes": "asticoter",
    "asticotât": "asticoter",
    "asticotâtes": "asticoter",
    "asticotèrent": "asticoter",
    "asticoté": "asticoter",
    "asticotée": "asticoter",
    "asticotées": "asticoter",
    "asticotés": "asticoter",
    "astigmates": "astigmate",
    "astiqua": "astiquer",
    "astiquages": "astiquage",
    "astiquai": "astiquer",
    "astiquaient": "astiquer",
    "astiquais": "astiquer",
    "astiquait": "astiquer",
    "astiquant": "astiquer",
    "astiquas": "astiquer",
    "astiquasse": "astiquer",
    "astiquassent": "astiquer",
    "astiquasses": "astiquer",
    "astiquassiez": "astiquer",
    "astiquassions": "astiquer",
    "astique": "astiquer",
    "astiquent": "astiquer",
    "astiquera": "astiquer",
    "astiquerai": "astiquer",
    "astiqueraient": "astiquer",
    "astiquerais": "astiquer",
    "astiquerait": "astiquer",
    "astiqueras": "astiquer",
    "astiquerez": "astiquer",
    "astiqueriez": "astiquer",
    "astiquerions": "astiquer",
    "astiquerons": "astiquer",
    "astiqueront": "astiquer",
    "astiques": "astiquer",
    "astiquez": "astiquer",
    "astiquiez": "astiquer",
    "astiquions": "astiquer",
    "astiquons": "astiquer",
    "astiquâmes": "astiquer",
    "astiquât": "astiquer",
    "astiquâtes": "astiquer",
    "astiquèrent": "astiquer",
    "astiqué": "astiquer",
    "astiquée": "astiquer",
    "astiquées": "astiquer",
    "astiqués": "astiquer",
    "astragales": "astragale",
    "astrakans": "astrakan",
    "astrale": "astral",
    "astrales": "astral",
    "astraux": "astral",
    "astreignaient": "astreindre",
    "astreignais": "astreindre",
    "astreignait": "astreindre",
    "astreignant": "astreindre",
    "astreignante": "astreignant",
    "astreignantes": "astreignant",
    "astreigne": "astreindre",
    "astreignent": "astreindre",
    "astreignes": "astreindre",
    "astreignez": "astreindre",
    "astreigniez": "astreindre",
    "astreignions": "astreindre",
    "astreignirent": "astreindre",
    "astreignis": "astreindre",
    "astreignisse": "astreindre",
    "astreignissent": "astreindre",
    "astreignisses": "astreindre",
    "astreignissiez": "astreindre",
    "astreignissions": "astreindre",
    "astreignit": "astreindre",
    "astreignons": "astreindre",
    "astreignîmes": "astreindre",
    "astreignît": "astreindre",
    "astreignîtes": "astreindre",
    "astreindra": "astreindre",
    "astreindrai": "astreindre",
    "astreindraient": "astreindre",
    "astreindrais": "astreindre",
    "astreindrait": "astreindre",
    "astreindras": "astreindre",
    "astreindrez": "astreindre",
    "astreindriez": "astreindre",
    "astreindrions": "astreindre",
    "astreindrons": "astreindre",
    "astreindront": "astreindre",
    "astreins": "astreindre",
    "astreint": "astreindre",
    "astreinte": "astreint",
    "astreintes": "astreinte",
    "astreints": "astreint",
    "astres": "astre",
    "astringente": "astringent",
    "astringentes": "astringent",
    "astringents": "astringent",
    "astrolabes": "astrolabe",
    "astrologies": "astrologie",
    "astrologiques": "astrologique",
    "astrologues": "astrologue",
    "astrolâtres": "astrolâtre",
    "astronautes": "astronaute",
    "astronefs": "astronef",
    "astronomes": "astronome",
    "astronomies": "astronomie",
    "astronomiques": "astronomique",
    "astrononiques": "astrononique",
    "astrophysicienne": "astrophysicien",
    "astrophysiciennes": "astrophysicien",
    "astrophysiciens": "astrophysicien",
    "astrophysiques": "astrophysique",
    "astuces": "astuce",
    "astucieuse": "astucieux",
    "astucieuses": "astucieux",
    "asturienne": "asturien",
    "asturiennes": "asturien",
    "asturiens": "asturien",
    "astérisques": "astérisque",
    "astéroïdes": "astéroïde",
    "asymptomatiques": "asymptomatique",
    "asymptotes": "asymptote",
    "asymétries": "asymétrie",
    "asymétriques": "asymétrique",
    "asyndètes": "asyndète",
    "atabegs": "atabeg",
    "atamans": "ataman",
    "ataviques": "atavique",
    "atavismes": "atavisme",
    "ateliers": "atelier",
    "atellanes": "atellane",
    "atermoie": "atermoyer",
    "atermoiements": "atermoiement",
    "atermoient": "atermoyer",
    "atermoiera": "atermoyer",
    "atermoierai": "atermoyer",
    "atermoieraient": "atermoyer",
    "atermoierais": "atermoyer",
    "atermoierait": "atermoyer",
    "atermoieras": "atermoyer",
    "atermoierez": "atermoyer",
    "atermoieriez": "atermoyer",
    "atermoierions": "atermoyer",
    "atermoierons": "atermoyer",
    "atermoieront": "atermoyer",
    "atermoies": "atermoyer",
    "atermoya": "atermoyer",
    "atermoyai": "atermoyer",
    "atermoyaient": "atermoyer",
    "atermoyais": "atermoyer",
    "atermoyait": "atermoyer",
    "atermoyant": "atermoyer",
    "atermoyas": "atermoyer",
    "atermoyasse": "atermoyer",
    "atermoyassent": "atermoyer",
    "atermoyasses": "atermoyer",
    "atermoyassiez": "atermoyer",
    "atermoyassions": "atermoyer",
    "atermoyez": "atermoyer",
    "atermoyiez": "atermoyer",
    "atermoyions": "atermoyer",
    "atermoyons": "atermoyer",
    "atermoyâmes": "atermoyer",
    "atermoyât": "atermoyer",
    "atermoyâtes": "atermoyer",
    "atermoyèrent": "atermoyer",
    "atermoyé": "atermoyer",
    "athlètes": "athlète",
    "athlétiques": "athlétique",
    "athlétismes": "athlétisme",
    "athées": "athée",
    "athéismes": "athéisme",
    "athénienne": "athénien",
    "athéniennes": "athénienne",
    "athéniens": "athénien",
    "athénées": "athénée",
    "atlantes": "atlante",
    "atlantiques": "atlantique",
    "atlantismes": "atlantisme",
    "atlantistes": "atlantiste",
    "atmoshères": "atmoshère",
    "atmosphères": "atmosphère",
    "atmosphériques": "atmosphérique",
    "atolls": "atoll",
    "atomes": "atome",
    "atomiques": "atomique",
    "atomisa": "atomiser",
    "atomisai": "atomiser",
    "atomisaient": "atomiser",
    "atomisais": "atomiser",
    "atomisait": "atomiser",
    "atomisant": "atomiser",
    "atomisas": "atomiser",
    "atomisasse": "atomiser",
    "atomisassent": "atomiser",
    "atomisasses": "atomiser",
    "atomisassiez": "atomiser",
    "atomisassions": "atomiser",
    "atomisations": "atomisation",
    "atomise": "atomiser",
    "atomisent": "atomiser",
    "atomisera": "atomiser",
    "atomiserai": "atomiser",
    "atomiseraient": "atomiser",
    "atomiserais": "atomiser",
    "atomiserait": "atomiser",
    "atomiseras": "atomiser",
    "atomiserez": "atomiser",
    "atomiseriez": "atomiser",
    "atomiserions": "atomiser",
    "atomiserons": "atomiser",
    "atomiseront": "atomiser",
    "atomises": "atomiser",
    "atomisez": "atomiser",
    "atomisiez": "atomiser",
    "atomisions": "atomiser",
    "atomisons": "atomiser",
    "atomistes": "atomiste",
    "atomisâmes": "atomiser",
    "atomisât": "atomiser",
    "atomisâtes": "atomiser",
    "atomisèrent": "atomiser",
    "atomisé": "atomiser",
    "atomisée": "atomiser",
    "atomisées": "atomiser",
    "atomisés": "atomiser",
    "atonale": "atonal",
    "atonales": "atonal",
    "atonaux": "atonal",
    "atones": "atone",
    "atonies": "atonie",
    "atourné": "atourner",
    "atours": "atour",
    "atouts": "atout",
    "atrazines": "atrazine",
    "atriums": "atrium",
    "atroces": "atroce",
    "atrocités": "atrocité",
    "atrophiait": "atrophier",
    "atrophie": "atrophier",
    "atrophient": "atrophier",
    "atrophieraient": "atrophier",
    "atrophies": "atrophier",
    "atrophié": "atrophier",
    "atrophiée": "atrophier",
    "atrophiées": "atrophié",
    "atrophiés": "atrophier",
    "attabla": "attabler",
    "attablai": "attabler",
    "attablaient": "attabler",
    "attablais": "attabler",
    "attablait": "attabler",
    "attablant": "attabler",
    "attablas": "attabler",
    "attablasse": "attabler",
    "attablassent": "attabler",
    "attablasses": "attabler",
    "attablassiez": "attabler",
    "attablassions": "attabler",
    "attable": "attabler",
    "attablent": "attabler",
    "attablera": "attabler",
    "attablerai": "attabler",
    "attableraient": "attabler",
    "attablerais": "attabler",
    "attablerait": "attabler",
    "attableras": "attabler",
    "attablerez": "attabler",
    "attableriez": "attabler",
    "attablerions": "attabler",
    "attablerons": "attabler",
    "attableront": "attabler",
    "attables": "attabler",
    "attablez": "attabler",
    "attabliez": "attabler",
    "attablions": "attabler",
    "attablons": "attabler",
    "attablâmes": "attabler",
    "attablât": "attabler",
    "attablâtes": "attabler",
    "attablèrent": "attabler",
    "attablé": "attabler",
    "attablée": "attabler",
    "attablées": "attabler",
    "attablés": "attabler",
    "attacha": "attacher",
    "attachai": "attacher",
    "attachaient": "attacher",
    "attachais": "attacher",
    "attachait": "attacher",
    "attachant": "attacher",
    "attachante": "attachant",
    "attachantes": "attachant",
    "attachants": "attachant",
    "attachas": "attacher",
    "attachasse": "attacher",
    "attachassent": "attacher",
    "attachasses": "attacher",
    "attachassiez": "attacher",
    "attachassions": "attacher",
    "attache": "attacher",
    "attachements": "attachement",
    "attachent": "attacher",
    "attachera": "attacher",
    "attacherai": "attacher",
    "attacheraient": "attacher",
    "attacherais": "attacher",
    "attacherait": "attacher",
    "attacheras": "attacher",
    "attacherez": "attacher",
    "attacheriez": "attacher",
    "attacherions": "attacher",
    "attacherons": "attacher",
    "attacheront": "attacher",
    "attaches": "attacher",
    "attachez": "attacher",
    "attachiez": "attacher",
    "attachions": "attacher",
    "attachons": "attacher",
    "attachâmes": "attacher",
    "attachât": "attacher",
    "attachâtes": "attacher",
    "attachèrent": "attacher",
    "attaché": "attacher",
    "attachée": "attacher",
    "attachées": "attacher",
    "attachés": "attacher",
    "attachés-cases": "attaché-case",
    "attaqua": "attaquer",
    "attaquai": "attaquer",
    "attaquaient": "attaquer",
    "attaquais": "attaquer",
    "attaquait": "attaquer",
    "attaquant": "attaquer",
    "attaquante": "attaquant",
    "attaquantes": "attaquant",
    "attaquants": "attaquant",
    "attaquas": "attaquer",
    "attaquasse": "attaquer",
    "attaquassent": "attaquer",
    "attaquasses": "attaquer",
    "attaquassiez": "attaquer",
    "attaquassions": "attaquer",
    "attaque": "attaquer",
    "attaquent": "attaquer",
    "attaquera": "attaquer",
    "attaquerai": "attaquer",
    "attaqueraient": "attaquer",
    "attaquerais": "attaquer",
    "attaquerait": "attaquer",
    "attaqueras": "attaquer",
    "attaquerez": "attaquer",
    "attaqueriez": "attaquer",
    "attaquerions": "attaquer",
    "attaquerons": "attaquer",
    "attaqueront": "attaquer",
    "attaques": "attaquer",
    "attaquez": "attaquer",
    "attaquiez": "attaquer",
    "attaquions": "attaquer",
    "attaquons": "attaquer",
    "attaquâmes": "attaquer",
    "attaquât": "attaquer",
    "attaquâtes": "attaquer",
    "attaquèrent": "attaquer",
    "attaqué": "attaquer",
    "attaquée": "attaquer",
    "attaquées": "attaquer",
    "attaqués": "attaquer",
    "attarda": "attarder",
    "attardai": "attarder",
    "attardaient": "attarder",
    "attardais": "attarder",
    "attardait": "attarder",
    "attardant": "attarder",
    "attardas": "attarder",
    "attardasse": "attarder",
    "attardassent": "attarder",
    "attardasses": "attarder",
    "attardassiez": "attarder",
    "attardassions": "attarder",
    "attarde": "attarder",
    "attardent": "attarder",
    "attardera": "attarder",
    "attarderai": "attarder",
    "attarderaient": "attarder",
    "attarderais": "attarder",
    "attarderait": "attarder",
    "attarderas": "attarder",
    "attarderez": "attarder",
    "attarderiez": "attarder",
    "attarderions": "attarder",
    "attarderons": "attarder",
    "attarderont": "attarder",
    "attardes": "attarder",
    "attardez": "attarder",
    "attardiez": "attarder",
    "attardions": "attarder",
    "attardons": "attarder",
    "attardâmes": "attarder",
    "attardât": "attarder",
    "attardâtes": "attarder",
    "attardèrent": "attarder",
    "attardé": "attarder",
    "attardée": "attarder",
    "attardées": "attarder",
    "attardés": "attarder",
    "atteignaient": "atteindre",
    "atteignais": "atteindre",
    "atteignait": "atteindre",
    "atteignant": "atteindre",
    "atteigne": "atteindre",
    "atteignent": "atteindre",
    "atteignes": "atteindre",
    "atteignez": "atteindre",
    "atteigniez": "atteindre",
    "atteignions": "atteindre",
    "atteignirent": "atteindre",
    "atteignis": "atteindre",
    "atteignisse": "atteindre",
    "atteignissent": "atteindre",
    "atteignisses": "atteindre",
    "atteignissiez": "atteindre",
    "atteignissions": "atteindre",
    "atteignit": "atteindre",
    "atteignons": "atteindre",
    "atteignîmes": "atteindre",
    "atteignît": "atteindre",
    "atteignîtes": "atteindre",
    "atteindra": "atteindre",
    "atteindrai": "atteindre",
    "atteindraient": "atteindre",
    "atteindrais": "atteindre",
    "atteindrait": "atteindre",
    "atteindras": "atteindre",
    "atteindrez": "atteindre",
    "atteindriez": "atteindre",
    "atteindrions": "atteindre",
    "atteindrons": "atteindre",
    "atteindront": "atteindre",
    "atteins": "atteindre",
    "atteint": "atteindre",
    "atteinte": "atteint",
    "atteintes": "atteinte",
    "atteints": "atteint",
    "attela": "atteler",
    "attelages": "attelage",
    "attelai": "atteler",
    "attelaient": "atteler",
    "attelais": "atteler",
    "attelait": "atteler",
    "attelant": "atteler",
    "attelas": "atteler",
    "attelasse": "atteler",
    "attelassent": "atteler",
    "attelasses": "atteler",
    "attelassiez": "atteler",
    "attelassions": "atteler",
    "attelez": "atteler",
    "atteliez": "atteler",
    "attelions": "atteler",
    "attelle": "atteler",
    "attellent": "atteler",
    "attellera": "atteler",
    "attellerai": "atteler",
    "attelleraient": "atteler",
    "attellerais": "atteler",
    "attellerait": "atteler",
    "attelleras": "atteler",
    "attellerez": "atteler",
    "attelleriez": "atteler",
    "attellerions": "atteler",
    "attellerons": "atteler",
    "attelleront": "atteler",
    "attelles": "attelle",
    "attelons": "atteler",
    "attelâmes": "atteler",
    "attelât": "atteler",
    "attelâtes": "atteler",
    "attelèrent": "atteler",
    "attelé": "atteler",
    "attelée": "atteler",
    "attelées": "atteler",
    "attelés": "atteler",
    "attenante": "attenant",
    "attenantes": "attenant",
    "attenants": "attenant",
    "attend": "attendre",
    "attendaient": "attendre",
    "attendais": "attendre",
    "attendait": "attendre",
    "attendant": "attendre",
    "attende": "attendre",
    "attendent": "attendre",
    "attendes": "attendre",
    "attendez": "attendre",
    "attendiez": "attendre",
    "attendions": "attendre",
    "attendirent": "attendre",
    "attendis": "attendre",
    "attendisse": "attendre",
    "attendissent": "attendre",
    "attendisses": "attendre",
    "attendissiez": "attendre",
    "attendissions": "attendre",
    "attendit": "attendre",
    "attendons": "attendre",
    "attendra": "attendre",
    "attendrai": "attendre",
    "attendraient": "attendre",
    "attendrais": "attendre",
    "attendrait": "attendre",
    "attendras": "attendre",
    "attendrez": "attendre",
    "attendri": "attendrir",
    "attendrie": "attendrir",
    "attendries": "attendrir",
    "attendriez": "attendre",
    "attendrions": "attendre",
    "attendrira": "attendrir",
    "attendrirai": "attendrir",
    "attendriraient": "attendrir",
    "attendrirais": "attendrir",
    "attendrirait": "attendrir",
    "attendriras": "attendrir",
    "attendrirent": "attendrir",
    "attendrirez": "attendrir",
    "attendririez": "attendrir",
    "attendririons": "attendrir",
    "attendrirons": "attendrir",
    "attendriront": "attendrir",
    "attendris": "attendrir",
    "attendrissaient": "attendrir",
    "attendrissais": "attendrir",
    "attendrissait": "attendrir",
    "attendrissant": "attendrir",
    "attendrissante": "attendrissant",
    "attendrissantes": "attendrissant",
    "attendrissants": "attendrissant",
    "attendrisse": "attendrir",
    "attendrissements": "attendrissement",
    "attendrissent": "attendrir",
    "attendrisses": "attendrir",
    "attendrissez": "attendrir",
    "attendrissiez": "attendrir",
    "attendrissions": "attendrir",
    "attendrissons": "attendrir",
    "attendrit": "attendrir",
    "attendrons": "attendre",
    "attendront": "attendre",
    "attendrîmes": "attendrir",
    "attendrît": "attendrir",
    "attendrîtes": "attendrir",
    "attends": "attendre",
    "attendu": "attendre",
    "attendue": "attendu",
    "attendues": "attendu",
    "attendus": "attendu",
    "attendîmes": "attendre",
    "attendît": "attendre",
    "attendîtes": "attendre",
    "attenta": "attenter",
    "attentai": "attenter",
    "attentaient": "attenter",
    "attentais": "attenter",
    "attentait": "attenter",
    "attentant": "attenter",
    "attentas": "attenter",
    "attentasse": "attenter",
    "attentassent": "attenter",
    "attentasses": "attenter",
    "attentassiez": "attenter",
    "attentassions": "attenter",
    "attentatoires": "attentatoire",
    "attentats": "attentat",
    "attente": "attenter",
    "attentent": "attenter",
    "attentera": "attenter",
    "attenterai": "attenter",
    "attenteraient": "attenter",
    "attenterais": "attenter",
    "attenterait": "attenter",
    "attenteras": "attenter",
    "attenterez": "attenter",
    "attenteriez": "attenter",
    "attenterions": "attenter",
    "attenterons": "attenter",
    "attenteront": "attenter",
    "attentes": "attenter",
    "attentez": "attenter",
    "attentiez": "attenter",
    "attentifs": "attentif",
    "attentionné": "attentionner",
    "attentionnée": "attentionner",
    "attentionnées": "attentionné",
    "attentionnés": "attentionner",
    "attentions": "attention",
    "attentismes": "attentisme",
    "attentistes": "attentiste",
    "attentive": "attentif",
    "attentives": "attentif",
    "attentons": "attenter",
    "attentâmes": "attenter",
    "attentât": "attenter",
    "attentâtes": "attenter",
    "attentèrent": "attenter",
    "attenté": "attenter",
    "atterra": "atterrer",
    "atterrages": "atterrage",
    "atterrai": "atterrer",
    "atterraient": "atterrer",
    "atterrais": "atterrer",
    "atterrait": "atterrer",
    "atterrant": "atterrer",
    "atterrante": "atterrant",
    "atterras": "atterrer",
    "atterrasse": "atterrer",
    "atterrassent": "atterrer",
    "atterrasses": "atterrer",
    "atterrassiez": "atterrer",
    "atterrassions": "atterrer",
    "atterre": "atterrer",
    "atterrent": "atterrer",
    "atterrera": "atterrer",
    "atterrerai": "atterrer",
    "atterreraient": "atterrer",
    "atterrerais": "atterrer",
    "atterrerait": "atterrer",
    "atterreras": "atterrer",
    "atterrerez": "atterrer",
    "atterreriez": "atterrer",
    "atterrerions": "atterrer",
    "atterrerons": "atterrer",
    "atterreront": "atterrer",
    "atterres": "atterrer",
    "atterrez": "atterrer",
    "atterri": "atterrir",
    "atterriez": "atterrer",
    "atterrions": "atterrer",
    "atterrira": "atterrir",
    "atterrirai": "atterrir",
    "atterriraient": "atterrir",
    "atterrirais": "atterrir",
    "atterrirait": "atterrir",
    "atterriras": "atterrir",
    "atterrirent": "atterrir",
    "atterrirez": "atterrir",
    "atterririez": "atterrir",
    "atterririons": "atterrir",
    "atterrirons": "atterrir",
    "atterriront": "atterrir",
    "atterris": "atterrir",
    "atterrissages": "atterrissage",
    "atterrissaient": "atterrir",
    "atterrissais": "atterrir",
    "atterrissait": "atterrir",
    "atterrissant": "atterrir",
    "atterrisse": "atterrir",
    "atterrissent": "atterrir",
    "atterrisses": "atterrir",
    "atterrissez": "atterrir",
    "atterrissiez": "atterrir",
    "atterrissions": "atterrir",
    "atterrissons": "atterrir",
    "atterrit": "atterrir",
    "atterrons": "atterrer",
    "atterrâmes": "atterrer",
    "atterrât": "atterrer",
    "atterrâtes": "atterrer",
    "atterrèrent": "atterrer",
    "atterré": "atterrer",
    "atterrée": "atterrer",
    "atterrées": "atterrer",
    "atterrés": "atterrer",
    "atterrîmes": "atterrir",
    "atterrît": "atterrir",
    "atterrîtes": "atterrir",
    "attesta": "attester",
    "attestai": "attester",
    "attestaient": "attester",
    "attestais": "attester",
    "attestait": "attester",
    "attestant": "attester",
    "attestas": "attester",
    "attestasse": "attester",
    "attestassent": "attester",
    "attestasses": "attester",
    "attestassiez": "attester",
    "attestassions": "attester",
    "attestations": "attestation",
    "atteste": "attester",
    "attestent": "attester",
    "attestera": "attester",
    "attesterai": "attester",
    "attesteraient": "attester",
    "attesterais": "attester",
    "attesterait": "attester",
    "attesteras": "attester",
    "attesterez": "attester",
    "attesteriez": "attester",
    "attesterions": "attester",
    "attesterons": "attester",
    "attesteront": "attester",
    "attestes": "attester",
    "attestez": "attester",
    "attestiez": "attester",
    "attestions": "attester",
    "attestons": "attester",
    "attestâmes": "attester",
    "attestât": "attester",
    "attestâtes": "attester",
    "attestèrent": "attester",
    "attesté": "attester",
    "attestée": "attester",
    "attestées": "attester",
    "attestés": "attester",
    "attifa": "attifer",
    "attifai": "attifer",
    "attifaient": "attifer",
    "attifais": "attifer",
    "attifait": "attifer",
    "attifant": "attifer",
    "attifas": "attifer",
    "attifasse": "attifer",
    "attifassent": "attifer",
    "attifasses": "attifer",
    "attifassiez": "attifer",
    "attifassions": "attifer",
    "attife": "attifer",
    "attifent": "attifer",
    "attifera": "attifer",
    "attiferai": "attifer",
    "attiferaient": "attifer",
    "attiferais": "attifer",
    "attiferait": "attifer",
    "attiferas": "attifer",
    "attiferez": "attifer",
    "attiferiez": "attifer",
    "attiferions": "attifer",
    "attiferons": "attifer",
    "attiferont": "attifer",
    "attifes": "attifer",
    "attifez": "attifer",
    "attifiez": "attifer",
    "attifions": "attifer",
    "attifons": "attifer",
    "attifâmes": "attifer",
    "attifât": "attifer",
    "attifâtes": "attifer",
    "attifèrent": "attifer",
    "attifé": "attifer",
    "attifée": "attifer",
    "attifées": "attifer",
    "attifés": "attifer",
    "attige": "attiger",
    "attigeait": "attiger",
    "attigent": "attiger",
    "attiges": "attiger",
    "attigés": "attiger",
    "attiques": "attique",
    "attira": "attirer",
    "attirai": "attirer",
    "attiraient": "attirer",
    "attirails": "attirail",
    "attirais": "attirer",
    "attirait": "attirer",
    "attirances": "attirance",
    "attirant": "attirer",
    "attirante": "attirant",
    "attirantes": "attirant",
    "attirants": "attirant",
    "attiras": "attirer",
    "attirasse": "attirer",
    "attirassent": "attirer",
    "attirasses": "attirer",
    "attirassiez": "attirer",
    "attirassions": "attirer",
    "attire": "attirer",
    "attirent": "attirer",
    "attirer": "avoir",
    "attirera": "attirer",
    "attirerai": "attirer",
    "attireraient": "attirer",
    "attirerais": "attirer",
    "attirerait": "attirer",
    "attireras": "attirer",
    "attirerez": "attirer",
    "attireriez": "attirer",
    "attirerions": "attirer",
    "attirerons": "attirer",
    "attireront": "attirer",
    "attires": "attirer",
    "attirez": "attirer",
    "attiriez": "attirer",
    "attirions": "attirer",
    "attirons": "attirer",
    "attirâmes": "attirer",
    "attirât": "attirer",
    "attirâtes": "attirer",
    "attirèrent": "attirer",
    "attiré": "attirer",
    "attirée": "attirer",
    "attirées": "attirer",
    "attirés": "attirer",
    "attisa": "attiser",
    "attisai": "attiser",
    "attisaient": "attiser",
    "attisais": "attiser",
    "attisait": "attiser",
    "attisant": "attiser",
    "attisas": "attiser",
    "attisasse": "attiser",
    "attisassent": "attiser",
    "attisasses": "attiser",
    "attisassiez": "attiser",
    "attisassions": "attiser",
    "attise": "attiser",
    "attisent": "attiser",
    "attisera": "attiser",
    "attiserai": "attiser",
    "attiseraient": "attiser",
    "attiserais": "attiser",
    "attiserait": "attiser",
    "attiseras": "attiser",
    "attiserez": "attiser",
    "attiseriez": "attiser",
    "attiserions": "attiser",
    "attiserons": "attiser",
    "attiseront": "attiser",
    "attises": "attiser",
    "attisez": "attiser",
    "attisiez": "attiser",
    "attisions": "attiser",
    "attisons": "attiser",
    "attisâmes": "attiser",
    "attisât": "attiser",
    "attisâtes": "attiser",
    "attisèrent": "attiser",
    "attisé": "attiser",
    "attisée": "attiser",
    "attisées": "attiser",
    "attisés": "attiser",
    "attitra": "attitrer",
    "attitrai": "attitrer",
    "attitraient": "attitrer",
    "attitrais": "attitrer",
    "attitrait": "attitrer",
    "attitrant": "attitrer",
    "attitras": "attitrer",
    "attitrasse": "attitrer",
    "attitrassent": "attitrer",
    "attitrasses": "attitrer",
    "attitrassiez": "attitrer",
    "attitrassions": "attitrer",
    "attitre": "attitrer",
    "attitrent": "attitrer",
    "attitrera": "attitrer",
    "attitrerai": "attitrer",
    "attitreraient": "attitrer",
    "attitrerais": "attitrer",
    "attitrerait": "attitrer",
    "attitreras": "attitrer",
    "attitrerez": "attitrer",
    "attitreriez": "attitrer",
    "attitrerions": "attitrer",
    "attitrerons": "attitrer",
    "attitreront": "attitrer",
    "attitres": "attitrer",
    "attitrez": "attitrer",
    "attitriez": "attitrer",
    "attitrions": "attitrer",
    "attitrons": "attitrer",
    "attitrâmes": "attitrer",
    "attitrât": "attitrer",
    "attitrâtes": "attitrer",
    "attitrèrent": "attitrer",
    "attitré": "attitrer",
    "attitrée": "attitrer",
    "attitrées": "attitrer",
    "attitrés": "attitrer",
    "attitudes": "attitude",
    "attiédi": "attiédir",
    "attiédie": "attiédir",
    "attiédies": "attiédir",
    "attiédira": "attiédir",
    "attiédirai": "attiédir",
    "attiédiraient": "attiédir",
    "attiédirais": "attiédir",
    "attiédirait": "attiédir",
    "attiédiras": "attiédir",
    "attiédirent": "attiédir",
    "attiédirez": "attiédir",
    "attiédiriez": "attiédir",
    "attiédirions": "attiédir",
    "attiédirons": "attiédir",
    "attiédiront": "attiédir",
    "attiédis": "attiédir",
    "attiédissaient": "attiédir",
    "attiédissais": "attiédir",
    "attiédissait": "attiédir",
    "attiédissant": "attiédir",
    "attiédisse": "attiédir",
    "attiédissent": "attiédir",
    "attiédisses": "attiédir",
    "attiédissez": "attiédir",
    "attiédissiez": "attiédir",
    "attiédissions": "attiédir",
    "attiédissons": "attiédir",
    "attiédit": "attiédir",
    "attiédîmes": "attiédir",
    "attiédît": "attiédir",
    "attiédîtes": "attiédir",
    "attorneys": "attorney",
    "attouchant": "attoucher",
    "attouchements": "attouchement",
    "attracteurs": "attracteur",
    "attractifs": "attractif",
    "attractions": "attraction",
    "attractive": "attractif",
    "attractives": "attractif",
    "attractivités": "attractivité",
    "attrait": "attraire",
    "attraits": "attrait",
    "attrapa": "attraper",
    "attrapai": "attraper",
    "attrapaient": "attraper",
    "attrapais": "attraper",
    "attrapait": "attraper",
    "attrapant": "attraper",
    "attrapas": "attraper",
    "attrapasse": "attraper",
    "attrapassent": "attraper",
    "attrapasses": "attraper",
    "attrapassiez": "attraper",
    "attrapassions": "attraper",
    "attrape": "attraper",
    "attrape-couillons": "attrape-couillon",
    "attrape-mouches": "attrape-mouche",
    "attrape-nigauds": "attrape-nigaud",
    "attrapent": "attraper",
    "attrapera": "attraper",
    "attraperai": "attraper",
    "attraperaient": "attraper",
    "attraperais": "attraper",
    "attraperait": "attraper",
    "attraperas": "attraper",
    "attraperez": "attraper",
    "attraperiez": "attraper",
    "attraperions": "attraper",
    "attraperons": "attraper",
    "attraperont": "attraper",
    "attrapes": "attraper",
    "attrapez": "attraper",
    "attrapiez": "attraper",
    "attrapions": "attraper",
    "attrapons": "attraper",
    "attrapâmes": "attraper",
    "attrapât": "attraper",
    "attrapâtes": "attraper",
    "attrapèrent": "attraper",
    "attrapé": "attraper",
    "attrapée": "attraper",
    "attrapées": "attraper",
    "attrapés": "attraper",
    "attrayante": "attrayant",
    "attrayantes": "attrayant",
    "attrayants": "attrayant",
    "attribua": "attribuer",
    "attribuables": "attribuable",
    "attribuai": "attribuer",
    "attribuaient": "attribuer",
    "attribuais": "attribuer",
    "attribuait": "attribuer",
    "attribuant": "attribuer",
    "attribuas": "attribuer",
    "attribuasse": "attribuer",
    "attribuassent": "attribuer",
    "attribuasses": "attribuer",
    "attribuassiez": "attribuer",
    "attribuassions": "attribuer",
    "attribue": "attribuer",
    "attribuent": "attribuer",
    "attribuera": "attribuer",
    "attribuerai": "attribuer",
    "attribueraient": "attribuer",
    "attribuerais": "attribuer",
    "attribuerait": "attribuer",
    "attribueras": "attribuer",
    "attribuerez": "attribuer",
    "attribueriez": "attribuer",
    "attribuerions": "attribuer",
    "attribuerons": "attribuer",
    "attribueront": "attribuer",
    "attribues": "attribuer",
    "attribuez": "attribuer",
    "attribuiez": "attribuer",
    "attribuions": "attribuer",
    "attribuons": "attribuer",
    "attributions": "attribution",
    "attributs": "attribut",
    "attribuâmes": "attribuer",
    "attribuât": "attribuer",
    "attribuâtes": "attribuer",
    "attribuèrent": "attribuer",
    "attribué": "attribuer",
    "attribuée": "attribuer",
    "attribuées": "attribuer",
    "attribués": "attribuer",
    "attriquait": "attriquer",
    "attriquant": "attriquer",
    "attrique": "attriquer",
    "attriquent": "attriquer",
    "attriquerait": "attriquer",
    "attriqué": "attriquer",
    "attriquée": "attriquer",
    "attrista": "attrister",
    "attristai": "attrister",
    "attristaient": "attrister",
    "attristais": "attrister",
    "attristait": "attrister",
    "attristant": "attrister",
    "attristante": "attristant",
    "attristantes": "attristant",
    "attristas": "attrister",
    "attristasse": "attrister",
    "attristassent": "attrister",
    "attristasses": "attrister",
    "attristassiez": "attrister",
    "attristassions": "attrister",
    "attriste": "attrister",
    "attristent": "attrister",
    "attristera": "attrister",
    "attristerai": "attrister",
    "attristeraient": "attrister",
    "attristerais": "attrister",
    "attristerait": "attrister",
    "attristeras": "attrister",
    "attristerez": "attrister",
    "attristeriez": "attrister",
    "attristerions": "attrister",
    "attristerons": "attrister",
    "attristeront": "attrister",
    "attristes": "attrister",
    "attristez": "attrister",
    "attristiez": "attrister",
    "attristions": "attrister",
    "attristons": "attrister",
    "attristâmes": "attrister",
    "attristât": "attrister",
    "attristâtes": "attrister",
    "attristèrent": "attrister",
    "attristé": "attrister",
    "attristée": "attrister",
    "attristées": "attrister",
    "attristés": "attrister",
    "attritions": "attrition",
    "attroupa": "attrouper",
    "attroupai": "attrouper",
    "attroupaient": "attrouper",
    "attroupais": "attrouper",
    "attroupait": "attrouper",
    "attroupant": "attrouper",
    "attroupas": "attrouper",
    "attroupasse": "attrouper",
    "attroupassent": "attrouper",
    "attroupasses": "attrouper",
    "attroupassiez": "attrouper",
    "attroupassions": "attrouper",
    "attroupe": "attrouper",
    "attroupements": "attroupement",
    "attroupent": "attrouper",
    "attroupera": "attrouper",
    "attrouperai": "attrouper",
    "attrouperaient": "attrouper",
    "attrouperais": "attrouper",
    "attrouperait": "attrouper",
    "attrouperas": "attrouper",
    "attrouperez": "attrouper",
    "attrouperiez": "attrouper",
    "attrouperions": "attrouper",
    "attrouperons": "attrouper",
    "attrouperont": "attrouper",
    "attroupes": "attrouper",
    "attroupez": "attrouper",
    "attroupiez": "attrouper",
    "attroupions": "attrouper",
    "attroupons": "attrouper",
    "attroupâmes": "attrouper",
    "attroupât": "attrouper",
    "attroupâtes": "attrouper",
    "attroupèrent": "attrouper",
    "attroupé": "attrouper",
    "attroupée": "attrouper",
    "attroupées": "attrouper",
    "attroupés": "attrouper",
    "atténua": "atténuer",
    "atténuai": "atténuer",
    "atténuaient": "atténuer",
    "atténuais": "atténuer",
    "atténuait": "atténuer",
    "atténuant": "atténuer",
    "atténuante": "atténuant",
    "atténuantes": "atténuant",
    "atténuants": "atténuant",
    "atténuas": "atténuer",
    "atténuasse": "atténuer",
    "atténuassent": "atténuer",
    "atténuasses": "atténuer",
    "atténuassiez": "atténuer",
    "atténuassions": "atténuer",
    "atténuations": "atténuation",
    "atténue": "atténuer",
    "atténuent": "atténuer",
    "atténuera": "atténuer",
    "atténuerai": "atténuer",
    "atténueraient": "atténuer",
    "atténuerais": "atténuer",
    "atténuerait": "atténuer",
    "atténueras": "atténuer",
    "atténuerez": "atténuer",
    "atténueriez": "atténuer",
    "atténuerions": "atténuer",
    "atténuerons": "atténuer",
    "atténueront": "atténuer",
    "atténues": "atténuer",
    "atténuez": "atténuer",
    "atténuiez": "atténuer",
    "atténuions": "atténuer",
    "atténuons": "atténuer",
    "atténuâmes": "atténuer",
    "atténuât": "atténuer",
    "atténuâtes": "atténuer",
    "atténuèrent": "atténuer",
    "atténué": "atténuer",
    "atténuée": "atténuer",
    "atténuées": "atténuer",
    "atténués": "atténuer",
    "atypiques": "atypique",
    "atèles": "atèle",
    "aubadent": "aubader",
    "aubades": "aubade",
    "aubaines": "aubaine",
    "auberges": "auberge",
    "aubergines": "aubergine",
    "aubergistes": "aubergiste",
    "aubes": "aube",
    "aubères": "aubère",
    "aubépines": "aubépine",
    "aucubas": "aucuba",
    "aucune": "aucun",
    "aucunes": "aucun",
    "aucuns": "aucun",
    "audaces": "audace",
    "audacieuse": "audacieux",
    "audacieuses": "audacieux",
    "audibles": "audible",
    "audiences": "audience",
    "audienciers": "audiencier",
    "audimats": "audimat",
    "audio-orale": "audio-oral",
    "audio-orales": "audio-oral",
    "audio-oraux": "audio-oral",
    "audio-visuelle": "audio-visuel",
    "audio-visuelles": "audio-visuel",
    "audio-visuels": "audio-visuel",
    "audios": "audio",
    "audiovisuelle": "audiovisuel",
    "audiovisuelles": "audiovisuel",
    "audiovisuels": "audiovisuel",
    "auditeurs": "auditeur",
    "auditifs": "auditif",
    "auditionna": "auditionner",
    "auditionnai": "auditionner",
    "auditionnaient": "auditionner",
    "auditionnais": "auditionner",
    "auditionnait": "auditionner",
    "auditionnant": "auditionner",
    "auditionnas": "auditionner",
    "auditionnasse": "auditionner",
    "auditionnassent": "auditionner",
    "auditionnasses": "auditionner",
    "auditionnassiez": "auditionner",
    "auditionnassions": "auditionner",
    "auditionne": "auditionner",
    "auditionnent": "auditionner",
    "auditionnera": "auditionner",
    "auditionnerai": "auditionner",
    "auditionneraient": "auditionner",
    "auditionnerais": "auditionner",
    "auditionnerait": "auditionner",
    "auditionneras": "auditionner",
    "auditionnerez": "auditionner",
    "auditionneriez": "auditionner",
    "auditionnerions": "auditionner",
    "auditionnerons": "auditionner",
    "auditionneront": "auditionner",
    "auditionnes": "auditionner",
    "auditionnez": "auditionner",
    "auditionniez": "auditionner",
    "auditionnions": "auditionner",
    "auditionnons": "auditionner",
    "auditionnâmes": "auditionner",
    "auditionnât": "auditionner",
    "auditionnâtes": "auditionner",
    "auditionnèrent": "auditionner",
    "auditionné": "auditionner",
    "auditionnée": "auditionner",
    "auditionnées": "auditionner",
    "auditionnés": "auditionner",
    "auditions": "audition",
    "auditive": "auditif",
    "auditives": "auditif",
    "auditoires": "auditoire",
    "auditorats": "auditorat",
    "auditoriums": "auditorium",
    "auditrice": "auditeur",
    "auditrices": "auditeur",
    "audits": "audit",
    "auges": "auge",
    "augmenta": "augmenter",
    "augmentai": "augmenter",
    "augmentaient": "augmenter",
    "augmentais": "augmenter",
    "augmentait": "augmenter",
    "augmentant": "augmenter",
    "augmentas": "augmenter",
    "augmentasse": "augmenter",
    "augmentassent": "augmenter",
    "augmentasses": "augmenter",
    "augmentassiez": "augmenter",
    "augmentassions": "augmenter",
    "augmentations": "augmentation",
    "augmente": "augmenter",
    "augmentent": "augmenter",
    "augmentera": "augmenter",
    "augmenterai": "augmenter",
    "augmenteraient": "augmenter",
    "augmenterais": "augmenter",
    "augmenterait": "augmenter",
    "augmenteras": "augmenter",
    "augmenterez": "augmenter",
    "augmenteriez": "augmenter",
    "augmenterions": "augmenter",
    "augmenterons": "augmenter",
    "augmenteront": "augmenter",
    "augmentes": "augmenter",
    "augmentez": "augmenter",
    "augmentiez": "augmenter",
    "augmentions": "augmenter",
    "augmentons": "augmenter",
    "augmentâmes": "augmenter",
    "augmentât": "augmenter",
    "augmentâtes": "augmenter",
    "augmentèrent": "augmenter",
    "augmenté": "augmenter",
    "augmentée": "augmenter",
    "augmentées": "augmenter",
    "augmentés": "augmenter",
    "augura": "augurer",
    "augurai": "augurer",
    "auguraient": "augurer",
    "augurais": "augurer",
    "augurait": "augurer",
    "augurale": "augural",
    "augurales": "augural",
    "augurant": "augurer",
    "auguras": "augurer",
    "augurasse": "augurer",
    "augurassent": "augurer",
    "augurasses": "augurer",
    "augurassiez": "augurer",
    "augurassions": "augurer",
    "auguraux": "augural",
    "augure": "augurer",
    "augurent": "augurer",
    "augurera": "augurer",
    "augurerai": "augurer",
    "augureraient": "augurer",
    "augurerais": "augurer",
    "augurerait": "augurer",
    "augureras": "augurer",
    "augurerez": "augurer",
    "augureriez": "augurer",
    "augurerions": "augurer",
    "augurerons": "augurer",
    "augureront": "augurer",
    "augures": "augurer",
    "augurez": "augurer",
    "auguriez": "augurer",
    "augurions": "augurer",
    "augurons": "augurer",
    "augurâmes": "augurer",
    "augurât": "augurer",
    "augurâtes": "augurer",
    "augurèrent": "augurer",
    "auguré": "augurer",
    "augurée": "augurer",
    "augurées": "augurer",
    "augurés": "augurer",
    "augustes": "auguste",
    "augustins": "augustin",
    "aujourd'hui": "aujourd'huie",
    "aulnes": "aulne",
    "aulx": "ail",
    "aumônes": "aumône",
    "aumôniers": "aumônier",
    "aumônière": "aumônier",
    "aumônières": "aumônier",
    "aunes": "aune",
    "aura": "avoir",
    "aurai": "avoir",
    "auraient": "avoir",
    "aurais": "avoir",
    "aurait": "avoir",
    "auras": "avoir",
    "aurez": "avoir",
    "auriculaires": "auriculaire",
    "auriez": "avoir",
    "aurifia": "aurifier",
    "aurifiai": "aurifier",
    "aurifiaient": "aurifier",
    "aurifiais": "aurifier",
    "aurifiait": "aurifier",
    "aurifiant": "aurifier",
    "aurifias": "aurifier",
    "aurifiasse": "aurifier",
    "aurifiassent": "aurifier",
    "aurifiasses": "aurifier",
    "aurifiassiez": "aurifier",
    "aurifiassions": "aurifier",
    "aurifie": "aurifier",
    "aurifient": "aurifier",
    "aurifiera": "aurifier",
    "aurifierai": "aurifier",
    "aurifieraient": "aurifier",
    "aurifierais": "aurifier",
    "aurifierait": "aurifier",
    "aurifieras": "aurifier",
    "aurifierez": "aurifier",
    "aurifieriez": "aurifier",
    "aurifierions": "aurifier",
    "aurifierons": "aurifier",
    "aurifieront": "aurifier",
    "aurifies": "aurifier",
    "aurifiez": "aurifier",
    "aurifiiez": "aurifier",
    "aurifiions": "aurifier",
    "aurifions": "aurifier",
    "aurifiâmes": "aurifier",
    "aurifiât": "aurifier",
    "aurifiâtes": "aurifier",
    "aurifièrent": "aurifier",
    "aurifié": "aurifier",
    "aurifiée": "aurifier",
    "aurifiées": "aurifier",
    "aurifiés": "aurifier",
    "aurifères": "aurifère",
    "aurions": "avoir",
    "aurons": "avoir",
    "auront": "avoir",
    "aurorale": "auroral",
    "aurorales": "auroral",
    "auroraux": "auroral",
    "aurores": "aurore",
    "auréola": "auréoler",
    "auréolai": "auréoler",
    "auréolaient": "auréoler",
    "auréolais": "auréoler",
    "auréolait": "auréoler",
    "auréolant": "auréoler",
    "auréolas": "auréoler",
    "auréolasse": "auréoler",
    "auréolassent": "auréoler",
    "auréolasses": "auréoler",
    "auréolassiez": "auréoler",
    "auréolassions": "auréoler",
    "auréole": "auréoler",
    "auréolent": "auréoler",
    "auréolera": "auréoler",
    "auréolerai": "auréoler",
    "auréoleraient": "auréoler",
    "auréolerais": "auréoler",
    "auréolerait": "auréoler",
    "auréoleras": "auréoler",
    "auréolerez": "auréoler",
    "auréoleriez": "auréoler",
    "auréolerions": "auréoler",
    "auréolerons": "auréoler",
    "auréoleront": "auréoler",
    "auréoles": "auréoler",
    "auréolez": "auréoler",
    "auréoliez": "auréoler",
    "auréolions": "auréoler",
    "auréolons": "auréoler",
    "auréolâmes": "auréoler",
    "auréolât": "auréoler",
    "auréolâtes": "auréoler",
    "auréolèrent": "auréoler",
    "auréolé": "auréoler",
    "auréolée": "auréoler",
    "auréolées": "auréoler",
    "auréolés": "auréoler",
    "ausculta": "ausculter",
    "auscultai": "ausculter",
    "auscultaient": "ausculter",
    "auscultais": "ausculter",
    "auscultait": "ausculter",
    "auscultant": "ausculter",
    "auscultas": "ausculter",
    "auscultasse": "ausculter",
    "auscultassent": "ausculter",
    "auscultasses": "ausculter",
    "auscultassiez": "ausculter",
    "auscultassions": "ausculter",
    "auscultations": "auscultation",
    "ausculte": "ausculter",
    "auscultent": "ausculter",
    "auscultera": "ausculter",
    "ausculterai": "ausculter",
    "ausculteraient": "ausculter",
    "ausculterais": "ausculter",
    "ausculterait": "ausculter",
    "ausculteras": "ausculter",
    "ausculterez": "ausculter",
    "ausculteriez": "ausculter",
    "ausculterions": "ausculter",
    "ausculterons": "ausculter",
    "ausculteront": "ausculter",
    "auscultes": "ausculter",
    "auscultez": "ausculter",
    "auscultiez": "ausculter",
    "auscultions": "ausculter",
    "auscultons": "ausculter",
    "auscultâmes": "ausculter",
    "auscultât": "ausculter",
    "auscultâtes": "ausculter",
    "auscultèrent": "ausculter",
    "ausculté": "ausculter",
    "auscultée": "ausculter",
    "auscultées": "ausculter",
    "auscultés": "ausculter",
    "auspices": "auspice",
    "aussières": "aussière",
    "australe": "austral",
    "australes": "austral",
    "australienne": "australien",
    "australiennes": "australienne",
    "australiens": "australien",
    "australopithèques": "australopithèque",
    "australs": "austral",
    "austraux": "austral",
    "austro-hongroises": "austro-hongrois",
    "austères": "austère",
    "austérités": "austérité",
    "autans": "autan",
    "autarcies": "autarcie",
    "autarciques": "autarcique",
    "autels": "autel",
    "auteure": "auteur",
    "auteurs": "auteur",
    "authenticités": "authenticité",
    "authentifiait": "authentifier",
    "authentifie": "authentifier",
    "authentifient": "authentifier",
    "authentifierait": "authentifier",
    "authentifiez": "authentifier",
    "authentifié": "authentifier",
    "authentifiée": "authentifier",
    "authentifiées": "authentifier",
    "authentifiés": "authentifier",
    "authentiquant": "authentiquer",
    "authentique": "authentiquer",
    "authentiques": "authentique",
    "autistes": "autiste",
    "auto-adhésive": "auto-adhésif",
    "auto-immune": "auto-immun",
    "auto-stoppeurs": "auto-stoppeur",
    "auto-stoppeuse": "auto-stoppeur",
    "auto-stoppeuses": "auto-stoppeur",
    "auto-stops": "auto-stop",
    "auto-tamponneuses": "auto-tamponneuse",
    "auto-écoles": "auto-école",
    "autobiographies": "autobiographie",
    "autobiographiques": "autobiographique",
    "autocaristes": "autocariste",
    "autocars": "autocar",
    "autocensure": "autocensurer",
    "autocensurent": "autocensurer",
    "autocensures": "autocensure",
    "autochtones": "autochtone",
    "autoclaves": "autoclave",
    "autocollante": "autocollant",
    "autocollantes": "autocollant",
    "autocollants": "autocollant",
    "autoconservations": "autoconservation",
    "autocontrôles": "autocontrôle",
    "autocrates": "autocrate",
    "autocraties": "autocratie",
    "autocratiques": "autocratique",
    "autocritiques": "autocritique",
    "autocuiseurs": "autocuiseur",
    "autodafés": "autodafé",
    "autodestructeurs": "autodestructeur",
    "autodestructrice": "autodestructeur",
    "autodidactes": "autodidacte",
    "autodisciplines": "autodiscipline",
    "autodromes": "autodrome",
    "autodéfenses": "autodéfense",
    "autodérisions": "autodérision",
    "autodéterminations": "autodétermination",
    "autodétruira": "autodétruire",
    "autodétruiront": "autodétruire",
    "autodétruisant": "autodétruire",
    "autodétruisent": "autodétruire",
    "autodétruit": "autodétruire",
    "autodétruite": "autodétruire",
    "autofinance": "autofinancer",
    "autofinancements": "autofinancement",
    "autofinancent": "autofinancer",
    "autofinancera": "autofinancer",
    "autofinancerai": "autofinancer",
    "autofinanceraient": "autofinancer",
    "autofinancerais": "autofinancer",
    "autofinancerait": "autofinancer",
    "autofinanceras": "autofinancer",
    "autofinancerez": "autofinancer",
    "autofinanceriez": "autofinancer",
    "autofinancerions": "autofinancer",
    "autofinancerons": "autofinancer",
    "autofinanceront": "autofinancer",
    "autofinances": "autofinancer",
    "autofinancez": "autofinancer",
    "autofinanciez": "autofinancer",
    "autofinancions": "autofinancer",
    "autofinancèrent": "autofinancer",
    "autofinancé": "autofinancer",
    "autofinancée": "autofinancer",
    "autofinancées": "autofinancer",
    "autofinancés": "autofinancer",
    "autofinança": "autofinancer",
    "autofinançai": "autofinancer",
    "autofinançaient": "autofinancer",
    "autofinançais": "autofinancer",
    "autofinançait": "autofinancer",
    "autofinançant": "autofinancer",
    "autofinanças": "autofinancer",
    "autofinançasse": "autofinancer",
    "autofinançassent": "autofinancer",
    "autofinançasses": "autofinancer",
    "autofinançassiez": "autofinancer",
    "autofinançassions": "autofinancer",
    "autofinançons": "autofinancer",
    "autofinançâmes": "autofinancer",
    "autofinançât": "autofinancer",
    "autofinançâtes": "autofinancer",
    "autoformations": "autoformation",
    "autofécondations": "autofécondation",
    "autogestionnaires": "autogestionnaire",
    "autogestions": "autogestion",
    "autogires": "autogire",
    "autographes": "autographe",
    "autographié": "autographier",
    "autoguida": "autoguider",
    "autoguidai": "autoguider",
    "autoguidaient": "autoguider",
    "autoguidais": "autoguider",
    "autoguidait": "autoguider",
    "autoguidant": "autoguider",
    "autoguidas": "autoguider",
    "autoguidasse": "autoguider",
    "autoguidassent": "autoguider",
    "autoguidasses": "autoguider",
    "autoguidassiez": "autoguider",
    "autoguidassions": "autoguider",
    "autoguide": "autoguider",
    "autoguident": "autoguider",
    "autoguidera": "autoguider",
    "autoguiderai": "autoguider",
    "autoguideraient": "autoguider",
    "autoguiderais": "autoguider",
    "autoguiderait": "autoguider",
    "autoguideras": "autoguider",
    "autoguiderez": "autoguider",
    "autoguideriez": "autoguider",
    "autoguiderions": "autoguider",
    "autoguiderons": "autoguider",
    "autoguideront": "autoguider",
    "autoguides": "autoguider",
    "autoguidez": "autoguider",
    "autoguidiez": "autoguider",
    "autoguidions": "autoguider",
    "autoguidons": "autoguider",
    "autoguidâmes": "autoguider",
    "autoguidât": "autoguider",
    "autoguidâtes": "autoguider",
    "autoguidèrent": "autoguider",
    "autoguidé": "autoguider",
    "autoguidée": "autoguider",
    "autoguidées": "autoguider",
    "autoguidés": "autoguider",
    "autogérée": "autogéré",
    "autolimitations": "autolimitation",
    "autolimite": "autolimiter",
    "autologues": "autologue",
    "automates": "automate",
    "automatiques": "automatique",
    "automatisables": "automatisable",
    "automatisations": "automatisation",
    "automatismes": "automatisme",
    "automatisé": "automatiser",
    "automatisée": "automatiser",
    "automatisées": "automatisé",
    "automatisés": "automatiser",
    "automitrailleuse": "automitrailleur",
    "automitrailleuses": "automitrailleur",
    "automnale": "automnal",
    "automnales": "automnal",
    "automnaux": "automnal",
    "automnes": "automne",
    "automobiles": "automobile",
    "automobilistes": "automobiliste",
    "automoteurs": "automoteur",
    "automotrice": "automoteur",
    "automotrices": "automoteur",
    "autoneiges": "autoneige",
    "autonettoyante": "autonettoyant",
    "autonomes": "autonome",
    "autonomies": "autonomie",
    "autonomisations": "autonomisation",
    "autonomistes": "autonomiste",
    "autoportraits": "autoportrait",
    "autoportée": "autoporté",
    "autoproclama": "autoproclamer",
    "autoproclamai": "autoproclamer",
    "autoproclamaient": "autoproclamer",
    "autoproclamais": "autoproclamer",
    "autoproclamait": "autoproclamer",
    "autoproclamant": "autoproclamer",
    "autoproclamas": "autoproclamer",
    "autoproclamasse": "autoproclamer",
    "autoproclamassent": "autoproclamer",
    "autoproclamasses": "autoproclamer",
    "autoproclamassiez": "autoproclamer",
    "autoproclamassions": "autoproclamer",
    "autoproclame": "autoproclamer",
    "autoproclament": "autoproclamer",
    "autoproclamera": "autoproclamer",
    "autoproclamerai": "autoproclamer",
    "autoproclameraient": "autoproclamer",
    "autoproclamerais": "autoproclamer",
    "autoproclamerait": "autoproclamer",
    "autoproclameras": "autoproclamer",
    "autoproclamerez": "autoproclamer",
    "autoproclameriez": "autoproclamer",
    "autoproclamerions": "autoproclamer",
    "autoproclamerons": "autoproclamer",
    "autoproclameront": "autoproclamer",
    "autoproclames": "autoproclamer",
    "autoproclamez": "autoproclamer",
    "autoproclamiez": "autoproclamer",
    "autoproclamions": "autoproclamer",
    "autoproclamons": "autoproclamer",
    "autoproclamâmes": "autoproclamer",
    "autoproclamât": "autoproclamer",
    "autoproclamâtes": "autoproclamer",
    "autoproclamèrent": "autoproclamer",
    "autoproclamé": "autoproclamer",
    "autoproclamée": "autoproclamer",
    "autoproclamées": "autoproclamer",
    "autoproclamés": "autoproclamer",
    "autopropulsée": "autopropulsé",
    "autopropulsés": "autopropulsé",
    "autopsia": "autopsier",
    "autopsiais": "autopsier",
    "autopsies": "autopsie",
    "autopsié": "autopsier",
    "autoradios": "autoradio",
    "autorails": "autorail",
    "autorisa": "autoriser",
    "autorisai": "autoriser",
    "autorisaient": "autoriser",
    "autorisais": "autoriser",
    "autorisait": "autoriser",
    "autorisant": "autoriser",
    "autorisas": "autoriser",
    "autorisasse": "autoriser",
    "autorisassent": "autoriser",
    "autorisasses": "autoriser",
    "autorisassiez": "autoriser",
    "autorisassions": "autoriser",
    "autorisations": "autorisation",
    "autorise": "autoriser",
    "autorisent": "autoriser",
    "autorisera": "autoriser",
    "autoriserai": "autoriser",
    "autoriseraient": "autoriser",
    "autoriserais": "autoriser",
    "autoriserait": "autoriser",
    "autoriseras": "autoriser",
    "autoriserez": "autoriser",
    "autoriseriez": "autoriser",
    "autoriserions": "autoriser",
    "autoriserons": "autoriser",
    "autoriseront": "autoriser",
    "autorises": "autoriser",
    "autorisez": "autoriser",
    "autorisiez": "autoriser",
    "autorisions": "autoriser",
    "autorisons": "autoriser",
    "autorisâmes": "autoriser",
    "autorisât": "autoriser",
    "autorisâtes": "autoriser",
    "autorisèrent": "autoriser",
    "autorisé": "autoriser",
    "autorisée": "autoriser",
    "autorisées": "autoriser",
    "autorisés": "autoriser",
    "autoritaires": "autoritaire",
    "autoritarismes": "autoritarisme",
    "autorités": "autorité",
    "autoroutes": "autoroute",
    "autoroutiers": "autoroutier",
    "autoroutière": "autoroutier",
    "autoroutières": "autoroutier",
    "autoréférentialités": "autoréférentialité",
    "autorégule": "autoréguler",
    "autos": "auto",
    "autosatisfactions": "autosatisfaction",
    "autostrades": "autostrade",
    "autosuffisances": "autosuffisance",
    "autosuffisante": "autosuffisant",
    "autosuffisantes": "autosuffisant",
    "autosuffisants": "autosuffisant",
    "autosuggestionna": "autosuggestionner",
    "autosuggestions": "autosuggestion",
    "autours": "autour",
    "autoépurations": "autoépuration",
    "autres": "autre",
    "autrichienne": "autrichien",
    "autrichiennes": "autrichien",
    "autrichiens": "autrichien",
    "autruches": "autruche",
    "auvents": "auvent",
    "auvergnate": "auvergnat",
    "auvergnates": "auvergnat",
    "auvergnats": "auvergnat",
    "auverpins": "auverpin",
    "auxerroise": "auxerrois",
    "auxiliaires": "auxiliaire",
    "avachi": "avachir",
    "avachie": "avachir",
    "avachies": "avachir",
    "avachira": "avachir",
    "avachirai": "avachir",
    "avachiraient": "avachir",
    "avachirais": "avachir",
    "avachirait": "avachir",
    "avachiras": "avachir",
    "avachirent": "avachir",
    "avachirez": "avachir",
    "avachiriez": "avachir",
    "avachirions": "avachir",
    "avachirons": "avachir",
    "avachiront": "avachir",
    "avachis": "avachir",
    "avachissaient": "avachir",
    "avachissais": "avachir",
    "avachissait": "avachir",
    "avachissant": "avachir",
    "avachisse": "avachir",
    "avachissent": "avachir",
    "avachisses": "avachir",
    "avachissez": "avachir",
    "avachissiez": "avachir",
    "avachissions": "avachir",
    "avachissons": "avachir",
    "avachit": "avachir",
    "avachîmes": "avachir",
    "avachît": "avachir",
    "avachîtes": "avachir",
    "avaient": "avoir",
    "avais": "avoir",
    "avait": "avoir",
    "avala": "avaler",
    "avalai": "avaler",
    "avalaient": "avaler",
    "avalais": "avaler",
    "avalait": "avaler",
    "avalanches": "avalanche",
    "avalant": "avaler",
    "avalas": "avaler",
    "avalasse": "avaler",
    "avalassent": "avaler",
    "avalasses": "avaler",
    "avalassiez": "avaler",
    "avalassions": "avaler",
    "avale": "avaler",
    "avalent": "avaler",
    "avalera": "avaler",
    "avalerai": "avaler",
    "avaleraient": "avaler",
    "avalerais": "avaler",
    "avalerait": "avaler",
    "avaleras": "avaler",
    "avalerez": "avaler",
    "avaleriez": "avaler",
    "avalerions": "avaler",
    "avalerons": "avaler",
    "avaleront": "avaler",
    "avales": "avaler",
    "avaleurs": "avaleur",
    "avaleuse": "avaleur",
    "avalez": "avaler",
    "avaliez": "avaler",
    "avalions": "avaler",
    "avalisa": "avaliser",
    "avalisai": "avaliser",
    "avalisaient": "avaliser",
    "avalisais": "avaliser",
    "avalisait": "avaliser",
    "avalisant": "avaliser",
    "avalisas": "avaliser",
    "avalisasse": "avaliser",
    "avalisassent": "avaliser",
    "avalisasses": "avaliser",
    "avalisassiez": "avaliser",
    "avalisassions": "avaliser",
    "avalise": "avaliser",
    "avalisent": "avaliser",
    "avalisera": "avaliser",
    "avaliserai": "avaliser",
    "avaliseraient": "avaliser",
    "avaliserais": "avaliser",
    "avaliserait": "avaliser",
    "avaliseras": "avaliser",
    "avaliserez": "avaliser",
    "avaliseriez": "avaliser",
    "avaliserions": "avaliser",
    "avaliserons": "avaliser",
    "avaliseront": "avaliser",
    "avalises": "avaliser",
    "avalisez": "avaliser",
    "avalisiez": "avaliser",
    "avalisions": "avaliser",
    "avalisons": "avaliser",
    "avalisâmes": "avaliser",
    "avalisât": "avaliser",
    "avalisâtes": "avaliser",
    "avalisèrent": "avaliser",
    "avalisé": "avaliser",
    "avalisée": "avaliser",
    "avalisées": "avaliser",
    "avalisés": "avaliser",
    "avaloires": "avaloire",
    "avalons": "avaler",
    "avals": "aval",
    "avalâmes": "avaler",
    "avalât": "avaler",
    "avalâtes": "avaler",
    "avalèrent": "avaler",
    "avalé": "avaler",
    "avalée": "avaler",
    "avalées": "avaler",
    "avalés": "avaler",
    "avance": "avancer",
    "avancements": "avancement",
    "avancent": "avancer",
    "avancera": "avancer",
    "avancerai": "avancer",
    "avanceraient": "avancer",
    "avancerais": "avancer",
    "avancerait": "avancer",
    "avanceras": "avancer",
    "avancerez": "avancer",
    "avanceriez": "avancer",
    "avancerions": "avancer",
    "avancerons": "avancer",
    "avanceront": "avancer",
    "avances": "avancer",
    "avancez": "avancer",
    "avanciez": "avancer",
    "avancions": "avancer",
    "avancèrent": "avancer",
    "avancé": "avancer",
    "avancée": "avancer",
    "avancées": "avancer",
    "avancés": "avancer",
    "avanies": "avanie",
    "avant-centres": "avant-centre",
    "avant-clous": "avant-clou",
    "avant-coureurs": "avant-coureur",
    "avant-courrière": "avant-courrier",
    "avant-courrières": "avant-courrier",
    "avant-cours": "avant-cour",
    "avant-derniers": "avant-dernier",
    "avant-dernière": "avant-dernier",
    "avant-dernières": "avant-dernier",
    "avant-gardes": "avant-garde",
    "avant-gardistes": "avant-gardiste",
    "avant-goûts": "avant-goût",
    "avant-guerres": "avant-guerre",
    "avant-mains": "avant-main",
    "avant-monts": "avant-mont",
    "avant-ports": "avant-port",
    "avant-postes": "avant-poste",
    "avant-premières": "avant-première",
    "avant-projets": "avant-projet",
    "avant-scènes": "avant-scène",
    "avant-toits": "avant-toit",
    "avant-trains": "avant-train",
    "avant-veilles": "avant-veille",
    "avantage": "avantager",
    "avantagea": "avantager",
    "avantageai": "avantager",
    "avantageaient": "avantager",
    "avantageais": "avantager",
    "avantageait": "avantager",
    "avantageant": "avantager",
    "avantageas": "avantager",
    "avantageasse": "avantager",
    "avantageassent": "avantager",
    "avantageasses": "avantager",
    "avantageassiez": "avantager",
    "avantageassions": "avantager",
    "avantagent": "avantager",
    "avantageons": "avantager",
    "avantagera": "avantager",
    "avantagerai": "avantager",
    "avantageraient": "avantager",
    "avantagerais": "avantager",
    "avantagerait": "avantager",
    "avantageras": "avantager",
    "avantagerez": "avantager",
    "avantageriez": "avantager",
    "avantagerions": "avantager",
    "avantagerons": "avantager",
    "avantageront": "avantager",
    "avantages": "avantager",
    "avantageuse": "avantageux",
    "avantageuses": "avantageux",
    "avantagez": "avantager",
    "avantageâmes": "avantager",
    "avantageât": "avantager",
    "avantageâtes": "avantager",
    "avantagiez": "avantager",
    "avantagions": "avantager",
    "avantagèrent": "avantager",
    "avantagé": "avantager",
    "avantagée": "avantager",
    "avantagées": "avantager",
    "avantagés": "avantager",
    "avants": "avant",
    "avança": "avancer",
    "avançai": "avancer",
    "avançaient": "avancer",
    "avançais": "avancer",
    "avançait": "avancer",
    "avançant": "avancer",
    "avanças": "avancer",
    "avançasse": "avancer",
    "avançassent": "avancer",
    "avançasses": "avancer",
    "avançassiez": "avancer",
    "avançassions": "avancer",
    "avançons": "avançon",
    "avançâmes": "avancer",
    "avançât": "avancer",
    "avançâtes": "avancer",
    "avares": "avare",
    "avaria": "avarier",
    "avariai": "avarier",
    "avariaient": "avarier",
    "avariais": "avarier",
    "avariait": "avarier",
    "avariant": "avarier",
    "avarias": "avarier",
    "avariasse": "avarier",
    "avariassent": "avarier",
    "avariasses": "avarier",
    "avariassiez": "avarier",
    "avariassions": "avarier",
    "avarices": "avarice",
    "avaricieuse": "avaricieux",
    "avarie": "avarier",
    "avarient": "avarier",
    "avariera": "avarier",
    "avarierai": "avarier",
    "avarieraient": "avarier",
    "avarierais": "avarier",
    "avarierait": "avarier",
    "avarieras": "avarier",
    "avarierez": "avarier",
    "avarieriez": "avarier",
    "avarierions": "avarier",
    "avarierons": "avarier",
    "avarieront": "avarier",
    "avaries": "avarier",
    "avariez": "avarier",
    "avariiez": "avarier",
    "avariions": "avarier",
    "avarions": "avarier",
    "avariâmes": "avarier",
    "avariât": "avarier",
    "avariâtes": "avarier",
    "avarièrent": "avarier",
    "avarié": "avarier",
    "avariée": "avarier",
    "avariées": "avarier",
    "avariés": "avarier",
    "avaros": "avaro",
    "avatars": "avatar",
    "avelines": "aveline",
    "avenante": "avenant",
    "avenantes": "avenant",
    "avenants": "avenant",
    "avenirs": "avenir",
    "avens": "aven",
    "aventura": "aventurer",
    "aventurai": "aventurer",
    "aventuraient": "aventurer",
    "aventurais": "aventurer",
    "aventurait": "aventurer",
    "aventurant": "aventurer",
    "aventuras": "aventurer",
    "aventurasse": "aventurer",
    "aventurassent": "aventurer",
    "aventurasses": "aventurer",
    "aventurassiez": "aventurer",
    "aventurassions": "aventurer",
    "aventure": "aventurer",
    "aventurent": "aventurer",
    "aventurera": "aventurer",
    "aventurerai": "aventurer",
    "aventureraient": "aventurer",
    "aventurerais": "aventurer",
    "aventurerait": "aventurer",
    "aventureras": "aventurer",
    "aventurerez": "aventurer",
    "aventureriez": "aventurer",
    "aventurerions": "aventurer",
    "aventurerons": "aventurer",
    "aventureront": "aventurer",
    "aventures": "aventurer",
    "aventureuse": "aventureux",
    "aventureuses": "aventureux",
    "aventurez": "aventurer",
    "aventuriers": "aventurier",
    "aventuriez": "aventurer",
    "aventurines": "aventurine",
    "aventurions": "aventurer",
    "aventurière": "aventurier",
    "aventurières": "aventurier",
    "aventurons": "aventurer",
    "aventurâmes": "aventurer",
    "aventurât": "aventurer",
    "aventurâtes": "aventurer",
    "aventurèrent": "aventurer",
    "aventuré": "aventurer",
    "aventurée": "aventurer",
    "aventurées": "aventurer",
    "aventurés": "aventurer",
    "avenue": "avenu",
    "avenues": "avenue",
    "avenus": "avenu",
    "averses": "averse",
    "aversions": "aversion",
    "averti": "avertir",
    "avertie": "avertir",
    "averties": "avertir",
    "avertira": "avertir",
    "avertirai": "avertir",
    "avertiraient": "avertir",
    "avertirais": "avertir",
    "avertirait": "avertir",
    "avertiras": "avertir",
    "avertirent": "avertir",
    "avertirez": "avertir",
    "avertiriez": "avertir",
    "avertirions": "avertir",
    "avertirons": "avertir",
    "avertiront": "avertir",
    "avertis": "avertir",
    "avertissaient": "avertir",
    "avertissais": "avertir",
    "avertissait": "avertir",
    "avertissant": "avertir",
    "avertisse": "avertir",
    "avertissements": "avertissement",
    "avertissent": "avertir",
    "avertisses": "avertir",
    "avertisseurs": "avertisseur",
    "avertisseuses": "avertisseur",
    "avertissez": "avertir",
    "avertissiez": "avertir",
    "avertissions": "avertir",
    "avertissons": "avertir",
    "avertisssements": "avertisssement",
    "avertit": "avertir",
    "avertîmes": "avertir",
    "avertît": "avertir",
    "avertîtes": "avertir",
    "aveugla": "aveugler",
    "aveuglai": "aveugler",
    "aveuglaient": "aveugler",
    "aveuglais": "aveugler",
    "aveuglait": "aveugler",
    "aveuglant": "aveugler",
    "aveuglante": "aveuglant",
    "aveuglantes": "aveuglant",
    "aveuglants": "aveuglant",
    "aveuglas": "aveugler",
    "aveuglasse": "aveugler",
    "aveuglassent": "aveugler",
    "aveuglasses": "aveugler",
    "aveuglassiez": "aveugler",
    "aveuglassions": "aveugler",
    "aveugle": "aveugler",
    "aveugle-née": "aveugle-né",
    "aveuglements": "aveuglement",
    "aveuglent": "aveugler",
    "aveuglera": "aveugler",
    "aveuglerai": "aveugler",
    "aveugleraient": "aveugler",
    "aveuglerais": "aveugler",
    "aveuglerait": "aveugler",
    "aveugleras": "aveugler",
    "aveuglerez": "aveugler",
    "aveugleriez": "aveugler",
    "aveuglerions": "aveugler",
    "aveuglerons": "aveugler",
    "aveugleront": "aveugler",
    "aveugles": "aveugler",
    "aveugles-nées": "aveugle-né",
    "aveugles-nés": "aveugle-né",
    "aveuglez": "aveugler",
    "aveugliez": "aveugler",
    "aveuglions": "aveugler",
    "aveuglons": "aveugler",
    "aveuglâmes": "aveugler",
    "aveuglât": "aveugler",
    "aveuglâtes": "aveugler",
    "aveuglèrent": "aveugler",
    "aveuglé": "aveugler",
    "aveuglée": "aveugler",
    "aveuglées": "aveugler",
    "aveuglés": "aveugler",
    "aveuli": "aveulir",
    "aveulie": "aveulir",
    "aveulies": "aveulir",
    "aveulira": "aveulir",
    "aveulirai": "aveulir",
    "aveuliraient": "aveulir",
    "aveulirais": "aveulir",
    "aveulirait": "aveulir",
    "aveuliras": "aveulir",
    "aveulirent": "aveulir",
    "aveulirez": "aveulir",
    "aveuliriez": "aveulir",
    "aveulirions": "aveulir",
    "aveulirons": "aveulir",
    "aveuliront": "aveulir",
    "aveulis": "aveulir",
    "aveulissaient": "aveulir",
    "aveulissais": "aveulir",
    "aveulissait": "aveulir",
    "aveulissant": "aveulir",
    "aveulissante": "aveulissant",
    "aveulisse": "aveulir",
    "aveulissent": "aveulir",
    "aveulisses": "aveulir",
    "aveulissez": "aveulir",
    "aveulissiez": "aveulir",
    "aveulissions": "aveulir",
    "aveulissons": "aveulir",
    "aveulit": "aveulir",
    "aveulîmes": "aveulir",
    "aveulît": "aveulir",
    "aveulîtes": "aveulir",
    "aveux": "aveu",
    "avez": "avoir",
    "aviaires": "aviaire",
    "aviateurs": "aviateur",
    "aviations": "aviation",
    "aviatrice": "aviateur",
    "aviatrices": "aviateur",
    "avicoles": "avicole",
    "aviculteurs": "aviculteur",
    "avicultrice": "aviculteur",
    "avicultrices": "aviculteur",
    "avicultures": "aviculture",
    "avides": "avide",
    "avidités": "avidité",
    "aviez": "avoir",
    "avifaunes": "avifaune",
    "avignonnaise": "avignonnais",
    "avili": "avilir",
    "avilie": "avilir",
    "avilies": "avilir",
    "avilira": "avilir",
    "avilirai": "avilir",
    "aviliraient": "avilir",
    "avilirais": "avilir",
    "avilirait": "avilir",
    "aviliras": "avilir",
    "avilirent": "avilir",
    "avilirez": "avilir",
    "aviliriez": "avilir",
    "avilirions": "avilir",
    "avilirons": "avilir",
    "aviliront": "avilir",
    "avilis": "avilir",
    "avilissaient": "avilir",
    "avilissais": "avilir",
    "avilissait": "avilir",
    "avilissant": "avilir",
    "avilissante": "avilissant",
    "avilissantes": "avilissant",
    "avilissants": "avilissant",
    "avilisse": "avilir",
    "avilissements": "avilissement",
    "avilissent": "avilir",
    "avilisses": "avilir",
    "avilissez": "avilir",
    "avilissiez": "avilir",
    "avilissions": "avilir",
    "avilissons": "avilir",
    "avilit": "avilir",
    "avilîmes": "avilir",
    "avilît": "avilir",
    "avilîtes": "avilir",
    "avinée": "aviné",
    "avinées": "aviner",
    "avinés": "aviner",
    "avionneries": "avionnerie",
    "avionnettes": "avionnette",
    "avionneurs": "avionneur",
    "avions": "avoir",
    "avions-cargos": "avion-cargo",
    "avions-citernes": "avion-citerne",
    "avions-écoles": "avion-école",
    "avirons": "aviron",
    "avisa": "aviser",
    "avisai": "aviser",
    "avisaient": "aviser",
    "avisais": "aviser",
    "avisait": "aviser",
    "avisant": "aviser",
    "avisas": "aviser",
    "avisasse": "aviser",
    "avisassent": "aviser",
    "avisasses": "aviser",
    "avisassiez": "aviser",
    "avisassions": "aviser",
    "avise": "aviser",
    "avisent": "aviser",
    "avisera": "aviser",
    "aviserai": "aviser",
    "aviseraient": "aviser",
    "aviserais": "aviser",
    "aviserait": "aviser",
    "aviseras": "aviser",
    "aviserez": "aviser",
    "aviseriez": "aviser",
    "aviserions": "aviser",
    "aviserons": "aviser",
    "aviseront": "aviser",
    "avises": "aviser",
    "avisez": "aviser",
    "avisiez": "aviser",
    "avisions": "aviser",
    "avisons": "aviser",
    "avisos": "aviso",
    "avisâmes": "aviser",
    "avisât": "aviser",
    "avisâtes": "aviser",
    "avisèrent": "aviser",
    "avisé": "aviser",
    "avisée": "aviser",
    "avisées": "aviser",
    "avisés": "aviser",
    "aviva": "aviver",
    "avivai": "aviver",
    "avivaient": "aviver",
    "avivais": "aviver",
    "avivait": "aviver",
    "avivant": "aviver",
    "avivas": "aviver",
    "avivasse": "aviver",
    "avivassent": "aviver",
    "avivasses": "aviver",
    "avivassiez": "aviver",
    "avivassions": "aviver",
    "avive": "aviver",
    "avivent": "aviver",
    "avivera": "aviver",
    "aviverai": "aviver",
    "aviveraient": "aviver",
    "aviverais": "aviver",
    "aviverait": "aviver",
    "aviveras": "aviver",
    "aviverez": "aviver",
    "aviveriez": "aviver",
    "aviverions": "aviver",
    "aviverons": "aviver",
    "aviveront": "aviver",
    "avives": "aviver",
    "avivez": "aviver",
    "aviviez": "aviver",
    "avivions": "aviver",
    "avivons": "aviver",
    "avivâmes": "aviver",
    "avivât": "aviver",
    "avivâtes": "aviver",
    "avivèrent": "aviver",
    "avivé": "aviver",
    "avivée": "aviver",
    "avivées": "aviver",
    "avivés": "aviver",
    "avocasseries": "avocasserie",
    "avocate": "avocat",
    "avocates": "avocat",
    "avocatiers": "avocatier",
    "avocats": "avocat",
    "avoient": "avoyer",
    "avoinaient": "avoiner",
    "avoines": "avoine",
    "avoirs": "avoir",
    "avoisina": "avoisiner",
    "avoisinai": "avoisiner",
    "avoisinaient": "avoisiner",
    "avoisinais": "avoisiner",
    "avoisinait": "avoisiner",
    "avoisinant": "avoisiner",
    "avoisinante": "avoisinant",
    "avoisinantes": "avoisinant",
    "avoisinants": "avoisinant",
    "avoisinas": "avoisiner",
    "avoisinasse": "avoisiner",
    "avoisinassent": "avoisiner",
    "avoisinasses": "avoisiner",
    "avoisinassiez": "avoisiner",
    "avoisinassions": "avoisiner",
    "avoisine": "avoisiner",
    "avoisinent": "avoisiner",
    "avoisinera": "avoisiner",
    "avoisinerai": "avoisiner",
    "avoisineraient": "avoisiner",
    "avoisinerais": "avoisiner",
    "avoisinerait": "avoisiner",
    "avoisineras": "avoisiner",
    "avoisinerez": "avoisiner",
    "avoisineriez": "avoisiner",
    "avoisinerions": "avoisiner",
    "avoisinerons": "avoisiner",
    "avoisineront": "avoisiner",
    "avoisines": "avoisiner",
    "avoisinez": "avoisiner",
    "avoisiniez": "avoisiner",
    "avoisinions": "avoisiner",
    "avoisinons": "avoisiner",
    "avoisinâmes": "avoisiner",
    "avoisinât": "avoisiner",
    "avoisinâtes": "avoisiner",
    "avoisinèrent": "avoisiner",
    "avoisiné": "avoisiner",
    "avoisinée": "avoisiner",
    "avoisinées": "avoisiner",
    "avoisinés": "avoisiner",
    "avons": "avoir",
    "avoriazienne": "avoriazien",
    "avoriaziennes": "avoriazien",
    "avoriaziens": "avoriazien",
    "avorta": "avorter",
    "avortai": "avorter",
    "avortaient": "avorter",
    "avortais": "avorter",
    "avortait": "avorter",
    "avortant": "avorter",
    "avortas": "avorter",
    "avortasse": "avorter",
    "avortassent": "avorter",
    "avortasses": "avorter",
    "avortassiez": "avorter",
    "avortassions": "avorter",
    "avorte": "avorter",
    "avortements": "avortement",
    "avortent": "avorter",
    "avortera": "avorter",
    "avorterai": "avorter",
    "avorteraient": "avorter",
    "avorterais": "avorter",
    "avorterait": "avorter",
    "avorteras": "avorter",
    "avorterez": "avorter",
    "avorteriez": "avorter",
    "avorterions": "avorter",
    "avorterons": "avorter",
    "avorteront": "avorter",
    "avortes": "avorter",
    "avorteurs": "avorteur",
    "avorteuse": "avorteur",
    "avorteuses": "avorteur",
    "avortez": "avorter",
    "avortiez": "avorter",
    "avortions": "avorter",
    "avortoirs": "avortoir",
    "avortons": "avorton",
    "avortâmes": "avorter",
    "avortât": "avorter",
    "avortâtes": "avorter",
    "avortèrent": "avorter",
    "avorté": "avorter",
    "avortée": "avorter",
    "avortées": "avorter",
    "avortés": "avorter",
    "avoua": "avouer",
    "avouables": "avouable",
    "avouai": "avouer",
    "avouaient": "avouer",
    "avouais": "avouer",
    "avouait": "avouer",
    "avouant": "avouer",
    "avouas": "avouer",
    "avouasse": "avouer",
    "avouassent": "avouer",
    "avouasses": "avouer",
    "avouassiez": "avouer",
    "avouassions": "avouer",
    "avoue": "avouer",
    "avouent": "avouer",
    "avouera": "avouer",
    "avouerai": "avouer",
    "avoueraient": "avouer",
    "avouerais": "avouer",
    "avouerait": "avouer",
    "avoueras": "avouer",
    "avouerez": "avouer",
    "avoueriez": "avouer",
    "avouerions": "avouer",
    "avouerons": "avouer",
    "avoueront": "avouer",
    "avoues": "avouer",
    "avouez": "avouer",
    "avouiez": "avouer",
    "avouions": "avouer",
    "avouons": "avouer",
    "avouâmes": "avouer",
    "avouât": "avouer",
    "avouâtes": "avouer",
    "avouèrent": "avouer",
    "avoué": "avouer",
    "avouée": "avouer",
    "avouées": "avouer",
    "avoués": "avouer",
    "avrils": "avril",
    "avènements": "avènement",
    "avère": "avérer",
    "avèrent": "avérer",
    "avères": "avérer",
    "avéra": "avérer",
    "avérai": "avérer",
    "avéraient": "avérer",
    "avérais": "avérer",
    "avérait": "avérer",
    "avérant": "avérer",
    "avéras": "avérer",
    "avérasse": "avérer",
    "avérassent": "avérer",
    "avérasses": "avérer",
    "avérassiez": "avérer",
    "avérassions": "avérer",
    "avérera": "avérer",
    "avérerai": "avérer",
    "avéreraient": "avérer",
    "avérerais": "avérer",
    "avérerait": "avérer",
    "avéreras": "avérer",
    "avérerez": "avérer",
    "avéreriez": "avérer",
    "avérerions": "avérer",
    "avérerons": "avérer",
    "avéreront": "avérer",
    "avérez": "avérer",
    "avériez": "avérer",
    "avérions": "avérer",
    "avérons": "avérer",
    "avérâmes": "avérer",
    "avérât": "avérer",
    "avérâtes": "avérer",
    "avérèrent": "avérer",
    "avéré": "avérer",
    "avérée": "avérer",
    "avérées": "avérer",
    "avérés": "avérer",
    "axa": "axer",
    "axai": "axer",
    "axaient": "axer",
    "axais": "axer",
    "axait": "axer",
    "axant": "axer",
    "axas": "axer",
    "axasse": "axer",
    "axassent": "axer",
    "axasses": "axer",
    "axassiez": "axer",
    "axassions": "axer",
    "axe": "axer",
    "axels": "axel",
    "axent": "axer",
    "axera": "axer",
    "axerai": "axer",
    "axeraient": "axer",
    "axerais": "axer",
    "axerait": "axer",
    "axeras": "axer",
    "axerez": "axer",
    "axeriez": "axer",
    "axerions": "axer",
    "axerons": "axer",
    "axeront": "axer",
    "axes": "axer",
    "axez": "axer",
    "axiale": "axial",
    "axiales": "axial",
    "axiaux": "axial",
    "axiez": "axer",
    "axiomes": "axiome",
    "axions": "axer",
    "axolotls": "axolotl",
    "axones": "axone",
    "axonges": "axonge",
    "axons": "axer",
    "axâmes": "axer",
    "axât": "axer",
    "axâtes": "axer",
    "axèrent": "axer",
    "axé": "axer",
    "axée": "axer",
    "axées": "axer",
    "axés": "axer",
    "ayans": "ayan",
    "ayant": "avoir",
    "ayatollahs": "ayatollah",
    "ayes-ayes": "aye-aye",
    "ayez": "avoir",
    "ayons": "avoir",
    "azalées": "azalée",
    "azerie": "azeri",
    "azeries": "azeri",
    "azeris": "azeri",
    "azimutale": "azimutal",
    "azimutales": "azimutal",
    "azimutaux": "azimutal",
    "azimuts": "azimut",
    "azimuté": "azimuter",
    "azimutée": "azimuter",
    "azotes": "azote",
    "azotée": "azoté",
    "azotées": "azoté",
    "azotés": "azoté",
    "aztèques": "aztèque",
    "azulejos": "azulejo",
    "azurs": "azur",
    "azuré": "azurer",
    "azurée": "azurer",
    "azurées": "azuré",
    "azurés": "azuré",
    "azymes": "azyme",
    "azérie": "azéri",
    "azéries": "azéri",
    "azéris": "azéri",
    "aèdes": "aède",
    "aère": "aérer",
    "aèrent": "aérer",
    "aères": "aérer",
    "aéra": "aérer",
    "aérai": "aérer",
    "aéraient": "aérer",
    "aérais": "aérer",
    "aérait": "aérer",
    "aérant": "aérer",
    "aéras": "aérer",
    "aérasse": "aérer",
    "aérassent": "aérer",
    "aérasses": "aérer",
    "aérassiez": "aérer",
    "aérassions": "aérer",
    "aérateurs": "aérateur",
    "aérations": "aération",
    "aérera": "aérer",
    "aérerai": "aérer",
    "aéreraient": "aérer",
    "aérerais": "aérer",
    "aérerait": "aérer",
    "aéreras": "aérer",
    "aérerez": "aérer",
    "aéreriez": "aérer",
    "aérerions": "aérer",
    "aérerons": "aérer",
    "aéreront": "aérer",
    "aérez": "aérer",
    "aérienne": "aérien",
    "aériennes": "aérien",
    "aériens": "aérien",
    "aériez": "aérer",
    "aérions": "aérer",
    "aériums": "aérium",
    "aérobics": "aérobic",
    "aérobies": "aérobie",
    "aérodromes": "aérodrome",
    "aérodynamiques": "aérodynamique",
    "aérofreins": "aérofrein",
    "aérogares": "aérogare",
    "aéroglisseurs": "aéroglisseur",
    "aérogénérateurs": "aérogénérateur",
    "aérolithes": "aérolithe",
    "aéronautes": "aéronaute",
    "aéronautiques": "aéronautique",
    "aéronavale": "aéronaval",
    "aéronavales": "aéronaval",
    "aéronavals": "aéronaval",
    "aéronefs": "aéronef",
    "aérons": "aérer",
    "aérophagies": "aérophagie",
    "aéroplanes": "aéroplane",
    "aéroports": "aéroport",
    "aéroportuaires": "aéroportuaire",
    "aéroportée": "aéroporté",
    "aéroportées": "aéroporté",
    "aéroportés": "aéroporté",
    "aéropostale": "aéropostal",
    "aéropostales": "aéropostal",
    "aéropostaux": "aéropostal",
    "aérosols": "aérosol",
    "aérospatiale": "aérospatial",
    "aérospatiales": "aérospatial",
    "aérospatiaux": "aérospatial",
    "aérostatiques": "aérostatique",
    "aérostats": "aérostat",
    "aérostiers": "aérostier",
    "aérotrains": "aérotrain",
    "aérâmes": "aérer",
    "aérât": "aérer",
    "aérâtes": "aérer",
    "aérèrent": "aérer",
    "aéré": "aérer",
    "aérée": "aérer",
    "aérées": "aérer",
    "aérés": "aérer",
    "aînesses": "aînesse",
    "aînée": "aîné",
    "aînées": "aîné",
    "aînés": "aîné",
    "aîtres": "aître",
    "aïeule": "aïeul",
    "aïeules": "aïeul",
    "aïeuls": "aïeul",
    "aïeux": "aïeul",
    "aïs": "aï",
    "babas": "baba",
    "babies": "baby",
    "babilla": "babiller",
    "babillages": "babillage",
    "babillai": "babiller",
    "babillaient": "babiller",
    "babillais": "babiller",
    "babillait": "babiller",
    "babillant": "babiller",
    "babillarde": "babillard",
    "babillas": "babiller",
    "babillasse": "babiller",
    "babillassent": "babiller",
    "babillasses": "babiller",
    "babillassiez": "babiller",
    "babillassions": "babiller",
    "babille": "babiller",
    "babillent": "babiller",
    "babillera": "babiller",
    "babillerai": "babiller",
    "babilleraient": "babiller",
    "babillerais": "babiller",
    "babillerait": "babiller",
    "babilleras": "babiller",
    "babillerez": "babiller",
    "babilleriez": "babiller",
    "babillerions": "babiller",
    "babillerons": "babiller",
    "babilleront": "babiller",
    "babilles": "babiller",
    "babillez": "babiller",
    "babilliez": "babiller",
    "babillions": "babiller",
    "babillons": "babiller",
    "babillâmes": "babiller",
    "babillât": "babiller",
    "babillâtes": "babiller",
    "babillèrent": "babiller",
    "babillé": "babiller",
    "babils": "babil",
    "babines": "babine",
    "babioles": "babiole",
    "babouches": "babouche",
    "babouchkas": "babouchka",
    "babouine": "babouin",
    "babouines": "babouin",
    "babouins": "babouin",
    "babouvistes": "babouviste",
    "baby-sitters": "baby-sitter",
    "babylonienne": "babylonien",
    "babyloniennes": "babylonien",
    "babyloniens": "babylonien",
    "babys": "baby",
    "babélienne": "babélien",
    "baccalauréats": "baccalauréat",
    "baccaras": "baccara",
    "baccarats": "baccarat",
    "bacchanales": "bacchanale",
    "bacchantes": "bacchante",
    "bachaghas": "bachagha",
    "bacheliers": "bachelier",
    "bachelière": "bachelier",
    "bachelières": "bachelier",
    "bachiques": "bachique",
    "bachotaient": "bachoter",
    "bachotait": "bachoter",
    "bachotant": "bachoter",
    "bachots": "bachot",
    "bacillaires": "bacillaire",
    "bacilles": "bacille",
    "bacs": "bac",
    "bactéricides": "bactéricide",
    "bactérienne": "bactérien",
    "bactériennes": "bactérien",
    "bactériens": "bactérien",
    "bactéries": "bactérie",
    "bactériologiques": "bactériologique",
    "bada": "bader",
    "badamiers": "badamier",
    "badant": "bader",
    "badauda": "badauder",
    "badaudai": "badauder",
    "badaudaient": "badauder",
    "badaudais": "badauder",
    "badaudait": "badauder",
    "badaudant": "badauder",
    "badaudas": "badauder",
    "badaudasse": "badauder",
    "badaudassent": "badauder",
    "badaudasses": "badauder",
    "badaudassiez": "badauder",
    "badaudassions": "badauder",
    "badaude": "badauder",
    "badaudent": "badauder",
    "badaudera": "badauder",
    "badauderai": "badauder",
    "badauderaient": "badauder",
    "badauderais": "badauder",
    "badauderait": "badauder",
    "badauderas": "badauder",
    "badauderez": "badauder",
    "badauderies": "badauderie",
    "badauderiez": "badauder",
    "badauderions": "badauder",
    "badauderons": "badauder",
    "badauderont": "badauder",
    "badaudes": "badauder",
    "badaudez": "badauder",
    "badaudiez": "badauder",
    "badaudions": "badauder",
    "badaudons": "badauder",
    "badauds": "badaud",
    "badaudâmes": "badauder",
    "badaudât": "badauder",
    "badaudâtes": "badauder",
    "badaudèrent": "badauder",
    "badaudé": "badauder",
    "badernes": "baderne",
    "bades": "bader",
    "badges": "badge",
    "badgés": "badgé",
    "badianes": "badiane",
    "badigeonna": "badigeonner",
    "badigeonnages": "badigeonnage",
    "badigeonnai": "badigeonner",
    "badigeonnaient": "badigeonner",
    "badigeonnais": "badigeonner",
    "badigeonnait": "badigeonner",
    "badigeonnant": "badigeonner",
    "badigeonnas": "badigeonner",
    "badigeonnasse": "badigeonner",
    "badigeonnassent": "badigeonner",
    "badigeonnasses": "badigeonner",
    "badigeonnassiez": "badigeonner",
    "badigeonnassions": "badigeonner",
    "badigeonne": "badigeonner",
    "badigeonnent": "badigeonner",
    "badigeonnera": "badigeonner",
    "badigeonnerai": "badigeonner",
    "badigeonneraient": "badigeonner",
    "badigeonnerais": "badigeonner",
    "badigeonnerait": "badigeonner",
    "badigeonneras": "badigeonner",
    "badigeonnerez": "badigeonner",
    "badigeonneriez": "badigeonner",
    "badigeonnerions": "badigeonner",
    "badigeonnerons": "badigeonner",
    "badigeonneront": "badigeonner",
    "badigeonnes": "badigeonner",
    "badigeonnez": "badigeonner",
    "badigeonniez": "badigeonner",
    "badigeonnions": "badigeonner",
    "badigeonnons": "badigeonner",
    "badigeonnâmes": "badigeonner",
    "badigeonnât": "badigeonner",
    "badigeonnâtes": "badigeonner",
    "badigeonnèrent": "badigeonner",
    "badigeonné": "badigeonner",
    "badigeonnée": "badigeonner",
    "badigeonnées": "badigeonner",
    "badigeonnés": "badigeonner",
    "badigeons": "badigeon",
    "badina": "badiner",
    "badinages": "badinage",
    "badinai": "badiner",
    "badinaient": "badiner",
    "badinais": "badiner",
    "badinait": "badiner",
    "badinant": "badiner",
    "badinas": "badiner",
    "badinasse": "badiner",
    "badinassent": "badiner",
    "badinasses": "badiner",
    "badinassiez": "badiner",
    "badinassions": "badiner",
    "badine": "badiner",
    "badinent": "badiner",
    "badinera": "badiner",
    "badinerai": "badiner",
    "badineraient": "badiner",
    "badinerais": "badiner",
    "badinerait": "badiner",
    "badineras": "badiner",
    "badinerez": "badiner",
    "badineriez": "badiner",
    "badinerions": "badiner",
    "badinerons": "badiner",
    "badineront": "badiner",
    "badines": "badiner",
    "badinez": "badiner",
    "badiniez": "badiner",
    "badinions": "badiner",
    "badinons": "badiner",
    "badins": "badin",
    "badinâmes": "badiner",
    "badinât": "badiner",
    "badinâtes": "badiner",
    "badinèrent": "badiner",
    "badiné": "badiner",
    "badmintons": "badminton",
    "badoise": "badois",
    "baffe": "baffer",
    "baffes": "baffe",
    "baffles": "baffle",
    "baffés": "baffer",
    "bafoua": "bafouer",
    "bafouai": "bafouer",
    "bafouaient": "bafouer",
    "bafouais": "bafouer",
    "bafouait": "bafouer",
    "bafouant": "bafouer",
    "bafouas": "bafouer",
    "bafouasse": "bafouer",
    "bafouassent": "bafouer",
    "bafouasses": "bafouer",
    "bafouassiez": "bafouer",
    "bafouassions": "bafouer",
    "bafoue": "bafouer",
    "bafouent": "bafouer",
    "bafouera": "bafouer",
    "bafouerai": "bafouer",
    "bafoueraient": "bafouer",
    "bafouerais": "bafouer",
    "bafouerait": "bafouer",
    "bafoueras": "bafouer",
    "bafouerez": "bafouer",
    "bafoueriez": "bafouer",
    "bafouerions": "bafouer",
    "bafouerons": "bafouer",
    "bafoueront": "bafouer",
    "bafoues": "bafouer",
    "bafouez": "bafouer",
    "bafouiez": "bafouer",
    "bafouilla": "bafouiller",
    "bafouillages": "bafouillage",
    "bafouillai": "bafouiller",
    "bafouillaient": "bafouiller",
    "bafouillais": "bafouiller",
    "bafouillait": "bafouiller",
    "bafouillant": "bafouiller",
    "bafouillante": "bafouillant",
    "bafouillantes": "bafouillant",
    "bafouillas": "bafouiller",
    "bafouillasse": "bafouiller",
    "bafouillassent": "bafouiller",
    "bafouillasses": "bafouiller",
    "bafouillassiez": "bafouiller",
    "bafouillassions": "bafouiller",
    "bafouille": "bafouiller",
    "bafouillent": "bafouiller",
    "bafouillera": "bafouiller",
    "bafouillerai": "bafouiller",
    "bafouilleraient": "bafouiller",
    "bafouillerais": "bafouiller",
    "bafouillerait": "bafouiller",
    "bafouilleras": "bafouiller",
    "bafouillerez": "bafouiller",
    "bafouilleriez": "bafouiller",
    "bafouillerions": "bafouiller",
    "bafouillerons": "bafouiller",
    "bafouilleront": "bafouiller",
    "bafouilles": "bafouiller",
    "bafouillez": "bafouiller",
    "bafouilliez": "bafouiller",
    "bafouillions": "bafouiller",
    "bafouillons": "bafouiller",
    "bafouillâmes": "bafouiller",
    "bafouillât": "bafouiller",
    "bafouillâtes": "bafouiller",
    "bafouillèrent": "bafouiller",
    "bafouillé": "bafouiller",
    "bafouillée": "bafouiller",
    "bafouillées": "bafouiller",
    "bafouillés": "bafouiller",
    "bafouions": "bafouer",
    "bafouons": "bafouer",
    "bafouâmes": "bafouer",
    "bafouât": "bafouer",
    "bafouâtes": "bafouer",
    "bafouèrent": "bafouer",
    "bafoué": "bafouer",
    "bafouée": "bafouer",
    "bafouées": "bafouer",
    "bafoués": "bafouer",
    "bagages": "bagage",
    "bagagistes": "bagagiste",
    "bagarra": "bagarrer",
    "bagarrai": "bagarrer",
    "bagarraient": "bagarrer",
    "bagarrais": "bagarrer",
    "bagarrait": "bagarrer",
    "bagarrant": "bagarrer",
    "bagarras": "bagarrer",
    "bagarrasse": "bagarrer",
    "bagarrassent": "bagarrer",
    "bagarrasses": "bagarrer",
    "bagarrassiez": "bagarrer",
    "bagarrassions": "bagarrer",
    "bagarre": "bagarrer",
    "bagarrent": "bagarrer",
    "bagarrera": "bagarrer",
    "bagarrerai": "bagarrer",
    "bagarreraient": "bagarrer",
    "bagarrerais": "bagarrer",
    "bagarrerait": "bagarrer",
    "bagarreras": "bagarrer",
    "bagarrerez": "bagarrer",
    "bagarreriez": "bagarrer",
    "bagarrerions": "bagarrer",
    "bagarrerons": "bagarrer",
    "bagarreront": "bagarrer",
    "bagarres": "bagarrer",
    "bagarreurs": "bagarreur",
    "bagarreuse": "bagarreur",
    "bagarreuses": "bagarreur",
    "bagarrez": "bagarrer",
    "bagarriez": "bagarrer",
    "bagarrions": "bagarrer",
    "bagarrons": "bagarrer",
    "bagarrâmes": "bagarrer",
    "bagarrât": "bagarrer",
    "bagarrâtes": "bagarrer",
    "bagarrèrent": "bagarrer",
    "bagarré": "bagarrer",
    "bagarrée": "bagarrer",
    "bagarrées": "bagarrer",
    "bagarrés": "bagarrer",
    "bagatelles": "bagatelle",
    "bagnards": "bagnard",
    "bagnes": "bagne",
    "bagnoles": "bagnole",
    "bagote": "bagoter",
    "bagottaient": "bagotter",
    "bagottais": "bagotter",
    "bagotte": "bagotter",
    "bagoulait": "bagouler",
    "bagoule": "bagouler",
    "bagous": "bagou",
    "bagousées": "bagousé",
    "bagouts": "bagout",
    "bagouzes": "bagouze",
    "bague": "baguer",
    "baguenauda": "baguenauder",
    "baguenaudai": "baguenauder",
    "baguenaudaient": "baguenauder",
    "baguenaudais": "baguenauder",
    "baguenaudait": "baguenauder",
    "baguenaudant": "baguenauder",
    "baguenaudas": "baguenauder",
    "baguenaudasse": "baguenauder",
    "baguenaudassent": "baguenauder",
    "baguenaudasses": "baguenauder",
    "baguenaudassiez": "baguenauder",
    "baguenaudassions": "baguenauder",
    "baguenaude": "baguenauder",
    "baguenaudent": "baguenauder",
    "baguenaudera": "baguenauder",
    "baguenauderai": "baguenauder",
    "baguenauderaient": "baguenauder",
    "baguenauderais": "baguenauder",
    "baguenauderait": "baguenauder",
    "baguenauderas": "baguenauder",
    "baguenauderez": "baguenauder",
    "baguenauderiez": "baguenauder",
    "baguenauderions": "baguenauder",
    "baguenauderons": "baguenauder",
    "baguenauderont": "baguenauder",
    "baguenaudes": "baguenauder",
    "baguenaudez": "baguenauder",
    "baguenaudiez": "baguenauder",
    "baguenaudions": "baguenauder",
    "baguenaudons": "baguenauder",
    "baguenaudâmes": "baguenauder",
    "baguenaudât": "baguenauder",
    "baguenaudâtes": "baguenauder",
    "baguenaudèrent": "baguenauder",
    "baguenaudé": "baguenauder",
    "bagues": "bague",
    "baguettes": "baguette",
    "bagué": "baguer",
    "baguée": "baguer",
    "baguées": "baguer",
    "bagués": "baguer",
    "bahts": "baht",
    "bahute": "bahuter",
    "bahutent": "bahuter",
    "bahuts": "bahut",
    "baie": "bayer",
    "baient": "bayer",
    "baiera": "bayer",
    "baierai": "bayer",
    "baieraient": "bayer",
    "baierais": "bayer",
    "baierait": "bayer",
    "baieras": "bayer",
    "baierez": "bayer",
    "baieriez": "bayer",
    "baierions": "bayer",
    "baierons": "bayer",
    "baieront": "bayer",
    "baies": "bayer",
    "baigna": "baigner",
    "baignades": "baignade",
    "baignai": "baigner",
    "baignaient": "baigner",
    "baignais": "baigner",
    "baignait": "baigner",
    "baignant": "baigner",
    "baignas": "baigner",
    "baignasse": "baigner",
    "baignassent": "baigner",
    "baignasses": "baigner",
    "baignassiez": "baigner",
    "baignassions": "baigner",
    "baigne": "baigner",
    "baignent": "baigner",
    "baignera": "baigner",
    "baignerai": "baigner",
    "baigneraient": "baigner",
    "baignerais": "baigner",
    "baignerait": "baigner",
    "baigneras": "baigner",
    "baignerez": "baigner",
    "baigneriez": "baigner",
    "baignerions": "baigner",
    "baignerons": "baigner",
    "baigneront": "baigner",
    "baignes": "baigner",
    "baigneurs": "baigneur",
    "baigneuse": "baigneur",
    "baigneuses": "baigneur",
    "baignez": "baigner",
    "baigniez": "baigner",
    "baignions": "baigner",
    "baignoires": "baignoire",
    "baignons": "baigner",
    "baignâmes": "baigner",
    "baignât": "baigner",
    "baignâtes": "baigner",
    "baignèrent": "baigner",
    "baigné": "baigner",
    "baignée": "baigner",
    "baignées": "baigner",
    "baignés": "baigner",
    "bailes": "baile",
    "bailla": "bailler",
    "baillai": "bailler",
    "baillaient": "bailler",
    "baillais": "bailler",
    "baillait": "bailler",
    "baillant": "bailler",
    "baillas": "bailler",
    "baillasse": "bailler",
    "baillassent": "bailler",
    "baillasses": "bailler",
    "baillassiez": "bailler",
    "baillassions": "bailler",
    "baille": "bailler",
    "baillee": "bailler",
    "baillees": "bailler",
    "baillent": "bailler",
    "baillera": "bailler",
    "baillerai": "bailler",
    "bailleraient": "bailler",
    "baillerais": "bailler",
    "baillerait": "bailler",
    "bailleras": "bailler",
    "bailleresse": "bailleur",
    "bailleresses": "bailleur",
    "baillerez": "bailler",
    "bailleriez": "bailler",
    "baillerions": "bailler",
    "baillerons": "bailler",
    "bailleront": "bailler",
    "bailles": "bailler",
    "bailleurs": "bailleur",
    "baillez": "bailler",
    "bailliez": "bailler",
    "baillions": "bailler",
    "baillis": "bailli",
    "baillons": "bailler",
    "baillâmes": "bailler",
    "baillât": "bailler",
    "baillâtes": "bailler",
    "baillèrent": "bailler",
    "baillé": "bailler",
    "bains": "bain",
    "bains-marie": "bain-marie",
    "bais": "bai",
    "baisa": "baiser",
    "baisables": "baisable",
    "baisai": "baiser",
    "baisaient": "baiser",
    "baisais": "baiser",
    "baisait": "baiser",
    "baisant": "baiser",
    "baisas": "baiser",
    "baisasse": "baiser",
    "baisassent": "baiser",
    "baisasses": "baiser",
    "baisassiez": "baiser",
    "baisassions": "baiser",
    "baise": "baiser",
    "baisemains": "baisemain",
    "baisent": "baiser",
    "baisera": "baiser",
    "baiserai": "baiser",
    "baiseraient": "baiser",
    "baiserais": "baiser",
    "baiserait": "baiser",
    "baiseras": "baiser",
    "baiserez": "baiser",
    "baiseriez": "baiser",
    "baiserions": "baiser",
    "baiserons": "baiser",
    "baiseront": "baiser",
    "baisers": "baiser",
    "baises": "baiser",
    "baiseurs": "baiseur",
    "baiseuse": "baiseur",
    "baisez": "baiser",
    "baisiez": "baiser",
    "baisions": "baiser",
    "baisons": "baiser",
    "baisotant": "baisoter",
    "baisouillé": "baisouiller",
    "baissa": "baisser",
    "baissai": "baisser",
    "baissaient": "baisser",
    "baissais": "baisser",
    "baissait": "baisser",
    "baissant": "baisser",
    "baissas": "baisser",
    "baissasse": "baisser",
    "baissassent": "baisser",
    "baissasses": "baisser",
    "baissassiez": "baisser",
    "baissassions": "baisser",
    "baisse": "baisser",
    "baissent": "baisser",
    "baissera": "baisser",
    "baisserai": "baisser",
    "baisseraient": "baisser",
    "baisserais": "baisser",
    "baisserait": "baisser",
    "baisseras": "baisser",
    "baisserez": "baisser",
    "baisseriez": "baisser",
    "baisserions": "baisser",
    "baisserons": "baisser",
    "baisseront": "baisser",
    "baisses": "baisser",
    "baissez": "baisser",
    "baissiez": "baisser",
    "baissions": "baisser",
    "baissons": "baisser",
    "baissâmes": "baisser",
    "baissât": "baisser",
    "baissâtes": "baisser",
    "baissèrent": "baisser",
    "baissé": "baisser",
    "baissée": "baisser",
    "baissées": "baisser",
    "baissés": "baisser",
    "baisâmes": "baiser",
    "baisât": "baiser",
    "baisâtes": "baiser",
    "baisèrent": "baiser",
    "baisé": "baiser",
    "baisée": "baiser",
    "baisées": "baiser",
    "baisés": "baiser",
    "bajoues": "bajoue",
    "bajoyers": "bajoyer",
    "bakchichs": "bakchich",
    "baklavas": "baklava",
    "balada": "balader",
    "baladai": "balader",
    "baladaient": "balader",
    "baladais": "balader",
    "baladait": "balader",
    "baladant": "balader",
    "baladas": "balader",
    "baladasse": "balader",
    "baladassent": "balader",
    "baladasses": "balader",
    "baladassiez": "balader",
    "baladassions": "balader",
    "balade": "balader",
    "baladent": "balader",
    "baladera": "balader",
    "baladerai": "balader",
    "baladeraient": "balader",
    "baladerais": "balader",
    "baladerait": "balader",
    "baladeras": "balader",
    "baladerez": "balader",
    "baladeriez": "balader",
    "baladerions": "balader",
    "baladerons": "balader",
    "baladeront": "balader",
    "balades": "balader",
    "baladeurs": "baladeur",
    "baladeuse": "baladeur",
    "baladeuses": "baladeur",
    "baladez": "balader",
    "baladiez": "balader",
    "baladins": "baladin",
    "baladions": "balader",
    "baladons": "balader",
    "baladâmes": "balader",
    "baladât": "balader",
    "baladâtes": "balader",
    "baladèrent": "balader",
    "baladé": "balader",
    "baladée": "balader",
    "baladées": "balader",
    "baladés": "balader",
    "balafons": "balafon",
    "balafra": "balafrer",
    "balafrai": "balafrer",
    "balafraient": "balafrer",
    "balafrais": "balafrer",
    "balafrait": "balafrer",
    "balafrant": "balafrer",
    "balafras": "balafrer",
    "balafrasse": "balafrer",
    "balafrassent": "balafrer",
    "balafrasses": "balafrer",
    "balafrassiez": "balafrer",
    "balafrassions": "balafrer",
    "balafre": "balafrer",
    "balafrent": "balafrer",
    "balafrera": "balafrer",
    "balafrerai": "balafrer",
    "balafreraient": "balafrer",
    "balafrerais": "balafrer",
    "balafrerait": "balafrer",
    "balafreras": "balafrer",
    "balafrerez": "balafrer",
    "balafreriez": "balafrer",
    "balafrerions": "balafrer",
    "balafrerons": "balafrer",
    "balafreront": "balafrer",
    "balafres": "balafrer",
    "balafrez": "balafrer",
    "balafriez": "balafrer",
    "balafrions": "balafrer",
    "balafrons": "balafrer",
    "balafrâmes": "balafrer",
    "balafrât": "balafrer",
    "balafrâtes": "balafrer",
    "balafrèrent": "balafrer",
    "balafré": "balafrer",
    "balafrée": "balafrer",
    "balafrées": "balafrer",
    "balafrés": "balafrer",
    "balaie": "balayer",
    "balaient": "balayer",
    "balaiera": "balayer",
    "balaierai": "balayer",
    "balaieraient": "balayer",
    "balaierais": "balayer",
    "balaierait": "balayer",
    "balaieras": "balayer",
    "balaierez": "balayer",
    "balaieriez": "balayer",
    "balaierions": "balayer",
    "balaierons": "balayer",
    "balaieront": "balayer",
    "balaies": "balayer",
    "balais": "balai",
    "balais-brosses": "balai-brosse",
    "balaises": "balaise",
    "balalaïkas": "balalaïka",
    "balance": "balancer",
    "balancelles": "balancelle",
    "balancements": "balancement",
    "balancent": "balancer",
    "balancera": "balancer",
    "balancerai": "balancer",
    "balanceraient": "balancer",
    "balancerais": "balancer",
    "balancerait": "balancer",
    "balanceras": "balancer",
    "balancerez": "balancer",
    "balanceriez": "balancer",
    "balancerions": "balancer",
    "balancerons": "balancer",
    "balanceront": "balancer",
    "balances": "balancer",
    "balancez": "balancer",
    "balanciers": "balancier",
    "balanciez": "balancer",
    "balancines": "balancine",
    "balancions": "balancer",
    "balancèrent": "balancer",
    "balancé": "balancer",
    "balancée": "balancer",
    "balancées": "balancer",
    "balancés": "balancer",
    "balanes": "balane",
    "balanstiquant": "balanstiquer",
    "balanstique": "balanstiquer",
    "balança": "balancer",
    "balançages": "balançage",
    "balançai": "balancer",
    "balançaient": "balancer",
    "balançais": "balancer",
    "balançait": "balancer",
    "balançant": "balancer",
    "balanças": "balancer",
    "balançasse": "balancer",
    "balançassent": "balancer",
    "balançasses": "balancer",
    "balançassiez": "balancer",
    "balançassions": "balancer",
    "balançoires": "balançoire",
    "balançons": "balancer",
    "balançâmes": "balancer",
    "balançât": "balancer",
    "balançâtes": "balancer",
    "balaya": "balayer",
    "balayages": "balayage",
    "balayai": "balayer",
    "balayaient": "balayer",
    "balayais": "balayer",
    "balayait": "balayer",
    "balayant": "balayer",
    "balayas": "balayer",
    "balayasse": "balayer",
    "balayassent": "balayer",
    "balayasses": "balayer",
    "balayassiez": "balayer",
    "balayassions": "balayer",
    "balaye": "balayer",
    "balayent": "balayer",
    "balayera": "balayer",
    "balayerai": "balayer",
    "balayeraient": "balayer",
    "balayerais": "balayer",
    "balayerait": "balayer",
    "balayeras": "balayer",
    "balayerez": "balayer",
    "balayeriez": "balayer",
    "balayerions": "balayer",
    "balayerons": "balayer",
    "balayeront": "balayer",
    "balayes": "balayer",
    "balayettes": "balayette",
    "balayeurs": "balayeur",
    "balayeuse": "balayeur",
    "balayeuses": "balayeur",
    "balayez": "balayer",
    "balayiez": "balayer",
    "balayions": "balayer",
    "balayons": "balayer",
    "balayures": "balayure",
    "balayâmes": "balayer",
    "balayât": "balayer",
    "balayâtes": "balayer",
    "balayèrent": "balayer",
    "balayé": "balayer",
    "balayée": "balayer",
    "balayées": "balayer",
    "balayés": "balayer",
    "balbutia": "balbutier",
    "balbutiai": "balbutier",
    "balbutiaient": "balbutier",
    "balbutiais": "balbutier",
    "balbutiait": "balbutier",
    "balbutiant": "balbutier",
    "balbutiante": "balbutiant",
    "balbutiantes": "balbutiant",
    "balbutiants": "balbutiant",
    "balbutias": "balbutier",
    "balbutiasse": "balbutier",
    "balbutiassent": "balbutier",
    "balbutiasses": "balbutier",
    "balbutiassiez": "balbutier",
    "balbutiassions": "balbutier",
    "balbutie": "balbutier",
    "balbutiements": "balbutiement",
    "balbutient": "balbutier",
    "balbutiera": "balbutier",
    "balbutierai": "balbutier",
    "balbutieraient": "balbutier",
    "balbutierais": "balbutier",
    "balbutierait": "balbutier",
    "balbutieras": "balbutier",
    "balbutierez": "balbutier",
    "balbutieriez": "balbutier",
    "balbutierions": "balbutier",
    "balbutierons": "balbutier",
    "balbutieront": "balbutier",
    "balbuties": "balbutier",
    "balbutiez": "balbutier",
    "balbutiiez": "balbutier",
    "balbutiions": "balbutier",
    "balbutions": "balbutier",
    "balbutiâmes": "balbutier",
    "balbutiât": "balbutier",
    "balbutiâtes": "balbutier",
    "balbutièrent": "balbutier",
    "balbutié": "balbutier",
    "balbutiée": "balbutier",
    "balbutiées": "balbutier",
    "balbutiés": "balbutier",
    "balconnets": "balconnet",
    "balcons": "balcon",
    "baldaquins": "baldaquin",
    "baleineaux": "baleineau",
    "baleines": "baleine",
    "baleiniers": "baleinier",
    "baleinière": "baleinier",
    "baleinières": "baleinier",
    "baleinée": "baleiné",
    "baleinées": "baleiné",
    "baleinés": "baleiné",
    "bales": "bale",
    "balinaise": "balinais",
    "balisa": "baliser",
    "balisai": "baliser",
    "balisaient": "baliser",
    "balisais": "baliser",
    "balisait": "baliser",
    "balisant": "baliser",
    "balisas": "baliser",
    "balisasse": "baliser",
    "balisassent": "baliser",
    "balisasses": "baliser",
    "balisassiez": "baliser",
    "balisassions": "baliser",
    "balise": "baliser",
    "balisent": "baliser",
    "balisera": "baliser",
    "baliserai": "baliser",
    "baliseraient": "baliser",
    "baliserais": "baliser",
    "baliserait": "baliser",
    "baliseras": "baliser",
    "baliserez": "baliser",
    "baliseriez": "baliser",
    "baliserions": "baliser",
    "baliserons": "baliser",
    "baliseront": "baliser",
    "balises": "baliser",
    "balisez": "baliser",
    "balisiez": "baliser",
    "balisions": "baliser",
    "balisons": "baliser",
    "balistes": "baliste",
    "balistiques": "balistique",
    "balisâmes": "baliser",
    "balisât": "baliser",
    "balisâtes": "baliser",
    "balisèrent": "baliser",
    "balisé": "baliser",
    "balisée": "baliser",
    "balisées": "baliser",
    "balisés": "baliser",
    "baliveaux": "baliveau",
    "balivernes": "baliverne",
    "balkaniques": "balkanique",
    "balkanisations": "balkanisation",
    "balkanisés": "balkaniser",
    "ball-traps": "ball-trap",
    "ballades": "ballade",
    "ballaient": "baller",
    "ballant": "baller",
    "ballante": "ballant",
    "ballantes": "ballant",
    "ballants": "ballant",
    "ballastages": "ballastage",
    "ballasts": "ballast",
    "ballerines": "ballerine",
    "balles": "balle",
    "ballets": "ballet",
    "balloches": "balloche",
    "ballonna": "ballonner",
    "ballonnai": "ballonner",
    "ballonnaient": "ballonner",
    "ballonnais": "ballonner",
    "ballonnait": "ballonner",
    "ballonnant": "ballonner",
    "ballonnante": "ballonnant",
    "ballonnants": "ballonnant",
    "ballonnas": "ballonner",
    "ballonnasse": "ballonner",
    "ballonnassent": "ballonner",
    "ballonnasses": "ballonner",
    "ballonnassiez": "ballonner",
    "ballonnassions": "ballonner",
    "ballonne": "ballonner",
    "ballonnements": "ballonnement",
    "ballonnent": "ballonner",
    "ballonnera": "ballonner",
    "ballonnerai": "ballonner",
    "ballonneraient": "ballonner",
    "ballonnerais": "ballonner",
    "ballonnerait": "ballonner",
    "ballonneras": "ballonner",
    "ballonnerez": "ballonner",
    "ballonneriez": "ballonner",
    "ballonnerions": "ballonner",
    "ballonnerons": "ballonner",
    "ballonneront": "ballonner",
    "ballonnes": "ballonner",
    "ballonnets": "ballonnet",
    "ballonnez": "ballonner",
    "ballonniez": "ballonner",
    "ballonnions": "ballonner",
    "ballonnons": "ballonner",
    "ballonnâmes": "ballonner",
    "ballonnât": "ballonner",
    "ballonnâtes": "ballonner",
    "ballonnèrent": "ballonner",
    "ballonné": "ballonner",
    "ballonnée": "ballonner",
    "ballonnées": "ballonner",
    "ballonnés": "ballonner",
    "ballons": "ballon",
    "ballons-sondes": "ballon-sonde",
    "ballotins": "ballotin",
    "ballots": "ballot",
    "ballotta": "ballotter",
    "ballottages": "ballottage",
    "ballottai": "ballotter",
    "ballottaient": "ballotter",
    "ballottais": "ballotter",
    "ballottait": "ballotter",
    "ballottant": "ballotter",
    "ballottante": "ballottant",
    "ballottantes": "ballottant",
    "ballottants": "ballottant",
    "ballottas": "ballotter",
    "ballottasse": "ballotter",
    "ballottassent": "ballotter",
    "ballottasses": "ballotter",
    "ballottassiez": "ballotter",
    "ballottassions": "ballotter",
    "ballotte": "ballotter",
    "ballottements": "ballottement",
    "ballottent": "ballotter",
    "ballottera": "ballotter",
    "ballotterai": "ballotter",
    "ballotteraient": "ballotter",
    "ballotterais": "ballotter",
    "ballotterait": "ballotter",
    "ballotteras": "ballotter",
    "ballotterez": "ballotter",
    "ballotteriez": "ballotter",
    "ballotterions": "ballotter",
    "ballotterons": "ballotter",
    "ballotteront": "ballotter",
    "ballottes": "ballotter",
    "ballottez": "ballotter",
    "ballottiez": "ballotter",
    "ballottines": "ballottine",
    "ballottions": "ballotter",
    "ballottons": "ballotter",
    "ballottâmes": "ballotter",
    "ballottât": "ballotter",
    "ballottâtes": "ballotter",
    "ballottèrent": "ballotter",
    "ballotté": "ballotter",
    "ballottée": "ballotter",
    "ballottées": "ballotter",
    "ballottés": "ballotter",
    "balluches": "balluche",
    "balluchonné": "balluchonner",
    "balluchons": "balluchon",
    "balnéaires": "balnéaire",
    "balourde": "balourd",
    "balourdes": "balourd",
    "balourdises": "balourdise",
    "balourds": "balourd",
    "bals": "bal",
    "balsamiers": "balsamier",
    "balsamines": "balsamine",
    "balsamiques": "balsamique",
    "baltes": "balte",
    "balthazars": "balthazar",
    "baltiques": "baltique",
    "baluchonne": "baluchonner",
    "baluchonnent": "baluchonner",
    "baluchonneurs": "baluchonneur",
    "baluchonné": "baluchonner",
    "baluchons": "baluchon",
    "balustrades": "balustrade",
    "balustres": "balustre",
    "balzacienne": "balzacien",
    "balzaciennes": "balzacien",
    "balzaciens": "balzacien",
    "balzanes": "balzane",
    "balzans": "balzan",
    "balèzes": "balèze",
    "baléarisations": "baléarisation",
    "bambine": "bambin",
    "bambines": "bambin",
    "bambinos": "bambino",
    "bambins": "bambin",
    "bambocha": "bambocher",
    "bambochades": "bambochade",
    "bambochai": "bambocher",
    "bambochaient": "bambocher",
    "bambochais": "bambocher",
    "bambochait": "bambocher",
    "bambochant": "bambocher",
    "bambochas": "bambocher",
    "bambochasse": "bambocher",
    "bambochassent": "bambocher",
    "bambochasses": "bambocher",
    "bambochassiez": "bambocher",
    "bambochassions": "bambocher",
    "bamboche": "bambocher",
    "bambochent": "bambocher",
    "bambochera": "bambocher",
    "bambocherai": "bambocher",
    "bambocheraient": "bambocher",
    "bambocherais": "bambocher",
    "bambocherait": "bambocher",
    "bambocheras": "bambocher",
    "bambocherez": "bambocher",
    "bambocheriez": "bambocher",
    "bambocherions": "bambocher",
    "bambocherons": "bambocher",
    "bambocheront": "bambocher",
    "bamboches": "bambocher",
    "bambocheurs": "bambocheur",
    "bambochez": "bambocher",
    "bambochiez": "bambocher",
    "bambochions": "bambocher",
    "bambochons": "bambocher",
    "bambochâmes": "bambocher",
    "bambochât": "bambocher",
    "bambochâtes": "bambocher",
    "bambochèrent": "bambocher",
    "bamboché": "bambocher",
    "bambochée": "bambocher",
    "bambochées": "bambocher",
    "bambochés": "bambocher",
    "bambous": "bambou",
    "banale": "banal",
    "banales": "banal",
    "banalisa": "banaliser",
    "banalisai": "banaliser",
    "banalisaient": "banaliser",
    "banalisais": "banaliser",
    "banalisait": "banaliser",
    "banalisant": "banaliser",
    "banalisas": "banaliser",
    "banalisasse": "banaliser",
    "banalisassent": "banaliser",
    "banalisasses": "banaliser",
    "banalisassiez": "banaliser",
    "banalisassions": "banaliser",
    "banalisations": "banalisation",
    "banalise": "banaliser",
    "banalisent": "banaliser",
    "banalisera": "banaliser",
    "banaliserai": "banaliser",
    "banaliseraient": "banaliser",
    "banaliserais": "banaliser",
    "banaliserait": "banaliser",
    "banaliseras": "banaliser",
    "banaliserez": "banaliser",
    "banaliseriez": "banaliser",
    "banaliserions": "banaliser",
    "banaliserons": "banaliser",
    "banaliseront": "banaliser",
    "banalises": "banaliser",
    "banalisez": "banaliser",
    "banalisiez": "banaliser",
    "banalisions": "banaliser",
    "banalisons": "banaliser",
    "banalisâmes": "banaliser",
    "banalisât": "banaliser",
    "banalisâtes": "banaliser",
    "banalisèrent": "banaliser",
    "banalisé": "banaliser",
    "banalisée": "banaliser",
    "banalisées": "banaliser",
    "banalisés": "banaliser",
    "banalités": "banalité",
    "banals": "banal",
    "banana": "bananer",
    "bananas": "bananer",
    "bananeraies": "bananeraie",
    "bananes": "banane",
    "bananiers": "bananier",
    "bananière": "bananier",
    "banaux": "banal",
    "bancaires": "bancaire",
    "bancale": "bancal",
    "bancales": "bancal",
    "bancals": "bancal",
    "banche": "bancher",
    "bancos": "banco",
    "bancroches": "bancroche",
    "bancs": "banc",
    "bancs-titres": "banc-titre",
    "banda": "bander",
    "bandages": "bandage",
    "bandai": "bander",
    "bandaient": "bander",
    "bandais": "bander",
    "bandaisons": "bandaison",
    "bandait": "bander",
    "bandanas": "bandana",
    "bandant": "bander",
    "bandante": "bandant",
    "bandantes": "bandant",
    "bandants": "bandant",
    "bandas": "bander",
    "bandasse": "bander",
    "bandassent": "bander",
    "bandasses": "bander",
    "bandassiez": "bander",
    "bandassions": "bander",
    "bande": "bander",
    "bandeaux": "bandeau",
    "bandelettes": "bandelette",
    "bandent": "bander",
    "bandera": "bander",
    "banderai": "bander",
    "banderaient": "bander",
    "banderais": "bander",
    "banderait": "bander",
    "banderas": "bandera",
    "banderez": "bander",
    "banderiez": "bander",
    "banderilleros": "banderillero",
    "banderilles": "banderille",
    "banderions": "bander",
    "banderoles": "banderole",
    "banderons": "bander",
    "banderont": "bander",
    "bandes": "bander",
    "bandes-annonces": "bande-annonce",
    "bandeurs": "bandeur",
    "bandez": "bander",
    "bandiez": "bander",
    "bandions": "bander",
    "banditismes": "banditisme",
    "bandits": "bandit",
    "bandons": "bander",
    "bandoulières": "bandoulière",
    "bandâmes": "bander",
    "bandât": "bander",
    "bandâtes": "bander",
    "bandèrent": "bander",
    "bandé": "bander",
    "bandée": "bander",
    "bandées": "bander",
    "bandés": "bander",
    "bangs": "bang",
    "banians": "banian",
    "banjos": "banjo",
    "bank-notes": "bank-note",
    "banlieues": "banlieue",
    "banlieusarde": "banlieusard",
    "banlieusardes": "banlieusard",
    "banlieusards": "banlieusard",
    "banne": "banner",
    "bannes": "banne",
    "banni": "bannir",
    "bannie": "bannir",
    "bannies": "bannir",
    "bannira": "bannir",
    "bannirai": "bannir",
    "banniraient": "bannir",
    "bannirais": "bannir",
    "bannirait": "bannir",
    "banniras": "bannir",
    "bannirent": "bannir",
    "bannirez": "bannir",
    "banniriez": "bannir",
    "bannirions": "bannir",
    "bannirons": "bannir",
    "banniront": "bannir",
    "bannis": "bannir",
    "bannissaient": "bannir",
    "bannissais": "bannir",
    "bannissait": "bannir",
    "bannissant": "bannir",
    "bannisse": "bannir",
    "bannissements": "bannissement",
    "bannissent": "bannir",
    "bannisses": "bannir",
    "bannissez": "bannir",
    "bannissiez": "bannir",
    "bannissions": "bannir",
    "bannissons": "bannir",
    "bannit": "bannir",
    "bannières": "bannière",
    "bannîmes": "bannir",
    "bannît": "bannir",
    "bannîtes": "bannir",
    "banqua": "banquer",
    "banquerai": "banquer",
    "banqueroutes": "banqueroute",
    "banqueroutiers": "banqueroutier",
    "banques": "banque",
    "banqueta": "banqueter",
    "banquetai": "banqueter",
    "banquetaient": "banqueter",
    "banquetais": "banqueter",
    "banquetait": "banqueter",
    "banquetant": "banqueter",
    "banquetas": "banqueter",
    "banquetasse": "banqueter",
    "banquetassent": "banqueter",
    "banquetasses": "banqueter",
    "banquetassiez": "banqueter",
    "banquetassions": "banqueter",
    "banquetez": "banqueter",
    "banquetiez": "banqueter",
    "banquetions": "banqueter",
    "banquetons": "banqueter",
    "banquets": "banquet",
    "banquette": "banqueter",
    "banquettent": "banqueter",
    "banquettera": "banqueter",
    "banquetterai": "banqueter",
    "banquetteraient": "banqueter",
    "banquetterais": "banqueter",
    "banquetterait": "banqueter",
    "banquetteras": "banqueter",
    "banquetterez": "banqueter",
    "banquetteriez": "banqueter",
    "banquetterions": "banqueter",
    "banquetterons": "banqueter",
    "banquetteront": "banqueter",
    "banquettes": "banquette",
    "banquetâmes": "banqueter",
    "banquetât": "banqueter",
    "banquetâtes": "banqueter",
    "banquetèrent": "banqueter",
    "banqueté": "banqueter",
    "banquiers": "banquier",
    "banquises": "banquise",
    "banquistes": "banquiste",
    "banquière": "banquier",
    "banquières": "banquier",
    "banqué": "banquer",
    "bans": "ban",
    "bantoue": "bantou",
    "bantoues": "bantou",
    "bantous": "bantou",
    "bantoustans": "bantoustan",
    "baobabs": "baobab",
    "baptisa": "baptiser",
    "baptisai": "baptiser",
    "baptisaient": "baptiser",
    "baptisais": "baptiser",
    "baptisait": "baptiser",
    "baptisant": "baptiser",
    "baptisas": "baptiser",
    "baptisasse": "baptiser",
    "baptisassent": "baptiser",
    "baptisasses": "baptiser",
    "baptisassiez": "baptiser",
    "baptisassions": "baptiser",
    "baptise": "baptiser",
    "baptisent": "baptiser",
    "baptisera": "baptiser",
    "baptiserai": "baptiser",
    "baptiseraient": "baptiser",
    "baptiserais": "baptiser",
    "baptiserait": "baptiser",
    "baptiseras": "baptiser",
    "baptiserez": "baptiser",
    "baptiseriez": "baptiser",
    "baptiserions": "baptiser",
    "baptiserons": "baptiser",
    "baptiseront": "baptiser",
    "baptises": "baptiser",
    "baptisez": "baptiser",
    "baptisiez": "baptiser",
    "baptisions": "baptiser",
    "baptismale": "baptismal",
    "baptismales": "baptismal",
    "baptismaux": "baptismal",
    "baptisons": "baptiser",
    "baptistes": "baptiste",
    "baptistères": "baptistère",
    "baptisâmes": "baptiser",
    "baptisât": "baptiser",
    "baptisâtes": "baptiser",
    "baptisèrent": "baptiser",
    "baptisé": "baptiser",
    "baptisée": "baptiser",
    "baptisées": "baptiser",
    "baptisés": "baptiser",
    "baptêmes": "baptême",
    "baquets": "baquet",
    "baragouina": "baragouiner",
    "baragouinai": "baragouiner",
    "baragouinaient": "baragouiner",
    "baragouinais": "baragouiner",
    "baragouinait": "baragouiner",
    "baragouinant": "baragouiner",
    "baragouinas": "baragouiner",
    "baragouinasse": "baragouiner",
    "baragouinassent": "baragouiner",
    "baragouinasses": "baragouiner",
    "baragouinassiez": "baragouiner",
    "baragouinassions": "baragouiner",
    "baragouine": "baragouiner",
    "baragouinent": "baragouiner",
    "baragouinera": "baragouiner",
    "baragouinerai": "baragouiner",
    "baragouineraient": "baragouiner",
    "baragouinerais": "baragouiner",
    "baragouinerait": "baragouiner",
    "baragouineras": "baragouiner",
    "baragouinerez": "baragouiner",
    "baragouineriez": "baragouiner",
    "baragouinerions": "baragouiner",
    "baragouinerons": "baragouiner",
    "baragouineront": "baragouiner",
    "baragouines": "baragouiner",
    "baragouinez": "baragouiner",
    "baragouiniez": "baragouiner",
    "baragouinions": "baragouiner",
    "baragouinons": "baragouiner",
    "baragouins": "baragouin",
    "baragouinâmes": "baragouiner",
    "baragouinât": "baragouiner",
    "baragouinâtes": "baragouiner",
    "baragouinèrent": "baragouiner",
    "baragouiné": "baragouiner",
    "baragouinée": "baragouiner",
    "baragouinées": "baragouiner",
    "baragouinés": "baragouiner",
    "barakas": "baraka",
    "baraquements": "baraquement",
    "baraques": "baraque",
    "baraqué": "baraquer",
    "baraquée": "baraquer",
    "baraqués": "baraquer",
    "baratina": "baratiner",
    "baratinai": "baratiner",
    "baratinaient": "baratiner",
    "baratinais": "baratiner",
    "baratinait": "baratiner",
    "baratinant": "baratiner",
    "baratinas": "baratiner",
    "baratinasse": "baratiner",
    "baratinassent": "baratiner",
    "baratinasses": "baratiner",
    "baratinassiez": "baratiner",
    "baratinassions": "baratiner",
    "baratine": "baratiner",
    "baratinent": "baratiner",
    "baratinera": "baratiner",
    "baratinerai": "baratiner",
    "baratineraient": "baratiner",
    "baratinerais": "baratiner",
    "baratinerait": "baratiner",
    "baratineras": "baratiner",
    "baratinerez": "baratiner",
    "baratineriez": "baratiner",
    "baratinerions": "baratiner",
    "baratinerons": "baratiner",
    "baratineront": "baratiner",
    "baratines": "baratiner",
    "baratineurs": "baratineur",
    "baratineuse": "baratineur",
    "baratinez": "baratiner",
    "baratiniez": "baratiner",
    "baratinions": "baratiner",
    "baratinons": "baratiner",
    "baratins": "baratin",
    "baratinâmes": "baratiner",
    "baratinât": "baratiner",
    "baratinâtes": "baratiner",
    "baratinèrent": "baratiner",
    "baratiné": "baratiner",
    "baratinée": "baratiner",
    "baratinées": "baratiner",
    "baratinés": "baratiner",
    "baratta": "baratter",
    "barattai": "baratter",
    "barattaient": "baratter",
    "barattais": "baratter",
    "barattait": "baratter",
    "barattant": "baratter",
    "barattas": "baratter",
    "barattasse": "baratter",
    "barattassent": "baratter",
    "barattasses": "baratter",
    "barattassiez": "baratter",
    "barattassions": "baratter",
    "baratte": "baratter",
    "barattent": "baratter",
    "barattera": "baratter",
    "baratterai": "baratter",
    "baratteraient": "baratter",
    "baratterais": "baratter",
    "baratterait": "baratter",
    "baratteras": "baratter",
    "baratterez": "baratter",
    "baratteriez": "baratter",
    "baratterions": "baratter",
    "baratterons": "baratter",
    "baratteront": "baratter",
    "barattes": "baratter",
    "barattez": "baratter",
    "barattiez": "baratter",
    "barattions": "baratter",
    "barattons": "baratter",
    "barattâmes": "baratter",
    "barattât": "baratter",
    "barattâtes": "baratter",
    "barattèrent": "baratter",
    "baratté": "baratter",
    "barattée": "baratter",
    "barattées": "baratter",
    "barattés": "baratter",
    "barba": "barber",
    "barbacanes": "barbacane",
    "barbaient": "barber",
    "barbait": "barber",
    "barbant": "barber",
    "barbante": "barbant",
    "barbantes": "barbant",
    "barbants": "barbant",
    "barbares": "barbare",
    "barbaresques": "barbaresque",
    "barbaries": "barbarie",
    "barbarismes": "barbarisme",
    "barbe": "barber",
    "barbeaux": "barbeau",
    "barbecues": "barbecue",
    "barbelée": "barbelé",
    "barbelées": "barbelé",
    "barbelés": "barbelé",
    "barbent": "barber",
    "barbera": "barber",
    "barberait": "barber",
    "barbes": "barber",
    "barbes-de-capucin": "barbe-de-capucin",
    "barbets": "barbet",
    "barbette": "barbet",
    "barbettes": "barbet",
    "barbiches": "barbiche",
    "barbichus": "barbichu",
    "barbiers": "barbier",
    "barbillons": "barbillon",
    "barbiquets": "barbiquet",
    "barbituriques": "barbiturique",
    "barbons": "barbon",
    "barbota": "barboter",
    "barbotages": "barbotage",
    "barbotai": "barboter",
    "barbotaient": "barboter",
    "barbotais": "barboter",
    "barbotait": "barboter",
    "barbotant": "barboter",
    "barbotas": "barboter",
    "barbotasse": "barboter",
    "barbotassent": "barboter",
    "barbotasses": "barboter",
    "barbotassiez": "barboter",
    "barbotassions": "barboter",
    "barbote": "barboter",
    "barbotent": "barboter",
    "barbotera": "barboter",
    "barboterai": "barboter",
    "barboteraient": "barboter",
    "barboterais": "barboter",
    "barboterait": "barboter",
    "barboteras": "barboter",
    "barboterez": "barboter",
    "barboteriez": "barboter",
    "barboterions": "barboter",
    "barboterons": "barboter",
    "barboteront": "barboter",
    "barbotes": "barboter",
    "barboteuse": "barboteur",
    "barboteuses": "barboteur",
    "barbotez": "barboter",
    "barbotiez": "barboter",
    "barbotions": "barboter",
    "barbotons": "barboter",
    "barbottes": "barbotte",
    "barbotâmes": "barboter",
    "barbotât": "barboter",
    "barbotâtes": "barboter",
    "barbotèrent": "barboter",
    "barboté": "barboter",
    "barbotée": "barboter",
    "barbotées": "barboter",
    "barbotés": "barboter",
    "barbouilla": "barbouiller",
    "barbouillages": "barbouillage",
    "barbouillai": "barbouiller",
    "barbouillaient": "barbouiller",
    "barbouillais": "barbouiller",
    "barbouillait": "barbouiller",
    "barbouillant": "barbouiller",
    "barbouillas": "barbouiller",
    "barbouillasse": "barbouiller",
    "barbouillassent": "barbouiller",
    "barbouillasses": "barbouiller",
    "barbouillassiez": "barbouiller",
    "barbouillassions": "barbouiller",
    "barbouille": "barbouiller",
    "barbouillent": "barbouiller",
    "barbouillera": "barbouiller",
    "barbouillerai": "barbouiller",
    "barbouilleraient": "barbouiller",
    "barbouillerais": "barbouiller",
    "barbouillerait": "barbouiller",
    "barbouilleras": "barbouiller",
    "barbouillerez": "barbouiller",
    "barbouilleriez": "barbouiller",
    "barbouillerions": "barbouiller",
    "barbouillerons": "barbouiller",
    "barbouilleront": "barbouiller",
    "barbouilles": "barbouiller",
    "barbouilleurs": "barbouilleur",
    "barbouillez": "barbouiller",
    "barbouilliez": "barbouiller",
    "barbouillions": "barbouiller",
    "barbouillons": "barbouiller",
    "barbouillâmes": "barbouiller",
    "barbouillât": "barbouiller",
    "barbouillâtes": "barbouiller",
    "barbouillèrent": "barbouiller",
    "barbouillé": "barbouiller",
    "barbouillée": "barbouiller",
    "barbouillées": "barbouiller",
    "barbouillés": "barbouiller",
    "barbouzes": "barbouze",
    "barbue": "barbu",
    "barbues": "barbue",
    "barbules": "barbule",
    "barbus": "barbu",
    "barbé": "barber",
    "barbés": "barber",
    "barcarolles": "barcarolle",
    "barcasses": "barcasse",
    "barda": "barder",
    "bardai": "barder",
    "bardaient": "barder",
    "bardais": "barder",
    "bardait": "barder",
    "bardanes": "bardane",
    "bardant": "barder",
    "bardas": "barder",
    "bardasse": "barder",
    "bardassent": "barder",
    "bardasses": "barder",
    "bardassiez": "barder",
    "bardassions": "barder",
    "barde": "barder",
    "bardeaux": "bardeau",
    "bardent": "barder",
    "bardera": "barder",
    "barderai": "barder",
    "barderaient": "barder",
    "barderais": "barder",
    "barderait": "barder",
    "barderas": "barder",
    "barderez": "barder",
    "barderiez": "barder",
    "barderions": "barder",
    "barderons": "barder",
    "barderont": "barder",
    "bardes": "barder",
    "bardeurs": "bardeur",
    "bardez": "barder",
    "bardiez": "barder",
    "bardions": "barder",
    "bardiques": "bardique",
    "bardons": "barder",
    "bardots": "bardot",
    "bardâmes": "barder",
    "bardât": "barder",
    "bardâtes": "barder",
    "bardèrent": "barder",
    "bardé": "barder",
    "bardée": "barder",
    "bardées": "barder",
    "bardés": "barder",
    "barges": "barge",
    "barguigna": "barguigner",
    "barguignai": "barguigner",
    "barguignaient": "barguigner",
    "barguignais": "barguigner",
    "barguignait": "barguigner",
    "barguignant": "barguigner",
    "barguignas": "barguigner",
    "barguignasse": "barguigner",
    "barguignassent": "barguigner",
    "barguignasses": "barguigner",
    "barguignassiez": "barguigner",
    "barguignassions": "barguigner",
    "barguigne": "barguigner",
    "barguignent": "barguigner",
    "barguignera": "barguigner",
    "barguignerai": "barguigner",
    "barguigneraient": "barguigner",
    "barguignerais": "barguigner",
    "barguignerait": "barguigner",
    "barguigneras": "barguigner",
    "barguignerez": "barguigner",
    "barguigneriez": "barguigner",
    "barguignerions": "barguigner",
    "barguignerons": "barguigner",
    "barguigneront": "barguigner",
    "barguignes": "barguigner",
    "barguignez": "barguigner",
    "barguigniez": "barguigner",
    "barguignions": "barguigner",
    "barguignons": "barguigner",
    "barguignâmes": "barguigner",
    "barguignât": "barguigner",
    "barguignâtes": "barguigner",
    "barguignèrent": "barguigner",
    "barguigné": "barguigner",
    "barigoules": "barigoule",
    "barillets": "barillet",
    "barils": "baril",
    "bariola": "barioler",
    "bariolages": "bariolage",
    "bariolai": "barioler",
    "bariolaient": "barioler",
    "bariolais": "barioler",
    "bariolait": "barioler",
    "bariolant": "barioler",
    "bariolas": "barioler",
    "bariolasse": "barioler",
    "bariolassent": "barioler",
    "bariolasses": "barioler",
    "bariolassiez": "barioler",
    "bariolassions": "barioler",
    "bariole": "barioler",
    "bariolent": "barioler",
    "bariolera": "barioler",
    "bariolerai": "barioler",
    "barioleraient": "barioler",
    "bariolerais": "barioler",
    "bariolerait": "barioler",
    "barioleras": "barioler",
    "bariolerez": "barioler",
    "barioleriez": "barioler",
    "bariolerions": "barioler",
    "bariolerons": "barioler",
    "barioleront": "barioler",
    "barioles": "barioler",
    "bariolez": "barioler",
    "barioliez": "barioler",
    "bariolions": "barioler",
    "bariolons": "barioler",
    "bariolures": "bariolure",
    "bariolâmes": "barioler",
    "bariolât": "barioler",
    "bariolâtes": "barioler",
    "bariolèrent": "barioler",
    "bariolé": "barioler",
    "bariolée": "barioler",
    "bariolées": "barioler",
    "bariolés": "barioler",
    "barjes": "barje",
    "barjos": "barjo",
    "barjots": "barjot",
    "barlongs": "barlong",
    "barlongue": "barlong",
    "barlongues": "barlong",
    "barmaid": "barman",
    "barmaids": "barman",
    "barmans": "barman",
    "barmen": "barman",
    "baromètres": "baromètre",
    "baronets": "baronet",
    "baronnait": "baronner",
    "baronne": "baron",
    "baronnes": "baron",
    "baronnets": "baronnet",
    "baronnez": "baronner",
    "baronnies": "baronnie",
    "barons": "baron",
    "baroques": "baroque",
    "baroudeurs": "baroudeur",
    "baroudeuse": "baroudeur",
    "barouds": "baroud",
    "baroudé": "barouder",
    "baroufs": "barouf",
    "barques": "barque",
    "barquettes": "barquette",
    "barra": "barrer",
    "barracudas": "barracuda",
    "barrages": "barrage",
    "barrai": "barrer",
    "barraient": "barrer",
    "barrais": "barrer",
    "barrait": "barrer",
    "barrant": "barrer",
    "barras": "barrer",
    "barrasse": "barrer",
    "barrassent": "barrer",
    "barrasses": "barrer",
    "barrassiez": "barrer",
    "barrassions": "barrer",
    "barre": "barrer",
    "barreaudées": "barreaudé",
    "barreaux": "barreau",
    "barrent": "barrer",
    "barrera": "barrer",
    "barrerai": "barrer",
    "barreraient": "barrer",
    "barrerais": "barrer",
    "barrerait": "barrer",
    "barreras": "barrer",
    "barrerez": "barrer",
    "barreriez": "barrer",
    "barrerions": "barrer",
    "barrerons": "barrer",
    "barreront": "barrer",
    "barres": "barrer",
    "barrettes": "barrette",
    "barreurs": "barreur",
    "barreuse": "barreur",
    "barrez": "barrer",
    "barri": "barrir",
    "barricada": "barricader",
    "barricadai": "barricader",
    "barricadaient": "barricader",
    "barricadait": "barricader",
    "barricade": "barricader",
    "barricadent": "barricader",
    "barricaderait": "barricader",
    "barricades": "barricader",
    "barricadez": "barricader",
    "barricadières": "barricadier",
    "barricadons": "barricader",
    "barricadèrent": "barricader",
    "barricadé": "barricader",
    "barricadée": "barricader",
    "barricadées": "barricader",
    "barricadés": "barricader",
    "barriez": "barrer",
    "barrions": "barrer",
    "barriques": "barrique",
    "barrira": "barrir",
    "barrirai": "barrir",
    "barriraient": "barrir",
    "barrirais": "barrir",
    "barrirait": "barrir",
    "barriras": "barrir",
    "barrirent": "barrir",
    "barrirez": "barrir",
    "barririez": "barrir",
    "barririons": "barrir",
    "barrirons": "barrir",
    "barriront": "barrir",
    "barris": "barrir",
    "barrissaient": "barrir",
    "barrissais": "barrir",
    "barrissait": "barrir",
    "barrissant": "barrir",
    "barrisse": "barrir",
    "barrissements": "barrissement",
    "barrissent": "barrir",
    "barrisses": "barrir",
    "barrissez": "barrir",
    "barrissiez": "barrir",
    "barrissions": "barrir",
    "barrissons": "barrir",
    "barristes": "barriste",
    "barrit": "barrir",
    "barrières": "barrière",
    "barrons": "barrer",
    "barrâmes": "barrer",
    "barrât": "barrer",
    "barrâtes": "barrer",
    "barrèrent": "barrer",
    "barré": "barrer",
    "barrée": "barrer",
    "barrées": "barrer",
    "barrés": "barrer",
    "barrîmes": "barrir",
    "barrît": "barrir",
    "barrîtes": "barrir",
    "bars": "bar",
    "bartavelles": "bartavelle",
    "barytonnant": "barytonner",
    "barytons": "baryton",
    "baryums": "baryum",
    "barèmes": "barème",
    "barêmes": "barême",
    "bas-bleus": "bas-bleu",
    "bas-côtés": "bas-côté",
    "bas-fonds": "bas-fond",
    "bas-jointée": "bas-jointé",
    "bas-jointées": "bas-jointé",
    "bas-jointés": "bas-jointé",
    "bas-reliefs": "bas-relief",
    "bas-ventres": "bas-ventre",
    "basa": "baser",
    "basai": "baser",
    "basaient": "baser",
    "basais": "baser",
    "basait": "baser",
    "basale": "basal",
    "basales": "basal",
    "basaltes": "basalte",
    "basanes": "basane",
    "basant": "baser",
    "basané": "basaner",
    "basanée": "basané",
    "basanées": "basaner",
    "basanés": "basaner",
    "basas": "baser",
    "basasse": "baser",
    "basassent": "baser",
    "basasses": "baser",
    "basassiez": "baser",
    "basassions": "baser",
    "basaux": "basal",
    "bascula": "basculer",
    "basculai": "basculer",
    "basculaient": "basculer",
    "basculais": "basculer",
    "basculait": "basculer",
    "basculant": "basculer",
    "basculante": "basculant",
    "basculants": "basculant",
    "basculas": "basculer",
    "basculasse": "basculer",
    "basculassent": "basculer",
    "basculasses": "basculer",
    "basculassiez": "basculer",
    "basculassions": "basculer",
    "bascule": "basculer",
    "basculements": "basculement",
    "basculent": "basculer",
    "basculera": "basculer",
    "basculerai": "basculer",
    "basculeraient": "basculer",
    "basculerais": "basculer",
    "basculerait": "basculer",
    "basculeras": "basculer",
    "basculerez": "basculer",
    "basculeriez": "basculer",
    "basculerions": "basculer",
    "basculerons": "basculer",
    "basculeront": "basculer",
    "bascules": "basculer",
    "basculez": "basculer",
    "basculiez": "basculer",
    "basculions": "basculer",
    "basculons": "basculer",
    "basculâmes": "basculer",
    "basculât": "basculer",
    "basculâtes": "basculer",
    "basculèrent": "basculer",
    "basculé": "basculer",
    "basculée": "basculer",
    "basculées": "basculer",
    "basculés": "basculer",
    "base": "baser",
    "base-balls": "base-ball",
    "baseballs": "baseball",
    "basent": "baser",
    "basera": "baser",
    "baserai": "baser",
    "baseraient": "baser",
    "baserais": "baser",
    "baserait": "baser",
    "baseras": "baser",
    "baserez": "baser",
    "baseriez": "baser",
    "baserions": "baser",
    "baserons": "baser",
    "baseront": "baser",
    "bases": "baser",
    "basez": "baser",
    "basiez": "baser",
    "basilicale": "basilical",
    "basilicales": "basilical",
    "basilicaux": "basilical",
    "basilics": "basilic",
    "basiliques": "basilique",
    "basions": "baser",
    "basiques": "basique",
    "basket-balls": "basket-ball",
    "baskets": "basket",
    "basketteurs": "basketteur",
    "basketteuse": "basketteur",
    "basketteuses": "basketteur",
    "basoches": "basoche",
    "basons": "baser",
    "basquaise": "basquais",
    "basques": "basque",
    "bassas": "bassa",
    "basse": "bas",
    "basses": "basse",
    "basses-cours": "basse-cour",
    "basses-fosses": "basse-fosse",
    "basses-tailles": "basse-taille",
    "bassesses": "bassesse",
    "bassets": "basset",
    "bassina": "bassiner",
    "bassinai": "bassiner",
    "bassinaient": "bassiner",
    "bassinais": "bassiner",
    "bassinait": "bassiner",
    "bassinant": "bassiner",
    "bassinas": "bassiner",
    "bassinasse": "bassiner",
    "bassinassent": "bassiner",
    "bassinasses": "bassiner",
    "bassinassiez": "bassiner",
    "bassinassions": "bassiner",
    "bassine": "bassiner",
    "bassinent": "bassiner",
    "bassinera": "bassiner",
    "bassinerai": "bassiner",
    "bassineraient": "bassiner",
    "bassinerais": "bassiner",
    "bassinerait": "bassiner",
    "bassineras": "bassiner",
    "bassinerez": "bassiner",
    "bassineriez": "bassiner",
    "bassinerions": "bassiner",
    "bassinerons": "bassiner",
    "bassineront": "bassiner",
    "bassines": "bassiner",
    "bassinez": "bassiner",
    "bassiniez": "bassiner",
    "bassinions": "bassiner",
    "bassinoires": "bassinoire",
    "bassinons": "bassiner",
    "bassins": "bassin",
    "bassinâmes": "bassiner",
    "bassinât": "bassiner",
    "bassinâtes": "bassiner",
    "bassinèrent": "bassiner",
    "bassiné": "bassiner",
    "bassinée": "bassiner",
    "bassinées": "bassiner",
    "bassinés": "bassiner",
    "bassistes": "bassiste",
    "bassons": "basson",
    "basta": "baster",
    "bastides": "bastide",
    "bastilles": "bastille",
    "bastingages": "bastingage",
    "bastionnée": "bastionner",
    "bastions": "bastion",
    "bastonnades": "bastonnade",
    "bastonne": "bastonner",
    "bastonnent": "bastonner",
    "bastonneurs": "bastonneur",
    "bastonné": "bastonner",
    "bastonnée": "bastonner",
    "bastonnés": "bastonner",
    "bastons": "baston",
    "bastringues": "bastringue",
    "basâmes": "baser",
    "basât": "baser",
    "basâtes": "baser",
    "basèrent": "baser",
    "basé": "baser",
    "basée": "baser",
    "basées": "baser",
    "basés": "baser",
    "bat": "battre",
    "batailla": "batailler",
    "bataillai": "batailler",
    "bataillaient": "batailler",
    "bataillais": "batailler",
    "bataillait": "batailler",
    "bataillant": "batailler",
    "bataillas": "batailler",
    "bataillasse": "batailler",
    "bataillassent": "batailler",
    "bataillasses": "batailler",
    "bataillassiez": "batailler",
    "bataillassions": "batailler",
    "bataille": "batailler",
    "bataillent": "batailler",
    "bataillera": "batailler",
    "bataillerai": "batailler",
    "batailleraient": "batailler",
    "bataillerais": "batailler",
    "bataillerait": "batailler",
    "batailleras": "batailler",
    "bataillerez": "batailler",
    "batailleriez": "batailler",
    "bataillerions": "batailler",
    "bataillerons": "batailler",
    "batailleront": "batailler",
    "batailles": "batailler",
    "batailleurs": "batailleur",
    "batailleuse": "batailleur",
    "batailleuses": "batailleur",
    "bataillez": "batailler",
    "batailliez": "batailler",
    "bataillions": "batailler",
    "bataillonnaires": "bataillonnaire",
    "bataillons": "bataillon",
    "bataillâmes": "batailler",
    "bataillât": "batailler",
    "bataillâtes": "batailler",
    "bataillèrent": "batailler",
    "bataillé": "batailler",
    "bataillée": "batailler",
    "bataillées": "batailler",
    "bataillés": "batailler",
    "batardeaux": "batardeau",
    "bataves": "batave",
    "batavias": "batavia",
    "bateaux": "bateau",
    "bateaux-feux": "bateau-feu",
    "bateaux-lavoirs": "bateau-lavoir",
    "bateaux-mouches": "bateau-mouche",
    "bateaux-pompes": "bateau-pompe",
    "batelets": "batelet",
    "bateleurs": "bateleur",
    "bateleuse": "bateleur",
    "bateleuses": "bateleur",
    "bateliers": "batelier",
    "batelière": "batelier",
    "batelières": "batelier",
    "batelleries": "batellerie",
    "bathyale": "bathyal",
    "bathyales": "bathyal",
    "bathyaux": "bathyal",
    "bathyscaphes": "bathyscaphe",
    "batifola": "batifoler",
    "batifolages": "batifolage",
    "batifolai": "batifoler",
    "batifolaient": "batifoler",
    "batifolais": "batifoler",
    "batifolait": "batifoler",
    "batifolant": "batifoler",
    "batifolas": "batifoler",
    "batifolasse": "batifoler",
    "batifolassent": "batifoler",
    "batifolasses": "batifoler",
    "batifolassiez": "batifoler",
    "batifolassions": "batifoler",
    "batifole": "batifoler",
    "batifolent": "batifoler",
    "batifolera": "batifoler",
    "batifolerai": "batifoler",
    "batifoleraient": "batifoler",
    "batifolerais": "batifoler",
    "batifolerait": "batifoler",
    "batifoleras": "batifoler",
    "batifolerez": "batifoler",
    "batifoleriez": "batifoler",
    "batifolerions": "batifoler",
    "batifolerons": "batifoler",
    "batifoleront": "batifoler",
    "batifoles": "batifoler",
    "batifoleurs": "batifoleur",
    "batifolez": "batifoler",
    "batifoliez": "batifoler",
    "batifolions": "batifoler",
    "batifolons": "batifoler",
    "batifolâmes": "batifoler",
    "batifolât": "batifoler",
    "batifolâtes": "batifoler",
    "batifolèrent": "batifoler",
    "batifolé": "batifoler",
    "batistes": "batiste",
    "batracienne": "batracien",
    "batraciens": "batracien",
    "bats": "battre",
    "battages": "battage",
    "battaient": "battre",
    "battais": "battre",
    "battait": "battre",
    "battant": "battre",
    "battante": "battant",
    "battantes": "battant",
    "battants": "battant",
    "batte": "battre",
    "battements": "battement",
    "battent": "battre",
    "batteries": "batterie",
    "battes": "battre",
    "batteurs": "batteur",
    "batteuse": "batteur",
    "batteuses": "batteur",
    "battez": "battre",
    "battiez": "battre",
    "battions": "battre",
    "battirent": "battre",
    "battis": "battre",
    "battisse": "battre",
    "battissent": "battre",
    "battisses": "battre",
    "battissiez": "battre",
    "battissions": "battre",
    "battit": "battre",
    "battoires": "battoire",
    "battoirs": "battoir",
    "battons": "battre",
    "battra": "battre",
    "battrai": "battre",
    "battraient": "battre",
    "battrais": "battre",
    "battrait": "battre",
    "battras": "battre",
    "battrez": "battre",
    "battriez": "battre",
    "battrions": "battre",
    "battrons": "battre",
    "battront": "battre",
    "battu": "battre",
    "battue": "battu",
    "battues": "battue",
    "battus": "battu",
    "battîmes": "battre",
    "battît": "battre",
    "battîtes": "battre",
    "baudelairiennes": "baudelairien",
    "baudelairiens": "baudelairien",
    "baudets": "baudet",
    "baudriers": "baudrier",
    "baudroies": "baudroie",
    "baudruches": "baudruche",
    "bauges": "bauge",
    "baugé": "bauger",
    "baumes": "baume",
    "baumiers": "baumier",
    "baux": "bau",
    "bauxites": "bauxite",
    "bava": "baver",
    "bavai": "baver",
    "bavaient": "baver",
    "bavais": "baver",
    "bavait": "baver",
    "bavant": "baver",
    "bavarda": "bavarder",
    "bavardages": "bavardage",
    "bavardai": "bavarder",
    "bavardaient": "bavarder",
    "bavardais": "bavarder",
    "bavardait": "bavarder",
    "bavardant": "bavarder",
    "bavardas": "bavarder",
    "bavardasse": "bavarder",
    "bavardassent": "bavarder",
    "bavardasses": "bavarder",
    "bavardassiez": "bavarder",
    "bavardassions": "bavarder",
    "bavarde": "bavarder",
    "bavardent": "bavarder",
    "bavardera": "bavarder",
    "bavarderai": "bavarder",
    "bavarderaient": "bavarder",
    "bavarderais": "bavarder",
    "bavarderait": "bavarder",
    "bavarderas": "bavarder",
    "bavarderez": "bavarder",
    "bavarderiez": "bavarder",
    "bavarderions": "bavarder",
    "bavarderons": "bavarder",
    "bavarderont": "bavarder",
    "bavardes": "bavarder",
    "bavardez": "bavarder",
    "bavardiez": "bavarder",
    "bavardions": "bavarder",
    "bavardons": "bavarder",
    "bavards": "bavard",
    "bavardâmes": "bavarder",
    "bavardât": "bavarder",
    "bavardâtes": "bavarder",
    "bavardèrent": "bavarder",
    "bavardé": "bavarder",
    "bavaroise": "bavarois",
    "bavaroises": "bavaroise",
    "bavas": "baver",
    "bavassaient": "bavasser",
    "bavassait": "bavasser",
    "bavassant": "bavasser",
    "bavasse": "baver",
    "bavassent": "baver",
    "bavasses": "baver",
    "bavassiez": "baver",
    "bavassions": "baver",
    "bavassé": "bavasser",
    "bave": "baver",
    "bavent": "baver",
    "bavera": "baver",
    "baverai": "baver",
    "baveraient": "baver",
    "baverais": "baver",
    "baverait": "baver",
    "baveras": "baver",
    "baverez": "baver",
    "baveriez": "baver",
    "baverions": "baver",
    "baverons": "baver",
    "baveront": "baver",
    "baves": "baver",
    "bavettes": "bavette",
    "baveurs": "baveur",
    "baveuse": "baveux",
    "baveuses": "baveux",
    "bavez": "baver",
    "baviez": "baver",
    "bavions": "baver",
    "bavoirs": "bavoir",
    "bavons": "baver",
    "bavotait": "bavoter",
    "bavotant": "bavoter",
    "bavures": "bavure",
    "bavâmes": "baver",
    "bavât": "baver",
    "bavâtes": "baver",
    "bavèrent": "baver",
    "bavé": "baver",
    "bavée": "baver",
    "bavées": "baver",
    "bavés": "baver",
    "baya": "bayer",
    "bayadères": "bayadère",
    "bayai": "bayer",
    "bayaient": "bayer",
    "bayais": "bayer",
    "bayait": "bayer",
    "bayant": "bayer",
    "bayas": "bayer",
    "bayasse": "bayer",
    "bayassent": "bayer",
    "bayasses": "bayer",
    "bayassiez": "bayer",
    "bayassions": "bayer",
    "baye": "bayer",
    "bayent": "bayer",
    "bayera": "bayer",
    "bayerai": "bayer",
    "bayeraient": "bayer",
    "bayerais": "bayer",
    "bayerait": "bayer",
    "bayeras": "bayer",
    "bayerez": "bayer",
    "bayeriez": "bayer",
    "bayerions": "bayer",
    "bayerons": "bayer",
    "bayeront": "bayer",
    "bayes": "bayer",
    "bayez": "bayer",
    "bayiez": "bayer",
    "bayions": "bayer",
    "bayons": "bayer",
    "bayous": "bayou",
    "bayâmes": "bayer",
    "bayât": "bayer",
    "bayâtes": "bayer",
    "bayèrent": "bayer",
    "bayé": "bayer",
    "bazarda": "bazarder",
    "bazardai": "bazarder",
    "bazardaient": "bazarder",
    "bazardais": "bazarder",
    "bazardait": "bazarder",
    "bazardant": "bazarder",
    "bazardas": "bazarder",
    "bazardasse": "bazarder",
    "bazardassent": "bazarder",
    "bazardasses": "bazarder",
    "bazardassiez": "bazarder",
    "bazardassions": "bazarder",
    "bazarde": "bazarder",
    "bazardent": "bazarder",
    "bazardera": "bazarder",
    "bazarderai": "bazarder",
    "bazarderaient": "bazarder",
    "bazarderais": "bazarder",
    "bazarderait": "bazarder",
    "bazarderas": "bazarder",
    "bazarderez": "bazarder",
    "bazarderiez": "bazarder",
    "bazarderions": "bazarder",
    "bazarderons": "bazarder",
    "bazarderont": "bazarder",
    "bazardes": "bazarder",
    "bazardez": "bazarder",
    "bazardiez": "bazarder",
    "bazardions": "bazarder",
    "bazardons": "bazarder",
    "bazardâmes": "bazarder",
    "bazardât": "bazarder",
    "bazardâtes": "bazarder",
    "bazardèrent": "bazarder",
    "bazardé": "bazarder",
    "bazardée": "bazarder",
    "bazardées": "bazarder",
    "bazardés": "bazarder",
    "bazars": "bazar",
    "bazookas": "bazooka",
    "baïonnettes": "baïonnette",
    "bds": "bd",
    "beagles": "beagle",
    "beatniks": "beatnik",
    "beauceronne": "beauceron",
    "beauceronnes": "beauceron",
    "beaucerons": "beauceron",
    "beaufs": "beauf",
    "beauprés": "beaupré",
    "beautés": "beauté",
    "beaux": "beau",
    "beaux-fils": "beau-fils",
    "beaux-frères": "beau-frère",
    "beaux-pères": "beau-père",
    "becfigues": "becfigue",
    "becquant": "becquer",
    "becqueta": "becqueter",
    "becquetai": "becqueter",
    "becquetaient": "becqueter",
    "becquetais": "becqueter",
    "becquetait": "becqueter",
    "becquetant": "becqueter",
    "becquetas": "becqueter",
    "becquetasse": "becqueter",
    "becquetassent": "becqueter",
    "becquetasses": "becqueter",
    "becquetassiez": "becqueter",
    "becquetassions": "becqueter",
    "becquetez": "becqueter",
    "becquetiez": "becqueter",
    "becquetions": "becqueter",
    "becquetons": "becqueter",
    "becquets": "becquet",
    "becquette": "becqueter",
    "becquettent": "becqueter",
    "becquettera": "becqueter",
    "becquetterai": "becqueter",
    "becquetteraient": "becqueter",
    "becquetterais": "becqueter",
    "becquetterait": "becqueter",
    "becquetteras": "becqueter",
    "becquetterez": "becqueter",
    "becquetteriez": "becqueter",
    "becquetterions": "becqueter",
    "becquetterons": "becqueter",
    "becquetteront": "becqueter",
    "becquettes": "becqueter",
    "becquetâmes": "becqueter",
    "becquetât": "becqueter",
    "becquetâtes": "becqueter",
    "becquetèrent": "becqueter",
    "becqueté": "becqueter",
    "becquetée": "becqueter",
    "becquetées": "becqueter",
    "becquetés": "becqueter",
    "becqué": "becquer",
    "becquées": "becquée",
    "becs": "bec",
    "becs-croisés": "bec-croisé",
    "becs-de-cane": "bec-de-cane",
    "becs-de-corbeau": "bec-de-corbeau",
    "becs-de-corbin": "bec-de-corbin",
    "becs-de-lièvre": "bec-de-lièvre",
    "becs-de-perroquet": "bec-de-perroquet",
    "becs-fins": "bec-fin",
    "becta": "becter",
    "bectai": "becter",
    "bectaient": "becter",
    "bectais": "becter",
    "bectait": "becter",
    "bectant": "becter",
    "bectas": "becter",
    "bectasse": "becter",
    "bectassent": "becter",
    "bectasses": "becter",
    "bectassiez": "becter",
    "bectassions": "becter",
    "becte": "becter",
    "bectent": "becter",
    "bectera": "becter",
    "becterai": "becter",
    "becteraient": "becter",
    "becterais": "becter",
    "becterait": "becter",
    "becteras": "becter",
    "becterez": "becter",
    "becteriez": "becter",
    "becterions": "becter",
    "becterons": "becter",
    "becteront": "becter",
    "bectes": "becter",
    "bectez": "becter",
    "bectiez": "becter",
    "bections": "becter",
    "bectons": "becter",
    "bectâmes": "becter",
    "bectât": "becter",
    "bectâtes": "becter",
    "bectèrent": "becter",
    "becté": "becter",
    "bectée": "becter",
    "bectées": "becter",
    "bectés": "becter",
    "bedaines": "bedaine",
    "bedeaux": "bedeau",
    "bedonna": "bedonner",
    "bedonnai": "bedonner",
    "bedonnaient": "bedonner",
    "bedonnais": "bedonner",
    "bedonnait": "bedonner",
    "bedonnant": "bedonner",
    "bedonnante": "bedonnant",
    "bedonnantes": "bedonnant",
    "bedonnants": "bedonnant",
    "bedonnas": "bedonner",
    "bedonnasse": "bedonner",
    "bedonnassent": "bedonner",
    "bedonnasses": "bedonner",
    "bedonnassiez": "bedonner",
    "bedonnassions": "bedonner",
    "bedonne": "bedonner",
    "bedonnent": "bedonner",
    "bedonnera": "bedonner",
    "bedonnerai": "bedonner",
    "bedonneraient": "bedonner",
    "bedonnerais": "bedonner",
    "bedonnerait": "bedonner",
    "bedonneras": "bedonner",
    "bedonnerez": "bedonner",
    "bedonneriez": "bedonner",
    "bedonnerions": "bedonner",
    "bedonnerons": "bedonner",
    "bedonneront": "bedonner",
    "bedonnes": "bedonner",
    "bedonnez": "bedonner",
    "bedonniez": "bedonner",
    "bedonnions": "bedonner",
    "bedonnons": "bedonner",
    "bedonnâmes": "bedonner",
    "bedonnât": "bedonner",
    "bedonnâtes": "bedonner",
    "bedonnèrent": "bedonner",
    "bedonné": "bedonner",
    "bedonnée": "bedonner",
    "bedonnées": "bedonner",
    "bedonnés": "bedonner",
    "bedons": "bedon",
    "beefsteaks": "beefsteak",
    "beffrois": "beffroi",
    "beigeasses": "beigeasse",
    "beiges": "beige",
    "beignes": "beigne",
    "beignets": "beignet",
    "bel": "beau",
    "belettes": "belette",
    "belges": "belge",
    "belgicains": "belgicain",
    "belladones": "belladone",
    "belle": "beau",
    "belle-mère": "beau-père",
    "belle-soeur": "beau-frère",
    "belles": "belle",
    "belles-dames": "belle-dame",
    "belles-de-jour": "belle-de-jour",
    "belles-de-nuit": "belle-de-nuit",
    "belles-familles": "belle-famille",
    "belles-filles": "belle-fille",
    "belles-lettres": "belle-lettre",
    "belles-mères": "belle-mère",
    "belles-soeurs": "belle-soeur",
    "bellevilloise": "bellevillois",
    "bellicistes": "belliciste",
    "belligérante": "belligérant",
    "belligérantes": "belligérant",
    "belligérants": "belligérant",
    "belliqueuse": "belliqueux",
    "belliqueuses": "belliqueux",
    "bellâtres": "bellâtre",
    "belons": "belon",
    "belotes": "belote",
    "beloteurs": "beloteur",
    "belotte": "belotter",
    "belvédères": "belvédère",
    "bengalis": "bengali",
    "benjamine": "benjamin",
    "benjamines": "benjamin",
    "benjamins": "benjamin",
    "benjoins": "benjoin",
    "bennes": "benne",
    "benoîte": "benoît",
    "benoîtes": "benoît",
    "benoîts": "benoît",
    "benthiques": "benthique",
    "benzidines": "benzidine",
    "benzines": "benzine",
    "benzènes": "benzène",
    "benêts": "benêt",
    "berbères": "berbère",
    "bercails": "bercail",
    "berce": "bercer",
    "berceaux": "berceau",
    "bercements": "bercement",
    "bercent": "bercer",
    "bercera": "bercer",
    "bercerai": "bercer",
    "berceraient": "bercer",
    "bercerais": "bercer",
    "bercerait": "bercer",
    "berceras": "bercer",
    "bercerez": "bercer",
    "berceriez": "bercer",
    "bercerions": "bercer",
    "bercerons": "bercer",
    "berceront": "bercer",
    "berces": "bercer",
    "berceurs": "berceur",
    "berceuse": "berceur",
    "berceuses": "berceur",
    "bercez": "bercer",
    "berciez": "bercer",
    "bercions": "bercer",
    "bercèrent": "bercer",
    "bercé": "bercer",
    "bercée": "bercer",
    "bercées": "bercer",
    "bercés": "bercer",
    "bergamasques": "bergamasque",
    "bergamotes": "bergamote",
    "bergeries": "bergerie",
    "bergeronnettes": "bergeronnette",
    "bergers": "berger",
    "berges": "berge",
    "bergère": "berger",
    "bergères": "berger",
    "berlines": "berline",
    "berlingots": "berlingot",
    "berlinoise": "berlinois",
    "berlinoises": "berlinois",
    "berlues": "berlue",
    "berlurais": "berlurer",
    "berlurait": "berlurer",
    "berlurent": "berlurer",
    "berlures": "berlure",
    "berluré": "berlurer",
    "berlurée": "berlurer",
    "bermes": "berme",
    "bermudas": "bermuda",
    "berna": "berner",
    "bernaches": "bernache",
    "bernai": "berner",
    "bernaient": "berner",
    "bernais": "berner",
    "bernait": "berner",
    "bernant": "berner",
    "bernardines": "bernardin",
    "bernas": "berner",
    "bernasse": "berner",
    "bernassent": "berner",
    "bernasses": "berner",
    "bernassiez": "berner",
    "bernassions": "berner",
    "berne": "berner",
    "bernent": "berner",
    "bernera": "berner",
    "bernerai": "berner",
    "berneraient": "berner",
    "bernerais": "berner",
    "bernerait": "berner",
    "berneras": "berner",
    "bernerez": "berner",
    "berneriez": "berner",
    "bernerions": "berner",
    "bernerons": "berner",
    "berneront": "berner",
    "bernes": "berner",
    "bernez": "berner",
    "bernicles": "bernicle",
    "berniez": "berner",
    "bernions": "berner",
    "berniques": "bernique",
    "bernoise": "bernois",
    "bernoises": "bernois",
    "bernons": "berner",
    "bernâmes": "berner",
    "bernât": "berner",
    "bernâtes": "berner",
    "bernèrent": "berner",
    "berné": "berner",
    "bernée": "berner",
    "bernées": "berner",
    "bernés": "berner",
    "berrichonne": "berrichon",
    "bersagliers": "bersaglier",
    "berthas": "bertha",
    "berça": "bercer",
    "berçai": "bercer",
    "berçaient": "bercer",
    "berçais": "bercer",
    "berçait": "bercer",
    "berçant": "bercer",
    "berças": "bercer",
    "berçasse": "bercer",
    "berçassent": "bercer",
    "berçasses": "bercer",
    "berçassiez": "bercer",
    "berçassions": "bercer",
    "berçons": "bercer",
    "berçâmes": "bercer",
    "berçât": "bercer",
    "berçâtes": "bercer",
    "besaces": "besace",
    "besaiguës": "besaiguë",
    "besants": "besant",
    "besogna": "besogner",
    "besognaient": "besogner",
    "besognais": "besogner",
    "besognait": "besogner",
    "besognant": "besogner",
    "besogne": "besogner",
    "besognent": "besogner",
    "besogneras": "besogner",
    "besognes": "besogne",
    "besogneuse": "besogneux",
    "besogneuses": "besogneux",
    "besognèrent": "besogner",
    "besogné": "besogner",
    "besoins": "besoin",
    "bessonne": "besson",
    "bessonnes": "besson",
    "bessons": "besson",
    "best-sellers": "best-seller",
    "bestiaires": "bestiaire",
    "bestiale": "bestial",
    "bestiales": "bestial",
    "bestialités": "bestialité",
    "bestiaux": "bestiau",
    "bestioles": "bestiole",
    "betteraves": "betterave",
    "betteraviers": "betteravier",
    "betteravière": "betteravier",
    "betteravières": "betteravier",
    "bettes": "bette",
    "beugla": "beugler",
    "beuglai": "beugler",
    "beuglaient": "beugler",
    "beuglais": "beugler",
    "beuglait": "beugler",
    "beuglant": "beugler",
    "beuglante": "beuglant",
    "beuglantes": "beuglant",
    "beuglants": "beuglant",
    "beuglas": "beugler",
    "beuglasse": "beugler",
    "beuglassent": "beugler",
    "beuglasses": "beugler",
    "beuglassiez": "beugler",
    "beuglassions": "beugler",
    "beugle": "beugler",
    "beuglements": "beuglement",
    "beuglent": "beugler",
    "beuglera": "beugler",
    "beuglerai": "beugler",
    "beugleraient": "beugler",
    "beuglerais": "beugler",
    "beuglerait": "beugler",
    "beugleras": "beugler",
    "beuglerez": "beugler",
    "beugleriez": "beugler",
    "beuglerions": "beugler",
    "beuglerons": "beugler",
    "beugleront": "beugler",
    "beugles": "beugler",
    "beuglez": "beugler",
    "beugliez": "beugler",
    "beuglions": "beugler",
    "beuglons": "beugler",
    "beuglâmes": "beugler",
    "beuglât": "beugler",
    "beuglâtes": "beugler",
    "beuglèrent": "beugler",
    "beuglé": "beugler",
    "beuglée": "beugler",
    "beuglées": "beugler",
    "beuglés": "beugler",
    "beurra": "beurrer",
    "beurrai": "beurrer",
    "beurraient": "beurrer",
    "beurrais": "beurrer",
    "beurrait": "beurrer",
    "beurrant": "beurrer",
    "beurras": "beurrer",
    "beurrasse": "beurrer",
    "beurrassent": "beurrer",
    "beurrasses": "beurrer",
    "beurrassiez": "beurrer",
    "beurrassions": "beurrer",
    "beurre": "beurrer",
    "beurrent": "beurrer",
    "beurrera": "beurrer",
    "beurrerai": "beurrer",
    "beurreraient": "beurrer",
    "beurrerais": "beurrer",
    "beurrerait": "beurrer",
    "beurreras": "beurrer",
    "beurrerez": "beurrer",
    "beurreriez": "beurrer",
    "beurrerions": "beurrer",
    "beurrerons": "beurrer",
    "beurreront": "beurrer",
    "beurres": "beurrer",
    "beurrez": "beurrer",
    "beurriez": "beurrer",
    "beurrions": "beurrer",
    "beurrons": "beurrer",
    "beurrâmes": "beurrer",
    "beurrât": "beurrer",
    "beurrâtes": "beurrer",
    "beurrèrent": "beurrer",
    "beurré": "beurrer",
    "beurrée": "beurrer",
    "beurrées": "beurrer",
    "beurrés": "beurrer",
    "beurs": "beur",
    "beuveries": "beuverie",
    "beylicale": "beylical",
    "beylicales": "beylical",
    "beylicaux": "beylical",
    "beys": "bey",
    "biaisa": "biaiser",
    "biaisai": "biaiser",
    "biaisaient": "biaiser",
    "biaisais": "biaiser",
    "biaisait": "biaiser",
    "biaisant": "biaiser",
    "biaisas": "biaiser",
    "biaisasse": "biaiser",
    "biaisassent": "biaiser",
    "biaisasses": "biaiser",
    "biaisassiez": "biaiser",
    "biaisassions": "biaiser",
    "biaise": "biaiser",
    "biaisements": "biaisement",
    "biaisent": "biaiser",
    "biaisera": "biaiser",
    "biaiserai": "biaiser",
    "biaiseraient": "biaiser",
    "biaiserais": "biaiser",
    "biaiserait": "biaiser",
    "biaiseras": "biaiser",
    "biaiserez": "biaiser",
    "biaiseriez": "biaiser",
    "biaiserions": "biaiser",
    "biaiserons": "biaiser",
    "biaiseront": "biaiser",
    "biaises": "biaiser",
    "biaisez": "biaiser",
    "biaisiez": "biaiser",
    "biaisions": "biaiser",
    "biaisons": "biaiser",
    "biaisâmes": "biaiser",
    "biaisât": "biaiser",
    "biaisâtes": "biaiser",
    "biaisèrent": "biaiser",
    "biaisé": "biaiser",
    "biaisée": "biaiser",
    "biaisées": "biaiser",
    "biaisés": "biaiser",
    "biannuelle": "biannuel",
    "biannuelles": "biannuel",
    "biannuels": "biannuel",
    "biaurale": "biaural",
    "biaurales": "biaural",
    "biauraux": "biaural",
    "bibelots": "bibelot",
    "biberonnait": "biberonner",
    "biberonne": "biberonner",
    "biberonneurs": "biberonneur",
    "biberonné": "biberonner",
    "biberons": "biberon",
    "bibines": "bibine",
    "bibis": "bibi",
    "bibles": "bible",
    "bibliographies": "bibliographie",
    "bibliographiques": "bibliographique",
    "bibliophiles": "bibliophile",
    "bibliothèques": "bibliothèque",
    "bibliothécaires": "bibliothécaire",
    "bibliques": "biblique",
    "bicamérale": "bicaméral",
    "bicarbonates": "bicarbonate",
    "bicentenaires": "bicentenaire",
    "bichais": "bicher",
    "bichait": "bicher",
    "bichant": "bicher",
    "biche": "bicher",
    "biches": "bicher",
    "bichez": "bicher",
    "bichonna": "bichonner",
    "bichonnai": "bichonner",
    "bichonnaient": "bichonner",
    "bichonnais": "bichonner",
    "bichonnait": "bichonner",
    "bichonnant": "bichonner",
    "bichonnas": "bichonner",
    "bichonnasse": "bichonner",
    "bichonnassent": "bichonner",
    "bichonnasses": "bichonner",
    "bichonnassiez": "bichonner",
    "bichonnassions": "bichonner",
    "bichonne": "bichonner",
    "bichonnent": "bichonner",
    "bichonnera": "bichonner",
    "bichonnerai": "bichonner",
    "bichonneraient": "bichonner",
    "bichonnerais": "bichonner",
    "bichonnerait": "bichonner",
    "bichonneras": "bichonner",
    "bichonnerez": "bichonner",
    "bichonneriez": "bichonner",
    "bichonnerions": "bichonner",
    "bichonnerons": "bichonner",
    "bichonneront": "bichonner",
    "bichonnes": "bichonner",
    "bichonnez": "bichonner",
    "bichonniez": "bichonner",
    "bichonnions": "bichonner",
    "bichonnons": "bichonner",
    "bichonnâmes": "bichonner",
    "bichonnât": "bichonner",
    "bichonnâtes": "bichonner",
    "bichonnèrent": "bichonner",
    "bichonné": "bichonner",
    "bichonnée": "bichonner",
    "bichonnées": "bichonner",
    "bichonnés": "bichonner",
    "biché": "bicher",
    "biclous": "biclou",
    "bicolores": "bicolore",
    "biconvexes": "biconvexe",
    "bicoques": "bicoque",
    "bicornes": "bicorne",
    "bicots": "bicot",
    "biculturelle": "biculturel",
    "bicycles": "bicycle",
    "bicyclettes": "bicyclette",
    "bicéphales": "bicéphale",
    "bidasses": "bidasse",
    "bides": "bide",
    "bidets": "bidet",
    "bidoches": "bidoche",
    "bidonnaient": "bidonner",
    "bidonnais": "bidonner",
    "bidonnait": "bidonner",
    "bidonnant": "bidonner",
    "bidonnante": "bidonnant",
    "bidonne": "bidonner",
    "bidonnent": "bidonner",
    "bidonnera": "bidonner",
    "bidonnez": "bidonner",
    "bidonné": "bidonner",
    "bidonnée": "bidonner",
    "bidonnées": "bidonner",
    "bidonnés": "bidonner",
    "bidons": "bidon",
    "bidonvilles": "bidonville",
    "bidouilla": "bidouiller",
    "bidouillerai": "bidouiller",
    "bidouillé": "bidouiller",
    "bidouillée": "bidouiller",
    "bidouillés": "bidouiller",
    "bidules": "bidule",
    "biefs": "bief",
    "bielles": "bielle",
    "bien-aimée": "bien-aimé",
    "bien-aimées": "bien-aimé",
    "bien-aimés": "bien-aimé",
    "bien-disants": "bien-disant",
    "bien-fondés": "bien-fondé",
    "bien-pensante": "bien-pensant",
    "bien-pensants": "bien-pensant",
    "bien-portants": "bien-portant",
    "bienfaisances": "bienfaisance",
    "bienfaisante": "bienfaisant",
    "bienfaisantes": "bienfaisant",
    "bienfaisants": "bienfaisant",
    "bienfaiteurs": "bienfaiteur",
    "bienfaitrice": "bienfaiteur",
    "bienfaitrices": "bienfaiteur",
    "bienfaits": "bienfait",
    "bienheureuse": "bienheureux",
    "bienheureuses": "bienheureux",
    "biennale": "biennal",
    "biennales": "biennal",
    "biennaux": "biennal",
    "biens": "bien",
    "biens-fonds": "bien-fonds",
    "bienséances": "bienséance",
    "bienséante": "bienséant",
    "bienséantes": "bienséant",
    "bienséants": "bienséant",
    "bienveillances": "bienveillance",
    "bienveillante": "bienveillant",
    "bienveillantes": "bienveillant",
    "bienveillants": "bienveillant",
    "bienvenue": "bienvenu",
    "bienvenues": "bienvenue",
    "bienvenus": "bienvenu",
    "bifaces": "biface",
    "biffa": "biffer",
    "biffai": "biffer",
    "biffaient": "biffer",
    "biffais": "biffer",
    "biffait": "biffer",
    "biffant": "biffer",
    "biffas": "biffer",
    "biffasse": "biffer",
    "biffassent": "biffer",
    "biffasses": "biffer",
    "biffassiez": "biffer",
    "biffassions": "biffer",
    "biffe": "biffer",
    "biffent": "biffer",
    "biffera": "biffer",
    "bifferai": "biffer",
    "bifferaient": "biffer",
    "bifferais": "biffer",
    "bifferait": "biffer",
    "bifferas": "biffer",
    "bifferez": "biffer",
    "bifferiez": "biffer",
    "bifferions": "biffer",
    "bifferons": "biffer",
    "bifferont": "biffer",
    "biffes": "biffer",
    "biffetons": "biffeton",
    "biffez": "biffer",
    "biffiez": "biffer",
    "biffins": "biffin",
    "biffions": "biffer",
    "biffons": "biffer",
    "biffures": "biffure",
    "biffâmes": "biffer",
    "biffât": "biffer",
    "biffâtes": "biffer",
    "biffèrent": "biffer",
    "biffé": "biffer",
    "biffée": "biffer",
    "biffées": "biffer",
    "biffés": "biffer",
    "bifides": "bifide",
    "bifocale": "bifocal",
    "bifocales": "bifocal",
    "bifocaux": "bifocal",
    "bifrons": "bifron",
    "biftecks": "bifteck",
    "biftons": "bifton",
    "biftèques": "biftèque",
    "bifurcations": "bifurcation",
    "bifurqua": "bifurquer",
    "bifurquai": "bifurquer",
    "bifurquaient": "bifurquer",
    "bifurquais": "bifurquer",
    "bifurquait": "bifurquer",
    "bifurquant": "bifurquer",
    "bifurquas": "bifurquer",
    "bifurquasse": "bifurquer",
    "bifurquassent": "bifurquer",
    "bifurquasses": "bifurquer",
    "bifurquassiez": "bifurquer",
    "bifurquassions": "bifurquer",
    "bifurque": "bifurquer",
    "bifurquent": "bifurquer",
    "bifurquera": "bifurquer",
    "bifurquerai": "bifurquer",
    "bifurqueraient": "bifurquer",
    "bifurquerais": "bifurquer",
    "bifurquerait": "bifurquer",
    "bifurqueras": "bifurquer",
    "bifurquerez": "bifurquer",
    "bifurqueriez": "bifurquer",
    "bifurquerions": "bifurquer",
    "bifurquerons": "bifurquer",
    "bifurqueront": "bifurquer",
    "bifurques": "bifurquer",
    "bifurquez": "bifurquer",
    "bifurquiez": "bifurquer",
    "bifurquions": "bifurquer",
    "bifurquons": "bifurquer",
    "bifurquâmes": "bifurquer",
    "bifurquât": "bifurquer",
    "bifurquâtes": "bifurquer",
    "bifurquèrent": "bifurquer",
    "bifurqué": "bifurquer",
    "bifurquée": "bifurquer",
    "bifurquées": "bifurquer",
    "bifurqués": "bifurquer",
    "bigames": "bigame",
    "bigarades": "bigarade",
    "bigarra": "bigarrer",
    "bigarrai": "bigarrer",
    "bigarraient": "bigarrer",
    "bigarrais": "bigarrer",
    "bigarrait": "bigarrer",
    "bigarrant": "bigarrer",
    "bigarras": "bigarrer",
    "bigarrasse": "bigarrer",
    "bigarrassent": "bigarrer",
    "bigarrasses": "bigarrer",
    "bigarrassiez": "bigarrer",
    "bigarrassions": "bigarrer",
    "bigarre": "bigarrer",
    "bigarreaux": "bigarreau",
    "bigarrent": "bigarrer",
    "bigarrera": "bigarrer",
    "bigarrerai": "bigarrer",
    "bigarreraient": "bigarrer",
    "bigarrerais": "bigarrer",
    "bigarrerait": "bigarrer",
    "bigarreras": "bigarrer",
    "bigarrerez": "bigarrer",
    "bigarreriez": "bigarrer",
    "bigarrerions": "bigarrer",
    "bigarrerons": "bigarrer",
    "bigarreront": "bigarrer",
    "bigarres": "bigarrer",
    "bigarrez": "bigarrer",
    "bigarriez": "bigarrer",
    "bigarrions": "bigarrer",
    "bigarrons": "bigarrer",
    "bigarrures": "bigarrure",
    "bigarrâmes": "bigarrer",
    "bigarrât": "bigarrer",
    "bigarrâtes": "bigarrer",
    "bigarrèrent": "bigarrer",
    "bigarré": "bigarrer",
    "bigarrée": "bigarrer",
    "bigarrées": "bigarrer",
    "bigarrés": "bigarrer",
    "bighorns": "bighorn",
    "bigla": "bigler",
    "biglai": "bigler",
    "biglaient": "bigler",
    "biglais": "bigler",
    "biglait": "bigler",
    "biglant": "bigler",
    "biglas": "bigler",
    "biglasse": "bigler",
    "biglassent": "bigler",
    "biglasses": "bigler",
    "biglassiez": "bigler",
    "biglassions": "bigler",
    "bigle": "bigler",
    "biglent": "bigler",
    "biglera": "bigler",
    "biglerai": "bigler",
    "bigleraient": "bigler",
    "biglerais": "bigler",
    "biglerait": "bigler",
    "bigleras": "bigler",
    "biglerez": "bigler",
    "bigleriez": "bigler",
    "biglerions": "bigler",
    "biglerons": "bigler",
    "bigleront": "bigler",
    "bigles": "bigler",
    "bigleuse": "bigleux",
    "biglez": "bigler",
    "bigliez": "bigler",
    "biglions": "bigler",
    "biglons": "bigler",
    "biglâmes": "bigler",
    "biglât": "bigler",
    "biglâtes": "bigler",
    "biglèrent": "bigler",
    "biglé": "bigler",
    "biglée": "bigler",
    "biglées": "bigler",
    "biglés": "bigler",
    "bignolait": "bignoler",
    "bignoles": "bignole",
    "bignones": "bignone",
    "bignonias": "bignonia",
    "bigophone": "bigophoner",
    "bigophones": "bigophoner",
    "bigophoné": "bigophoner",
    "bigorna": "bigorner",
    "bigornai": "bigorner",
    "bigornaient": "bigorner",
    "bigornais": "bigorner",
    "bigornait": "bigorner",
    "bigornant": "bigorner",
    "bigornas": "bigorner",
    "bigornasse": "bigorner",
    "bigornassent": "bigorner",
    "bigornasses": "bigorner",
    "bigornassiez": "bigorner",
    "bigornassions": "bigorner",
    "bigorne": "bigorner",
    "bigorneaux": "bigorneau",
    "bigornent": "bigorner",
    "bigornera": "bigorner",
    "bigornerai": "bigorner",
    "bigorneraient": "bigorner",
    "bigornerais": "bigorner",
    "bigornerait": "bigorner",
    "bigorneras": "bigorner",
    "bigornerez": "bigorner",
    "bigorneriez": "bigorner",
    "bigornerions": "bigorner",
    "bigornerons": "bigorner",
    "bigorneront": "bigorner",
    "bigornes": "bigorner",
    "bigornez": "bigorner",
    "bigorniez": "bigorner",
    "bigornions": "bigorner",
    "bigornons": "bigorner",
    "bigornâmes": "bigorner",
    "bigornât": "bigorner",
    "bigornâtes": "bigorner",
    "bigornèrent": "bigorner",
    "bigorné": "bigorner",
    "bigornée": "bigorner",
    "bigornées": "bigorner",
    "bigornés": "bigorner",
    "bigote": "bigot",
    "bigoteries": "bigoterie",
    "bigotes": "bigot",
    "bigots": "bigot",
    "bigoudens": "bigouden",
    "bigoudis": "bigoudi",
    "bihebdomadaires": "bihebdomadaire",
    "bihoreaux": "bihoreau",
    "bijouteries": "bijouterie",
    "bijoutiers": "bijoutier",
    "bijoutière": "bijoutier",
    "bijoutières": "bijoutier",
    "bijoux": "bijou",
    "bikinis": "bikini",
    "bilais": "biler",
    "bilait": "biler",
    "bilans": "bilan",
    "bilatérale": "bilatéral",
    "bilatérales": "bilatéral",
    "bilatéraux": "bilatéral",
    "bilboquets": "bilboquet",
    "bile": "biler",
    "biles": "biler",
    "bileuse": "bileux",
    "bileuses": "bileux",
    "bilez": "biler",
    "biliaires": "biliaire",
    "bilieuse": "bilieux",
    "bilieuses": "bilieux",
    "bilingues": "bilingue",
    "billards": "billard",
    "billes": "bille",
    "billets": "billet",
    "billetteries": "billetterie",
    "billettes": "billette",
    "billevesées": "billevesée",
    "billions": "billion",
    "billons": "billon",
    "billots": "billot",
    "bills": "bill",
    "bilobée": "bilobé",
    "bimbeloteries": "bimbeloterie",
    "bimensuelle": "bimensuel",
    "bimensuelles": "bimensuel",
    "bimensuels": "bimensuel",
    "bimoteurs": "bimoteur",
    "bina": "biner",
    "binai": "biner",
    "binaient": "biner",
    "binaires": "binaire",
    "binais": "biner",
    "binait": "biner",
    "binant": "biner",
    "binas": "biner",
    "binasse": "biner",
    "binassent": "biner",
    "binasses": "biner",
    "binassiez": "biner",
    "binassions": "biner",
    "binationale": "binational",
    "binationales": "binational",
    "binationaux": "binational",
    "binaurale": "binaural",
    "binaurales": "binaural",
    "binauraux": "binaural",
    "bine": "biner",
    "binent": "biner",
    "binera": "biner",
    "binerai": "biner",
    "bineraient": "biner",
    "binerais": "biner",
    "binerait": "biner",
    "bineras": "biner",
    "binerez": "biner",
    "bineriez": "biner",
    "binerions": "biner",
    "binerons": "biner",
    "bineront": "biner",
    "bines": "biner",
    "binettes": "binette",
    "binez": "biner",
    "biniez": "biner",
    "binions": "biner",
    "binious": "biniou",
    "binoclarde": "binoclard",
    "binoclards": "binoclard",
    "binocles": "binocle",
    "binomiale": "binomial",
    "binomiales": "binomial",
    "binomiaux": "binomial",
    "binons": "biner",
    "binâmes": "biner",
    "binât": "biner",
    "binâtes": "biner",
    "binèrent": "biner",
    "biné": "biner",
    "binée": "biner",
    "binées": "biner",
    "binés": "biner",
    "binômes": "binôme",
    "biocarburants": "biocarburant",
    "biocatalyses": "biocatalyse",
    "biochimiques": "biochimique",
    "biochimistes": "biochimiste",
    "biocides": "biocide",
    "biocombustibles": "biocombustible",
    "biodiesels": "biodiesel",
    "biodiversités": "biodiversité",
    "biodégradables": "biodégradable",
    "biographes": "biographe",
    "biographies": "biographie",
    "biographiques": "biographique",
    "biologies": "biologie",
    "biologiques": "biologique",
    "biologistes": "biologiste",
    "biologisé": "biologiser",
    "bioluminescente": "bioluminescent",
    "biomasses": "biomasse",
    "biomatériaux": "biomatériau",
    "biomédecines": "biomédecine",
    "biomédicale": "biomédical",
    "biomédicales": "biomédical",
    "biomédicaux": "biomédical",
    "biométriques": "biométrique",
    "bioniques": "bionique",
    "biophysicienne": "biophysicien",
    "biophysiciennes": "biophysicien",
    "biophysiciens": "biophysicien",
    "biopsies": "biopsie",
    "biorythmes": "biorythme",
    "bios": "bio",
    "biosphères": "biosphère",
    "biosynthétiques": "biosynthétique",
    "biosécurités": "biosécurité",
    "biotechnologies": "biotechnologie",
    "biotechnologiques": "biotechnologique",
    "biotopes": "biotope",
    "bioénergies": "bioénergie",
    "bioéthanols": "bioéthanol",
    "bioéthiques": "bioéthique",
    "bipais": "biper",
    "bipartie": "biparti",
    "biparties": "biparti",
    "bipartis": "biparti",
    "bipartites": "bipartite",
    "bipe": "biper",
    "biperai": "biper",
    "biperait": "biper",
    "bipes": "biper",
    "bipez": "biper",
    "biplaces": "biplace",
    "biplans": "biplan",
    "bipolaires": "bipolaire",
    "bips": "bip",
    "bipèdes": "bipède",
    "bipé": "biper",
    "bipée": "biper",
    "bipés": "biper",
    "biques": "bique",
    "biquets": "biquet",
    "biquettes": "biquette",
    "biquotidienne": "biquotidien",
    "biquotidiens": "biquotidien",
    "birbes": "birbe",
    "birchers": "bircher",
    "birmane": "birman",
    "birmanes": "birman",
    "birmans": "birman",
    "biroutes": "biroute",
    "biréacteurs": "biréacteur",
    "bisa": "biser",
    "bisai": "biser",
    "bisaient": "biser",
    "bisais": "biser",
    "bisait": "biser",
    "bisannuelle": "bisannuel",
    "bisannuelles": "bisannuel",
    "bisannuels": "bisannuel",
    "bisant": "biser",
    "bisas": "biser",
    "bisasse": "biser",
    "bisassent": "biser",
    "bisasses": "biser",
    "bisassiez": "biser",
    "bisassions": "biser",
    "bisaïeule": "bisaïeul",
    "bisaïeules": "bisaïeul",
    "bisaïeuls": "bisaïeul",
    "bisbilles": "bisbille",
    "biscornue": "biscornu",
    "biscornues": "biscornu",
    "biscornus": "biscornu",
    "biscoteaux": "biscoteau",
    "biscotos": "biscoto",
    "biscottes": "biscotte",
    "biscuits": "biscuit",
    "bise": "biser",
    "biseauté": "biseauter",
    "biseautée": "biseauter",
    "biseautées": "biseauter",
    "biseautés": "biseauter",
    "biseaux": "biseau",
    "bisent": "biser",
    "bisera": "biser",
    "biserai": "biser",
    "biseraient": "biser",
    "biserais": "biser",
    "biserait": "biser",
    "biseras": "biser",
    "biserez": "biser",
    "biseriez": "biser",
    "biserions": "biser",
    "biserons": "biser",
    "biseront": "biser",
    "bises": "biser",
    "bisets": "biset",
    "bisexuelle": "bisexuel",
    "bisexuelles": "bisexuel",
    "bisexuels": "bisexuel",
    "bisexués": "bisexué",
    "bisez": "biser",
    "bisiez": "biser",
    "bisions": "biser",
    "bismuths": "bismuth",
    "bisons": "bison",
    "bisous": "bisou",
    "bisqua": "bisquer",
    "bisquai": "bisquer",
    "bisquaient": "bisquer",
    "bisquais": "bisquer",
    "bisquait": "bisquer",
    "bisquant": "bisquer",
    "bisquas": "bisquer",
    "bisquasse": "bisquer",
    "bisquassent": "bisquer",
    "bisquasses": "bisquer",
    "bisquassiez": "bisquer",
    "bisquassions": "bisquer",
    "bisque": "bisquer",
    "bisquent": "bisquer",
    "bisquera": "bisquer",
    "bisquerai": "bisquer",
    "bisqueraient": "bisquer",
    "bisquerais": "bisquer",
    "bisquerait": "bisquer",
    "bisqueras": "bisquer",
    "bisquerez": "bisquer",
    "bisqueriez": "bisquer",
    "bisquerions": "bisquer",
    "bisquerons": "bisquer",
    "bisqueront": "bisquer",
    "bisques": "bisquer",
    "bisquez": "bisquer",
    "bisquiez": "bisquer",
    "bisquions": "bisquer",
    "bisquons": "bisquer",
    "bisquâmes": "bisquer",
    "bisquât": "bisquer",
    "bisquâtes": "bisquer",
    "bisquèrent": "bisquer",
    "bisqué": "bisquer",
    "bissa": "bisser",
    "bissacs": "bissac",
    "bissai": "bisser",
    "bissaient": "bisser",
    "bissais": "bisser",
    "bissait": "bisser",
    "bissant": "bisser",
    "bissas": "bisser",
    "bissasse": "bisser",
    "bissassent": "bisser",
    "bissasses": "bisser",
    "bissassiez": "bisser",
    "bissassions": "bisser",
    "bisse": "bisser",
    "bissent": "bisser",
    "bissera": "bisser",
    "bisserai": "bisser",
    "bisseraient": "bisser",
    "bisserais": "bisser",
    "bisserait": "bisser",
    "bisseras": "bisser",
    "bisserez": "bisser",
    "bisseriez": "bisser",
    "bisserions": "bisser",
    "bisserons": "bisser",
    "bisseront": "bisser",
    "bisses": "bisser",
    "bissextiles": "bissextile",
    "bissez": "bisser",
    "bissiez": "bisser",
    "bissions": "bisser",
    "bissons": "bisser",
    "bissâmes": "bisser",
    "bissât": "bisser",
    "bissâtes": "bisser",
    "bissèrent": "bisser",
    "bissé": "bisser",
    "bissée": "bisser",
    "bissées": "bisser",
    "bissés": "bisser",
    "bistouris": "bistouri",
    "bistres": "bistre",
    "bistros": "bistro",
    "bistrote": "bistrot",
    "bistrotiers": "bistrotier",
    "bistrotière": "bistrotier",
    "bistrotières": "bistrotier",
    "bistrots": "bistrot",
    "bistré": "bistrer",
    "bistrée": "bistrer",
    "bistrées": "bistrer",
    "bistrés": "bistrer",
    "bisâmes": "biser",
    "bisât": "biser",
    "bisâtes": "biser",
    "bisèrent": "biser",
    "bisé": "biser",
    "bitent": "biter",
    "bites": "bite",
    "bithyniens": "bithynien",
    "bits": "bit",
    "bitters": "bitter",
    "bittes": "bitte",
    "bitumes": "bitume",
    "bitumeuse": "bitumeux",
    "bitumineuse": "bitumineux",
    "bitumé": "bitumer",
    "bitumée": "bitumer",
    "bitumées": "bitumer",
    "bitures": "biture",
    "biturins": "biturin",
    "bituré": "biturer",
    "biturés": "biturer",
    "bité": "biter",
    "bivalente": "bivalent",
    "bivalves": "bivalve",
    "biveaux": "biveau",
    "bivouacs": "bivouac",
    "bivouaquaient": "bivouaquer",
    "bivouaquait": "bivouaquer",
    "bivouaque": "bivouaquer",
    "bivouaquent": "bivouaquer",
    "bivouaquerons": "bivouaquer",
    "bivouaquons": "bivouaquer",
    "bivouaqué": "bivouaquer",
    "bivouaquée": "bivouaquer",
    "bizarreries": "bizarrerie",
    "bizarres": "bizarre",
    "bizarroïdes": "bizarroïde",
    "bizous": "bizou",
    "bizutages": "bizutage",
    "bizuteurs": "bizuteur",
    "bizuths": "bizuth",
    "bizuts": "bizut",
    "bizuté": "bizuter",
    "bières": "bière",
    "bla bla": "bla-bla",
    "blablatait": "blablater",
    "blablateurs": "blablateur",
    "blablatez": "blablater",
    "blablaté": "blablater",
    "black-rots": "black-rot",
    "blackboula": "blackbouler",
    "blackboulai": "blackbouler",
    "blackboulaient": "blackbouler",
    "blackboulais": "blackbouler",
    "blackboulait": "blackbouler",
    "blackboulant": "blackbouler",
    "blackboulas": "blackbouler",
    "blackboulasse": "blackbouler",
    "blackboulassent": "blackbouler",
    "blackboulasses": "blackbouler",
    "blackboulassiez": "blackbouler",
    "blackboulassions": "blackbouler",
    "blackboule": "blackbouler",
    "blackboulent": "blackbouler",
    "blackboulera": "blackbouler",
    "blackboulerai": "blackbouler",
    "blackbouleraient": "blackbouler",
    "blackboulerais": "blackbouler",
    "blackboulerait": "blackbouler",
    "blackbouleras": "blackbouler",
    "blackboulerez": "blackbouler",
    "blackbouleriez": "blackbouler",
    "blackboulerions": "blackbouler",
    "blackboulerons": "blackbouler",
    "blackbouleront": "blackbouler",
    "blackboules": "blackbouler",
    "blackboulez": "blackbouler",
    "blackbouliez": "blackbouler",
    "blackboulions": "blackbouler",
    "blackboulons": "blackbouler",
    "blackboulâmes": "blackbouler",
    "blackboulât": "blackbouler",
    "blackboulâtes": "blackbouler",
    "blackboulèrent": "blackbouler",
    "blackboulé": "blackbouler",
    "blackboulée": "blackbouler",
    "blackboulées": "blackbouler",
    "blackboulés": "blackbouler",
    "blacks": "black",
    "blafarde": "blafard",
    "blafardes": "blafard",
    "blafards": "blafard",
    "blagua": "blaguer",
    "blaguai": "blaguer",
    "blaguaient": "blaguer",
    "blaguais": "blaguer",
    "blaguait": "blaguer",
    "blaguant": "blaguer",
    "blaguas": "blaguer",
    "blaguasse": "blaguer",
    "blaguassent": "blaguer",
    "blaguasses": "blaguer",
    "blaguassiez": "blaguer",
    "blaguassions": "blaguer",
    "blague": "blaguer",
    "blaguent": "blaguer",
    "blaguera": "blaguer",
    "blaguerai": "blaguer",
    "blagueraient": "blaguer",
    "blaguerais": "blaguer",
    "blaguerait": "blaguer",
    "blagueras": "blaguer",
    "blaguerez": "blaguer",
    "blagueriez": "blaguer",
    "blaguerions": "blaguer",
    "blaguerons": "blaguer",
    "blagueront": "blaguer",
    "blagues": "blaguer",
    "blagueurs": "blagueur",
    "blagueuse": "blagueur",
    "blagueuses": "blagueur",
    "blaguez": "blaguer",
    "blaguiez": "blaguer",
    "blaguions": "blaguer",
    "blaguons": "blaguer",
    "blaguâmes": "blaguer",
    "blaguât": "blaguer",
    "blaguâtes": "blaguer",
    "blaguèrent": "blaguer",
    "blagué": "blaguer",
    "blaguée": "blaguer",
    "blaguées": "blaguer",
    "blagués": "blaguer",
    "blairaient": "blairer",
    "blairait": "blairer",
    "blaire": "blairer",
    "blaireaux": "blaireau",
    "blairs": "blair",
    "blairé": "blairer",
    "blaise": "blaiser",
    "blanc-estocs": "blanc-estoc",
    "blanc-étocs": "blanc-étoc",
    "blanche": "blanc",
    "blanchecailles": "blanchecaille",
    "blanches": "blanche",
    "blancheurs": "blancheur",
    "blanchi": "blanchir",
    "blanchie": "blanchir",
    "blanchies": "blanchir",
    "blanchiments": "blanchiment",
    "blanchira": "blanchir",
    "blanchirai": "blanchir",
    "blanchiraient": "blanchir",
    "blanchirais": "blanchir",
    "blanchirait": "blanchir",
    "blanchiras": "blanchir",
    "blanchirent": "blanchir",
    "blanchirez": "blanchir",
    "blanchiriez": "blanchir",
    "blanchirions": "blanchir",
    "blanchirons": "blanchir",
    "blanchiront": "blanchir",
    "blanchis": "blanchir",
    "blanchissages": "blanchissage",
    "blanchissaient": "blanchir",
    "blanchissais": "blanchir",
    "blanchissait": "blanchir",
    "blanchissant": "blanchir",
    "blanchissante": "blanchissant",
    "blanchissantes": "blanchissant",
    "blanchissants": "blanchissant",
    "blanchisse": "blanchir",
    "blanchissent": "blanchir",
    "blanchisseries": "blanchisserie",
    "blanchisses": "blanchir",
    "blanchisseurs": "blanchisseur",
    "blanchisseuse": "blanchisseur",
    "blanchisseuses": "blanchisseur",
    "blanchissez": "blanchir",
    "blanchissiez": "blanchir",
    "blanchissions": "blanchir",
    "blanchissons": "blanchir",
    "blanchit": "blanchir",
    "blanchoie": "blanchoyer",
    "blanchoyait": "blanchoyer",
    "blanchoyant": "blanchoyer",
    "blanchâtres": "blanchâtre",
    "blanchîmes": "blanchir",
    "blanchît": "blanchir",
    "blanchîtes": "blanchir",
    "blancs": "blanc",
    "blancs-becs": "blanc-bec",
    "blancs-seings": "blanc-seing",
    "blandices": "blandice",
    "blanquettes": "blanquette",
    "blasa": "blaser",
    "blasai": "blaser",
    "blasaient": "blaser",
    "blasais": "blaser",
    "blasait": "blaser",
    "blasant": "blaser",
    "blasas": "blaser",
    "blasasse": "blaser",
    "blasassent": "blaser",
    "blasasses": "blaser",
    "blasassiez": "blaser",
    "blasassions": "blaser",
    "blase": "blaser",
    "blasent": "blaser",
    "blasera": "blaser",
    "blaserai": "blaser",
    "blaseraient": "blaser",
    "blaserais": "blaser",
    "blaserait": "blaser",
    "blaseras": "blaser",
    "blaserez": "blaser",
    "blaseriez": "blaser",
    "blaserions": "blaser",
    "blaserons": "blaser",
    "blaseront": "blaser",
    "blases": "blaser",
    "blasez": "blaser",
    "blasiez": "blaser",
    "blasions": "blaser",
    "blasonnait": "blasonner",
    "blasonné": "blasonner",
    "blasonnée": "blasonner",
    "blasonnées": "blasonner",
    "blasonnés": "blasonner",
    "blasons": "blason",
    "blasphème": "blasphémer",
    "blasphèment": "blasphémer",
    "blasphèmes": "blasphémer",
    "blasphéma": "blasphémer",
    "blasphémai": "blasphémer",
    "blasphémaient": "blasphémer",
    "blasphémais": "blasphémer",
    "blasphémait": "blasphémer",
    "blasphémant": "blasphémer",
    "blasphémas": "blasphémer",
    "blasphémasse": "blasphémer",
    "blasphémassent": "blasphémer",
    "blasphémasses": "blasphémer",
    "blasphémassiez": "blasphémer",
    "blasphémassions": "blasphémer",
    "blasphémateurs": "blasphémateur",
    "blasphématoires": "blasphématoire",
    "blasphématrice": "blasphémateur",
    "blasphématrices": "blasphémateur",
    "blasphémera": "blasphémer",
    "blasphémerai": "blasphémer",
    "blasphémeraient": "blasphémer",
    "blasphémerais": "blasphémer",
    "blasphémerait": "blasphémer",
    "blasphémeras": "blasphémer",
    "blasphémerez": "blasphémer",
    "blasphémeriez": "blasphémer",
    "blasphémerions": "blasphémer",
    "blasphémerons": "blasphémer",
    "blasphémeront": "blasphémer",
    "blasphémez": "blasphémer",
    "blasphémiez": "blasphémer",
    "blasphémions": "blasphémer",
    "blasphémons": "blasphémer",
    "blasphémâmes": "blasphémer",
    "blasphémât": "blasphémer",
    "blasphémâtes": "blasphémer",
    "blasphémèrent": "blasphémer",
    "blasphémé": "blasphémer",
    "blasphémée": "blasphémer",
    "blasphémées": "blasphémer",
    "blasphémés": "blasphémer",
    "blasâmes": "blaser",
    "blasât": "blaser",
    "blasâtes": "blaser",
    "blasèrent": "blaser",
    "blasé": "blaser",
    "blasée": "blaser",
    "blasées": "blaser",
    "blasés": "blaser",
    "blattes": "blatte",
    "blatère": "blatérer",
    "blatèrent": "blatérer",
    "blatères": "blatérer",
    "blatéra": "blatérer",
    "blatérai": "blatérer",
    "blatéraient": "blatérer",
    "blatérais": "blatérer",
    "blatérait": "blatérer",
    "blatérant": "blatérer",
    "blatéras": "blatérer",
    "blatérasse": "blatérer",
    "blatérassent": "blatérer",
    "blatérasses": "blatérer",
    "blatérassiez": "blatérer",
    "blatérassions": "blatérer",
    "blatérera": "blatérer",
    "blatérerai": "blatérer",
    "blatéreraient": "blatérer",
    "blatérerais": "blatérer",
    "blatérerait": "blatérer",
    "blatéreras": "blatérer",
    "blatérerez": "blatérer",
    "blatéreriez": "blatérer",
    "blatérerions": "blatérer",
    "blatérerons": "blatérer",
    "blatéreront": "blatérer",
    "blatérez": "blatérer",
    "blatériez": "blatérer",
    "blatérions": "blatérer",
    "blatérons": "blatérer",
    "blatérâmes": "blatérer",
    "blatérât": "blatérer",
    "blatérâtes": "blatérer",
    "blatérèrent": "blatérer",
    "blatéré": "blatérer",
    "blazers": "blazer",
    "blazes": "blaze",
    "bleds": "bled",
    "blennies": "blennie",
    "blennorragies": "blennorragie",
    "blennorragiques": "blennorragique",
    "blessa": "blesser",
    "blessai": "blesser",
    "blessaient": "blesser",
    "blessais": "blesser",
    "blessait": "blesser",
    "blessant": "blesser",
    "blessante": "blessant",
    "blessantes": "blessant",
    "blessants": "blessant",
    "blessas": "blesser",
    "blessasse": "blesser",
    "blessassent": "blesser",
    "blessasses": "blesser",
    "blessassiez": "blesser",
    "blessassions": "blesser",
    "blesse": "blesser",
    "blessent": "blesser",
    "blessera": "blesser",
    "blesserai": "blesser",
    "blesseraient": "blesser",
    "blesserais": "blesser",
    "blesserait": "blesser",
    "blesseras": "blesser",
    "blesserez": "blesser",
    "blesseriez": "blesser",
    "blesserions": "blesser",
    "blesserons": "blesser",
    "blesseront": "blesser",
    "blesses": "blesser",
    "blessez": "blesser",
    "blessiez": "blesser",
    "blessions": "blesser",
    "blessons": "blesser",
    "blessures": "blessure",
    "blessâmes": "blesser",
    "blessât": "blesser",
    "blessâtes": "blesser",
    "blessèrent": "blesser",
    "blessé": "blesser",
    "blessée": "blesser",
    "blessées": "blesser",
    "blessés": "blesser",
    "blets": "blet",
    "blette": "blet",
    "blettes": "blette",
    "bletti": "blettir",
    "blettie": "blettir",
    "bletties": "blettir",
    "blettira": "blettir",
    "blettirai": "blettir",
    "blettiraient": "blettir",
    "blettirais": "blettir",
    "blettirait": "blettir",
    "blettiras": "blettir",
    "blettirent": "blettir",
    "blettirez": "blettir",
    "blettiriez": "blettir",
    "blettirions": "blettir",
    "blettirons": "blettir",
    "blettiront": "blettir",
    "blettis": "blettir",
    "blettissaient": "blettir",
    "blettissais": "blettir",
    "blettissait": "blettir",
    "blettissant": "blettir",
    "blettisse": "blettir",
    "blettissent": "blettir",
    "blettisses": "blettir",
    "blettissez": "blettir",
    "blettissiez": "blettir",
    "blettissions": "blettir",
    "blettissons": "blettir",
    "blettit": "blettir",
    "blettîmes": "blettir",
    "blettît": "blettir",
    "blettîtes": "blettir",
    "bleubites": "bleubite",
    "bleue": "bleu",
    "bleues": "bleu",
    "bleuets": "bleuet",
    "bleui": "bleuir",
    "bleuie": "bleuir",
    "bleuies": "bleuir",
    "bleuira": "bleuir",
    "bleuirai": "bleuir",
    "bleuiraient": "bleuir",
    "bleuirais": "bleuir",
    "bleuirait": "bleuir",
    "bleuiras": "bleuir",
    "bleuirent": "bleuir",
    "bleuirez": "bleuir",
    "bleuiriez": "bleuir",
    "bleuirions": "bleuir",
    "bleuirons": "bleuir",
    "bleuiront": "bleuir",
    "bleuis": "bleuir",
    "bleuissaient": "bleuir",
    "bleuissais": "bleuir",
    "bleuissait": "bleuir",
    "bleuissant": "bleuir",
    "bleuissante": "bleuissant",
    "bleuissantes": "bleuissant",
    "bleuisse": "bleuir",
    "bleuissent": "bleuir",
    "bleuisses": "bleuir",
    "bleuissez": "bleuir",
    "bleuissiez": "bleuir",
    "bleuissions": "bleuir",
    "bleuissons": "bleuir",
    "bleuit": "bleuir",
    "bleus": "bleu",
    "bleusailles": "bleusaille",
    "bleuté": "bleuter",
    "bleutée": "bleuter",
    "bleutées": "bleuter",
    "bleutés": "bleuter",
    "bleuâtres": "bleuâtre",
    "bleuîmes": "bleuir",
    "bleuît": "bleuir",
    "bleuîtes": "bleuir",
    "blinda": "blinder",
    "blindages": "blindage",
    "blindai": "blinder",
    "blindaient": "blinder",
    "blindais": "blinder",
    "blindait": "blinder",
    "blindant": "blinder",
    "blindas": "blinder",
    "blindasse": "blinder",
    "blindassent": "blinder",
    "blindasses": "blinder",
    "blindassiez": "blinder",
    "blindassions": "blinder",
    "blinde": "blinder",
    "blindent": "blinder",
    "blindera": "blinder",
    "blinderai": "blinder",
    "blinderaient": "blinder",
    "blinderais": "blinder",
    "blinderait": "blinder",
    "blinderas": "blinder",
    "blinderez": "blinder",
    "blinderiez": "blinder",
    "blinderions": "blinder",
    "blinderons": "blinder",
    "blinderont": "blinder",
    "blindes": "blinder",
    "blindez": "blinder",
    "blindiez": "blinder",
    "blindions": "blinder",
    "blindons": "blinder",
    "blindâmes": "blinder",
    "blindât": "blinder",
    "blindâtes": "blinder",
    "blindèrent": "blinder",
    "blindé": "blinder",
    "blindée": "blinder",
    "blindées": "blinder",
    "blindés": "blinder",
    "blinis": "blini",
    "blizzards": "blizzard",
    "blocages": "blocage",
    "blocks": "block",
    "blocs": "bloc",
    "blocs-cuisines": "bloc-cuisine",
    "blocs-diagrammes": "bloc-diagramme",
    "blocs-eaux": "bloc-eau",
    "blocs-moteurs": "bloc-moteur",
    "blocs-notes": "bloc-notes",
    "blocs-systèmes": "bloc-système",
    "blondasses": "blondasse",
    "blonde": "blond",
    "blondes": "blond",
    "blondeurs": "blondeur",
    "blondi": "blondir",
    "blondie": "blondir",
    "blondies": "blondir",
    "blondine": "blondin",
    "blondines": "blondin",
    "blondinets": "blondinet",
    "blondinette": "blondinet",
    "blondira": "blondir",
    "blondirai": "blondir",
    "blondiraient": "blondir",
    "blondirais": "blondir",
    "blondirait": "blondir",
    "blondiras": "blondir",
    "blondirent": "blondir",
    "blondirez": "blondir",
    "blondiriez": "blondir",
    "blondirions": "blondir",
    "blondirons": "blondir",
    "blondiront": "blondir",
    "blondis": "blondir",
    "blondissaient": "blondir",
    "blondissais": "blondir",
    "blondissait": "blondir",
    "blondissant": "blondir",
    "blondisse": "blondir",
    "blondissent": "blondir",
    "blondisses": "blondir",
    "blondissez": "blondir",
    "blondissiez": "blondir",
    "blondissions": "blondir",
    "blondissons": "blondir",
    "blondit": "blondir",
    "blonds": "blond",
    "blondîmes": "blondir",
    "blondît": "blondir",
    "blondîtes": "blondir",
    "bloqua": "bloquer",
    "bloquai": "bloquer",
    "bloquaient": "bloquer",
    "bloquais": "bloquer",
    "bloquait": "bloquer",
    "bloquant": "bloquer",
    "bloquas": "bloquer",
    "bloquasse": "bloquer",
    "bloquassent": "bloquer",
    "bloquasses": "bloquer",
    "bloquassiez": "bloquer",
    "bloquassions": "bloquer",
    "bloque": "bloquer",
    "bloquent": "bloquer",
    "bloquera": "bloquer",
    "bloquerai": "bloquer",
    "bloqueraient": "bloquer",
    "bloquerais": "bloquer",
    "bloquerait": "bloquer",
    "bloqueras": "bloquer",
    "bloquerez": "bloquer",
    "bloqueriez": "bloquer",
    "bloquerions": "bloquer",
    "bloquerons": "bloquer",
    "bloqueront": "bloquer",
    "bloques": "bloquer",
    "bloqueurs": "bloqueur",
    "bloquez": "bloquer",
    "bloquiez": "bloquer",
    "bloquions": "bloquer",
    "bloquons": "bloquer",
    "bloquâmes": "bloquer",
    "bloquât": "bloquer",
    "bloquâtes": "bloquer",
    "bloquèrent": "bloquer",
    "bloqué": "bloquer",
    "bloquée": "bloquer",
    "bloquées": "bloquer",
    "bloqués": "bloquer",
    "blots": "blot",
    "blotti": "blottir",
    "blottie": "blottir",
    "blotties": "blottir",
    "blottira": "blottir",
    "blottirai": "blottir",
    "blottiraient": "blottir",
    "blottirais": "blottir",
    "blottirait": "blottir",
    "blottiras": "blottir",
    "blottirent": "blottir",
    "blottirez": "blottir",
    "blottiriez": "blottir",
    "blottirions": "blottir",
    "blottirons": "blottir",
    "blottiront": "blottir",
    "blottis": "blottir",
    "blottissaient": "blottir",
    "blottissais": "blottir",
    "blottissait": "blottir",
    "blottissant": "blottir",
    "blottisse": "blottir",
    "blottissent": "blottir",
    "blottisses": "blottir",
    "blottissez": "blottir",
    "blottissiez": "blottir",
    "blottissions": "blottir",
    "blottissons": "blottir",
    "blottit": "blottir",
    "blottîmes": "blottir",
    "blottît": "blottir",
    "blottîtes": "blottir",
    "blousa": "blouser",
    "blousai": "blouser",
    "blousaient": "blouser",
    "blousais": "blouser",
    "blousait": "blouser",
    "blousant": "blouser",
    "blousantes": "blousant",
    "blousas": "blouser",
    "blousasse": "blouser",
    "blousassent": "blouser",
    "blousasses": "blouser",
    "blousassiez": "blouser",
    "blousassions": "blouser",
    "blouse": "blouser",
    "blousent": "blouser",
    "blousera": "blouser",
    "blouserai": "blouser",
    "blouseraient": "blouser",
    "blouserais": "blouser",
    "blouserait": "blouser",
    "blouseras": "blouser",
    "blouserez": "blouser",
    "blouseriez": "blouser",
    "blouserions": "blouser",
    "blouserons": "blouser",
    "blouseront": "blouser",
    "blouses": "blouser",
    "blousez": "blouser",
    "blousiez": "blouser",
    "blousions": "blouser",
    "blousons": "blouson",
    "blousâmes": "blouser",
    "blousât": "blouser",
    "blousâtes": "blouser",
    "blousèrent": "blouser",
    "blousé": "blouser",
    "blousée": "blouser",
    "blousées": "blouser",
    "blousés": "blouser",
    "blue jeans": "blue-jean",
    "blue-jeans": "blue-jean",
    "bluesmen": "bluesman",
    "bluets": "bluet",
    "bluettes": "bluette",
    "bluffa": "bluffer",
    "bluffai": "bluffer",
    "bluffaient": "bluffer",
    "bluffais": "bluffer",
    "bluffait": "bluffer",
    "bluffant": "bluffer",
    "bluffas": "bluffer",
    "bluffasse": "bluffer",
    "bluffassent": "bluffer",
    "bluffasses": "bluffer",
    "bluffassiez": "bluffer",
    "bluffassions": "bluffer",
    "bluffe": "bluffer",
    "bluffent": "bluffer",
    "bluffera": "bluffer",
    "blufferai": "bluffer",
    "blufferaient": "bluffer",
    "blufferais": "bluffer",
    "blufferait": "bluffer",
    "blufferas": "bluffer",
    "blufferez": "bluffer",
    "blufferiez": "bluffer",
    "blufferions": "bluffer",
    "blufferons": "bluffer",
    "blufferont": "bluffer",
    "bluffes": "bluffer",
    "bluffeurs": "bluffeur",
    "bluffeuses": "bluffeur",
    "bluffez": "bluffer",
    "bluffiez": "bluffer",
    "bluffions": "bluffer",
    "bluffons": "bluffer",
    "bluffs": "bluff",
    "bluffâmes": "bluffer",
    "bluffât": "bluffer",
    "bluffâtes": "bluffer",
    "bluffèrent": "bluffer",
    "bluffé": "bluffer",
    "bluffée": "bluffer",
    "bluffées": "bluffer",
    "bluffés": "bluffer",
    "bluta": "bluter",
    "blutai": "bluter",
    "blutaient": "bluter",
    "blutais": "bluter",
    "blutait": "bluter",
    "blutant": "bluter",
    "blutas": "bluter",
    "blutasse": "bluter",
    "blutassent": "bluter",
    "blutasses": "bluter",
    "blutassiez": "bluter",
    "blutassions": "bluter",
    "blute": "bluter",
    "blutent": "bluter",
    "blutera": "bluter",
    "bluterai": "bluter",
    "bluteraient": "bluter",
    "bluterais": "bluter",
    "bluterait": "bluter",
    "bluteras": "bluter",
    "bluterez": "bluter",
    "bluteriez": "bluter",
    "bluterions": "bluter",
    "bluterons": "bluter",
    "bluteront": "bluter",
    "blutes": "bluter",
    "blutez": "bluter",
    "blutiez": "bluter",
    "blutions": "bluter",
    "blutons": "bluter",
    "blutâmes": "bluter",
    "blutât": "bluter",
    "blutâtes": "bluter",
    "blutèrent": "bluter",
    "bluté": "bluter",
    "blutée": "bluter",
    "blutées": "bluter",
    "blutés": "bluter",
    "blâma": "blâmer",
    "blâmables": "blâmable",
    "blâmai": "blâmer",
    "blâmaient": "blâmer",
    "blâmais": "blâmer",
    "blâmait": "blâmer",
    "blâmant": "blâmer",
    "blâmas": "blâmer",
    "blâmasse": "blâmer",
    "blâmassent": "blâmer",
    "blâmasses": "blâmer",
    "blâmassiez": "blâmer",
    "blâmassions": "blâmer",
    "blâme": "blâmer",
    "blâment": "blâmer",
    "blâmera": "blâmer",
    "blâmerai": "blâmer",
    "blâmeraient": "blâmer",
    "blâmerais": "blâmer",
    "blâmerait": "blâmer",
    "blâmeras": "blâmer",
    "blâmerez": "blâmer",
    "blâmeriez": "blâmer",
    "blâmerions": "blâmer",
    "blâmerons": "blâmer",
    "blâmeront": "blâmer",
    "blâmes": "blâmer",
    "blâmez": "blâmer",
    "blâmiez": "blâmer",
    "blâmions": "blâmer",
    "blâmons": "blâmer",
    "blâmâmes": "blâmer",
    "blâmât": "blâmer",
    "blâmâtes": "blâmer",
    "blâmèrent": "blâmer",
    "blâmé": "blâmer",
    "blâmée": "blâmer",
    "blâmées": "blâmer",
    "blâmés": "blâmer",
    "blèches": "blèche",
    "blèse": "bléser",
    "blèsements": "blèsement",
    "blèsent": "bléser",
    "blèses": "bléser",
    "blédards": "blédard",
    "blépharites": "blépharite",
    "blés": "blé",
    "blésa": "bléser",
    "blésai": "bléser",
    "blésaient": "bléser",
    "blésais": "bléser",
    "blésait": "bléser",
    "blésant": "bléser",
    "blésas": "bléser",
    "blésasse": "bléser",
    "blésassent": "bléser",
    "blésasses": "bléser",
    "blésassiez": "bléser",
    "blésassions": "bléser",
    "blésera": "bléser",
    "bléserai": "bléser",
    "bléseraient": "bléser",
    "bléserais": "bléser",
    "bléserait": "bléser",
    "bléseras": "bléser",
    "bléserez": "bléser",
    "bléseriez": "bléser",
    "bléserions": "bléser",
    "bléserons": "bléser",
    "bléseront": "bléser",
    "blésez": "bléser",
    "blésiez": "bléser",
    "blésions": "bléser",
    "blésités": "blésité",
    "blésons": "bléser",
    "blésâmes": "bléser",
    "blésât": "bléser",
    "blésâtes": "bléser",
    "blésèrent": "bléser",
    "blésé": "bléser",
    "blêmes": "blême",
    "blêmi": "blêmir",
    "blêmie": "blêmir",
    "blêmies": "blêmir",
    "blêmira": "blêmir",
    "blêmirai": "blêmir",
    "blêmiraient": "blêmir",
    "blêmirais": "blêmir",
    "blêmirait": "blêmir",
    "blêmiras": "blêmir",
    "blêmirent": "blêmir",
    "blêmirez": "blêmir",
    "blêmiriez": "blêmir",
    "blêmirions": "blêmir",
    "blêmirons": "blêmir",
    "blêmiront": "blêmir",
    "blêmis": "blêmir",
    "blêmissaient": "blêmir",
    "blêmissais": "blêmir",
    "blêmissait": "blêmir",
    "blêmissant": "blêmir",
    "blêmissante": "blêmissant",
    "blêmisse": "blêmir",
    "blêmissent": "blêmir",
    "blêmisses": "blêmir",
    "blêmissez": "blêmir",
    "blêmissiez": "blêmir",
    "blêmissions": "blêmir",
    "blêmissons": "blêmir",
    "blêmit": "blêmir",
    "blêmîmes": "blêmir",
    "blêmît": "blêmir",
    "blêmîtes": "blêmir",
    "boas": "boa",
    "bobards": "bobard",
    "bobinait": "bobiner",
    "bobinards": "bobinard",
    "bobine": "bobiner",
    "bobines": "bobiner",
    "bobinettes": "bobinette",
    "bobineuse": "bobineur",
    "bobineuses": "bobineur",
    "bobonnes": "bobonne",
    "bobos": "bobo",
    "bobs": "bob",
    "bobsleighs": "bobsleigh",
    "bobèches": "bobèche",
    "bocages": "bocage",
    "bocagères": "bocager",
    "bocaux": "bocal",
    "boches": "boche",
    "bocks": "bock",
    "bodegas": "bodega",
    "boers": "boer",
    "boeufs": "boeuf",
    "boggies": "boggie",
    "bogheis": "boghei",
    "bogies": "bogie",
    "bogomiles": "bogomile",
    "bogue": "boguer",
    "bogues": "bogue",
    "boguets": "boguet",
    "bohèmes": "bohème",
    "bohémienne": "bohémien",
    "bohémiennes": "bohémien",
    "bohémiens": "bohémien",
    "boira": "boire",
    "boirai": "boire",
    "boiraient": "boire",
    "boirais": "boire",
    "boirait": "boire",
    "boiras": "boire",
    "boirez": "boire",
    "boiriez": "boire",
    "boirions": "boire",
    "boirons": "boire",
    "boiront": "boire",
    "bois": "boire",
    "boisa": "boiser",
    "boisai": "boiser",
    "boisaient": "boiser",
    "boisais": "boiser",
    "boisait": "boiser",
    "boisant": "boiser",
    "boisas": "boiser",
    "boisasse": "boiser",
    "boisassent": "boiser",
    "boisasses": "boiser",
    "boisassiez": "boiser",
    "boisassions": "boiser",
    "boise": "boiser",
    "boisements": "boisement",
    "boisent": "boiser",
    "boisera": "boiser",
    "boiserai": "boiser",
    "boiseraient": "boiser",
    "boiserais": "boiser",
    "boiserait": "boiser",
    "boiseras": "boiser",
    "boiserez": "boiser",
    "boiseries": "boiserie",
    "boiseriez": "boiser",
    "boiserions": "boiser",
    "boiserons": "boiser",
    "boiseront": "boiser",
    "boises": "boiser",
    "boisez": "boiser",
    "boisiez": "boiser",
    "boisions": "boiser",
    "boisons": "boiser",
    "boisseaux": "boisseau",
    "boissonnée": "boissonner",
    "boissons": "boisson",
    "boisâmes": "boiser",
    "boisât": "boiser",
    "boisâtes": "boiser",
    "boisèrent": "boiser",
    "boisé": "boiser",
    "boisée": "boiser",
    "boisées": "boiser",
    "boisés": "boiser",
    "boit": "boire",
    "boita": "boiter",
    "boitai": "boiter",
    "boitaient": "boiter",
    "boitais": "boiter",
    "boitait": "boiter",
    "boitant": "boiter",
    "boitas": "boiter",
    "boitasse": "boiter",
    "boitassent": "boiter",
    "boitasses": "boiter",
    "boitassiez": "boiter",
    "boitassions": "boiter",
    "boite": "boiter",
    "boitent": "boiter",
    "boitera": "boiter",
    "boiterai": "boiter",
    "boiteraient": "boiter",
    "boiterais": "boiter",
    "boiterait": "boiter",
    "boiteras": "boiter",
    "boiterez": "boiter",
    "boiteriez": "boiter",
    "boiterions": "boiter",
    "boiterons": "boiter",
    "boiteront": "boiter",
    "boites": "boiter",
    "boiteuse": "boiteux",
    "boiteuses": "boiteux",
    "boitez": "boiter",
    "boitiez": "boiter",
    "boitillait": "boitiller",
    "boitillant": "boitiller",
    "boitille": "boitiller",
    "boitillements": "boitillement",
    "boitions": "boiter",
    "boitons": "boiter",
    "boittes": "boitte",
    "boitâmes": "boiter",
    "boitât": "boiter",
    "boitâtes": "boiter",
    "boitèrent": "boiter",
    "boité": "boiter",
    "boitée": "boiter",
    "boitées": "boiter",
    "boités": "boiter",
    "boive": "boire",
    "boivent": "boire",
    "boives": "boire",
    "bolas": "bola",
    "bolcheviks": "bolchevik",
    "bolcheviques": "bolchevique",
    "bolchevismes": "bolchevisme",
    "bolchevistes": "bolcheviste",
    "bolchévismes": "bolchévisme",
    "bolets": "bolet",
    "bolides": "bolide",
    "bolivienne": "bolivien",
    "boliviens": "bolivien",
    "bolognaise": "bolognais",
    "bolognaises": "bolognais",
    "bolonaise": "bolonais",
    "bols": "bol",
    "bolées": "bolée",
    "boléros": "boléro",
    "bomba": "bomber",
    "bombages": "bombage",
    "bombai": "bomber",
    "bombaient": "bomber",
    "bombais": "bomber",
    "bombait": "bomber",
    "bombances": "bombance",
    "bombant": "bomber",
    "bombarda": "bombarder",
    "bombardai": "bombarder",
    "bombardaient": "bombarder",
    "bombardais": "bombarder",
    "bombardait": "bombarder",
    "bombardant": "bombarder",
    "bombardas": "bombarder",
    "bombardasse": "bombarder",
    "bombardassent": "bombarder",
    "bombardasses": "bombarder",
    "bombardassiez": "bombarder",
    "bombardassions": "bombarder",
    "bombarde": "bombarder",
    "bombardements": "bombardement",
    "bombardent": "bombarder",
    "bombardera": "bombarder",
    "bombarderai": "bombarder",
    "bombarderaient": "bombarder",
    "bombarderais": "bombarder",
    "bombarderait": "bombarder",
    "bombarderas": "bombarder",
    "bombarderez": "bombarder",
    "bombarderiez": "bombarder",
    "bombarderions": "bombarder",
    "bombarderons": "bombarder",
    "bombarderont": "bombarder",
    "bombardes": "bombarder",
    "bombardez": "bombarder",
    "bombardiers": "bombardier",
    "bombardiez": "bombarder",
    "bombardions": "bombarder",
    "bombardons": "bombardon",
    "bombardâmes": "bombarder",
    "bombardât": "bombarder",
    "bombardâtes": "bombarder",
    "bombardèrent": "bombarder",
    "bombardé": "bombarder",
    "bombardée": "bombarder",
    "bombardées": "bombarder",
    "bombardés": "bombarder",
    "bombas": "bomber",
    "bombasse": "bomber",
    "bombassent": "bomber",
    "bombasses": "bomber",
    "bombassiez": "bomber",
    "bombassions": "bomber",
    "bombe": "bomber",
    "bombements": "bombement",
    "bombent": "bomber",
    "bombera": "bomber",
    "bomberai": "bomber",
    "bomberaient": "bomber",
    "bomberais": "bomber",
    "bomberait": "bomber",
    "bomberas": "bomber",
    "bomberez": "bomber",
    "bomberiez": "bomber",
    "bomberions": "bomber",
    "bomberons": "bomber",
    "bomberont": "bomber",
    "bombes": "bomber",
    "bombes-test": "bombe-test",
    "bombez": "bomber",
    "bombiez": "bomber",
    "bombinettes": "bombinette",
    "bombions": "bomber",
    "bombonnes": "bombonne",
    "bombons": "bomber",
    "bombâmes": "bomber",
    "bombât": "bomber",
    "bombâtes": "bomber",
    "bombèrent": "bomber",
    "bombé": "bomber",
    "bombée": "bomber",
    "bombées": "bomber",
    "bombés": "bomber",
    "bonaces": "bonace",
    "bonapartismes": "bonapartisme",
    "bonapartistes": "bonapartiste",
    "bonardes": "bonard",
    "bonasses": "bonasse",
    "bonbonnes": "bonbonne",
    "bonbonnières": "bonbonnière",
    "bonbons": "bonbon",
    "bondages": "bondage",
    "bondait": "bonder",
    "bondes": "bonde",
    "bondi": "bondir",
    "bondieuseries": "bondieuserie",
    "bondieuses": "bondieuser",
    "bondira": "bondir",
    "bondirai": "bondir",
    "bondiraient": "bondir",
    "bondirais": "bondir",
    "bondirait": "bondir",
    "bondiras": "bondir",
    "bondirent": "bondir",
    "bondirez": "bondir",
    "bondiriez": "bondir",
    "bondirions": "bondir",
    "bondirons": "bondir",
    "bondiront": "bondir",
    "bondis": "bondir",
    "bondissaient": "bondir",
    "bondissais": "bondir",
    "bondissait": "bondir",
    "bondissant": "bondir",
    "bondissante": "bondissant",
    "bondissantes": "bondissant",
    "bondissants": "bondissant",
    "bondisse": "bondir",
    "bondissements": "bondissement",
    "bondissent": "bondir",
    "bondisses": "bondir",
    "bondissez": "bondir",
    "bondissiez": "bondir",
    "bondissions": "bondir",
    "bondissons": "bondir",
    "bondit": "bondir",
    "bonds": "bond",
    "bondé": "bonder",
    "bondée": "bonder",
    "bondées": "bonder",
    "bondés": "bonder",
    "bondîmes": "bondir",
    "bondît": "bondir",
    "bondîtes": "bondir",
    "bongos": "bongo",
    "bonheurs": "bonheur",
    "bonheurs-du-jour": "bonheur-du-jour",
    "bonhomies": "bonhomie",
    "bonhommes": "bonhomme",
    "boniches": "boniche",
    "bonifia": "bonifier",
    "bonifiai": "bonifier",
    "bonifiaient": "bonifier",
    "bonifiais": "bonifier",
    "bonifiait": "bonifier",
    "bonifiant": "bonifier",
    "bonifias": "bonifier",
    "bonifiasse": "bonifier",
    "bonifiassent": "bonifier",
    "bonifiasses": "bonifier",
    "bonifiassiez": "bonifier",
    "bonifiassions": "bonifier",
    "bonifications": "bonification",
    "bonifie": "bonifier",
    "bonifient": "bonifier",
    "bonifiera": "bonifier",
    "bonifierai": "bonifier",
    "bonifieraient": "bonifier",
    "bonifierais": "bonifier",
    "bonifierait": "bonifier",
    "bonifieras": "bonifier",
    "bonifierez": "bonifier",
    "bonifieriez": "bonifier",
    "bonifierions": "bonifier",
    "bonifierons": "bonifier",
    "bonifieront": "bonifier",
    "bonifies": "bonifier",
    "bonifiez": "bonifier",
    "bonifiiez": "bonifier",
    "bonifiions": "bonifier",
    "bonifions": "bonifier",
    "bonifiâmes": "bonifier",
    "bonifiât": "bonifier",
    "bonifiâtes": "bonifier",
    "bonifièrent": "bonifier",
    "bonifié": "bonifier",
    "bonifiée": "bonifier",
    "bonifiées": "bonifier",
    "bonifiés": "bonifier",
    "bonimentait": "bonimenter",
    "bonimente": "bonimenter",
    "bonimenteurs": "bonimenteur",
    "boniments": "boniment",
    "bonis": "boni",
    "bonissait": "bonir",
    "bonisse": "bonir",
    "bonit": "bonir",
    "bonjours": "bonjour",
    "bonnarde": "bonnard",
    "bonnardes": "bonnard",
    "bonnards": "bonnard",
    "bonne": "bon",
    "bonnes": "bonne",
    "bonnes-mamans": "bonne-maman",
    "bonneteaux": "bonneteau",
    "bonneteries": "bonneterie",
    "bonneteurs": "bonneteur",
    "bonnets": "bonnet",
    "bonnettes": "bonnette",
    "bonni": "bonnir",
    "bonniches": "bonniche",
    "bonnie": "bonnir",
    "bonnis": "bonnir",
    "bonnisse": "bonnir",
    "bonnissent": "bonnir",
    "bonnit": "bonnir",
    "bons": "bon",
    "bons-cadeaux": "bon-cadeaux",
    "bons-chrétiens": "bon-chrétien",
    "bons-papas": "bon-papa",
    "bonsaïs": "bonsaï",
    "bonshommes": "bonhomme",
    "bonsoirs": "bonsoir",
    "bontés": "bonté",
    "bonzes": "bonze",
    "bonzesse": "bonze",
    "bonzesses": "bonze",
    "boogie-woogies": "boogie-woogie",
    "bookmakers": "bookmaker",
    "bookmakings": "bookmaking",
    "books": "book",
    "boomerangs": "boomerang",
    "booms": "boom",
    "boosters": "booster",
    "bootleggers": "bootlegger",
    "boqueteaux": "boqueteau",
    "boquillons": "boquillon",
    "borborygmes": "borborygme",
    "borda": "border",
    "bordages": "bordage",
    "bordai": "border",
    "bordaient": "border",
    "bordais": "border",
    "bordait": "border",
    "bordant": "border",
    "bordas": "border",
    "bordasse": "border",
    "bordassent": "border",
    "bordasses": "border",
    "bordassiez": "border",
    "bordassions": "border",
    "borde": "border",
    "bordelaise": "bordelais",
    "bordelaises": "bordelais",
    "bordelières": "bordelier",
    "bordels": "bordel",
    "bordent": "border",
    "bordera": "border",
    "borderai": "border",
    "borderaient": "border",
    "borderais": "border",
    "borderait": "border",
    "borderas": "border",
    "bordereaux": "bordereau",
    "borderez": "border",
    "borderiez": "border",
    "borderions": "border",
    "borderons": "border",
    "borderont": "border",
    "bordes": "border",
    "bordez": "border",
    "bordiez": "border",
    "bordions": "border",
    "bordons": "border",
    "bords": "bord",
    "bordurant": "bordurer",
    "bordures": "bordure",
    "borduré": "bordurer",
    "bordurée": "bordurer",
    "bordâmes": "border",
    "bordât": "border",
    "bordâtes": "border",
    "bordèrent": "border",
    "bordé": "border",
    "bordée": "border",
    "bordées": "border",
    "bordéliques": "bordélique",
    "bordés": "border",
    "bores": "bore",
    "borgnes": "borgne",
    "borgnotaient": "borgnoter",
    "borgnotant": "borgnoter",
    "borgnote": "borgnoter",
    "borgnoté": "borgnoter",
    "borgésienne": "borgésien",
    "borgésiennes": "borgésien",
    "borgésiens": "borgésien",
    "boriques": "borique",
    "borna": "borner",
    "bornages": "bornage",
    "bornai": "borner",
    "bornaient": "borner",
    "bornais": "borner",
    "bornait": "borner",
    "bornant": "borner",
    "bornas": "borner",
    "bornasse": "borner",
    "bornassent": "borner",
    "bornasses": "borner",
    "bornassiez": "borner",
    "bornassions": "borner",
    "borne": "borner",
    "bornent": "borner",
    "bornera": "borner",
    "bornerai": "borner",
    "borneraient": "borner",
    "bornerais": "borner",
    "bornerait": "borner",
    "borneras": "borner",
    "bornerez": "borner",
    "borneriez": "borner",
    "bornerions": "borner",
    "bornerons": "borner",
    "borneront": "borner",
    "bornes": "borner",
    "bornes-fontaines": "borne-fontaine",
    "bornez": "borner",
    "borniez": "borner",
    "bornions": "borner",
    "bornons": "borner",
    "bornâmes": "borner",
    "bornât": "borner",
    "bornâtes": "borner",
    "bornèrent": "borner",
    "borné": "borner",
    "bornée": "borner",
    "bornées": "borner",
    "bornés": "borner",
    "borts": "bort",
    "boréale": "boréal",
    "boréales": "boréal",
    "boréals": "boréal",
    "boréaux": "boréal",
    "boscotte": "boscot",
    "bosniaques": "bosniaque",
    "bosquets": "bosquet",
    "bossa": "bosser",
    "bossages": "bossage",
    "bossai": "bosser",
    "bossaient": "bosser",
    "bossais": "bosser",
    "bossait": "bosser",
    "bossant": "bosser",
    "bossas": "bosser",
    "bossas-novas": "bossa-nova",
    "bossasse": "bosser",
    "bossassent": "bosser",
    "bossasses": "bosser",
    "bossassiez": "bosser",
    "bossassions": "bosser",
    "bosse": "bosser",
    "bossela": "bosseler",
    "bosselai": "bosseler",
    "bosselaient": "bosseler",
    "bosselais": "bosseler",
    "bosselait": "bosseler",
    "bosselant": "bosseler",
    "bosselas": "bosseler",
    "bosselasse": "bosseler",
    "bosselassent": "bosseler",
    "bosselasses": "bosseler",
    "bosselassiez": "bosseler",
    "bosselassions": "bosseler",
    "bosselez": "bosseler",
    "bosseliez": "bosseler",
    "bosselions": "bosseler",
    "bosselle": "bosseler",
    "bossellements": "bossellement",
    "bossellent": "bosseler",
    "bossellera": "bosseler",
    "bossellerai": "bosseler",
    "bosselleraient": "bosseler",
    "bossellerais": "bosseler",
    "bossellerait": "bosseler",
    "bosselleras": "bosseler",
    "bossellerez": "bosseler",
    "bosselleriez": "bosseler",
    "bossellerions": "bosseler",
    "bossellerons": "bosseler",
    "bosselleront": "bosseler",
    "bosselles": "bosseler",
    "bosselons": "bosseler",
    "bosselâmes": "bosseler",
    "bosselât": "bosseler",
    "bosselâtes": "bosseler",
    "bosselèrent": "bosseler",
    "bosselé": "bosseler",
    "bosselée": "bosseler",
    "bosselées": "bosseler",
    "bosselés": "bosseler",
    "bossent": "bosser",
    "bossera": "bosser",
    "bosserai": "bosser",
    "bosseraient": "bosser",
    "bosserais": "bosser",
    "bosserait": "bosser",
    "bosseras": "bosser",
    "bosserez": "bosser",
    "bosseriez": "bosser",
    "bosserions": "bosser",
    "bosserons": "bosser",
    "bosseront": "bosser",
    "bosses": "bosser",
    "bossettes": "bossette",
    "bosseurs": "bosseur",
    "bosseuse": "bosseur",
    "bossez": "bosser",
    "bossiez": "bosser",
    "bossions": "bosser",
    "bossoirs": "bossoir",
    "bossons": "bosson",
    "bossuaient": "bossuer",
    "bossue": "bossuer",
    "bossues": "bossu",
    "bossus": "bossu",
    "bossué": "bossuer",
    "bossuée": "bossué",
    "bossuées": "bossuer",
    "bossués": "bossué",
    "bossâmes": "bosser",
    "bossât": "bosser",
    "bossâtes": "bosser",
    "bossèrent": "bosser",
    "bossé": "bosser",
    "bossée": "bosser",
    "bossées": "bosser",
    "bossés": "bosser",
    "bostonienne": "bostonien",
    "bostoniens": "bostonien",
    "bostons": "boston",
    "botaniques": "botanique",
    "botanistes": "botaniste",
    "bote": "bot",
    "botes": "bot",
    "bots": "bot",
    "botswanaise": "botswanais",
    "botswanaises": "botswanais",
    "botta": "botter",
    "bottai": "botter",
    "bottaient": "botter",
    "bottais": "botter",
    "bottait": "botter",
    "bottant": "botter",
    "bottas": "botter",
    "bottasse": "botter",
    "bottassent": "botter",
    "bottasses": "botter",
    "bottassiez": "botter",
    "bottassions": "botter",
    "botte": "botter",
    "bottela": "botteler",
    "bottelai": "botteler",
    "bottelaient": "botteler",
    "bottelais": "botteler",
    "bottelait": "botteler",
    "bottelant": "botteler",
    "bottelas": "botteler",
    "bottelasse": "botteler",
    "bottelassent": "botteler",
    "bottelasses": "botteler",
    "bottelassiez": "botteler",
    "bottelassions": "botteler",
    "bottelez": "botteler",
    "botteliez": "botteler",
    "bottelions": "botteler",
    "bottelle": "botteler",
    "bottellent": "botteler",
    "bottellera": "botteler",
    "bottellerai": "botteler",
    "bottelleraient": "botteler",
    "bottellerais": "botteler",
    "bottellerait": "botteler",
    "bottelleras": "botteler",
    "bottellerez": "botteler",
    "bottelleriez": "botteler",
    "bottellerions": "botteler",
    "bottellerons": "botteler",
    "bottelleront": "botteler",
    "bottelles": "botteler",
    "bottelons": "botteler",
    "bottelâmes": "botteler",
    "bottelât": "botteler",
    "bottelâtes": "botteler",
    "bottelèrent": "botteler",
    "bottelé": "botteler",
    "bottelée": "botteler",
    "bottelées": "botteler",
    "bottelés": "botteler",
    "bottent": "botter",
    "bottera": "botter",
    "botterai": "botter",
    "botteraient": "botter",
    "botterais": "botter",
    "botterait": "botter",
    "botteras": "botter",
    "botterez": "botter",
    "botteriez": "botter",
    "botterions": "botter",
    "botterons": "botter",
    "botteront": "botter",
    "bottes": "botter",
    "botteurs": "botteur",
    "bottez": "botter",
    "botticellienne": "botticellien",
    "bottiers": "bottier",
    "bottiez": "botter",
    "bottillons": "bottillon",
    "bottines": "bottine",
    "bottins": "bottin",
    "bottiné": "bottiner",
    "bottions": "botter",
    "bottons": "botter",
    "bottâmes": "botter",
    "bottât": "botter",
    "bottâtes": "botter",
    "bottèrent": "botter",
    "botté": "botter",
    "bottée": "botter",
    "bottées": "botter",
    "bottés": "botter",
    "bouboule": "boubouler",
    "bouboules": "boubouler",
    "boubous": "boubou",
    "boucana": "boucaner",
    "boucanai": "boucaner",
    "boucanaient": "boucaner",
    "boucanais": "boucaner",
    "boucanait": "boucaner",
    "boucanant": "boucaner",
    "boucanas": "boucaner",
    "boucanasse": "boucaner",
    "boucanassent": "boucaner",
    "boucanasses": "boucaner",
    "boucanassiez": "boucaner",
    "boucanassions": "boucaner",
    "boucane": "boucaner",
    "boucanent": "boucaner",
    "boucanera": "boucaner",
    "boucanerai": "boucaner",
    "boucaneraient": "boucaner",
    "boucanerais": "boucaner",
    "boucanerait": "boucaner",
    "boucaneras": "boucaner",
    "boucanerez": "boucaner",
    "boucaneriez": "boucaner",
    "boucanerions": "boucaner",
    "boucanerons": "boucaner",
    "boucaneront": "boucaner",
    "boucanes": "boucaner",
    "boucanez": "boucaner",
    "boucaniers": "boucanier",
    "boucaniez": "boucaner",
    "boucanions": "boucaner",
    "boucanons": "boucaner",
    "boucans": "boucan",
    "boucanâmes": "boucaner",
    "boucanât": "boucaner",
    "boucanâtes": "boucaner",
    "boucanèrent": "boucaner",
    "boucané": "boucaner",
    "boucanée": "boucaner",
    "boucanées": "boucaner",
    "boucanés": "boucaner",
    "boucaux": "boucau",
    "boucha": "boucher",
    "bouchai": "boucher",
    "bouchaient": "boucher",
    "bouchais": "boucher",
    "bouchait": "boucher",
    "bouchant": "boucher",
    "bouchardant": "boucharder",
    "bouchardes": "boucharde",
    "bouchas": "boucher",
    "bouchasse": "boucher",
    "bouchassent": "boucher",
    "bouchasses": "boucher",
    "bouchassiez": "boucher",
    "bouchassions": "boucher",
    "bouche": "boucher",
    "bouche-trous": "bouche-trou",
    "bouchent": "boucher",
    "bouchera": "boucher",
    "boucherai": "boucher",
    "boucheraient": "boucher",
    "boucherais": "boucher",
    "boucherait": "boucher",
    "boucheras": "boucher",
    "boucherez": "boucher",
    "boucheries": "boucherie",
    "boucheriez": "boucher",
    "boucherions": "boucher",
    "boucherons": "boucher",
    "boucheront": "boucher",
    "bouchers": "boucher",
    "bouches": "boucher",
    "bouchez": "boucher",
    "bouchiez": "boucher",
    "bouchions": "boucher",
    "bouchonna": "bouchonner",
    "bouchonnai": "bouchonner",
    "bouchonnaient": "bouchonner",
    "bouchonnais": "bouchonner",
    "bouchonnait": "bouchonner",
    "bouchonnant": "bouchonner",
    "bouchonnas": "bouchonner",
    "bouchonnasse": "bouchonner",
    "bouchonnassent": "bouchonner",
    "bouchonnasses": "bouchonner",
    "bouchonnassiez": "bouchonner",
    "bouchonnassions": "bouchonner",
    "bouchonne": "bouchonner",
    "bouchonnent": "bouchonner",
    "bouchonnera": "bouchonner",
    "bouchonnerai": "bouchonner",
    "bouchonneraient": "bouchonner",
    "bouchonnerais": "bouchonner",
    "bouchonnerait": "bouchonner",
    "bouchonneras": "bouchonner",
    "bouchonnerez": "bouchonner",
    "bouchonneriez": "bouchonner",
    "bouchonnerions": "bouchonner",
    "bouchonnerons": "bouchonner",
    "bouchonneront": "bouchonner",
    "bouchonnes": "bouchonner",
    "bouchonnez": "bouchonner",
    "bouchonniez": "bouchonner",
    "bouchonnions": "bouchonner",
    "bouchonnons": "bouchonner",
    "bouchonnâmes": "bouchonner",
    "bouchonnât": "bouchonner",
    "bouchonnâtes": "bouchonner",
    "bouchonnèrent": "bouchonner",
    "bouchonné": "bouchonner",
    "bouchonnée": "bouchonner",
    "bouchonnées": "bouchonner",
    "bouchonnés": "bouchonner",
    "bouchons": "bouchon",
    "bouchoteurs": "bouchoteur",
    "bouchots": "bouchot",
    "bouchâmes": "boucher",
    "bouchât": "boucher",
    "bouchâtes": "boucher",
    "bouchère": "boucher",
    "bouchèrent": "boucher",
    "bouchères": "boucher",
    "bouché": "boucher",
    "bouchée": "boucher",
    "bouchées": "boucher",
    "bouchés": "boucher",
    "boucla": "boucler",
    "bouclages": "bouclage",
    "bouclai": "boucler",
    "bouclaient": "boucler",
    "bouclais": "boucler",
    "bouclait": "boucler",
    "bouclant": "boucler",
    "bouclas": "boucler",
    "bouclasse": "boucler",
    "bouclassent": "boucler",
    "bouclasses": "boucler",
    "bouclassiez": "boucler",
    "bouclassions": "boucler",
    "boucle": "boucler",
    "bouclent": "boucler",
    "bouclera": "boucler",
    "bouclerai": "boucler",
    "boucleraient": "boucler",
    "bouclerais": "boucler",
    "bouclerait": "boucler",
    "boucleras": "boucler",
    "bouclerez": "boucler",
    "boucleriez": "boucler",
    "bouclerions": "boucler",
    "bouclerons": "boucler",
    "boucleront": "boucler",
    "boucles": "boucler",
    "bouclettes": "bouclette",
    "bouclez": "boucler",
    "boucliers": "bouclier",
    "boucliez": "boucler",
    "bouclions": "boucler",
    "bouclons": "boucler",
    "bouclâmes": "boucler",
    "bouclât": "boucler",
    "bouclâtes": "boucler",
    "bouclèrent": "boucler",
    "bouclé": "boucler",
    "bouclée": "boucler",
    "bouclées": "boucler",
    "bouclés": "boucler",
    "boucs": "bouc",
    "bouda": "bouder",
    "boudai": "bouder",
    "boudaient": "bouder",
    "boudais": "bouder",
    "boudait": "bouder",
    "boudant": "bouder",
    "boudas": "bouder",
    "boudasse": "bouder",
    "boudassent": "bouder",
    "boudasses": "bouder",
    "boudassiez": "bouder",
    "boudassions": "bouder",
    "bouddhas": "bouddha",
    "bouddhiques": "bouddhique",
    "bouddhismes": "bouddhisme",
    "bouddhistes": "bouddhiste",
    "boude": "bouder",
    "boudent": "bouder",
    "boudera": "bouder",
    "bouderai": "bouder",
    "bouderaient": "bouder",
    "bouderais": "bouder",
    "bouderait": "bouder",
    "bouderas": "bouder",
    "bouderez": "bouder",
    "bouderies": "bouderie",
    "bouderiez": "bouder",
    "bouderions": "bouder",
    "bouderons": "bouder",
    "bouderont": "bouder",
    "boudes": "bouder",
    "boudeurs": "boudeur",
    "boudeuse": "boudeur",
    "boudeuses": "boudeur",
    "boudez": "bouder",
    "boudiez": "bouder",
    "boudina": "boudiner",
    "boudinai": "boudiner",
    "boudinaient": "boudiner",
    "boudinais": "boudiner",
    "boudinait": "boudiner",
    "boudinant": "boudiner",
    "boudinas": "boudiner",
    "boudinasse": "boudiner",
    "boudinassent": "boudiner",
    "boudinasses": "boudiner",
    "boudinassiez": "boudiner",
    "boudinassions": "boudiner",
    "boudine": "boudiner",
    "boudinent": "boudiner",
    "boudinera": "boudiner",
    "boudinerai": "boudiner",
    "boudineraient": "boudiner",
    "boudinerais": "boudiner",
    "boudinerait": "boudiner",
    "boudineras": "boudiner",
    "boudinerez": "boudiner",
    "boudineriez": "boudiner",
    "boudinerions": "boudiner",
    "boudinerons": "boudiner",
    "boudineront": "boudiner",
    "boudines": "boudiner",
    "boudinez": "boudiner",
    "boudiniez": "boudiner",
    "boudinions": "boudiner",
    "boudinons": "boudiner",
    "boudins": "boudin",
    "boudinâmes": "boudiner",
    "boudinât": "boudiner",
    "boudinâtes": "boudiner",
    "boudinèrent": "boudiner",
    "boudiné": "boudiner",
    "boudinée": "boudiner",
    "boudinées": "boudiner",
    "boudinés": "boudiner",
    "boudions": "bouder",
    "boudoirs": "boudoir",
    "boudons": "bouder",
    "boudâmes": "bouder",
    "boudât": "bouder",
    "boudâtes": "bouder",
    "boudèrent": "bouder",
    "boudé": "bouder",
    "boudée": "bouder",
    "boudées": "bouder",
    "boudés": "bouder",
    "boues": "boue",
    "boueuse": "boueux",
    "boueuses": "boueux",
    "bouffa": "bouffer",
    "bouffai": "bouffer",
    "bouffaient": "bouffer",
    "bouffais": "bouffer",
    "bouffait": "bouffer",
    "bouffant": "bouffer",
    "bouffante": "bouffant",
    "bouffantes": "bouffant",
    "bouffants": "bouffant",
    "bouffardes": "bouffarde",
    "bouffas": "bouffer",
    "bouffasse": "bouffer",
    "bouffassent": "bouffer",
    "bouffasses": "bouffer",
    "bouffassiez": "bouffer",
    "bouffassions": "bouffer",
    "bouffe": "bouffer",
    "bouffent": "bouffer",
    "bouffera": "bouffer",
    "boufferai": "bouffer",
    "boufferaient": "bouffer",
    "boufferais": "bouffer",
    "boufferait": "bouffer",
    "boufferas": "bouffer",
    "boufferez": "bouffer",
    "boufferiez": "bouffer",
    "boufferions": "bouffer",
    "boufferons": "bouffer",
    "boufferont": "bouffer",
    "bouffes": "bouffer",
    "bouffettes": "bouffette",
    "bouffeurs": "bouffeur",
    "bouffeuse": "bouffeur",
    "bouffeuses": "bouffeur",
    "bouffez": "bouffer",
    "bouffi": "bouffir",
    "bouffie": "bouffir",
    "bouffies": "bouffir",
    "bouffiez": "bouffer",
    "bouffions": "bouffer",
    "bouffira": "bouffir",
    "bouffirai": "bouffir",
    "bouffiraient": "bouffir",
    "bouffirais": "bouffir",
    "bouffirait": "bouffir",
    "bouffiras": "bouffir",
    "bouffirent": "bouffir",
    "bouffirez": "bouffir",
    "bouffiriez": "bouffir",
    "bouffirions": "bouffir",
    "bouffirons": "bouffir",
    "bouffiront": "bouffir",
    "bouffis": "bouffir",
    "bouffissaient": "bouffir",
    "bouffissais": "bouffir",
    "bouffissait": "bouffir",
    "bouffissant": "bouffir",
    "bouffisse": "bouffir",
    "bouffissent": "bouffir",
    "bouffisses": "bouffir",
    "bouffissez": "bouffir",
    "bouffissiez": "bouffir",
    "bouffissions": "bouffir",
    "bouffissons": "bouffir",
    "bouffissures": "bouffissure",
    "bouffit": "bouffir",
    "bouffonna": "bouffonner",
    "bouffonnait": "bouffonner",
    "bouffonnant": "bouffonner",
    "bouffonnante": "bouffonnant",
    "bouffonnantes": "bouffonnant",
    "bouffonnants": "bouffonnant",
    "bouffonne": "bouffon",
    "bouffonneries": "bouffonnerie",
    "bouffonnes": "bouffonner",
    "bouffonneuse": "bouffonneux",
    "bouffonneuses": "bouffonneux",
    "bouffons": "bouffon",
    "bouffâmes": "bouffer",
    "bouffât": "bouffer",
    "bouffâtes": "bouffer",
    "bouffèrent": "bouffer",
    "bouffé": "bouffer",
    "bouffée": "bouffer",
    "bouffées": "bouffer",
    "bouffés": "bouffer",
    "bouffîmes": "bouffir",
    "bouffît": "bouffir",
    "bouffîtes": "bouffir",
    "bougainvilliers": "bougainvillier",
    "bougainvillées": "bougainvillée",
    "bouge": "bouger",
    "bougea": "bouger",
    "bougeai": "bouger",
    "bougeaient": "bouger",
    "bougeais": "bouger",
    "bougeait": "bouger",
    "bougeant": "bouger",
    "bougeas": "bouger",
    "bougeasse": "bouger",
    "bougeassent": "bouger",
    "bougeasses": "bouger",
    "bougeassiez": "bouger",
    "bougeassions": "bouger",
    "bougent": "bouger",
    "bougeoirs": "bougeoir",
    "bougeons": "bouger",
    "bougeottes": "bougeotte",
    "bougera": "bouger",
    "bougerai": "bouger",
    "bougeraient": "bouger",
    "bougerais": "bouger",
    "bougerait": "bouger",
    "bougeras": "bouger",
    "bougerez": "bouger",
    "bougeriez": "bouger",
    "bougerions": "bouger",
    "bougerons": "bouger",
    "bougeront": "bouger",
    "bouges": "bouger",
    "bougez": "bouger",
    "bougeâmes": "bouger",
    "bougeât": "bouger",
    "bougeâtes": "bouger",
    "bougies": "bougie",
    "bougiez": "bougier",
    "bougions": "bouger",
    "bougnats": "bougnat",
    "bougne": "bougner",
    "bougnes": "bougner",
    "bougnoules": "bougnoule",
    "bougonna": "bougonner",
    "bougonnai": "bougonner",
    "bougonnaient": "bougonner",
    "bougonnais": "bougonner",
    "bougonnait": "bougonner",
    "bougonnant": "bougonner",
    "bougonnas": "bougonner",
    "bougonnasse": "bougonner",
    "bougonnassent": "bougonner",
    "bougonnasses": "bougonner",
    "bougonnassiez": "bougonner",
    "bougonnassions": "bougonner",
    "bougonne": "bougonner",
    "bougonnent": "bougonner",
    "bougonnera": "bougonner",
    "bougonnerai": "bougonner",
    "bougonneraient": "bougonner",
    "bougonnerais": "bougonner",
    "bougonnerait": "bougonner",
    "bougonneras": "bougonner",
    "bougonnerez": "bougonner",
    "bougonneriez": "bougonner",
    "bougonnerions": "bougonner",
    "bougonnerons": "bougonner",
    "bougonneront": "bougonner",
    "bougonnes": "bougonner",
    "bougonnez": "bougonner",
    "bougonniez": "bougonner",
    "bougonnions": "bougonner",
    "bougonnons": "bougonner",
    "bougonnâmes": "bougonner",
    "bougonnât": "bougonner",
    "bougonnâtes": "bougonner",
    "bougonnèrent": "bougonner",
    "bougonné": "bougonner",
    "bougonnée": "bougonner",
    "bougonnées": "bougonner",
    "bougonnés": "bougonner",
    "bougons": "bougon",
    "bougreries": "bougrerie",
    "bougres": "bougre",
    "bougresse": "bougre",
    "bougresses": "bougre",
    "bougèrent": "bouger",
    "bougé": "bouger",
    "bougée": "bouger",
    "bougées": "bouger",
    "bougés": "bouger",
    "bouibouis": "bouiboui",
    "bouillabaisses": "bouillabaisse",
    "bouillaient": "bouillir",
    "bouillais": "bouillir",
    "bouillait": "bouillir",
    "bouillant": "bouillir",
    "bouillante": "bouillant",
    "bouillantes": "bouillant",
    "bouillants": "bouillant",
    "bouille": "bouillir",
    "bouillent": "bouillir",
    "bouilles": "bouillir",
    "bouilleurs": "bouilleur",
    "bouillez": "bouillir",
    "bouilli": "bouillir",
    "bouillie": "bouillir",
    "bouillies": "bouillir",
    "bouilliez": "bouillir",
    "bouillions": "bouillir",
    "bouillira": "bouillir",
    "bouillirai": "bouillir",
    "bouilliraient": "bouillir",
    "bouillirais": "bouillir",
    "bouillirait": "bouillir",
    "bouilliras": "bouillir",
    "bouillirent": "bouillir",
    "bouillirez": "bouillir",
    "bouilliriez": "bouillir",
    "bouillirions": "bouillir",
    "bouillirons": "bouillir",
    "bouilliront": "bouillir",
    "bouillis": "bouillir",
    "bouillisse": "bouillir",
    "bouillissent": "bouillir",
    "bouillisses": "bouillir",
    "bouillissiez": "bouillir",
    "bouillissions": "bouillir",
    "bouillit": "bouillir",
    "bouilloires": "bouilloire",
    "bouillonna": "bouillonner",
    "bouillonnai": "bouillonner",
    "bouillonnaient": "bouillonner",
    "bouillonnais": "bouillonner",
    "bouillonnait": "bouillonner",
    "bouillonnant": "bouillonner",
    "bouillonnante": "bouillonnant",
    "bouillonnantes": "bouillonnant",
    "bouillonnants": "bouillonnant",
    "bouillonnas": "bouillonner",
    "bouillonnasse": "bouillonner",
    "bouillonnassent": "bouillonner",
    "bouillonnasses": "bouillonner",
    "bouillonnassiez": "bouillonner",
    "bouillonnassions": "bouillonner",
    "bouillonne": "bouillonner",
    "bouillonnements": "bouillonnement",
    "bouillonnent": "bouillonner",
    "bouillonnera": "bouillonner",
    "bouillonnerai": "bouillonner",
    "bouillonneraient": "bouillonner",
    "bouillonnerais": "bouillonner",
    "bouillonnerait": "bouillonner",
    "bouillonneras": "bouillonner",
    "bouillonnerez": "bouillonner",
    "bouillonneriez": "bouillonner",
    "bouillonnerions": "bouillonner",
    "bouillonnerons": "bouillonner",
    "bouillonneront": "bouillonner",
    "bouillonnes": "bouillonner",
    "bouillonnez": "bouillonner",
    "bouillonniez": "bouillonner",
    "bouillonnions": "bouillonner",
    "bouillonnons": "bouillonner",
    "bouillonnâmes": "bouillonner",
    "bouillonnât": "bouillonner",
    "bouillonnâtes": "bouillonner",
    "bouillonnèrent": "bouillonner",
    "bouillonné": "bouillonner",
    "bouillonnée": "bouillonner",
    "bouillonnées": "bouillonner",
    "bouillonnés": "bouillonner",
    "bouillons": "bouillon",
    "bouillottait": "bouillotter",
    "bouillottes": "bouillotte",
    "bouillîmes": "bouillir",
    "bouillît": "bouillir",
    "bouillîtes": "bouillir",
    "bouis-bouis": "boui-boui",
    "boul.": "boulevard",
    "boula": "bouler",
    "boulait": "bouler",
    "boulangeries": "boulangerie",
    "boulangers": "boulanger",
    "boulangère": "boulanger",
    "boulangères": "boulanger",
    "boulants": "boulant",
    "boule": "bouler",
    "bouleaux": "bouleau",
    "bouledogues": "bouledogue",
    "boulent": "bouler",
    "boules": "bouler",
    "boules-de-neige": "boule-de-neige",
    "boulets": "boulet",
    "boulettes": "boulette",
    "boulevardiers": "boulevardier",
    "boulevardière": "boulevardier",
    "boulevards": "boulevard",
    "bouleversa": "bouleverser",
    "bouleversai": "bouleverser",
    "bouleversaient": "bouleverser",
    "bouleversais": "bouleverser",
    "bouleversait": "bouleverser",
    "bouleversant": "bouleverser",
    "bouleversante": "bouleversant",
    "bouleversantes": "bouleversant",
    "bouleversants": "bouleversant",
    "bouleversas": "bouleverser",
    "bouleversasse": "bouleverser",
    "bouleversassent": "bouleverser",
    "bouleversasses": "bouleverser",
    "bouleversassiez": "bouleverser",
    "bouleversassions": "bouleverser",
    "bouleverse": "bouleverser",
    "bouleversements": "bouleversement",
    "bouleversent": "bouleverser",
    "bouleversera": "bouleverser",
    "bouleverserai": "bouleverser",
    "bouleverseraient": "bouleverser",
    "bouleverserais": "bouleverser",
    "bouleverserait": "bouleverser",
    "bouleverseras": "bouleverser",
    "bouleverserez": "bouleverser",
    "bouleverseriez": "bouleverser",
    "bouleverserions": "bouleverser",
    "bouleverserons": "bouleverser",
    "bouleverseront": "bouleverser",
    "bouleverses": "bouleverser",
    "bouleversez": "bouleverser",
    "bouleversiez": "bouleverser",
    "bouleversions": "bouleverser",
    "bouleversons": "bouleverser",
    "bouleversâmes": "bouleverser",
    "bouleversât": "bouleverser",
    "bouleversâtes": "bouleverser",
    "bouleversèrent": "bouleverser",
    "bouleversé": "bouleverser",
    "bouleversée": "bouleverser",
    "bouleversées": "bouleverser",
    "bouleversés": "bouleverser",
    "bouliers": "boulier",
    "boulimies": "boulimie",
    "boulimiques": "boulimique",
    "boulines": "bouline",
    "boulingrins": "boulingrin",
    "boulins": "boulin",
    "boulistes": "bouliste",
    "boulochait": "boulocher",
    "boulonna": "boulonner",
    "boulonnai": "boulonner",
    "boulonnaient": "boulonner",
    "boulonnais": "boulonner",
    "boulonnait": "boulonner",
    "boulonnant": "boulonner",
    "boulonnas": "boulonner",
    "boulonnasse": "boulonner",
    "boulonnassent": "boulonner",
    "boulonnasses": "boulonner",
    "boulonnassiez": "boulonner",
    "boulonnassions": "boulonner",
    "boulonne": "boulonner",
    "boulonnent": "boulonner",
    "boulonnera": "boulonner",
    "boulonnerai": "boulonner",
    "boulonneraient": "boulonner",
    "boulonnerais": "boulonner",
    "boulonnerait": "boulonner",
    "boulonneras": "boulonner",
    "boulonnerez": "boulonner",
    "boulonneriez": "boulonner",
    "boulonnerions": "boulonner",
    "boulonnerons": "boulonner",
    "boulonneront": "boulonner",
    "boulonnes": "boulonner",
    "boulonnez": "boulonner",
    "boulonniez": "boulonner",
    "boulonnions": "boulonner",
    "boulonnons": "boulonner",
    "boulonnâmes": "boulonner",
    "boulonnât": "boulonner",
    "boulonnâtes": "boulonner",
    "boulonnèrent": "boulonner",
    "boulonné": "boulonner",
    "boulonnée": "boulonner",
    "boulonnées": "boulonner",
    "boulonnés": "boulonner",
    "boulons": "boulon",
    "boulots": "boulot",
    "boulotta": "boulotter",
    "boulottai": "boulotter",
    "boulottaient": "boulotter",
    "boulottais": "boulotter",
    "boulottait": "boulotter",
    "boulottant": "boulotter",
    "boulottas": "boulotter",
    "boulottasse": "boulotter",
    "boulottassent": "boulotter",
    "boulottasses": "boulotter",
    "boulottassiez": "boulotter",
    "boulottassions": "boulotter",
    "boulotte": "boulotter",
    "boulottent": "boulotter",
    "boulottera": "boulotter",
    "boulotterai": "boulotter",
    "boulotteraient": "boulotter",
    "boulotterais": "boulotter",
    "boulotterait": "boulotter",
    "boulotteras": "boulotter",
    "boulotterez": "boulotter",
    "boulotteriez": "boulotter",
    "boulotterions": "boulotter",
    "boulotterons": "boulotter",
    "boulotteront": "boulotter",
    "boulottes": "boulotter",
    "boulottez": "boulotter",
    "boulottiez": "boulotter",
    "boulottions": "boulotter",
    "boulottons": "boulotter",
    "boulottâmes": "boulotter",
    "boulottât": "boulotter",
    "boulottâtes": "boulotter",
    "boulottèrent": "boulotter",
    "boulotté": "boulotter",
    "boulottée": "boulotter",
    "boulottées": "boulotter",
    "boulottés": "boulotter",
    "boulus": "boulu",
    "boulé": "bouler",
    "boulés": "bouler",
    "boumaient": "boumer",
    "boumait": "boumer",
    "boume": "boumer",
    "boums": "boum",
    "boumé": "boumer",
    "bouniouls": "bounioul",
    "bouquetins": "bouquetin",
    "bouquetière": "bouquetier",
    "bouquets": "bouquet",
    "bouquinais": "bouquiner",
    "bouquinait": "bouquiner",
    "bouquinant": "bouquiner",
    "bouquine": "bouquiner",
    "bouquinerait": "bouquiner",
    "bouquinistes": "bouquiniste",
    "bouquins": "bouquin",
    "bouquiné": "bouquiner",
    "bourbes": "bourbe",
    "bourbeuse": "bourbeux",
    "bourbeuses": "bourbeux",
    "bourbiers": "bourbier",
    "bourbillons": "bourbillon",
    "bourbonienne": "bourbonien",
    "bourbons": "bourbon",
    "bourdaines": "bourdaine",
    "bourdalous": "bourdalou",
    "bourdes": "bourde",
    "bourdonna": "bourdonner",
    "bourdonnai": "bourdonner",
    "bourdonnaient": "bourdonner",
    "bourdonnais": "bourdonner",
    "bourdonnait": "bourdonner",
    "bourdonnant": "bourdonner",
    "bourdonnante": "bourdonnant",
    "bourdonnantes": "bourdonnant",
    "bourdonnants": "bourdonnant",
    "bourdonnas": "bourdonner",
    "bourdonnasse": "bourdonner",
    "bourdonnassent": "bourdonner",
    "bourdonnasses": "bourdonner",
    "bourdonnassiez": "bourdonner",
    "bourdonnassions": "bourdonner",
    "bourdonne": "bourdonner",
    "bourdonnements": "bourdonnement",
    "bourdonnent": "bourdonner",
    "bourdonnera": "bourdonner",
    "bourdonnerai": "bourdonner",
    "bourdonneraient": "bourdonner",
    "bourdonnerais": "bourdonner",
    "bourdonnerait": "bourdonner",
    "bourdonneras": "bourdonner",
    "bourdonnerez": "bourdonner",
    "bourdonneriez": "bourdonner",
    "bourdonnerions": "bourdonner",
    "bourdonnerons": "bourdonner",
    "bourdonneront": "bourdonner",
    "bourdonnes": "bourdonner",
    "bourdonnez": "bourdonner",
    "bourdonniez": "bourdonner",
    "bourdonnions": "bourdonner",
    "bourdonnons": "bourdonner",
    "bourdonnâmes": "bourdonner",
    "bourdonnât": "bourdonner",
    "bourdonnâtes": "bourdonner",
    "bourdonnèrent": "bourdonner",
    "bourdonné": "bourdonner",
    "bourdonnée": "bourdonner",
    "bourdonnées": "bourdonner",
    "bourdonnés": "bourdonner",
    "bourdons": "bourdon",
    "bourgades": "bourgade",
    "bourgeoise": "bourgeois",
    "bourgeoises": "bourgeois",
    "bourgeoisies": "bourgeoisie",
    "bourgeonna": "bourgeonner",
    "bourgeonnai": "bourgeonner",
    "bourgeonnaient": "bourgeonner",
    "bourgeonnais": "bourgeonner",
    "bourgeonnait": "bourgeonner",
    "bourgeonnant": "bourgeonner",
    "bourgeonnante": "bourgeonnant",
    "bourgeonnants": "bourgeonnant",
    "bourgeonnas": "bourgeonner",
    "bourgeonnasse": "bourgeonner",
    "bourgeonnassent": "bourgeonner",
    "bourgeonnasses": "bourgeonner",
    "bourgeonnassiez": "bourgeonner",
    "bourgeonnassions": "bourgeonner",
    "bourgeonne": "bourgeonner",
    "bourgeonnements": "bourgeonnement",
    "bourgeonnent": "bourgeonner",
    "bourgeonnera": "bourgeonner",
    "bourgeonnerai": "bourgeonner",
    "bourgeonneraient": "bourgeonner",
    "bourgeonnerais": "bourgeonner",
    "bourgeonnerait": "bourgeonner",
    "bourgeonneras": "bourgeonner",
    "bourgeonnerez": "bourgeonner",
    "bourgeonneriez": "bourgeonner",
    "bourgeonnerions": "bourgeonner",
    "bourgeonnerons": "bourgeonner",
    "bourgeonneront": "bourgeonner",
    "bourgeonnes": "bourgeonner",
    "bourgeonneuse": "bourgeonneux",
    "bourgeonnez": "bourgeonner",
    "bourgeonniez": "bourgeonner",
    "bourgeonnions": "bourgeonner",
    "bourgeonnons": "bourgeonner",
    "bourgeonnâmes": "bourgeonner",
    "bourgeonnât": "bourgeonner",
    "bourgeonnâtes": "bourgeonner",
    "bourgeonnèrent": "bourgeonner",
    "bourgeonné": "bourgeonner",
    "bourgeonnée": "bourgeonner",
    "bourgeonnées": "bourgeonner",
    "bourgeonnés": "bourgeonner",
    "bourgeons": "bourgeon",
    "bourgerons": "bourgeron",
    "bourges": "bourge",
    "bourgmestres": "bourgmestre",
    "bourgognes": "bourgogne",
    "bourgs": "bourg",
    "bourgues": "bourgue",
    "bourguignonne": "bourguignon",
    "bourguignonnes": "bourguignon",
    "bourguignons": "bourguignon",
    "bouriates": "bouriate",
    "bourlingua": "bourlinguer",
    "bourlinguai": "bourlinguer",
    "bourlinguaient": "bourlinguer",
    "bourlinguais": "bourlinguer",
    "bourlinguait": "bourlinguer",
    "bourlinguant": "bourlinguer",
    "bourlinguas": "bourlinguer",
    "bourlinguasse": "bourlinguer",
    "bourlinguassent": "bourlinguer",
    "bourlinguasses": "bourlinguer",
    "bourlinguassiez": "bourlinguer",
    "bourlinguassions": "bourlinguer",
    "bourlingue": "bourlinguer",
    "bourlinguent": "bourlinguer",
    "bourlinguera": "bourlinguer",
    "bourlinguerai": "bourlinguer",
    "bourlingueraient": "bourlinguer",
    "bourlinguerais": "bourlinguer",
    "bourlinguerait": "bourlinguer",
    "bourlingueras": "bourlinguer",
    "bourlinguerez": "bourlinguer",
    "bourlingueriez": "bourlinguer",
    "bourlinguerions": "bourlinguer",
    "bourlinguerons": "bourlinguer",
    "bourlingueront": "bourlinguer",
    "bourlingues": "bourlinguer",
    "bourlingueuses": "bourlingueur",
    "bourlinguez": "bourlinguer",
    "bourlinguiez": "bourlinguer",
    "bourlinguions": "bourlinguer",
    "bourlinguons": "bourlinguer",
    "bourlinguâmes": "bourlinguer",
    "bourlinguât": "bourlinguer",
    "bourlinguâtes": "bourlinguer",
    "bourlinguèrent": "bourlinguer",
    "bourlingué": "bourlinguer",
    "bourra": "bourrer",
    "bourraches": "bourrache",
    "bourrades": "bourrade",
    "bourrages": "bourrage",
    "bourrai": "bourrer",
    "bourraient": "bourrer",
    "bourrais": "bourrer",
    "bourrait": "bourrer",
    "bourrant": "bourrer",
    "bourras": "bourrer",
    "bourrasques": "bourrasque",
    "bourrasse": "bourrer",
    "bourrassent": "bourrer",
    "bourrasses": "bourrer",
    "bourrassiez": "bourrer",
    "bourrassions": "bourrer",
    "bourrative": "bourratif",
    "bourratives": "bourratif",
    "bourre": "bourrer",
    "bourreaux": "bourreau",
    "bourrela": "bourreler",
    "bourrelai": "bourreler",
    "bourrelaient": "bourreler",
    "bourrelais": "bourreler",
    "bourrelait": "bourreler",
    "bourrelant": "bourreler",
    "bourrelas": "bourreler",
    "bourrelasse": "bourreler",
    "bourrelassent": "bourreler",
    "bourrelasses": "bourreler",
    "bourrelassiez": "bourreler",
    "bourrelassions": "bourreler",
    "bourrelets": "bourrelet",
    "bourrelez": "bourreler",
    "bourreliers": "bourrelier",
    "bourreliez": "bourreler",
    "bourrelions": "bourreler",
    "bourrelle": "bourreler",
    "bourrellent": "bourreler",
    "bourrellera": "bourreler",
    "bourrellerai": "bourreler",
    "bourrelleraient": "bourreler",
    "bourrellerais": "bourreler",
    "bourrellerait": "bourreler",
    "bourrelleras": "bourreler",
    "bourrellerez": "bourreler",
    "bourrelleries": "bourrellerie",
    "bourrelleriez": "bourreler",
    "bourrellerions": "bourreler",
    "bourrellerons": "bourreler",
    "bourrelleront": "bourreler",
    "bourrelles": "bourreler",
    "bourrelons": "bourreler",
    "bourrelâmes": "bourreler",
    "bourrelât": "bourreler",
    "bourrelâtes": "bourreler",
    "bourrelèrent": "bourreler",
    "bourrelé": "bourreler",
    "bourrelée": "bourreler",
    "bourrelées": "bourreler",
    "bourrelés": "bourreler",
    "bourrent": "bourrer",
    "bourrera": "bourrer",
    "bourrerai": "bourrer",
    "bourreraient": "bourrer",
    "bourrerais": "bourrer",
    "bourrerait": "bourrer",
    "bourreras": "bourrer",
    "bourrerez": "bourrer",
    "bourreriez": "bourrer",
    "bourrerions": "bourrer",
    "bourrerons": "bourrer",
    "bourreront": "bourrer",
    "bourres": "bourrer",
    "bourrez": "bourrer",
    "bourriches": "bourriche",
    "bourricots": "bourricot",
    "bourrides": "bourride",
    "bourriez": "bourrer",
    "bourrins": "bourrin",
    "bourrions": "bourrer",
    "bourriquait": "bourriquer",
    "bourriques": "bourrique",
    "bourriquets": "bourriquet",
    "bourrons": "bourrer",
    "bourrue": "bourru",
    "bourrues": "bourru",
    "bourrus": "bourru",
    "bourrâmes": "bourrer",
    "bourrât": "bourrer",
    "bourrâtes": "bourrer",
    "bourrèlements": "bourrèlement",
    "bourrèrent": "bourrer",
    "bourré": "bourrer",
    "bourrée": "bourrer",
    "bourrées": "bourrer",
    "bourrés": "bourrer",
    "bourses": "bourse",
    "boursicota": "boursicoter",
    "boursicotai": "boursicoter",
    "boursicotaient": "boursicoter",
    "boursicotais": "boursicoter",
    "boursicotait": "boursicoter",
    "boursicotant": "boursicoter",
    "boursicotas": "boursicoter",
    "boursicotasse": "boursicoter",
    "boursicotassent": "boursicoter",
    "boursicotasses": "boursicoter",
    "boursicotassiez": "boursicoter",
    "boursicotassions": "boursicoter",
    "boursicote": "boursicoter",
    "boursicotent": "boursicoter",
    "boursicotera": "boursicoter",
    "boursicoterai": "boursicoter",
    "boursicoteraient": "boursicoter",
    "boursicoterais": "boursicoter",
    "boursicoterait": "boursicoter",
    "boursicoteras": "boursicoter",
    "boursicoterez": "boursicoter",
    "boursicoteriez": "boursicoter",
    "boursicoterions": "boursicoter",
    "boursicoterons": "boursicoter",
    "boursicoteront": "boursicoter",
    "boursicotes": "boursicoter",
    "boursicoteurs": "boursicoteur",
    "boursicotez": "boursicoter",
    "boursicotiez": "boursicoter",
    "boursicotions": "boursicoter",
    "boursicotons": "boursicoter",
    "boursicotâmes": "boursicoter",
    "boursicotât": "boursicoter",
    "boursicotâtes": "boursicoter",
    "boursicotèrent": "boursicoter",
    "boursicoté": "boursicoter",
    "boursiers": "boursier",
    "boursière": "boursier",
    "boursières": "boursier",
    "boursoufla": "boursoufler",
    "boursouflai": "boursoufler",
    "boursouflaient": "boursoufler",
    "boursouflais": "boursoufler",
    "boursouflait": "boursoufler",
    "boursouflant": "boursoufler",
    "boursouflas": "boursoufler",
    "boursouflasse": "boursoufler",
    "boursouflassent": "boursoufler",
    "boursouflasses": "boursoufler",
    "boursouflassiez": "boursoufler",
    "boursouflassions": "boursoufler",
    "boursoufle": "boursoufler",
    "boursouflent": "boursoufler",
    "boursouflera": "boursoufler",
    "boursouflerai": "boursoufler",
    "boursoufleraient": "boursoufler",
    "boursouflerais": "boursoufler",
    "boursouflerait": "boursoufler",
    "boursoufleras": "boursoufler",
    "boursouflerez": "boursoufler",
    "boursoufleriez": "boursoufler",
    "boursouflerions": "boursoufler",
    "boursouflerons": "boursoufler",
    "boursoufleront": "boursoufler",
    "boursoufles": "boursoufler",
    "boursouflez": "boursoufler",
    "boursoufliez": "boursoufler",
    "boursouflions": "boursoufler",
    "boursouflons": "boursoufler",
    "boursouflures": "boursouflure",
    "boursouflâmes": "boursoufler",
    "boursouflât": "boursoufler",
    "boursouflâtes": "boursoufler",
    "boursouflèrent": "boursoufler",
    "boursouflé": "boursoufler",
    "boursouflée": "boursoufler",
    "boursouflées": "boursoufler",
    "boursouflés": "boursoufler",
    "bous": "bouillir",
    "bousards": "bousard",
    "bousbirs": "bousbir",
    "bouscula": "bousculer",
    "bousculades": "bousculade",
    "bousculai": "bousculer",
    "bousculaient": "bousculer",
    "bousculais": "bousculer",
    "bousculait": "bousculer",
    "bousculant": "bousculer",
    "bousculas": "bousculer",
    "bousculasse": "bousculer",
    "bousculassent": "bousculer",
    "bousculasses": "bousculer",
    "bousculassiez": "bousculer",
    "bousculassions": "bousculer",
    "bouscule": "bousculer",
    "bousculent": "bousculer",
    "bousculera": "bousculer",
    "bousculerai": "bousculer",
    "bousculeraient": "bousculer",
    "bousculerais": "bousculer",
    "bousculerait": "bousculer",
    "bousculeras": "bousculer",
    "bousculerez": "bousculer",
    "bousculeriez": "bousculer",
    "bousculerions": "bousculer",
    "bousculerons": "bousculer",
    "bousculeront": "bousculer",
    "bouscules": "bousculer",
    "bousculez": "bousculer",
    "bousculiez": "bousculer",
    "bousculions": "bousculer",
    "bousculons": "bousculer",
    "bousculâmes": "bousculer",
    "bousculât": "bousculer",
    "bousculâtes": "bousculer",
    "bousculèrent": "bousculer",
    "bousculé": "bousculer",
    "bousculée": "bousculer",
    "bousculées": "bousculer",
    "bousculés": "bousculer",
    "bouses": "bouse",
    "bouseuse": "bouseux",
    "bousiers": "bousier",
    "bousilla": "bousiller",
    "bousillages": "bousillage",
    "bousillai": "bousiller",
    "bousillaient": "bousiller",
    "bousillais": "bousiller",
    "bousillait": "bousiller",
    "bousillant": "bousiller",
    "bousillas": "bousiller",
    "bousillasse": "bousiller",
    "bousillassent": "bousiller",
    "bousillasses": "bousiller",
    "bousillassiez": "bousiller",
    "bousillassions": "bousiller",
    "bousille": "bousiller",
    "bousillent": "bousiller",
    "bousillera": "bousiller",
    "bousillerai": "bousiller",
    "bousilleraient": "bousiller",
    "bousillerais": "bousiller",
    "bousillerait": "bousiller",
    "bousilleras": "bousiller",
    "bousillerez": "bousiller",
    "bousilleriez": "bousiller",
    "bousillerions": "bousiller",
    "bousillerons": "bousiller",
    "bousilleront": "bousiller",
    "bousilles": "bousiller",
    "bousillez": "bousiller",
    "bousilliez": "bousiller",
    "bousillions": "bousiller",
    "bousillons": "bousiller",
    "bousillâmes": "bousiller",
    "bousillât": "bousiller",
    "bousillâtes": "bousiller",
    "bousillèrent": "bousiller",
    "bousillé": "bousiller",
    "bousillée": "bousiller",
    "bousillées": "bousiller",
    "bousillés": "bousiller",
    "bousins": "bousin",
    "boussoles": "boussole",
    "boustifailles": "boustifaille",
    "boustifailleuse": "boustifailleur",
    "bout": "bouillir",
    "bouta": "bouter",
    "boutades": "boutade",
    "boutai": "bouter",
    "boutaient": "bouter",
    "boutais": "bouter",
    "boutait": "bouter",
    "boutanches": "boutanche",
    "boutant": "bouter",
    "boutas": "bouter",
    "boutasse": "bouter",
    "boutassent": "bouter",
    "boutasses": "bouter",
    "boutassiez": "bouter",
    "boutassions": "bouter",
    "boute": "bouter",
    "boutefeux": "boutefeu",
    "bouteilles": "bouteille",
    "bouteillons": "bouteillon",
    "boutent": "bouter",
    "boutera": "bouter",
    "bouterai": "bouter",
    "bouteraient": "bouter",
    "bouterais": "bouter",
    "bouterait": "bouter",
    "bouteras": "bouter",
    "bouterez": "bouter",
    "bouteriez": "bouter",
    "bouterions": "bouter",
    "bouterons": "bouter",
    "bouteront": "bouter",
    "boutes": "bouter",
    "bouteurs": "bouteur",
    "boutez": "bouter",
    "bouthéons": "bouthéon",
    "boutiez": "bouter",
    "boutions": "bouter",
    "boutiques": "boutique",
    "boutiquiers": "boutiquier",
    "boutiquière": "boutiquier",
    "boutiquières": "boutiquier",
    "boutiqué": "boutiquer",
    "boutisses": "boutisse",
    "boutonna": "boutonner",
    "boutonnai": "boutonner",
    "boutonnaient": "boutonner",
    "boutonnais": "boutonner",
    "boutonnait": "boutonner",
    "boutonnant": "boutonner",
    "boutonnas": "boutonner",
    "boutonnasse": "boutonner",
    "boutonnassent": "boutonner",
    "boutonnasses": "boutonner",
    "boutonnassiez": "boutonner",
    "boutonnassions": "boutonner",
    "boutonne": "boutonner",
    "boutonnent": "boutonner",
    "boutonnera": "boutonner",
    "boutonnerai": "boutonner",
    "boutonneraient": "boutonner",
    "boutonnerais": "boutonner",
    "boutonnerait": "boutonner",
    "boutonneras": "boutonner",
    "boutonnerez": "boutonner",
    "boutonneriez": "boutonner",
    "boutonnerions": "boutonner",
    "boutonnerons": "boutonner",
    "boutonneront": "boutonner",
    "boutonnes": "boutonner",
    "boutonneuse": "boutonneux",
    "boutonneuses": "boutonneux",
    "boutonnez": "boutonner",
    "boutonniez": "boutonner",
    "boutonnions": "boutonner",
    "boutonnières": "boutonnière",
    "boutonnons": "boutonner",
    "boutonnâmes": "boutonner",
    "boutonnât": "boutonner",
    "boutonnâtes": "boutonner",
    "boutonnèrent": "boutonner",
    "boutonné": "boutonner",
    "boutonnée": "boutonner",
    "boutonnées": "boutonner",
    "boutonnés": "boutonner",
    "boutons": "bouton",
    "boutons-d'argent": "bouton-d'argent",
    "boutons-d'or": "bouton-d'or",
    "boutons-pression": "bouton-pression",
    "boutres": "boutre",
    "bouts": "bout",
    "bouts-dehors": "bout-dehors",
    "bouts-rimés": "bout-rimé",
    "boutures": "bouture",
    "boutâmes": "bouter",
    "boutât": "bouter",
    "boutâtes": "bouter",
    "boutèrent": "bouter",
    "bouté": "bouter",
    "boutée": "bouter",
    "boutées": "bouter",
    "boutés": "bouter",
    "bouviers": "bouvier",
    "bouvilloise": "bouvillois",
    "bouvilloises": "bouvillois",
    "bouvillons": "bouvillon",
    "bouvière": "bouvier",
    "bouvières": "bouvier",
    "bouvreuils": "bouvreuil",
    "bouées": "bouée",
    "bovarysmes": "bovarysme",
    "bovidés": "bovidé",
    "bovine": "bovin",
    "bovines": "bovin",
    "bovins": "bovin",
    "bow-strings": "bow-string",
    "bow-windows": "bow-window",
    "bowlings": "bowling",
    "box-offices": "box-office",
    "boxa": "boxer",
    "boxai": "boxer",
    "boxaient": "boxer",
    "boxais": "boxer",
    "boxait": "boxer",
    "boxant": "boxer",
    "boxas": "boxer",
    "boxasse": "boxer",
    "boxassent": "boxer",
    "boxasses": "boxer",
    "boxassiez": "boxer",
    "boxassions": "boxer",
    "boxe": "boxer",
    "boxent": "boxer",
    "boxera": "boxer",
    "boxerai": "boxer",
    "boxeraient": "boxer",
    "boxerais": "boxer",
    "boxerait": "boxer",
    "boxeras": "boxer",
    "boxerez": "boxer",
    "boxeriez": "boxer",
    "boxerions": "boxer",
    "boxerons": "boxer",
    "boxeront": "boxer",
    "boxers": "boxer",
    "boxes": "boxer",
    "boxeurs": "boxeur",
    "boxeuse": "boxeur",
    "boxeuses": "boxeur",
    "boxez": "boxer",
    "boxiez": "boxer",
    "boxions": "boxer",
    "boxons": "boxon",
    "boxâmes": "boxer",
    "boxât": "boxer",
    "boxâtes": "boxer",
    "boxèrent": "boxer",
    "boxé": "boxer",
    "boxée": "boxer",
    "boxées": "boxer",
    "boxés": "boxer",
    "boy-scouts": "boy-scout",
    "boyards": "boyard",
    "boyaux": "boyau",
    "boycotta": "boycotter",
    "boycottages": "boycottage",
    "boycottai": "boycotter",
    "boycottaient": "boycotter",
    "boycottais": "boycotter",
    "boycottait": "boycotter",
    "boycottant": "boycotter",
    "boycottas": "boycotter",
    "boycottasse": "boycotter",
    "boycottassent": "boycotter",
    "boycottasses": "boycotter",
    "boycottassiez": "boycotter",
    "boycottassions": "boycotter",
    "boycotte": "boycotter",
    "boycottent": "boycotter",
    "boycottera": "boycotter",
    "boycotterai": "boycotter",
    "boycotteraient": "boycotter",
    "boycotterais": "boycotter",
    "boycotterait": "boycotter",
    "boycotteras": "boycotter",
    "boycotterez": "boycotter",
    "boycotteriez": "boycotter",
    "boycotterions": "boycotter",
    "boycotterons": "boycotter",
    "boycotteront": "boycotter",
    "boycottes": "boycotter",
    "boycottez": "boycotter",
    "boycottiez": "boycotter",
    "boycottions": "boycotter",
    "boycottons": "boycotter",
    "boycotts": "boycott",
    "boycottâmes": "boycotter",
    "boycottât": "boycotter",
    "boycottâtes": "boycotter",
    "boycottèrent": "boycotter",
    "boycotté": "boycotter",
    "boycottée": "boycotter",
    "boycottées": "boycotter",
    "boycottés": "boycotter",
    "boys": "boy",
    "boëttes": "boëtte",
    "boîtes": "boîte",
    "boîtes-repas": "boîte-repas",
    "boîtiers": "boîtier",
    "brabançonne": "brabançon",
    "brabançons": "brabançon",
    "bracelets": "bracelet",
    "bracelets-montres": "bracelet-montre",
    "brachiale": "brachial",
    "brachiales": "brachial",
    "brachiaux": "brachial",
    "brachycéphales": "brachycéphale",
    "braconna": "braconner",
    "braconnages": "braconnage",
    "braconnai": "braconner",
    "braconnaient": "braconner",
    "braconnais": "braconner",
    "braconnait": "braconner",
    "braconnant": "braconner",
    "braconnas": "braconner",
    "braconnasse": "braconner",
    "braconnassent": "braconner",
    "braconnasses": "braconner",
    "braconnassiez": "braconner",
    "braconnassions": "braconner",
    "braconne": "braconner",
    "braconnent": "braconner",
    "braconnera": "braconner",
    "braconnerai": "braconner",
    "braconneraient": "braconner",
    "braconnerais": "braconner",
    "braconnerait": "braconner",
    "braconneras": "braconner",
    "braconnerez": "braconner",
    "braconneriez": "braconner",
    "braconnerions": "braconner",
    "braconnerons": "braconner",
    "braconneront": "braconner",
    "braconnes": "braconner",
    "braconnez": "braconner",
    "braconniers": "braconnier",
    "braconniez": "braconner",
    "braconnions": "braconner",
    "braconnière": "braconnier",
    "braconnières": "braconnier",
    "braconnons": "braconner",
    "braconnâmes": "braconner",
    "braconnât": "braconner",
    "braconnâtes": "braconner",
    "braconnèrent": "braconner",
    "braconné": "braconner",
    "braconnée": "braconner",
    "braconnées": "braconner",
    "braconnés": "braconner",
    "bractées": "bractée",
    "brada": "brader",
    "bradai": "brader",
    "bradaient": "brader",
    "bradais": "brader",
    "bradait": "brader",
    "bradant": "brader",
    "bradas": "brader",
    "bradasse": "brader",
    "bradassent": "brader",
    "bradasses": "brader",
    "bradassiez": "brader",
    "bradassions": "brader",
    "brade": "brader",
    "bradent": "brader",
    "bradera": "brader",
    "braderai": "brader",
    "braderaient": "brader",
    "braderais": "brader",
    "braderait": "brader",
    "braderas": "brader",
    "braderez": "brader",
    "braderies": "braderie",
    "braderiez": "brader",
    "braderions": "brader",
    "braderons": "brader",
    "braderont": "brader",
    "brades": "brader",
    "bradez": "brader",
    "bradiez": "brader",
    "bradillons": "bradillon",
    "bradions": "brader",
    "bradons": "brader",
    "bradâmes": "brader",
    "bradât": "brader",
    "bradâtes": "brader",
    "bradèrent": "brader",
    "bradé": "brader",
    "bradée": "brader",
    "bradées": "brader",
    "bradés": "brader",
    "braguettes": "braguette",
    "brahmanes": "brahmane",
    "brahmaniques": "brahmanique",
    "brahmanistes": "brahmaniste",
    "braie": "brayer",
    "braiements": "braiement",
    "braient": "braire",
    "braies": "braie",
    "brailla": "brailler",
    "braillai": "brailler",
    "braillaient": "brailler",
    "braillais": "brailler",
    "braillait": "brailler",
    "braillant": "brailler",
    "braillarde": "braillard",
    "braillardes": "braillard",
    "braillards": "braillard",
    "braillas": "brailler",
    "braillasse": "brailler",
    "braillassent": "brailler",
    "braillasses": "brailler",
    "braillassiez": "brailler",
    "braillassions": "brailler",
    "braille": "brailler",
    "braillements": "braillement",
    "braillent": "brailler",
    "braillera": "brailler",
    "braillerai": "brailler",
    "brailleraient": "brailler",
    "braillerais": "brailler",
    "braillerait": "brailler",
    "brailleras": "brailler",
    "braillerez": "brailler",
    "brailleriez": "brailler",
    "braillerions": "brailler",
    "braillerons": "brailler",
    "brailleront": "brailler",
    "brailles": "brailler",
    "brailleurs": "brailleur",
    "brailleuse": "brailleur",
    "braillez": "brailler",
    "brailliez": "brailler",
    "braillions": "brailler",
    "braillons": "brailler",
    "braillâmes": "brailler",
    "braillât": "brailler",
    "braillâtes": "brailler",
    "braillèrent": "brailler",
    "braillé": "brailler",
    "braillée": "brailler",
    "braillées": "brailler",
    "braillés": "brailler",
    "braiments": "braiment",
    "brain-trusts": "brain-trust",
    "brainstormings": "brainstorming",
    "braira": "braire",
    "brairaient": "braire",
    "brairait": "braire",
    "brairont": "braire",
    "brais": "brai",
    "braise": "braiser",
    "braises": "braiser",
    "braisillante": "braisillant",
    "braisé": "braiser",
    "braisée": "braiser",
    "braisés": "braisé",
    "brait": "braire",
    "brama": "bramer",
    "bramai": "bramer",
    "bramaient": "bramer",
    "bramais": "bramer",
    "bramait": "bramer",
    "bramant": "bramer",
    "bramas": "bramer",
    "bramasse": "bramer",
    "bramassent": "bramer",
    "bramasses": "bramer",
    "bramassiez": "bramer",
    "bramassions": "bramer",
    "brame": "bramer",
    "bramements": "bramement",
    "brament": "bramer",
    "bramera": "bramer",
    "bramerai": "bramer",
    "brameraient": "bramer",
    "bramerais": "bramer",
    "bramerait": "bramer",
    "brameras": "bramer",
    "bramerez": "bramer",
    "brameriez": "bramer",
    "bramerions": "bramer",
    "bramerons": "bramer",
    "brameront": "bramer",
    "brames": "bramer",
    "bramez": "bramer",
    "bramiez": "bramer",
    "bramions": "bramer",
    "bramons": "bramer",
    "bramâmes": "bramer",
    "bramât": "bramer",
    "bramâtes": "bramer",
    "bramèrent": "bramer",
    "bramé": "bramer",
    "bramée": "bramer",
    "bramées": "bramer",
    "bramés": "bramer",
    "brancardiers": "brancardier",
    "brancards": "brancard",
    "brancha": "brancher",
    "branchages": "branchage",
    "branchai": "brancher",
    "branchaient": "brancher",
    "branchais": "brancher",
    "branchait": "brancher",
    "branchant": "brancher",
    "branchas": "brancher",
    "branchasse": "brancher",
    "branchassent": "brancher",
    "branchasses": "brancher",
    "branchassiez": "brancher",
    "branchassions": "brancher",
    "branche": "brancher",
    "branchements": "branchement",
    "branchent": "brancher",
    "branchera": "brancher",
    "brancherai": "brancher",
    "brancheraient": "brancher",
    "brancherais": "brancher",
    "brancherait": "brancher",
    "brancheras": "brancher",
    "brancherez": "brancher",
    "brancheriez": "brancher",
    "brancherions": "brancher",
    "brancherons": "brancher",
    "brancheront": "brancher",
    "branches": "brancher",
    "branchettes": "branchette",
    "branchez": "brancher",
    "branchiale": "branchial",
    "branchiales": "branchial",
    "branchiaux": "branchial",
    "branchies": "branchie",
    "branchiez": "brancher",
    "branchions": "brancher",
    "branchons": "brancher",
    "branchue": "branchu",
    "branchus": "branchu",
    "branchâmes": "brancher",
    "branchât": "brancher",
    "branchâtes": "brancher",
    "branchèrent": "brancher",
    "branché": "brancher",
    "branchée": "brancher",
    "branchées": "brancher",
    "branchés": "brancher",
    "brandades": "brandade",
    "brande": "brand",
    "brandebourgs": "brandebourg",
    "brandes": "brande",
    "brandi": "brandir",
    "brandie": "brandir",
    "brandies": "brandir",
    "brandillons": "brandillon",
    "brandira": "brandir",
    "brandirai": "brandir",
    "brandiraient": "brandir",
    "brandirais": "brandir",
    "brandirait": "brandir",
    "brandiras": "brandir",
    "brandirent": "brandir",
    "brandirez": "brandir",
    "brandiriez": "brandir",
    "brandirions": "brandir",
    "brandirons": "brandir",
    "brandiront": "brandir",
    "brandis": "brandir",
    "brandissaient": "brandir",
    "brandissais": "brandir",
    "brandissait": "brandir",
    "brandissant": "brandir",
    "brandisse": "brandir",
    "brandissent": "brandir",
    "brandisses": "brandir",
    "brandissez": "brandir",
    "brandissiez": "brandir",
    "brandissions": "brandir",
    "brandissons": "brandir",
    "brandit": "brandir",
    "brandons": "brandon",
    "brandouille": "brandouiller",
    "brandys": "brandy",
    "brandîmes": "brandir",
    "brandît": "brandir",
    "brandîtes": "brandir",
    "branla": "branler",
    "branlai": "branler",
    "branlaient": "branler",
    "branlais": "branler",
    "branlait": "branler",
    "branlant": "branler",
    "branlante": "branlant",
    "branlantes": "branlant",
    "branlants": "branlant",
    "branlas": "branler",
    "branlasse": "branler",
    "branlassent": "branler",
    "branlasses": "branler",
    "branlassiez": "branler",
    "branlassions": "branler",
    "branle": "branler",
    "branlent": "branler",
    "branlera": "branler",
    "branlerai": "branler",
    "branleraient": "branler",
    "branlerais": "branler",
    "branlerait": "branler",
    "branleras": "branler",
    "branlerez": "branler",
    "branleriez": "branler",
    "branlerions": "branler",
    "branlerons": "branler",
    "branleront": "branler",
    "branles": "branler",
    "branlettes": "branlette",
    "branleurs": "branleur",
    "branleuse": "branleur",
    "branleuses": "branleur",
    "branlez": "branler",
    "branliez": "branler",
    "branlions": "branler",
    "branlochais": "branlocher",
    "branlochant": "branlocher",
    "branlochent": "branlocher",
    "branlons": "branler",
    "branlâmes": "branler",
    "branlât": "branler",
    "branlâtes": "branler",
    "branlèrent": "branler",
    "branlé": "branler",
    "branlée": "branler",
    "branlées": "branler",
    "branlés": "branler",
    "branques": "branque",
    "branquignols": "branquignol",
    "braqua": "braquer",
    "braquages": "braquage",
    "braquai": "braquer",
    "braquaient": "braquer",
    "braquais": "braquer",
    "braquait": "braquer",
    "braquant": "braquer",
    "braquas": "braquer",
    "braquasse": "braquer",
    "braquassent": "braquer",
    "braquasses": "braquer",
    "braquassiez": "braquer",
    "braquassions": "braquer",
    "braque": "braquer",
    "braquemarts": "braquemart",
    "braquent": "braquer",
    "braquera": "braquer",
    "braquerai": "braquer",
    "braqueraient": "braquer",
    "braquerais": "braquer",
    "braquerait": "braquer",
    "braqueras": "braquer",
    "braquerez": "braquer",
    "braqueriez": "braquer",
    "braquerions": "braquer",
    "braquerons": "braquer",
    "braqueront": "braquer",
    "braques": "braquer",
    "braquets": "braquet",
    "braqueurs": "braqueur",
    "braqueuse": "braqueur",
    "braqueuses": "braqueur",
    "braquez": "braquer",
    "braquiez": "braquer",
    "braquions": "braquer",
    "braquons": "braquer",
    "braquâmes": "braquer",
    "braquât": "braquer",
    "braquâtes": "braquer",
    "braquèrent": "braquer",
    "braqué": "braquer",
    "braquée": "braquer",
    "braquées": "braquer",
    "braqués": "braquer",
    "brasa": "braser",
    "brasai": "braser",
    "brasaient": "braser",
    "brasais": "braser",
    "brasait": "braser",
    "brasant": "braser",
    "brasas": "braser",
    "brasasse": "braser",
    "brasassent": "braser",
    "brasasses": "braser",
    "brasassiez": "braser",
    "brasassions": "braser",
    "brase": "braser",
    "brasent": "braser",
    "brasera": "braser",
    "braserai": "braser",
    "braseraient": "braser",
    "braserais": "braser",
    "braserait": "braser",
    "braseras": "braser",
    "braserez": "braser",
    "braseriez": "braser",
    "braserions": "braser",
    "braserons": "braser",
    "braseront": "braser",
    "braseros": "brasero",
    "brases": "braser",
    "brasez": "braser",
    "brasiers": "brasier",
    "brasiez": "braser",
    "brasillaient": "brasiller",
    "brasillait": "brasiller",
    "brasillant": "brasiller",
    "brasille": "brasiller",
    "brasions": "braser",
    "brasons": "braser",
    "brassa": "brasser",
    "brassages": "brassage",
    "brassai": "brasser",
    "brassaient": "brasser",
    "brassais": "brasser",
    "brassait": "brasser",
    "brassant": "brasser",
    "brassards": "brassard",
    "brassas": "brasser",
    "brassasse": "brasser",
    "brassassent": "brasser",
    "brassasses": "brasser",
    "brassassiez": "brasser",
    "brassassions": "brasser",
    "brasse": "brasser",
    "brassent": "brasser",
    "brassera": "brasser",
    "brasserai": "brasser",
    "brasseraient": "brasser",
    "brasserais": "brasser",
    "brasserait": "brasser",
    "brasseras": "brasser",
    "brasserez": "brasser",
    "brasseries": "brasserie",
    "brasseriez": "brasser",
    "brasserions": "brasser",
    "brasserons": "brasser",
    "brasseront": "brasser",
    "brasses": "brasser",
    "brasseurs": "brasseur",
    "brassez": "brasser",
    "brassicoles": "brassicole",
    "brassiez": "brasser",
    "brassions": "brasser",
    "brassières": "brassière",
    "brassons": "brasser",
    "brassâmes": "brasser",
    "brassât": "brasser",
    "brassâtes": "brasser",
    "brassèrent": "brasser",
    "brassé": "brasser",
    "brassée": "brasser",
    "brassées": "brasser",
    "brassés": "brasser",
    "brasâmes": "braser",
    "brasât": "braser",
    "brasâtes": "braser",
    "brasèrent": "braser",
    "brasé": "braser",
    "brasée": "braser",
    "brasées": "braser",
    "brasés": "braser",
    "brava": "braver",
    "bravaches": "bravache",
    "bravades": "bravade",
    "bravai": "braver",
    "bravaient": "braver",
    "bravais": "braver",
    "bravait": "braver",
    "bravant": "braver",
    "bravas": "braver",
    "bravasse": "braver",
    "bravassent": "braver",
    "bravasses": "braver",
    "bravassiez": "braver",
    "bravassions": "braver",
    "brave": "braver",
    "bravent": "braver",
    "bravera": "braver",
    "braverai": "braver",
    "braveraient": "braver",
    "braverais": "braver",
    "braverait": "braver",
    "braveras": "braver",
    "braverez": "braver",
    "braveries": "braverie",
    "braveriez": "braver",
    "braverions": "braver",
    "braverons": "braver",
    "braveront": "braver",
    "braves": "braver",
    "bravez": "braver",
    "braviez": "braver",
    "bravions": "braver",
    "bravons": "braver",
    "bravos": "bravo",
    "bravoures": "bravoure",
    "bravâmes": "braver",
    "bravât": "braver",
    "bravâtes": "braver",
    "bravèrent": "braver",
    "bravé": "braver",
    "bravée": "braver",
    "bravées": "braver",
    "bravés": "braver",
    "brayaient": "brayer",
    "brayait": "brayer",
    "brayes": "brayer",
    "brayons": "brayon",
    "breakfasts": "breakfast",
    "breaks": "break",
    "brechtienne": "brechtien",
    "bredouilla": "bredouiller",
    "bredouillai": "bredouiller",
    "bredouillaient": "bredouiller",
    "bredouillais": "bredouiller",
    "bredouillait": "bredouiller",
    "bredouillant": "bredouiller",
    "bredouillante": "bredouillant",
    "bredouillas": "bredouiller",
    "bredouillasse": "bredouiller",
    "bredouillassent": "bredouiller",
    "bredouillasses": "bredouiller",
    "bredouillassiez": "bredouiller",
    "bredouillassions": "bredouiller",
    "bredouille": "bredouiller",
    "bredouillements": "bredouillement",
    "bredouillent": "bredouiller",
    "bredouillera": "bredouiller",
    "bredouillerai": "bredouiller",
    "bredouilleraient": "bredouiller",
    "bredouillerais": "bredouiller",
    "bredouillerait": "bredouiller",
    "bredouilleras": "bredouiller",
    "bredouillerez": "bredouiller",
    "bredouilleriez": "bredouiller",
    "bredouillerions": "bredouiller",
    "bredouillerons": "bredouiller",
    "bredouilleront": "bredouiller",
    "bredouilles": "bredouiller",
    "bredouilleurs": "bredouilleur",
    "bredouillez": "bredouiller",
    "bredouilliez": "bredouiller",
    "bredouillions": "bredouiller",
    "bredouillons": "bredouiller",
    "bredouillâmes": "bredouiller",
    "bredouillât": "bredouiller",
    "bredouillâtes": "bredouiller",
    "bredouillèrent": "bredouiller",
    "bredouillé": "bredouiller",
    "bredouillée": "bredouiller",
    "bredouillées": "bredouiller",
    "bredouillés": "bredouiller",
    "brefs": "bref",
    "brejnévienne": "brejnévien",
    "brejnéviennes": "brejnévien",
    "brejnéviens": "brejnévien",
    "brelans": "brelan",
    "breloques": "breloque",
    "breneuses": "breneux",
    "bressane": "bressan",
    "bressanes": "bressan",
    "bressans": "bressan",
    "brestoise": "brestois",
    "bretelles": "bretelle",
    "bretonnants": "bretonnant",
    "bretonne": "breton",
    "bretonnes": "breton",
    "bretons": "breton",
    "bretteurs": "bretteur",
    "bretzels": "bretzel",
    "bretèches": "bretèche",
    "breuils": "breuil",
    "breuvages": "breuvage",
    "breveta": "breveter",
    "brevetabilités": "brevetabilité",
    "brevetables": "brevetable",
    "brevetai": "breveter",
    "brevetaient": "breveter",
    "brevetais": "breveter",
    "brevetait": "breveter",
    "brevetant": "breveter",
    "brevetas": "breveter",
    "brevetasse": "breveter",
    "brevetassent": "breveter",
    "brevetasses": "breveter",
    "brevetassiez": "breveter",
    "brevetassions": "breveter",
    "brevetez": "breveter",
    "brevetiez": "breveter",
    "brevetions": "breveter",
    "brevetons": "breveter",
    "brevets": "brevet",
    "brevette": "breveter",
    "brevettent": "breveter",
    "brevettera": "breveter",
    "brevetterai": "breveter",
    "brevetteraient": "breveter",
    "brevetterais": "breveter",
    "brevetterait": "breveter",
    "brevetteras": "breveter",
    "brevetterez": "breveter",
    "brevetteriez": "breveter",
    "brevetterions": "breveter",
    "brevetterons": "breveter",
    "brevetteront": "breveter",
    "brevettes": "breveter",
    "brevetâmes": "breveter",
    "brevetât": "breveter",
    "brevetâtes": "breveter",
    "brevetèrent": "breveter",
    "breveté": "breveter",
    "brevetée": "breveter",
    "brevetées": "breveter",
    "brevetés": "breveter",
    "briarde": "briard",
    "briards": "briard",
    "bribes": "bribe",
    "bricks": "brick",
    "bricola": "bricoler",
    "bricolages": "bricolage",
    "bricolai": "bricoler",
    "bricolaient": "bricoler",
    "bricolais": "bricoler",
    "bricolait": "bricoler",
    "bricolant": "bricoler",
    "bricolas": "bricoler",
    "bricolasse": "bricoler",
    "bricolassent": "bricoler",
    "bricolasses": "bricoler",
    "bricolassiez": "bricoler",
    "bricolassions": "bricoler",
    "bricole": "bricoler",
    "bricolent": "bricoler",
    "bricolera": "bricoler",
    "bricolerai": "bricoler",
    "bricoleraient": "bricoler",
    "bricolerais": "bricoler",
    "bricolerait": "bricoler",
    "bricoleras": "bricoler",
    "bricolerez": "bricoler",
    "bricoleriez": "bricoler",
    "bricolerions": "bricoler",
    "bricolerons": "bricoler",
    "bricoleront": "bricoler",
    "bricoles": "bricoler",
    "bricoleurs": "bricoleur",
    "bricoleuse": "bricoleur",
    "bricoleuses": "bricoleur",
    "bricolez": "bricoler",
    "bricoliez": "bricoler",
    "bricolions": "bricoler",
    "bricolons": "bricoler",
    "bricolos": "bricolo",
    "bricolâmes": "bricoler",
    "bricolât": "bricoler",
    "bricolâtes": "bricoler",
    "bricolèrent": "bricoler",
    "bricolé": "bricoler",
    "bricolée": "bricoler",
    "bricolées": "bricoler",
    "bricolés": "bricoler",
    "bridais": "brider",
    "bridait": "brider",
    "bridant": "brider",
    "bride": "brider",
    "brident": "brider",
    "brides": "brider",
    "bridez": "brider",
    "bridgeait": "bridger",
    "bridgeant": "bridger",
    "bridgent": "bridger",
    "bridgeons": "bridger",
    "bridges": "bridge",
    "bridgeurs": "bridgeur",
    "bridgeuse": "bridgeur",
    "bridgez": "bridger",
    "bridgées": "bridger",
    "bridons": "bridon",
    "bridé": "brider",
    "bridée": "brider",
    "bridées": "brider",
    "bridés": "brider",
    "briefe": "briefer",
    "briefera": "briefer",
    "brieferai": "briefer",
    "brieferas": "briefer",
    "briefes": "briefer",
    "briefez": "briefer",
    "briefings": "briefing",
    "briefé": "briefer",
    "briefée": "briefer",
    "briefés": "briefer",
    "bries": "brie",
    "brifez": "brifer",
    "briffe": "briffer",
    "brigades": "brigade",
    "brigadiers": "brigadier",
    "brigadiers-chefs": "brigadier-chef",
    "brigadistes": "brigadiste",
    "briganda": "brigander",
    "brigandages": "brigandage",
    "brigandai": "brigander",
    "brigandaient": "brigander",
    "brigandais": "brigander",
    "brigandait": "brigander",
    "brigandant": "brigander",
    "brigandas": "brigander",
    "brigandasse": "brigander",
    "brigandassent": "brigander",
    "brigandasses": "brigander",
    "brigandassiez": "brigander",
    "brigandassions": "brigander",
    "brigande": "brigander",
    "brigandeaux": "brigandeau",
    "brigandent": "brigander",
    "brigandera": "brigander",
    "briganderai": "brigander",
    "briganderaient": "brigander",
    "briganderais": "brigander",
    "briganderait": "brigander",
    "briganderas": "brigander",
    "briganderez": "brigander",
    "briganderiez": "brigander",
    "briganderions": "brigander",
    "briganderons": "brigander",
    "briganderont": "brigander",
    "brigandes": "brigander",
    "brigandez": "brigander",
    "brigandiez": "brigander",
    "brigandions": "brigander",
    "brigandons": "brigander",
    "brigands": "brigand",
    "brigandâmes": "brigander",
    "brigandât": "brigander",
    "brigandâtes": "brigander",
    "brigandèrent": "brigander",
    "brigandé": "brigander",
    "brigantins": "brigantin",
    "briguaient": "briguer",
    "briguait": "briguer",
    "briguant": "briguer",
    "brigue": "briguer",
    "briguerait": "briguer",
    "brigues": "brigue",
    "briguèrent": "briguer",
    "brigué": "briguer",
    "brilla": "briller",
    "brillai": "briller",
    "brillaient": "briller",
    "brillais": "briller",
    "brillait": "briller",
    "brillances": "brillance",
    "brillant": "briller",
    "brillante": "brillanter",
    "brillantes": "brillant",
    "brillantine": "brillantiner",
    "brillantinée": "brillantiner",
    "brillantinées": "brillantiner",
    "brillantinés": "brillantiner",
    "brillants": "brillant",
    "brillantés": "brillanter",
    "brillas": "briller",
    "brillasse": "briller",
    "brillassent": "briller",
    "brillasses": "briller",
    "brillassiez": "briller",
    "brillassions": "briller",
    "brille": "briller",
    "brillent": "briller",
    "brillera": "briller",
    "brillerai": "briller",
    "brilleraient": "briller",
    "brillerais": "briller",
    "brillerait": "briller",
    "brilleras": "briller",
    "brillerez": "briller",
    "brilleriez": "briller",
    "brillerions": "briller",
    "brillerons": "briller",
    "brilleront": "briller",
    "brilles": "briller",
    "brillez": "briller",
    "brilliante": "brilliant",
    "brilliantes": "brilliant",
    "brilliants": "brilliant",
    "brilliez": "briller",
    "brillions": "briller",
    "brillons": "briller",
    "brillâmes": "briller",
    "brillât": "briller",
    "brillâtes": "briller",
    "brillèrent": "briller",
    "brillé": "briller",
    "brima": "brimer",
    "brimades": "brimade",
    "brimai": "brimer",
    "brimaient": "brimer",
    "brimais": "brimer",
    "brimait": "brimer",
    "brimant": "brimer",
    "brimas": "brimer",
    "brimasse": "brimer",
    "brimassent": "brimer",
    "brimasses": "brimer",
    "brimassiez": "brimer",
    "brimassions": "brimer",
    "brimbala": "brimbaler",
    "brimbalai": "brimbaler",
    "brimbalaient": "brimbaler",
    "brimbalais": "brimbaler",
    "brimbalait": "brimbaler",
    "brimbalant": "brimbaler",
    "brimbalas": "brimbaler",
    "brimbalasse": "brimbaler",
    "brimbalassent": "brimbaler",
    "brimbalasses": "brimbaler",
    "brimbalassiez": "brimbaler",
    "brimbalassions": "brimbaler",
    "brimbale": "brimbaler",
    "brimbalements": "brimbalement",
    "brimbalent": "brimbaler",
    "brimbalera": "brimbaler",
    "brimbalerai": "brimbaler",
    "brimbaleraient": "brimbaler",
    "brimbalerais": "brimbaler",
    "brimbalerait": "brimbaler",
    "brimbaleras": "brimbaler",
    "brimbalerez": "brimbaler",
    "brimbaleriez": "brimbaler",
    "brimbalerions": "brimbaler",
    "brimbalerons": "brimbaler",
    "brimbaleront": "brimbaler",
    "brimbales": "brimbaler",
    "brimbalez": "brimbaler",
    "brimbaliez": "brimbaler",
    "brimbalions": "brimbaler",
    "brimbalons": "brimbaler",
    "brimbalâmes": "brimbaler",
    "brimbalât": "brimbaler",
    "brimbalâtes": "brimbaler",
    "brimbalèrent": "brimbaler",
    "brimbalé": "brimbaler",
    "brimbalée": "brimbaler",
    "brimbalées": "brimbaler",
    "brimbalés": "brimbaler",
    "brimborions": "brimborion",
    "brime": "brimer",
    "briment": "brimer",
    "brimera": "brimer",
    "brimerai": "brimer",
    "brimeraient": "brimer",
    "brimerais": "brimer",
    "brimerait": "brimer",
    "brimeras": "brimer",
    "brimerez": "brimer",
    "brimeriez": "brimer",
    "brimerions": "brimer",
    "brimerons": "brimer",
    "brimeront": "brimer",
    "brimes": "brimer",
    "brimez": "brimer",
    "brimiez": "brimer",
    "brimions": "brimer",
    "brimons": "brimer",
    "brimâmes": "brimer",
    "brimât": "brimer",
    "brimâtes": "brimer",
    "brimèrent": "brimer",
    "brimé": "brimer",
    "brimée": "brimer",
    "brimées": "brimer",
    "brimés": "brimer",
    "brindes": "brinde",
    "brindilles": "brindille",
    "bringuebala": "bringuebaler",
    "bringuebalai": "bringuebaler",
    "bringuebalaient": "bringuebaler",
    "bringuebalais": "bringuebaler",
    "bringuebalait": "bringuebaler",
    "bringuebalant": "bringuebaler",
    "bringuebalante": "bringuebalant",
    "bringuebalantes": "bringuebalant",
    "bringuebalants": "bringuebalant",
    "bringuebalas": "bringuebaler",
    "bringuebalasse": "bringuebaler",
    "bringuebalassent": "bringuebaler",
    "bringuebalasses": "bringuebaler",
    "bringuebalassiez": "bringuebaler",
    "bringuebalassions": "bringuebaler",
    "bringuebale": "bringuebaler",
    "bringuebalent": "bringuebaler",
    "bringuebalera": "bringuebaler",
    "bringuebalerai": "bringuebaler",
    "bringuebaleraient": "bringuebaler",
    "bringuebalerais": "bringuebaler",
    "bringuebalerait": "bringuebaler",
    "bringuebaleras": "bringuebaler",
    "bringuebalerez": "bringuebaler",
    "bringuebaleriez": "bringuebaler",
    "bringuebalerions": "bringuebaler",
    "bringuebalerons": "bringuebaler",
    "bringuebaleront": "bringuebaler",
    "bringuebales": "bringuebaler",
    "bringuebalez": "bringuebaler",
    "bringuebaliez": "bringuebaler",
    "bringuebalions": "bringuebaler",
    "bringuebalons": "bringuebaler",
    "bringuebalâmes": "bringuebaler",
    "bringuebalât": "bringuebaler",
    "bringuebalâtes": "bringuebaler",
    "bringuebalèrent": "bringuebaler",
    "bringuebalé": "bringuebaler",
    "bringuebalée": "bringuebaler",
    "bringuebalées": "bringuebaler",
    "bringuebalés": "bringuebaler",
    "brinquebala": "brinquebaler",
    "brinquebalai": "brinquebaler",
    "brinquebalaient": "brinquebaler",
    "brinquebalais": "brinquebaler",
    "brinquebalait": "brinquebaler",
    "brinquebalant": "brinquebaler",
    "brinquebalants": "brinquebalant",
    "brinquebalas": "brinquebaler",
    "brinquebalasse": "brinquebaler",
    "brinquebalassent": "brinquebaler",
    "brinquebalasses": "brinquebaler",
    "brinquebalassiez": "brinquebaler",
    "brinquebalassions": "brinquebaler",
    "brinquebale": "brinquebaler",
    "brinquebalent": "brinquebaler",
    "brinquebalera": "brinquebaler",
    "brinquebalerai": "brinquebaler",
    "brinquebaleraient": "brinquebaler",
    "brinquebalerais": "brinquebaler",
    "brinquebalerait": "brinquebaler",
    "brinquebaleras": "brinquebaler",
    "brinquebalerez": "brinquebaler",
    "brinquebaleriez": "brinquebaler",
    "brinquebalerions": "brinquebaler",
    "brinquebalerons": "brinquebaler",
    "brinquebaleront": "brinquebaler",
    "brinquebales": "brinquebaler",
    "brinquebalez": "brinquebaler",
    "brinquebaliez": "brinquebaler",
    "brinquebalions": "brinquebaler",
    "brinqueballant": "brinqueballer",
    "brinqueballé": "brinqueballer",
    "brinqueballés": "brinqueballer",
    "brinquebalons": "brinquebaler",
    "brinquebalâmes": "brinquebaler",
    "brinquebalât": "brinquebaler",
    "brinquebalâtes": "brinquebaler",
    "brinquebalèrent": "brinquebaler",
    "brinquebalé": "brinquebaler",
    "brinquebalée": "brinquebaler",
    "brinquebalées": "brinquebaler",
    "brinquebalés": "brinquebaler",
    "brins": "brin",
    "brioches": "brioche",
    "briochée": "brioché",
    "briochés": "brioché",
    "brions": "brion",
    "brios": "brio",
    "briquaient": "briquer",
    "briquais": "briquer",
    "briquait": "briquer",
    "briquant": "briquer",
    "brique": "briquer",
    "briquent": "briquer",
    "briquerait": "briquer",
    "briques": "brique",
    "briqueteries": "briqueterie",
    "briquets": "briquet",
    "briquettes": "briquette",
    "briquetées": "briqueté",
    "briquez": "briquer",
    "briqué": "briquer",
    "briquée": "briquer",
    "briquées": "briquer",
    "briqués": "briquer",
    "brisa": "briser",
    "brisai": "briser",
    "brisaient": "briser",
    "brisais": "briser",
    "brisait": "briser",
    "brisant": "briser",
    "brisante": "brisant",
    "brisantes": "brisant",
    "brisants": "brisant",
    "brisas": "briser",
    "brisasse": "briser",
    "brisassent": "briser",
    "brisasses": "briser",
    "brisassiez": "briser",
    "brisassions": "briser",
    "briscards": "briscard",
    "brise": "briser",
    "brise-jets": "brise-jet",
    "brisent": "briser",
    "brisera": "briser",
    "briserai": "briser",
    "briseraient": "briser",
    "briserais": "briser",
    "briserait": "briser",
    "briseras": "briser",
    "briserez": "briser",
    "briseriez": "briser",
    "briserions": "briser",
    "briserons": "briser",
    "briseront": "briser",
    "brises": "briser",
    "briseurs": "briseur",
    "briseuse": "briseur",
    "brisez": "briser",
    "brisiez": "briser",
    "brisions": "briser",
    "brisons": "briser",
    "brisquards": "brisquard",
    "brisques": "brisque",
    "bristols": "bristol",
    "brisures": "brisure",
    "brisâmes": "briser",
    "brisât": "briser",
    "brisâtes": "briser",
    "brisèrent": "briser",
    "brisé": "briser",
    "brisée": "briser",
    "brisées": "briser",
    "brisés": "briser",
    "britanniques": "britannique",
    "brivadoise": "brivadois",
    "brièvetés": "brièveté",
    "brocanta": "brocanter",
    "brocantai": "brocanter",
    "brocantaient": "brocanter",
    "brocantais": "brocanter",
    "brocantait": "brocanter",
    "brocantant": "brocanter",
    "brocantas": "brocanter",
    "brocantasse": "brocanter",
    "brocantassent": "brocanter",
    "brocantasses": "brocanter",
    "brocantassiez": "brocanter",
    "brocantassions": "brocanter",
    "brocante": "brocanter",
    "brocantent": "brocanter",
    "brocantera": "brocanter",
    "brocanterai": "brocanter",
    "brocanteraient": "brocanter",
    "brocanterais": "brocanter",
    "brocanterait": "brocanter",
    "brocanteras": "brocanter",
    "brocanterez": "brocanter",
    "brocanteriez": "brocanter",
    "brocanterions": "brocanter",
    "brocanterons": "brocanter",
    "brocanteront": "brocanter",
    "brocantes": "brocanter",
    "brocanteurs": "brocanteur",
    "brocanteuse": "brocanteur",
    "brocantez": "brocanter",
    "brocantiez": "brocanter",
    "brocantions": "brocanter",
    "brocantons": "brocanter",
    "brocantâmes": "brocanter",
    "brocantât": "brocanter",
    "brocantâtes": "brocanter",
    "brocantèrent": "brocanter",
    "brocanté": "brocanter",
    "brocantée": "brocanter",
    "brocantées": "brocanter",
    "brocantés": "brocanter",
    "brocarda": "brocarder",
    "brocardai": "brocarder",
    "brocardaient": "brocarder",
    "brocardais": "brocarder",
    "brocardait": "brocarder",
    "brocardant": "brocarder",
    "brocardas": "brocarder",
    "brocardasse": "brocarder",
    "brocardassent": "brocarder",
    "brocardasses": "brocarder",
    "brocardassiez": "brocarder",
    "brocardassions": "brocarder",
    "brocarde": "brocarder",
    "brocardent": "brocarder",
    "brocardera": "brocarder",
    "brocarderai": "brocarder",
    "brocarderaient": "brocarder",
    "brocarderais": "brocarder",
    "brocarderait": "brocarder",
    "brocarderas": "brocarder",
    "brocarderez": "brocarder",
    "brocarderiez": "brocarder",
    "brocarderions": "brocarder",
    "brocarderons": "brocarder",
    "brocarderont": "brocarder",
    "brocardes": "brocarder",
    "brocardez": "brocarder",
    "brocardiez": "brocarder",
    "brocardions": "brocarder",
    "brocardons": "brocarder",
    "brocards": "brocard",
    "brocardâmes": "brocarder",
    "brocardât": "brocarder",
    "brocardâtes": "brocarder",
    "brocardèrent": "brocarder",
    "brocardé": "brocarder",
    "brocardée": "brocarder",
    "brocardées": "brocarder",
    "brocardés": "brocarder",
    "brocarts": "brocart",
    "brocha": "brocher",
    "brochages": "brochage",
    "brochai": "brocher",
    "brochaient": "brocher",
    "brochais": "brocher",
    "brochait": "brocher",
    "brochant": "brocher",
    "brochas": "brocher",
    "brochasse": "brocher",
    "brochassent": "brocher",
    "brochasses": "brocher",
    "brochassiez": "brocher",
    "brochassions": "brocher",
    "broche": "brocher",
    "brochent": "brocher",
    "brochera": "brocher",
    "brocherai": "brocher",
    "brocheraient": "brocher",
    "brocherais": "brocher",
    "brocherait": "brocher",
    "brocheras": "brocher",
    "brocherez": "brocher",
    "brocheriez": "brocher",
    "brocherions": "brocher",
    "brocherons": "brocher",
    "brocheront": "brocher",
    "broches": "brocher",
    "brochets": "brochet",
    "brochettes": "brochette",
    "brocheurs": "brocheur",
    "brochez": "brocher",
    "brochiez": "brocher",
    "brochions": "brocher",
    "brochoirs": "brochoir",
    "brochons": "brocher",
    "brochures": "brochure",
    "brochâmes": "brocher",
    "brochât": "brocher",
    "brochâtes": "brocher",
    "brochèrent": "brocher",
    "broché": "brocher",
    "brochée": "brocher",
    "brochées": "brocher",
    "brochés": "brocher",
    "brocolis": "brocoli",
    "brocs": "broc",
    "broda": "broder",
    "brodai": "broder",
    "brodaient": "broder",
    "brodais": "broder",
    "brodait": "broder",
    "brodant": "broder",
    "brodas": "broder",
    "brodasse": "broder",
    "brodassent": "broder",
    "brodasses": "broder",
    "brodassiez": "broder",
    "brodassions": "broder",
    "brode": "broder",
    "brodent": "broder",
    "brodequins": "brodequin",
    "brodera": "broder",
    "broderai": "broder",
    "broderaient": "broder",
    "broderais": "broder",
    "broderait": "broder",
    "broderas": "broder",
    "broderez": "broder",
    "broderies": "broderie",
    "broderiez": "broder",
    "broderions": "broder",
    "broderons": "broder",
    "broderont": "broder",
    "brodes": "broder",
    "brodeuse": "brodeur",
    "brodeuses": "brodeur",
    "brodez": "broder",
    "brodiez": "broder",
    "brodions": "broder",
    "brodons": "broder",
    "brodâmes": "broder",
    "brodât": "broder",
    "brodâtes": "broder",
    "brodèrent": "broder",
    "brodé": "broder",
    "brodée": "broder",
    "brodées": "broder",
    "brodés": "broder",
    "broie": "broyer",
    "broiements": "broiement",
    "broient": "broyer",
    "broiera": "broyer",
    "broierai": "broyer",
    "broieraient": "broyer",
    "broierais": "broyer",
    "broierait": "broyer",
    "broieras": "broyer",
    "broierez": "broyer",
    "broieriez": "broyer",
    "broierions": "broyer",
    "broierons": "broyer",
    "broieront": "broyer",
    "broies": "broyer",
    "bromes": "brome",
    "bromures": "bromure",
    "broncha": "broncher",
    "bronchai": "broncher",
    "bronchaient": "broncher",
    "bronchais": "broncher",
    "bronchait": "broncher",
    "bronchant": "broncher",
    "bronchas": "broncher",
    "bronchasse": "broncher",
    "bronchassent": "broncher",
    "bronchasses": "broncher",
    "bronchassiez": "broncher",
    "bronchassions": "broncher",
    "bronche": "broncher",
    "bronchent": "broncher",
    "bronchera": "broncher",
    "broncherai": "broncher",
    "broncheraient": "broncher",
    "broncherais": "broncher",
    "broncherait": "broncher",
    "broncheras": "broncher",
    "broncherez": "broncher",
    "broncheriez": "broncher",
    "broncherions": "broncher",
    "broncherons": "broncher",
    "broncheront": "broncher",
    "bronches": "broncher",
    "bronchez": "broncher",
    "bronchiez": "broncher",
    "bronchioles": "bronchiole",
    "bronchions": "broncher",
    "bronchiques": "bronchique",
    "bronchites": "bronchite",
    "bronchitiques": "bronchitique",
    "broncho-pneumonies": "broncho-pneumonie",
    "bronchons": "broncher",
    "bronchâmes": "broncher",
    "bronchât": "broncher",
    "bronchâtes": "broncher",
    "bronchèrent": "broncher",
    "bronché": "broncher",
    "brontosaures": "brontosaure",
    "bronza": "bronzer",
    "bronzages": "bronzage",
    "bronzai": "bronzer",
    "bronzaient": "bronzer",
    "bronzais": "bronzer",
    "bronzait": "bronzer",
    "bronzant": "bronzer",
    "bronzante": "bronzant",
    "bronzants": "bronzant",
    "bronzas": "bronzer",
    "bronzasse": "bronzer",
    "bronzassent": "bronzer",
    "bronzasses": "bronzer",
    "bronzassiez": "bronzer",
    "bronzassions": "bronzer",
    "bronze": "bronzer",
    "bronzent": "bronzer",
    "bronzera": "bronzer",
    "bronzerai": "bronzer",
    "bronzeraient": "bronzer",
    "bronzerais": "bronzer",
    "bronzerait": "bronzer",
    "bronzeras": "bronzer",
    "bronzerez": "bronzer",
    "bronzeriez": "bronzer",
    "bronzerions": "bronzer",
    "bronzerons": "bronzer",
    "bronzeront": "bronzer",
    "bronzes": "bronzer",
    "bronzettes": "bronzette",
    "bronzez": "bronzer",
    "bronziez": "bronzer",
    "bronzions": "bronzer",
    "bronzons": "bronzer",
    "bronzâmes": "bronzer",
    "bronzât": "bronzer",
    "bronzâtes": "bronzer",
    "bronzèrent": "bronzer",
    "bronzé": "bronzer",
    "bronzée": "bronzer",
    "bronzées": "bronzer",
    "bronzés": "bronzer",
    "brooks": "brook",
    "broquarts": "broquart",
    "broques": "broque",
    "broquettes": "broquette",
    "broquilles": "broquille",
    "brossa": "brosser",
    "brossages": "brossage",
    "brossai": "brosser",
    "brossaient": "brosser",
    "brossais": "brosser",
    "brossait": "brosser",
    "brossant": "brosser",
    "brossas": "brosser",
    "brossasse": "brosser",
    "brossassent": "brosser",
    "brossasses": "brosser",
    "brossassiez": "brosser",
    "brossassions": "brosser",
    "brosse": "brosser",
    "brossent": "brosser",
    "brossera": "brosser",
    "brosserai": "brosser",
    "brosseraient": "brosser",
    "brosserais": "brosser",
    "brosserait": "brosser",
    "brosseras": "brosser",
    "brosserez": "brosser",
    "brosseriez": "brosser",
    "brosserions": "brosser",
    "brosserons": "brosser",
    "brosseront": "brosser",
    "brosses": "brosser",
    "brosseurs": "brosseur",
    "brossez": "brosser",
    "brossiez": "brosser",
    "brossions": "brosser",
    "brossons": "brosser",
    "brossâmes": "brosser",
    "brossât": "brosser",
    "brossâtes": "brosser",
    "brossèrent": "brosser",
    "brossé": "brosser",
    "brossée": "brosser",
    "brossées": "brosser",
    "brossés": "brosser",
    "brouets": "brouet",
    "brouetta": "brouetter",
    "brouettait": "brouetter",
    "brouettes": "brouette",
    "brouettées": "brouettée",
    "brouhahas": "brouhaha",
    "brouilla": "brouiller",
    "brouillages": "brouillage",
    "brouillai": "brouiller",
    "brouillaient": "brouiller",
    "brouillais": "brouiller",
    "brouillait": "brouiller",
    "brouillaminis": "brouillamini",
    "brouillant": "brouiller",
    "brouillardeuse": "brouillardeux",
    "brouillards": "brouillard",
    "brouillas": "brouiller",
    "brouillassait": "brouillasser",
    "brouillasse": "brouiller",
    "brouillassent": "brouiller",
    "brouillasses": "brouiller",
    "brouillassiez": "brouiller",
    "brouillassions": "brouiller",
    "brouille": "brouiller",
    "brouillent": "brouiller",
    "brouillera": "brouiller",
    "brouillerai": "brouiller",
    "brouilleraient": "brouiller",
    "brouillerais": "brouiller",
    "brouillerait": "brouiller",
    "brouilleras": "brouiller",
    "brouillerez": "brouiller",
    "brouilleriez": "brouiller",
    "brouillerions": "brouiller",
    "brouillerons": "brouiller",
    "brouilleront": "brouiller",
    "brouilles": "brouiller",
    "brouilleurs": "brouilleur",
    "brouillez": "brouiller",
    "brouilliez": "brouiller",
    "brouillions": "brouiller",
    "brouillonne": "brouillon",
    "brouillonnes": "brouillon",
    "brouillonné": "brouillonner",
    "brouillons": "brouillon",
    "brouillâmes": "brouiller",
    "brouillât": "brouiller",
    "brouillâtes": "brouiller",
    "brouillèrent": "brouiller",
    "brouillé": "brouiller",
    "brouillée": "brouiller",
    "brouillées": "brouiller",
    "brouillés": "brouiller",
    "brouis": "brouir",
    "brouit": "brouir",
    "brous": "brou",
    "broussailles": "broussaille",
    "broussailleuse": "broussailleux",
    "broussailleuses": "broussailleux",
    "broussait": "brousser",
    "brousses": "brousse",
    "brouta": "brouter",
    "broutai": "brouter",
    "broutaient": "brouter",
    "broutais": "brouter",
    "broutait": "brouter",
    "broutant": "brouter",
    "broutantes": "broutant",
    "broutas": "brouter",
    "broutasse": "brouter",
    "broutassent": "brouter",
    "broutasses": "brouter",
    "broutassiez": "brouter",
    "broutassions": "brouter",
    "broute": "brouter",
    "broutent": "brouter",
    "broutera": "brouter",
    "brouterai": "brouter",
    "brouteraient": "brouter",
    "brouterais": "brouter",
    "brouterait": "brouter",
    "brouteras": "brouter",
    "brouterez": "brouter",
    "brouteriez": "brouter",
    "brouterions": "brouter",
    "brouterons": "brouter",
    "brouteront": "brouter",
    "broutes": "brouter",
    "brouteurs": "brouteur",
    "brouteuse": "brouteur",
    "brouteuses": "brouteur",
    "broutez": "brouter",
    "broutiez": "brouter",
    "broutilles": "broutille",
    "broutions": "brouter",
    "broutons": "brouter",
    "broutâmes": "brouter",
    "broutât": "brouter",
    "broutâtes": "brouter",
    "broutèrent": "brouter",
    "brouté": "brouter",
    "broutée": "brouter",
    "broutées": "brouter",
    "broutés": "brouter",
    "browniens": "brownien",
    "brownings": "browning",
    "broya": "broyer",
    "broyages": "broyage",
    "broyai": "broyer",
    "broyaient": "broyer",
    "broyais": "broyer",
    "broyait": "broyer",
    "broyant": "broyer",
    "broyas": "broyer",
    "broyasse": "broyer",
    "broyassent": "broyer",
    "broyasses": "broyer",
    "broyassiez": "broyer",
    "broyassions": "broyer",
    "broyeurs": "broyeur",
    "broyeuse": "broyeur",
    "broyez": "broyer",
    "broyiez": "broyer",
    "broyions": "broyer",
    "broyons": "broyer",
    "broyâmes": "broyer",
    "broyât": "broyer",
    "broyâtes": "broyer",
    "broyèrent": "broyer",
    "broyé": "broyer",
    "broyée": "broyer",
    "broyées": "broyer",
    "broyés": "broyer",
    "bruants": "bruant",
    "brucelloses": "brucellose",
    "brugeoise": "brugeois",
    "brugeoises": "brugeois",
    "brugnons": "brugnon",
    "bruinait": "bruiner",
    "bruinasse": "bruiner",
    "bruine": "bruiner",
    "bruines": "bruine",
    "bruissa": "bruisser",
    "bruissaient": "bruisser",
    "bruissait": "bruisser",
    "bruissant": "bruisser",
    "bruissante": "bruissant",
    "bruissantes": "bruissant",
    "bruissants": "bruissant",
    "bruisse": "bruisser",
    "bruissements": "bruissement",
    "bruissent": "bruisser",
    "bruissé": "bruisser",
    "bruit": "bruire",
    "bruita": "bruiter",
    "bruitages": "bruitage",
    "bruitai": "bruiter",
    "bruitaient": "bruiter",
    "bruitais": "bruiter",
    "bruitait": "bruiter",
    "bruitant": "bruiter",
    "bruitas": "bruiter",
    "bruitasse": "bruiter",
    "bruitassent": "bruiter",
    "bruitasses": "bruiter",
    "bruitassiez": "bruiter",
    "bruitassions": "bruiter",
    "bruite": "bruiter",
    "bruitent": "bruiter",
    "bruitera": "bruiter",
    "bruiterai": "bruiter",
    "bruiteraient": "bruiter",
    "bruiterais": "bruiter",
    "bruiterait": "bruiter",
    "bruiteras": "bruiter",
    "bruiterez": "bruiter",
    "bruiteriez": "bruiter",
    "bruiterions": "bruiter",
    "bruiterons": "bruiter",
    "bruiteront": "bruiter",
    "bruites": "bruiter",
    "bruiteuse": "bruiteur",
    "bruitez": "bruiter",
    "bruitiez": "bruiter",
    "bruitions": "bruiter",
    "bruitons": "bruiter",
    "bruits": "bruit",
    "bruitâmes": "bruiter",
    "bruitât": "bruiter",
    "bruitâtes": "bruiter",
    "bruitèrent": "bruiter",
    "bruité": "bruiter",
    "bruitée": "bruiter",
    "bruitées": "bruiter",
    "bruités": "bruiter",
    "bruma": "brumer",
    "brumaires": "brumaire",
    "brumait": "brumer",
    "brumant": "brumer",
    "brumassait": "brumasser",
    "brumasses": "brumasse",
    "brume": "brumer",
    "brument": "brumer",
    "brumera": "brumer",
    "brumerait": "brumer",
    "brumes": "brume",
    "brumeuse": "brumeux",
    "brumeuses": "brumeux",
    "brumât": "brumer",
    "brumé": "brumer",
    "brunches": "brunch",
    "brunchs": "brunch",
    "brune": "brun",
    "brunes": "brune",
    "brunette": "brunet",
    "brunettes": "brunette",
    "bruni": "brunir",
    "brunie": "brunir",
    "brunies": "brunir",
    "brunira": "brunir",
    "brunirai": "brunir",
    "bruniraient": "brunir",
    "brunirais": "brunir",
    "brunirait": "brunir",
    "bruniras": "brunir",
    "brunirent": "brunir",
    "brunirez": "brunir",
    "bruniriez": "brunir",
    "brunirions": "brunir",
    "brunirons": "brunir",
    "bruniront": "brunir",
    "brunis": "brunir",
    "brunissaient": "brunir",
    "brunissais": "brunir",
    "brunissait": "brunir",
    "brunissant": "brunir",
    "brunisse": "brunir",
    "brunissent": "brunir",
    "brunisses": "brunir",
    "brunissez": "brunir",
    "brunissiez": "brunir",
    "brunissions": "brunir",
    "brunissons": "brunir",
    "brunissures": "brunissure",
    "brunit": "brunir",
    "bruns": "brun",
    "brunâtres": "brunâtre",
    "brunîmes": "brunir",
    "brunît": "brunir",
    "brunîtes": "brunir",
    "brus": "bru",
    "brusqua": "brusquer",
    "brusquai": "brusquer",
    "brusquaient": "brusquer",
    "brusquais": "brusquer",
    "brusquait": "brusquer",
    "brusquant": "brusquer",
    "brusquas": "brusquer",
    "brusquasse": "brusquer",
    "brusquassent": "brusquer",
    "brusquasses": "brusquer",
    "brusquassiez": "brusquer",
    "brusquassions": "brusquer",
    "brusque": "brusquer",
    "brusquent": "brusquer",
    "brusquera": "brusquer",
    "brusquerai": "brusquer",
    "brusqueraient": "brusquer",
    "brusquerais": "brusquer",
    "brusquerait": "brusquer",
    "brusqueras": "brusquer",
    "brusquerez": "brusquer",
    "brusqueries": "brusquerie",
    "brusqueriez": "brusquer",
    "brusquerions": "brusquer",
    "brusquerons": "brusquer",
    "brusqueront": "brusquer",
    "brusques": "brusquer",
    "brusquette": "brusquet",
    "brusquez": "brusquer",
    "brusquiez": "brusquer",
    "brusquions": "brusquer",
    "brusquons": "brusquer",
    "brusquâmes": "brusquer",
    "brusquât": "brusquer",
    "brusquâtes": "brusquer",
    "brusquèrent": "brusquer",
    "brusqué": "brusquer",
    "brusquée": "brusquer",
    "brusquées": "brusquer",
    "brusqués": "brusquer",
    "brutale": "brutal",
    "brutales": "brutal",
    "brutalisa": "brutaliser",
    "brutalisai": "brutaliser",
    "brutalisaient": "brutaliser",
    "brutalisais": "brutaliser",
    "brutalisait": "brutaliser",
    "brutalisant": "brutaliser",
    "brutalisas": "brutaliser",
    "brutalisasse": "brutaliser",
    "brutalisassent": "brutaliser",
    "brutalisasses": "brutaliser",
    "brutalisassiez": "brutaliser",
    "brutalisassions": "brutaliser",
    "brutalise": "brutaliser",
    "brutalisent": "brutaliser",
    "brutalisera": "brutaliser",
    "brutaliserai": "brutaliser",
    "brutaliseraient": "brutaliser",
    "brutaliserais": "brutaliser",
    "brutaliserait": "brutaliser",
    "brutaliseras": "brutaliser",
    "brutaliserez": "brutaliser",
    "brutaliseriez": "brutaliser",
    "brutaliserions": "brutaliser",
    "brutaliserons": "brutaliser",
    "brutaliseront": "brutaliser",
    "brutalises": "brutaliser",
    "brutalisez": "brutaliser",
    "brutalisiez": "brutaliser",
    "brutalisions": "brutaliser",
    "brutalisons": "brutaliser",
    "brutalisâmes": "brutaliser",
    "brutalisât": "brutaliser",
    "brutalisâtes": "brutaliser",
    "brutalisèrent": "brutaliser",
    "brutalisé": "brutaliser",
    "brutalisée": "brutaliser",
    "brutalisées": "brutaliser",
    "brutalisés": "brutaliser",
    "brutalités": "brutalité",
    "brutaux": "brutal",
    "brute": "brut",
    "brutes": "brute",
    "bruts": "brut",
    "bruxelloise": "bruxellois",
    "bruxelloises": "bruxellois",
    "bruyante": "bruyant",
    "bruyantes": "bruyant",
    "bruyants": "bruyant",
    "bruyères": "bruyère",
    "brèche-dents": "brèche-dent",
    "brèches": "brèche",
    "brèmes": "brème",
    "brève": "bref",
    "brèves": "brève",
    "bréchets": "bréchet",
    "bréhaignes": "bréhaigne",
    "brésilienne": "brésilien",
    "brésiliennes": "brésilien",
    "brésiliens": "brésilien",
    "brésils": "brésil",
    "bréviaires": "bréviaire",
    "brêles": "brêler",
    "brûla": "brûler",
    "brûlai": "brûler",
    "brûlaient": "brûler",
    "brûlais": "brûler",
    "brûlait": "brûler",
    "brûlant": "brûler",
    "brûlante": "brûlant",
    "brûlantes": "brûlant",
    "brûlants": "brûlant",
    "brûlas": "brûler",
    "brûlasse": "brûler",
    "brûlassent": "brûler",
    "brûlasses": "brûler",
    "brûlassiez": "brûler",
    "brûlassions": "brûler",
    "brûle": "brûler",
    "brûlent": "brûler",
    "brûlera": "brûler",
    "brûlerai": "brûler",
    "brûleraient": "brûler",
    "brûlerais": "brûler",
    "brûlerait": "brûler",
    "brûleras": "brûler",
    "brûlerez": "brûler",
    "brûleriez": "brûler",
    "brûlerions": "brûler",
    "brûlerons": "brûler",
    "brûleront": "brûler",
    "brûles": "brûler",
    "brûleurs": "brûleur",
    "brûleuse": "brûleur",
    "brûlez": "brûler",
    "brûliez": "brûler",
    "brûlions": "brûler",
    "brûloirs": "brûloir",
    "brûlons": "brûler",
    "brûlots": "brûlot",
    "brûlures": "brûlure",
    "brûlâmes": "brûler",
    "brûlât": "brûler",
    "brûlâtes": "brûler",
    "brûlèrent": "brûler",
    "brûlé": "brûler",
    "brûlée": "brûler",
    "brûlées": "brûler",
    "brûlés": "brûler",
    "bu": "boire",
    "bua": "buer",
    "buanderies": "buanderie",
    "bubble gum": "bubble-gum",
    "bubons": "bubon",
    "buccale": "buccal",
    "buccales": "buccal",
    "buccaux": "buccal",
    "bucco-génitales": "bucco-génital",
    "bucco-génitaux": "bucco-génital",
    "buccogénitales": "buccogénital",
    "bucoliastes": "bucoliaste",
    "bucoliques": "bucolique",
    "bucranes": "bucrane",
    "bucéphales": "bucéphale",
    "budgets": "budget",
    "budgétaires": "budgétaire",
    "budgétivores": "budgétivore",
    "bue": "bu",
    "bues": "bu",
    "buffets": "buffet",
    "buffles": "buffle",
    "buffleteries": "buffleterie",
    "bufflonne": "bufflon",
    "buggies": "buggy",
    "bugles": "bugle",
    "bugnes": "bugne",
    "bugné": "bugner",
    "bugs": "bug",
    "buildings": "building",
    "buires": "buire",
    "buissonnant": "buissonner",
    "buissonnants": "buissonnant",
    "buissonne": "buissonner",
    "buissonneuse": "buissonneux",
    "buissonneuses": "buissonneux",
    "buissonniers": "buissonnier",
    "buissonnière": "buissonnier",
    "buissonnières": "buissonnier",
    "buissons": "buisson",
    "buissons-ardents": "buisson-ardent",
    "bulbes": "bulbe",
    "bulbeuse": "bulbeux",
    "bulgares": "bulgare",
    "bulgarisations": "bulgarisation",
    "bull-dogs": "bull-dog",
    "bull-finchs": "bull-finch",
    "bull-terriers": "bull-terrier",
    "bulla": "buller",
    "bulldogs": "bulldog",
    "bulldozers": "bulldozer",
    "bulle": "buller",
    "bulles": "buller",
    "bulletins": "bulletin",
    "bullez": "buller",
    "bulls": "bull",
    "bulots": "bulot",
    "bungalows": "bungalow",
    "bunkers": "bunker",
    "buprestes": "bupreste",
    "buralistes": "buraliste",
    "bureaucrates": "bureaucrate",
    "bureaucraties": "bureaucratie",
    "bureaucratiques": "bureaucratique",
    "bureaucratisations": "bureaucratisation",
    "bureaucratisées": "bureaucratiser",
    "bureaus": "bureau",
    "bureautiques": "bureautique",
    "bureaux": "bureau",
    "burent": "boire",
    "bures": "bure",
    "burettes": "burette",
    "burgers": "burger",
    "burgondes": "burgonde",
    "burgraves": "burgrave",
    "burina": "buriner",
    "burinai": "buriner",
    "burinaient": "buriner",
    "burinais": "buriner",
    "burinait": "buriner",
    "burinant": "buriner",
    "burinas": "buriner",
    "burinasse": "buriner",
    "burinassent": "buriner",
    "burinasses": "buriner",
    "burinassiez": "buriner",
    "burinassions": "buriner",
    "burine": "buriner",
    "burinent": "buriner",
    "burinera": "buriner",
    "burinerai": "buriner",
    "burineraient": "buriner",
    "burinerais": "buriner",
    "burinerait": "buriner",
    "burineras": "buriner",
    "burinerez": "buriner",
    "burineriez": "buriner",
    "burinerions": "buriner",
    "burinerons": "buriner",
    "burineront": "buriner",
    "burines": "buriner",
    "burinez": "buriner",
    "buriniez": "buriner",
    "burinions": "buriner",
    "burinons": "buriner",
    "burins": "burin",
    "burinâmes": "buriner",
    "burinât": "buriner",
    "burinâtes": "buriner",
    "burinèrent": "buriner",
    "buriné": "buriner",
    "burinée": "buriner",
    "burinées": "buriner",
    "burinés": "buriner",
    "burlesques": "burlesque",
    "burlingues": "burlingue",
    "burnes": "burne",
    "burons": "buron",
    "burundaise": "burundais",
    "burundaises": "burundais",
    "bus": "boire",
    "busards": "busard",
    "buscs": "busc",
    "buses": "buse",
    "businessmans": "businessman",
    "businessmen": "businessman",
    "busqué": "busquer",
    "busse": "boire",
    "bussent": "boire",
    "busses": "boire",
    "bussiez": "boire",
    "bussions": "boire",
    "bustes": "buste",
    "but": "boire",
    "buta": "buter",
    "butai": "buter",
    "butaient": "buter",
    "butais": "buter",
    "butait": "buter",
    "butant": "buter",
    "butas": "buter",
    "butasse": "buter",
    "butassent": "buter",
    "butasses": "buter",
    "butassiez": "buter",
    "butassions": "buter",
    "bute": "buter",
    "butent": "buter",
    "butera": "buter",
    "buterai": "buter",
    "buteraient": "buter",
    "buterais": "buter",
    "buterait": "buter",
    "buteras": "buter",
    "buterez": "buter",
    "buteriez": "buter",
    "buterions": "buter",
    "buterons": "buter",
    "buteront": "buter",
    "butes": "buter",
    "butez": "buter",
    "butiez": "buter",
    "butina": "butiner",
    "butinai": "butiner",
    "butinaient": "butiner",
    "butinais": "butiner",
    "butinait": "butiner",
    "butinant": "butiner",
    "butinas": "butiner",
    "butinasse": "butiner",
    "butinassent": "butiner",
    "butinasses": "butiner",
    "butinassiez": "butiner",
    "butinassions": "butiner",
    "butine": "butiner",
    "butinent": "butiner",
    "butinera": "butiner",
    "butinerai": "butiner",
    "butineraient": "butiner",
    "butinerais": "butiner",
    "butinerait": "butiner",
    "butineras": "butiner",
    "butinerez": "butiner",
    "butineriez": "butiner",
    "butinerions": "butiner",
    "butinerons": "butiner",
    "butineront": "butiner",
    "butines": "butiner",
    "butineuse": "butineur",
    "butineuses": "butineur",
    "butinez": "butiner",
    "butiniez": "butiner",
    "butinions": "butiner",
    "butinons": "butiner",
    "butins": "butin",
    "butinâmes": "butiner",
    "butinât": "butiner",
    "butinâtes": "butiner",
    "butinèrent": "butiner",
    "butiné": "butiner",
    "butinée": "butiner",
    "butinées": "butiner",
    "butinés": "butiner",
    "butions": "buter",
    "butoirs": "butoir",
    "butons": "buter",
    "butors": "butor",
    "buts": "but",
    "butta": "butter",
    "buttai": "butter",
    "buttaient": "butter",
    "buttais": "butter",
    "buttait": "butter",
    "buttant": "butter",
    "buttas": "butter",
    "buttasse": "butter",
    "buttassent": "butter",
    "buttasses": "butter",
    "buttassiez": "butter",
    "buttassions": "butter",
    "butte": "butter",
    "buttent": "butter",
    "buttera": "butter",
    "butterai": "butter",
    "butteraient": "butter",
    "butterais": "butter",
    "butterait": "butter",
    "butteras": "butter",
    "butterez": "butter",
    "butteriez": "butter",
    "butterions": "butter",
    "butterons": "butter",
    "butteront": "butter",
    "buttes": "butter",
    "buttez": "butter",
    "buttiez": "butter",
    "buttions": "butter",
    "buttons": "butter",
    "buttâmes": "butter",
    "buttât": "butter",
    "buttâtes": "butter",
    "buttèrent": "butter",
    "butté": "butter",
    "buttée": "butter",
    "buttées": "butter",
    "buttés": "butter",
    "butâmes": "buter",
    "butât": "buter",
    "butâtes": "buter",
    "butèrent": "buter",
    "buté": "buter",
    "butée": "buter",
    "butées": "buter",
    "butés": "buter",
    "buvables": "buvable",
    "buvaient": "boire",
    "buvais": "boire",
    "buvait": "boire",
    "buvant": "boire",
    "buvarde": "buvarder",
    "buvards": "buvard",
    "buvardé": "buvarder",
    "buvardés": "buvarder",
    "buvettes": "buvette",
    "buveurs": "buveur",
    "buveuse": "buveur",
    "buveuses": "buveur",
    "buvez": "boire",
    "buviez": "boire",
    "buvions": "boire",
    "buvons": "boire",
    "buées": "buée",
    "bytes": "byte",
    "bytures": "byture",
    "byzantine": "byzantin",
    "byzantines": "byzantin",
    "byzantins": "byzantin",
    "bâbords": "bâbord",
    "bâche": "bâcher",
    "bâches": "bâche",
    "bâché": "bâcher",
    "bâchée": "bâcher",
    "bâchées": "bâcher",
    "bâchés": "bâché",
    "bâcla": "bâcler",
    "bâclai": "bâcler",
    "bâclaient": "bâcler",
    "bâclais": "bâcler",
    "bâclait": "bâcler",
    "bâclant": "bâcler",
    "bâclas": "bâcler",
    "bâclasse": "bâcler",
    "bâclassent": "bâcler",
    "bâclasses": "bâcler",
    "bâclassiez": "bâcler",
    "bâclassions": "bâcler",
    "bâcle": "bâcler",
    "bâclent": "bâcler",
    "bâclera": "bâcler",
    "bâclerai": "bâcler",
    "bâcleraient": "bâcler",
    "bâclerais": "bâcler",
    "bâclerait": "bâcler",
    "bâcleras": "bâcler",
    "bâclerez": "bâcler",
    "bâcleriez": "bâcler",
    "bâclerions": "bâcler",
    "bâclerons": "bâcler",
    "bâcleront": "bâcler",
    "bâcles": "bâcler",
    "bâcleurs": "bâcleur",
    "bâclez": "bâcler",
    "bâcliez": "bâcler",
    "bâclions": "bâcler",
    "bâclons": "bâcler",
    "bâclâmes": "bâcler",
    "bâclât": "bâcler",
    "bâclâtes": "bâcler",
    "bâclèrent": "bâcler",
    "bâclé": "bâcler",
    "bâclée": "bâcler",
    "bâclées": "bâcler",
    "bâclés": "bâcler",
    "bâfra": "bâfrer",
    "bâfrai": "bâfrer",
    "bâfraient": "bâfrer",
    "bâfrais": "bâfrer",
    "bâfrait": "bâfrer",
    "bâfrant": "bâfrer",
    "bâfras": "bâfrer",
    "bâfrasse": "bâfrer",
    "bâfrassent": "bâfrer",
    "bâfrasses": "bâfrer",
    "bâfrassiez": "bâfrer",
    "bâfrassions": "bâfrer",
    "bâfre": "bâfrer",
    "bâfrements": "bâfrement",
    "bâfrent": "bâfrer",
    "bâfrera": "bâfrer",
    "bâfrerai": "bâfrer",
    "bâfreraient": "bâfrer",
    "bâfrerais": "bâfrer",
    "bâfrerait": "bâfrer",
    "bâfreras": "bâfrer",
    "bâfrerez": "bâfrer",
    "bâfreriez": "bâfrer",
    "bâfrerions": "bâfrer",
    "bâfrerons": "bâfrer",
    "bâfreront": "bâfrer",
    "bâfres": "bâfrer",
    "bâfreurs": "bâfreur",
    "bâfrez": "bâfrer",
    "bâfriez": "bâfrer",
    "bâfrions": "bâfrer",
    "bâfrons": "bâfrer",
    "bâfrâmes": "bâfrer",
    "bâfrât": "bâfrer",
    "bâfrâtes": "bâfrer",
    "bâfrèrent": "bâfrer",
    "bâfré": "bâfrer",
    "bâfrée": "bâfrer",
    "bâfrées": "bâfrer",
    "bâfrés": "bâfrer",
    "bâilla": "bâiller",
    "bâillai": "bâiller",
    "bâillaient": "bâiller",
    "bâillais": "bâiller",
    "bâillait": "bâiller",
    "bâillant": "bâiller",
    "bâillante": "bâillant",
    "bâillantes": "bâillant",
    "bâillas": "bâiller",
    "bâillasse": "bâiller",
    "bâillassent": "bâiller",
    "bâillasses": "bâiller",
    "bâillassiez": "bâiller",
    "bâillassions": "bâiller",
    "bâille": "bâiller",
    "bâillements": "bâillement",
    "bâillent": "bâiller",
    "bâillera": "bâiller",
    "bâillerai": "bâiller",
    "bâilleraient": "bâiller",
    "bâillerais": "bâiller",
    "bâillerait": "bâiller",
    "bâilleras": "bâiller",
    "bâillerez": "bâiller",
    "bâilleriez": "bâiller",
    "bâillerions": "bâiller",
    "bâillerons": "bâiller",
    "bâilleront": "bâiller",
    "bâilles": "bâiller",
    "bâillez": "bâiller",
    "bâilliez": "bâiller",
    "bâillions": "bâiller",
    "bâillonna": "bâillonner",
    "bâillonnai": "bâillonner",
    "bâillonnaient": "bâillonner",
    "bâillonnais": "bâillonner",
    "bâillonnait": "bâillonner",
    "bâillonnant": "bâillonner",
    "bâillonnas": "bâillonner",
    "bâillonnasse": "bâillonner",
    "bâillonnassent": "bâillonner",
    "bâillonnasses": "bâillonner",
    "bâillonnassiez": "bâillonner",
    "bâillonnassions": "bâillonner",
    "bâillonne": "bâillonner",
    "bâillonnent": "bâillonner",
    "bâillonnera": "bâillonner",
    "bâillonnerai": "bâillonner",
    "bâillonneraient": "bâillonner",
    "bâillonnerais": "bâillonner",
    "bâillonnerait": "bâillonner",
    "bâillonneras": "bâillonner",
    "bâillonnerez": "bâillonner",
    "bâillonneriez": "bâillonner",
    "bâillonnerions": "bâillonner",
    "bâillonnerons": "bâillonner",
    "bâillonneront": "bâillonner",
    "bâillonnes": "bâillonner",
    "bâillonnez": "bâillonner",
    "bâillonniez": "bâillonner",
    "bâillonnions": "bâillonner",
    "bâillonnons": "bâillonner",
    "bâillonnâmes": "bâillonner",
    "bâillonnât": "bâillonner",
    "bâillonnâtes": "bâillonner",
    "bâillonnèrent": "bâillonner",
    "bâillonné": "bâillonner",
    "bâillonnée": "bâillonner",
    "bâillonnées": "bâillonner",
    "bâillonnés": "bâillonner",
    "bâillons": "bâillon",
    "bâillâmes": "bâiller",
    "bâillât": "bâiller",
    "bâillâtes": "bâiller",
    "bâillèrent": "bâiller",
    "bâillé": "bâiller",
    "bâillée": "bâiller",
    "bâillées": "bâiller",
    "bâillés": "bâiller",
    "bâta": "bâter",
    "bâtai": "bâter",
    "bâtaient": "bâter",
    "bâtais": "bâter",
    "bâtait": "bâter",
    "bâtant": "bâter",
    "bâtarde": "bâtard",
    "bâtardes": "bâtard",
    "bâtardises": "bâtardise",
    "bâtards": "bâtard",
    "bâtas": "bâter",
    "bâtasse": "bâter",
    "bâtassent": "bâter",
    "bâtasses": "bâter",
    "bâtassiez": "bâter",
    "bâtassions": "bâter",
    "bâte": "bâter",
    "bâtent": "bâter",
    "bâtera": "bâter",
    "bâterai": "bâter",
    "bâteraient": "bâter",
    "bâterais": "bâter",
    "bâterait": "bâter",
    "bâteras": "bâter",
    "bâterez": "bâter",
    "bâteriez": "bâter",
    "bâterions": "bâter",
    "bâterons": "bâter",
    "bâteront": "bâter",
    "bâtes": "bâter",
    "bâtez": "bâter",
    "bâti": "bâtir",
    "bâtie": "bâtir",
    "bâties": "bâtir",
    "bâtiez": "bâter",
    "bâtiments": "bâtiment",
    "bâtions": "bâter",
    "bâtira": "bâtir",
    "bâtirai": "bâtir",
    "bâtiraient": "bâtir",
    "bâtirais": "bâtir",
    "bâtirait": "bâtir",
    "bâtiras": "bâtir",
    "bâtirent": "bâtir",
    "bâtirez": "bâtir",
    "bâtiriez": "bâtir",
    "bâtirions": "bâtir",
    "bâtirons": "bâtir",
    "bâtiront": "bâtir",
    "bâtis": "bâtir",
    "bâtissaient": "bâtir",
    "bâtissais": "bâtir",
    "bâtissait": "bâtir",
    "bâtissant": "bâtir",
    "bâtisse": "bâtir",
    "bâtissent": "bâtir",
    "bâtisses": "bâtisse",
    "bâtisseurs": "bâtisseur",
    "bâtisseuse": "bâtisseur",
    "bâtissez": "bâtir",
    "bâtissiez": "bâtir",
    "bâtissions": "bâtir",
    "bâtissons": "bâtir",
    "bâtit": "bâtir",
    "bâtière": "bâtier",
    "bâtonnant": "bâtonner",
    "bâtonnets": "bâtonnet",
    "bâtonniers": "bâtonnier",
    "bâtonnée": "bâtonner",
    "bâtons": "bâton",
    "bâts": "bât",
    "bâtâmes": "bâter",
    "bâtât": "bâter",
    "bâtâtes": "bâter",
    "bâtèrent": "bâter",
    "bâté": "bâter",
    "bâtée": "bâter",
    "bâtées": "bâter",
    "bâtés": "bâter",
    "bâtîmes": "bâtir",
    "bâtît": "bâtir",
    "bâtîtes": "bâtir",
    "bègues": "bègue",
    "béa": "béer",
    "béai": "béer",
    "béaient": "béer",
    "béais": "béer",
    "béait": "béer",
    "béant": "béer",
    "béante": "béant",
    "béantes": "béant",
    "béants": "béant",
    "béarnaise": "béarnais",
    "béarnaises": "béarnais",
    "béas": "béer",
    "béasse": "béer",
    "béassent": "béer",
    "béasses": "béer",
    "béassiez": "béer",
    "béassions": "béer",
    "béate": "béat",
    "béates": "béat",
    "béatifia": "béatifier",
    "béatifiai": "béatifier",
    "béatifiaient": "béatifier",
    "béatifiais": "béatifier",
    "béatifiait": "béatifier",
    "béatifiant": "béatifier",
    "béatifias": "béatifier",
    "béatifiasse": "béatifier",
    "béatifiassent": "béatifier",
    "béatifiasses": "béatifier",
    "béatifiassiez": "béatifier",
    "béatifiassions": "béatifier",
    "béatifications": "béatification",
    "béatifie": "béatifier",
    "béatifient": "béatifier",
    "béatifiera": "béatifier",
    "béatifierai": "béatifier",
    "béatifieraient": "béatifier",
    "béatifierais": "béatifier",
    "béatifierait": "béatifier",
    "béatifieras": "béatifier",
    "béatifierez": "béatifier",
    "béatifieriez": "béatifier",
    "béatifierions": "béatifier",
    "béatifierons": "béatifier",
    "béatifieront": "béatifier",
    "béatifies": "béatifier",
    "béatifiez": "béatifier",
    "béatifiiez": "béatifier",
    "béatifiions": "béatifier",
    "béatifions": "béatifier",
    "béatifiâmes": "béatifier",
    "béatifiât": "béatifier",
    "béatifiâtes": "béatifier",
    "béatifièrent": "béatifier",
    "béatifié": "béatifier",
    "béatifiée": "béatifier",
    "béatifiées": "béatifier",
    "béatifiés": "béatifier",
    "béatitudes": "béatitude",
    "béats": "béat",
    "bébés": "bébé",
    "bébés-éprouvette": "bébé-éprouvette",
    "bébêtes": "bébête",
    "bécanes": "bécane",
    "bécasseaux": "bécasseau",
    "bécasses": "bécasse",
    "bécassines": "bécassine",
    "béchamels": "béchamel",
    "bécota": "bécoter",
    "bécotai": "bécoter",
    "bécotaient": "bécoter",
    "bécotais": "bécoter",
    "bécotait": "bécoter",
    "bécotant": "bécoter",
    "bécotas": "bécoter",
    "bécotasse": "bécoter",
    "bécotassent": "bécoter",
    "bécotasses": "bécoter",
    "bécotassiez": "bécoter",
    "bécotassions": "bécoter",
    "bécote": "bécoter",
    "bécotent": "bécoter",
    "bécotera": "bécoter",
    "bécoterai": "bécoter",
    "bécoteraient": "bécoter",
    "bécoterais": "bécoter",
    "bécoterait": "bécoter",
    "bécoteras": "bécoter",
    "bécoterez": "bécoter",
    "bécoteriez": "bécoter",
    "bécoterions": "bécoter",
    "bécoterons": "bécoter",
    "bécoteront": "bécoter",
    "bécotes": "bécoter",
    "bécotez": "bécoter",
    "bécotiez": "bécoter",
    "bécotions": "bécoter",
    "bécotons": "bécoter",
    "bécots": "bécot",
    "bécotâmes": "bécoter",
    "bécotât": "bécoter",
    "bécotâtes": "bécoter",
    "bécotèrent": "bécoter",
    "bécoté": "bécoter",
    "bécotée": "bécoter",
    "bécotées": "bécoter",
    "bécotés": "bécoter",
    "bédanes": "bédane",
    "bédouine": "bédouin",
    "bédouines": "bédouin",
    "bédouins": "bédouin",
    "bédéphiles": "bédéphile",
    "bédés": "bédé",
    "bée": "béer",
    "béent": "béer",
    "béera": "béer",
    "béerai": "béer",
    "béeraient": "béer",
    "béerais": "béer",
    "béerait": "béer",
    "béeras": "béer",
    "béerez": "béer",
    "béeriez": "béer",
    "béerions": "béer",
    "béerons": "béer",
    "béeront": "béer",
    "bées": "béer",
    "béez": "béer",
    "bégaie": "bégayer",
    "bégaiements": "bégaiement",
    "bégaient": "bégayer",
    "bégaiera": "bégayer",
    "bégaierai": "bégayer",
    "bégaieraient": "bégayer",
    "bégaierais": "bégayer",
    "bégaierait": "bégayer",
    "bégaieras": "bégayer",
    "bégaierez": "bégayer",
    "bégaieriez": "bégayer",
    "bégaierions": "bégayer",
    "bégaierons": "bégayer",
    "bégaieront": "bégayer",
    "bégaies": "bégayer",
    "bégaya": "bégayer",
    "bégayai": "bégayer",
    "bégayaient": "bégayer",
    "bégayais": "bégayer",
    "bégayait": "bégayer",
    "bégayant": "bégayer",
    "bégayante": "bégayant",
    "bégayantes": "bégayant",
    "bégayants": "bégayant",
    "bégayas": "bégayer",
    "bégayasse": "bégayer",
    "bégayassent": "bégayer",
    "bégayasses": "bégayer",
    "bégayassiez": "bégayer",
    "bégayassions": "bégayer",
    "bégaye": "bégayer",
    "bégayent": "bégayer",
    "bégayera": "bégayer",
    "bégayerai": "bégayer",
    "bégayeraient": "bégayer",
    "bégayerais": "bégayer",
    "bégayerait": "bégayer",
    "bégayeras": "bégayer",
    "bégayerez": "bégayer",
    "bégayeriez": "bégayer",
    "bégayerions": "bégayer",
    "bégayerons": "bégayer",
    "bégayeront": "bégayer",
    "bégayes": "bégayer",
    "bégayez": "bégayer",
    "bégayiez": "bégayer",
    "bégayions": "bégayer",
    "bégayons": "bégayer",
    "bégayâmes": "bégayer",
    "bégayât": "bégayer",
    "bégayâtes": "bégayer",
    "bégayèrent": "bégayer",
    "bégayé": "bégayer",
    "bégayée": "bégayer",
    "bégayées": "bégayer",
    "bégayés": "bégayer",
    "bégonias": "bégonia",
    "bégueta": "bégueter",
    "béguetai": "bégueter",
    "béguetaient": "bégueter",
    "béguetais": "bégueter",
    "béguetait": "bégueter",
    "béguetant": "bégueter",
    "béguetas": "bégueter",
    "béguetasse": "bégueter",
    "béguetassent": "bégueter",
    "béguetasses": "bégueter",
    "béguetassiez": "bégueter",
    "béguetassions": "bégueter",
    "béguetez": "bégueter",
    "béguetiez": "bégueter",
    "béguetions": "bégueter",
    "béguetons": "bégueter",
    "béguetâmes": "bégueter",
    "béguetât": "bégueter",
    "béguetâtes": "bégueter",
    "béguetèrent": "bégueter",
    "bégueté": "bégueter",
    "béguetée": "bégueter",
    "béguetées": "bégueter",
    "béguetés": "bégueter",
    "bégueules": "bégueule",
    "béguins": "béguin",
    "béguète": "bégueter",
    "béguètements": "béguètement",
    "béguètent": "bégueter",
    "béguètera": "bégueter",
    "béguèterai": "bégueter",
    "béguèteraient": "bégueter",
    "béguèterais": "bégueter",
    "béguèterait": "bégueter",
    "béguèteras": "bégueter",
    "béguèterez": "bégueter",
    "béguèteriez": "bégueter",
    "béguèterions": "bégueter",
    "béguèterons": "bégueter",
    "béguèteront": "bégueter",
    "béguètes": "bégueter",
    "béiez": "béer",
    "béions": "béer",
    "béliers": "bélier",
    "bélougas": "bélouga",
    "bélugas": "béluga",
    "bélîtres": "bélître",
    "bémolisé": "bémoliser",
    "bémols": "bémol",
    "bénarde": "bénard",
    "bénards": "bénard",
    "bénefs": "bénef",
    "béni": "bénir",
    "bénie": "bénir",
    "bénies": "bénir",
    "bénigne": "bénin",
    "bénignes": "bénin",
    "bénignités": "bénignité",
    "bénins": "bénin",
    "bénira": "bénir",
    "bénirai": "bénir",
    "béniraient": "bénir",
    "bénirais": "bénir",
    "bénirait": "bénir",
    "béniras": "bénir",
    "bénirent": "bénir",
    "bénirez": "bénir",
    "béniriez": "bénir",
    "bénirions": "bénir",
    "bénirons": "bénir",
    "béniront": "bénir",
    "bénis": "bénir",
    "bénissaient": "bénir",
    "bénissais": "bénir",
    "bénissait": "bénir",
    "bénissant": "bénir",
    "bénisse": "bénir",
    "bénissent": "bénir",
    "bénisses": "bénir",
    "bénisseurs": "bénisseur",
    "bénisseuse": "bénisseur",
    "bénissez": "bénir",
    "bénissiez": "bénir",
    "bénissions": "bénir",
    "bénissons": "bénir",
    "bénit": "bénir",
    "bénite": "bénit",
    "bénites": "bénit",
    "bénitiers": "bénitier",
    "bénits": "bénit",
    "bénédicités": "bénédicité",
    "bénédictine": "bénédictin",
    "bénédictines": "bénédictin",
    "bénédictins": "bénédictin",
    "bénédictions": "bénédiction",
    "bénéfices": "bénéfice",
    "bénéficia": "bénéficier",
    "bénéficiai": "bénéficier",
    "bénéficiaient": "bénéficier",
    "bénéficiaires": "bénéficiaire",
    "bénéficiais": "bénéficier",
    "bénéficiait": "bénéficier",
    "bénéficiant": "bénéficier",
    "bénéficias": "bénéficier",
    "bénéficiasse": "bénéficier",
    "bénéficiassent": "bénéficier",
    "bénéficiasses": "bénéficier",
    "bénéficiassiez": "bénéficier",
    "bénéficiassions": "bénéficier",
    "bénéficie": "bénéficier",
    "bénéficient": "bénéficier",
    "bénéficiera": "bénéficier",
    "bénéficierai": "bénéficier",
    "bénéficieraient": "bénéficier",
    "bénéficierais": "bénéficier",
    "bénéficierait": "bénéficier",
    "bénéficieras": "bénéficier",
    "bénéficierez": "bénéficier",
    "bénéficieriez": "bénéficier",
    "bénéficierions": "bénéficier",
    "bénéficierons": "bénéficier",
    "bénéficieront": "bénéficier",
    "bénéficies": "bénéficier",
    "bénéficiez": "bénéficier",
    "bénéficiiez": "bénéficier",
    "bénéficiions": "bénéficier",
    "bénéficions": "bénéficier",
    "bénéficiâmes": "bénéficier",
    "bénéficiât": "bénéficier",
    "bénéficiâtes": "bénéficier",
    "bénéficièrent": "bénéficier",
    "bénéficié": "bénéficier",
    "bénéfiques": "bénéfique",
    "bénévolats": "bénévolat",
    "bénévoles": "bénévole",
    "bénîmes": "bénir",
    "bénît": "bénir",
    "bénîtes": "bénir",
    "béons": "béer",
    "béotienne": "béotien",
    "béotiens": "béotien",
    "béquant": "béquer",
    "béquets": "béquet",
    "béquillant": "béquiller",
    "béquillent": "béquiller",
    "béquilles": "béquille",
    "bérets": "béret",
    "béribéris": "béribéri",
    "bérullienne": "bérullien",
    "béryls": "béryl",
    "bétaillères": "bétaillère",
    "bétails": "bétail",
    "bétels": "bétel",
    "bétonna": "bétonner",
    "bétonnages": "bétonnage",
    "bétonnai": "bétonner",
    "bétonnaient": "bétonner",
    "bétonnais": "bétonner",
    "bétonnait": "bétonner",
    "bétonnant": "bétonner",
    "bétonnas": "bétonner",
    "bétonnasse": "bétonner",
    "bétonnassent": "bétonner",
    "bétonnasses": "bétonner",
    "bétonnassiez": "bétonner",
    "bétonnassions": "bétonner",
    "bétonne": "bétonner",
    "bétonnent": "bétonner",
    "bétonnera": "bétonner",
    "bétonnerai": "bétonner",
    "bétonneraient": "bétonner",
    "bétonnerais": "bétonner",
    "bétonnerait": "bétonner",
    "bétonneras": "bétonner",
    "bétonnerez": "bétonner",
    "bétonneriez": "bétonner",
    "bétonnerions": "bétonner",
    "bétonnerons": "bétonner",
    "bétonneront": "bétonner",
    "bétonnes": "bétonner",
    "bétonneurs": "bétonneur",
    "bétonneuse": "bétonneur",
    "bétonneuses": "bétonneuse",
    "bétonnez": "bétonner",
    "bétonniez": "bétonner",
    "bétonnions": "bétonner",
    "bétonnières": "bétonnière",
    "bétonnons": "bétonner",
    "bétonnâmes": "bétonner",
    "bétonnât": "bétonner",
    "bétonnâtes": "bétonner",
    "bétonnèrent": "bétonner",
    "bétonné": "bétonner",
    "bétonnée": "bétonner",
    "bétonnées": "bétonner",
    "bétonnés": "bétonner",
    "bétons": "béton",
    "bévues": "bévue",
    "béâmes": "béer",
    "béât": "béer",
    "béâtes": "béer",
    "béèrent": "béer",
    "béé": "béer",
    "béée": "béer",
    "béées": "béer",
    "béés": "béer",
    "bêcha": "bêcher",
    "bêchai": "bêcher",
    "bêchaient": "bêcher",
    "bêchais": "bêcher",
    "bêchait": "bêcher",
    "bêchant": "bêcher",
    "bêchas": "bêcher",
    "bêchasse": "bêcher",
    "bêchassent": "bêcher",
    "bêchasses": "bêcher",
    "bêchassiez": "bêcher",
    "bêchassions": "bêcher",
    "bêche": "bêcher",
    "bêchent": "bêcher",
    "bêchera": "bêcher",
    "bêcherai": "bêcher",
    "bêcheraient": "bêcher",
    "bêcherais": "bêcher",
    "bêcherait": "bêcher",
    "bêcheras": "bêcher",
    "bêcherez": "bêcher",
    "bêcheriez": "bêcher",
    "bêcherions": "bêcher",
    "bêcherons": "bêcher",
    "bêcheront": "bêcher",
    "bêches": "bêcher",
    "bêcheurs": "bêcheur",
    "bêcheuse": "bêcheur",
    "bêcheuses": "bêcheur",
    "bêchez": "bêcher",
    "bêchiez": "bêcher",
    "bêchions": "bêcher",
    "bêchons": "bêcher",
    "bêchâmes": "bêcher",
    "bêchât": "bêcher",
    "bêchâtes": "bêcher",
    "bêchèrent": "bêcher",
    "bêché": "bêcher",
    "bêchée": "bêcher",
    "bêchées": "bêcher",
    "bêchés": "bêcher",
    "bêla": "bêler",
    "bêlai": "bêler",
    "bêlaient": "bêler",
    "bêlais": "bêler",
    "bêlait": "bêler",
    "bêlant": "bêler",
    "bêlantes": "bêlant",
    "bêlants": "bêlant",
    "bêlas": "bêler",
    "bêlasse": "bêler",
    "bêlassent": "bêler",
    "bêlasses": "bêler",
    "bêlassiez": "bêler",
    "bêlassions": "bêler",
    "bêle": "bêler",
    "bêlements": "bêlement",
    "bêlent": "bêler",
    "bêlera": "bêler",
    "bêlerai": "bêler",
    "bêleraient": "bêler",
    "bêlerais": "bêler",
    "bêlerait": "bêler",
    "bêleras": "bêler",
    "bêlerez": "bêler",
    "bêleriez": "bêler",
    "bêlerions": "bêler",
    "bêlerons": "bêler",
    "bêleront": "bêler",
    "bêles": "bêler",
    "bêlez": "bêler",
    "bêliez": "bêler",
    "bêlions": "bêler",
    "bêlons": "bêler",
    "bêlâmes": "bêler",
    "bêlât": "bêler",
    "bêlâtes": "bêler",
    "bêlèrent": "bêler",
    "bêlé": "bêler",
    "bêtas": "bêta",
    "bêtasse": "bêta",
    "bêtasses": "bêta",
    "bêtes": "bête",
    "bêtifia": "bêtifier",
    "bêtifiaient": "bêtifier",
    "bêtifiais": "bêtifier",
    "bêtifiait": "bêtifier",
    "bêtifie": "bêtifier",
    "bêtifié": "bêtifier",
    "bêtises": "bêtise",
    "bêtisiers": "bêtisier",
    "bômes": "bôme",
    "böettes": "böette",
    "bûcha": "bûcher",
    "bûchai": "bûcher",
    "bûchaient": "bûcher",
    "bûchais": "bûcher",
    "bûchait": "bûcher",
    "bûchant": "bûcher",
    "bûchas": "bûcher",
    "bûchasse": "bûcher",
    "bûchassent": "bûcher",
    "bûchasses": "bûcher",
    "bûchassiez": "bûcher",
    "bûchassions": "bûcher",
    "bûche": "bûcher",
    "bûchent": "bûcher",
    "bûchera": "bûcher",
    "bûcherai": "bûcher",
    "bûcheraient": "bûcher",
    "bûcherais": "bûcher",
    "bûcherait": "bûcher",
    "bûcheras": "bûcher",
    "bûcherez": "bûcher",
    "bûcheriez": "bûcher",
    "bûcherions": "bûcher",
    "bûcheronne": "bûcheronner",
    "bûcheronnes": "bûcheron",
    "bûcherons": "bûcheron",
    "bûcheront": "bûcher",
    "bûchers": "bûcher",
    "bûches": "bûcher",
    "bûchettes": "bûchette",
    "bûcheurs": "bûcheur",
    "bûcheuse": "bûcheur",
    "bûcheuses": "bûcheur",
    "bûchez": "bûcher",
    "bûchiez": "bûcher",
    "bûchions": "bûcher",
    "bûchons": "bûcher",
    "bûchâmes": "bûcher",
    "bûchât": "bûcher",
    "bûchâtes": "bûcher",
    "bûchèrent": "bûcher",
    "bûché": "bûcher",
    "bûchée": "bûcher",
    "bûchées": "bûcher",
    "bûchés": "bûcher",
    "bûmes": "boire",
    "bût": "boire",
    "bûtes": "boire",
    "c'": "ce",
    "c'est-à-dire": "c'est-à-diree",
    "c.-à-d.": "c'est-à-dire",
    "cab-signaux": "cab-signal",
    "cabales": "cabale",
    "cabalistes": "cabaliste",
    "cabalistiques": "cabalistique",
    "cabana": "cabaner",
    "cabanes": "cabane",
    "cabanettes": "cabanette",
    "cabanons": "cabanon",
    "cabans": "caban",
    "cabaretiers": "cabaretier",
    "cabaretière": "cabaretier",
    "cabaretières": "cabaretier",
    "cabarets": "cabaret",
    "cabernets": "cabernet",
    "cabestans": "cabestan",
    "cabiais": "cabiai",
    "cabillauds": "cabillaud",
    "cabillots": "cabillot",
    "cabines": "cabine",
    "cabinets": "cabinet",
    "cabocharde": "cabochard",
    "cabochardes": "cabochard",
    "cabochards": "cabochard",
    "caboches": "caboche",
    "cabochons": "cabochon",
    "cabossa": "cabosser",
    "cabossages": "cabossage",
    "cabossait": "cabosser",
    "cabosse": "cabosser",
    "cabosses": "cabosse",
    "cabossé": "cabosser",
    "cabossée": "cabosser",
    "cabossées": "cabosser",
    "cabossés": "cabosser",
    "cabota": "caboter",
    "cabotages": "cabotage",
    "cabotai": "caboter",
    "cabotaient": "caboter",
    "cabotais": "caboter",
    "cabotait": "caboter",
    "cabotant": "caboter",
    "cabotas": "caboter",
    "cabotasse": "caboter",
    "cabotassent": "caboter",
    "cabotasses": "caboter",
    "cabotassiez": "caboter",
    "cabotassions": "caboter",
    "cabote": "caboter",
    "cabotent": "caboter",
    "cabotera": "caboter",
    "caboterai": "caboter",
    "caboteraient": "caboter",
    "caboterais": "caboter",
    "caboterait": "caboter",
    "caboteras": "caboter",
    "caboterez": "caboter",
    "caboteriez": "caboter",
    "caboterions": "caboter",
    "caboterons": "caboter",
    "caboteront": "caboter",
    "cabotes": "caboter",
    "caboteurs": "caboteur",
    "cabotez": "caboter",
    "cabotiez": "caboter",
    "cabotine": "cabotin",
    "cabotines": "cabotiner",
    "cabotins": "cabotin",
    "cabotions": "caboter",
    "cabotons": "caboter",
    "cabots": "cabot",
    "cabotâmes": "caboter",
    "cabotât": "caboter",
    "cabotâtes": "caboter",
    "cabotèrent": "caboter",
    "caboté": "caboter",
    "cabotée": "caboter",
    "cabotées": "caboter",
    "cabotés": "caboter",
    "caboulots": "caboulot",
    "cabra": "cabrer",
    "cabrai": "cabrer",
    "cabraient": "cabrer",
    "cabrais": "cabrer",
    "cabrait": "cabrer",
    "cabrant": "cabrer",
    "cabras": "cabrer",
    "cabrasse": "cabrer",
    "cabrassent": "cabrer",
    "cabrasses": "cabrer",
    "cabrassiez": "cabrer",
    "cabrassions": "cabrer",
    "cabre": "cabrer",
    "cabrent": "cabrer",
    "cabrera": "cabrer",
    "cabrerai": "cabrer",
    "cabreraient": "cabrer",
    "cabrerais": "cabrer",
    "cabrerait": "cabrer",
    "cabreras": "cabrer",
    "cabrerez": "cabrer",
    "cabreriez": "cabrer",
    "cabrerions": "cabrer",
    "cabrerons": "cabrer",
    "cabreront": "cabrer",
    "cabres": "cabrer",
    "cabrez": "cabrer",
    "cabriez": "cabrer",
    "cabriola": "cabrioler",
    "cabriolai": "cabrioler",
    "cabriolaient": "cabrioler",
    "cabriolais": "cabrioler",
    "cabriolait": "cabrioler",
    "cabriolant": "cabrioler",
    "cabriolas": "cabrioler",
    "cabriolasse": "cabrioler",
    "cabriolassent": "cabrioler",
    "cabriolasses": "cabrioler",
    "cabriolassiez": "cabrioler",
    "cabriolassions": "cabrioler",
    "cabriole": "cabrioler",
    "cabriolent": "cabrioler",
    "cabriolera": "cabrioler",
    "cabriolerai": "cabrioler",
    "cabrioleraient": "cabrioler",
    "cabriolerais": "cabrioler",
    "cabriolerait": "cabrioler",
    "cabrioleras": "cabrioler",
    "cabriolerez": "cabrioler",
    "cabrioleriez": "cabrioler",
    "cabriolerions": "cabrioler",
    "cabriolerons": "cabrioler",
    "cabrioleront": "cabrioler",
    "cabrioles": "cabrioler",
    "cabriolets": "cabriolet",
    "cabriolez": "cabrioler",
    "cabrioliez": "cabrioler",
    "cabriolions": "cabrioler",
    "cabriolons": "cabrioler",
    "cabriolâmes": "cabrioler",
    "cabriolât": "cabrioler",
    "cabriolâtes": "cabrioler",
    "cabriolèrent": "cabrioler",
    "cabriolé": "cabrioler",
    "cabrions": "cabrer",
    "cabris": "cabri",
    "cabrons": "cabrer",
    "cabrâmes": "cabrer",
    "cabrât": "cabrer",
    "cabrâtes": "cabrer",
    "cabrèrent": "cabrer",
    "cabré": "cabrer",
    "cabrée": "cabrer",
    "cabrées": "cabrer",
    "cabrés": "cabrer",
    "cabs": "cab",
    "cabèches": "cabèche",
    "cabécous": "cabécou",
    "cacahouètes": "cacahouète",
    "cacahuètes": "cacahuète",
    "cacaos": "cacao",
    "cacaotés": "cacaoté",
    "cacaoyers": "cacaoyer",
    "cacarda": "cacarder",
    "cacardait": "cacarder",
    "cacarde": "cacarder",
    "cacas": "caca",
    "cacha": "cacher",
    "cachai": "cacher",
    "cachaient": "cacher",
    "cachais": "cacher",
    "cachait": "cacher",
    "cachalots": "cachalot",
    "cachant": "cacher",
    "cachas": "cacher",
    "cachasse": "cacher",
    "cachassent": "cacher",
    "cachasses": "cacher",
    "cachassiez": "cacher",
    "cachassions": "cacher",
    "cache": "cacher",
    "cache-pots": "cache-pot",
    "cachectiques": "cachectique",
    "cachemires": "cachemire",
    "cachemiris": "cachemiri",
    "cachent": "cacher",
    "cachera": "cacher",
    "cacherai": "cacher",
    "cacheraient": "cacher",
    "cacherais": "cacher",
    "cacherait": "cacher",
    "cacheras": "cacher",
    "cacherez": "cacher",
    "cacheriez": "cacher",
    "cacherions": "cacher",
    "cacherons": "cacher",
    "cacheront": "cacher",
    "caches": "cacher",
    "cacheta": "cacheter",
    "cachetai": "cacheter",
    "cachetaient": "cacheter",
    "cachetais": "cacheter",
    "cachetait": "cacheter",
    "cachetant": "cacheter",
    "cachetas": "cacheter",
    "cachetasse": "cacheter",
    "cachetassent": "cacheter",
    "cachetasses": "cacheter",
    "cachetassiez": "cacheter",
    "cachetassions": "cacheter",
    "cachetez": "cacheter",
    "cachetiez": "cacheter",
    "cachetions": "cacheter",
    "cachetonnais": "cachetonner",
    "cachetonnait": "cachetonner",
    "cachetonne": "cachetonner",
    "cachetons": "cacheton",
    "cachets": "cachet",
    "cachette": "cacheter",
    "cachettent": "cacheter",
    "cachettera": "cacheter",
    "cachetterai": "cacheter",
    "cachetteraient": "cacheter",
    "cachetterais": "cacheter",
    "cachetterait": "cacheter",
    "cachetteras": "cacheter",
    "cachetterez": "cacheter",
    "cachetteriez": "cacheter",
    "cachetterions": "cacheter",
    "cachetterons": "cacheter",
    "cachetteront": "cacheter",
    "cachettes": "cachette",
    "cachetâmes": "cacheter",
    "cachetât": "cacheter",
    "cachetâtes": "cacheter",
    "cachetèrent": "cacheter",
    "cacheté": "cacheter",
    "cachetée": "cacheter",
    "cachetées": "cacheter",
    "cachetés": "cacheter",
    "cachexies": "cachexie",
    "cachez": "cacher",
    "cachiez": "cacher",
    "cachions": "cacher",
    "cachons": "cacher",
    "cachots": "cachot",
    "cachotteries": "cachotterie",
    "cachottiers": "cachottier",
    "cachottière": "cachottier",
    "cachottières": "cachottier",
    "cachous": "cachou",
    "cachâmes": "cacher",
    "cachât": "cacher",
    "cachâtes": "cacher",
    "cachèrent": "cacher",
    "caché": "cacher",
    "cachée": "cacher",
    "cachées": "cacher",
    "cachés": "cacher",
    "caciques": "cacique",
    "cacochymes": "cacochyme",
    "cacodylates": "cacodylate",
    "cacographes": "cacographe",
    "cacographies": "cacographie",
    "cacophonies": "cacophonie",
    "cacophoniques": "cacophonique",
    "cactacées": "cactacée",
    "cactées": "cactée",
    "cadastrale": "cadastral",
    "cadastrales": "cadastral",
    "cadastraux": "cadastral",
    "cadastres": "cadastre",
    "cadastré": "cadastrer",
    "cadastrée": "cadastrer",
    "cadavres": "cadavre",
    "cadavéreuse": "cadavéreux",
    "cadavéreuses": "cadavéreux",
    "cadavériques": "cadavérique",
    "cadavérise": "cadavériser",
    "cadavérisés": "cadavériser",
    "caddies": "caddie",
    "cadeaux": "cadeau",
    "cadenassa": "cadenasser",
    "cadenassai": "cadenasser",
    "cadenassaient": "cadenasser",
    "cadenassais": "cadenasser",
    "cadenassait": "cadenasser",
    "cadenassant": "cadenasser",
    "cadenassas": "cadenasser",
    "cadenassasse": "cadenasser",
    "cadenassassent": "cadenasser",
    "cadenassasses": "cadenasser",
    "cadenassassiez": "cadenasser",
    "cadenassassions": "cadenasser",
    "cadenasse": "cadenasser",
    "cadenassent": "cadenasser",
    "cadenassera": "cadenasser",
    "cadenasserai": "cadenasser",
    "cadenasseraient": "cadenasser",
    "cadenasserais": "cadenasser",
    "cadenasserait": "cadenasser",
    "cadenasseras": "cadenasser",
    "cadenasserez": "cadenasser",
    "cadenasseriez": "cadenasser",
    "cadenasserions": "cadenasser",
    "cadenasserons": "cadenasser",
    "cadenasseront": "cadenasser",
    "cadenasses": "cadenasser",
    "cadenassez": "cadenasser",
    "cadenassiez": "cadenasser",
    "cadenassions": "cadenasser",
    "cadenassons": "cadenasser",
    "cadenassâmes": "cadenasser",
    "cadenassât": "cadenasser",
    "cadenassâtes": "cadenasser",
    "cadenassèrent": "cadenasser",
    "cadenassé": "cadenasser",
    "cadenassée": "cadenasser",
    "cadenassées": "cadenasser",
    "cadenassés": "cadenasser",
    "cadence": "cadencer",
    "cadences": "cadence",
    "cadencé": "cadencer",
    "cadencée": "cadencer",
    "cadencées": "cadencé",
    "cadencés": "cadencer",
    "cadenettes": "cadenette",
    "cades": "cade",
    "cadets": "cadet",
    "cadette": "cadet",
    "cadettes": "cadet",
    "cadis": "cadi",
    "cadmiums": "cadmium",
    "cadmié": "cadmier",
    "cadors": "cador",
    "cadra": "cadrer",
    "cadrages": "cadrage",
    "cadrai": "cadrer",
    "cadraient": "cadrer",
    "cadrais": "cadrer",
    "cadrait": "cadrer",
    "cadrans": "cadran",
    "cadrant": "cadrer",
    "cadras": "cadrer",
    "cadrasse": "cadrer",
    "cadrassent": "cadrer",
    "cadrasses": "cadrer",
    "cadrassiez": "cadrer",
    "cadrassions": "cadrer",
    "cadratins": "cadratin",
    "cadre": "cadrer",
    "cadrent": "cadrer",
    "cadrera": "cadrer",
    "cadrerai": "cadrer",
    "cadreraient": "cadrer",
    "cadrerais": "cadrer",
    "cadrerait": "cadrer",
    "cadreras": "cadrer",
    "cadrerez": "cadrer",
    "cadreriez": "cadrer",
    "cadrerions": "cadrer",
    "cadrerons": "cadrer",
    "cadreront": "cadrer",
    "cadres": "cadrer",
    "cadreurs": "cadreur",
    "cadrez": "cadrer",
    "cadriez": "cadrer",
    "cadrions": "cadrer",
    "cadrons": "cadrer",
    "cadrâmes": "cadrer",
    "cadrât": "cadrer",
    "cadrâtes": "cadrer",
    "cadrèrent": "cadrer",
    "cadré": "cadrer",
    "cadrée": "cadrer",
    "cadrées": "cadrer",
    "cadrés": "cadrer",
    "caducs": "caduc",
    "caducées": "caducée",
    "caduque": "caduc",
    "caduques": "caduque",
    "cadènes": "cadène",
    "caecale": "caecal",
    "caecales": "caecal",
    "caecaux": "caecal",
    "caecums": "caecum",
    "cafarde": "cafarder",
    "cafarderait": "cafarder",
    "cafardes": "cafard",
    "cafardeuse": "cafardeur",
    "cafards": "cafard",
    "cafetais": "cafeter",
    "cafetans": "cafetan",
    "cafeterias": "cafeteria",
    "cafetiers": "cafetier",
    "cafetières": "cafetière",
    "cafeté": "cafeter",
    "cafouilla": "cafouiller",
    "cafouillages": "cafouillage",
    "cafouillai": "cafouiller",
    "cafouillaient": "cafouiller",
    "cafouillais": "cafouiller",
    "cafouillait": "cafouiller",
    "cafouillant": "cafouiller",
    "cafouillas": "cafouiller",
    "cafouillasse": "cafouiller",
    "cafouillassent": "cafouiller",
    "cafouillasses": "cafouiller",
    "cafouillassiez": "cafouiller",
    "cafouillassions": "cafouiller",
    "cafouille": "cafouiller",
    "cafouillent": "cafouiller",
    "cafouillera": "cafouiller",
    "cafouillerai": "cafouiller",
    "cafouilleraient": "cafouiller",
    "cafouillerais": "cafouiller",
    "cafouillerait": "cafouiller",
    "cafouilleras": "cafouiller",
    "cafouillerez": "cafouiller",
    "cafouilleriez": "cafouiller",
    "cafouillerions": "cafouiller",
    "cafouillerons": "cafouiller",
    "cafouilleront": "cafouiller",
    "cafouilles": "cafouiller",
    "cafouilleuse": "cafouilleux",
    "cafouillez": "cafouiller",
    "cafouilliez": "cafouiller",
    "cafouillions": "cafouiller",
    "cafouillons": "cafouiller",
    "cafouillâmes": "cafouiller",
    "cafouillât": "cafouiller",
    "cafouillâtes": "cafouiller",
    "cafouillèrent": "cafouiller",
    "cafouillé": "cafouiller",
    "caftaient": "cafter",
    "caftait": "cafter",
    "caftans": "caftan",
    "cafte": "cafter",
    "cafterai": "cafter",
    "cafterait": "cafter",
    "cafteras": "cafter",
    "caftes": "cafter",
    "cafteurs": "cafteur",
    "cafteuse": "cafteur",
    "cafté": "cafter",
    "caftés": "cafter",
    "caféiers": "caféier",
    "caféines": "caféine",
    "cafés": "café",
    "cafés-concerts": "café-concert",
    "cafés-théâtres": "café-théâtre",
    "cafétérias": "cafétéria",
    "cagades": "cagade",
    "cageots": "cageot",
    "cages": "cage",
    "cagettes": "cagette",
    "cagibis": "cagibi",
    "cagnards": "cagnard",
    "cagnas": "cagna",
    "cagneuse": "cagneux",
    "cagneuses": "cagneux",
    "cagnottes": "cagnotte",
    "cagote": "cagot",
    "cagotes": "cagot",
    "cagots": "cagot",
    "cagoulards": "cagoulard",
    "cagoules": "cagoule",
    "cagoulés": "cagoulé",
    "cagous": "cagou",
    "caguait": "caguer",
    "cague": "caguer",
    "cahiers": "cahier",
    "cahota": "cahoter",
    "cahotai": "cahoter",
    "cahotaient": "cahoter",
    "cahotais": "cahoter",
    "cahotait": "cahoter",
    "cahotant": "cahoter",
    "cahotante": "cahotant",
    "cahotantes": "cahotant",
    "cahotants": "cahotant",
    "cahotas": "cahoter",
    "cahotasse": "cahoter",
    "cahotassent": "cahoter",
    "cahotasses": "cahoter",
    "cahotassiez": "cahoter",
    "cahotassions": "cahoter",
    "cahote": "cahoter",
    "cahotent": "cahoter",
    "cahotera": "cahoter",
    "cahoterai": "cahoter",
    "cahoteraient": "cahoter",
    "cahoterais": "cahoter",
    "cahoterait": "cahoter",
    "cahoteras": "cahoter",
    "cahoterez": "cahoter",
    "cahoteriez": "cahoter",
    "cahoterions": "cahoter",
    "cahoterons": "cahoter",
    "cahoteront": "cahoter",
    "cahotes": "cahoter",
    "cahoteuse": "cahoteux",
    "cahoteuses": "cahoteux",
    "cahotez": "cahoter",
    "cahotiez": "cahoter",
    "cahotions": "cahoter",
    "cahotons": "cahoter",
    "cahots": "cahot",
    "cahotâmes": "cahoter",
    "cahotât": "cahoter",
    "cahotâtes": "cahoter",
    "cahotèrent": "cahoter",
    "cahoté": "cahoter",
    "cahotée": "cahoter",
    "cahotées": "cahoter",
    "cahotés": "cahoter",
    "cahutes": "cahute",
    "cailla": "cailler",
    "caillai": "cailler",
    "caillaient": "cailler",
    "caillais": "cailler",
    "caillait": "cailler",
    "caillant": "cailler",
    "caillas": "cailler",
    "caillasse": "cailler",
    "caillassent": "cailler",
    "caillasses": "cailler",
    "caillassiez": "cailler",
    "caillassions": "cailler",
    "caille": "cailler",
    "caillebottes": "caillebotte",
    "caillent": "cailler",
    "caillera": "cailler",
    "caillerai": "cailler",
    "cailleraient": "cailler",
    "caillerais": "cailler",
    "caillerait": "cailler",
    "cailleras": "cailler",
    "caillerez": "cailler",
    "cailleriez": "cailler",
    "caillerions": "cailler",
    "caillerons": "cailler",
    "cailleront": "cailler",
    "cailles": "cailler",
    "caillettes": "caillette",
    "caillez": "cailler",
    "cailliez": "cailler",
    "caillions": "cailler",
    "caillons": "cailler",
    "caillots": "caillot",
    "caillouteuse": "caillouteux",
    "caillouteuses": "caillouteux",
    "caillouté": "caillouter",
    "cailloux": "caillou",
    "caillâmes": "cailler",
    "caillât": "cailler",
    "caillâtes": "cailler",
    "caillèrent": "cailler",
    "caillé": "cailler",
    "caillée": "cailler",
    "caillées": "cailler",
    "caillés": "cailler",
    "cairns": "cairn",
    "cairotes": "cairote",
    "caisses": "caisse",
    "caissettes": "caissette",
    "caissiers": "caissier",
    "caissière": "caissier",
    "caissières": "caissier",
    "caissons": "caisson",
    "cajola": "cajoler",
    "cajolai": "cajoler",
    "cajolaient": "cajoler",
    "cajolais": "cajoler",
    "cajolait": "cajoler",
    "cajolant": "cajoler",
    "cajolas": "cajoler",
    "cajolasse": "cajoler",
    "cajolassent": "cajoler",
    "cajolasses": "cajoler",
    "cajolassiez": "cajoler",
    "cajolassions": "cajoler",
    "cajole": "cajoler",
    "cajolent": "cajoler",
    "cajolera": "cajoler",
    "cajolerai": "cajoler",
    "cajoleraient": "cajoler",
    "cajolerais": "cajoler",
    "cajolerait": "cajoler",
    "cajoleras": "cajoler",
    "cajolerez": "cajoler",
    "cajoleries": "cajolerie",
    "cajoleriez": "cajoler",
    "cajolerions": "cajoler",
    "cajolerons": "cajoler",
    "cajoleront": "cajoler",
    "cajoles": "cajoler",
    "cajoleurs": "cajoleur",
    "cajoleuse": "cajoleur",
    "cajolez": "cajoler",
    "cajoliez": "cajoler",
    "cajolions": "cajoler",
    "cajolons": "cajoler",
    "cajolâmes": "cajoler",
    "cajolât": "cajoler",
    "cajolâtes": "cajoler",
    "cajolèrent": "cajoler",
    "cajolé": "cajoler",
    "cajolée": "cajoler",
    "cajolées": "cajoler",
    "cajolés": "cajoler",
    "cajous": "cajou",
    "cajuns": "cajun",
    "cakes": "cake",
    "cala": "caler",
    "calabraises": "calabrais",
    "calai": "caler",
    "calaient": "caler",
    "calais": "caler",
    "calaisiens": "calaisien",
    "calait": "caler",
    "calamars": "calamar",
    "calames": "calame",
    "calamines": "calamine",
    "calamistre": "calamistrer",
    "calamistrée": "calamistré",
    "calamistrés": "calamistré",
    "calamita": "calamiter",
    "calamitait": "calamiter",
    "calamiteuse": "calamiteux",
    "calamiteuses": "calamiteux",
    "calamité": "calamiter",
    "calamités": "calamité",
    "calanchaient": "calancher",
    "calanchais": "calancher",
    "calanche": "calancher",
    "calanché": "calancher",
    "calandra": "calandrer",
    "calandrai": "calandrer",
    "calandraient": "calandrer",
    "calandrais": "calandrer",
    "calandrait": "calandrer",
    "calandrant": "calandrer",
    "calandras": "calandrer",
    "calandrasse": "calandrer",
    "calandrassent": "calandrer",
    "calandrasses": "calandrer",
    "calandrassiez": "calandrer",
    "calandrassions": "calandrer",
    "calandre": "calandrer",
    "calandrent": "calandrer",
    "calandrera": "calandrer",
    "calandrerai": "calandrer",
    "calandreraient": "calandrer",
    "calandrerais": "calandrer",
    "calandrerait": "calandrer",
    "calandreras": "calandrer",
    "calandrerez": "calandrer",
    "calandreriez": "calandrer",
    "calandrerions": "calandrer",
    "calandrerons": "calandrer",
    "calandreront": "calandrer",
    "calandres": "calandrer",
    "calandrez": "calandrer",
    "calandriez": "calandrer",
    "calandrions": "calandrer",
    "calandrons": "calandrer",
    "calandrâmes": "calandrer",
    "calandrât": "calandrer",
    "calandrâtes": "calandrer",
    "calandrèrent": "calandrer",
    "calandré": "calandrer",
    "calandrée": "calandrer",
    "calandrées": "calandrer",
    "calandrés": "calandrer",
    "calanques": "calanque",
    "calant": "caler",
    "calas": "caler",
    "calasse": "caler",
    "calassent": "caler",
    "calasses": "caler",
    "calassiez": "caler",
    "calassions": "caler",
    "calbars": "calbar",
    "calbombes": "calbombe",
    "calcaires": "calcaire",
    "calce": "calcer",
    "calcerais": "calcer",
    "calcifications": "calcification",
    "calcifié": "calcifier",
    "calcifiée": "calcifier",
    "calcifiées": "calcifié",
    "calcifiés": "calcifié",
    "calcifs": "calcif",
    "calcina": "calciner",
    "calcinai": "calciner",
    "calcinaient": "calciner",
    "calcinais": "calciner",
    "calcinait": "calciner",
    "calcinant": "calciner",
    "calcinas": "calciner",
    "calcinasse": "calciner",
    "calcinassent": "calciner",
    "calcinasses": "calciner",
    "calcinassiez": "calciner",
    "calcinassions": "calciner",
    "calcine": "calciner",
    "calcinent": "calciner",
    "calcinera": "calciner",
    "calcinerai": "calciner",
    "calcineraient": "calciner",
    "calcinerais": "calciner",
    "calcinerait": "calciner",
    "calcineras": "calciner",
    "calcinerez": "calciner",
    "calcineriez": "calciner",
    "calcinerions": "calciner",
    "calcinerons": "calciner",
    "calcineront": "calciner",
    "calcines": "calciner",
    "calcinez": "calciner",
    "calciniez": "calciner",
    "calcinions": "calciner",
    "calcinons": "calciner",
    "calcinâmes": "calciner",
    "calcinât": "calciner",
    "calcinâtes": "calciner",
    "calcinèrent": "calciner",
    "calciné": "calciner",
    "calcinée": "calciner",
    "calcinées": "calciner",
    "calcinés": "calciner",
    "calciums": "calcium",
    "calcula": "calculer",
    "calculables": "calculable",
    "calculai": "calculer",
    "calculaient": "calculer",
    "calculais": "calculer",
    "calculait": "calculer",
    "calculant": "calculer",
    "calculas": "calculer",
    "calculasse": "calculer",
    "calculassent": "calculer",
    "calculasses": "calculer",
    "calculassiez": "calculer",
    "calculassions": "calculer",
    "calculateurs": "calculateur",
    "calculatrices": "calculatrice",
    "calcule": "calculer",
    "calculent": "calculer",
    "calculera": "calculer",
    "calculerai": "calculer",
    "calculeraient": "calculer",
    "calculerais": "calculer",
    "calculerait": "calculer",
    "calculeras": "calculer",
    "calculerez": "calculer",
    "calculeriez": "calculer",
    "calculerions": "calculer",
    "calculerons": "calculer",
    "calculeront": "calculer",
    "calcules": "calculer",
    "calculettes": "calculette",
    "calculeuse": "calculeux",
    "calculez": "calculer",
    "calculiez": "calculer",
    "calculions": "calculer",
    "calculons": "calculer",
    "calculs": "calcul",
    "calculâmes": "calculer",
    "calculât": "calculer",
    "calculâtes": "calculer",
    "calculèrent": "calculer",
    "calculé": "calculer",
    "calculée": "calculer",
    "calculées": "calculer",
    "calculés": "calculer",
    "cale": "caler",
    "cale-pieds": "cale-pied",
    "calebasses": "calebasse",
    "calembours": "calembour",
    "calembredaines": "calembredaine",
    "calenché": "calencher",
    "calendriers": "calendrier",
    "calent": "caler",
    "calepins": "calepin",
    "calera": "caler",
    "calerai": "caler",
    "caleraient": "caler",
    "calerais": "caler",
    "calerait": "caler",
    "caleras": "caler",
    "calerez": "caler",
    "caleriez": "caler",
    "calerions": "caler",
    "calerons": "caler",
    "caleront": "caler",
    "cales": "caler",
    "calez": "caler",
    "caleçons": "caleçon",
    "calfata": "calfater",
    "calfatai": "calfater",
    "calfataient": "calfater",
    "calfatais": "calfater",
    "calfatait": "calfater",
    "calfatant": "calfater",
    "calfatas": "calfater",
    "calfatasse": "calfater",
    "calfatassent": "calfater",
    "calfatasses": "calfater",
    "calfatassiez": "calfater",
    "calfatassions": "calfater",
    "calfate": "calfater",
    "calfatent": "calfater",
    "calfatera": "calfater",
    "calfaterai": "calfater",
    "calfateraient": "calfater",
    "calfaterais": "calfater",
    "calfaterait": "calfater",
    "calfateras": "calfater",
    "calfaterez": "calfater",
    "calfateriez": "calfater",
    "calfaterions": "calfater",
    "calfaterons": "calfater",
    "calfateront": "calfater",
    "calfates": "calfater",
    "calfatez": "calfater",
    "calfatiez": "calfater",
    "calfations": "calfater",
    "calfatons": "calfater",
    "calfats": "calfat",
    "calfatâmes": "calfater",
    "calfatât": "calfater",
    "calfatâtes": "calfater",
    "calfatèrent": "calfater",
    "calfaté": "calfater",
    "calfatée": "calfater",
    "calfatées": "calfater",
    "calfatés": "calfater",
    "calfeutra": "calfeutrer",
    "calfeutrai": "calfeutrer",
    "calfeutraient": "calfeutrer",
    "calfeutrais": "calfeutrer",
    "calfeutrait": "calfeutrer",
    "calfeutrant": "calfeutrer",
    "calfeutras": "calfeutrer",
    "calfeutrasse": "calfeutrer",
    "calfeutrassent": "calfeutrer",
    "calfeutrasses": "calfeutrer",
    "calfeutrassiez": "calfeutrer",
    "calfeutrassions": "calfeutrer",
    "calfeutre": "calfeutrer",
    "calfeutrent": "calfeutrer",
    "calfeutrera": "calfeutrer",
    "calfeutrerai": "calfeutrer",
    "calfeutreraient": "calfeutrer",
    "calfeutrerais": "calfeutrer",
    "calfeutrerait": "calfeutrer",
    "calfeutreras": "calfeutrer",
    "calfeutrerez": "calfeutrer",
    "calfeutreriez": "calfeutrer",
    "calfeutrerions": "calfeutrer",
    "calfeutrerons": "calfeutrer",
    "calfeutreront": "calfeutrer",
    "calfeutres": "calfeutrer",
    "calfeutrez": "calfeutrer",
    "calfeutriez": "calfeutrer",
    "calfeutrions": "calfeutrer",
    "calfeutrons": "calfeutrer",
    "calfeutrâmes": "calfeutrer",
    "calfeutrât": "calfeutrer",
    "calfeutrâtes": "calfeutrer",
    "calfeutrèrent": "calfeutrer",
    "calfeutré": "calfeutrer",
    "calfeutrée": "calfeutrer",
    "calfeutrées": "calfeutrer",
    "calfeutrés": "calfeutrer",
    "calibra": "calibrer",
    "calibrages": "calibrage",
    "calibrai": "calibrer",
    "calibraient": "calibrer",
    "calibrais": "calibrer",
    "calibrait": "calibrer",
    "calibrant": "calibrer",
    "calibras": "calibrer",
    "calibrasse": "calibrer",
    "calibrassent": "calibrer",
    "calibrasses": "calibrer",
    "calibrassiez": "calibrer",
    "calibrassions": "calibrer",
    "calibre": "calibrer",
    "calibrent": "calibrer",
    "calibrera": "calibrer",
    "calibrerai": "calibrer",
    "calibreraient": "calibrer",
    "calibrerais": "calibrer",
    "calibrerait": "calibrer",
    "calibreras": "calibrer",
    "calibrerez": "calibrer",
    "calibreriez": "calibrer",
    "calibrerions": "calibrer",
    "calibrerons": "calibrer",
    "calibreront": "calibrer",
    "calibres": "calibrer",
    "calibrez": "calibrer",
    "calibriez": "calibrer",
    "calibrions": "calibrer",
    "calibrons": "calibrer",
    "calibrâmes": "calibrer",
    "calibrât": "calibrer",
    "calibrâtes": "calibrer",
    "calibrèrent": "calibrer",
    "calibré": "calibrer",
    "calibrée": "calibrer",
    "calibrées": "calibrer",
    "calibrés": "calibrer",
    "calices": "calice",
    "calicots": "calicot",
    "caliez": "caler",
    "califes": "calife",
    "californienne": "californien",
    "californiennes": "californien",
    "californiens": "californien",
    "calions": "caler",
    "calissons": "calisson",
    "call girl": "call-girl",
    "call girls": "call-girl",
    "call-girls": "call-girl",
    "calla": "caller",
    "calle": "caller",
    "calles": "caller",
    "calleuse": "calleux",
    "calleuses": "calleux",
    "calligrammes": "calligramme",
    "calligraphes": "calligraphe",
    "calligraphiais": "calligraphier",
    "calligraphiait": "calligraphier",
    "calligraphiant": "calligraphier",
    "calligraphie": "calligraphier",
    "calligraphient": "calligraphier",
    "calligraphies": "calligraphie",
    "calligraphiez": "calligraphier",
    "calligraphiques": "calligraphique",
    "calligraphié": "calligraphier",
    "calligraphiée": "calligraphier",
    "calligraphiées": "calligraphier",
    "calligraphiés": "calligraphier",
    "callipyges": "callipyge",
    "callosités": "callosité",
    "calma": "calmer",
    "calmai": "calmer",
    "calmaient": "calmer",
    "calmais": "calmer",
    "calmait": "calmer",
    "calmant": "calmer",
    "calmante": "calmant",
    "calmants": "calmant",
    "calmars": "calmar",
    "calmas": "calmer",
    "calmasse": "calmer",
    "calmassent": "calmer",
    "calmasses": "calmer",
    "calmassiez": "calmer",
    "calmassions": "calmer",
    "calme": "calmer",
    "calment": "calmer",
    "calmera": "calmer",
    "calmerai": "calmer",
    "calmeraient": "calmer",
    "calmerais": "calmer",
    "calmerait": "calmer",
    "calmeras": "calmer",
    "calmerez": "calmer",
    "calmeriez": "calmer",
    "calmerions": "calmer",
    "calmerons": "calmer",
    "calmeront": "calmer",
    "calmes": "calmer",
    "calmez": "calmer",
    "calmi": "calmir",
    "calmie": "calmir",
    "calmies": "calmir",
    "calmiez": "calmer",
    "calmions": "calmer",
    "calmira": "calmir",
    "calmirai": "calmir",
    "calmiraient": "calmir",
    "calmirais": "calmir",
    "calmirait": "calmir",
    "calmiras": "calmir",
    "calmirent": "calmir",
    "calmirez": "calmir",
    "calmiriez": "calmir",
    "calmirions": "calmir",
    "calmirons": "calmir",
    "calmiront": "calmir",
    "calmis": "calmir",
    "calmissaient": "calmir",
    "calmissais": "calmir",
    "calmissait": "calmir",
    "calmissant": "calmir",
    "calmisse": "calmir",
    "calmissent": "calmir",
    "calmisses": "calmir",
    "calmissez": "calmir",
    "calmissiez": "calmir",
    "calmissions": "calmir",
    "calmissons": "calmir",
    "calmit": "calmir",
    "calmons": "calmer",
    "calmâmes": "calmer",
    "calmât": "calmer",
    "calmâtes": "calmer",
    "calmèrent": "calmer",
    "calmé": "calmer",
    "calmée": "calmer",
    "calmées": "calmer",
    "calmés": "calmer",
    "calmîmes": "calmir",
    "calmît": "calmir",
    "calmîtes": "calmir",
    "calomnia": "calomnier",
    "calomniai": "calomnier",
    "calomniaient": "calomnier",
    "calomniais": "calomnier",
    "calomniait": "calomnier",
    "calomniant": "calomnier",
    "calomnias": "calomnier",
    "calomniasse": "calomnier",
    "calomniassent": "calomnier",
    "calomniasses": "calomnier",
    "calomniassiez": "calomnier",
    "calomniassions": "calomnier",
    "calomniateurs": "calomniateur",
    "calomniatrice": "calomniateur",
    "calomnie": "calomnier",
    "calomnient": "calomnier",
    "calomniera": "calomnier",
    "calomnierai": "calomnier",
    "calomnieraient": "calomnier",
    "calomnierais": "calomnier",
    "calomnierait": "calomnier",
    "calomnieras": "calomnier",
    "calomnierez": "calomnier",
    "calomnieriez": "calomnier",
    "calomnierions": "calomnier",
    "calomnierons": "calomnier",
    "calomnieront": "calomnier",
    "calomnies": "calomnier",
    "calomnieuse": "calomnieux",
    "calomnieuses": "calomnieux",
    "calomniez": "calomnier",
    "calomniiez": "calomnier",
    "calomniions": "calomnier",
    "calomnions": "calomnier",
    "calomniâmes": "calomnier",
    "calomniât": "calomnier",
    "calomniâtes": "calomnier",
    "calomnièrent": "calomnier",
    "calomnié": "calomnier",
    "calomniée": "calomnier",
    "calomniées": "calomnier",
    "calomniés": "calomnier",
    "calons": "caler",
    "calories": "calorie",
    "calorifiques": "calorifique",
    "calorifuges": "calorifuge",
    "calorifères": "calorifère",
    "calotins": "calotin",
    "calots": "calot",
    "calottais": "calotter",
    "calotte": "calotter",
    "calottes": "calotter",
    "calotté": "calotter",
    "calottées": "calotter",
    "calottés": "calotter",
    "calqua": "calquer",
    "calquai": "calquer",
    "calquaient": "calquer",
    "calquais": "calquer",
    "calquait": "calquer",
    "calquant": "calquer",
    "calquas": "calquer",
    "calquasse": "calquer",
    "calquassent": "calquer",
    "calquasses": "calquer",
    "calquassiez": "calquer",
    "calquassions": "calquer",
    "calque": "calquer",
    "calquent": "calquer",
    "calquera": "calquer",
    "calquerai": "calquer",
    "calqueraient": "calquer",
    "calquerais": "calquer",
    "calquerait": "calquer",
    "calqueras": "calquer",
    "calquerez": "calquer",
    "calqueriez": "calquer",
    "calquerions": "calquer",
    "calquerons": "calquer",
    "calqueront": "calquer",
    "calques": "calquer",
    "calquez": "calquer",
    "calquiez": "calquer",
    "calquions": "calquer",
    "calquons": "calquer",
    "calquâmes": "calquer",
    "calquât": "calquer",
    "calquâtes": "calquer",
    "calquèrent": "calquer",
    "calqué": "calquer",
    "calquée": "calquer",
    "calquées": "calquer",
    "calqués": "calquer",
    "cals": "cal",
    "calte": "calter",
    "caltent": "calter",
    "caltez": "calter",
    "caltons": "calter",
    "caltés": "calter",
    "calumets": "calumet",
    "calvaires": "calvaire",
    "calvas": "calva",
    "calvilles": "calville",
    "calvinismes": "calvinisme",
    "calvinistes": "calviniste",
    "calvities": "calvitie",
    "calâmes": "caler",
    "calât": "caler",
    "calâtes": "caler",
    "calèches": "calèche",
    "calèrent": "caler",
    "calé": "caler",
    "calédonienne": "calédonien",
    "calédoniennes": "calédonien",
    "calédoniens": "calédonien",
    "calée": "caler",
    "calées": "caler",
    "calés": "caler",
    "cama": "camer",
    "camails": "camail",
    "camaraderies": "camaraderie",
    "camarades": "camarade",
    "camarde": "camard",
    "camardes": "camard",
    "camards": "camard",
    "camareros": "camarero",
    "camarguaises": "camarguais",
    "camarillas": "camarilla",
    "camarins": "camarin",
    "camaïeux": "camaïeu",
    "cambiale": "cambial",
    "cambiales": "cambial",
    "cambiaux": "cambial",
    "cambistes": "cambiste",
    "cambodgienne": "cambodgien",
    "cambodgiennes": "cambodgien",
    "cambodgiens": "cambodgien",
    "cambra": "cambrer",
    "cambrai": "cambrer",
    "cambraient": "cambrer",
    "cambrais": "cambrer",
    "cambrait": "cambrer",
    "cambrant": "cambrer",
    "cambras": "cambrer",
    "cambrasse": "cambrer",
    "cambrassent": "cambrer",
    "cambrasses": "cambrer",
    "cambrassiez": "cambrer",
    "cambrassions": "cambrer",
    "cambre": "cambrer",
    "cambrent": "cambrer",
    "cambrera": "cambrer",
    "cambrerai": "cambrer",
    "cambreraient": "cambrer",
    "cambrerais": "cambrer",
    "cambrerait": "cambrer",
    "cambreras": "cambrer",
    "cambrerez": "cambrer",
    "cambreriez": "cambrer",
    "cambrerions": "cambrer",
    "cambrerons": "cambrer",
    "cambreront": "cambrer",
    "cambres": "cambrer",
    "cambrez": "cambrer",
    "cambrienne": "cambrien",
    "cambriez": "cambrer",
    "cambriola": "cambrioler",
    "cambriolages": "cambriolage",
    "cambriolai": "cambrioler",
    "cambriolaient": "cambrioler",
    "cambriolais": "cambrioler",
    "cambriolait": "cambrioler",
    "cambriolant": "cambrioler",
    "cambriolas": "cambrioler",
    "cambriolasse": "cambrioler",
    "cambriolassent": "cambrioler",
    "cambriolasses": "cambrioler",
    "cambriolassiez": "cambrioler",
    "cambriolassions": "cambrioler",
    "cambriole": "cambrioler",
    "cambriolent": "cambrioler",
    "cambriolera": "cambrioler",
    "cambriolerai": "cambrioler",
    "cambrioleraient": "cambrioler",
    "cambriolerais": "cambrioler",
    "cambriolerait": "cambrioler",
    "cambrioleras": "cambrioler",
    "cambriolerez": "cambrioler",
    "cambrioleriez": "cambrioler",
    "cambriolerions": "cambrioler",
    "cambriolerons": "cambrioler",
    "cambrioleront": "cambrioler",
    "cambrioles": "cambrioler",
    "cambrioleurs": "cambrioleur",
    "cambrioleuse": "cambrioleur",
    "cambrioleuses": "cambrioleur",
    "cambriolez": "cambrioler",
    "cambrioliez": "cambrioler",
    "cambriolions": "cambrioler",
    "cambriolons": "cambrioler",
    "cambriolâmes": "cambrioler",
    "cambriolât": "cambrioler",
    "cambriolâtes": "cambrioler",
    "cambriolèrent": "cambrioler",
    "cambriolé": "cambrioler",
    "cambriolée": "cambrioler",
    "cambriolées": "cambrioler",
    "cambriolés": "cambrioler",
    "cambrions": "cambrer",
    "cambrons": "cambrer",
    "cambrousses": "cambrousse",
    "cambrures": "cambrure",
    "cambrâmes": "cambrer",
    "cambrât": "cambrer",
    "cambrâtes": "cambrer",
    "cambrèrent": "cambrer",
    "cambré": "cambrer",
    "cambrée": "cambrer",
    "cambrées": "cambrer",
    "cambrés": "cambrer",
    "cambuses": "cambuse",
    "cambute": "cambuter",
    "cambuté": "cambuter",
    "camelotes": "camelote",
    "camelots": "camelot",
    "camemberts": "camembert",
    "cament": "camer",
    "camera": "camer",
    "cameramen": "cameraman",
    "cameras": "camer",
    "camerlingues": "camerlingue",
    "camerounaise": "camerounais",
    "camerounaises": "camerounais",
    "cames": "came",
    "camez": "camer",
    "camionna": "camionner",
    "camionnai": "camionner",
    "camionnaient": "camionner",
    "camionnais": "camionner",
    "camionnait": "camionner",
    "camionnant": "camionner",
    "camionnas": "camionner",
    "camionnasse": "camionner",
    "camionnassent": "camionner",
    "camionnasses": "camionner",
    "camionnassiez": "camionner",
    "camionnassions": "camionner",
    "camionne": "camionner",
    "camionnent": "camionner",
    "camionnera": "camionner",
    "camionnerai": "camionner",
    "camionneraient": "camionner",
    "camionnerais": "camionner",
    "camionnerait": "camionner",
    "camionneras": "camionner",
    "camionnerez": "camionner",
    "camionneriez": "camionner",
    "camionnerions": "camionner",
    "camionnerons": "camionner",
    "camionneront": "camionner",
    "camionnes": "camionner",
    "camionnettes": "camionnette",
    "camionneurs": "camionneur",
    "camionnez": "camionner",
    "camionniez": "camionner",
    "camionnions": "camionner",
    "camionnons": "camionner",
    "camionnâmes": "camionner",
    "camionnât": "camionner",
    "camionnâtes": "camionner",
    "camionnèrent": "camionner",
    "camionné": "camionner",
    "camionnée": "camionner",
    "camionnées": "camionner",
    "camionnés": "camionner",
    "camions": "camion",
    "camions-bennes": "camion-benne",
    "camions-citernes": "camion-citerne",
    "camisards": "camisard",
    "camisoles": "camisole",
    "camomilles": "camomille",
    "camoufla": "camoufler",
    "camouflages": "camouflage",
    "camouflai": "camoufler",
    "camouflaient": "camoufler",
    "camouflais": "camoufler",
    "camouflait": "camoufler",
    "camouflant": "camoufler",
    "camouflas": "camoufler",
    "camouflasse": "camoufler",
    "camouflassent": "camoufler",
    "camouflasses": "camoufler",
    "camouflassiez": "camoufler",
    "camouflassions": "camoufler",
    "camoufle": "camoufler",
    "camouflent": "camoufler",
    "camouflera": "camoufler",
    "camouflerai": "camoufler",
    "camoufleraient": "camoufler",
    "camouflerais": "camoufler",
    "camouflerait": "camoufler",
    "camoufleras": "camoufler",
    "camouflerez": "camoufler",
    "camoufleriez": "camoufler",
    "camouflerions": "camoufler",
    "camouflerons": "camoufler",
    "camoufleront": "camoufler",
    "camoufles": "camoufler",
    "camouflets": "camouflet",
    "camouflez": "camoufler",
    "camoufliez": "camoufler",
    "camouflions": "camoufler",
    "camouflons": "camoufler",
    "camouflâmes": "camoufler",
    "camouflât": "camoufler",
    "camouflâtes": "camoufler",
    "camouflèrent": "camoufler",
    "camouflé": "camoufler",
    "camouflée": "camoufler",
    "camouflées": "camoufler",
    "camouflés": "camoufler",
    "campa": "camper",
    "campagnarde": "campagnard",
    "campagnardes": "campagnard",
    "campagnards": "campagnard",
    "campagnes": "campagne",
    "campagnols": "campagnol",
    "campai": "camper",
    "campaient": "camper",
    "campais": "camper",
    "campait": "camper",
    "campanelles": "campanelle",
    "campanienne": "campanien",
    "campaniennes": "campanien",
    "campaniens": "campanien",
    "campaniles": "campanile",
    "campant": "camper",
    "campanules": "campanule",
    "campas": "camper",
    "campasse": "camper",
    "campassent": "camper",
    "campasses": "camper",
    "campassiez": "camper",
    "campassions": "camper",
    "campe": "camper",
    "campements": "campement",
    "campent": "camper",
    "campera": "camper",
    "camperai": "camper",
    "camperaient": "camper",
    "camperais": "camper",
    "camperait": "camper",
    "camperas": "camper",
    "camperez": "camper",
    "camperiez": "camper",
    "camperions": "camper",
    "camperons": "camper",
    "camperont": "camper",
    "campes": "camper",
    "campeurs": "campeur",
    "campeuse": "campeur",
    "campeuses": "campeur",
    "campez": "camper",
    "camphres": "camphre",
    "camphrée": "camphrer",
    "camphrées": "camphré",
    "campiez": "camper",
    "camping-cars": "camping-car",
    "campings": "camping",
    "campions": "camper",
    "campons": "camper",
    "campos": "campo",
    "camps": "camp",
    "campâmes": "camper",
    "campât": "camper",
    "campâtes": "camper",
    "campèrent": "camper",
    "campé": "camper",
    "campée": "camper",
    "campées": "camper",
    "campés": "camper",
    "campêches": "campêche",
    "camuse": "camus",
    "camuses": "camus",
    "camé": "camer",
    "camée": "camer",
    "camées": "camée",
    "camélias": "camélia",
    "camélidés": "camélidé",
    "caméléons": "caméléon",
    "caméramans": "caméraman",
    "caméras": "caméra",
    "camériers": "camérier",
    "caméristes": "camériste",
    "camés": "camer",
    "caméscopes": "caméscope",
    "cana": "caner",
    "canadairs": "canadair",
    "canadienne": "canadien",
    "canadiennes": "canadienne",
    "canadiens": "canadien",
    "canai": "caner",
    "canaient": "caner",
    "canailleries": "canaillerie",
    "canailles": "canaille",
    "canais": "caner",
    "canait": "caner",
    "canalicules": "canalicule",
    "canalisa": "canaliser",
    "canalisai": "canaliser",
    "canalisaient": "canaliser",
    "canalisais": "canaliser",
    "canalisait": "canaliser",
    "canalisant": "canaliser",
    "canalisas": "canaliser",
    "canalisasse": "canaliser",
    "canalisassent": "canaliser",
    "canalisasses": "canaliser",
    "canalisassiez": "canaliser",
    "canalisassions": "canaliser",
    "canalisations": "canalisation",
    "canalise": "canaliser",
    "canalisent": "canaliser",
    "canalisera": "canaliser",
    "canaliserai": "canaliser",
    "canaliseraient": "canaliser",
    "canaliserais": "canaliser",
    "canaliserait": "canaliser",
    "canaliseras": "canaliser",
    "canaliserez": "canaliser",
    "canaliseriez": "canaliser",
    "canaliserions": "canaliser",
    "canaliserons": "canaliser",
    "canaliseront": "canaliser",
    "canalises": "canaliser",
    "canalisez": "canaliser",
    "canalisiez": "canaliser",
    "canalisions": "canaliser",
    "canalisons": "canaliser",
    "canalisâmes": "canaliser",
    "canalisât": "canaliser",
    "canalisâtes": "canaliser",
    "canalisèrent": "canaliser",
    "canalisé": "canaliser",
    "canalisée": "canaliser",
    "canalisées": "canaliser",
    "canalisés": "canaliser",
    "canant": "caner",
    "canapés": "canapé",
    "canapés-lits": "canapé-lit",
    "canaques": "canaque",
    "canarda": "canarder",
    "canardai": "canarder",
    "canardaient": "canarder",
    "canardais": "canarder",
    "canardait": "canarder",
    "canardant": "canarder",
    "canardas": "canarder",
    "canardasse": "canarder",
    "canardassent": "canarder",
    "canardasses": "canarder",
    "canardassiez": "canarder",
    "canardassions": "canarder",
    "canarde": "canarder",
    "canardeaux": "canardeau",
    "canardent": "canarder",
    "canardera": "canarder",
    "canarderai": "canarder",
    "canarderaient": "canarder",
    "canarderais": "canarder",
    "canarderait": "canarder",
    "canarderas": "canarder",
    "canarderez": "canarder",
    "canarderiez": "canarder",
    "canarderions": "canarder",
    "canarderons": "canarder",
    "canarderont": "canarder",
    "canardes": "canarder",
    "canardez": "canarder",
    "canardiez": "canarder",
    "canardions": "canarder",
    "canardons": "canarder",
    "canards": "canard",
    "canardâmes": "canarder",
    "canardât": "canarder",
    "canardâtes": "canarder",
    "canardèrent": "canarder",
    "canardé": "canarder",
    "canardée": "canarder",
    "canardées": "canarder",
    "canardés": "canarder",
    "canarienne": "canarien",
    "canariennes": "canarien",
    "canariens": "canarien",
    "canaris": "canari",
    "canas": "caner",
    "canasse": "caner",
    "canassent": "caner",
    "canasses": "caner",
    "canassiez": "caner",
    "canassions": "caner",
    "canassons": "canasson",
    "canaux": "canal",
    "cancana": "cancaner",
    "cancanai": "cancaner",
    "cancanaient": "cancaner",
    "cancanais": "cancaner",
    "cancanait": "cancaner",
    "cancanant": "cancaner",
    "cancanas": "cancaner",
    "cancanasse": "cancaner",
    "cancanassent": "cancaner",
    "cancanasses": "cancaner",
    "cancanassiez": "cancaner",
    "cancanassions": "cancaner",
    "cancane": "cancaner",
    "cancanent": "cancaner",
    "cancanera": "cancaner",
    "cancanerai": "cancaner",
    "cancaneraient": "cancaner",
    "cancanerais": "cancaner",
    "cancanerait": "cancaner",
    "cancaneras": "cancaner",
    "cancanerez": "cancaner",
    "cancaneries": "cancanerie",
    "cancaneriez": "cancaner",
    "cancanerions": "cancaner",
    "cancanerons": "cancaner",
    "cancaneront": "cancaner",
    "cancanes": "cancaner",
    "cancanez": "cancaner",
    "cancaniez": "cancaner",
    "cancanions": "cancaner",
    "cancanière": "cancanier",
    "cancanières": "cancanier",
    "cancanons": "cancaner",
    "cancans": "cancan",
    "cancanâmes": "cancaner",
    "cancanât": "cancaner",
    "cancanâtes": "cancaner",
    "cancanèrent": "cancaner",
    "cancané": "cancaner",
    "cancanée": "cancaner",
    "cancanées": "cancaner",
    "cancanés": "cancaner",
    "cancers": "cancer",
    "cancrelats": "cancrelat",
    "cancres": "cancre",
    "cancéreuse": "cancéreux",
    "cancéreuses": "cancéreux",
    "cancérigènes": "cancérigène",
    "cancérogenèses": "cancérogenèse",
    "cancérogènes": "cancérogène",
    "cancérologies": "cancérologie",
    "cancérologues": "cancérologue",
    "candeurs": "candeur",
    "candi": "candir",
    "candidate": "candidat",
    "candidates": "candidat",
    "candidats": "candidat",
    "candidatures": "candidature",
    "candides": "candide",
    "candie": "candir",
    "candies": "candir",
    "candira": "candir",
    "candirai": "candir",
    "candiraient": "candir",
    "candirais": "candir",
    "candirait": "candir",
    "candiras": "candir",
    "candirent": "candir",
    "candirez": "candir",
    "candiriez": "candir",
    "candirions": "candir",
    "candirons": "candir",
    "candiront": "candir",
    "candis": "candir",
    "candissaient": "candir",
    "candissais": "candir",
    "candissait": "candir",
    "candissant": "candir",
    "candisse": "candir",
    "candissent": "candir",
    "candisses": "candir",
    "candissez": "candir",
    "candissiez": "candir",
    "candissions": "candir",
    "candissons": "candir",
    "candit": "candir",
    "candélabres": "candélabre",
    "candîmes": "candir",
    "candît": "candir",
    "candîtes": "candir",
    "cane": "caner",
    "canent": "caner",
    "canera": "caner",
    "canerai": "caner",
    "caneraient": "caner",
    "canerais": "caner",
    "canerait": "caner",
    "caneras": "caner",
    "canerez": "caner",
    "caneriez": "caner",
    "canerions": "caner",
    "canerons": "caner",
    "caneront": "caner",
    "canes": "caner",
    "canetons": "caneton",
    "canettes": "canette",
    "canez": "caner",
    "cangues": "cangue",
    "caniches": "caniche",
    "caniculaires": "caniculaire",
    "canicules": "canicule",
    "canidés": "canidé",
    "caniez": "caner",
    "canifs": "canif",
    "canine": "canin",
    "canines": "canine",
    "canins": "canin",
    "canions": "caner",
    "canisses": "canisse",
    "canities": "canitie",
    "caniveaux": "caniveau",
    "canna": "canner",
    "cannages": "cannage",
    "cannai": "canner",
    "cannaient": "canner",
    "cannais": "canner",
    "cannait": "canner",
    "cannant": "canner",
    "cannas": "canner",
    "cannasse": "canner",
    "cannassent": "canner",
    "cannasses": "canner",
    "cannassiez": "canner",
    "cannassions": "canner",
    "canne": "canner",
    "canneberges": "canneberge",
    "cannela": "canneler",
    "cannelai": "canneler",
    "cannelaient": "canneler",
    "cannelais": "canneler",
    "cannelait": "canneler",
    "cannelant": "canneler",
    "cannelas": "canneler",
    "cannelasse": "canneler",
    "cannelassent": "canneler",
    "cannelasses": "canneler",
    "cannelassiez": "canneler",
    "cannelassions": "canneler",
    "cannelez": "canneler",
    "canneliers": "cannelier",
    "canneliez": "canneler",
    "cannelions": "canneler",
    "cannelle": "canneler",
    "cannellent": "canneler",
    "cannellera": "canneler",
    "cannellerai": "canneler",
    "cannelleraient": "canneler",
    "cannellerais": "canneler",
    "cannellerait": "canneler",
    "cannelleras": "canneler",
    "cannellerez": "canneler",
    "cannelleriez": "canneler",
    "cannellerions": "canneler",
    "cannellerons": "canneler",
    "cannelleront": "canneler",
    "cannelles": "cannelle",
    "cannellonis": "cannelloni",
    "cannelons": "canneler",
    "cannelures": "cannelure",
    "cannelâmes": "canneler",
    "cannelât": "canneler",
    "cannelâtes": "canneler",
    "cannelèrent": "canneler",
    "cannelé": "canneler",
    "cannelée": "canneler",
    "cannelées": "canneler",
    "cannelés": "canneler",
    "cannent": "canner",
    "cannera": "canner",
    "cannerai": "canner",
    "canneraient": "canner",
    "cannerais": "canner",
    "cannerait": "canner",
    "canneras": "canner",
    "cannerez": "canner",
    "canneriez": "canner",
    "cannerions": "canner",
    "cannerons": "canner",
    "canneront": "canner",
    "cannes": "canner",
    "cannes-épées": "canne-épée",
    "cannettes": "cannette",
    "cannez": "canner",
    "cannibales": "cannibale",
    "cannibalisations": "cannibalisation",
    "canniez": "canner",
    "cannions": "canner",
    "cannoise": "cannois",
    "cannons": "canner",
    "cannâmes": "canner",
    "cannât": "canner",
    "cannâtes": "canner",
    "cannèrent": "canner",
    "canné": "canner",
    "cannée": "canner",
    "cannées": "canner",
    "cannés": "canner",
    "canoniale": "canonial",
    "canoniales": "canonial",
    "canoniaux": "canonial",
    "canoniques": "canonique",
    "canonisa": "canoniser",
    "canonisai": "canoniser",
    "canonisaient": "canoniser",
    "canonisais": "canoniser",
    "canonisait": "canoniser",
    "canonisant": "canoniser",
    "canonisas": "canoniser",
    "canonisasse": "canoniser",
    "canonisassent": "canoniser",
    "canonisasses": "canoniser",
    "canonisassiez": "canoniser",
    "canonisassions": "canoniser",
    "canonisations": "canonisation",
    "canonise": "canoniser",
    "canonisent": "canoniser",
    "canonisera": "canoniser",
    "canoniserai": "canoniser",
    "canoniseraient": "canoniser",
    "canoniserais": "canoniser",
    "canoniserait": "canoniser",
    "canoniseras": "canoniser",
    "canoniserez": "canoniser",
    "canoniseriez": "canoniser",
    "canoniserions": "canoniser",
    "canoniserons": "canoniser",
    "canoniseront": "canoniser",
    "canonises": "canoniser",
    "canonisez": "canoniser",
    "canonisiez": "canoniser",
    "canonisions": "canoniser",
    "canonisons": "canoniser",
    "canonisâmes": "canoniser",
    "canonisât": "canoniser",
    "canonisâtes": "canoniser",
    "canonisèrent": "canoniser",
    "canonisé": "canoniser",
    "canonisée": "canoniser",
    "canonisées": "canoniser",
    "canonisés": "canoniser",
    "canonna": "canonner",
    "canonnades": "canonnade",
    "canonnai": "canonner",
    "canonnaient": "canonner",
    "canonnais": "canonner",
    "canonnait": "canonner",
    "canonnant": "canonner",
    "canonnas": "canonner",
    "canonnasse": "canonner",
    "canonnassent": "canonner",
    "canonnasses": "canonner",
    "canonnassiez": "canonner",
    "canonnassions": "canonner",
    "canonne": "canonner",
    "canonnent": "canonner",
    "canonnera": "canonner",
    "canonnerai": "canonner",
    "canonneraient": "canonner",
    "canonnerais": "canonner",
    "canonnerait": "canonner",
    "canonneras": "canonner",
    "canonnerez": "canonner",
    "canonneriez": "canonner",
    "canonnerions": "canonner",
    "canonnerons": "canonner",
    "canonneront": "canonner",
    "canonnes": "canonner",
    "canonnez": "canonner",
    "canonniers": "canonnier",
    "canonniez": "canonner",
    "canonnions": "canonner",
    "canonnières": "canonnière",
    "canonnons": "canonner",
    "canonnâmes": "canonner",
    "canonnât": "canonner",
    "canonnâtes": "canonner",
    "canonnèrent": "canonner",
    "canonné": "canonner",
    "canonnée": "canonner",
    "canonnées": "canonner",
    "canonnés": "canonner",
    "canons": "canon",
    "canopes": "canope",
    "canotages": "canotage",
    "canotaient": "canoter",
    "canote": "canoter",
    "canotent": "canoter",
    "canoteurs": "canoteur",
    "canotiers": "canotier",
    "canots": "canot",
    "canotâmes": "canoter",
    "canoté": "canoter",
    "canoéismes": "canoéisme",
    "canoës": "canoë",
    "cantabiles": "cantabile",
    "cantabriques": "cantabrique",
    "cantaloups": "cantaloup",
    "cantals": "cantal",
    "cantates": "cantate",
    "cantatrices": "cantatrice",
    "canters": "canter",
    "canthares": "canthare",
    "cantharides": "cantharide",
    "cantilènes": "cantilène",
    "cantina": "cantiner",
    "cantinaient": "cantiner",
    "cantines": "cantine",
    "cantiniers": "cantinier",
    "cantinière": "cantinier",
    "cantinières": "cantinier",
    "cantiques": "cantique",
    "cantonades": "cantonade",
    "cantonaise": "cantonais",
    "cantonale": "cantonal",
    "cantonales": "cantonal",
    "cantonaux": "cantonal",
    "cantonna": "cantonner",
    "cantonnai": "cantonner",
    "cantonnaient": "cantonner",
    "cantonnais": "cantonner",
    "cantonnait": "cantonner",
    "cantonnant": "cantonner",
    "cantonnas": "cantonner",
    "cantonnasse": "cantonner",
    "cantonnassent": "cantonner",
    "cantonnasses": "cantonner",
    "cantonnassiez": "cantonner",
    "cantonnassions": "cantonner",
    "cantonne": "cantonner",
    "cantonnements": "cantonnement",
    "cantonnent": "cantonner",
    "cantonnera": "cantonner",
    "cantonnerai": "cantonner",
    "cantonneraient": "cantonner",
    "cantonnerais": "cantonner",
    "cantonnerait": "cantonner",
    "cantonneras": "cantonner",
    "cantonnerez": "cantonner",
    "cantonneriez": "cantonner",
    "cantonnerions": "cantonner",
    "cantonnerons": "cantonner",
    "cantonneront": "cantonner",
    "cantonnes": "cantonner",
    "cantonnez": "cantonner",
    "cantonniers": "cantonnier",
    "cantonniez": "cantonner",
    "cantonnions": "cantonner",
    "cantonnières": "cantonnière",
    "cantonnons": "cantonner",
    "cantonnâmes": "cantonner",
    "cantonnât": "cantonner",
    "cantonnâtes": "cantonner",
    "cantonnèrent": "cantonner",
    "cantonné": "cantonner",
    "cantonnée": "cantonner",
    "cantonnées": "cantonner",
    "cantonnés": "cantonner",
    "cantons": "canton",
    "canulant": "canuler",
    "canulars": "canular",
    "canules": "canule",
    "canuse": "canut",
    "canuses": "canut",
    "canuts": "canut",
    "canyons": "canyon",
    "canzonettes": "canzonette",
    "canâmes": "caner",
    "canât": "caner",
    "canâtes": "caner",
    "canèrent": "caner",
    "cané": "caner",
    "canée": "caner",
    "canées": "caner",
    "canéphores": "canéphore",
    "canés": "caner",
    "caouas": "caoua",
    "caoutchoucs": "caoutchouc",
    "caoutchouta": "caoutchouter",
    "caoutchoutai": "caoutchouter",
    "caoutchoutaient": "caoutchouter",
    "caoutchoutais": "caoutchouter",
    "caoutchoutait": "caoutchouter",
    "caoutchoutant": "caoutchouter",
    "caoutchoutas": "caoutchouter",
    "caoutchoutasse": "caoutchouter",
    "caoutchoutassent": "caoutchouter",
    "caoutchoutasses": "caoutchouter",
    "caoutchoutassiez": "caoutchouter",
    "caoutchoutassions": "caoutchouter",
    "caoutchoute": "caoutchouter",
    "caoutchoutent": "caoutchouter",
    "caoutchoutera": "caoutchouter",
    "caoutchouterai": "caoutchouter",
    "caoutchouteraient": "caoutchouter",
    "caoutchouterais": "caoutchouter",
    "caoutchouterait": "caoutchouter",
    "caoutchouteras": "caoutchouter",
    "caoutchouterez": "caoutchouter",
    "caoutchouteriez": "caoutchouter",
    "caoutchouterions": "caoutchouter",
    "caoutchouterons": "caoutchouter",
    "caoutchouteront": "caoutchouter",
    "caoutchoutes": "caoutchouter",
    "caoutchouteuse": "caoutchouteux",
    "caoutchouteuses": "caoutchouteux",
    "caoutchoutez": "caoutchouter",
    "caoutchoutiez": "caoutchouter",
    "caoutchoutions": "caoutchouter",
    "caoutchoutons": "caoutchouter",
    "caoutchoutâmes": "caoutchouter",
    "caoutchoutât": "caoutchouter",
    "caoutchoutâtes": "caoutchouter",
    "caoutchoutèrent": "caoutchouter",
    "caoutchouté": "caoutchouter",
    "caoutchoutée": "caoutchouter",
    "caoutchoutées": "caoutchouter",
    "caoutchoutés": "caoutchouter",
    "cap-horniers": "cap-hornier",
    "capables": "capable",
    "capacités": "capacité",
    "capades": "capade",
    "caparaçonna": "caparaçonner",
    "caparaçonnai": "caparaçonner",
    "caparaçonnaient": "caparaçonner",
    "caparaçonnais": "caparaçonner",
    "caparaçonnait": "caparaçonner",
    "caparaçonnant": "caparaçonner",
    "caparaçonnas": "caparaçonner",
    "caparaçonnasse": "caparaçonner",
    "caparaçonnassent": "caparaçonner",
    "caparaçonnasses": "caparaçonner",
    "caparaçonnassiez": "caparaçonner",
    "caparaçonnassions": "caparaçonner",
    "caparaçonne": "caparaçonner",
    "caparaçonnent": "caparaçonner",
    "caparaçonnera": "caparaçonner",
    "caparaçonnerai": "caparaçonner",
    "caparaçonneraient": "caparaçonner",
    "caparaçonnerais": "caparaçonner",
    "caparaçonnerait": "caparaçonner",
    "caparaçonneras": "caparaçonner",
    "caparaçonnerez": "caparaçonner",
    "caparaçonneriez": "caparaçonner",
    "caparaçonnerions": "caparaçonner",
    "caparaçonnerons": "caparaçonner",
    "caparaçonneront": "caparaçonner",
    "caparaçonnes": "caparaçonner",
    "caparaçonnez": "caparaçonner",
    "caparaçonniez": "caparaçonner",
    "caparaçonnions": "caparaçonner",
    "caparaçonnons": "caparaçonner",
    "caparaçonnâmes": "caparaçonner",
    "caparaçonnât": "caparaçonner",
    "caparaçonnâtes": "caparaçonner",
    "caparaçonnèrent": "caparaçonner",
    "caparaçonné": "caparaçonner",
    "caparaçonnée": "caparaçonner",
    "caparaçonnées": "caparaçonner",
    "caparaçonnés": "caparaçonner",
    "caparaçons": "caparaçon",
    "capela": "capeler",
    "capelages": "capelage",
    "capelai": "capeler",
    "capelaient": "capeler",
    "capelais": "capeler",
    "capelait": "capeler",
    "capelant": "capeler",
    "capelas": "capeler",
    "capelasse": "capeler",
    "capelassent": "capeler",
    "capelasses": "capeler",
    "capelassiez": "capeler",
    "capelassions": "capeler",
    "capelez": "capeler",
    "capeliez": "capeler",
    "capelines": "capeline",
    "capelions": "capeler",
    "capelle": "capeler",
    "capellent": "capeler",
    "capellera": "capeler",
    "capellerai": "capeler",
    "capelleraient": "capeler",
    "capellerais": "capeler",
    "capellerait": "capeler",
    "capelleras": "capeler",
    "capellerez": "capeler",
    "capelleriez": "capeler",
    "capellerions": "capeler",
    "capellerons": "capeler",
    "capelleront": "capeler",
    "capelles": "capeler",
    "capelons": "capeler",
    "capelâmes": "capeler",
    "capelât": "capeler",
    "capelâtes": "capeler",
    "capelèrent": "capeler",
    "capelé": "capeler",
    "capelée": "capeler",
    "capelées": "capeler",
    "capelés": "capeler",
    "capes": "cape",
    "capharnaüms": "capharnaüm",
    "capillaires": "capillaire",
    "capillarités": "capillarité",
    "capilotades": "capilotade",
    "capitaines": "capitaine",
    "capitale": "capital",
    "capitales": "capitale",
    "capitalisa": "capitaliser",
    "capitalisables": "capitalisable",
    "capitalisai": "capitaliser",
    "capitalisaient": "capitaliser",
    "capitalisais": "capitaliser",
    "capitalisait": "capitaliser",
    "capitalisant": "capitaliser",
    "capitalisas": "capitaliser",
    "capitalisasse": "capitaliser",
    "capitalisassent": "capitaliser",
    "capitalisasses": "capitaliser",
    "capitalisassiez": "capitaliser",
    "capitalisassions": "capitaliser",
    "capitalisations": "capitalisation",
    "capitalise": "capitaliser",
    "capitalisent": "capitaliser",
    "capitalisera": "capitaliser",
    "capitaliserai": "capitaliser",
    "capitaliseraient": "capitaliser",
    "capitaliserais": "capitaliser",
    "capitaliserait": "capitaliser",
    "capitaliseras": "capitaliser",
    "capitaliserez": "capitaliser",
    "capitaliseriez": "capitaliser",
    "capitaliserions": "capitaliser",
    "capitaliserons": "capitaliser",
    "capitaliseront": "capitaliser",
    "capitalises": "capitaliser",
    "capitalisez": "capitaliser",
    "capitalisiez": "capitaliser",
    "capitalisions": "capitaliser",
    "capitalismes": "capitalisme",
    "capitalisons": "capitaliser",
    "capitalistes": "capitaliste",
    "capitalistiques": "capitalistique",
    "capitalisâmes": "capitaliser",
    "capitalisât": "capitaliser",
    "capitalisâtes": "capitaliser",
    "capitalisèrent": "capitaliser",
    "capitalisé": "capitaliser",
    "capitalisée": "capitaliser",
    "capitalisées": "capitaliser",
    "capitalisés": "capitaliser",
    "capitans": "capitan",
    "capitations": "capitation",
    "capitaux": "capital",
    "capiteuse": "capiteux",
    "capiteuses": "capiteux",
    "capitoles": "capitole",
    "capitonna": "capitonner",
    "capitonnai": "capitonner",
    "capitonnaient": "capitonner",
    "capitonnais": "capitonner",
    "capitonnait": "capitonner",
    "capitonnant": "capitonner",
    "capitonnas": "capitonner",
    "capitonnasse": "capitonner",
    "capitonnassent": "capitonner",
    "capitonnasses": "capitonner",
    "capitonnassiez": "capitonner",
    "capitonnassions": "capitonner",
    "capitonne": "capitonner",
    "capitonnent": "capitonner",
    "capitonnera": "capitonner",
    "capitonnerai": "capitonner",
    "capitonneraient": "capitonner",
    "capitonnerais": "capitonner",
    "capitonnerait": "capitonner",
    "capitonneras": "capitonner",
    "capitonnerez": "capitonner",
    "capitonneriez": "capitonner",
    "capitonnerions": "capitonner",
    "capitonnerons": "capitonner",
    "capitonneront": "capitonner",
    "capitonnes": "capitonner",
    "capitonnez": "capitonner",
    "capitonniez": "capitonner",
    "capitonnions": "capitonner",
    "capitonnons": "capitonner",
    "capitonnâmes": "capitonner",
    "capitonnât": "capitonner",
    "capitonnâtes": "capitonner",
    "capitonnèrent": "capitonner",
    "capitonné": "capitonner",
    "capitonnée": "capitonner",
    "capitonnées": "capitonner",
    "capitonnés": "capitonner",
    "capitons": "capiton",
    "capitouls": "capitoul",
    "capitula": "capituler",
    "capitulai": "capituler",
    "capitulaient": "capituler",
    "capitulaires": "capitulaire",
    "capitulais": "capituler",
    "capitulait": "capituler",
    "capitulant": "capituler",
    "capitulas": "capituler",
    "capitulasse": "capituler",
    "capitulassent": "capituler",
    "capitulasses": "capituler",
    "capitulassiez": "capituler",
    "capitulassions": "capituler",
    "capitulations": "capitulation",
    "capitule": "capituler",
    "capitulent": "capituler",
    "capitulera": "capituler",
    "capitulerai": "capituler",
    "capituleraient": "capituler",
    "capitulerais": "capituler",
    "capitulerait": "capituler",
    "capituleras": "capituler",
    "capitulerez": "capituler",
    "capituleriez": "capituler",
    "capitulerions": "capituler",
    "capitulerons": "capituler",
    "capituleront": "capituler",
    "capitules": "capituler",
    "capitulez": "capituler",
    "capituliez": "capituler",
    "capitulions": "capituler",
    "capitulons": "capituler",
    "capitulâmes": "capituler",
    "capitulât": "capituler",
    "capitulâtes": "capituler",
    "capitulèrent": "capituler",
    "capitulé": "capituler",
    "caponne": "capon",
    "caponnes": "capon",
    "capons": "capon",
    "caporale": "caporal",
    "caporaux": "caporal",
    "capos": "capo",
    "capota": "capoter",
    "capotai": "capoter",
    "capotaient": "capoter",
    "capotais": "capoter",
    "capotait": "capoter",
    "capotant": "capoter",
    "capotas": "capoter",
    "capotasse": "capoter",
    "capotassent": "capoter",
    "capotasses": "capoter",
    "capotassiez": "capoter",
    "capotassions": "capoter",
    "capote": "capoter",
    "capotent": "capoter",
    "capotera": "capoter",
    "capoterai": "capoter",
    "capoteraient": "capoter",
    "capoterais": "capoter",
    "capoterait": "capoter",
    "capoteras": "capoter",
    "capoterez": "capoter",
    "capoteriez": "capoter",
    "capoterions": "capoter",
    "capoterons": "capoter",
    "capoteront": "capoter",
    "capotes": "capoter",
    "capotez": "capoter",
    "capotiez": "capoter",
    "capotions": "capoter",
    "capotons": "capoter",
    "capots": "capot",
    "capotâmes": "capoter",
    "capotât": "capoter",
    "capotâtes": "capoter",
    "capotèrent": "capoter",
    "capoté": "capoter",
    "capotée": "capoter",
    "capotées": "capoter",
    "capotés": "capoter",
    "cappuccinos": "cappuccino",
    "capricants": "capricant",
    "caprices": "caprice",
    "capricieuse": "capricieux",
    "capricieuses": "capricieux",
    "capricornes": "capricorne",
    "caprine": "caprin",
    "caprines": "caprin",
    "caprins": "caprin",
    "caps": "cap",
    "capsule": "capsuler",
    "capsules": "capsule",
    "capsulé": "capsuler",
    "capta": "capter",
    "captages": "captage",
    "captai": "capter",
    "captaient": "capter",
    "captais": "capter",
    "captait": "capter",
    "captals": "captal",
    "captant": "capter",
    "captas": "capter",
    "captasse": "capter",
    "captassent": "capter",
    "captasses": "capter",
    "captassiez": "capter",
    "captassions": "capter",
    "captations": "captation",
    "capte": "capter",
    "captent": "capter",
    "captera": "capter",
    "capterai": "capter",
    "capteraient": "capter",
    "capterais": "capter",
    "capterait": "capter",
    "capteras": "capter",
    "capterez": "capter",
    "capteriez": "capter",
    "capterions": "capter",
    "capterons": "capter",
    "capteront": "capter",
    "captes": "capter",
    "capteurs": "capteur",
    "captez": "capter",
    "captieuse": "captieux",
    "captieuses": "captieux",
    "captiez": "capter",
    "captifs": "captif",
    "captions": "capter",
    "captiva": "captiver",
    "captivai": "captiver",
    "captivaient": "captiver",
    "captivais": "captiver",
    "captivait": "captiver",
    "captivant": "captiver",
    "captivante": "captivant",
    "captivantes": "captivant",
    "captivants": "captivant",
    "captivas": "captiver",
    "captivasse": "captiver",
    "captivassent": "captiver",
    "captivasses": "captiver",
    "captivassiez": "captiver",
    "captivassions": "captiver",
    "captive": "captiver",
    "captivent": "captiver",
    "captivera": "captiver",
    "captiverai": "captiver",
    "captiveraient": "captiver",
    "captiverais": "captiver",
    "captiverait": "captiver",
    "captiveras": "captiver",
    "captiverez": "captiver",
    "captiveriez": "captiver",
    "captiverions": "captiver",
    "captiverons": "captiver",
    "captiveront": "captiver",
    "captives": "captiver",
    "captivez": "captiver",
    "captiviez": "captiver",
    "captivions": "captiver",
    "captivités": "captivité",
    "captivons": "captiver",
    "captivâmes": "captiver",
    "captivât": "captiver",
    "captivâtes": "captiver",
    "captivèrent": "captiver",
    "captivé": "captiver",
    "captivée": "captiver",
    "captivées": "captiver",
    "captivés": "captiver",
    "captons": "capter",
    "captura": "capturer",
    "capturai": "capturer",
    "capturaient": "capturer",
    "capturais": "capturer",
    "capturait": "capturer",
    "capturant": "capturer",
    "capturas": "capturer",
    "capturasse": "capturer",
    "capturassent": "capturer",
    "capturasses": "capturer",
    "capturassiez": "capturer",
    "capturassions": "capturer",
    "capture": "capturer",
    "capturent": "capturer",
    "capturera": "capturer",
    "capturerai": "capturer",
    "captureraient": "capturer",
    "capturerais": "capturer",
    "capturerait": "capturer",
    "captureras": "capturer",
    "capturerez": "capturer",
    "captureriez": "capturer",
    "capturerions": "capturer",
    "capturerons": "capturer",
    "captureront": "capturer",
    "captures": "capturer",
    "capturez": "capturer",
    "capturiez": "capturer",
    "capturions": "capturer",
    "capturons": "capturer",
    "capturâmes": "capturer",
    "capturât": "capturer",
    "capturâtes": "capturer",
    "capturèrent": "capturer",
    "capturé": "capturer",
    "capturée": "capturer",
    "capturées": "capturer",
    "capturés": "capturer",
    "captâmes": "capter",
    "captât": "capter",
    "captâtes": "capter",
    "captèrent": "capter",
    "capté": "capter",
    "captée": "capter",
    "captées": "capter",
    "captés": "capter",
    "capuces": "capuce",
    "capuches": "capuche",
    "capuchonnés": "capuchonner",
    "capuchons": "capuchon",
    "capucinades": "capucinade",
    "capucines": "capucine",
    "capucins": "capucin",
    "capulets": "capulet",
    "capétienne": "capétien",
    "capétiennes": "capétien",
    "caques": "caque",
    "caquetages": "caquetage",
    "caquetaient": "caqueter",
    "caquetait": "caqueter",
    "caquetant": "caqueter",
    "caquetante": "caquetant",
    "caquetantes": "caquetant",
    "caqueteuse": "caqueteur",
    "caquets": "caquet",
    "caquette": "caqueter",
    "caquettent": "caqueter",
    "caquètements": "caquètement",
    "car-ferries": "car-ferry",
    "carabes": "carabe",
    "carabines": "carabine",
    "carabiniers": "carabinier",
    "carabins": "carabin",
    "carabinée": "carabiné",
    "carabinées": "carabiné",
    "carabinés": "carabiné",
    "caracals": "caracal",
    "caracola": "caracoler",
    "caracolai": "caracoler",
    "caracolaient": "caracoler",
    "caracolais": "caracoler",
    "caracolait": "caracoler",
    "caracolant": "caracoler",
    "caracolas": "caracoler",
    "caracolasse": "caracoler",
    "caracolassent": "caracoler",
    "caracolasses": "caracoler",
    "caracolassiez": "caracoler",
    "caracolassions": "caracoler",
    "caracole": "caracoler",
    "caracolent": "caracoler",
    "caracolera": "caracoler",
    "caracolerai": "caracoler",
    "caracoleraient": "caracoler",
    "caracolerais": "caracoler",
    "caracolerait": "caracoler",
    "caracoleras": "caracoler",
    "caracolerez": "caracoler",
    "caracoleriez": "caracoler",
    "caracolerions": "caracoler",
    "caracolerons": "caracoler",
    "caracoleront": "caracoler",
    "caracoles": "caracoler",
    "caracolez": "caracoler",
    "caracoliez": "caracoler",
    "caracolions": "caracoler",
    "caracolons": "caracoler",
    "caracolâmes": "caracoler",
    "caracolât": "caracoler",
    "caracolâtes": "caracoler",
    "caracolèrent": "caracoler",
    "caracolé": "caracoler",
    "caracos": "caraco",
    "caractères": "caractère",
    "caractérielle": "caractériel",
    "caractérielles": "caractériel",
    "caractériels": "caractériel",
    "caractérisa": "caractériser",
    "caractérisai": "caractériser",
    "caractérisaient": "caractériser",
    "caractérisais": "caractériser",
    "caractérisait": "caractériser",
    "caractérisant": "caractériser",
    "caractérisas": "caractériser",
    "caractérisasse": "caractériser",
    "caractérisassent": "caractériser",
    "caractérisasses": "caractériser",
    "caractérisassiez": "caractériser",
    "caractérisassions": "caractériser",
    "caractérisations": "caractérisation",
    "caractérise": "caractériser",
    "caractérisent": "caractériser",
    "caractérisera": "caractériser",
    "caractériserai": "caractériser",
    "caractériseraient": "caractériser",
    "caractériserais": "caractériser",
    "caractériserait": "caractériser",
    "caractériseras": "caractériser",
    "caractériserez": "caractériser",
    "caractériseriez": "caractériser",
    "caractériserions": "caractériser",
    "caractériserons": "caractériser",
    "caractériseront": "caractériser",
    "caractérises": "caractériser",
    "caractérisez": "caractériser",
    "caractérisiez": "caractériser",
    "caractérisions": "caractériser",
    "caractérisons": "caractériser",
    "caractéristiques": "caractéristique",
    "caractérisâmes": "caractériser",
    "caractérisât": "caractériser",
    "caractérisâtes": "caractériser",
    "caractérisèrent": "caractériser",
    "caractérisé": "caractériser",
    "caractérisée": "caractériser",
    "caractérisées": "caractériser",
    "caractérisés": "caractériser",
    "caraculs": "caracul",
    "carafes": "carafe",
    "carafons": "carafon",
    "carambars": "carambar",
    "carambola": "caramboler",
    "carambolages": "carambolage",
    "carambolai": "caramboler",
    "carambolaient": "caramboler",
    "carambolais": "caramboler",
    "carambolait": "caramboler",
    "carambolant": "caramboler",
    "carambolas": "caramboler",
    "carambolasse": "caramboler",
    "carambolassent": "caramboler",
    "carambolasses": "caramboler",
    "carambolassiez": "caramboler",
    "carambolassions": "caramboler",
    "carambole": "caramboler",
    "carambolent": "caramboler",
    "carambolera": "caramboler",
    "carambolerai": "caramboler",
    "caramboleraient": "caramboler",
    "carambolerais": "caramboler",
    "carambolerait": "caramboler",
    "caramboleras": "caramboler",
    "carambolerez": "caramboler",
    "caramboleriez": "caramboler",
    "carambolerions": "caramboler",
    "carambolerons": "caramboler",
    "caramboleront": "caramboler",
    "caramboles": "caramboler",
    "carambolez": "caramboler",
    "caramboliez": "caramboler",
    "carambolions": "caramboler",
    "carambolons": "caramboler",
    "carambolâmes": "caramboler",
    "carambolât": "caramboler",
    "carambolâtes": "caramboler",
    "carambolèrent": "caramboler",
    "carambolé": "caramboler",
    "carambolée": "caramboler",
    "carambolées": "caramboler",
    "carambolés": "caramboler",
    "carambouilles": "carambouille",
    "carambouilleurs": "carambouilleur",
    "carambouillé": "carambouiller",
    "caramels": "caramel",
    "caramélisa": "caraméliser",
    "caramélisai": "caraméliser",
    "caramélisaient": "caraméliser",
    "caramélisais": "caraméliser",
    "caramélisait": "caraméliser",
    "caramélisant": "caraméliser",
    "caramélisas": "caraméliser",
    "caramélisasse": "caraméliser",
    "caramélisassent": "caraméliser",
    "caramélisasses": "caraméliser",
    "caramélisassiez": "caraméliser",
    "caramélisassions": "caraméliser",
    "caramélise": "caraméliser",
    "caramélisent": "caraméliser",
    "caramélisera": "caraméliser",
    "caraméliserai": "caraméliser",
    "caraméliseraient": "caraméliser",
    "caraméliserais": "caraméliser",
    "caraméliserait": "caraméliser",
    "caraméliseras": "caraméliser",
    "caraméliserez": "caraméliser",
    "caraméliseriez": "caraméliser",
    "caraméliserions": "caraméliser",
    "caraméliserons": "caraméliser",
    "caraméliseront": "caraméliser",
    "caramélises": "caraméliser",
    "caramélisez": "caraméliser",
    "caramélisiez": "caraméliser",
    "caramélisions": "caraméliser",
    "caramélisons": "caraméliser",
    "caramélisâmes": "caraméliser",
    "caramélisât": "caraméliser",
    "caramélisâtes": "caraméliser",
    "caramélisèrent": "caraméliser",
    "caramélisé": "caraméliser",
    "caramélisée": "caraméliser",
    "caramélisées": "caraméliser",
    "caramélisés": "caraméliser",
    "carapaces": "carapace",
    "carapatait": "carapater",
    "carapate": "carapater",
    "carapatent": "carapater",
    "carapaté": "carapater",
    "carapatés": "carapater",
    "carats": "carat",
    "caravanes": "caravane",
    "caravaniers": "caravanier",
    "caravanings": "caravaning",
    "caravanière": "caravanier",
    "caravanières": "caravanier",
    "caravansérails": "caravansérail",
    "caravelles": "caravelle",
    "caraïbes": "caraïbe",
    "carbets": "carbet",
    "carbonades": "carbonade",
    "carbonaros": "carbonaro",
    "carbonates": "carbonate",
    "carbones": "carbone",
    "carbonifères": "carbonifère",
    "carboniques": "carbonique",
    "carbonisa": "carboniser",
    "carbonisai": "carboniser",
    "carbonisaient": "carboniser",
    "carbonisais": "carboniser",
    "carbonisait": "carboniser",
    "carbonisant": "carboniser",
    "carbonisas": "carboniser",
    "carbonisasse": "carboniser",
    "carbonisassent": "carboniser",
    "carbonisasses": "carboniser",
    "carbonisassiez": "carboniser",
    "carbonisassions": "carboniser",
    "carbonise": "carboniser",
    "carbonisent": "carboniser",
    "carbonisera": "carboniser",
    "carboniserai": "carboniser",
    "carboniseraient": "carboniser",
    "carboniserais": "carboniser",
    "carboniserait": "carboniser",
    "carboniseras": "carboniser",
    "carboniserez": "carboniser",
    "carboniseriez": "carboniser",
    "carboniserions": "carboniser",
    "carboniserons": "carboniser",
    "carboniseront": "carboniser",
    "carbonises": "carboniser",
    "carbonisez": "carboniser",
    "carbonisiez": "carboniser",
    "carbonisions": "carboniser",
    "carbonisons": "carboniser",
    "carbonisâmes": "carboniser",
    "carbonisât": "carboniser",
    "carbonisâtes": "carboniser",
    "carbonisèrent": "carboniser",
    "carbonisé": "carboniser",
    "carbonisée": "carboniser",
    "carbonisées": "carboniser",
    "carbonisés": "carboniser",
    "carbonnades": "carbonnade",
    "carbura": "carburer",
    "carburai": "carburer",
    "carburaient": "carburer",
    "carburais": "carburer",
    "carburait": "carburer",
    "carburant": "carburer",
    "carburants": "carburant",
    "carburas": "carburer",
    "carburasse": "carburer",
    "carburassent": "carburer",
    "carburasses": "carburer",
    "carburassiez": "carburer",
    "carburassions": "carburer",
    "carburateurs": "carburateur",
    "carbure": "carburer",
    "carburent": "carburer",
    "carburera": "carburer",
    "carburerai": "carburer",
    "carbureraient": "carburer",
    "carburerais": "carburer",
    "carburerait": "carburer",
    "carbureras": "carburer",
    "carburerez": "carburer",
    "carbureriez": "carburer",
    "carburerions": "carburer",
    "carburerons": "carburer",
    "carbureront": "carburer",
    "carbures": "carburer",
    "carburez": "carburer",
    "carburiez": "carburer",
    "carburions": "carburer",
    "carburons": "carburer",
    "carburâmes": "carburer",
    "carburât": "carburer",
    "carburâtes": "carburer",
    "carburèrent": "carburer",
    "carburé": "carburer",
    "carburée": "carburer",
    "carburées": "carburer",
    "carburés": "carburer",
    "carcailla": "carcailler",
    "carcaillai": "carcailler",
    "carcaillaient": "carcailler",
    "carcaillais": "carcailler",
    "carcaillait": "carcailler",
    "carcaillant": "carcailler",
    "carcaillas": "carcailler",
    "carcaillasse": "carcailler",
    "carcaillassent": "carcailler",
    "carcaillasses": "carcailler",
    "carcaillassiez": "carcailler",
    "carcaillassions": "carcailler",
    "carcaille": "carcailler",
    "carcaillent": "carcailler",
    "carcaillera": "carcailler",
    "carcaillerai": "carcailler",
    "carcailleraient": "carcailler",
    "carcaillerais": "carcailler",
    "carcaillerait": "carcailler",
    "carcailleras": "carcailler",
    "carcaillerez": "carcailler",
    "carcailleriez": "carcailler",
    "carcaillerions": "carcailler",
    "carcaillerons": "carcailler",
    "carcailleront": "carcailler",
    "carcailles": "carcailler",
    "carcaillez": "carcailler",
    "carcailliez": "carcailler",
    "carcaillions": "carcailler",
    "carcaillons": "carcailler",
    "carcaillâmes": "carcailler",
    "carcaillât": "carcailler",
    "carcaillâtes": "carcailler",
    "carcaillèrent": "carcailler",
    "carcaillé": "carcailler",
    "carcajous": "carcajou",
    "carcans": "carcan",
    "carcasses": "carcasse",
    "carcinogènes": "carcinogène",
    "carcinomes": "carcinome",
    "carcinoïdes": "carcinoïde",
    "carcérale": "carcéral",
    "carcérales": "carcéral",
    "carcéraux": "carcéral",
    "carda": "carder",
    "cardai": "carder",
    "cardaient": "carder",
    "cardais": "carder",
    "cardait": "carder",
    "cardamines": "cardamine",
    "cardamomes": "cardamome",
    "cardans": "cardan",
    "cardant": "carder",
    "cardas": "carder",
    "cardasse": "carder",
    "cardassent": "carder",
    "cardasses": "carder",
    "cardassiez": "carder",
    "cardassions": "carder",
    "carde": "carder",
    "cardent": "carder",
    "cardera": "carder",
    "carderai": "carder",
    "carderaient": "carder",
    "carderais": "carder",
    "carderait": "carder",
    "carderas": "carder",
    "carderez": "carder",
    "carderiez": "carder",
    "carderions": "carder",
    "carderons": "carder",
    "carderont": "carder",
    "cardes": "carder",
    "cardeuse": "cardeur",
    "cardeuses": "cardeur",
    "cardez": "carder",
    "cardiaques": "cardiaque",
    "cardias": "cardia",
    "cardiez": "carder",
    "cardigans": "cardigan",
    "cardinale": "cardinal",
    "cardinales": "cardinal",
    "cardinalices": "cardinalice",
    "cardinaux": "cardinal",
    "cardio-circulatoires": "cardio-circulatoire",
    "cardio-vasculaires": "cardio-vasculaire",
    "cardiologies": "cardiologie",
    "cardiologues": "cardiologue",
    "cardions": "carder",
    "cardons": "cardon",
    "cardâmes": "carder",
    "cardât": "carder",
    "cardâtes": "carder",
    "cardèrent": "carder",
    "cardères": "cardère",
    "cardé": "carder",
    "cardée": "carder",
    "cardées": "carder",
    "cardés": "carder",
    "carences": "carence",
    "caressa": "caresser",
    "caressai": "caresser",
    "caressaient": "caresser",
    "caressais": "caresser",
    "caressait": "caresser",
    "caressant": "caresser",
    "caressante": "caressant",
    "caressantes": "caressant",
    "caressants": "caressant",
    "caressas": "caresser",
    "caressasse": "caresser",
    "caressassent": "caresser",
    "caressasses": "caresser",
    "caressassiez": "caresser",
    "caressassions": "caresser",
    "caresse": "caresser",
    "caressent": "caresser",
    "caressera": "caresser",
    "caresserai": "caresser",
    "caresseraient": "caresser",
    "caresserais": "caresser",
    "caresserait": "caresser",
    "caresseras": "caresser",
    "caresserez": "caresser",
    "caresseriez": "caresser",
    "caresserions": "caresser",
    "caresserons": "caresser",
    "caresseront": "caresser",
    "caresses": "caresser",
    "caresseurs": "caresseur",
    "caresseuse": "caresseur",
    "caresseuses": "caresseur",
    "caressez": "caresser",
    "caressiez": "caresser",
    "caressions": "caresser",
    "caressons": "caresser",
    "caressâmes": "caresser",
    "caressât": "caresser",
    "caressâtes": "caresser",
    "caressèrent": "caresser",
    "caressé": "caresser",
    "caressée": "caresser",
    "caressées": "caresser",
    "caressés": "caresser",
    "carets": "caret",
    "cargaisons": "cargaison",
    "cargos": "cargo",
    "cargua": "carguer",
    "carguent": "carguer",
    "carguez": "carguer",
    "carguée": "carguer",
    "carguées": "carguer",
    "cariatides": "cariatide",
    "caribous": "caribou",
    "caribéenne": "caribéen",
    "caricatura": "caricaturer",
    "caricaturai": "caricaturer",
    "caricaturaient": "caricaturer",
    "caricaturais": "caricaturer",
    "caricaturait": "caricaturer",
    "caricaturale": "caricatural",
    "caricaturales": "caricatural",
    "caricaturant": "caricaturer",
    "caricaturas": "caricaturer",
    "caricaturasse": "caricaturer",
    "caricaturassent": "caricaturer",
    "caricaturasses": "caricaturer",
    "caricaturassiez": "caricaturer",
    "caricaturassions": "caricaturer",
    "caricaturaux": "caricatural",
    "caricature": "caricaturer",
    "caricaturent": "caricaturer",
    "caricaturera": "caricaturer",
    "caricaturerai": "caricaturer",
    "caricatureraient": "caricaturer",
    "caricaturerais": "caricaturer",
    "caricaturerait": "caricaturer",
    "caricatureras": "caricaturer",
    "caricaturerez": "caricaturer",
    "caricatureriez": "caricaturer",
    "caricaturerions": "caricaturer",
    "caricaturerons": "caricaturer",
    "caricatureront": "caricaturer",
    "caricatures": "caricaturer",
    "caricaturez": "caricaturer",
    "caricaturiez": "caricaturer",
    "caricaturions": "caricaturer",
    "caricaturistes": "caricaturiste",
    "caricaturons": "caricaturer",
    "caricaturâmes": "caricaturer",
    "caricaturât": "caricaturer",
    "caricaturâtes": "caricaturer",
    "caricaturèrent": "caricaturer",
    "caricaturé": "caricaturer",
    "caricaturée": "caricaturer",
    "caricaturées": "caricaturer",
    "caricaturés": "caricaturer",
    "caries": "carie",
    "carillonna": "carillonner",
    "carillonnai": "carillonner",
    "carillonnaient": "carillonner",
    "carillonnais": "carillonner",
    "carillonnait": "carillonner",
    "carillonnant": "carillonner",
    "carillonnas": "carillonner",
    "carillonnasse": "carillonner",
    "carillonnassent": "carillonner",
    "carillonnasses": "carillonner",
    "carillonnassiez": "carillonner",
    "carillonnassions": "carillonner",
    "carillonne": "carillonner",
    "carillonnent": "carillonner",
    "carillonnera": "carillonner",
    "carillonnerai": "carillonner",
    "carillonneraient": "carillonner",
    "carillonnerais": "carillonner",
    "carillonnerait": "carillonner",
    "carillonneras": "carillonner",
    "carillonnerez": "carillonner",
    "carillonneriez": "carillonner",
    "carillonnerions": "carillonner",
    "carillonnerons": "carillonner",
    "carillonneront": "carillonner",
    "carillonnes": "carillonner",
    "carillonneuse": "carillonneur",
    "carillonnez": "carillonner",
    "carillonniez": "carillonner",
    "carillonnions": "carillonner",
    "carillonnons": "carillonner",
    "carillonnâmes": "carillonner",
    "carillonnât": "carillonner",
    "carillonnâtes": "carillonner",
    "carillonnèrent": "carillonner",
    "carillonné": "carillonner",
    "carillonnée": "carillonner",
    "carillonnées": "carillonner",
    "carillonnés": "carillonner",
    "carillons": "carillon",
    "caris": "cari",
    "caritatifs": "caritatif",
    "caritative": "caritatif",
    "caritatives": "caritatif",
    "cariée": "carier",
    "cariées": "carier",
    "carlines": "carline",
    "carlingues": "carlingue",
    "carlins": "carlin",
    "carlistes": "carliste",
    "carma": "carmer",
    "carmagnoles": "carmagnole",
    "carmant": "carmer",
    "carmes": "carme",
    "carmina": "carminer",
    "carminatifs": "carminatif",
    "carminative": "carminatif",
    "carminatives": "carminatif",
    "carmine": "carminer",
    "carmins": "carmin",
    "carminée": "carminer",
    "carminées": "carminé",
    "carminés": "carminé",
    "carmé": "carmer",
    "carmée": "carmer",
    "carmélites": "carmélite",
    "carnages": "carnage",
    "carnassiers": "carnassier",
    "carnassière": "carnassier",
    "carnassières": "carnassier",
    "carnations": "carnation",
    "carnavals": "carnaval",
    "carneaux": "carneau",
    "carnes": "carne",
    "carnets": "carnet",
    "carniers": "carnier",
    "carnivores": "carnivore",
    "carnée": "carné",
    "carnées": "carné",
    "carnés": "carné",
    "caroline": "carolin",
    "carolines": "carolin",
    "carolingienne": "carolingien",
    "carolingiennes": "carolingien",
    "carolingiens": "carolingien",
    "carolins": "carolin",
    "caronades": "caronade",
    "caroncules": "caroncule",
    "carotides": "carotide",
    "carotidienne": "carotidien",
    "carotta": "carotter",
    "carottai": "carotter",
    "carottaient": "carotter",
    "carottais": "carotter",
    "carottait": "carotter",
    "carottant": "carotter",
    "carottas": "carotter",
    "carottasse": "carotter",
    "carottassent": "carotter",
    "carottasses": "carotter",
    "carottassiez": "carotter",
    "carottassions": "carotter",
    "carotte": "carotter",
    "carottent": "carotter",
    "carottera": "carotter",
    "carotterai": "carotter",
    "carotteraient": "carotter",
    "carotterais": "carotter",
    "carotterait": "carotter",
    "carotteras": "carotter",
    "carotterez": "carotter",
    "carotteriez": "carotter",
    "carotterions": "carotter",
    "carotterons": "carotter",
    "carotteront": "carotter",
    "carottes": "carotter",
    "carotteuse": "carotteur",
    "carottez": "carotter",
    "carottiez": "carotter",
    "carottions": "carotter",
    "carottons": "carotter",
    "carottâmes": "carotter",
    "carottât": "carotter",
    "carottâtes": "carotter",
    "carottèrent": "carotter",
    "carotté": "carotter",
    "carottée": "carotter",
    "carottées": "carotter",
    "carottés": "carotter",
    "caroubes": "caroube",
    "caroubiers": "caroubier",
    "caroublant": "caroubler",
    "caroubles": "carouble",
    "carouges": "carouge",
    "carpeaux": "carpeau",
    "carpelles": "carpelle",
    "carpes": "carpe",
    "carpettes": "carpette",
    "carpienne": "carpien",
    "carra": "carrer",
    "carrai": "carrer",
    "carraient": "carrer",
    "carrais": "carrer",
    "carrait": "carrer",
    "carrant": "carrer",
    "carrares": "carrare",
    "carras": "carrer",
    "carrasse": "carrer",
    "carrassent": "carrer",
    "carrasses": "carrer",
    "carrassiez": "carrer",
    "carrassions": "carrer",
    "carre": "carrer",
    "carreaux": "carreau",
    "carrefours": "carrefour",
    "carrela": "carreler",
    "carrelages": "carrelage",
    "carrelai": "carreler",
    "carrelaient": "carreler",
    "carrelais": "carreler",
    "carrelait": "carreler",
    "carrelant": "carreler",
    "carrelas": "carreler",
    "carrelasse": "carreler",
    "carrelassent": "carreler",
    "carrelasses": "carreler",
    "carrelassiez": "carreler",
    "carrelassions": "carreler",
    "carrelets": "carrelet",
    "carreleurs": "carreleur",
    "carrelez": "carreler",
    "carreliez": "carreler",
    "carrelions": "carreler",
    "carrelle": "carreler",
    "carrellent": "carreler",
    "carrellera": "carreler",
    "carrellerai": "carreler",
    "carrelleraient": "carreler",
    "carrellerais": "carreler",
    "carrellerait": "carreler",
    "carrelleras": "carreler",
    "carrellerez": "carreler",
    "carrelleriez": "carreler",
    "carrellerions": "carreler",
    "carrellerons": "carreler",
    "carrelleront": "carreler",
    "carrelles": "carreler",
    "carrelons": "carreler",
    "carrelâmes": "carreler",
    "carrelât": "carreler",
    "carrelâtes": "carreler",
    "carrelèrent": "carreler",
    "carrelé": "carreler",
    "carrelée": "carreler",
    "carrelées": "carreler",
    "carrelés": "carreler",
    "carrent": "carrer",
    "carrera": "carrer",
    "carrerai": "carrer",
    "carreraient": "carrer",
    "carrerais": "carrer",
    "carrerait": "carrer",
    "carreras": "carrer",
    "carrerez": "carrer",
    "carreriez": "carrer",
    "carrerions": "carrer",
    "carrerons": "carrer",
    "carreront": "carrer",
    "carres": "carrer",
    "carrez": "carrer",
    "carricks": "carrick",
    "carriers": "carrier",
    "carriez": "carrer",
    "carrioles": "carriole",
    "carrions": "carrer",
    "carrières": "carrière",
    "carriérismes": "carriérisme",
    "carriéristes": "carriériste",
    "carrons": "carrer",
    "carrossa": "carrosser",
    "carrossables": "carrossable",
    "carrossai": "carrosser",
    "carrossaient": "carrosser",
    "carrossais": "carrosser",
    "carrossait": "carrosser",
    "carrossant": "carrosser",
    "carrossas": "carrosser",
    "carrossasse": "carrosser",
    "carrossassent": "carrosser",
    "carrossasses": "carrosser",
    "carrossassiez": "carrosser",
    "carrossassions": "carrosser",
    "carrosse": "carrosser",
    "carrossent": "carrosser",
    "carrossera": "carrosser",
    "carrosserai": "carrosser",
    "carrosseraient": "carrosser",
    "carrosserais": "carrosser",
    "carrosserait": "carrosser",
    "carrosseras": "carrosser",
    "carrosserez": "carrosser",
    "carrosseries": "carrosserie",
    "carrosseriez": "carrosser",
    "carrosserions": "carrosser",
    "carrosserons": "carrosser",
    "carrosseront": "carrosser",
    "carrosses": "carrosser",
    "carrossez": "carrosser",
    "carrossiers": "carrossier",
    "carrossiez": "carrosser",
    "carrossions": "carrosser",
    "carrossons": "carrosser",
    "carrossâmes": "carrosser",
    "carrossât": "carrosser",
    "carrossâtes": "carrosser",
    "carrossèrent": "carrosser",
    "carrossé": "carrosser",
    "carrossée": "carrosser",
    "carrossées": "carrosser",
    "carrossés": "carrosser",
    "carrousels": "carrousel",
    "carrures": "carrure",
    "carrâmes": "carrer",
    "carrât": "carrer",
    "carrâtes": "carrer",
    "carrèrent": "carrer",
    "carré": "carrer",
    "carrée": "carrer",
    "carrées": "carrer",
    "carrés": "carrer",
    "cars": "car",
    "carta": "carter",
    "cartables": "cartable",
    "cartels": "cartel",
    "carters": "carter",
    "cartes": "carte",
    "cartes-lettres": "carte-lettre",
    "carthaginoise": "carthaginois",
    "cartilages": "cartilage",
    "cartilagineuse": "cartilagineux",
    "cartilagineuses": "cartilagineux",
    "cartographes": "cartographe",
    "cartographient": "cartographier",
    "cartographies": "cartographie",
    "cartographiques": "cartographique",
    "cartographié": "cartographier",
    "cartographiés": "cartographier",
    "cartomancienne": "cartomancien",
    "cartomanciennes": "cartomancien",
    "cartomancies": "cartomancie",
    "cartonna": "cartonner",
    "cartonnages": "cartonnage",
    "cartonnai": "cartonner",
    "cartonnaient": "cartonner",
    "cartonnais": "cartonner",
    "cartonnait": "cartonner",
    "cartonnant": "cartonner",
    "cartonnas": "cartonner",
    "cartonnasse": "cartonner",
    "cartonnassent": "cartonner",
    "cartonnasses": "cartonner",
    "cartonnassiez": "cartonner",
    "cartonnassions": "cartonner",
    "cartonne": "cartonner",
    "cartonnent": "cartonner",
    "cartonnera": "cartonner",
    "cartonnerai": "cartonner",
    "cartonneraient": "cartonner",
    "cartonnerais": "cartonner",
    "cartonnerait": "cartonner",
    "cartonneras": "cartonner",
    "cartonnerez": "cartonner",
    "cartonneriez": "cartonner",
    "cartonnerions": "cartonner",
    "cartonnerons": "cartonner",
    "cartonneront": "cartonner",
    "cartonnes": "cartonner",
    "cartonneuse": "cartonneux",
    "cartonneuses": "cartonneux",
    "cartonnez": "cartonner",
    "cartonniers": "cartonnier",
    "cartonniez": "cartonner",
    "cartonnions": "cartonner",
    "cartonnons": "cartonner",
    "cartonnâmes": "cartonner",
    "cartonnât": "cartonner",
    "cartonnâtes": "cartonner",
    "cartonnèrent": "cartonner",
    "cartonné": "cartonner",
    "cartonnée": "cartonner",
    "cartonnées": "cartonner",
    "cartonnés": "cartonner",
    "cartons": "carton",
    "cartons-pierres": "carton-pierre",
    "cartons-pâtes": "carton-pâte",
    "cartoons": "cartoon",
    "cartouches": "cartouche",
    "cartouchières": "cartouchière",
    "cartulaires": "cartulaire",
    "carté": "carter",
    "cartésianismes": "cartésianisme",
    "cartésienne": "cartésien",
    "cartésiennes": "cartésien",
    "cartésiens": "cartésien",
    "carvis": "carvi",
    "caryatides": "caryatide",
    "caryocinèses": "caryocinèse",
    "carys": "cary",
    "carène": "caréner",
    "carènent": "caréner",
    "carènes": "caréner",
    "caréna": "caréner",
    "carénages": "carénage",
    "carénai": "caréner",
    "carénaient": "caréner",
    "carénais": "caréner",
    "carénait": "caréner",
    "carénant": "caréner",
    "carénas": "caréner",
    "carénasse": "caréner",
    "carénassent": "caréner",
    "carénasses": "caréner",
    "carénassiez": "caréner",
    "carénassions": "caréner",
    "carénera": "caréner",
    "carénerai": "caréner",
    "caréneraient": "caréner",
    "carénerais": "caréner",
    "carénerait": "caréner",
    "caréneras": "caréner",
    "carénerez": "caréner",
    "caréneriez": "caréner",
    "carénerions": "caréner",
    "carénerons": "caréner",
    "caréneront": "caréner",
    "carénez": "caréner",
    "caréniez": "caréner",
    "carénions": "caréner",
    "carénons": "caréner",
    "carénâmes": "caréner",
    "carénât": "caréner",
    "carénâtes": "caréner",
    "carénèrent": "caréner",
    "caréné": "caréner",
    "carénée": "caréner",
    "carénées": "caréner",
    "carénés": "caréner",
    "carêmes": "carême",
    "carêmes-prenants": "carême-prenant",
    "casa": "caser",
    "casablancaise": "casablancais",
    "casablancaises": "casablancais",
    "casai": "caser",
    "casaient": "caser",
    "casais": "caser",
    "casait": "caser",
    "casaniers": "casanier",
    "casanière": "casanier",
    "casanières": "casanier",
    "casant": "caser",
    "casaques": "casaque",
    "casas": "caser",
    "casasse": "caser",
    "casassent": "caser",
    "casasses": "caser",
    "casassiez": "caser",
    "casassions": "caser",
    "casbahs": "casbah",
    "cascada": "cascader",
    "cascadai": "cascader",
    "cascadaient": "cascader",
    "cascadais": "cascader",
    "cascadait": "cascader",
    "cascadant": "cascader",
    "cascadas": "cascader",
    "cascadasse": "cascader",
    "cascadassent": "cascader",
    "cascadasses": "cascader",
    "cascadassiez": "cascader",
    "cascadassions": "cascader",
    "cascade": "cascader",
    "cascadent": "cascader",
    "cascadera": "cascader",
    "cascaderai": "cascader",
    "cascaderaient": "cascader",
    "cascaderais": "cascader",
    "cascaderait": "cascader",
    "cascaderas": "cascader",
    "cascaderez": "cascader",
    "cascaderiez": "cascader",
    "cascaderions": "cascader",
    "cascaderons": "cascader",
    "cascaderont": "cascader",
    "cascades": "cascader",
    "cascadeurs": "cascadeur",
    "cascadeuse": "cascadeur",
    "cascadez": "cascader",
    "cascadiez": "cascader",
    "cascadions": "cascader",
    "cascadons": "cascader",
    "cascadâmes": "cascader",
    "cascadât": "cascader",
    "cascadâtes": "cascader",
    "cascadèrent": "cascader",
    "cascadé": "cascader",
    "cascatelles": "cascatelle",
    "case": "caser",
    "casemates": "casemate",
    "casent": "caser",
    "casera": "caser",
    "caserai": "caser",
    "caseraient": "caser",
    "caserais": "caser",
    "caserait": "caser",
    "caseras": "caser",
    "caserez": "caser",
    "caseriez": "caser",
    "caserions": "caser",
    "casernements": "casernement",
    "casernes": "caserne",
    "caserné": "caserner",
    "casernés": "caserner",
    "caserons": "caser",
    "caseront": "caser",
    "cases": "caser",
    "casettes": "casette",
    "casez": "caser",
    "cash-flows": "cash-flow",
    "casiers": "casier",
    "casiez": "caser",
    "casinos": "casino",
    "casions": "caser",
    "casoars": "casoar",
    "casons": "caser",
    "caspiennes": "caspienne",
    "casqua": "casquer",
    "casquai": "casquer",
    "casquaient": "casquer",
    "casquais": "casquer",
    "casquait": "casquer",
    "casquant": "casquer",
    "casquas": "casquer",
    "casquasse": "casquer",
    "casquassent": "casquer",
    "casquasses": "casquer",
    "casquassiez": "casquer",
    "casquassions": "casquer",
    "casque": "casquer",
    "casquent": "casquer",
    "casquera": "casquer",
    "casquerai": "casquer",
    "casqueraient": "casquer",
    "casquerais": "casquer",
    "casquerait": "casquer",
    "casqueras": "casquer",
    "casquerez": "casquer",
    "casqueriez": "casquer",
    "casquerions": "casquer",
    "casquerons": "casquer",
    "casqueront": "casquer",
    "casques": "casquer",
    "casquettes": "casquette",
    "casquettiers": "casquettier",
    "casquettés": "casquetté",
    "casquez": "casquer",
    "casquiez": "casquer",
    "casquions": "casquer",
    "casquons": "casquer",
    "casquâmes": "casquer",
    "casquât": "casquer",
    "casquâtes": "casquer",
    "casquèrent": "casquer",
    "casqué": "casquer",
    "casquée": "casquer",
    "casquées": "casquer",
    "casqués": "casquer",
    "cassa": "casser",
    "cassables": "cassable",
    "cassages": "cassage",
    "cassai": "casser",
    "cassaient": "casser",
    "cassais": "casser",
    "cassait": "casser",
    "cassant": "casser",
    "cassante": "cassant",
    "cassantes": "cassant",
    "cassants": "cassant",
    "cassas": "casser",
    "cassasse": "casser",
    "cassassent": "casser",
    "cassasses": "casser",
    "cassassiez": "casser",
    "cassassions": "casser",
    "cassations": "cassation",
    "casse": "casser",
    "casse-bonbons": "casse-bonbon",
    "casse-croûtes": "casse-croûte",
    "casse-dalles": "casse-dalle",
    "casseaux": "casseau",
    "cassements": "cassement",
    "cassent": "casser",
    "cassera": "casser",
    "casserai": "casser",
    "casseraient": "casser",
    "casserais": "casser",
    "casserait": "casser",
    "casseras": "casser",
    "casserez": "casser",
    "casseriez": "casser",
    "casserions": "casser",
    "casseroles": "casserole",
    "casserolées": "casserolée",
    "casserons": "casser",
    "casseront": "casser",
    "casses": "casser",
    "cassetins": "cassetin",
    "cassettes": "cassette",
    "casseurs": "casseur",
    "casseuse": "casseur",
    "casseuses": "casseur",
    "cassez": "casser",
    "cassiers": "cassier",
    "cassies": "cassie",
    "cassiez": "casser",
    "cassions": "casser",
    "cassolettes": "cassolette",
    "cassonades": "cassonade",
    "cassons": "casson",
    "cassoulets": "cassoulet",
    "cassures": "cassure",
    "cassâmes": "casser",
    "cassât": "casser",
    "cassâtes": "casser",
    "cassèrent": "casser",
    "cassé": "casser",
    "cassée": "casser",
    "cassées": "casser",
    "cassés": "casser",
    "castagnait": "castagner",
    "castagnent": "castagner",
    "castagnes": "castagner",
    "castagnettes": "castagnette",
    "castagné": "castagner",
    "castes": "caste",
    "castillane": "castillan",
    "castillanes": "castillan",
    "castillans": "castillan",
    "castings": "casting",
    "castors": "castor",
    "castoréums": "castoréum",
    "castra": "castrer",
    "castrai": "castrer",
    "castraient": "castrer",
    "castrais": "castrer",
    "castrait": "castrer",
    "castrant": "castrer",
    "castras": "castrer",
    "castrasse": "castrer",
    "castrassent": "castrer",
    "castrasses": "castrer",
    "castrassiez": "castrer",
    "castrassions": "castrer",
    "castrations": "castration",
    "castratrice": "castrateur",
    "castratrices": "castrateur",
    "castrats": "castrat",
    "castre": "castrer",
    "castrent": "castrer",
    "castrera": "castrer",
    "castrerai": "castrer",
    "castreraient": "castrer",
    "castrerais": "castrer",
    "castrerait": "castrer",
    "castreras": "castrer",
    "castrerez": "castrer",
    "castreriez": "castrer",
    "castrerions": "castrer",
    "castrerons": "castrer",
    "castreront": "castrer",
    "castres": "castrer",
    "castreurs": "castreur",
    "castrez": "castrer",
    "castriez": "castrer",
    "castrions": "castrer",
    "castrismes": "castrisme",
    "castristes": "castriste",
    "castrons": "castrer",
    "castrâmes": "castrer",
    "castrât": "castrer",
    "castrâtes": "castrer",
    "castrèrent": "castrer",
    "castré": "castrer",
    "castrée": "castrer",
    "castrées": "castrer",
    "castrés": "castrer",
    "casuistes": "casuiste",
    "casuistiques": "casuistique",
    "casâmes": "caser",
    "casât": "caser",
    "casâtes": "caser",
    "casèrent": "caser",
    "casé": "caser",
    "casée": "caser",
    "casées": "caser",
    "caséeuse": "caséeux",
    "caséines": "caséine",
    "casés": "caser",
    "catachrèses": "catachrèse",
    "cataclysmale": "cataclysmal",
    "cataclysmales": "cataclysmal",
    "cataclysmaux": "cataclysmal",
    "cataclysmes": "cataclysme",
    "cataclysmiques": "cataclysmique",
    "catacombes": "catacombe",
    "catadioptres": "catadioptre",
    "catafalques": "catafalque",
    "catalane": "catalan",
    "catalanes": "catalan",
    "catalans": "catalan",
    "catalauniques": "catalaunique",
    "catalectiques": "catalectique",
    "catalepsies": "catalepsie",
    "cataleptiques": "cataleptique",
    "catalogages": "catalogage",
    "catalogua": "cataloguer",
    "cataloguai": "cataloguer",
    "cataloguaient": "cataloguer",
    "cataloguais": "cataloguer",
    "cataloguait": "cataloguer",
    "cataloguant": "cataloguer",
    "cataloguas": "cataloguer",
    "cataloguasse": "cataloguer",
    "cataloguassent": "cataloguer",
    "cataloguasses": "cataloguer",
    "cataloguassiez": "cataloguer",
    "cataloguassions": "cataloguer",
    "catalogue": "cataloguer",
    "cataloguent": "cataloguer",
    "cataloguera": "cataloguer",
    "cataloguerai": "cataloguer",
    "catalogueraient": "cataloguer",
    "cataloguerais": "cataloguer",
    "cataloguerait": "cataloguer",
    "catalogueras": "cataloguer",
    "cataloguerez": "cataloguer",
    "catalogueriez": "cataloguer",
    "cataloguerions": "cataloguer",
    "cataloguerons": "cataloguer",
    "catalogueront": "cataloguer",
    "catalogues": "cataloguer",
    "cataloguez": "cataloguer",
    "cataloguiez": "cataloguer",
    "cataloguions": "cataloguer",
    "cataloguons": "cataloguer",
    "cataloguâmes": "cataloguer",
    "cataloguât": "cataloguer",
    "cataloguâtes": "cataloguer",
    "cataloguèrent": "cataloguer",
    "catalogué": "cataloguer",
    "cataloguée": "cataloguer",
    "cataloguées": "cataloguer",
    "catalogués": "cataloguer",
    "catalpas": "catalpa",
    "catalyses": "catalyse",
    "catalyseurs": "catalyseur",
    "catalysé": "catalyser",
    "catalytiques": "catalytique",
    "cataphotes": "cataphote",
    "cataplasmes": "cataplasme",
    "catapulta": "catapulter",
    "catapultait": "catapulter",
    "catapulte": "catapulter",
    "catapultera": "catapulter",
    "catapultes": "catapulte",
    "catapulté": "catapulter",
    "catapultée": "catapulter",
    "catapultées": "catapulter",
    "catapultés": "catapulter",
    "cataractes": "cataracte",
    "catarrhes": "catarrhe",
    "catarrheuse": "catarrheux",
    "catastropha": "catastropher",
    "catastrophait": "catastropher",
    "catastrophas": "catastropher",
    "catastrophes": "catastrophe",
    "catastrophiques": "catastrophique",
    "catastrophismes": "catastrophisme",
    "catastrophé": "catastropher",
    "catastrophée": "catastropher",
    "catatoniques": "catatonique",
    "catcheurs": "catcheur",
    "catcheuse": "catcheur",
    "catcheuses": "catcheur",
    "catchs": "catch",
    "catché": "catcher",
    "catguts": "catgut",
    "cathares": "cathare",
    "cathartiques": "cathartique",
    "catherinettes": "catherinette",
    "cathodes": "cathode",
    "cathodiques": "cathodique",
    "catholicismes": "catholicisme",
    "catholiques": "catholique",
    "cathos": "catho",
    "cathèdres": "cathèdre",
    "cathédrales": "cathédrale",
    "cathéters": "cathéter",
    "cathétérismes": "cathétérisme",
    "cati": "catir",
    "catie": "catir",
    "caties": "catir",
    "catins": "catin",
    "catira": "catir",
    "catirai": "catir",
    "catiraient": "catir",
    "catirais": "catir",
    "catirait": "catir",
    "catiras": "catir",
    "catirent": "catir",
    "catirez": "catir",
    "catiriez": "catir",
    "catirions": "catir",
    "catirons": "catir",
    "catiront": "catir",
    "catis": "catir",
    "catissaient": "catir",
    "catissais": "catir",
    "catissait": "catir",
    "catissant": "catir",
    "catisse": "catir",
    "catissent": "catir",
    "catisses": "catir",
    "catissez": "catir",
    "catissiez": "catir",
    "catissions": "catir",
    "catissons": "catir",
    "catit": "catir",
    "catogans": "catogan",
    "cattleyas": "cattleya",
    "catéchisa": "catéchiser",
    "catéchisai": "catéchiser",
    "catéchisaient": "catéchiser",
    "catéchisais": "catéchiser",
    "catéchisait": "catéchiser",
    "catéchisant": "catéchiser",
    "catéchisas": "catéchiser",
    "catéchisasse": "catéchiser",
    "catéchisassent": "catéchiser",
    "catéchisasses": "catéchiser",
    "catéchisassiez": "catéchiser",
    "catéchisassions": "catéchiser",
    "catéchise": "catéchiser",
    "catéchisent": "catéchiser",
    "catéchisera": "catéchiser",
    "catéchiserai": "catéchiser",
    "catéchiseraient": "catéchiser",
    "catéchiserais": "catéchiser",
    "catéchiserait": "catéchiser",
    "catéchiseras": "catéchiser",
    "catéchiserez": "catéchiser",
    "catéchiseriez": "catéchiser",
    "catéchiserions": "catéchiser",
    "catéchiserons": "catéchiser",
    "catéchiseront": "catéchiser",
    "catéchises": "catéchiser",
    "catéchisez": "catéchiser",
    "catéchisiez": "catéchiser",
    "catéchisions": "catéchiser",
    "catéchismes": "catéchisme",
    "catéchisons": "catéchiser",
    "catéchisâmes": "catéchiser",
    "catéchisât": "catéchiser",
    "catéchisâtes": "catéchiser",
    "catéchisèrent": "catéchiser",
    "catéchisé": "catéchiser",
    "catéchisée": "catéchiser",
    "catéchisées": "catéchiser",
    "catéchisés": "catéchiser",
    "catéchumènes": "catéchumène",
    "catéchèses": "catéchèse",
    "catégorielle": "catégoriel",
    "catégorielles": "catégoriel",
    "catégoriels": "catégoriel",
    "catégories": "catégorie",
    "catégoriques": "catégorique",
    "catégorise": "catégoriser",
    "catégorisé": "catégoriser",
    "caténaires": "caténaire",
    "catîmes": "catir",
    "catît": "catir",
    "catîtes": "catir",
    "caucasienne": "caucasien",
    "caucasiennes": "caucasien",
    "caucasiens": "caucasien",
    "cauchemardais": "cauchemarder",
    "cauchemarde": "cauchemarder",
    "cauchemardes": "cauchemarder",
    "cauchemardesques": "cauchemardesque",
    "cauchemardeuse": "cauchemardeux",
    "cauchemardeuses": "cauchemardeux",
    "cauchemardé": "cauchemarder",
    "cauchemars": "cauchemar",
    "cauchoise": "cauchois",
    "cauchoises": "cauchois",
    "caudale": "caudal",
    "caudales": "caudal",
    "caudaux": "caudal",
    "cauris": "cauri",
    "causa": "causer",
    "causai": "causer",
    "causaient": "causer",
    "causais": "causer",
    "causait": "causer",
    "causale": "causal",
    "causales": "causal",
    "causalités": "causalité",
    "causals": "causal",
    "causant": "causer",
    "causante": "causant",
    "causantes": "causant",
    "causants": "causant",
    "causas": "causer",
    "causasse": "causer",
    "causassent": "causer",
    "causasses": "causer",
    "causassiez": "causer",
    "causassions": "causer",
    "causaux": "causal",
    "cause": "causer",
    "causent": "causer",
    "causera": "causer",
    "causerai": "causer",
    "causeraient": "causer",
    "causerais": "causer",
    "causerait": "causer",
    "causeras": "causer",
    "causerez": "causer",
    "causeries": "causerie",
    "causeriez": "causer",
    "causerions": "causer",
    "causerons": "causer",
    "causeront": "causer",
    "causes": "causer",
    "causettes": "causette",
    "causeurs": "causeur",
    "causeuse": "causeur",
    "causeuses": "causeur",
    "causez": "causer",
    "causiez": "causer",
    "causions": "causer",
    "causons": "causer",
    "causses": "causse",
    "caustiques": "caustique",
    "causâmes": "causer",
    "causât": "causer",
    "causâtes": "causer",
    "causèrent": "causer",
    "causé": "causer",
    "causée": "causer",
    "causées": "causer",
    "causés": "causer",
    "cauteleuse": "cauteleux",
    "cauteleuses": "cauteleux",
    "cautionna": "cautionner",
    "cautionnai": "cautionner",
    "cautionnaient": "cautionner",
    "cautionnais": "cautionner",
    "cautionnait": "cautionner",
    "cautionnant": "cautionner",
    "cautionnas": "cautionner",
    "cautionnasse": "cautionner",
    "cautionnassent": "cautionner",
    "cautionnasses": "cautionner",
    "cautionnassiez": "cautionner",
    "cautionnassions": "cautionner",
    "cautionne": "cautionner",
    "cautionnent": "cautionner",
    "cautionnera": "cautionner",
    "cautionnerai": "cautionner",
    "cautionneraient": "cautionner",
    "cautionnerais": "cautionner",
    "cautionnerait": "cautionner",
    "cautionneras": "cautionner",
    "cautionnerez": "cautionner",
    "cautionneriez": "cautionner",
    "cautionnerions": "cautionner",
    "cautionnerons": "cautionner",
    "cautionneront": "cautionner",
    "cautionnes": "cautionner",
    "cautionnez": "cautionner",
    "cautionniez": "cautionner",
    "cautionnions": "cautionner",
    "cautionnons": "cautionner",
    "cautionnâmes": "cautionner",
    "cautionnât": "cautionner",
    "cautionnâtes": "cautionner",
    "cautionnèrent": "cautionner",
    "cautionné": "cautionner",
    "cautionnée": "cautionner",
    "cautionnées": "cautionner",
    "cautionnés": "cautionner",
    "cautions": "caution",
    "cautèles": "cautèle",
    "cautères": "cautère",
    "cautérisa": "cautériser",
    "cautérisai": "cautériser",
    "cautérisaient": "cautériser",
    "cautérisais": "cautériser",
    "cautérisait": "cautériser",
    "cautérisant": "cautériser",
    "cautérisas": "cautériser",
    "cautérisasse": "cautériser",
    "cautérisassent": "cautériser",
    "cautérisasses": "cautériser",
    "cautérisassiez": "cautériser",
    "cautérisassions": "cautériser",
    "cautérise": "cautériser",
    "cautérisent": "cautériser",
    "cautérisera": "cautériser",
    "cautériserai": "cautériser",
    "cautériseraient": "cautériser",
    "cautériserais": "cautériser",
    "cautériserait": "cautériser",
    "cautériseras": "cautériser",
    "cautériserez": "cautériser",
    "cautériseriez": "cautériser",
    "cautériserions": "cautériser",
    "cautériserons": "cautériser",
    "cautériseront": "cautériser",
    "cautérises": "cautériser",
    "cautérisez": "cautériser",
    "cautérisiez": "cautériser",
    "cautérisions": "cautériser",
    "cautérisons": "cautériser",
    "cautérisâmes": "cautériser",
    "cautérisât": "cautériser",
    "cautérisâtes": "cautériser",
    "cautérisèrent": "cautériser",
    "cautérisé": "cautériser",
    "cautérisée": "cautériser",
    "cautérisées": "cautériser",
    "cautérisés": "cautériser",
    "cava": "caver",
    "cavai": "caver",
    "cavaient": "caver",
    "cavais": "caver",
    "cavait": "caver",
    "cavala": "cavaler",
    "cavalai": "cavaler",
    "cavalaient": "cavaler",
    "cavalais": "cavaler",
    "cavalait": "cavaler",
    "cavalant": "cavaler",
    "cavalas": "cavaler",
    "cavalasse": "cavaler",
    "cavalassent": "cavaler",
    "cavalasses": "cavaler",
    "cavalassiez": "cavaler",
    "cavalassions": "cavaler",
    "cavalcadaient": "cavalcader",
    "cavalcadait": "cavalcader",
    "cavalcadant": "cavalcader",
    "cavalcadent": "cavalcader",
    "cavalcades": "cavalcade",
    "cavale": "cavaler",
    "cavalent": "cavaler",
    "cavalera": "cavaler",
    "cavalerai": "cavaler",
    "cavaleraient": "cavaler",
    "cavalerais": "cavaler",
    "cavalerait": "cavaler",
    "cavaleras": "cavaler",
    "cavalerez": "cavaler",
    "cavaleries": "cavalerie",
    "cavaleriez": "cavaler",
    "cavalerions": "cavaler",
    "cavalerons": "cavaler",
    "cavaleront": "cavaler",
    "cavales": "cavaler",
    "cavaleurs": "cavaleur",
    "cavaleuse": "cavaleur",
    "cavalez": "cavaler",
    "cavaliers": "cavalier",
    "cavaliez": "cavaler",
    "cavalions": "cavaler",
    "cavalière": "cavalier",
    "cavalières": "cavalier",
    "cavalons": "cavaler",
    "cavalâmes": "cavaler",
    "cavalât": "cavaler",
    "cavalâtes": "cavaler",
    "cavalèrent": "cavaler",
    "cavalé": "cavaler",
    "cavalée": "cavaler",
    "cavalées": "cavaler",
    "cavalés": "cavaler",
    "cavant": "caver",
    "cavas": "caver",
    "cavasse": "caver",
    "cavassent": "caver",
    "cavasses": "caver",
    "cavassiez": "caver",
    "cavassions": "caver",
    "cavatines": "cavatine",
    "cave": "caver",
    "caveaux": "caveau",
    "cavecés": "cavecé",
    "cavent": "caver",
    "cavera": "caver",
    "caverai": "caver",
    "caveraient": "caver",
    "caverais": "caver",
    "caverait": "caver",
    "caveras": "caver",
    "caverez": "caver",
    "caveriez": "caver",
    "caverions": "caver",
    "cavernes": "caverne",
    "caverneuse": "caverneux",
    "caverneuses": "caverneux",
    "cavernicoles": "cavernicole",
    "caverons": "caver",
    "caveront": "caver",
    "caves": "caver",
    "cavets": "cavet",
    "cavettes": "cavette",
    "cavez": "caver",
    "caveçons": "caveçon",
    "caviarda": "caviarder",
    "caviardai": "caviarder",
    "caviardaient": "caviarder",
    "caviardais": "caviarder",
    "caviardait": "caviarder",
    "caviardant": "caviarder",
    "caviardas": "caviarder",
    "caviardasse": "caviarder",
    "caviardassent": "caviarder",
    "caviardasses": "caviarder",
    "caviardassiez": "caviarder",
    "caviardassions": "caviarder",
    "caviarde": "caviarder",
    "caviardent": "caviarder",
    "caviardera": "caviarder",
    "caviarderai": "caviarder",
    "caviarderaient": "caviarder",
    "caviarderais": "caviarder",
    "caviarderait": "caviarder",
    "caviarderas": "caviarder",
    "caviarderez": "caviarder",
    "caviarderiez": "caviarder",
    "caviarderions": "caviarder",
    "caviarderons": "caviarder",
    "caviarderont": "caviarder",
    "caviardes": "caviarder",
    "caviardez": "caviarder",
    "caviardiez": "caviarder",
    "caviardions": "caviarder",
    "caviardons": "caviarder",
    "caviardâmes": "caviarder",
    "caviardât": "caviarder",
    "caviardâtes": "caviarder",
    "caviardèrent": "caviarder",
    "caviardé": "caviarder",
    "caviardée": "caviarder",
    "caviardées": "caviarder",
    "caviardés": "caviarder",
    "caviars": "caviar",
    "cavicornes": "cavicorne",
    "caviez": "caver",
    "cavillonne": "cavillon",
    "cavillons": "cavillon",
    "cavions": "caver",
    "cavités": "cavité",
    "cavons": "caver",
    "cavâmes": "caver",
    "cavât": "caver",
    "cavâtes": "caver",
    "cavèrent": "caver",
    "cavé": "caver",
    "cavée": "caver",
    "cavées": "caver",
    "cavés": "caver",
    "cayeux": "cayeu",
    "caïds": "caïd",
    "caïeux": "caïeu",
    "caïmans": "caïman",
    "caïques": "caïque",
    "ceignaient": "ceindre",
    "ceignais": "ceindre",
    "ceignait": "ceindre",
    "ceignant": "ceindre",
    "ceigne": "ceindre",
    "ceignent": "ceindre",
    "ceignes": "ceindre",
    "ceignez": "ceindre",
    "ceigniez": "ceindre",
    "ceignions": "ceindre",
    "ceignirent": "ceindre",
    "ceignis": "ceindre",
    "ceignisse": "ceindre",
    "ceignissent": "ceindre",
    "ceignisses": "ceindre",
    "ceignissiez": "ceindre",
    "ceignissions": "ceindre",
    "ceignit": "ceindre",
    "ceignons": "ceindre",
    "ceignîmes": "ceindre",
    "ceignît": "ceindre",
    "ceignîtes": "ceindre",
    "ceindra": "ceindre",
    "ceindrai": "ceindre",
    "ceindraient": "ceindre",
    "ceindrais": "ceindre",
    "ceindrait": "ceindre",
    "ceindras": "ceindre",
    "ceindrez": "ceindre",
    "ceindriez": "ceindre",
    "ceindrions": "ceindre",
    "ceindrons": "ceindre",
    "ceindront": "ceindre",
    "ceins": "ceindre",
    "ceint": "ceindre",
    "ceinte": "ceindre",
    "ceintes": "ceindre",
    "ceints": "ceindre",
    "ceintura": "ceinturer",
    "ceinturaient": "ceinturer",
    "ceinturait": "ceinturer",
    "ceinturant": "ceinturer",
    "ceinture": "ceinturer",
    "ceinturent": "ceinturer",
    "ceintures": "ceinturer",
    "ceinturez": "ceinturer",
    "ceinturons": "ceinturon",
    "ceinturât": "ceinturer",
    "ceinturèrent": "ceinturer",
    "ceinturé": "ceinturer",
    "ceinturée": "ceinturer",
    "ceinturées": "ceinturer",
    "ceinturés": "ceinturer",
    "cela": "celer",
    "celai": "celer",
    "celaient": "celer",
    "celais": "celer",
    "celait": "celer",
    "celant": "celer",
    "celas": "celer",
    "celasse": "celer",
    "celassent": "celer",
    "celasses": "celer",
    "celassiez": "celer",
    "celassions": "celer",
    "celez": "celer",
    "celiez": "celer",
    "celions": "celer",
    "celle": "celui",
    "celle-ci": "celui-ci",
    "celle-là": "celui-là",
    "celles": "celui",
    "celles-ci": "celui-ci",
    "celles-là": "celui-là",
    "celliers": "cellier",
    "cellophanes": "cellophane",
    "cellulaires": "cellulaire",
    "cellules": "cellule",
    "cellulites": "cellulite",
    "celluloses": "cellulose",
    "celluloïds": "celluloïd",
    "celons": "celer",
    "celtes": "celte",
    "celtiques": "celtique",
    "celtisants": "celtisant",
    "celâmes": "celer",
    "celât": "celer",
    "celâtes": "celer",
    "celèrent": "celer",
    "celé": "celer",
    "celée": "celer",
    "celées": "celer",
    "celés": "celer",
    "cendra": "cendrer",
    "cendrai": "cendrer",
    "cendraient": "cendrer",
    "cendrais": "cendrer",
    "cendrait": "cendrer",
    "cendrant": "cendrer",
    "cendras": "cendrer",
    "cendrasse": "cendrer",
    "cendrassent": "cendrer",
    "cendrasses": "cendrer",
    "cendrassiez": "cendrer",
    "cendrassions": "cendrer",
    "cendre": "cendrer",
    "cendrent": "cendrer",
    "cendrera": "cendrer",
    "cendrerai": "cendrer",
    "cendreraient": "cendrer",
    "cendrerais": "cendrer",
    "cendrerait": "cendrer",
    "cendreras": "cendrer",
    "cendrerez": "cendrer",
    "cendreriez": "cendrer",
    "cendrerions": "cendrer",
    "cendrerons": "cendrer",
    "cendreront": "cendrer",
    "cendres": "cendrer",
    "cendreuse": "cendreux",
    "cendreuses": "cendreux",
    "cendrez": "cendrer",
    "cendriers": "cendrier",
    "cendriez": "cendrer",
    "cendrillons": "cendrillon",
    "cendrions": "cendrer",
    "cendrons": "cendrer",
    "cendrâmes": "cendrer",
    "cendrât": "cendrer",
    "cendrâtes": "cendrer",
    "cendrèrent": "cendrer",
    "cendré": "cendrer",
    "cendrée": "cendrer",
    "cendrées": "cendrer",
    "cendrés": "cendrer",
    "censeurs": "censeur",
    "censoriale": "censorial",
    "censoriales": "censorial",
    "censoriaux": "censorial",
    "censura": "censurer",
    "censurai": "censurer",
    "censuraient": "censurer",
    "censurais": "censurer",
    "censurait": "censurer",
    "censurant": "censurer",
    "censuras": "censurer",
    "censurasse": "censurer",
    "censurassent": "censurer",
    "censurasses": "censurer",
    "censurassiez": "censurer",
    "censurassions": "censurer",
    "censure": "censurer",
    "censurent": "censurer",
    "censurera": "censurer",
    "censurerai": "censurer",
    "censureraient": "censurer",
    "censurerais": "censurer",
    "censurerait": "censurer",
    "censureras": "censurer",
    "censurerez": "censurer",
    "censureriez": "censurer",
    "censurerions": "censurer",
    "censurerons": "censurer",
    "censureront": "censurer",
    "censures": "censurer",
    "censurez": "censurer",
    "censuriez": "censurer",
    "censurions": "censurer",
    "censurons": "censurer",
    "censurâmes": "censurer",
    "censurât": "censurer",
    "censurâtes": "censurer",
    "censurèrent": "censurer",
    "censuré": "censurer",
    "censurée": "censurer",
    "censurées": "censurer",
    "censurés": "censurer",
    "censée": "censé",
    "censées": "censé",
    "censés": "censé",
    "cent-gardes": "cent-garde",
    "cent-unièmes": "cent-unième",
    "centaines": "centaine",
    "centaures": "centaure",
    "centaurées": "centaurée",
    "centavos": "centavo",
    "centenaires": "centenaire",
    "centennale": "centennal",
    "centennales": "centennal",
    "centennaux": "centennal",
    "centigrades": "centigrade",
    "centigrammes": "centigramme",
    "centilitres": "centilitre",
    "centimes": "centime",
    "centimètres": "centimètre",
    "centièmes": "centième",
    "centons": "centon",
    "centra": "centrer",
    "centrafricaine": "centrafricain",
    "centrafricaines": "centrafricain",
    "centrafricains": "centrafricain",
    "centrai": "centrer",
    "centraient": "centrer",
    "centrais": "centrer",
    "centrait": "centrer",
    "centrale": "central",
    "centrales": "centrale",
    "centralienne": "centralien",
    "centraliennes": "centralien",
    "centraliens": "centralien",
    "centralisa": "centraliser",
    "centralisai": "centraliser",
    "centralisaient": "centraliser",
    "centralisais": "centraliser",
    "centralisait": "centraliser",
    "centralisant": "centraliser",
    "centralisas": "centraliser",
    "centralisasse": "centraliser",
    "centralisassent": "centraliser",
    "centralisasses": "centraliser",
    "centralisassiez": "centraliser",
    "centralisassions": "centraliser",
    "centralisateurs": "centralisateur",
    "centralisations": "centralisation",
    "centralisatrice": "centralisateur",
    "centralisatrices": "centralisateur",
    "centralise": "centraliser",
    "centralisent": "centraliser",
    "centralisera": "centraliser",
    "centraliserai": "centraliser",
    "centraliseraient": "centraliser",
    "centraliserais": "centraliser",
    "centraliserait": "centraliser",
    "centraliseras": "centraliser",
    "centraliserez": "centraliser",
    "centraliseriez": "centraliser",
    "centraliserions": "centraliser",
    "centraliserons": "centraliser",
    "centraliseront": "centraliser",
    "centralises": "centraliser",
    "centralisez": "centraliser",
    "centralisiez": "centraliser",
    "centralisions": "centraliser",
    "centralismes": "centralisme",
    "centralisons": "centraliser",
    "centralistes": "centraliste",
    "centralisâmes": "centraliser",
    "centralisât": "centraliser",
    "centralisâtes": "centraliser",
    "centralisèrent": "centraliser",
    "centralisé": "centraliser",
    "centralisée": "centraliser",
    "centralisées": "centraliser",
    "centralisés": "centraliser",
    "centraméricaine": "centraméricain",
    "centraméricaines": "centraméricain",
    "centraméricains": "centraméricain",
    "centrant": "centrer",
    "centras": "centrer",
    "centrasse": "centrer",
    "centrassent": "centrer",
    "centrasses": "centrer",
    "centrassiez": "centrer",
    "centrassions": "centrer",
    "centraux": "central",
    "centre": "centrer",
    "centre-villes": "centre-ville",
    "centrent": "centrer",
    "centrera": "centrer",
    "centrerai": "centrer",
    "centreraient": "centrer",
    "centrerais": "centrer",
    "centrerait": "centrer",
    "centreras": "centrer",
    "centrerez": "centrer",
    "centreriez": "centrer",
    "centrerions": "centrer",
    "centrerons": "centrer",
    "centreront": "centrer",
    "centres": "centrer",
    "centres-gauches": "centre-gauche",
    "centrez": "centrer",
    "centriez": "centrer",
    "centrifugations": "centrifugation",
    "centrifuge": "centrifuger",
    "centrifugea": "centrifuger",
    "centrifugeai": "centrifuger",
    "centrifugeaient": "centrifuger",
    "centrifugeais": "centrifuger",
    "centrifugeait": "centrifuger",
    "centrifugeant": "centrifuger",
    "centrifugeas": "centrifuger",
    "centrifugeasse": "centrifuger",
    "centrifugeassent": "centrifuger",
    "centrifugeasses": "centrifuger",
    "centrifugeassiez": "centrifuger",
    "centrifugeassions": "centrifuger",
    "centrifugent": "centrifuger",
    "centrifugeons": "centrifuger",
    "centrifugera": "centrifuger",
    "centrifugerai": "centrifuger",
    "centrifugeraient": "centrifuger",
    "centrifugerais": "centrifuger",
    "centrifugerait": "centrifuger",
    "centrifugeras": "centrifuger",
    "centrifugerez": "centrifuger",
    "centrifugeriez": "centrifuger",
    "centrifugerions": "centrifuger",
    "centrifugerons": "centrifuger",
    "centrifugeront": "centrifuger",
    "centrifuges": "centrifuger",
    "centrifugeuse": "centrifugeur",
    "centrifugeuses": "centrifugeur",
    "centrifugez": "centrifuger",
    "centrifugeâmes": "centrifuger",
    "centrifugeât": "centrifuger",
    "centrifugeâtes": "centrifuger",
    "centrifugiez": "centrifuger",
    "centrifugions": "centrifuger",
    "centrifugèrent": "centrifuger",
    "centrifugé": "centrifuger",
    "centrifugée": "centrifuger",
    "centrifugées": "centrifuger",
    "centrifugés": "centrifuger",
    "centrions": "centrer",
    "centripètes": "centripète",
    "centrismes": "centrisme",
    "centristes": "centriste",
    "centroaméricaine": "centroaméricain",
    "centroaméricaines": "centroaméricain",
    "centroaméricains": "centroaméricain",
    "centrons": "centrer",
    "centrâmes": "centrer",
    "centrât": "centrer",
    "centrâtes": "centrer",
    "centrèrent": "centrer",
    "centré": "centrer",
    "centrée": "centrer",
    "centrées": "centrer",
    "centrés": "centrer",
    "cents": "cent",
    "centuples": "centuple",
    "centuplé": "centupler",
    "centuplée": "centupler",
    "centuries": "centurie",
    "centurions": "centurion",
    "centésimale": "centésimal",
    "centésimales": "centésimal",
    "centésimaux": "centésimal",
    "ceps": "cep",
    "cerbères": "cerbère",
    "cerceaux": "cerceau",
    "cercla": "cercler",
    "cerclai": "cercler",
    "cerclaient": "cercler",
    "cerclais": "cercler",
    "cerclait": "cercler",
    "cerclant": "cercler",
    "cerclas": "cercler",
    "cerclasse": "cercler",
    "cerclassent": "cercler",
    "cerclasses": "cercler",
    "cerclassiez": "cercler",
    "cerclassions": "cercler",
    "cercle": "cercler",
    "cerclent": "cercler",
    "cerclera": "cercler",
    "cerclerai": "cercler",
    "cercleraient": "cercler",
    "cerclerais": "cercler",
    "cerclerait": "cercler",
    "cercleras": "cercler",
    "cerclerez": "cercler",
    "cercleriez": "cercler",
    "cerclerions": "cercler",
    "cerclerons": "cercler",
    "cercleront": "cercler",
    "cercles": "cercler",
    "cerclez": "cercler",
    "cercliez": "cercler",
    "cerclions": "cercler",
    "cerclons": "cercler",
    "cerclâmes": "cercler",
    "cerclât": "cercler",
    "cerclâtes": "cercler",
    "cerclèrent": "cercler",
    "cerclé": "cercler",
    "cerclée": "cercler",
    "cerclées": "cercler",
    "cerclés": "cercler",
    "cercopithèques": "cercopithèque",
    "cercueils": "cercueil",
    "cerfeuils": "cerfeuil",
    "cerfs": "cerf",
    "cerfs-volants": "cerf-volant",
    "cerises": "cerise",
    "cerisiers": "cerisier",
    "cerna": "cerner",
    "cernai": "cerner",
    "cernaient": "cerner",
    "cernais": "cerner",
    "cernait": "cerner",
    "cernant": "cerner",
    "cernas": "cerner",
    "cernasse": "cerner",
    "cernassent": "cerner",
    "cernasses": "cerner",
    "cernassiez": "cerner",
    "cernassions": "cerner",
    "cerne": "cerner",
    "cerneaux": "cerneau",
    "cernent": "cerner",
    "cernera": "cerner",
    "cernerai": "cerner",
    "cerneraient": "cerner",
    "cernerais": "cerner",
    "cernerait": "cerner",
    "cerneras": "cerner",
    "cernerez": "cerner",
    "cerneriez": "cerner",
    "cernerions": "cerner",
    "cernerons": "cerner",
    "cerneront": "cerner",
    "cernes": "cerner",
    "cernez": "cerner",
    "cerniez": "cerner",
    "cernions": "cerner",
    "cernons": "cerner",
    "cernâmes": "cerner",
    "cernât": "cerner",
    "cernâtes": "cerner",
    "cernèrent": "cerner",
    "cerné": "cerner",
    "cernée": "cerner",
    "cernées": "cerner",
    "cernés": "cerner",
    "certaine": "certain",
    "certaines": "certains",
    "certains": "certain",
    "certifia": "certifier",
    "certifiai": "certifier",
    "certifiaient": "certifier",
    "certifiais": "certifier",
    "certifiait": "certifier",
    "certifiant": "certifier",
    "certifias": "certifier",
    "certifiasse": "certifier",
    "certifiassent": "certifier",
    "certifiasses": "certifier",
    "certifiassiez": "certifier",
    "certifiassions": "certifier",
    "certifications": "certification",
    "certificats": "certificat",
    "certifie": "certifier",
    "certifient": "certifier",
    "certifiera": "certifier",
    "certifierai": "certifier",
    "certifieraient": "certifier",
    "certifierais": "certifier",
    "certifierait": "certifier",
    "certifieras": "certifier",
    "certifierez": "certifier",
    "certifieriez": "certifier",
    "certifierions": "certifier",
    "certifierons": "certifier",
    "certifieront": "certifier",
    "certifies": "certifier",
    "certifiez": "certifier",
    "certifiiez": "certifier",
    "certifiions": "certifier",
    "certifions": "certifier",
    "certifiâmes": "certifier",
    "certifiât": "certifier",
    "certifiâtes": "certifier",
    "certifièrent": "certifier",
    "certifié": "certifier",
    "certifiée": "certifier",
    "certifiées": "certifier",
    "certifiés": "certifier",
    "certifs": "certif",
    "certitudes": "certitude",
    "cerveaux": "cerveau",
    "cervelets": "cervelet",
    "cervelles": "cervelle",
    "cervicale": "cervical",
    "cervicales": "cervical",
    "cervicaux": "cervical",
    "cervidés": "cervidé",
    "cervoises": "cervoise",
    "ces": "ce",
    "cessa": "cesser",
    "cessai": "cesser",
    "cessaient": "cesser",
    "cessais": "cesser",
    "cessait": "cesser",
    "cessant": "cesser",
    "cessante": "cessant",
    "cessantes": "cessant",
    "cessants": "cessant",
    "cessas": "cesser",
    "cessasse": "cesser",
    "cessassent": "cesser",
    "cessasses": "cesser",
    "cessassiez": "cesser",
    "cessassions": "cesser",
    "cessations": "cessation",
    "cesse": "cesser",
    "cessent": "cesser",
    "cessera": "cesser",
    "cesserai": "cesser",
    "cesseraient": "cesser",
    "cesserais": "cesser",
    "cesserait": "cesser",
    "cesseras": "cesser",
    "cesserez": "cesser",
    "cesseriez": "cesser",
    "cesserions": "cesser",
    "cesserons": "cesser",
    "cesseront": "cesser",
    "cesses": "cesser",
    "cessez": "cesser",
    "cessibles": "cessible",
    "cessiez": "cesser",
    "cessions": "cession",
    "cessons": "cesser",
    "cessâmes": "cesser",
    "cessât": "cesser",
    "cessâtes": "cesser",
    "cessèrent": "cesser",
    "cessé": "cesser",
    "cessée": "cesser",
    "cessées": "cesser",
    "cessés": "cesser",
    "cestes": "ceste",
    "cet": "ce",
    "cette": "ce",
    "ceux": "celui",
    "ceux-ci": "celui-ci",
    "ceux-là": "celui-là",
    "ch'timis": "ch'timi",
    "chabichous": "chabichou",
    "chaboisseaux": "chaboisseau",
    "chabots": "chabot",
    "chacals": "chacal",
    "chacune": "chacun",
    "chafauds": "chafaud",
    "chafouine": "chafouin",
    "chafouines": "chafouin",
    "chafouins": "chafouin",
    "chagattes": "chagatte",
    "chagrina": "chagriner",
    "chagrinaient": "chagriner",
    "chagrinait": "chagriner",
    "chagrine": "chagriner",
    "chagrinent": "chagriner",
    "chagrinerait": "chagriner",
    "chagrines": "chagriner",
    "chagrins": "chagrin",
    "chagriné": "chagriner",
    "chagrinée": "chagriner",
    "chagrinés": "chagriner",
    "chahs": "chah",
    "chahuta": "chahuter",
    "chahutai": "chahuter",
    "chahutaient": "chahuter",
    "chahutais": "chahuter",
    "chahutait": "chahuter",
    "chahutant": "chahuter",
    "chahutas": "chahuter",
    "chahutasse": "chahuter",
    "chahutassent": "chahuter",
    "chahutasses": "chahuter",
    "chahutassiez": "chahuter",
    "chahutassions": "chahuter",
    "chahute": "chahuter",
    "chahutent": "chahuter",
    "chahutera": "chahuter",
    "chahuterai": "chahuter",
    "chahuteraient": "chahuter",
    "chahuterais": "chahuter",
    "chahuterait": "chahuter",
    "chahuteras": "chahuter",
    "chahuterez": "chahuter",
    "chahuteriez": "chahuter",
    "chahuterions": "chahuter",
    "chahuterons": "chahuter",
    "chahuteront": "chahuter",
    "chahutes": "chahuter",
    "chahuteurs": "chahuteur",
    "chahuteuse": "chahuteur",
    "chahutez": "chahuter",
    "chahutiez": "chahuter",
    "chahutions": "chahuter",
    "chahutons": "chahuter",
    "chahuts": "chahut",
    "chahutâmes": "chahuter",
    "chahutât": "chahuter",
    "chahutâtes": "chahuter",
    "chahutèrent": "chahuter",
    "chahuté": "chahuter",
    "chahutée": "chahuter",
    "chahutées": "chahuter",
    "chahutés": "chahuter",
    "chaires": "chaire",
    "chairs": "chair",
    "chais": "chai",
    "chaises": "chaise",
    "chaisière": "chaisier",
    "chaisières": "chaisier",
    "chalande": "chaland",
    "chalandes": "chaland",
    "chalands": "chaland",
    "chalazions": "chalazion",
    "chalcographies": "chalcographie",
    "chaldaïques": "chaldaïque",
    "chaldéens": "chaldéen",
    "chalets": "chalet",
    "chaleureuse": "chaleureux",
    "chaleureuses": "chaleureux",
    "chaleurs": "chaleur",
    "challengers": "challenger",
    "challenges": "challenge",
    "challengeurs": "challengeur",
    "chalonnaises": "chalonnais",
    "chalons": "chalon",
    "chaloupait": "chalouper",
    "chaloupant": "chalouper",
    "chaloupes": "chaloupe",
    "chaloupé": "chalouper",
    "chaloupée": "chalouper",
    "chaloupées": "chalouper",
    "chaloupés": "chalouper",
    "chalumeaux": "chalumeau",
    "chalutiers": "chalutier",
    "chaluts": "chalut",
    "chamades": "chamade",
    "chamailla": "chamailler",
    "chamaillai": "chamailler",
    "chamaillaient": "chamailler",
    "chamaillais": "chamailler",
    "chamaillait": "chamailler",
    "chamaillant": "chamailler",
    "chamaillas": "chamailler",
    "chamaillasse": "chamailler",
    "chamaillassent": "chamailler",
    "chamaillasses": "chamailler",
    "chamaillassiez": "chamailler",
    "chamaillassions": "chamailler",
    "chamaille": "chamailler",
    "chamaillent": "chamailler",
    "chamaillera": "chamailler",
    "chamaillerai": "chamailler",
    "chamailleraient": "chamailler",
    "chamaillerais": "chamailler",
    "chamaillerait": "chamailler",
    "chamailleras": "chamailler",
    "chamaillerez": "chamailler",
    "chamailleries": "chamaillerie",
    "chamailleriez": "chamailler",
    "chamaillerions": "chamailler",
    "chamaillerons": "chamailler",
    "chamailleront": "chamailler",
    "chamailles": "chamailler",
    "chamailleurs": "chamailleur",
    "chamailleuse": "chamailleur",
    "chamaillez": "chamailler",
    "chamailliez": "chamailler",
    "chamaillions": "chamailler",
    "chamaillons": "chamailler",
    "chamaillâmes": "chamailler",
    "chamaillât": "chamailler",
    "chamaillâtes": "chamailler",
    "chamaillèrent": "chamailler",
    "chamaillé": "chamailler",
    "chamaillée": "chamailler",
    "chamaillées": "chamailler",
    "chamaillés": "chamailler",
    "chamanes": "chamane",
    "chamans": "chaman",
    "chamarra": "chamarrer",
    "chamarrai": "chamarrer",
    "chamarraient": "chamarrer",
    "chamarrais": "chamarrer",
    "chamarrait": "chamarrer",
    "chamarrant": "chamarrer",
    "chamarras": "chamarrer",
    "chamarrasse": "chamarrer",
    "chamarrassent": "chamarrer",
    "chamarrasses": "chamarrer",
    "chamarrassiez": "chamarrer",
    "chamarrassions": "chamarrer",
    "chamarre": "chamarrer",
    "chamarrent": "chamarrer",
    "chamarrera": "chamarrer",
    "chamarrerai": "chamarrer",
    "chamarreraient": "chamarrer",
    "chamarrerais": "chamarrer",
    "chamarrerait": "chamarrer",
    "chamarreras": "chamarrer",
    "chamarrerez": "chamarrer",
    "chamarreriez": "chamarrer",
    "chamarrerions": "chamarrer",
    "chamarrerons": "chamarrer",
    "chamarreront": "chamarrer",
    "chamarres": "chamarrer",
    "chamarrez": "chamarrer",
    "chamarriez": "chamarrer",
    "chamarrions": "chamarrer",
    "chamarrons": "chamarrer",
    "chamarrures": "chamarrure",
    "chamarrâmes": "chamarrer",
    "chamarrât": "chamarrer",
    "chamarrâtes": "chamarrer",
    "chamarrèrent": "chamarrer",
    "chamarré": "chamarrer",
    "chamarrée": "chamarrer",
    "chamarrées": "chamarrer",
    "chamarrés": "chamarrer",
    "chambarda": "chambarder",
    "chambardait": "chambarder",
    "chambardements": "chambardement",
    "chambards": "chambard",
    "chambardé": "chambarder",
    "chambardée": "chambarder",
    "chambellans": "chambellan",
    "chambertins": "chambertin",
    "chamboulaient": "chambouler",
    "chamboulait": "chambouler",
    "chamboulant": "chambouler",
    "chamboule": "chambouler",
    "chamboulements": "chamboulement",
    "chamboulent": "chambouler",
    "chambouleras": "chambouler",
    "chamboulez": "chambouler",
    "chamboulât": "chambouler",
    "chamboulé": "chambouler",
    "chamboulée": "chambouler",
    "chamboulées": "chambouler",
    "chamboulés": "chambouler",
    "chambra": "chambrer",
    "chambrais": "chambrer",
    "chambrait": "chambrer",
    "chambranles": "chambranle",
    "chambrant": "chambrer",
    "chambre": "chambrer",
    "chambrent": "chambrer",
    "chambres": "chambrer",
    "chambrez": "chambrer",
    "chambrières": "chambrière",
    "chambré": "chambrer",
    "chambrée": "chambrer",
    "chambrées": "chambrée",
    "chameaux": "chameau",
    "chameliers": "chamelier",
    "chamelle": "chameau",
    "chamelles": "chameau",
    "chamoisa": "chamoiser",
    "chamoisai": "chamoiser",
    "chamoisaient": "chamoiser",
    "chamoisais": "chamoiser",
    "chamoisait": "chamoiser",
    "chamoisant": "chamoiser",
    "chamoisas": "chamoiser",
    "chamoisasse": "chamoiser",
    "chamoisassent": "chamoiser",
    "chamoisasses": "chamoiser",
    "chamoisassiez": "chamoiser",
    "chamoisassions": "chamoiser",
    "chamoise": "chamoiser",
    "chamoisent": "chamoiser",
    "chamoisera": "chamoiser",
    "chamoiserai": "chamoiser",
    "chamoiseraient": "chamoiser",
    "chamoiserais": "chamoiser",
    "chamoiserait": "chamoiser",
    "chamoiseras": "chamoiser",
    "chamoiserez": "chamoiser",
    "chamoiseriez": "chamoiser",
    "chamoiserions": "chamoiser",
    "chamoiserons": "chamoiser",
    "chamoiseront": "chamoiser",
    "chamoises": "chamoiser",
    "chamoisez": "chamoiser",
    "chamoisiez": "chamoiser",
    "chamoisions": "chamoiser",
    "chamoisons": "chamoiser",
    "chamoisâmes": "chamoiser",
    "chamoisât": "chamoiser",
    "chamoisâtes": "chamoiser",
    "chamoisèrent": "chamoiser",
    "chamoisé": "chamoiser",
    "chamoisée": "chamoiser",
    "chamoisées": "chamoiser",
    "chamoisés": "chamoiser",
    "champ'": "champ",
    "champagnes": "champagne",
    "champagnisés": "champagniser",
    "champarts": "champart",
    "champenoise": "champenois",
    "champenoises": "champenois",
    "champignonnaient": "champignonner",
    "champignonnait": "champignonner",
    "champignonne": "champignonner",
    "champignonnent": "champignonner",
    "champignonnistes": "champignonniste",
    "champignonnières": "champignonnière",
    "champignons": "champignon",
    "championnats": "championnat",
    "championne": "champion",
    "championnes": "champion",
    "champions": "champion",
    "champis": "champi",
    "champleva": "champlever",
    "champlevai": "champlever",
    "champlevaient": "champlever",
    "champlevais": "champlever",
    "champlevait": "champlever",
    "champlevant": "champlever",
    "champlevas": "champlever",
    "champlevasse": "champlever",
    "champlevassent": "champlever",
    "champlevasses": "champlever",
    "champlevassiez": "champlever",
    "champlevassions": "champlever",
    "champlevez": "champlever",
    "champleviez": "champlever",
    "champlevions": "champlever",
    "champlevons": "champlever",
    "champlevâmes": "champlever",
    "champlevât": "champlever",
    "champlevâtes": "champlever",
    "champlevèrent": "champlever",
    "champlevé": "champlever",
    "champlevée": "champlever",
    "champlevées": "champlever",
    "champlevés": "champlever",
    "champlève": "champlever",
    "champlèvent": "champlever",
    "champlèvera": "champlever",
    "champlèverai": "champlever",
    "champlèveraient": "champlever",
    "champlèverais": "champlever",
    "champlèverait": "champlever",
    "champlèveras": "champlever",
    "champlèverez": "champlever",
    "champlèveriez": "champlever",
    "champlèverions": "champlever",
    "champlèverons": "champlever",
    "champlèveront": "champlever",
    "champlèves": "champlever",
    "champs": "champ",
    "champêtres": "champêtre",
    "chamsins": "chamsin",
    "chancela": "chanceler",
    "chancelai": "chanceler",
    "chancelaient": "chanceler",
    "chancelais": "chanceler",
    "chancelait": "chanceler",
    "chancelant": "chanceler",
    "chancelante": "chancelant",
    "chancelantes": "chancelant",
    "chancelants": "chancelant",
    "chancelas": "chanceler",
    "chancelasse": "chanceler",
    "chancelassent": "chanceler",
    "chancelasses": "chanceler",
    "chancelassiez": "chanceler",
    "chancelassions": "chanceler",
    "chancelez": "chanceler",
    "chanceliers": "chancelier",
    "chanceliez": "chanceler",
    "chancelions": "chanceler",
    "chancelières": "chancelier",
    "chancelle": "chanceler",
    "chancellent": "chanceler",
    "chancellera": "chanceler",
    "chancellerai": "chanceler",
    "chancelleraient": "chanceler",
    "chancellerais": "chanceler",
    "chancellerait": "chanceler",
    "chancelleras": "chanceler",
    "chancellerez": "chanceler",
    "chancelleries": "chancellerie",
    "chancelleriez": "chanceler",
    "chancellerions": "chanceler",
    "chancellerons": "chanceler",
    "chancelleront": "chanceler",
    "chancelles": "chanceler",
    "chancelons": "chanceler",
    "chancelâmes": "chanceler",
    "chancelât": "chanceler",
    "chancelâtes": "chanceler",
    "chancelèrent": "chanceler",
    "chancelé": "chanceler",
    "chances": "chance",
    "chanceuse": "chanceux",
    "chanceuses": "chanceux",
    "chanci": "chancir",
    "chancie": "chancir",
    "chancies": "chancir",
    "chancira": "chancir",
    "chancirai": "chancir",
    "chanciraient": "chancir",
    "chancirais": "chancir",
    "chancirait": "chancir",
    "chanciras": "chancir",
    "chancirent": "chancir",
    "chancirez": "chancir",
    "chanciriez": "chancir",
    "chancirions": "chancir",
    "chancirons": "chancir",
    "chanciront": "chancir",
    "chancis": "chancir",
    "chancissaient": "chancir",
    "chancissais": "chancir",
    "chancissait": "chancir",
    "chancissant": "chancir",
    "chancisse": "chancir",
    "chancissent": "chancir",
    "chancisses": "chancir",
    "chancissez": "chancir",
    "chancissiez": "chancir",
    "chancissions": "chancir",
    "chancissons": "chancir",
    "chancit": "chancir",
    "chancres": "chancre",
    "chancîmes": "chancir",
    "chancît": "chancir",
    "chancîtes": "chancir",
    "chandails": "chandail",
    "chandeleurs": "chandeleur",
    "chandeliers": "chandelier",
    "chandelles": "chandelle",
    "chanfreinée": "chanfreiner",
    "change": "changer",
    "changea": "changer",
    "changeai": "changer",
    "changeaient": "changer",
    "changeais": "changer",
    "changeait": "changer",
    "changeant": "changer",
    "changeante": "changeant",
    "changeantes": "changeant",
    "changeants": "changeant",
    "changeas": "changer",
    "changeasse": "changer",
    "changeassent": "changer",
    "changeasses": "changer",
    "changeassiez": "changer",
    "changeassions": "changer",
    "changements": "changement",
    "changent": "changer",
    "changeons": "changer",
    "changera": "changer",
    "changerai": "changer",
    "changeraient": "changer",
    "changerais": "changer",
    "changerait": "changer",
    "changeras": "changer",
    "changerez": "changer",
    "changeriez": "changer",
    "changerions": "changer",
    "changerons": "changer",
    "changeront": "changer",
    "changes": "changer",
    "changeurs": "changeur",
    "changeuse": "changeur",
    "changez": "changer",
    "changeâmes": "changer",
    "changeât": "changer",
    "changeâtes": "changer",
    "changiez": "changer",
    "changions": "changer",
    "changèrent": "changer",
    "changé": "changer",
    "changée": "changer",
    "changées": "changer",
    "changés": "changer",
    "chanoines": "chanoine",
    "chanoinesse": "chanoine",
    "chanoinesses": "chanoinesse",
    "chansonnettes": "chansonnette",
    "chansonniers": "chansonnier",
    "chansonnière": "chansonnier",
    "chansonnières": "chansonnier",
    "chansons": "chanson",
    "chanstiquait": "chanstiquer",
    "chanstique": "chanstiquer",
    "chanstiquent": "chanstiquer",
    "chanstiquèrent": "chanstiquer",
    "chanstiqué": "chanstiquer",
    "chanstiquée": "chanstiquer",
    "chanta": "chanter",
    "chantages": "chantage",
    "chantai": "chanter",
    "chantaient": "chanter",
    "chantais": "chanter",
    "chantait": "chanter",
    "chantant": "chanter",
    "chantante": "chantant",
    "chantantes": "chantant",
    "chantants": "chantant",
    "chantas": "chanter",
    "chantasse": "chanter",
    "chantassent": "chanter",
    "chantasses": "chanter",
    "chantassiez": "chanter",
    "chantassions": "chanter",
    "chante": "chanter",
    "chanteaux": "chanteau",
    "chantent": "chanter",
    "chantepleures": "chantepleure",
    "chantera": "chanter",
    "chanterai": "chanter",
    "chanteraient": "chanter",
    "chanterais": "chanter",
    "chanterait": "chanter",
    "chanteras": "chanter",
    "chanterelles": "chanterelle",
    "chanterez": "chanter",
    "chanteriez": "chanter",
    "chanterions": "chanter",
    "chanterons": "chanter",
    "chanteront": "chanter",
    "chantes": "chanter",
    "chanteurs": "chanteur",
    "chanteuse": "chanteur",
    "chanteuses": "chanteur",
    "chantez": "chanter",
    "chantiers": "chantier",
    "chantiez": "chanter",
    "chantions": "chanter",
    "chantonna": "chantonner",
    "chantonnai": "chantonner",
    "chantonnaient": "chantonner",
    "chantonnais": "chantonner",
    "chantonnait": "chantonner",
    "chantonnant": "chantonner",
    "chantonnante": "chantonnant",
    "chantonnas": "chantonner",
    "chantonnasse": "chantonner",
    "chantonnassent": "chantonner",
    "chantonnasses": "chantonner",
    "chantonnassiez": "chantonner",
    "chantonnassions": "chantonner",
    "chantonne": "chantonner",
    "chantonnent": "chantonner",
    "chantonnera": "chantonner",
    "chantonnerai": "chantonner",
    "chantonneraient": "chantonner",
    "chantonnerais": "chantonner",
    "chantonnerait": "chantonner",
    "chantonneras": "chantonner",
    "chantonnerez": "chantonner",
    "chantonneriez": "chantonner",
    "chantonnerions": "chantonner",
    "chantonnerons": "chantonner",
    "chantonneront": "chantonner",
    "chantonnes": "chantonner",
    "chantonnez": "chantonner",
    "chantonniez": "chantonner",
    "chantonnions": "chantonner",
    "chantonnons": "chantonner",
    "chantonnâmes": "chantonner",
    "chantonnât": "chantonner",
    "chantonnâtes": "chantonner",
    "chantonnèrent": "chantonner",
    "chantonné": "chantonner",
    "chantonnée": "chantonner",
    "chantonnées": "chantonner",
    "chantonnés": "chantonner",
    "chantons": "chanter",
    "chantoungs": "chantoung",
    "chantourné": "chantourner",
    "chantournées": "chantourner",
    "chantournés": "chantourner",
    "chantres": "chantre",
    "chants": "chant",
    "chantâmes": "chanter",
    "chantât": "chanter",
    "chantâtes": "chanter",
    "chantèrent": "chanter",
    "chanté": "chanter",
    "chantée": "chanter",
    "chantées": "chanter",
    "chantés": "chanter",
    "chanvres": "chanvre",
    "chançarde": "chançard",
    "chaotiques": "chaotique",
    "chaouchs": "chaouch",
    "chaparda": "chaparder",
    "chapardages": "chapardage",
    "chapardai": "chaparder",
    "chapardaient": "chaparder",
    "chapardais": "chaparder",
    "chapardait": "chaparder",
    "chapardant": "chaparder",
    "chapardas": "chaparder",
    "chapardasse": "chaparder",
    "chapardassent": "chaparder",
    "chapardasses": "chaparder",
    "chapardassiez": "chaparder",
    "chapardassions": "chaparder",
    "chaparde": "chaparder",
    "chapardent": "chaparder",
    "chapardera": "chaparder",
    "chaparderai": "chaparder",
    "chaparderaient": "chaparder",
    "chaparderais": "chaparder",
    "chaparderait": "chaparder",
    "chaparderas": "chaparder",
    "chaparderez": "chaparder",
    "chaparderiez": "chaparder",
    "chaparderions": "chaparder",
    "chaparderons": "chaparder",
    "chaparderont": "chaparder",
    "chapardes": "chaparder",
    "chapardeurs": "chapardeur",
    "chapardeuse": "chapardeur",
    "chapardez": "chaparder",
    "chapardiez": "chaparder",
    "chapardions": "chaparder",
    "chapardons": "chaparder",
    "chapardâmes": "chaparder",
    "chapardât": "chaparder",
    "chapardâtes": "chaparder",
    "chapardèrent": "chaparder",
    "chapardé": "chaparder",
    "chapardée": "chaparder",
    "chapardées": "chaparder",
    "chapardés": "chaparder",
    "chaparrals": "chaparral",
    "chapeautait": "chapeauter",
    "chapeaute": "chapeauter",
    "chapeauté": "chapeauter",
    "chapeautée": "chapeauter",
    "chapeautées": "chapeauter",
    "chapeautés": "chapeauter",
    "chapeaux": "chapeau",
    "chapelains": "chapelain",
    "chapelets": "chapelet",
    "chapeliers": "chapelier",
    "chapelière": "chapelier",
    "chapelières": "chapelier",
    "chapelleries": "chapellerie",
    "chapelles": "chapelle",
    "chapelures": "chapelure",
    "chaperonna": "chaperonner",
    "chaperonnai": "chaperonner",
    "chaperonnaient": "chaperonner",
    "chaperonnais": "chaperonner",
    "chaperonnait": "chaperonner",
    "chaperonnant": "chaperonner",
    "chaperonnas": "chaperonner",
    "chaperonnasse": "chaperonner",
    "chaperonnassent": "chaperonner",
    "chaperonnasses": "chaperonner",
    "chaperonnassiez": "chaperonner",
    "chaperonnassions": "chaperonner",
    "chaperonne": "chaperonner",
    "chaperonnent": "chaperonner",
    "chaperonnera": "chaperonner",
    "chaperonnerai": "chaperonner",
    "chaperonneraient": "chaperonner",
    "chaperonnerais": "chaperonner",
    "chaperonnerait": "chaperonner",
    "chaperonneras": "chaperonner",
    "chaperonnerez": "chaperonner",
    "chaperonneriez": "chaperonner",
    "chaperonnerions": "chaperonner",
    "chaperonnerons": "chaperonner",
    "chaperonneront": "chaperonner",
    "chaperonnes": "chaperonner",
    "chaperonnez": "chaperonner",
    "chaperonniez": "chaperonner",
    "chaperonnions": "chaperonner",
    "chaperonnons": "chaperonner",
    "chaperonnâmes": "chaperonner",
    "chaperonnât": "chaperonner",
    "chaperonnâtes": "chaperonner",
    "chaperonnèrent": "chaperonner",
    "chaperonné": "chaperonner",
    "chaperonnée": "chaperonner",
    "chaperonnées": "chaperonner",
    "chaperonnés": "chaperonner",
    "chaperons": "chaperon",
    "chapes": "chape",
    "chapiteaux": "chapiteau",
    "chapiteaux-dortoirs": "chapiteau-dortoir",
    "chapitrale": "chapitral",
    "chapitrales": "chapitral",
    "chapitraux": "chapitral",
    "chapitre": "chapitrer",
    "chapitres": "chapitrer",
    "chapitré": "chapitrer",
    "chapitrée": "chapitrer",
    "chapitrées": "chapitrer",
    "chapkas": "chapka",
    "chaponna": "chaponner",
    "chaponnai": "chaponner",
    "chaponnaient": "chaponner",
    "chaponnais": "chaponner",
    "chaponnait": "chaponner",
    "chaponnant": "chaponner",
    "chaponnas": "chaponner",
    "chaponnasse": "chaponner",
    "chaponnassent": "chaponner",
    "chaponnasses": "chaponner",
    "chaponnassiez": "chaponner",
    "chaponnassions": "chaponner",
    "chaponne": "chaponner",
    "chaponnent": "chaponner",
    "chaponnera": "chaponner",
    "chaponnerai": "chaponner",
    "chaponneraient": "chaponner",
    "chaponnerais": "chaponner",
    "chaponnerait": "chaponner",
    "chaponneras": "chaponner",
    "chaponnerez": "chaponner",
    "chaponneriez": "chaponner",
    "chaponnerions": "chaponner",
    "chaponnerons": "chaponner",
    "chaponneront": "chaponner",
    "chaponnes": "chaponner",
    "chaponnez": "chaponner",
    "chaponniez": "chaponner",
    "chaponnions": "chaponner",
    "chaponnons": "chaponner",
    "chaponnâmes": "chaponner",
    "chaponnât": "chaponner",
    "chaponnâtes": "chaponner",
    "chaponnèrent": "chaponner",
    "chaponné": "chaponner",
    "chaponnée": "chaponner",
    "chaponnées": "chaponner",
    "chaponnés": "chaponner",
    "chapons": "chapon",
    "chapskas": "chapska",
    "chaptalisa": "chaptaliser",
    "chaptalisai": "chaptaliser",
    "chaptalisaient": "chaptaliser",
    "chaptalisais": "chaptaliser",
    "chaptalisait": "chaptaliser",
    "chaptalisant": "chaptaliser",
    "chaptalisas": "chaptaliser",
    "chaptalisasse": "chaptaliser",
    "chaptalisassent": "chaptaliser",
    "chaptalisasses": "chaptaliser",
    "chaptalisassiez": "chaptaliser",
    "chaptalisassions": "chaptaliser",
    "chaptalisations": "chaptalisation",
    "chaptalise": "chaptaliser",
    "chaptalisent": "chaptaliser",
    "chaptalisera": "chaptaliser",
    "chaptaliserai": "chaptaliser",
    "chaptaliseraient": "chaptaliser",
    "chaptaliserais": "chaptaliser",
    "chaptaliserait": "chaptaliser",
    "chaptaliseras": "chaptaliser",
    "chaptaliserez": "chaptaliser",
    "chaptaliseriez": "chaptaliser",
    "chaptaliserions": "chaptaliser",
    "chaptaliserons": "chaptaliser",
    "chaptaliseront": "chaptaliser",
    "chaptalises": "chaptaliser",
    "chaptalisez": "chaptaliser",
    "chaptalisiez": "chaptaliser",
    "chaptalisions": "chaptaliser",
    "chaptalisons": "chaptaliser",
    "chaptalisâmes": "chaptaliser",
    "chaptalisât": "chaptaliser",
    "chaptalisâtes": "chaptaliser",
    "chaptalisèrent": "chaptaliser",
    "chaptalisé": "chaptaliser",
    "chaptalisée": "chaptaliser",
    "chaptalisées": "chaptaliser",
    "chaptalisés": "chaptaliser",
    "chapés": "chapé",
    "charabias": "charabia",
    "charades": "charade",
    "charançonnée": "charançonné",
    "charançonnés": "charançonné",
    "charançons": "charançon",
    "charbonnages": "charbonnage",
    "charbonnaient": "charbonner",
    "charbonnait": "charbonner",
    "charbonne": "charbonner",
    "charbonnent": "charbonner",
    "charbonneuse": "charbonneux",
    "charbonneuses": "charbonneux",
    "charbonniers": "charbonnier",
    "charbonnière": "charbonnier",
    "charbonnières": "charbonnier",
    "charbonné": "charbonner",
    "charbonnées": "charbonner",
    "charbonnés": "charbonner",
    "charbons": "charbon",
    "charcuta": "charcuter",
    "charcutai": "charcuter",
    "charcutaient": "charcuter",
    "charcutais": "charcuter",
    "charcutait": "charcuter",
    "charcutant": "charcuter",
    "charcutas": "charcuter",
    "charcutasse": "charcuter",
    "charcutassent": "charcuter",
    "charcutasses": "charcuter",
    "charcutassiez": "charcuter",
    "charcutassions": "charcuter",
    "charcute": "charcuter",
    "charcutent": "charcuter",
    "charcutera": "charcuter",
    "charcuterai": "charcuter",
    "charcuteraient": "charcuter",
    "charcuterais": "charcuter",
    "charcuterait": "charcuter",
    "charcuteras": "charcuter",
    "charcuterez": "charcuter",
    "charcuteries": "charcuterie",
    "charcuteriez": "charcuter",
    "charcuterions": "charcuter",
    "charcuterons": "charcuter",
    "charcuteront": "charcuter",
    "charcutes": "charcuter",
    "charcutez": "charcuter",
    "charcutiers": "charcutier",
    "charcutiez": "charcuter",
    "charcutions": "charcuter",
    "charcutière": "charcutier",
    "charcutières": "charcutier",
    "charcutons": "charcuter",
    "charcutâmes": "charcuter",
    "charcutât": "charcuter",
    "charcutâtes": "charcuter",
    "charcutèrent": "charcuter",
    "charcuté": "charcuter",
    "charcutée": "charcuter",
    "charcutées": "charcuter",
    "charcutés": "charcuter",
    "chardonnays": "chardonnay",
    "chardonnerets": "chardonneret",
    "chardons": "chardon",
    "charentaise": "charentais",
    "charentaises": "charentais",
    "charge": "charger",
    "chargea": "charger",
    "chargeai": "charger",
    "chargeaient": "charger",
    "chargeais": "charger",
    "chargeait": "charger",
    "chargeant": "charger",
    "chargeas": "charger",
    "chargeasse": "charger",
    "chargeassent": "charger",
    "chargeasses": "charger",
    "chargeassiez": "charger",
    "chargeassions": "charger",
    "chargements": "chargement",
    "chargent": "charger",
    "chargeons": "charger",
    "chargera": "charger",
    "chargerai": "charger",
    "chargeraient": "charger",
    "chargerais": "charger",
    "chargerait": "charger",
    "chargeras": "charger",
    "chargerez": "charger",
    "chargeriez": "charger",
    "chargerions": "charger",
    "chargerons": "charger",
    "chargeront": "charger",
    "charges": "charger",
    "chargeurs": "chargeur",
    "chargez": "charger",
    "chargeâmes": "charger",
    "chargeât": "charger",
    "chargeâtes": "charger",
    "chargiez": "charger",
    "chargions": "charger",
    "chargèrent": "charger",
    "chargé": "charger",
    "chargée": "charger",
    "chargées": "charger",
    "chargés": "charger",
    "chariots": "chariot",
    "charismatiques": "charismatique",
    "charismes": "charisme",
    "charitables": "charitable",
    "charités": "charité",
    "charivaris": "charivari",
    "charlatanismes": "charlatanisme",
    "charlatans": "charlatan",
    "charlots": "charlot",
    "charlottes": "charlotte",
    "charma": "charmer",
    "charmai": "charmer",
    "charmaient": "charmer",
    "charmais": "charmer",
    "charmait": "charmer",
    "charmant": "charmer",
    "charmante": "charmant",
    "charmantes": "charmant",
    "charmants": "charmant",
    "charmas": "charmer",
    "charmasse": "charmer",
    "charmassent": "charmer",
    "charmasses": "charmer",
    "charmassiez": "charmer",
    "charmassions": "charmer",
    "charme": "charmer",
    "charment": "charmer",
    "charmera": "charmer",
    "charmerai": "charmer",
    "charmeraient": "charmer",
    "charmerais": "charmer",
    "charmerait": "charmer",
    "charmeras": "charmer",
    "charmerez": "charmer",
    "charmeriez": "charmer",
    "charmerions": "charmer",
    "charmerons": "charmer",
    "charmeront": "charmer",
    "charmes": "charmer",
    "charmeurs": "charmeur",
    "charmeuse": "charmeur",
    "charmeuses": "charmeur",
    "charmez": "charmer",
    "charmiez": "charmer",
    "charmilles": "charmille",
    "charmions": "charmer",
    "charmons": "charmer",
    "charmâmes": "charmer",
    "charmât": "charmer",
    "charmâtes": "charmer",
    "charmèrent": "charmer",
    "charmé": "charmer",
    "charmée": "charmer",
    "charmées": "charmer",
    "charmés": "charmer",
    "charnelle": "charnel",
    "charnelles": "charnel",
    "charnels": "charnel",
    "charniers": "charnier",
    "charnières": "charnière",
    "charnue": "charnu",
    "charnues": "charnu",
    "charnus": "charnu",
    "charognards": "charognard",
    "charognes": "charogne",
    "charolaise": "charolais",
    "charolaises": "charolais",
    "charpenta": "charpenter",
    "charpentai": "charpenter",
    "charpentaient": "charpenter",
    "charpentais": "charpenter",
    "charpentait": "charpenter",
    "charpentant": "charpenter",
    "charpentas": "charpenter",
    "charpentasse": "charpenter",
    "charpentassent": "charpenter",
    "charpentasses": "charpenter",
    "charpentassiez": "charpenter",
    "charpentassions": "charpenter",
    "charpente": "charpenter",
    "charpentent": "charpenter",
    "charpentera": "charpenter",
    "charpenterai": "charpenter",
    "charpenteraient": "charpenter",
    "charpenterais": "charpenter",
    "charpenterait": "charpenter",
    "charpenteras": "charpenter",
    "charpenterez": "charpenter",
    "charpenteriez": "charpenter",
    "charpenterions": "charpenter",
    "charpenterons": "charpenter",
    "charpenteront": "charpenter",
    "charpentes": "charpenter",
    "charpentez": "charpenter",
    "charpentiers": "charpentier",
    "charpentiez": "charpenter",
    "charpentions": "charpenter",
    "charpentière": "charpentier",
    "charpentières": "charpentier",
    "charpentons": "charpenter",
    "charpentâmes": "charpenter",
    "charpentât": "charpenter",
    "charpentâtes": "charpenter",
    "charpentèrent": "charpenter",
    "charpenté": "charpenter",
    "charpentée": "charpenter",
    "charpentées": "charpenter",
    "charpentés": "charpenter",
    "charpies": "charpie",
    "charres": "charre",
    "charretiers": "charretier",
    "charretière": "charretier",
    "charretières": "charretier",
    "charretons": "charreton",
    "charrettes": "charrette",
    "charretées": "charretée",
    "charria": "charrier",
    "charriai": "charrier",
    "charriaient": "charrier",
    "charriais": "charrier",
    "charriait": "charrier",
    "charriant": "charrier",
    "charrias": "charrier",
    "charriasse": "charrier",
    "charriassent": "charrier",
    "charriasses": "charrier",
    "charriassiez": "charrier",
    "charriassions": "charrier",
    "charrie": "charrier",
    "charrient": "charrier",
    "charriera": "charrier",
    "charrierai": "charrier",
    "charrieraient": "charrier",
    "charrierais": "charrier",
    "charrierait": "charrier",
    "charrieras": "charrier",
    "charrierez": "charrier",
    "charrieriez": "charrier",
    "charrierions": "charrier",
    "charrierons": "charrier",
    "charrieront": "charrier",
    "charries": "charrier",
    "charrieurs": "charrieur",
    "charriez": "charrier",
    "charriiez": "charrier",
    "charriions": "charrier",
    "charrions": "charrier",
    "charriâmes": "charrier",
    "charriât": "charrier",
    "charriâtes": "charrier",
    "charrière": "charrier",
    "charrièrent": "charrier",
    "charrières": "charrier",
    "charrié": "charrier",
    "charriée": "charrier",
    "charriées": "charrier",
    "charriés": "charrier",
    "charroie": "charroyer",
    "charroient": "charroyer",
    "charroiera": "charroyer",
    "charroierai": "charroyer",
    "charroieraient": "charroyer",
    "charroierais": "charroyer",
    "charroierait": "charroyer",
    "charroieras": "charroyer",
    "charroierez": "charroyer",
    "charroieriez": "charroyer",
    "charroierions": "charroyer",
    "charroierons": "charroyer",
    "charroieront": "charroyer",
    "charroies": "charroyer",
    "charrois": "charroi",
    "charronnées": "charronner",
    "charrons": "charron",
    "charroya": "charroyer",
    "charroyai": "charroyer",
    "charroyaient": "charroyer",
    "charroyais": "charroyer",
    "charroyait": "charroyer",
    "charroyant": "charroyer",
    "charroyas": "charroyer",
    "charroyasse": "charroyer",
    "charroyassent": "charroyer",
    "charroyasses": "charroyer",
    "charroyassiez": "charroyer",
    "charroyassions": "charroyer",
    "charroyez": "charroyer",
    "charroyiez": "charroyer",
    "charroyions": "charroyer",
    "charroyons": "charroyer",
    "charroyâmes": "charroyer",
    "charroyât": "charroyer",
    "charroyâtes": "charroyer",
    "charroyèrent": "charroyer",
    "charroyé": "charroyer",
    "charroyée": "charroyer",
    "charroyées": "charroyer",
    "charroyés": "charroyer",
    "charrues": "charrue",
    "charruée": "charruer",
    "chars": "char",
    "charters": "charter",
    "chartes": "charte",
    "chartistes": "chartiste",
    "chartreuse": "chartreux",
    "chartreuses": "chartreux",
    "chassa": "chasser",
    "chassables": "chassable",
    "chassai": "chasser",
    "chassaient": "chasser",
    "chassais": "chasser",
    "chassait": "chasser",
    "chassant": "chasser",
    "chassas": "chasser",
    "chassasse": "chasser",
    "chassassent": "chasser",
    "chassasses": "chasser",
    "chassassiez": "chasser",
    "chassassions": "chasser",
    "chasse": "chasser",
    "chasse-clous": "chasse-clou",
    "chasse-goupilles": "chasse-goupille",
    "chassent": "chasser",
    "chassera": "chasser",
    "chasserai": "chasser",
    "chasseraient": "chasser",
    "chasserais": "chasser",
    "chasserait": "chasser",
    "chasseras": "chasser",
    "chasseresse": "chasseur",
    "chasseresses": "chasseur",
    "chasserez": "chasser",
    "chasseriez": "chasser",
    "chasserions": "chasser",
    "chasserons": "chasser",
    "chasseront": "chasser",
    "chasses": "chasser",
    "chasseurs": "chasseur",
    "chasseuse": "chasseur",
    "chasseuses": "chasseur",
    "chassez": "chasser",
    "chassies": "chassie",
    "chassieuse": "chassieux",
    "chassieuses": "chassieux",
    "chassiez": "chasser",
    "chassions": "chasser",
    "chassons": "chasser",
    "chassâmes": "chasser",
    "chassât": "chasser",
    "chassâtes": "chasser",
    "chassèrent": "chasser",
    "chassé": "chasser",
    "chassée": "chasser",
    "chassées": "chasser",
    "chassés": "chasser",
    "chassés-croisés": "chassé-croisé",
    "chastes": "chaste",
    "chasubles": "chasuble",
    "chat-bottés": "chat-botté",
    "chateaubriands": "chateaubriand",
    "chatières": "chatière",
    "chatoie": "chatoyer",
    "chatoiements": "chatoiement",
    "chatoient": "chatoyer",
    "chatoiera": "chatoyer",
    "chatoierai": "chatoyer",
    "chatoieraient": "chatoyer",
    "chatoierais": "chatoyer",
    "chatoierait": "chatoyer",
    "chatoieras": "chatoyer",
    "chatoierez": "chatoyer",
    "chatoieriez": "chatoyer",
    "chatoierions": "chatoyer",
    "chatoierons": "chatoyer",
    "chatoieront": "chatoyer",
    "chatoies": "chatoyer",
    "chatonne": "chatonner",
    "chatons": "chaton",
    "chatouilla": "chatouiller",
    "chatouillai": "chatouiller",
    "chatouillaient": "chatouiller",
    "chatouillais": "chatouiller",
    "chatouillait": "chatouiller",
    "chatouillant": "chatouiller",
    "chatouillas": "chatouiller",
    "chatouillasse": "chatouiller",
    "chatouillassent": "chatouiller",
    "chatouillasses": "chatouiller",
    "chatouillassiez": "chatouiller",
    "chatouillassions": "chatouiller",
    "chatouille": "chatouiller",
    "chatouillements": "chatouillement",
    "chatouillent": "chatouiller",
    "chatouillera": "chatouiller",
    "chatouillerai": "chatouiller",
    "chatouilleraient": "chatouiller",
    "chatouillerais": "chatouiller",
    "chatouillerait": "chatouiller",
    "chatouilleras": "chatouiller",
    "chatouillerez": "chatouiller",
    "chatouilleriez": "chatouiller",
    "chatouillerions": "chatouiller",
    "chatouillerons": "chatouiller",
    "chatouilleront": "chatouiller",
    "chatouilles": "chatouiller",
    "chatouilleuse": "chatouilleux",
    "chatouilleuses": "chatouilleux",
    "chatouillez": "chatouiller",
    "chatouilliez": "chatouiller",
    "chatouillions": "chatouiller",
    "chatouillons": "chatouiller",
    "chatouillâmes": "chatouiller",
    "chatouillât": "chatouiller",
    "chatouillâtes": "chatouiller",
    "chatouillèrent": "chatouiller",
    "chatouillé": "chatouiller",
    "chatouillée": "chatouiller",
    "chatouillées": "chatouiller",
    "chatouillés": "chatouiller",
    "chatoya": "chatoyer",
    "chatoyai": "chatoyer",
    "chatoyaient": "chatoyer",
    "chatoyais": "chatoyer",
    "chatoyait": "chatoyer",
    "chatoyant": "chatoyer",
    "chatoyante": "chatoyant",
    "chatoyantes": "chatoyant",
    "chatoyants": "chatoyant",
    "chatoyas": "chatoyer",
    "chatoyasse": "chatoyer",
    "chatoyassent": "chatoyer",
    "chatoyasses": "chatoyer",
    "chatoyassiez": "chatoyer",
    "chatoyassions": "chatoyer",
    "chatoyez": "chatoyer",
    "chatoyiez": "chatoyer",
    "chatoyions": "chatoyer",
    "chatoyons": "chatoyer",
    "chatoyâmes": "chatoyer",
    "chatoyât": "chatoyer",
    "chatoyâtes": "chatoyer",
    "chatoyèrent": "chatoyer",
    "chatoyé": "chatoyer",
    "chats": "chat",
    "chats-huants": "chat-huant",
    "chattant": "chatter",
    "chatte": "chat",
    "chattemites": "chattemite",
    "chatteries": "chatterie",
    "chattertons": "chatterton",
    "chattes": "chat",
    "chattons": "chatter",
    "chaude": "chaud",
    "chaudes": "chaud",
    "chaudes-pisses": "chaude-pisse",
    "chaudières": "chaudière",
    "chaudronneries": "chaudronnerie",
    "chaudronniers": "chaudronnier",
    "chaudronné": "chaudronner",
    "chaudrons": "chaudron",
    "chauds": "chaud",
    "chauds-froids": "chaud-froid",
    "chauffa": "chauffer",
    "chauffages": "chauffage",
    "chauffai": "chauffer",
    "chauffaient": "chauffer",
    "chauffais": "chauffer",
    "chauffait": "chauffer",
    "chauffant": "chauffer",
    "chauffante": "chauffant",
    "chauffantes": "chauffant",
    "chauffants": "chauffant",
    "chauffarde": "chauffard",
    "chauffardes": "chauffard",
    "chauffards": "chauffard",
    "chauffas": "chauffer",
    "chauffasse": "chauffer",
    "chauffassent": "chauffer",
    "chauffasses": "chauffer",
    "chauffassiez": "chauffer",
    "chauffassions": "chauffer",
    "chauffe": "chauffer",
    "chauffe-bains": "chauffe-bain",
    "chauffe-biberons": "chauffe-biberon",
    "chauffent": "chauffer",
    "chauffera": "chauffer",
    "chaufferai": "chauffer",
    "chaufferaient": "chauffer",
    "chaufferais": "chauffer",
    "chaufferait": "chauffer",
    "chaufferas": "chauffer",
    "chaufferettes": "chaufferette",
    "chaufferez": "chauffer",
    "chaufferies": "chaufferie",
    "chaufferiez": "chauffer",
    "chaufferions": "chauffer",
    "chaufferons": "chauffer",
    "chaufferont": "chauffer",
    "chauffes": "chauffer",
    "chauffeurs": "chauffeur",
    "chauffeuse": "chauffeur",
    "chauffez": "chauffer",
    "chauffiez": "chauffer",
    "chauffions": "chauffer",
    "chauffons": "chauffer",
    "chauffâmes": "chauffer",
    "chauffât": "chauffer",
    "chauffâtes": "chauffer",
    "chauffèrent": "chauffer",
    "chauffé": "chauffer",
    "chauffée": "chauffer",
    "chauffées": "chauffer",
    "chauffés": "chauffer",
    "chaula": "chauler",
    "chaulai": "chauler",
    "chaulaient": "chauler",
    "chaulais": "chauler",
    "chaulait": "chauler",
    "chaulant": "chauler",
    "chaulas": "chauler",
    "chaulasse": "chauler",
    "chaulassent": "chauler",
    "chaulasses": "chauler",
    "chaulassiez": "chauler",
    "chaulassions": "chauler",
    "chaule": "chauler",
    "chaulent": "chauler",
    "chaulera": "chauler",
    "chaulerai": "chauler",
    "chauleraient": "chauler",
    "chaulerais": "chauler",
    "chaulerait": "chauler",
    "chauleras": "chauler",
    "chaulerez": "chauler",
    "chauleriez": "chauler",
    "chaulerions": "chauler",
    "chaulerons": "chauler",
    "chauleront": "chauler",
    "chaules": "chauler",
    "chaulez": "chauler",
    "chauliez": "chauler",
    "chaulions": "chauler",
    "chaulons": "chauler",
    "chaulâmes": "chauler",
    "chaulât": "chauler",
    "chaulâtes": "chauler",
    "chaulèrent": "chauler",
    "chaulé": "chauler",
    "chaulée": "chauler",
    "chaulées": "chauler",
    "chaulés": "chauler",
    "chaumes": "chaume",
    "chaumines": "chaumine",
    "chaumières": "chaumière",
    "chaumé": "chaumer",
    "chaussa": "chausser",
    "chaussai": "chausser",
    "chaussaient": "chausser",
    "chaussais": "chausser",
    "chaussait": "chausser",
    "chaussant": "chausser",
    "chaussas": "chausser",
    "chaussasse": "chausser",
    "chaussassent": "chausser",
    "chaussasses": "chausser",
    "chaussassiez": "chausser",
    "chaussassions": "chausser",
    "chausse": "chausser",
    "chausse-pieds": "chausse-pied",
    "chausse-trapes": "chausse-trape",
    "chausse-trappes": "chausse-trappe",
    "chaussent": "chausser",
    "chaussera": "chausser",
    "chausserai": "chausser",
    "chausseraient": "chausser",
    "chausserais": "chausser",
    "chausserait": "chausser",
    "chausseras": "chausser",
    "chausserez": "chausser",
    "chausseriez": "chausser",
    "chausserions": "chausser",
    "chausserons": "chausser",
    "chausseront": "chausser",
    "chausses": "chausser",
    "chaussettes": "chaussette",
    "chausseurs": "chausseur",
    "chaussez": "chausser",
    "chaussiez": "chausser",
    "chaussions": "chausser",
    "chaussons": "chausson",
    "chaussures": "chaussure",
    "chaussâmes": "chausser",
    "chaussât": "chausser",
    "chaussâtes": "chausser",
    "chaussèrent": "chausser",
    "chaussé": "chausser",
    "chaussée": "chausser",
    "chaussées": "chausser",
    "chaussés": "chausser",
    "chaut": "chaloir",
    "chauves": "chauve",
    "chauves-souris": "chauve-souris",
    "chauvi": "chauvir",
    "chauvie": "chauvir",
    "chauvies": "chauvir",
    "chauvine": "chauvin",
    "chauvines": "chauvin",
    "chauvinismes": "chauvinisme",
    "chauvins": "chauvin",
    "chauvira": "chauvir",
    "chauvirai": "chauvir",
    "chauviraient": "chauvir",
    "chauvirais": "chauvir",
    "chauvirait": "chauvir",
    "chauviras": "chauvir",
    "chauvirent": "chauvir",
    "chauvirez": "chauvir",
    "chauviriez": "chauvir",
    "chauvirions": "chauvir",
    "chauvirons": "chauvir",
    "chauviront": "chauvir",
    "chauvis": "chauvir",
    "chauvissaient": "chauvir",
    "chauvissais": "chauvir",
    "chauvissait": "chauvir",
    "chauvissant": "chauvir",
    "chauvisse": "chauvir",
    "chauvissent": "chauvir",
    "chauvisses": "chauvir",
    "chauvissez": "chauvir",
    "chauvissiez": "chauvir",
    "chauvissions": "chauvir",
    "chauvissons": "chauvir",
    "chauvit": "chauvir",
    "chauvîmes": "chauvir",
    "chauvît": "chauvir",
    "chauvîtes": "chauvir",
    "chavira": "chavirer",
    "chavirages": "chavirage",
    "chavirai": "chavirer",
    "chaviraient": "chavirer",
    "chavirais": "chavirer",
    "chavirait": "chavirer",
    "chavirant": "chavirer",
    "chavirante": "chavirant",
    "chaviras": "chavirer",
    "chavirasse": "chavirer",
    "chavirassent": "chavirer",
    "chavirasses": "chavirer",
    "chavirassiez": "chavirer",
    "chavirassions": "chavirer",
    "chavire": "chavirer",
    "chavirements": "chavirement",
    "chavirent": "chavirer",
    "chavirera": "chavirer",
    "chavirerai": "chavirer",
    "chavireraient": "chavirer",
    "chavirerais": "chavirer",
    "chavirerait": "chavirer",
    "chavireras": "chavirer",
    "chavirerez": "chavirer",
    "chavireriez": "chavirer",
    "chavirerions": "chavirer",
    "chavirerons": "chavirer",
    "chavireront": "chavirer",
    "chavires": "chavirer",
    "chavirez": "chavirer",
    "chaviriez": "chavirer",
    "chavirions": "chavirer",
    "chavirons": "chavirer",
    "chavirâmes": "chavirer",
    "chavirât": "chavirer",
    "chavirâtes": "chavirer",
    "chavirèrent": "chavirer",
    "chaviré": "chavirer",
    "chavirée": "chavirer",
    "chavirées": "chavirer",
    "chavirés": "chavirer",
    "chaîna": "chaîner",
    "chaînai": "chaîner",
    "chaînaient": "chaîner",
    "chaînais": "chaîner",
    "chaînait": "chaîner",
    "chaînant": "chaîner",
    "chaînas": "chaîner",
    "chaînasse": "chaîner",
    "chaînassent": "chaîner",
    "chaînasses": "chaîner",
    "chaînassiez": "chaîner",
    "chaînassions": "chaîner",
    "chaîne": "chaîner",
    "chaînent": "chaîner",
    "chaînera": "chaîner",
    "chaînerai": "chaîner",
    "chaîneraient": "chaîner",
    "chaînerais": "chaîner",
    "chaînerait": "chaîner",
    "chaîneras": "chaîner",
    "chaînerez": "chaîner",
    "chaîneriez": "chaîner",
    "chaînerions": "chaîner",
    "chaînerons": "chaîner",
    "chaîneront": "chaîner",
    "chaînes": "chaîner",
    "chaînettes": "chaînette",
    "chaînez": "chaîner",
    "chaîniez": "chaîner",
    "chaînions": "chaîner",
    "chaînons": "chaînon",
    "chaînâmes": "chaîner",
    "chaînât": "chaîner",
    "chaînâtes": "chaîner",
    "chaînèrent": "chaîner",
    "chaîné": "chaîner",
    "chaînée": "chaîner",
    "chaînées": "chaîner",
    "chaînés": "chaîner",
    "check up": "check-up",
    "check-lists": "check-list",
    "cheese-cakes": "cheese-cake",
    "cheeseburgers": "cheeseburger",
    "cheffesse": "chef",
    "cheffesses": "chef",
    "chefs": "chef",
    "chefs-d'oeuvre": "chef-d'oeuvre",
    "chefs-lieux": "chef-lieu",
    "cheftaine": "chef",
    "cheftaines": "cheftaine",
    "cheikhs": "cheikh",
    "cheiks": "cheik",
    "chelems": "chelem",
    "chemina": "cheminer",
    "cheminai": "cheminer",
    "cheminaient": "cheminer",
    "cheminais": "cheminer",
    "cheminait": "cheminer",
    "cheminant": "cheminer",
    "cheminas": "cheminer",
    "cheminasse": "cheminer",
    "cheminassent": "cheminer",
    "cheminasses": "cheminer",
    "cheminassiez": "cheminer",
    "cheminassions": "cheminer",
    "chemine": "cheminer",
    "chemineaux": "chemineau",
    "cheminements": "cheminement",
    "cheminent": "cheminer",
    "cheminera": "cheminer",
    "cheminerai": "cheminer",
    "chemineraient": "cheminer",
    "cheminerais": "cheminer",
    "cheminerait": "cheminer",
    "chemineras": "cheminer",
    "cheminerez": "cheminer",
    "chemineriez": "cheminer",
    "cheminerions": "cheminer",
    "cheminerons": "cheminer",
    "chemineront": "cheminer",
    "chemines": "cheminer",
    "cheminez": "cheminer",
    "cheminiez": "cheminer",
    "cheminions": "cheminer",
    "cheminons": "cheminer",
    "cheminots": "cheminot",
    "chemins": "chemin",
    "cheminâmes": "cheminer",
    "cheminât": "cheminer",
    "cheminâtes": "cheminer",
    "cheminèrent": "cheminer",
    "cheminé": "cheminer",
    "cheminée": "cheminer",
    "cheminées": "cheminer",
    "chemises": "chemise",
    "chemisettes": "chemisette",
    "chemisiers": "chemisier",
    "chemisée": "chemiser",
    "chemisées": "chemiser",
    "chenapans": "chenapan",
    "chenaux": "chenal",
    "chenets": "chenet",
    "chenilles": "chenille",
    "chenillettes": "chenillette",
    "chenillés": "chenillé",
    "chenils": "chenil",
    "chenue": "chenu",
    "chenues": "chenu",
    "chenus": "chenu",
    "cheptels": "cheptel",
    "chercha": "chercher",
    "cherchai": "chercher",
    "cherchaient": "chercher",
    "cherchais": "chercher",
    "cherchait": "chercher",
    "cherchant": "chercher",
    "cherchas": "chercher",
    "cherchasse": "chercher",
    "cherchassent": "chercher",
    "cherchasses": "chercher",
    "cherchassiez": "chercher",
    "cherchassions": "chercher",
    "cherche": "chercher",
    "cherchent": "chercher",
    "cherchera": "chercher",
    "chercherai": "chercher",
    "chercheraient": "chercher",
    "chercherais": "chercher",
    "chercherait": "chercher",
    "chercheras": "chercher",
    "chercherez": "chercher",
    "chercheriez": "chercher",
    "chercherions": "chercher",
    "chercherons": "chercher",
    "chercheront": "chercher",
    "cherches": "chercher",
    "chercheurs": "chercheur",
    "chercheuse": "chercheur",
    "chercheuses": "chercheur",
    "cherchez": "chercher",
    "cherchiez": "chercher",
    "cherchions": "chercher",
    "cherchons": "chercher",
    "cherchâmes": "chercher",
    "cherchât": "chercher",
    "cherchâtes": "chercher",
    "cherchèrent": "chercher",
    "cherché": "chercher",
    "cherchée": "chercher",
    "cherchées": "chercher",
    "cherchés": "chercher",
    "cherokees": "cherokee",
    "cherres": "cherrer",
    "chers": "cher",
    "chertés": "cherté",
    "chesters": "chester",
    "chevai": "chever",
    "chevaines": "chevaine",
    "chevaleresques": "chevaleresque",
    "chevaleries": "chevalerie",
    "chevalets": "chevalet",
    "chevaliers": "chevalier",
    "chevaline": "chevalin",
    "chevalins": "chevalin",
    "chevalières": "chevalière",
    "chevalée": "chevaler",
    "chevau-légers": "chevau-léger",
    "chevaucha": "chevaucher",
    "chevauchai": "chevaucher",
    "chevauchaient": "chevaucher",
    "chevauchais": "chevaucher",
    "chevauchait": "chevaucher",
    "chevauchant": "chevaucher",
    "chevauchas": "chevaucher",
    "chevauchasse": "chevaucher",
    "chevauchassent": "chevaucher",
    "chevauchasses": "chevaucher",
    "chevauchassiez": "chevaucher",
    "chevauchassions": "chevaucher",
    "chevauche": "chevaucher",
    "chevauchements": "chevauchement",
    "chevauchent": "chevaucher",
    "chevauchera": "chevaucher",
    "chevaucherai": "chevaucher",
    "chevaucheraient": "chevaucher",
    "chevaucherais": "chevaucher",
    "chevaucherait": "chevaucher",
    "chevaucheras": "chevaucher",
    "chevaucherez": "chevaucher",
    "chevaucheriez": "chevaucher",
    "chevaucherions": "chevaucher",
    "chevaucherons": "chevaucher",
    "chevaucheront": "chevaucher",
    "chevauches": "chevaucher",
    "chevauchez": "chevaucher",
    "chevauchiez": "chevaucher",
    "chevauchions": "chevaucher",
    "chevauchons": "chevaucher",
    "chevauchâmes": "chevaucher",
    "chevauchât": "chevaucher",
    "chevauchâtes": "chevaucher",
    "chevauchèrent": "chevaucher",
    "chevauché": "chevaucher",
    "chevauchée": "chevaucher",
    "chevauchées": "chevaucher",
    "chevauchés": "chevaucher",
    "chevaux": "cheval",
    "chevaux-vapeur": "cheval-vapeur",
    "chevelue": "chevelu",
    "chevelues": "chevelu",
    "chevelures": "chevelure",
    "chevelus": "chevelu",
    "chevesnes": "chevesne",
    "chevets": "chevet",
    "cheveux": "cheveu",
    "chevillards": "chevillard",
    "chevilles": "cheville",
    "chevillé": "cheviller",
    "chevillée": "cheviller",
    "chevillées": "cheviller",
    "cheviottes": "cheviotte",
    "chevreaux": "chevreau",
    "chevrettes": "chevrette",
    "chevreuils": "chevreuil",
    "chevriers": "chevrier",
    "chevrière": "chevrier",
    "chevrières": "chevrier",
    "chevronné": "chevronner",
    "chevronnée": "chevronner",
    "chevronnées": "chevronné",
    "chevronnés": "chevronner",
    "chevrons": "chevron",
    "chevrota": "chevroter",
    "chevrotai": "chevroter",
    "chevrotaient": "chevroter",
    "chevrotains": "chevrotain",
    "chevrotais": "chevroter",
    "chevrotait": "chevroter",
    "chevrotant": "chevroter",
    "chevrotante": "chevrotant",
    "chevrotas": "chevroter",
    "chevrotasse": "chevroter",
    "chevrotassent": "chevroter",
    "chevrotasses": "chevroter",
    "chevrotassiez": "chevroter",
    "chevrotassions": "chevroter",
    "chevrote": "chevroter",
    "chevrotements": "chevrotement",
    "chevrotent": "chevroter",
    "chevrotera": "chevroter",
    "chevroterai": "chevroter",
    "chevroteraient": "chevroter",
    "chevroterais": "chevroter",
    "chevroterait": "chevroter",
    "chevroteras": "chevroter",
    "chevroterez": "chevroter",
    "chevroteriez": "chevroter",
    "chevroterions": "chevroter",
    "chevroterons": "chevroter",
    "chevroteront": "chevroter",
    "chevrotes": "chevroter",
    "chevrotez": "chevroter",
    "chevrotiez": "chevroter",
    "chevrotines": "chevrotine",
    "chevrotins": "chevrotin",
    "chevrotions": "chevroter",
    "chevrotons": "chevroter",
    "chevrotâmes": "chevroter",
    "chevrotât": "chevroter",
    "chevrotâtes": "chevroter",
    "chevrotèrent": "chevroter",
    "chevroté": "chevroter",
    "chevrotée": "chevroter",
    "chevrotées": "chevroter",
    "chevrotés": "chevroter",
    "chevêches": "chevêche",
    "chevêtres": "chevêtre",
    "chewing gum": "chewing-gum",
    "chewing-gums": "chewing-gum",
    "chia": "chier",
    "chiadé": "chiader",
    "chiadée": "chiader",
    "chiadées": "chiader",
    "chiai": "chier",
    "chiaient": "chier",
    "chiais": "chier",
    "chiait": "chier",
    "chiala": "chialer",
    "chialaient": "chialer",
    "chialais": "chialer",
    "chialait": "chialer",
    "chialant": "chialer",
    "chiale": "chialer",
    "chialent": "chialer",
    "chialera": "chialer",
    "chialeraient": "chialer",
    "chialerais": "chialer",
    "chialerait": "chialer",
    "chialeras": "chialer",
    "chialeries": "chialerie",
    "chiales": "chialer",
    "chialeuse": "chialeur",
    "chialez": "chialer",
    "chialèrent": "chialer",
    "chialé": "chialer",
    "chiant": "chier",
    "chiante": "chiant",
    "chiantes": "chiant",
    "chiantis": "chianti",
    "chiants": "chiant",
    "chiards": "chiard",
    "chias": "chier",
    "chiasmes": "chiasme",
    "chiasse": "chier",
    "chiassent": "chier",
    "chiasses": "chier",
    "chiassiez": "chier",
    "chiassions": "chier",
    "chiatiques": "chiatique",
    "chicana": "chicaner",
    "chicanai": "chicaner",
    "chicanaient": "chicaner",
    "chicanais": "chicaner",
    "chicanait": "chicaner",
    "chicanant": "chicaner",
    "chicanas": "chicaner",
    "chicanasse": "chicaner",
    "chicanassent": "chicaner",
    "chicanasses": "chicaner",
    "chicanassiez": "chicaner",
    "chicanassions": "chicaner",
    "chicane": "chicaner",
    "chicanent": "chicaner",
    "chicanera": "chicaner",
    "chicanerai": "chicaner",
    "chicaneraient": "chicaner",
    "chicanerais": "chicaner",
    "chicanerait": "chicaner",
    "chicaneras": "chicaner",
    "chicanerez": "chicaner",
    "chicaneries": "chicanerie",
    "chicaneriez": "chicaner",
    "chicanerions": "chicaner",
    "chicanerons": "chicaner",
    "chicaneront": "chicaner",
    "chicanes": "chicaner",
    "chicanez": "chicaner",
    "chicaniers": "chicanier",
    "chicaniez": "chicaner",
    "chicanions": "chicaner",
    "chicanière": "chicanier",
    "chicanières": "chicanier",
    "chicanons": "chicaner",
    "chicanos": "chicano",
    "chicanâmes": "chicaner",
    "chicanât": "chicaner",
    "chicanâtes": "chicaner",
    "chicanèrent": "chicaner",
    "chicané": "chicaner",
    "chicanée": "chicaner",
    "chicanées": "chicaner",
    "chicanés": "chicaner",
    "chicas": "chica",
    "chiches": "chiche",
    "chiches-kebabs": "chiche-kebab",
    "chichis": "chichi",
    "chichiteuse": "chichiteux",
    "chichiteuses": "chichiteux",
    "chicons": "chicon",
    "chicore": "chicorer",
    "chicorent": "chicorer",
    "chicores": "chicorer",
    "chicoré": "chicorer",
    "chicorées": "chicorée",
    "chicote": "chicot",
    "chicotins": "chicotin",
    "chicots": "chicot",
    "chicoté": "chicoter",
    "chics": "chic",
    "chie": "chier",
    "chienchiens": "chienchien",
    "chiendents": "chiendent",
    "chienlits": "chienlit",
    "chiennasse": "chienner",
    "chienne": "chien",
    "chienneries": "chiennerie",
    "chiennes": "chien",
    "chiens": "chien",
    "chiens-loups": "chien-loup",
    "chient": "chier",
    "chiera": "chier",
    "chierai": "chier",
    "chieraient": "chier",
    "chierais": "chier",
    "chierait": "chier",
    "chieras": "chier",
    "chierez": "chier",
    "chieries": "chierie",
    "chieriez": "chier",
    "chierions": "chier",
    "chierons": "chier",
    "chieront": "chier",
    "chies": "chier",
    "chieurs": "chieur",
    "chieuse": "chieur",
    "chieuses": "chieur",
    "chiez": "chier",
    "chiffes": "chiffe",
    "chiffonna": "chiffonner",
    "chiffonnades": "chiffonnade",
    "chiffonnai": "chiffonner",
    "chiffonnaient": "chiffonner",
    "chiffonnais": "chiffonner",
    "chiffonnait": "chiffonner",
    "chiffonnant": "chiffonner",
    "chiffonnas": "chiffonner",
    "chiffonnasse": "chiffonner",
    "chiffonnassent": "chiffonner",
    "chiffonnasses": "chiffonner",
    "chiffonnassiez": "chiffonner",
    "chiffonnassions": "chiffonner",
    "chiffonne": "chiffonner",
    "chiffonnent": "chiffonner",
    "chiffonnera": "chiffonner",
    "chiffonnerai": "chiffonner",
    "chiffonneraient": "chiffonner",
    "chiffonnerais": "chiffonner",
    "chiffonnerait": "chiffonner",
    "chiffonneras": "chiffonner",
    "chiffonnerez": "chiffonner",
    "chiffonneriez": "chiffonner",
    "chiffonnerions": "chiffonner",
    "chiffonnerons": "chiffonner",
    "chiffonneront": "chiffonner",
    "chiffonnes": "chiffonner",
    "chiffonnez": "chiffonner",
    "chiffonniers": "chiffonnier",
    "chiffonniez": "chiffonner",
    "chiffonnions": "chiffonner",
    "chiffonnière": "chiffonnier",
    "chiffonnières": "chiffonnier",
    "chiffonnons": "chiffonner",
    "chiffonnâmes": "chiffonner",
    "chiffonnât": "chiffonner",
    "chiffonnâtes": "chiffonner",
    "chiffonnèrent": "chiffonner",
    "chiffonné": "chiffonner",
    "chiffonnée": "chiffonner",
    "chiffonnées": "chiffonner",
    "chiffonnés": "chiffonner",
    "chiffons": "chiffon",
    "chiffra": "chiffrer",
    "chiffrai": "chiffrer",
    "chiffraient": "chiffrer",
    "chiffrais": "chiffrer",
    "chiffrait": "chiffrer",
    "chiffrant": "chiffrer",
    "chiffras": "chiffrer",
    "chiffrasse": "chiffrer",
    "chiffrassent": "chiffrer",
    "chiffrasses": "chiffrer",
    "chiffrassiez": "chiffrer",
    "chiffrassions": "chiffrer",
    "chiffre": "chiffrer",
    "chiffrent": "chiffrer",
    "chiffrera": "chiffrer",
    "chiffrerai": "chiffrer",
    "chiffreraient": "chiffrer",
    "chiffrerais": "chiffrer",
    "chiffrerait": "chiffrer",
    "chiffreras": "chiffrer",
    "chiffrerez": "chiffrer",
    "chiffreriez": "chiffrer",
    "chiffrerions": "chiffrer",
    "chiffrerons": "chiffrer",
    "chiffreront": "chiffrer",
    "chiffres": "chiffrer",
    "chiffres-clés": "chiffres-clé",
    "chiffreurs": "chiffreur",
    "chiffreuse": "chiffreur",
    "chiffrez": "chiffrer",
    "chiffriez": "chiffrer",
    "chiffrions": "chiffrer",
    "chiffrons": "chiffrer",
    "chiffrâmes": "chiffrer",
    "chiffrât": "chiffrer",
    "chiffrâtes": "chiffrer",
    "chiffrèrent": "chiffrer",
    "chiffré": "chiffrer",
    "chiffrée": "chiffrer",
    "chiffrées": "chiffrer",
    "chiffrés": "chiffrer",
    "chignoles": "chignole",
    "chignons": "chignon",
    "chihuahuas": "chihuahua",
    "chiiez": "chier",
    "chiions": "chier",
    "chiites": "chiite",
    "chiles": "chile",
    "chilienne": "chilien",
    "chiliennes": "chilienne",
    "chiliens": "chilien",
    "chilis": "chili",
    "chimies": "chimie",
    "chimiques": "chimique",
    "chimistes": "chimiste",
    "chimpanzés": "chimpanzé",
    "chimères": "chimère",
    "chimériques": "chimérique",
    "china": "chiner",
    "chinai": "chiner",
    "chinaient": "chiner",
    "chinais": "chiner",
    "chinait": "chiner",
    "chinant": "chiner",
    "chinas": "chiner",
    "chinasse": "chiner",
    "chinassent": "chiner",
    "chinasses": "chiner",
    "chinassiez": "chiner",
    "chinassions": "chiner",
    "chinchillas": "chinchilla",
    "chine": "chiner",
    "chinent": "chiner",
    "chinera": "chiner",
    "chinerai": "chiner",
    "chineraient": "chiner",
    "chinerais": "chiner",
    "chinerait": "chiner",
    "chineras": "chiner",
    "chinerez": "chiner",
    "chineriez": "chiner",
    "chinerions": "chiner",
    "chinerons": "chiner",
    "chineront": "chiner",
    "chines": "chiner",
    "chinetoques": "chinetoque",
    "chineurs": "chineur",
    "chinez": "chiner",
    "chiniez": "chiner",
    "chinions": "chiner",
    "chinoise": "chinois",
    "chinoiseries": "chinoiserie",
    "chinoises": "chinois",
    "chinons": "chiner",
    "chinâmes": "chiner",
    "chinât": "chiner",
    "chinâtes": "chiner",
    "chinèrent": "chiner",
    "chiné": "chiner",
    "chinée": "chiner",
    "chinées": "chiner",
    "chinés": "chiner",
    "chions": "chier",
    "chiots": "chiot",
    "chiottes": "chiotte",
    "chiourmes": "chiourme",
    "chipa": "chiper",
    "chipai": "chiper",
    "chipaient": "chiper",
    "chipais": "chiper",
    "chipait": "chiper",
    "chipant": "chiper",
    "chipas": "chiper",
    "chipasse": "chiper",
    "chipassent": "chiper",
    "chipasses": "chiper",
    "chipassiez": "chiper",
    "chipassions": "chiper",
    "chipe": "chiper",
    "chipent": "chiper",
    "chipera": "chiper",
    "chiperai": "chiper",
    "chiperaient": "chiper",
    "chiperais": "chiper",
    "chiperait": "chiper",
    "chiperas": "chiper",
    "chiperez": "chiper",
    "chiperiez": "chiper",
    "chiperions": "chiper",
    "chiperons": "chiper",
    "chiperont": "chiper",
    "chipes": "chiper",
    "chipez": "chiper",
    "chipies": "chipie",
    "chipiez": "chiper",
    "chipions": "chiper",
    "chipolatas": "chipolata",
    "chipons": "chiper",
    "chipota": "chipoter",
    "chipotages": "chipotage",
    "chipotai": "chipoter",
    "chipotaient": "chipoter",
    "chipotais": "chipoter",
    "chipotait": "chipoter",
    "chipotant": "chipoter",
    "chipotas": "chipoter",
    "chipotasse": "chipoter",
    "chipotassent": "chipoter",
    "chipotasses": "chipoter",
    "chipotassiez": "chipoter",
    "chipotassions": "chipoter",
    "chipote": "chipoter",
    "chipotent": "chipoter",
    "chipotera": "chipoter",
    "chipoterai": "chipoter",
    "chipoteraient": "chipoter",
    "chipoterais": "chipoter",
    "chipoterait": "chipoter",
    "chipoteras": "chipoter",
    "chipoterez": "chipoter",
    "chipoteriez": "chipoter",
    "chipoterions": "chipoter",
    "chipoterons": "chipoter",
    "chipoteront": "chipoter",
    "chipotes": "chipoter",
    "chipoteuse": "chipoteur",
    "chipotez": "chipoter",
    "chipotiez": "chipoter",
    "chipotions": "chipoter",
    "chipotons": "chipoter",
    "chipotâmes": "chipoter",
    "chipotât": "chipoter",
    "chipotâtes": "chipoter",
    "chipotèrent": "chipoter",
    "chipoté": "chipoter",
    "chipotée": "chipoter",
    "chipotées": "chipoter",
    "chipotés": "chipoter",
    "chippendales": "chippendale",
    "chipâmes": "chiper",
    "chipât": "chiper",
    "chipâtes": "chiper",
    "chipèrent": "chiper",
    "chipé": "chiper",
    "chipée": "chiper",
    "chipées": "chiper",
    "chipés": "chiper",
    "chiqua": "chiquer",
    "chiquai": "chiquer",
    "chiquaient": "chiquer",
    "chiquais": "chiquer",
    "chiquait": "chiquer",
    "chiquant": "chiquer",
    "chiquas": "chiquer",
    "chiquasse": "chiquer",
    "chiquassent": "chiquer",
    "chiquasses": "chiquer",
    "chiquassiez": "chiquer",
    "chiquassions": "chiquer",
    "chique": "chiquer",
    "chiquenaudes": "chiquenaude",
    "chiquent": "chiquer",
    "chiquera": "chiquer",
    "chiquerai": "chiquer",
    "chiqueraient": "chiquer",
    "chiquerais": "chiquer",
    "chiquerait": "chiquer",
    "chiqueras": "chiquer",
    "chiquerez": "chiquer",
    "chiqueriez": "chiquer",
    "chiquerions": "chiquer",
    "chiquerons": "chiquer",
    "chiqueront": "chiquer",
    "chiques": "chiquer",
    "chiqueurs": "chiqueur",
    "chiqueuses": "chiqueur",
    "chiquez": "chiquer",
    "chiquiez": "chiquer",
    "chiquions": "chiquer",
    "chiquons": "chiquer",
    "chiquâmes": "chiquer",
    "chiquât": "chiquer",
    "chiquâtes": "chiquer",
    "chiquèrent": "chiquer",
    "chiqué": "chiquer",
    "chiquée": "chiquer",
    "chiquées": "chiquer",
    "chiqués": "chiquer",
    "chiraquienne": "chiraquien",
    "chiraquiennes": "chiraquien",
    "chiraquiens": "chiraquien",
    "chiricahuas": "chiricahua",
    "chiromancienne": "chiromancien",
    "chiromanciennes": "chiromancien",
    "chiromanciens": "chiromancien",
    "chiromancies": "chiromancie",
    "chiropraticienne": "chiropraticien",
    "chiroptères": "chiroptère",
    "chirurgicale": "chirurgical",
    "chirurgicales": "chirurgical",
    "chirurgicaux": "chirurgical",
    "chirurgienne": "chirurgien",
    "chirurgiens": "chirurgien",
    "chirurgies": "chirurgie",
    "chisteras": "chistera",
    "chiures": "chiure",
    "chiâmes": "chier",
    "chiât": "chier",
    "chiâtes": "chier",
    "chièrent": "chier",
    "chié": "chier",
    "chiée": "chier",
    "chiées": "chier",
    "chiés": "chier",
    "chlamydes": "chlamyde",
    "chlamydiae": "chlamydia",
    "chleuhs": "chleuh",
    "chlingue": "chlinguer",
    "chlingues": "chlinguer",
    "chlorals": "chloral",
    "chlorations": "chloration",
    "chlores": "chlore",
    "chlorhydriques": "chlorhydrique",
    "chlorofluorocarbones": "chlorofluorocarbone",
    "chlorofluorocarbures": "chlorofluorocarbure",
    "chloroformant": "chloroformer",
    "chloroforme": "chloroformer",
    "chloroformes": "chloroformer",
    "chloroformez": "chloroformer",
    "chloroformé": "chloroformer",
    "chlorophytums": "chlorophytum",
    "chlorotiques": "chlorotique",
    "chlorures": "chlorure",
    "chloré": "chlorer",
    "chlorée": "chloré",
    "chlorées": "chloré",
    "chlorés": "chloré",
    "chnoques": "chnoque",
    "choanes": "choane",
    "chochottes": "chochotte",
    "chocolateries": "chocolaterie",
    "chocolatière": "chocolatier",
    "chocolats": "chocolat",
    "chocolatée": "chocolaté",
    "chocolatées": "chocolaté",
    "chocolatés": "chocolaté",
    "chocottes": "chocotte",
    "chocs": "choc",
    "choeurs": "choeur",
    "choie": "choyer",
    "choient": "choyer",
    "choiera": "choyer",
    "choierai": "choyer",
    "choieraient": "choyer",
    "choierais": "choyer",
    "choierait": "choyer",
    "choieras": "choyer",
    "choierez": "choyer",
    "choieriez": "choyer",
    "choierions": "choyer",
    "choierons": "choyer",
    "choieront": "choyer",
    "choies": "choyer",
    "choira": "choir",
    "choirai": "choir",
    "choiraient": "choir",
    "choirais": "choir",
    "choirait": "choir",
    "choiras": "choir",
    "choirez": "choir",
    "choiriez": "choir",
    "choirions": "choir",
    "choirons": "choir",
    "choiront": "choir",
    "chois": "choir",
    "choisi": "choisir",
    "choisie": "choisir",
    "choisies": "choisir",
    "choisira": "choisir",
    "choisirai": "choisir",
    "choisiraient": "choisir",
    "choisirais": "choisir",
    "choisirait": "choisir",
    "choisiras": "choisir",
    "choisirent": "choisir",
    "choisirez": "choisir",
    "choisiriez": "choisir",
    "choisirions": "choisir",
    "choisirons": "choisir",
    "choisiront": "choisir",
    "choisis": "choisir",
    "choisissaient": "choisir",
    "choisissais": "choisir",
    "choisissait": "choisir",
    "choisissant": "choisir",
    "choisisse": "choisir",
    "choisissent": "choisir",
    "choisisses": "choisir",
    "choisissez": "choisir",
    "choisissiez": "choisir",
    "choisissions": "choisir",
    "choisissons": "choisir",
    "choisit": "choisir",
    "choisîmes": "choisir",
    "choisît": "choisir",
    "choisîtes": "choisir",
    "choit": "choir",
    "cholera": "choler",
    "cholestérols": "cholestérol",
    "cholines": "choline",
    "cholédoques": "cholédoque",
    "choléras": "choléra",
    "cholériques": "cholérique",
    "chomâges": "chomâge",
    "chopaient": "choper",
    "chopais": "choper",
    "chopait": "choper",
    "chopant": "choper",
    "chope": "choper",
    "chopent": "choper",
    "chopera": "choper",
    "choperai": "choper",
    "choperais": "choper",
    "choperait": "choper",
    "choperas": "choper",
    "choperez": "choper",
    "choperons": "choper",
    "choperont": "choper",
    "chopes": "choper",
    "chopez": "choper",
    "chopines": "chopine",
    "chopons": "choper",
    "choppe": "chopper",
    "choppent": "chopper",
    "choppers": "chopper",
    "choppes": "chopper",
    "choppez": "chopper",
    "choppons": "chopper",
    "choppé": "chopper",
    "choppée": "chopper",
    "chopé": "choper",
    "chopée": "choper",
    "chopées": "choper",
    "chopés": "choper",
    "choqua": "choquer",
    "choquai": "choquer",
    "choquaient": "choquer",
    "choquais": "choquer",
    "choquait": "choquer",
    "choquant": "choquer",
    "choquante": "choquant",
    "choquantes": "choquant",
    "choquants": "choquant",
    "choquas": "choquer",
    "choquasse": "choquer",
    "choquassent": "choquer",
    "choquasses": "choquer",
    "choquassiez": "choquer",
    "choquassions": "choquer",
    "choque": "choquer",
    "choquent": "choquer",
    "choquera": "choquer",
    "choquerai": "choquer",
    "choqueraient": "choquer",
    "choquerais": "choquer",
    "choquerait": "choquer",
    "choqueras": "choquer",
    "choquerez": "choquer",
    "choqueriez": "choquer",
    "choquerions": "choquer",
    "choquerons": "choquer",
    "choqueront": "choquer",
    "choques": "choquer",
    "choquez": "choquer",
    "choquiez": "choquer",
    "choquions": "choquer",
    "choquons": "choquer",
    "choquâmes": "choquer",
    "choquât": "choquer",
    "choquâtes": "choquer",
    "choquèrent": "choquer",
    "choqué": "choquer",
    "choquée": "choquer",
    "choquées": "choquer",
    "choqués": "choquer",
    "chorale": "choral",
    "chorales": "chorale",
    "chorals": "choral",
    "choraux": "choral",
    "choreutes": "choreute",
    "choristes": "choriste",
    "chorizos": "chorizo",
    "chortens": "chorten",
    "chorèges": "chorège",
    "chorées": "chorée",
    "chorégraphes": "chorégraphe",
    "chorégraphies": "chorégraphie",
    "chorégraphiques": "chorégraphique",
    "chorégraphiées": "chorégraphier",
    "choses": "chose",
    "chosifient": "chosifier",
    "chotts": "chott",
    "chouanneries": "chouannerie",
    "chouans": "chouan",
    "choucarde": "choucard",
    "choucardes": "choucard",
    "choucards": "choucard",
    "chouchous": "chouchou",
    "chouchoutaient": "chouchouter",
    "chouchoutait": "chouchouter",
    "chouchoute": "chouchouter",
    "chouchouteras": "chouchouter",
    "chouchoutes": "chouchoute",
    "chouchoutez": "chouchouter",
    "chouchouté": "chouchouter",
    "chouchoutée": "chouchouter",
    "choucroutes": "choucroute",
    "chouettes": "chouette",
    "chougnait": "chougner",
    "chougne": "chougner",
    "choura": "chourer",
    "chouravait": "chouraver",
    "chourave": "chouraver",
    "chouravent": "chouraver",
    "chouraveurs": "chouraveur",
    "chouraveuse": "chouraveur",
    "chouraveuses": "chouraveur",
    "chouravé": "chouraver",
    "chouravée": "chouraver",
    "chouravés": "chouraver",
    "choure": "chourer",
    "chourent": "chourer",
    "chouriez": "chourer",
    "chourineurs": "chourineur",
    "chouré": "chourer",
    "chourée": "chourer",
    "chourées": "chourer",
    "choute": "chou",
    "choutes": "chou",
    "choux": "chou",
    "choux-fleurs": "chou-fleur",
    "choux-raves": "chou-rave",
    "chows-chows": "chow-chow",
    "choya": "choyer",
    "choyai": "choyer",
    "choyaient": "choyer",
    "choyais": "choyer",
    "choyait": "choyer",
    "choyant": "choyer",
    "choyas": "choyer",
    "choyasse": "choyer",
    "choyassent": "choyer",
    "choyasses": "choyer",
    "choyassiez": "choyer",
    "choyassions": "choyer",
    "choyez": "choyer",
    "choyiez": "choyer",
    "choyions": "choyer",
    "choyons": "choyer",
    "choyâmes": "choyer",
    "choyât": "choyer",
    "choyâtes": "choyer",
    "choyèrent": "choyer",
    "choyé": "choyer",
    "choyée": "choyer",
    "choyées": "choyer",
    "choyés": "choyer",
    "choéphores": "choéphore",
    "chrestomathies": "chrestomathie",
    "christianias": "christiania",
    "christianisa": "christianiser",
    "christianisai": "christianiser",
    "christianisaient": "christianiser",
    "christianisais": "christianiser",
    "christianisait": "christianiser",
    "christianisant": "christianiser",
    "christianisas": "christianiser",
    "christianisasse": "christianiser",
    "christianisassent": "christianiser",
    "christianisasses": "christianiser",
    "christianisassiez": "christianiser",
    "christianisassions": "christianiser",
    "christianise": "christianiser",
    "christianisent": "christianiser",
    "christianisera": "christianiser",
    "christianiserai": "christianiser",
    "christianiseraient": "christianiser",
    "christianiserais": "christianiser",
    "christianiserait": "christianiser",
    "christianiseras": "christianiser",
    "christianiserez": "christianiser",
    "christianiseriez": "christianiser",
    "christianiserions": "christianiser",
    "christianiserons": "christianiser",
    "christianiseront": "christianiser",
    "christianises": "christianiser",
    "christianisez": "christianiser",
    "christianisiez": "christianiser",
    "christianisions": "christianiser",
    "christianismes": "christianisme",
    "christianisons": "christianiser",
    "christianisâmes": "christianiser",
    "christianisât": "christianiser",
    "christianisâtes": "christianiser",
    "christianisèrent": "christianiser",
    "christianisé": "christianiser",
    "christianisée": "christianiser",
    "christianisées": "christianiser",
    "christianisés": "christianiser",
    "christs": "christ",
    "chroma": "chromer",
    "chromai": "chromer",
    "chromaient": "chromer",
    "chromais": "chromer",
    "chromait": "chromer",
    "chromant": "chromer",
    "chromas": "chromer",
    "chromasse": "chromer",
    "chromassent": "chromer",
    "chromasses": "chromer",
    "chromassiez": "chromer",
    "chromassions": "chromer",
    "chromatiques": "chromatique",
    "chromatismes": "chromatisme",
    "chrome": "chromer",
    "chroment": "chromer",
    "chromera": "chromer",
    "chromerai": "chromer",
    "chromeraient": "chromer",
    "chromerais": "chromer",
    "chromerait": "chromer",
    "chromeras": "chromer",
    "chromerez": "chromer",
    "chromeriez": "chromer",
    "chromerions": "chromer",
    "chromerons": "chromer",
    "chromeront": "chromer",
    "chromes": "chromer",
    "chromez": "chromer",
    "chromiez": "chromer",
    "chromions": "chromer",
    "chromogènes": "chromogène",
    "chromolithographies": "chromolithographie",
    "chromons": "chromer",
    "chromos": "chromo",
    "chromosomes": "chromosome",
    "chromosomiques": "chromosomique",
    "chromâmes": "chromer",
    "chromât": "chromer",
    "chromâtes": "chromer",
    "chromèrent": "chromer",
    "chromé": "chromer",
    "chromée": "chromer",
    "chromées": "chromer",
    "chromés": "chromer",
    "chronicités": "chronicité",
    "chroniquais": "chroniquer",
    "chronique": "chroniquer",
    "chroniques": "chronique",
    "chroniqueurs": "chroniqueur",
    "chroniqueuse": "chroniqueur",
    "chroniqueuses": "chroniqueur",
    "chronographes": "chronographe",
    "chronologies": "chronologie",
    "chronologiques": "chronologique",
    "chronomètre": "chronométrer",
    "chronomètrent": "chronométrer",
    "chronomètres": "chronométrer",
    "chronométra": "chronométrer",
    "chronométrai": "chronométrer",
    "chronométraient": "chronométrer",
    "chronométrais": "chronométrer",
    "chronométrait": "chronométrer",
    "chronométrant": "chronométrer",
    "chronométras": "chronométrer",
    "chronométrasse": "chronométrer",
    "chronométrassent": "chronométrer",
    "chronométrasses": "chronométrer",
    "chronométrassiez": "chronométrer",
    "chronométrassions": "chronométrer",
    "chronométrera": "chronométrer",
    "chronométrerai": "chronométrer",
    "chronométreraient": "chronométrer",
    "chronométrerais": "chronométrer",
    "chronométrerait": "chronométrer",
    "chronométreras": "chronométrer",
    "chronométrerez": "chronométrer",
    "chronométreriez": "chronométrer",
    "chronométrerions": "chronométrer",
    "chronométrerons": "chronométrer",
    "chronométreront": "chronométrer",
    "chronométrez": "chronométrer",
    "chronométriez": "chronométrer",
    "chronométrions": "chronométrer",
    "chronométrons": "chronométrer",
    "chronométrâmes": "chronométrer",
    "chronométrât": "chronométrer",
    "chronométrâtes": "chronométrer",
    "chronométrèrent": "chronométrer",
    "chronométré": "chronométrer",
    "chronométrée": "chronométrer",
    "chronométrées": "chronométrer",
    "chronométrés": "chronométrer",
    "chronos": "chrono",
    "chrysalides": "chrysalide",
    "chrysanthèmes": "chrysanthème",
    "chrysocales": "chrysocale",
    "chrysolites": "chrysolite",
    "chrémeaux": "chrémeau",
    "chrétienne": "chrétien",
    "chrétienne-démocrate": "chrétien-démocrate",
    "chrétiennes": "chrétien",
    "chrétiennes-démocrates": "chrétien-démocrate",
    "chrétiens": "chrétien",
    "chrétiens-démocrates": "chrétien-démocrate",
    "chrétientés": "chrétienté",
    "chrêmes": "chrême",
    "chtarbée": "chtarbé",
    "chtarbées": "chtarbé",
    "chthoniennes": "chthonien",
    "chtimis": "chtimi",
    "chu": "choir",
    "chuchota": "chuchoter",
    "chuchotai": "chuchoter",
    "chuchotaient": "chuchoter",
    "chuchotais": "chuchoter",
    "chuchotait": "chuchoter",
    "chuchotant": "chuchoter",
    "chuchotante": "chuchotant",
    "chuchotantes": "chuchotant",
    "chuchotants": "chuchotant",
    "chuchotas": "chuchoter",
    "chuchotasse": "chuchoter",
    "chuchotassent": "chuchoter",
    "chuchotasses": "chuchoter",
    "chuchotassiez": "chuchoter",
    "chuchotassions": "chuchoter",
    "chuchote": "chuchoter",
    "chuchotements": "chuchotement",
    "chuchotent": "chuchoter",
    "chuchotera": "chuchoter",
    "chuchoterai": "chuchoter",
    "chuchoteraient": "chuchoter",
    "chuchoterais": "chuchoter",
    "chuchoterait": "chuchoter",
    "chuchoteras": "chuchoter",
    "chuchoterez": "chuchoter",
    "chuchoteries": "chuchoterie",
    "chuchoteriez": "chuchoter",
    "chuchoterions": "chuchoter",
    "chuchoterons": "chuchoter",
    "chuchoteront": "chuchoter",
    "chuchotes": "chuchoter",
    "chuchoteuse": "chuchoteur",
    "chuchotez": "chuchoter",
    "chuchotiez": "chuchoter",
    "chuchotions": "chuchoter",
    "chuchotons": "chuchoter",
    "chuchotâmes": "chuchoter",
    "chuchotât": "chuchoter",
    "chuchotâtes": "chuchoter",
    "chuchotèrent": "chuchoter",
    "chuchoté": "chuchoter",
    "chuchotée": "chuchoter",
    "chuchotées": "chuchoter",
    "chuchotés": "chuchoter",
    "chue": "choir",
    "chues": "choir",
    "chuinta": "chuinter",
    "chuintai": "chuinter",
    "chuintaient": "chuinter",
    "chuintais": "chuinter",
    "chuintait": "chuinter",
    "chuintant": "chuinter",
    "chuintante": "chuintant",
    "chuintants": "chuintant",
    "chuintas": "chuinter",
    "chuintasse": "chuinter",
    "chuintassent": "chuinter",
    "chuintasses": "chuinter",
    "chuintassiez": "chuinter",
    "chuintassions": "chuinter",
    "chuinte": "chuinter",
    "chuintements": "chuintement",
    "chuintent": "chuinter",
    "chuintera": "chuinter",
    "chuinterai": "chuinter",
    "chuinteraient": "chuinter",
    "chuinterais": "chuinter",
    "chuinterait": "chuinter",
    "chuinteras": "chuinter",
    "chuinterez": "chuinter",
    "chuinteriez": "chuinter",
    "chuinterions": "chuinter",
    "chuinterons": "chuinter",
    "chuinteront": "chuinter",
    "chuintes": "chuinter",
    "chuintez": "chuinter",
    "chuintiez": "chuinter",
    "chuintions": "chuinter",
    "chuintons": "chuinter",
    "chuintâmes": "chuinter",
    "chuintât": "chuinter",
    "chuintâtes": "chuinter",
    "chuintèrent": "chuinter",
    "chuinté": "chuinter",
    "chuintée": "chuinter",
    "chuintées": "chuinter",
    "chuintés": "chuinter",
    "churent": "choir",
    "churros": "churro",
    "chus": "choir",
    "chut": "choir",
    "chuta": "chuter",
    "chutai": "chuter",
    "chutaient": "chuter",
    "chutais": "chuter",
    "chutait": "chuter",
    "chutant": "chuter",
    "chutas": "chuter",
    "chutasse": "chuter",
    "chutassent": "chuter",
    "chutasses": "chuter",
    "chutassiez": "chuter",
    "chutassions": "chuter",
    "chute": "chuter",
    "chutent": "chuter",
    "chutera": "chuter",
    "chuterai": "chuter",
    "chuteraient": "chuter",
    "chuterais": "chuter",
    "chuterait": "chuter",
    "chuteras": "chuter",
    "chuterez": "chuter",
    "chuteriez": "chuter",
    "chuterions": "chuter",
    "chuterons": "chuter",
    "chuteront": "chuter",
    "chutes": "chuter",
    "chutez": "chuter",
    "chutiez": "chuter",
    "chutions": "chuter",
    "chutons": "chuter",
    "chutâmes": "chuter",
    "chutât": "chuter",
    "chutâtes": "chuter",
    "chutèrent": "chuter",
    "chuté": "chuter",
    "chutée": "chuter",
    "chutées": "chuter",
    "chutés": "chuter",
    "chyles": "chyle",
    "chymes": "chyme",
    "chypriotes": "chypriote",
    "châles": "châle",
    "châlits": "châlit",
    "châsses": "châsse",
    "châtaignent": "châtaigner",
    "châtaigneraies": "châtaigneraie",
    "châtaignes": "châtaigne",
    "châtaigniers": "châtaignier",
    "châtaigné": "châtaigner",
    "châtaine": "châtain",
    "châtaines": "châtain",
    "châtains": "châtain",
    "châteaubriants": "châteaubriant",
    "châteaux": "château",
    "châtelaine": "châtelain",
    "châtelaines": "châtelain",
    "châtelains": "châtelain",
    "châtia": "châtier",
    "châtiai": "châtier",
    "châtiaient": "châtier",
    "châtiais": "châtier",
    "châtiait": "châtier",
    "châtiant": "châtier",
    "châtias": "châtier",
    "châtiasse": "châtier",
    "châtiassent": "châtier",
    "châtiasses": "châtier",
    "châtiassiez": "châtier",
    "châtiassions": "châtier",
    "châtie": "châtier",
    "châtient": "châtier",
    "châtiera": "châtier",
    "châtierai": "châtier",
    "châtieraient": "châtier",
    "châtierais": "châtier",
    "châtierait": "châtier",
    "châtieras": "châtier",
    "châtierez": "châtier",
    "châtieriez": "châtier",
    "châtierions": "châtier",
    "châtierons": "châtier",
    "châtieront": "châtier",
    "châties": "châtier",
    "châtiez": "châtier",
    "châtiiez": "châtier",
    "châtiions": "châtier",
    "châtiments": "châtiment",
    "châtions": "châtier",
    "châtiâmes": "châtier",
    "châtiât": "châtier",
    "châtiâtes": "châtier",
    "châtièrent": "châtier",
    "châtié": "châtier",
    "châtiée": "châtier",
    "châtiées": "châtier",
    "châtiés": "châtier",
    "châtra": "châtrer",
    "châtrai": "châtrer",
    "châtraient": "châtrer",
    "châtrais": "châtrer",
    "châtrait": "châtrer",
    "châtrant": "châtrer",
    "châtras": "châtrer",
    "châtrasse": "châtrer",
    "châtrassent": "châtrer",
    "châtrasses": "châtrer",
    "châtrassiez": "châtrer",
    "châtrassions": "châtrer",
    "châtre": "châtrer",
    "châtrent": "châtrer",
    "châtrera": "châtrer",
    "châtrerai": "châtrer",
    "châtreraient": "châtrer",
    "châtrerais": "châtrer",
    "châtrerait": "châtrer",
    "châtreras": "châtrer",
    "châtrerez": "châtrer",
    "châtreriez": "châtrer",
    "châtrerions": "châtrer",
    "châtrerons": "châtrer",
    "châtreront": "châtrer",
    "châtres": "châtrer",
    "châtrez": "châtrer",
    "châtriez": "châtrer",
    "châtrions": "châtrer",
    "châtrons": "châtron",
    "châtrâmes": "châtrer",
    "châtrât": "châtrer",
    "châtrâtes": "châtrer",
    "châtrèrent": "châtrer",
    "châtré": "châtrer",
    "châtrée": "châtrer",
    "châtrées": "châtrer",
    "châtrés": "châtrer",
    "chèches": "chèche",
    "chènevières": "chènevière",
    "chèques": "chèque",
    "chère": "cher",
    "chères": "chère",
    "chèvrefeuilles": "chèvrefeuille",
    "chèvres": "chèvre",
    "chéchias": "chéchia",
    "chéiroptères": "chéiroptère",
    "chélidoines": "chélidoine",
    "chéneaux": "chéneau",
    "chéquiers": "chéquier",
    "chéri": "chérir",
    "chérie": "chérir",
    "chéries": "chérir",
    "chérifienne": "chérifien",
    "chérira": "chérir",
    "chérirai": "chérir",
    "chériraient": "chérir",
    "chérirais": "chérir",
    "chérirait": "chérir",
    "chériras": "chérir",
    "chérirent": "chérir",
    "chérirez": "chérir",
    "chéririez": "chérir",
    "chéririons": "chérir",
    "chérirons": "chérir",
    "chériront": "chérir",
    "chéris": "chérir",
    "chérissaient": "chérir",
    "chérissais": "chérir",
    "chérissait": "chérir",
    "chérissant": "chérir",
    "chérisse": "chérir",
    "chérissent": "chérir",
    "chérisses": "chérir",
    "chérissez": "chérir",
    "chérissiez": "chérir",
    "chérissions": "chérir",
    "chérissons": "chérir",
    "chérit": "chérir",
    "chérubins": "chérubin",
    "chérîmes": "chérir",
    "chérît": "chérir",
    "chérîtes": "chérir",
    "chétifs": "chétif",
    "chétive": "chétif",
    "chétives": "chétif",
    "chênaies": "chênaie",
    "chênes": "chêne",
    "chênes-lièges": "chêne-liège",
    "chôma": "chômer",
    "chômages": "chômage",
    "chômai": "chômer",
    "chômaient": "chômer",
    "chômais": "chômer",
    "chômait": "chômer",
    "chômant": "chômer",
    "chômas": "chômer",
    "chômasse": "chômer",
    "chômassent": "chômer",
    "chômasses": "chômer",
    "chômassiez": "chômer",
    "chômassions": "chômer",
    "chôme": "chômer",
    "chôment": "chômer",
    "chômera": "chômer",
    "chômerai": "chômer",
    "chômeraient": "chômer",
    "chômerais": "chômer",
    "chômerait": "chômer",
    "chômeras": "chômer",
    "chômerez": "chômer",
    "chômeriez": "chômer",
    "chômerions": "chômer",
    "chômerons": "chômer",
    "chômeront": "chômer",
    "chômes": "chômer",
    "chômeurs": "chômeur",
    "chômeuse": "chômeur",
    "chômeuses": "chômeur",
    "chômez": "chômer",
    "chômiez": "chômer",
    "chômions": "chômer",
    "chômons": "chômer",
    "chômâmes": "chômer",
    "chômât": "chômer",
    "chômâtes": "chômer",
    "chômèrent": "chômer",
    "chômé": "chômer",
    "chômée": "chômer",
    "chômées": "chômer",
    "chômés": "chômer",
    "chûmes": "choir",
    "chût": "choir",
    "chûtes": "choir",
    "ci-annexée": "ci-annexé",
    "ci-annexées": "ci-annexé",
    "ci-annexés": "ci-annexé",
    "ci-incluse": "ci-inclus",
    "ci-incluses": "ci-inclus",
    "ci-jointe": "ci-joint",
    "ci-jointes": "ci-joint",
    "ci-joints": "ci-joint",
    "cibiches": "cibiche",
    "cibistes": "cibiste",
    "cibla": "cibler",
    "ciblages": "ciblage",
    "ciblai": "cibler",
    "ciblaient": "cibler",
    "ciblais": "cibler",
    "ciblait": "cibler",
    "ciblant": "cibler",
    "ciblas": "cibler",
    "ciblasse": "cibler",
    "ciblassent": "cibler",
    "ciblasses": "cibler",
    "ciblassiez": "cibler",
    "ciblassions": "cibler",
    "cible": "cibler",
    "ciblent": "cibler",
    "ciblera": "cibler",
    "ciblerai": "cibler",
    "cibleraient": "cibler",
    "ciblerais": "cibler",
    "ciblerait": "cibler",
    "cibleras": "cibler",
    "ciblerez": "cibler",
    "cibleriez": "cibler",
    "ciblerions": "cibler",
    "ciblerons": "cibler",
    "cibleront": "cibler",
    "cibles": "cibler",
    "ciblez": "cibler",
    "cibliez": "cibler",
    "ciblions": "cibler",
    "ciblons": "cibler",
    "ciblâmes": "cibler",
    "ciblât": "cibler",
    "ciblâtes": "cibler",
    "ciblèrent": "cibler",
    "ciblé": "cibler",
    "ciblée": "cibler",
    "ciblées": "cibler",
    "ciblés": "cibler",
    "ciboires": "ciboire",
    "ciboulettes": "ciboulette",
    "ciboulots": "ciboulot",
    "cicatrices": "cicatrice",
    "cicatricielle": "cicatriciel",
    "cicatricielles": "cicatriciel",
    "cicatriciels": "cicatriciel",
    "cicatrisa": "cicatriser",
    "cicatrisai": "cicatriser",
    "cicatrisaient": "cicatriser",
    "cicatrisais": "cicatriser",
    "cicatrisait": "cicatriser",
    "cicatrisant": "cicatriser",
    "cicatrisante": "cicatrisant",
    "cicatrisants": "cicatrisant",
    "cicatrisas": "cicatriser",
    "cicatrisasse": "cicatriser",
    "cicatrisassent": "cicatriser",
    "cicatrisasses": "cicatriser",
    "cicatrisassiez": "cicatriser",
    "cicatrisassions": "cicatriser",
    "cicatrisations": "cicatrisation",
    "cicatrise": "cicatriser",
    "cicatrisent": "cicatriser",
    "cicatrisera": "cicatriser",
    "cicatriserai": "cicatriser",
    "cicatriseraient": "cicatriser",
    "cicatriserais": "cicatriser",
    "cicatriserait": "cicatriser",
    "cicatriseras": "cicatriser",
    "cicatriserez": "cicatriser",
    "cicatriseriez": "cicatriser",
    "cicatriserions": "cicatriser",
    "cicatriserons": "cicatriser",
    "cicatriseront": "cicatriser",
    "cicatrises": "cicatriser",
    "cicatrisez": "cicatriser",
    "cicatrisiez": "cicatriser",
    "cicatrisions": "cicatriser",
    "cicatrisons": "cicatriser",
    "cicatrisâmes": "cicatriser",
    "cicatrisât": "cicatriser",
    "cicatrisâtes": "cicatriser",
    "cicatrisèrent": "cicatriser",
    "cicatrisé": "cicatriser",
    "cicatrisée": "cicatriser",
    "cicatrisées": "cicatriser",
    "cicatrisés": "cicatriser",
    "cicindèles": "cicindèle",
    "cicérones": "cicérone",
    "cicéronienne": "cicéronien",
    "cidres": "cidre",
    "ciels": "ciel",
    "cierges": "cierge",
    "cieux": "ciel",
    "cigales": "cigale",
    "cigares": "cigare",
    "cigarettes": "cigarette",
    "cigarillos": "cigarillo",
    "cigarière": "cigarier",
    "cigarières": "cigarier",
    "cigle": "cigler",
    "ciglent": "cigler",
    "ciglé": "cigler",
    "ciglées": "cigler",
    "ciglés": "cigler",
    "cigogneaux": "cigogneau",
    "cigognes": "cigogne",
    "ciguës": "ciguë",
    "ciliaires": "ciliaire",
    "cilices": "cilice",
    "cilla": "ciller",
    "cillai": "ciller",
    "cillaient": "ciller",
    "cillais": "ciller",
    "cillait": "ciller",
    "cillant": "ciller",
    "cillas": "ciller",
    "cillasse": "ciller",
    "cillassent": "ciller",
    "cillasses": "ciller",
    "cillassiez": "ciller",
    "cillassions": "ciller",
    "cille": "ciller",
    "cillements": "cillement",
    "cillent": "ciller",
    "cillera": "ciller",
    "cillerai": "ciller",
    "cilleraient": "ciller",
    "cillerais": "ciller",
    "cillerait": "ciller",
    "cilleras": "ciller",
    "cillerez": "ciller",
    "cilleriez": "ciller",
    "cillerions": "ciller",
    "cillerons": "ciller",
    "cilleront": "ciller",
    "cilles": "ciller",
    "cillez": "ciller",
    "cilliez": "ciller",
    "cillions": "ciller",
    "cillons": "ciller",
    "cillâmes": "ciller",
    "cillât": "ciller",
    "cillâtes": "ciller",
    "cillèrent": "ciller",
    "cillé": "ciller",
    "cillée": "ciller",
    "cillées": "ciller",
    "cillés": "ciller",
    "cils": "cil",
    "cimaises": "cimaise",
    "cimenta": "cimenter",
    "cimentai": "cimenter",
    "cimentaient": "cimenter",
    "cimentais": "cimenter",
    "cimentait": "cimenter",
    "cimentant": "cimenter",
    "cimentas": "cimenter",
    "cimentasse": "cimenter",
    "cimentassent": "cimenter",
    "cimentasses": "cimenter",
    "cimentassiez": "cimenter",
    "cimentassions": "cimenter",
    "cimente": "cimenter",
    "cimentent": "cimenter",
    "cimentera": "cimenter",
    "cimenterai": "cimenter",
    "cimenteraient": "cimenter",
    "cimenterais": "cimenter",
    "cimenterait": "cimenter",
    "cimenteras": "cimenter",
    "cimenterez": "cimenter",
    "cimenteries": "cimenterie",
    "cimenteriez": "cimenter",
    "cimenterions": "cimenter",
    "cimenterons": "cimenter",
    "cimenteront": "cimenter",
    "cimentes": "cimenter",
    "cimentez": "cimenter",
    "cimentiez": "cimenter",
    "cimentions": "cimenter",
    "cimentières": "cimentière",
    "cimentons": "cimenter",
    "ciments": "ciment",
    "cimentâmes": "cimenter",
    "cimentât": "cimenter",
    "cimentâtes": "cimenter",
    "cimentèrent": "cimenter",
    "cimenté": "cimenter",
    "cimentée": "cimenter",
    "cimentées": "cimenter",
    "cimentés": "cimenter",
    "cimes": "cime",
    "cimeterres": "cimeterre",
    "cimetières": "cimetière",
    "cimiers": "cimier",
    "cinabres": "cinabre",
    "cingalaise": "cingalais",
    "cingalaises": "cingalais",
    "cinghalaise": "cinghalais",
    "cinghalaises": "cinghalais",
    "cingla": "cingler",
    "cinglai": "cingler",
    "cinglaient": "cingler",
    "cinglais": "cingler",
    "cinglait": "cingler",
    "cinglant": "cingler",
    "cinglante": "cinglant",
    "cinglantes": "cinglant",
    "cinglants": "cinglant",
    "cinglas": "cingler",
    "cinglasse": "cingler",
    "cinglassent": "cingler",
    "cinglasses": "cingler",
    "cinglassiez": "cingler",
    "cinglassions": "cingler",
    "cingle": "cingler",
    "cinglent": "cingler",
    "cinglera": "cingler",
    "cinglerai": "cingler",
    "cingleraient": "cingler",
    "cinglerais": "cingler",
    "cinglerait": "cingler",
    "cingleras": "cingler",
    "cinglerez": "cingler",
    "cingleriez": "cingler",
    "cinglerions": "cingler",
    "cinglerons": "cingler",
    "cingleront": "cingler",
    "cingles": "cingler",
    "cinglez": "cingler",
    "cingliez": "cingler",
    "cinglions": "cingler",
    "cinglons": "cinglon",
    "cinglâmes": "cingler",
    "cinglât": "cingler",
    "cinglâtes": "cingler",
    "cinglèrent": "cingler",
    "cinglé": "cingler",
    "cinglée": "cingler",
    "cinglées": "cingler",
    "cinglés": "cingler",
    "cinoches": "cinoche",
    "cinoques": "cinoque",
    "cinquantaines": "cinquantaine",
    "cinquante-cinquièmes": "cinquante-cinquième",
    "cinquante-deuxièmes": "cinquante-deuxième",
    "cinquante-et-unièmes": "cinquante-et-unième",
    "cinquante-huitièmes": "cinquante-huitième",
    "cinquante-neuvièmes": "cinquante-neuvième",
    "cinquante-quatrièmes": "cinquante-quatrième",
    "cinquante-septièmes": "cinquante-septième",
    "cinquante-sixièmes": "cinquante-sixième",
    "cinquante-troisièmes": "cinquante-troisième",
    "cinquantenaires": "cinquantenaire",
    "cinquantièmes": "cinquantième",
    "cinquièmes": "cinquième",
    "cintra": "cintrer",
    "cintrai": "cintrer",
    "cintraient": "cintrer",
    "cintrais": "cintrer",
    "cintrait": "cintrer",
    "cintrant": "cintrer",
    "cintras": "cintrer",
    "cintrasse": "cintrer",
    "cintrassent": "cintrer",
    "cintrasses": "cintrer",
    "cintrassiez": "cintrer",
    "cintrassions": "cintrer",
    "cintre": "cintrer",
    "cintrent": "cintrer",
    "cintrera": "cintrer",
    "cintrerai": "cintrer",
    "cintreraient": "cintrer",
    "cintrerais": "cintrer",
    "cintrerait": "cintrer",
    "cintreras": "cintrer",
    "cintrerez": "cintrer",
    "cintreriez": "cintrer",
    "cintrerions": "cintrer",
    "cintrerons": "cintrer",
    "cintreront": "cintrer",
    "cintres": "cintrer",
    "cintrez": "cintrer",
    "cintriez": "cintrer",
    "cintrions": "cintrer",
    "cintrons": "cintrer",
    "cintrâmes": "cintrer",
    "cintrât": "cintrer",
    "cintrâtes": "cintrer",
    "cintrèrent": "cintrer",
    "cintré": "cintrer",
    "cintrée": "cintrer",
    "cintrées": "cintrer",
    "cintrés": "cintrer",
    "ciné-clubs": "ciné-club",
    "cinéastes": "cinéaste",
    "cinémas": "cinéma",
    "cinémathèques": "cinémathèque",
    "cinématiques": "cinématique",
    "cinématographes": "cinématographe",
    "cinématographies": "cinématographie",
    "cinématographiques": "cinématographique",
    "cinémomètres": "cinémomètre",
    "cinéphiles": "cinéphile",
    "cinéraires": "cinéraire",
    "cinés": "ciné",
    "cinétiques": "cinétique",
    "cipayes": "cipaye",
    "cipolins": "cipolin",
    "cippes": "cippe",
    "cira": "cirer",
    "cirages": "cirage",
    "cirai": "cirer",
    "ciraient": "cirer",
    "cirais": "cirer",
    "cirait": "cirer",
    "cirant": "cirer",
    "ciras": "cirer",
    "cirasse": "cirer",
    "cirassent": "cirer",
    "cirasses": "cirer",
    "cirassiez": "cirer",
    "cirassions": "cirer",
    "circassienne": "circassien",
    "circassiennes": "circassienne",
    "circaètes": "circaète",
    "circoncira": "circoncire",
    "circoncirai": "circoncire",
    "circonciraient": "circoncire",
    "circoncirais": "circoncire",
    "circoncirait": "circoncire",
    "circonciras": "circoncire",
    "circoncirent": "circoncire",
    "circoncirez": "circoncire",
    "circonciriez": "circoncire",
    "circoncirions": "circoncire",
    "circoncirons": "circoncire",
    "circonciront": "circoncire",
    "circoncis": "circoncire",
    "circoncisaient": "circoncire",
    "circoncisais": "circoncire",
    "circoncisait": "circoncire",
    "circoncisant": "circoncire",
    "circoncise": "circoncire",
    "circoncisent": "circoncire",
    "circoncises": "circoncire",
    "circoncisez": "circoncire",
    "circoncisiez": "circoncire",
    "circoncisions": "circoncision",
    "circoncisons": "circoncire",
    "circoncisse": "circoncire",
    "circoncissent": "circoncire",
    "circoncisses": "circoncire",
    "circoncissiez": "circoncire",
    "circoncissions": "circoncire",
    "circoncit": "circoncire",
    "circoncîmes": "circoncire",
    "circoncît": "circoncire",
    "circoncîtes": "circoncire",
    "circonflexes": "circonflexe",
    "circonférences": "circonférence",
    "circonlocutions": "circonlocution",
    "circonscriptions": "circonscription",
    "circonscriptions-clés": "circonscriptions-clé",
    "circonscrira": "circonscrire",
    "circonscrirai": "circonscrire",
    "circonscriraient": "circonscrire",
    "circonscrirais": "circonscrire",
    "circonscrirait": "circonscrire",
    "circonscriras": "circonscrire",
    "circonscrirez": "circonscrire",
    "circonscririez": "circonscrire",
    "circonscririons": "circonscrire",
    "circonscrirons": "circonscrire",
    "circonscriront": "circonscrire",
    "circonscris": "circonscrire",
    "circonscrit": "circonscrire",
    "circonscrite": "circonscrire",
    "circonscrites": "circonscrire",
    "circonscrits": "circonscrire",
    "circonscrivaient": "circonscrire",
    "circonscrivais": "circonscrire",
    "circonscrivait": "circonscrire",
    "circonscrivant": "circonscrire",
    "circonscrive": "circonscrire",
    "circonscrivent": "circonscrire",
    "circonscrives": "circonscrire",
    "circonscrivez": "circonscrire",
    "circonscriviez": "circonscrire",
    "circonscrivions": "circonscrire",
    "circonscrivirent": "circonscrire",
    "circonscrivis": "circonscrire",
    "circonscrivisse": "circonscrire",
    "circonscrivissent": "circonscrire",
    "circonscrivisses": "circonscrire",
    "circonscrivissiez": "circonscrire",
    "circonscrivissions": "circonscrire",
    "circonscrivit": "circonscrire",
    "circonscrivons": "circonscrire",
    "circonscrivîmes": "circonscrire",
    "circonscrivît": "circonscrire",
    "circonscrivîtes": "circonscrire",
    "circonspecte": "circonspect",
    "circonspectes": "circonspect",
    "circonspections": "circonspection",
    "circonspects": "circonspect",
    "circonstances": "circonstance",
    "circonstancia": "circonstancier",
    "circonstancielle": "circonstanciel",
    "circonstancielles": "circonstanciel",
    "circonstanciels": "circonstanciel",
    "circonstancié": "circonstancier",
    "circonstanciée": "circonstancier",
    "circonstanciées": "circonstancié",
    "circonstanciés": "circonstancié",
    "circonvallations": "circonvallation",
    "circonvenaient": "circonvenir",
    "circonvenais": "circonvenir",
    "circonvenait": "circonvenir",
    "circonvenant": "circonvenir",
    "circonvenez": "circonvenir",
    "circonveniez": "circonvenir",
    "circonvenions": "circonvenir",
    "circonvenons": "circonvenir",
    "circonvenu": "circonvenir",
    "circonvenue": "circonvenir",
    "circonvenues": "circonvenir",
    "circonvenus": "circonvenir",
    "circonviendra": "circonvenir",
    "circonviendrai": "circonvenir",
    "circonviendraient": "circonvenir",
    "circonviendrais": "circonvenir",
    "circonviendrait": "circonvenir",
    "circonviendras": "circonvenir",
    "circonviendrez": "circonvenir",
    "circonviendriez": "circonvenir",
    "circonviendrions": "circonvenir",
    "circonviendrons": "circonvenir",
    "circonviendront": "circonvenir",
    "circonvienne": "circonvenir",
    "circonviennent": "circonvenir",
    "circonviennes": "circonvenir",
    "circonviens": "circonvenir",
    "circonvient": "circonvenir",
    "circonvinrent": "circonvenir",
    "circonvins": "circonvenir",
    "circonvinsse": "circonvenir",
    "circonvinssent": "circonvenir",
    "circonvinsses": "circonvenir",
    "circonvinssiez": "circonvenir",
    "circonvinssions": "circonvenir",
    "circonvint": "circonvenir",
    "circonvoisins": "circonvoisin",
    "circonvolutions": "circonvolution",
    "circonvînmes": "circonvenir",
    "circonvînt": "circonvenir",
    "circonvîntes": "circonvenir",
    "circuits": "circuit",
    "circula": "circuler",
    "circulai": "circuler",
    "circulaient": "circuler",
    "circulaires": "circulaire",
    "circulais": "circuler",
    "circulait": "circuler",
    "circulant": "circuler",
    "circulas": "circuler",
    "circulasse": "circuler",
    "circulassent": "circuler",
    "circulasses": "circuler",
    "circulassiez": "circuler",
    "circulassions": "circuler",
    "circulations": "circulation",
    "circulatoires": "circulatoire",
    "circule": "circuler",
    "circulent": "circuler",
    "circulera": "circuler",
    "circulerai": "circuler",
    "circuleraient": "circuler",
    "circulerais": "circuler",
    "circulerait": "circuler",
    "circuleras": "circuler",
    "circulerez": "circuler",
    "circuleriez": "circuler",
    "circulerions": "circuler",
    "circulerons": "circuler",
    "circuleront": "circuler",
    "circules": "circuler",
    "circulez": "circuler",
    "circuliez": "circuler",
    "circulions": "circuler",
    "circulons": "circuler",
    "circulâmes": "circuler",
    "circulât": "circuler",
    "circulâtes": "circuler",
    "circulèrent": "circuler",
    "circulé": "circuler",
    "circumnavigations": "circumnavigation",
    "circumpolaires": "circumpolaire",
    "cire": "cirer",
    "cirent": "cirer",
    "cirera": "cirer",
    "cirerai": "cirer",
    "cireraient": "cirer",
    "cirerais": "cirer",
    "cirerait": "cirer",
    "cireras": "cirer",
    "cirerez": "cirer",
    "cireriez": "cirer",
    "cirerions": "cirer",
    "cirerons": "cirer",
    "cireront": "cirer",
    "cires": "cirer",
    "cireurs": "cireur",
    "cireuse": "cireux",
    "cireuses": "cireux",
    "cirez": "cirer",
    "ciriez": "cirer",
    "cirions": "cirer",
    "cirons": "ciron",
    "cirques": "cirque",
    "cirrhoses": "cirrhose",
    "cirses": "cirse",
    "cirâmes": "cirer",
    "cirât": "cirer",
    "cirâtes": "cirer",
    "cirèrent": "cirer",
    "ciré": "cirer",
    "cirée": "cirer",
    "cirées": "cirer",
    "cirés": "cirer",
    "cisailla": "cisailler",
    "cisaillai": "cisailler",
    "cisaillaient": "cisailler",
    "cisaillais": "cisailler",
    "cisaillait": "cisailler",
    "cisaillant": "cisailler",
    "cisaillas": "cisailler",
    "cisaillasse": "cisailler",
    "cisaillassent": "cisailler",
    "cisaillasses": "cisailler",
    "cisaillassiez": "cisailler",
    "cisaillassions": "cisailler",
    "cisaille": "cisailler",
    "cisaillent": "cisailler",
    "cisaillera": "cisailler",
    "cisaillerai": "cisailler",
    "cisailleraient": "cisailler",
    "cisaillerais": "cisailler",
    "cisaillerait": "cisailler",
    "cisailleras": "cisailler",
    "cisaillerez": "cisailler",
    "cisailleriez": "cisailler",
    "cisaillerions": "cisailler",
    "cisaillerons": "cisailler",
    "cisailleront": "cisailler",
    "cisailles": "cisailler",
    "cisaillez": "cisailler",
    "cisailliez": "cisailler",
    "cisaillions": "cisailler",
    "cisaillons": "cisailler",
    "cisaillâmes": "cisailler",
    "cisaillât": "cisailler",
    "cisaillâtes": "cisailler",
    "cisaillèrent": "cisailler",
    "cisaillé": "cisailler",
    "cisaillée": "cisailler",
    "cisaillées": "cisailler",
    "cisaillés": "cisailler",
    "cisalpine": "cisalpin",
    "cisalpines": "cisalpin",
    "cisalpins": "cisalpin",
    "ciseaux": "ciseau",
    "cisela": "ciseler",
    "ciselai": "ciseler",
    "ciselaient": "ciseler",
    "ciselais": "ciseler",
    "ciselait": "ciseler",
    "ciselant": "ciseler",
    "ciselas": "ciseler",
    "ciselasse": "ciseler",
    "ciselassent": "ciseler",
    "ciselasses": "ciseler",
    "ciselassiez": "ciseler",
    "ciselassions": "ciseler",
    "ciseleurs": "ciseleur",
    "ciselez": "ciseler",
    "ciseliez": "ciseler",
    "ciselions": "ciseler",
    "ciselons": "ciseler",
    "ciselures": "ciselure",
    "ciselâmes": "ciseler",
    "ciselât": "ciseler",
    "ciselâtes": "ciseler",
    "ciselèrent": "ciseler",
    "ciselé": "ciseler",
    "ciselée": "ciseler",
    "ciselées": "ciseler",
    "ciselés": "ciseler",
    "cistercienne": "cistercien",
    "cisterciennes": "cistercien",
    "cisterciens": "cistercien",
    "cistes": "ciste",
    "cistres": "cistre",
    "cisèle": "ciseler",
    "cisèlent": "ciseler",
    "cisèlera": "ciseler",
    "cisèlerai": "ciseler",
    "cisèleraient": "ciseler",
    "cisèlerais": "ciseler",
    "cisèlerait": "ciseler",
    "cisèleras": "ciseler",
    "cisèlerez": "ciseler",
    "cisèleriez": "ciseler",
    "cisèlerions": "ciseler",
    "cisèlerons": "ciseler",
    "cisèleront": "ciseler",
    "cisèles": "ciseler",
    "cita": "citer",
    "citadelles": "citadelle",
    "citadine": "citadin",
    "citadines": "citadin",
    "citadins": "citadin",
    "citai": "citer",
    "citaient": "citer",
    "citais": "citer",
    "citait": "citer",
    "citant": "citer",
    "citas": "citer",
    "citasse": "citer",
    "citassent": "citer",
    "citasses": "citer",
    "citassiez": "citer",
    "citassions": "citer",
    "citations": "citation",
    "cite": "citer",
    "citent": "citer",
    "citera": "citer",
    "citerai": "citer",
    "citeraient": "citer",
    "citerais": "citer",
    "citerait": "citer",
    "citeras": "citer",
    "citerez": "citer",
    "citeriez": "citer",
    "citerions": "citer",
    "citernes": "citerne",
    "citerons": "citer",
    "citeront": "citer",
    "cites": "citer",
    "citez": "citer",
    "cithares": "cithare",
    "citiez": "citer",
    "citions": "citer",
    "citons": "citer",
    "citoyenne": "citoyen",
    "citoyennes": "citoyen",
    "citoyennetés": "citoyenneté",
    "citoyens": "citoyen",
    "citrates": "citrate",
    "citriques": "citrique",
    "citronnades": "citronnade",
    "citronnelles": "citronnelle",
    "citronnez": "citronner",
    "citronniers": "citronnier",
    "citronnée": "citronner",
    "citrons": "citron",
    "citrouilles": "citrouille",
    "citâmes": "citer",
    "citât": "citer",
    "citâtes": "citer",
    "citèrent": "citer",
    "cité": "citer",
    "citée": "citer",
    "citées": "citer",
    "citérieure": "citérieur",
    "citérieures": "citérieur",
    "citérieurs": "citérieur",
    "cités": "citer",
    "cités-dortoirs": "cité-dortoir",
    "cités-jardins": "cité-jardin",
    "civelles": "civelle",
    "civelots": "civelot",
    "civets": "civet",
    "civettes": "civette",
    "civile": "civil",
    "civiles": "civil",
    "civilisa": "civiliser",
    "civilisai": "civiliser",
    "civilisaient": "civiliser",
    "civilisais": "civiliser",
    "civilisait": "civiliser",
    "civilisant": "civiliser",
    "civilisas": "civiliser",
    "civilisasse": "civiliser",
    "civilisassent": "civiliser",
    "civilisasses": "civiliser",
    "civilisassiez": "civiliser",
    "civilisassions": "civiliser",
    "civilisations": "civilisation",
    "civilisatrice": "civilisateur",
    "civilise": "civiliser",
    "civilisent": "civiliser",
    "civilisera": "civiliser",
    "civiliserai": "civiliser",
    "civiliseraient": "civiliser",
    "civiliserais": "civiliser",
    "civiliserait": "civiliser",
    "civiliseras": "civiliser",
    "civiliserez": "civiliser",
    "civiliseriez": "civiliser",
    "civiliserions": "civiliser",
    "civiliserons": "civiliser",
    "civiliseront": "civiliser",
    "civilises": "civiliser",
    "civilisez": "civiliser",
    "civilisiez": "civiliser",
    "civilisions": "civiliser",
    "civilisons": "civiliser",
    "civilisâmes": "civiliser",
    "civilisât": "civiliser",
    "civilisâtes": "civiliser",
    "civilisèrent": "civiliser",
    "civilisé": "civiliser",
    "civilisée": "civiliser",
    "civilisées": "civiliser",
    "civilisés": "civiliser",
    "civilités": "civilité",
    "civils": "civil",
    "civiques": "civique",
    "civismes": "civisme",
    "civières": "civière",
    "clabauda": "clabauder",
    "clabaudages": "clabaudage",
    "clabaudai": "clabauder",
    "clabaudaient": "clabauder",
    "clabaudais": "clabauder",
    "clabaudait": "clabauder",
    "clabaudant": "clabauder",
    "clabaudas": "clabauder",
    "clabaudasse": "clabauder",
    "clabaudassent": "clabauder",
    "clabaudasses": "clabauder",
    "clabaudassiez": "clabauder",
    "clabaudassions": "clabauder",
    "clabaude": "clabauder",
    "clabaudent": "clabauder",
    "clabaudera": "clabauder",
    "clabauderai": "clabauder",
    "clabauderaient": "clabauder",
    "clabauderais": "clabauder",
    "clabauderait": "clabauder",
    "clabauderas": "clabauder",
    "clabauderez": "clabauder",
    "clabauderies": "clabauderie",
    "clabauderiez": "clabauder",
    "clabauderions": "clabauder",
    "clabauderons": "clabauder",
    "clabauderont": "clabauder",
    "clabaudes": "clabauder",
    "clabaudez": "clabauder",
    "clabaudiez": "clabauder",
    "clabaudions": "clabauder",
    "clabaudons": "clabauder",
    "clabaudâmes": "clabauder",
    "clabaudât": "clabauder",
    "clabaudâtes": "clabauder",
    "clabaudèrent": "clabauder",
    "clabaudé": "clabauder",
    "clabote": "claboter",
    "clabotent": "claboter",
    "claboté": "claboter",
    "claies": "claie",
    "claire": "clair",
    "claires": "claire",
    "claires-voies": "claire-voie",
    "clairets": "clairet",
    "clairette": "clairet",
    "clairettes": "clairet",
    "clairières": "clairière",
    "claironna": "claironner",
    "claironnai": "claironner",
    "claironnaient": "claironner",
    "claironnais": "claironner",
    "claironnait": "claironner",
    "claironnant": "claironner",
    "claironnante": "claironnant",
    "claironnantes": "claironnant",
    "claironnants": "claironnant",
    "claironnas": "claironner",
    "claironnasse": "claironner",
    "claironnassent": "claironner",
    "claironnasses": "claironner",
    "claironnassiez": "claironner",
    "claironnassions": "claironner",
    "claironne": "claironner",
    "claironnent": "claironner",
    "claironnera": "claironner",
    "claironnerai": "claironner",
    "claironneraient": "claironner",
    "claironnerais": "claironner",
    "claironnerait": "claironner",
    "claironneras": "claironner",
    "claironnerez": "claironner",
    "claironneriez": "claironner",
    "claironnerions": "claironner",
    "claironnerons": "claironner",
    "claironneront": "claironner",
    "claironnes": "claironner",
    "claironnez": "claironner",
    "claironniez": "claironner",
    "claironnions": "claironner",
    "claironnons": "claironner",
    "claironnâmes": "claironner",
    "claironnât": "claironner",
    "claironnâtes": "claironner",
    "claironnèrent": "claironner",
    "claironné": "claironner",
    "claironnée": "claironner",
    "claironnées": "claironner",
    "claironnés": "claironner",
    "clairons": "clairon",
    "clairs": "clair",
    "clairs-obscurs": "clair-obscur",
    "clairsemaient": "clairsemer",
    "clairsemait": "clairsemer",
    "clairsemant": "clairsemer",
    "clairsemé": "clairsemer",
    "clairsemée": "clairsemer",
    "clairsemées": "clairsemer",
    "clairsemés": "clairsemer",
    "clairvoyances": "clairvoyance",
    "clairvoyante": "clairvoyant",
    "clairvoyantes": "clairvoyant",
    "clairvoyants": "clairvoyant",
    "clama": "clamer",
    "clamai": "clamer",
    "clamaient": "clamer",
    "clamais": "clamer",
    "clamait": "clamer",
    "clamant": "clamer",
    "clamas": "clamer",
    "clamasse": "clamer",
    "clamassent": "clamer",
    "clamasses": "clamer",
    "clamassiez": "clamer",
    "clamassions": "clamer",
    "clame": "clamer",
    "clamecé": "clamecer",
    "clamecée": "clamecer",
    "clament": "clamer",
    "clamera": "clamer",
    "clamerai": "clamer",
    "clameraient": "clamer",
    "clamerais": "clamer",
    "clamerait": "clamer",
    "clameras": "clamer",
    "clamerez": "clamer",
    "clameriez": "clamer",
    "clamerions": "clamer",
    "clamerons": "clamer",
    "clameront": "clamer",
    "clames": "clamer",
    "clameurs": "clameur",
    "clamez": "clamer",
    "clamiez": "clamer",
    "clamions": "clamer",
    "clamons": "clamer",
    "clampe": "clamper",
    "clampins": "clampin",
    "clamps": "clamp",
    "clampé": "clamper",
    "clams": "clam",
    "clamse": "clamser",
    "clamserai": "clamser",
    "clamserait": "clamser",
    "clamsé": "clamser",
    "clamsée": "clamser",
    "clamsés": "clamser",
    "clamâmes": "clamer",
    "clamât": "clamer",
    "clamâtes": "clamer",
    "clamèrent": "clamer",
    "clamé": "clamer",
    "clamée": "clamer",
    "clamées": "clamer",
    "clamés": "clamer",
    "clandestine": "clandestin",
    "clandestines": "clandestin",
    "clandestinités": "clandestinité",
    "clandestins": "clandestin",
    "clandés": "clandé",
    "clanismes": "clanisme",
    "clans": "clan",
    "clapant": "claper",
    "clape": "claper",
    "clapent": "claper",
    "claperai": "claper",
    "clapes": "claper",
    "clapets": "clapet",
    "clapi": "clapir",
    "clapie": "clapir",
    "clapiers": "clapier",
    "clapies": "clapir",
    "clapira": "clapir",
    "clapirai": "clapir",
    "clapiraient": "clapir",
    "clapirais": "clapir",
    "clapirait": "clapir",
    "clapiras": "clapir",
    "clapirent": "clapir",
    "clapirez": "clapir",
    "clapiriez": "clapir",
    "clapirions": "clapir",
    "clapirons": "clapir",
    "clapiront": "clapir",
    "clapis": "clapir",
    "clapissaient": "clapir",
    "clapissais": "clapir",
    "clapissait": "clapir",
    "clapissant": "clapir",
    "clapisse": "clapir",
    "clapissent": "clapir",
    "clapisses": "clapir",
    "clapissez": "clapir",
    "clapissiez": "clapir",
    "clapissions": "clapir",
    "clapissons": "clapir",
    "clapit": "clapir",
    "clapota": "clapoter",
    "clapotai": "clapoter",
    "clapotaient": "clapoter",
    "clapotais": "clapoter",
    "clapotait": "clapoter",
    "clapotant": "clapoter",
    "clapotante": "clapotant",
    "clapotantes": "clapotant",
    "clapotas": "clapoter",
    "clapotasse": "clapoter",
    "clapotassent": "clapoter",
    "clapotasses": "clapoter",
    "clapotassiez": "clapoter",
    "clapotassions": "clapoter",
    "clapote": "clapoter",
    "clapotements": "clapotement",
    "clapotent": "clapoter",
    "clapotera": "clapoter",
    "clapoterai": "clapoter",
    "clapoteraient": "clapoter",
    "clapoterais": "clapoter",
    "clapoterait": "clapoter",
    "clapoteras": "clapoter",
    "clapoterez": "clapoter",
    "clapoteriez": "clapoter",
    "clapoterions": "clapoter",
    "clapoterons": "clapoter",
    "clapoteront": "clapoter",
    "clapotes": "clapoter",
    "clapotez": "clapoter",
    "clapotiez": "clapoter",
    "clapotions": "clapoter",
    "clapotons": "clapoter",
    "clapotâmes": "clapoter",
    "clapotât": "clapoter",
    "clapotâtes": "clapoter",
    "clapotèrent": "clapoter",
    "clapoté": "clapoter",
    "clappa": "clapper",
    "clappai": "clapper",
    "clappaient": "clapper",
    "clappais": "clapper",
    "clappait": "clapper",
    "clappant": "clapper",
    "clappas": "clapper",
    "clappasse": "clapper",
    "clappassent": "clapper",
    "clappasses": "clapper",
    "clappassiez": "clapper",
    "clappassions": "clapper",
    "clappe": "clapper",
    "clappements": "clappement",
    "clappent": "clapper",
    "clappera": "clapper",
    "clapperai": "clapper",
    "clapperaient": "clapper",
    "clapperais": "clapper",
    "clapperait": "clapper",
    "clapperas": "clapper",
    "clapperez": "clapper",
    "clapperiez": "clapper",
    "clapperions": "clapper",
    "clapperons": "clapper",
    "clapperont": "clapper",
    "clappes": "clapper",
    "clappez": "clapper",
    "clappiez": "clapper",
    "clappions": "clapper",
    "clappons": "clapper",
    "clappâmes": "clapper",
    "clappât": "clapper",
    "clappâtes": "clapper",
    "clappèrent": "clapper",
    "clappé": "clapper",
    "clapé": "claper",
    "clapîmes": "clapir",
    "clapît": "clapir",
    "clapîtes": "clapir",
    "claqua": "claquer",
    "claquai": "claquer",
    "claquaient": "claquer",
    "claquais": "claquer",
    "claquait": "claquer",
    "claquant": "claquer",
    "claquante": "claquant",
    "claquantes": "claquant",
    "claquants": "claquant",
    "claquas": "claquer",
    "claquasse": "claquer",
    "claquassent": "claquer",
    "claquasses": "claquer",
    "claquassiez": "claquer",
    "claquassions": "claquer",
    "claque": "claquer",
    "claquedents": "claquedent",
    "claquements": "claquement",
    "claquemura": "claquemurer",
    "claquemurai": "claquemurer",
    "claquemuraient": "claquemurer",
    "claquemurais": "claquemurer",
    "claquemurait": "claquemurer",
    "claquemurant": "claquemurer",
    "claquemuras": "claquemurer",
    "claquemurasse": "claquemurer",
    "claquemurassent": "claquemurer",
    "claquemurasses": "claquemurer",
    "claquemurassiez": "claquemurer",
    "claquemurassions": "claquemurer",
    "claquemure": "claquemurer",
    "claquemurent": "claquemurer",
    "claquemurera": "claquemurer",
    "claquemurerai": "claquemurer",
    "claquemureraient": "claquemurer",
    "claquemurerais": "claquemurer",
    "claquemurerait": "claquemurer",
    "claquemureras": "claquemurer",
    "claquemurerez": "claquemurer",
    "claquemureriez": "claquemurer",
    "claquemurerions": "claquemurer",
    "claquemurerons": "claquemurer",
    "claquemureront": "claquemurer",
    "claquemures": "claquemurer",
    "claquemurez": "claquemurer",
    "claquemuriez": "claquemurer",
    "claquemurions": "claquemurer",
    "claquemurons": "claquemurer",
    "claquemurâmes": "claquemurer",
    "claquemurât": "claquemurer",
    "claquemurâtes": "claquemurer",
    "claquemurèrent": "claquemurer",
    "claquemuré": "claquemurer",
    "claquemurée": "claquemurer",
    "claquemurées": "claquemurer",
    "claquemurés": "claquemurer",
    "claquent": "claquer",
    "claquera": "claquer",
    "claquerai": "claquer",
    "claqueraient": "claquer",
    "claquerais": "claquer",
    "claquerait": "claquer",
    "claqueras": "claquer",
    "claquerez": "claquer",
    "claqueriez": "claquer",
    "claquerions": "claquer",
    "claquerons": "claquer",
    "claqueront": "claquer",
    "claques": "claquer",
    "claqueta": "claqueter",
    "claquetai": "claqueter",
    "claquetaient": "claqueter",
    "claquetais": "claqueter",
    "claquetait": "claqueter",
    "claquetant": "claqueter",
    "claquetas": "claqueter",
    "claquetasse": "claqueter",
    "claquetassent": "claqueter",
    "claquetasses": "claqueter",
    "claquetassiez": "claqueter",
    "claquetassions": "claqueter",
    "claquetez": "claqueter",
    "claquetiez": "claqueter",
    "claquetions": "claqueter",
    "claquetons": "claqueter",
    "claquette": "claqueter",
    "claquettent": "claqueter",
    "claquettera": "claqueter",
    "claquetterai": "claqueter",
    "claquetteraient": "claqueter",
    "claquetterais": "claqueter",
    "claquetterait": "claqueter",
    "claquetteras": "claqueter",
    "claquetterez": "claqueter",
    "claquetteriez": "claqueter",
    "claquetterions": "claqueter",
    "claquetterons": "claqueter",
    "claquetteront": "claqueter",
    "claquettes": "claquette",
    "claquetâmes": "claqueter",
    "claquetât": "claqueter",
    "claquetâtes": "claqueter",
    "claquetèrent": "claqueter",
    "claqueté": "claqueter",
    "claqueurs": "claqueur",
    "claquez": "claquer",
    "claquiez": "claquer",
    "claquions": "claquer",
    "claquoirs": "claquoir",
    "claquons": "claquer",
    "claquâmes": "claquer",
    "claquât": "claquer",
    "claquâtes": "claquer",
    "claquèrent": "claquer",
    "claqué": "claquer",
    "claquée": "claquer",
    "claquées": "claquer",
    "claqués": "claquer",
    "clarifia": "clarifier",
    "clarifiai": "clarifier",
    "clarifiaient": "clarifier",
    "clarifiais": "clarifier",
    "clarifiait": "clarifier",
    "clarifiant": "clarifier",
    "clarifias": "clarifier",
    "clarifiasse": "clarifier",
    "clarifiassent": "clarifier",
    "clarifiasses": "clarifier",
    "clarifiassiez": "clarifier",
    "clarifiassions": "clarifier",
    "clarifications": "clarification",
    "clarifie": "clarifier",
    "clarifient": "clarifier",
    "clarifiera": "clarifier",
    "clarifierai": "clarifier",
    "clarifieraient": "clarifier",
    "clarifierais": "clarifier",
    "clarifierait": "clarifier",
    "clarifieras": "clarifier",
    "clarifierez": "clarifier",
    "clarifieriez": "clarifier",
    "clarifierions": "clarifier",
    "clarifierons": "clarifier",
    "clarifieront": "clarifier",
    "clarifies": "clarifier",
    "clarifiez": "clarifier",
    "clarifiiez": "clarifier",
    "clarifiions": "clarifier",
    "clarifions": "clarifier",
    "clarifiâmes": "clarifier",
    "clarifiât": "clarifier",
    "clarifiâtes": "clarifier",
    "clarifièrent": "clarifier",
    "clarifié": "clarifier",
    "clarifiée": "clarifier",
    "clarifiées": "clarifier",
    "clarifiés": "clarifier",
    "clarines": "clarine",
    "clarinettes": "clarinette",
    "clarinettistes": "clarinettiste",
    "clarisses": "clarisse",
    "clarissimes": "clarissime",
    "clartés": "clarté",
    "classa": "classer",
    "classai": "classer",
    "classaient": "classer",
    "classais": "classer",
    "classait": "classer",
    "classant": "classer",
    "classas": "classer",
    "classasse": "classer",
    "classassent": "classer",
    "classasses": "classer",
    "classassiez": "classer",
    "classassions": "classer",
    "classe": "classer",
    "classements": "classement",
    "classent": "classer",
    "classera": "classer",
    "classerai": "classer",
    "classeraient": "classer",
    "classerais": "classer",
    "classerait": "classer",
    "classeras": "classer",
    "classerez": "classer",
    "classeriez": "classer",
    "classerions": "classer",
    "classerons": "classer",
    "classeront": "classer",
    "classes": "classer",
    "classeurs": "classeur",
    "classez": "classer",
    "classicismes": "classicisme",
    "classieuse": "classieux",
    "classiez": "classer",
    "classifia": "classifier",
    "classifiables": "classifiable",
    "classifiai": "classifier",
    "classifiaient": "classifier",
    "classifiais": "classifier",
    "classifiait": "classifier",
    "classifiant": "classifier",
    "classifias": "classifier",
    "classifiasse": "classifier",
    "classifiassent": "classifier",
    "classifiasses": "classifier",
    "classifiassiez": "classifier",
    "classifiassions": "classifier",
    "classifications": "classification",
    "classificatrice": "classificateur",
    "classifie": "classifier",
    "classifient": "classifier",
    "classifiera": "classifier",
    "classifierai": "classifier",
    "classifieraient": "classifier",
    "classifierais": "classifier",
    "classifierait": "classifier",
    "classifieras": "classifier",
    "classifierez": "classifier",
    "classifieriez": "classifier",
    "classifierions": "classifier",
    "classifierons": "classifier",
    "classifieront": "classifier",
    "classifies": "classifier",
    "classifiez": "classifier",
    "classifiiez": "classifier",
    "classifiions": "classifier",
    "classifions": "classifier",
    "classifiâmes": "classifier",
    "classifiât": "classifier",
    "classifiâtes": "classifier",
    "classifièrent": "classifier",
    "classifié": "classifier",
    "classifiée": "classifier",
    "classifiées": "classifier",
    "classifiés": "classifier",
    "classions": "classer",
    "classiques": "classique",
    "classons": "classer",
    "classâmes": "classer",
    "classât": "classer",
    "classâtes": "classer",
    "classèrent": "classer",
    "classé": "classer",
    "classée": "classer",
    "classées": "classer",
    "classés": "classer",
    "clastiques": "clastique",
    "clathres": "clathre",
    "claudicante": "claudicant",
    "claudicantes": "claudicant",
    "claudicants": "claudicant",
    "claudications": "claudication",
    "claudiqua": "claudiquer",
    "claudiquai": "claudiquer",
    "claudiquaient": "claudiquer",
    "claudiquais": "claudiquer",
    "claudiquait": "claudiquer",
    "claudiquant": "claudiquer",
    "claudiquas": "claudiquer",
    "claudiquasse": "claudiquer",
    "claudiquassent": "claudiquer",
    "claudiquasses": "claudiquer",
    "claudiquassiez": "claudiquer",
    "claudiquassions": "claudiquer",
    "claudique": "claudiquer",
    "claudiquent": "claudiquer",
    "claudiquera": "claudiquer",
    "claudiquerai": "claudiquer",
    "claudiqueraient": "claudiquer",
    "claudiquerais": "claudiquer",
    "claudiquerait": "claudiquer",
    "claudiqueras": "claudiquer",
    "claudiquerez": "claudiquer",
    "claudiqueriez": "claudiquer",
    "claudiquerions": "claudiquer",
    "claudiquerons": "claudiquer",
    "claudiqueront": "claudiquer",
    "claudiques": "claudiquer",
    "claudiquez": "claudiquer",
    "claudiquiez": "claudiquer",
    "claudiquions": "claudiquer",
    "claudiquons": "claudiquer",
    "claudiquâmes": "claudiquer",
    "claudiquât": "claudiquer",
    "claudiquâtes": "claudiquer",
    "claudiquèrent": "claudiquer",
    "claudiqué": "claudiquer",
    "claudiquée": "claudiquer",
    "claudiquées": "claudiquer",
    "claudiqués": "claudiquer",
    "claudélienne": "claudélien",
    "clauses": "clause",
    "clausewitziens": "clausewitzien",
    "claustra": "claustrer",
    "claustrai": "claustrer",
    "claustraient": "claustrer",
    "claustrais": "claustrer",
    "claustrait": "claustrer",
    "claustrale": "claustral",
    "claustrales": "claustral",
    "claustrant": "claustrer",
    "claustras": "claustrer",
    "claustrasse": "claustrer",
    "claustrassent": "claustrer",
    "claustrasses": "claustrer",
    "claustrassiez": "claustrer",
    "claustrassions": "claustrer",
    "claustraux": "claustral",
    "claustre": "claustrer",
    "claustrent": "claustrer",
    "claustrera": "claustrer",
    "claustrerai": "claustrer",
    "claustreraient": "claustrer",
    "claustrerais": "claustrer",
    "claustrerait": "claustrer",
    "claustreras": "claustrer",
    "claustrerez": "claustrer",
    "claustreriez": "claustrer",
    "claustrerions": "claustrer",
    "claustrerons": "claustrer",
    "claustreront": "claustrer",
    "claustres": "claustrer",
    "claustrez": "claustrer",
    "claustriez": "claustrer",
    "claustrions": "claustrer",
    "claustrons": "claustrer",
    "claustrophobies": "claustrophobie",
    "claustrâmes": "claustrer",
    "claustrât": "claustrer",
    "claustrâtes": "claustrer",
    "claustrèrent": "claustrer",
    "claustré": "claustrer",
    "claustrée": "claustrer",
    "claustrées": "claustrer",
    "claustrés": "claustrer",
    "clavaires": "clavaire",
    "claveaux": "claveau",
    "clavecinistes": "claveciniste",
    "clavecins": "clavecin",
    "clavelées": "clavelée",
    "clavettes": "clavette",
    "clavicules": "clavicule",
    "claviers": "clavier",
    "clayettes": "clayette",
    "clayonnages": "clayonnage",
    "clayonnée": "clayonner",
    "clayons": "clayon",
    "clayères": "clayère",
    "clearings": "clearing",
    "clefs": "clef",
    "clenches": "clenche",
    "clepsydres": "clepsydre",
    "cleptomanes": "cleptomane",
    "cleptomanies": "cleptomanie",
    "clercs": "clerc",
    "clergymen": "clergyman",
    "clergés": "clergé",
    "clermontoise": "clermontois",
    "clicha": "clicher",
    "clichai": "clicher",
    "clichaient": "clicher",
    "clichais": "clicher",
    "clichait": "clicher",
    "clichant": "clicher",
    "clichas": "clicher",
    "clichasse": "clicher",
    "clichassent": "clicher",
    "clichasses": "clicher",
    "clichassiez": "clicher",
    "clichassions": "clicher",
    "cliche": "clicher",
    "clichent": "clicher",
    "clichera": "clicher",
    "clicherai": "clicher",
    "clicheraient": "clicher",
    "clicherais": "clicher",
    "clicherait": "clicher",
    "clicheras": "clicher",
    "clicherez": "clicher",
    "clicheriez": "clicher",
    "clicherions": "clicher",
    "clicherons": "clicher",
    "clicheront": "clicher",
    "cliches": "clicher",
    "clichez": "clicher",
    "clichiez": "clicher",
    "clichions": "clicher",
    "clichons": "clicher",
    "clichâmes": "clicher",
    "clichât": "clicher",
    "clichâtes": "clicher",
    "clichèrent": "clicher",
    "cliché": "clicher",
    "clichée": "clicher",
    "clichées": "clicher",
    "clichés": "clicher",
    "clics": "clic",
    "cliente": "client",
    "clientes": "client",
    "clients": "client",
    "clientèles": "clientèle",
    "clientélismes": "clientélisme",
    "clientélistes": "clientéliste",
    "cligna": "cligner",
    "clignai": "cligner",
    "clignaient": "cligner",
    "clignais": "cligner",
    "clignait": "cligner",
    "clignant": "cligner",
    "clignas": "cligner",
    "clignasse": "cligner",
    "clignassent": "cligner",
    "clignasses": "cligner",
    "clignassiez": "cligner",
    "clignassions": "cligner",
    "cligne": "cligner",
    "clignements": "clignement",
    "clignent": "cligner",
    "clignera": "cligner",
    "clignerai": "cligner",
    "cligneraient": "cligner",
    "clignerais": "cligner",
    "clignerait": "cligner",
    "cligneras": "cligner",
    "clignerez": "cligner",
    "cligneriez": "cligner",
    "clignerions": "cligner",
    "clignerons": "cligner",
    "cligneront": "cligner",
    "clignes": "cligner",
    "clignez": "cligner",
    "cligniez": "cligner",
    "clignions": "cligner",
    "clignons": "cligner",
    "clignota": "clignoter",
    "clignotai": "clignoter",
    "clignotaient": "clignoter",
    "clignotais": "clignoter",
    "clignotait": "clignoter",
    "clignotant": "clignoter",
    "clignotante": "clignotant",
    "clignotantes": "clignotant",
    "clignotants": "clignotant",
    "clignotas": "clignoter",
    "clignotasse": "clignoter",
    "clignotassent": "clignoter",
    "clignotasses": "clignoter",
    "clignotassiez": "clignoter",
    "clignotassions": "clignoter",
    "clignote": "clignoter",
    "clignotements": "clignotement",
    "clignotent": "clignoter",
    "clignotera": "clignoter",
    "clignoterai": "clignoter",
    "clignoteraient": "clignoter",
    "clignoterais": "clignoter",
    "clignoterait": "clignoter",
    "clignoteras": "clignoter",
    "clignoterez": "clignoter",
    "clignoteriez": "clignoter",
    "clignoterions": "clignoter",
    "clignoterons": "clignoter",
    "clignoteront": "clignoter",
    "clignotes": "clignoter",
    "clignotez": "clignoter",
    "clignotiez": "clignoter",
    "clignotions": "clignoter",
    "clignotons": "clignoter",
    "clignotâmes": "clignoter",
    "clignotât": "clignoter",
    "clignotâtes": "clignoter",
    "clignotèrent": "clignoter",
    "clignoté": "clignoter",
    "clignâmes": "cligner",
    "clignât": "cligner",
    "clignâtes": "cligner",
    "clignèrent": "cligner",
    "cligné": "cligner",
    "clignée": "cligner",
    "clignées": "cligner",
    "clignés": "cligner",
    "clilles": "clille",
    "climatiques": "climatique",
    "climatisa": "climatiser",
    "climatisai": "climatiser",
    "climatisaient": "climatiser",
    "climatisais": "climatiser",
    "climatisait": "climatiser",
    "climatisant": "climatiser",
    "climatisas": "climatiser",
    "climatisasse": "climatiser",
    "climatisassent": "climatiser",
    "climatisasses": "climatiser",
    "climatisassiez": "climatiser",
    "climatisassions": "climatiser",
    "climatisations": "climatisation",
    "climatise": "climatiser",
    "climatisent": "climatiser",
    "climatisera": "climatiser",
    "climatiserai": "climatiser",
    "climatiseraient": "climatiser",
    "climatiserais": "climatiser",
    "climatiserait": "climatiser",
    "climatiseras": "climatiser",
    "climatiserez": "climatiser",
    "climatiseriez": "climatiser",
    "climatiserions": "climatiser",
    "climatiserons": "climatiser",
    "climatiseront": "climatiser",
    "climatises": "climatiser",
    "climatiseurs": "climatiseur",
    "climatisez": "climatiser",
    "climatisiez": "climatiser",
    "climatisions": "climatiser",
    "climatisons": "climatiser",
    "climatisâmes": "climatiser",
    "climatisât": "climatiser",
    "climatisâtes": "climatiser",
    "climatisèrent": "climatiser",
    "climatisé": "climatiser",
    "climatisée": "climatiser",
    "climatisées": "climatiser",
    "climatisés": "climatiser",
    "climats": "climat",
    "climatériques": "climatérique",
    "clinfocs": "clinfoc",
    "clinicats": "clinicat",
    "clinicienne": "clinicien",
    "cliniciennes": "clinicien",
    "cliniciens": "clinicien",
    "cliniques": "clinique",
    "clinquante": "clinquant",
    "clinquantes": "clinquant",
    "clinquants": "clinquant",
    "clins": "clin",
    "clippers": "clipper",
    "clips": "clip",
    "cliquant": "cliquer",
    "cliques": "clique",
    "cliqueta": "cliqueter",
    "cliquetai": "cliqueter",
    "cliquetaient": "cliqueter",
    "cliquetais": "cliqueter",
    "cliquetait": "cliqueter",
    "cliquetant": "cliqueter",
    "cliquetante": "cliquetant",
    "cliquetantes": "cliquetant",
    "cliquetants": "cliquetant",
    "cliquetas": "cliqueter",
    "cliquetasse": "cliqueter",
    "cliquetassent": "cliqueter",
    "cliquetasses": "cliqueter",
    "cliquetassiez": "cliqueter",
    "cliquetassions": "cliqueter",
    "cliquetez": "cliqueter",
    "cliquetiez": "cliqueter",
    "cliquetions": "cliqueter",
    "cliquetons": "cliqueter",
    "cliquets": "cliquet",
    "cliquette": "cliqueter",
    "cliquettements": "cliquettement",
    "cliquettent": "cliqueter",
    "cliquettera": "cliqueter",
    "cliquetterai": "cliqueter",
    "cliquetteraient": "cliqueter",
    "cliquetterais": "cliqueter",
    "cliquetterait": "cliqueter",
    "cliquetteras": "cliqueter",
    "cliquetterez": "cliqueter",
    "cliquetteriez": "cliqueter",
    "cliquetterions": "cliqueter",
    "cliquetterons": "cliqueter",
    "cliquetteront": "cliqueter",
    "cliquettes": "cliquette",
    "cliquetâmes": "cliqueter",
    "cliquetât": "cliqueter",
    "cliquetâtes": "cliqueter",
    "cliquetèrent": "cliqueter",
    "cliqueté": "cliqueter",
    "cliquez": "cliquer",
    "cliquètements": "cliquètement",
    "cliqué": "cliquer",
    "clisses": "clisse",
    "clissées": "clisser",
    "clitoridienne": "clitoridien",
    "cliva": "cliver",
    "clivages": "clivage",
    "clivai": "cliver",
    "clivaient": "cliver",
    "clivais": "cliver",
    "clivait": "cliver",
    "clivant": "cliver",
    "clivas": "cliver",
    "clivasse": "cliver",
    "clivassent": "cliver",
    "clivasses": "cliver",
    "clivassiez": "cliver",
    "clivassions": "cliver",
    "clive": "cliver",
    "clivent": "cliver",
    "clivera": "cliver",
    "cliverai": "cliver",
    "cliveraient": "cliver",
    "cliverais": "cliver",
    "cliverait": "cliver",
    "cliveras": "cliver",
    "cliverez": "cliver",
    "cliveriez": "cliver",
    "cliverions": "cliver",
    "cliverons": "cliver",
    "cliveront": "cliver",
    "clives": "cliver",
    "clivez": "cliver",
    "cliviez": "cliver",
    "clivions": "cliver",
    "clivons": "cliver",
    "clivâmes": "cliver",
    "clivât": "cliver",
    "clivâtes": "cliver",
    "clivèrent": "cliver",
    "clivé": "cliver",
    "clivée": "cliver",
    "clivées": "cliver",
    "clivés": "cliver",
    "cloacale": "cloacal",
    "cloacales": "cloacal",
    "cloacaux": "cloacal",
    "cloaques": "cloaque",
    "clocha": "clocher",
    "clochai": "clocher",
    "clochaient": "clocher",
    "clochais": "clocher",
    "clochait": "clocher",
    "clochant": "clocher",
    "clocharde": "clochard",
    "clochardes": "clochard",
    "clochardisait": "clochardiser",
    "clochardisé": "clochardiser",
    "clochards": "clochard",
    "clochas": "clocher",
    "clochasse": "clocher",
    "clochassent": "clocher",
    "clochasses": "clocher",
    "clochassiez": "clocher",
    "clochassions": "clocher",
    "cloche": "clocher",
    "clochent": "clocher",
    "clochera": "clocher",
    "clocherai": "clocher",
    "clocheraient": "clocher",
    "clocherais": "clocher",
    "clocherait": "clocher",
    "clocheras": "clocher",
    "clocherez": "clocher",
    "clocheriez": "clocher",
    "clocherions": "clocher",
    "clocherons": "clocher",
    "clocheront": "clocher",
    "clochers": "clocher",
    "cloches": "clocher",
    "clochetons": "clocheton",
    "clochettes": "clochette",
    "clochez": "clocher",
    "clochiez": "clocher",
    "clochions": "clocher",
    "clochons": "clocher",
    "clochâmes": "clocher",
    "clochât": "clocher",
    "clochâtes": "clocher",
    "clochèrent": "clocher",
    "cloché": "clocher",
    "clodos": "clodo",
    "cloisonna": "cloisonner",
    "cloisonnai": "cloisonner",
    "cloisonnaient": "cloisonner",
    "cloisonnais": "cloisonner",
    "cloisonnait": "cloisonner",
    "cloisonnant": "cloisonner",
    "cloisonnas": "cloisonner",
    "cloisonnasse": "cloisonner",
    "cloisonnassent": "cloisonner",
    "cloisonnasses": "cloisonner",
    "cloisonnassiez": "cloisonner",
    "cloisonnassions": "cloisonner",
    "cloisonne": "cloisonner",
    "cloisonnements": "cloisonnement",
    "cloisonnent": "cloisonner",
    "cloisonnera": "cloisonner",
    "cloisonnerai": "cloisonner",
    "cloisonneraient": "cloisonner",
    "cloisonnerais": "cloisonner",
    "cloisonnerait": "cloisonner",
    "cloisonneras": "cloisonner",
    "cloisonnerez": "cloisonner",
    "cloisonneriez": "cloisonner",
    "cloisonnerions": "cloisonner",
    "cloisonnerons": "cloisonner",
    "cloisonneront": "cloisonner",
    "cloisonnes": "cloisonner",
    "cloisonnez": "cloisonner",
    "cloisonniez": "cloisonner",
    "cloisonnions": "cloisonner",
    "cloisonnons": "cloisonner",
    "cloisonnâmes": "cloisonner",
    "cloisonnât": "cloisonner",
    "cloisonnâtes": "cloisonner",
    "cloisonnèrent": "cloisonner",
    "cloisonné": "cloisonner",
    "cloisonnée": "cloisonner",
    "cloisonnées": "cloisonner",
    "cloisonnés": "cloisonner",
    "cloisons": "cloison",
    "clonant": "cloner",
    "clone": "cloner",
    "clonent": "cloner",
    "clones": "clone",
    "cloné": "cloner",
    "clonés": "cloner",
    "clopais": "cloper",
    "clopant": "cloper",
    "clope": "cloper",
    "clopes": "cloper",
    "clopina": "clopiner",
    "clopinai": "clopiner",
    "clopinaient": "clopiner",
    "clopinais": "clopiner",
    "clopinait": "clopiner",
    "clopinant": "clopiner",
    "clopinante": "clopinant",
    "clopinantes": "clopinant",
    "clopinants": "clopinant",
    "clopinas": "clopiner",
    "clopinasse": "clopiner",
    "clopinassent": "clopiner",
    "clopinasses": "clopiner",
    "clopinassiez": "clopiner",
    "clopinassions": "clopiner",
    "clopine": "clopiner",
    "clopinements": "clopinement",
    "clopinent": "clopiner",
    "clopinera": "clopiner",
    "clopinerai": "clopiner",
    "clopineraient": "clopiner",
    "clopinerais": "clopiner",
    "clopinerait": "clopiner",
    "clopineras": "clopiner",
    "clopinerez": "clopiner",
    "clopineriez": "clopiner",
    "clopinerions": "clopiner",
    "clopinerons": "clopiner",
    "clopineront": "clopiner",
    "clopines": "clopiner",
    "clopinez": "clopiner",
    "clopiniez": "clopiner",
    "clopinions": "clopiner",
    "clopinons": "clopiner",
    "clopinâmes": "clopiner",
    "clopinât": "clopiner",
    "clopinâtes": "clopiner",
    "clopinèrent": "clopiner",
    "clopiné": "clopiner",
    "cloportes": "cloporte",
    "cloquait": "cloquer",
    "cloquant": "cloquer",
    "cloque": "cloquer",
    "cloquent": "cloquer",
    "cloques": "cloque",
    "cloqué": "cloquer",
    "cloquée": "cloquer",
    "cloquées": "cloquer",
    "cloqués": "cloquer",
    "clora": "clore",
    "clorai": "clore",
    "cloraient": "clore",
    "clorais": "clore",
    "clorait": "clore",
    "cloras": "clore",
    "clorez": "clore",
    "cloriez": "clore",
    "clorions": "clore",
    "clorons": "clore",
    "cloront": "clore",
    "clos": "clore",
    "closant": "clore",
    "close": "clos",
    "close-combats": "close-combat",
    "closeaux": "closeau",
    "closent": "clore",
    "closes": "clos",
    "closiez": "clore",
    "closions": "clore",
    "clotûra": "clotûrer",
    "clotûrai": "clotûrer",
    "clotûraient": "clotûrer",
    "clotûrais": "clotûrer",
    "clotûrait": "clotûrer",
    "clotûrant": "clotûrer",
    "clotûras": "clotûrer",
    "clotûrasse": "clotûrer",
    "clotûrassent": "clotûrer",
    "clotûrasses": "clotûrer",
    "clotûrassiez": "clotûrer",
    "clotûrassions": "clotûrer",
    "clotûre": "clotûrer",
    "clotûrent": "clotûrer",
    "clotûrera": "clotûrer",
    "clotûrerai": "clotûrer",
    "clotûreraient": "clotûrer",
    "clotûrerais": "clotûrer",
    "clotûrerait": "clotûrer",
    "clotûreras": "clotûrer",
    "clotûrerez": "clotûrer",
    "clotûreriez": "clotûrer",
    "clotûrerions": "clotûrer",
    "clotûrerons": "clotûrer",
    "clotûreront": "clotûrer",
    "clotûres": "clotûrer",
    "clotûrez": "clotûrer",
    "clotûriez": "clotûrer",
    "clotûrions": "clotûrer",
    "clotûrons": "clotûrer",
    "clotûrâmes": "clotûrer",
    "clotûrât": "clotûrer",
    "clotûrâtes": "clotûrer",
    "clotûrèrent": "clotûrer",
    "clotûré": "clotûrer",
    "clotûrée": "clotûrer",
    "clotûrées": "clotûrer",
    "clotûrés": "clotûrer",
    "cloua": "clouer",
    "clouai": "clouer",
    "clouaient": "clouer",
    "clouais": "clouer",
    "clouait": "clouer",
    "clouant": "clouer",
    "clouas": "clouer",
    "clouasse": "clouer",
    "clouassent": "clouer",
    "clouasses": "clouer",
    "clouassiez": "clouer",
    "clouassions": "clouer",
    "cloue": "clouer",
    "clouent": "clouer",
    "clouera": "clouer",
    "clouerai": "clouer",
    "cloueraient": "clouer",
    "clouerais": "clouer",
    "clouerait": "clouer",
    "cloueras": "clouer",
    "clouerez": "clouer",
    "cloueriez": "clouer",
    "clouerions": "clouer",
    "clouerons": "clouer",
    "cloueront": "clouer",
    "cloues": "clouer",
    "cloueuse": "cloueur",
    "clouez": "clouer",
    "clouiez": "clouer",
    "clouions": "clouer",
    "clouons": "clouer",
    "clous": "clou",
    "clouta": "clouter",
    "cloutai": "clouter",
    "cloutaient": "clouter",
    "cloutais": "clouter",
    "cloutait": "clouter",
    "cloutant": "clouter",
    "cloutas": "clouter",
    "cloutasse": "clouter",
    "cloutassent": "clouter",
    "cloutasses": "clouter",
    "cloutassiez": "clouter",
    "cloutassions": "clouter",
    "cloute": "clouter",
    "cloutent": "clouter",
    "cloutera": "clouter",
    "clouterai": "clouter",
    "clouteraient": "clouter",
    "clouterais": "clouter",
    "clouterait": "clouter",
    "clouteras": "clouter",
    "clouterez": "clouter",
    "clouteriez": "clouter",
    "clouterions": "clouter",
    "clouterons": "clouter",
    "clouteront": "clouter",
    "cloutes": "clouter",
    "cloutez": "clouter",
    "cloutiez": "clouter",
    "cloutions": "clouter",
    "cloutons": "clouter",
    "cloutâmes": "clouter",
    "cloutât": "clouter",
    "cloutâtes": "clouter",
    "cloutèrent": "clouter",
    "clouté": "clouter",
    "cloutée": "clouter",
    "cloutées": "clouter",
    "cloutés": "clouter",
    "clouâmes": "clouer",
    "clouât": "clouer",
    "clouâtes": "clouer",
    "clouèrent": "clouer",
    "cloué": "clouer",
    "clouée": "clouer",
    "clouées": "clouer",
    "cloués": "clouer",
    "clovisses": "clovisse",
    "clowneries": "clownerie",
    "clownesques": "clownesque",
    "clownesse": "clown",
    "clownesses": "clown",
    "clowns": "clown",
    "cloyères": "cloyère",
    "cloîtra": "cloîtrer",
    "cloîtrai": "cloîtrer",
    "cloîtraient": "cloîtrer",
    "cloîtrais": "cloîtrer",
    "cloîtrait": "cloîtrer",
    "cloîtrant": "cloîtrer",
    "cloîtras": "cloîtrer",
    "cloîtrasse": "cloîtrer",
    "cloîtrassent": "cloîtrer",
    "cloîtrasses": "cloîtrer",
    "cloîtrassiez": "cloîtrer",
    "cloîtrassions": "cloîtrer",
    "cloître": "cloîtrer",
    "cloîtrent": "cloîtrer",
    "cloîtrera": "cloîtrer",
    "cloîtrerai": "cloîtrer",
    "cloîtreraient": "cloîtrer",
    "cloîtrerais": "cloîtrer",
    "cloîtrerait": "cloîtrer",
    "cloîtreras": "cloîtrer",
    "cloîtrerez": "cloîtrer",
    "cloîtreriez": "cloîtrer",
    "cloîtrerions": "cloîtrer",
    "cloîtrerons": "cloîtrer",
    "cloîtreront": "cloîtrer",
    "cloîtres": "cloîtrer",
    "cloîtrez": "cloîtrer",
    "cloîtriez": "cloîtrer",
    "cloîtrions": "cloîtrer",
    "cloîtrons": "cloîtrer",
    "cloîtrâmes": "cloîtrer",
    "cloîtrât": "cloîtrer",
    "cloîtrâtes": "cloîtrer",
    "cloîtrèrent": "cloîtrer",
    "cloîtré": "cloîtrer",
    "cloîtrée": "cloîtrer",
    "cloîtrées": "cloîtrer",
    "cloîtrés": "cloîtrer",
    "clubs": "club",
    "cluses": "cluse",
    "clystères": "clystère",
    "clébards": "clébard",
    "clématites": "clématite",
    "clémences": "clémence",
    "clémente": "clément",
    "clémentes": "clément",
    "cléments": "clément",
    "cléricale": "clérical",
    "cléricales": "clérical",
    "cléricaux": "clérical",
    "clés": "clé",
    "clôt": "clore",
    "clôtura": "clôturer",
    "clôturai": "clôturer",
    "clôturaient": "clôturer",
    "clôturais": "clôturer",
    "clôturait": "clôturer",
    "clôturant": "clôturer",
    "clôturas": "clôturer",
    "clôturasse": "clôturer",
    "clôturassent": "clôturer",
    "clôturasses": "clôturer",
    "clôturassiez": "clôturer",
    "clôturassions": "clôturer",
    "clôture": "clôturer",
    "clôturent": "clôturer",
    "clôturera": "clôturer",
    "clôturerai": "clôturer",
    "clôtureraient": "clôturer",
    "clôturerais": "clôturer",
    "clôturerait": "clôturer",
    "clôtureras": "clôturer",
    "clôturerez": "clôturer",
    "clôtureriez": "clôturer",
    "clôturerions": "clôturer",
    "clôturerons": "clôturer",
    "clôtureront": "clôturer",
    "clôtures": "clôturer",
    "clôturez": "clôturer",
    "clôturiez": "clôturer",
    "clôturions": "clôturer",
    "clôturons": "clôturer",
    "clôturâmes": "clôturer",
    "clôturât": "clôturer",
    "clôturâtes": "clôturer",
    "clôturèrent": "clôturer",
    "clôturé": "clôturer",
    "clôturée": "clôturer",
    "clôturées": "clôturer",
    "clôturés": "clôturer",
    "co-auteurs": "co-auteur",
    "co-dépendante": "co-dépendant",
    "co-pilotes": "co-pilote",
    "co-productions": "co-production",
    "co-proprios": "co-proprio",
    "co-propriétaires": "co-propriétaire",
    "co-signons": "cosigner",
    "co-éducative": "co-éducatif",
    "co-équipière": "coéquipier",
    "coaccusée": "coaccusé",
    "coaccusées": "coaccusé",
    "coaccusés": "coaccusé",
    "coache": "coacher",
    "coaches": "coache",
    "coachs": "coach",
    "coaché": "coacher",
    "coacquéreurs": "coacquéreur",
    "coactionnaires": "coactionnaire",
    "coadjuteurs": "coadjuteur",
    "coagula": "coaguler",
    "coagulai": "coaguler",
    "coagulaient": "coaguler",
    "coagulais": "coaguler",
    "coagulait": "coaguler",
    "coagulant": "coaguler",
    "coagulantes": "coagulant",
    "coagulants": "coagulant",
    "coagulas": "coaguler",
    "coagulasse": "coaguler",
    "coagulassent": "coaguler",
    "coagulasses": "coaguler",
    "coagulassiez": "coaguler",
    "coagulassions": "coaguler",
    "coagule": "coaguler",
    "coagulent": "coaguler",
    "coagulera": "coaguler",
    "coagulerai": "coaguler",
    "coaguleraient": "coaguler",
    "coagulerais": "coaguler",
    "coagulerait": "coaguler",
    "coaguleras": "coaguler",
    "coagulerez": "coaguler",
    "coaguleriez": "coaguler",
    "coagulerions": "coaguler",
    "coagulerons": "coaguler",
    "coaguleront": "coaguler",
    "coagules": "coaguler",
    "coagulez": "coaguler",
    "coaguliez": "coaguler",
    "coagulions": "coaguler",
    "coagulons": "coaguler",
    "coagulâmes": "coaguler",
    "coagulât": "coaguler",
    "coagulâtes": "coaguler",
    "coagulèrent": "coaguler",
    "coagulé": "coaguler",
    "coagulée": "coaguler",
    "coagulées": "coaguler",
    "coagulés": "coaguler",
    "coalisa": "coaliser",
    "coalisai": "coaliser",
    "coalisaient": "coaliser",
    "coalisais": "coaliser",
    "coalisait": "coaliser",
    "coalisant": "coaliser",
    "coalisas": "coaliser",
    "coalisasse": "coaliser",
    "coalisassent": "coaliser",
    "coalisasses": "coaliser",
    "coalisassiez": "coaliser",
    "coalisassions": "coaliser",
    "coalise": "coaliser",
    "coalisent": "coaliser",
    "coalisera": "coaliser",
    "coaliserai": "coaliser",
    "coaliseraient": "coaliser",
    "coaliserais": "coaliser",
    "coaliserait": "coaliser",
    "coaliseras": "coaliser",
    "coaliserez": "coaliser",
    "coaliseriez": "coaliser",
    "coaliserions": "coaliser",
    "coaliserons": "coaliser",
    "coaliseront": "coaliser",
    "coalises": "coaliser",
    "coalisez": "coaliser",
    "coalisiez": "coaliser",
    "coalisions": "coaliser",
    "coalisons": "coaliser",
    "coalisâmes": "coaliser",
    "coalisât": "coaliser",
    "coalisâtes": "coaliser",
    "coalisèrent": "coaliser",
    "coalisé": "coaliser",
    "coalisée": "coaliser",
    "coalisées": "coaliser",
    "coalisés": "coaliser",
    "coalitions": "coalition",
    "coaltars": "coaltar",
    "coassa": "coasser",
    "coassai": "coasser",
    "coassaient": "coasser",
    "coassais": "coasser",
    "coassait": "coasser",
    "coassant": "coasser",
    "coassas": "coasser",
    "coassasse": "coasser",
    "coassassent": "coasser",
    "coassasses": "coasser",
    "coassassiez": "coasser",
    "coassassions": "coasser",
    "coasse": "coasser",
    "coassements": "coassement",
    "coassent": "coasser",
    "coassera": "coasser",
    "coasserai": "coasser",
    "coasseraient": "coasser",
    "coasserais": "coasser",
    "coasserait": "coasser",
    "coasseras": "coasser",
    "coasserez": "coasser",
    "coasseriez": "coasser",
    "coasserions": "coasser",
    "coasserons": "coasser",
    "coasseront": "coasser",
    "coasses": "coasser",
    "coassez": "coasser",
    "coassiez": "coasser",
    "coassions": "coasser",
    "coassons": "coasser",
    "coassâmes": "coasser",
    "coassât": "coasser",
    "coassâtes": "coasser",
    "coassèrent": "coasser",
    "coassé": "coasser",
    "coauteurs": "coauteur",
    "coaxiale": "coaxial",
    "coaxiales": "coaxial",
    "coaxiaux": "coaxial",
    "cobalts": "cobalt",
    "cobayes": "cobaye",
    "cobelligérants": "cobelligérant",
    "cobras": "cobra",
    "cobéas": "cobéa",
    "cocagnes": "cocagne",
    "cocardasse": "cocarder",
    "cocardes": "cocarde",
    "cocardiers": "cocardier",
    "cocardière": "cocardier",
    "cocardières": "cocardier",
    "cocards": "cocard",
    "cocardés": "cocarder",
    "cocas": "coca",
    "cocasses": "cocasse",
    "cocaïnes": "cocaïne",
    "coccinelles": "coccinelle",
    "cocha": "cocher",
    "cochai": "cocher",
    "cochaient": "cocher",
    "cochais": "cocher",
    "cochait": "cocher",
    "cochant": "cocher",
    "cochas": "cocher",
    "cochasse": "cocher",
    "cochassent": "cocher",
    "cochasses": "cocher",
    "cochassiez": "cocher",
    "cochassions": "cocher",
    "coche": "cocher",
    "cochenilles": "cochenille",
    "cochent": "cocher",
    "cochera": "cocher",
    "cocherai": "cocher",
    "cocheraient": "cocher",
    "cocherais": "cocher",
    "cocherait": "cocher",
    "cocheras": "cocher",
    "cocherez": "cocher",
    "cocheriez": "cocher",
    "cocherions": "cocher",
    "cocherons": "cocher",
    "cocheront": "cocher",
    "cochers": "cocher",
    "coches": "cocher",
    "cochets": "cochet",
    "cochez": "cocher",
    "cochiez": "cocher",
    "cochions": "cocher",
    "cochléaires": "cochléaire",
    "cochléarias": "cochléaria",
    "cochoncetés": "cochonceté",
    "cochonna": "cochonner",
    "cochonnai": "cochonner",
    "cochonnaient": "cochonner",
    "cochonnailles": "cochonnaille",
    "cochonnais": "cochonner",
    "cochonnait": "cochonner",
    "cochonnant": "cochonner",
    "cochonnas": "cochonner",
    "cochonnasse": "cochonner",
    "cochonnassent": "cochonner",
    "cochonnasses": "cochonner",
    "cochonnassiez": "cochonner",
    "cochonnassions": "cochonner",
    "cochonne": "cochonner",
    "cochonnent": "cochonner",
    "cochonnera": "cochonner",
    "cochonnerai": "cochonner",
    "cochonneraient": "cochonner",
    "cochonnerais": "cochonner",
    "cochonnerait": "cochonner",
    "cochonneras": "cochonner",
    "cochonnerez": "cochonner",
    "cochonneries": "cochonnerie",
    "cochonneriez": "cochonner",
    "cochonnerions": "cochonner",
    "cochonnerons": "cochonner",
    "cochonneront": "cochonner",
    "cochonnes": "cochonner",
    "cochonnets": "cochonnet",
    "cochonnez": "cochonner",
    "cochonniez": "cochonner",
    "cochonnions": "cochonner",
    "cochonnons": "cochonner",
    "cochonnâmes": "cochonner",
    "cochonnât": "cochonner",
    "cochonnâtes": "cochonner",
    "cochonnèrent": "cochonner",
    "cochonné": "cochonner",
    "cochonnée": "cochonner",
    "cochonnées": "cochonner",
    "cochonnés": "cochonner",
    "cochons": "cochon",
    "cochâmes": "cocher",
    "cochât": "cocher",
    "cochâtes": "cocher",
    "cochère": "cocher",
    "cochèrent": "cocher",
    "cochères": "cochère",
    "coché": "cocher",
    "cochée": "cocher",
    "cochées": "cocher",
    "cochés": "cocher",
    "cockers": "cocker",
    "cockneys": "cockney",
    "cockpits": "cockpit",
    "cocktails": "cocktail",
    "cocolait": "cocoler",
    "cocole": "cocoler",
    "cocons": "cocon",
    "cocoonings": "cocooning",
    "cocoricos": "cocorico",
    "cocos": "coco",
    "cocotent": "cocoter",
    "cocoteraies": "cocoteraie",
    "cocoterait": "cocoter",
    "cocotiers": "cocotier",
    "cocotte": "cocotter",
    "cocottes": "cocotte",
    "cocottes-minute": "cocotte-minute",
    "cocuages": "cocuage",
    "cocue": "cocu",
    "cocues": "cocu",
    "cocufiant": "cocufier",
    "cocufie": "cocufier",
    "cocufiera": "cocufier",
    "cocufié": "cocufier",
    "cocus": "cocu",
    "coda": "coder",
    "codages": "codage",
    "codai": "coder",
    "codaient": "coder",
    "codais": "coder",
    "codait": "coder",
    "codant": "coder",
    "codante": "codant",
    "codas": "coder",
    "codasse": "coder",
    "codassent": "coder",
    "codasses": "coder",
    "codassiez": "coder",
    "codassions": "coder",
    "code": "coder",
    "codent": "coder",
    "codera": "coder",
    "coderai": "coder",
    "coderaient": "coder",
    "coderais": "coder",
    "coderait": "coder",
    "coderas": "coder",
    "coderez": "coder",
    "coderiez": "coder",
    "coderions": "coder",
    "coderons": "coder",
    "coderont": "coder",
    "codes": "coder",
    "codes-clés": "codes-clé",
    "codez": "coder",
    "codicilles": "codicille",
    "codiez": "coder",
    "codifia": "codifier",
    "codifiai": "codifier",
    "codifiaient": "codifier",
    "codifiais": "codifier",
    "codifiait": "codifier",
    "codifiant": "codifier",
    "codifias": "codifier",
    "codifiasse": "codifier",
    "codifiassent": "codifier",
    "codifiasses": "codifier",
    "codifiassiez": "codifier",
    "codifiassions": "codifier",
    "codifications": "codification",
    "codifie": "codifier",
    "codifient": "codifier",
    "codifiera": "codifier",
    "codifierai": "codifier",
    "codifieraient": "codifier",
    "codifierais": "codifier",
    "codifierait": "codifier",
    "codifieras": "codifier",
    "codifierez": "codifier",
    "codifieriez": "codifier",
    "codifierions": "codifier",
    "codifierons": "codifier",
    "codifieront": "codifier",
    "codifies": "codifier",
    "codifiez": "codifier",
    "codifiiez": "codifier",
    "codifiions": "codifier",
    "codifions": "codifier",
    "codifiâmes": "codifier",
    "codifiât": "codifier",
    "codifiâtes": "codifier",
    "codifièrent": "codifier",
    "codifié": "codifier",
    "codifiée": "codifier",
    "codifiées": "codifier",
    "codifiés": "codifier",
    "codions": "coder",
    "codirecteurs": "codirecteur",
    "codirectrice": "codirecteur",
    "codirectrices": "codirecteur",
    "codons": "coder",
    "codâmes": "coder",
    "codât": "coder",
    "codâtes": "coder",
    "codèrent": "coder",
    "codé": "coder",
    "codécisions": "codécision",
    "codée": "coder",
    "codées": "coder",
    "codéines": "codéine",
    "codés": "coder",
    "codétenue": "codétenu",
    "codétenues": "codétenu",
    "codétenus": "codétenu",
    "coefficients": "coefficient",
    "coelentérés": "coelentéré",
    "coercitifs": "coercitif",
    "coercitions": "coercition",
    "coercitive": "coercitif",
    "coercitives": "coercitif",
    "coeur-poumons": "coeur-poumon",
    "coeurs": "coeur",
    "coeurs-de-pigeon": "coeur-de-pigeon",
    "coexista": "coexister",
    "coexistai": "coexister",
    "coexistaient": "coexister",
    "coexistais": "coexister",
    "coexistait": "coexister",
    "coexistant": "coexister",
    "coexistants": "coexistant",
    "coexistas": "coexister",
    "coexistasse": "coexister",
    "coexistassent": "coexister",
    "coexistasses": "coexister",
    "coexistassiez": "coexister",
    "coexistassions": "coexister",
    "coexiste": "coexister",
    "coexistences": "coexistence",
    "coexistent": "coexister",
    "coexistera": "coexister",
    "coexisterai": "coexister",
    "coexisteraient": "coexister",
    "coexisterais": "coexister",
    "coexisterait": "coexister",
    "coexisteras": "coexister",
    "coexisterez": "coexister",
    "coexisteriez": "coexister",
    "coexisterions": "coexister",
    "coexisterons": "coexister",
    "coexisteront": "coexister",
    "coexistes": "coexister",
    "coexistez": "coexister",
    "coexistiez": "coexister",
    "coexistions": "coexister",
    "coexistons": "coexister",
    "coexistâmes": "coexister",
    "coexistât": "coexister",
    "coexistâtes": "coexister",
    "coexistèrent": "coexister",
    "coexisté": "coexister",
    "coffins": "coffin",
    "coffios": "coffio",
    "coffiots": "coffiot",
    "coffrages": "coffrage",
    "coffraient": "coffrer",
    "coffrait": "coffrer",
    "coffre": "coffrer",
    "coffrent": "coffrer",
    "coffrera": "coffrer",
    "coffrerai": "coffrer",
    "coffrerais": "coffrer",
    "coffrerons": "coffrer",
    "coffreront": "coffrer",
    "coffres": "coffrer",
    "coffres-forts": "coffre-fort",
    "coffrets": "coffret",
    "coffrez": "coffrer",
    "coffrons": "coffrer",
    "coffré": "coffrer",
    "coffrée": "coffrer",
    "coffrées": "coffrer",
    "coffrés": "coffrer",
    "cofinance": "cofinancer",
    "cofinancements": "cofinancement",
    "cofinancent": "cofinancer",
    "cofinancera": "cofinancer",
    "cofinancerai": "cofinancer",
    "cofinanceraient": "cofinancer",
    "cofinancerais": "cofinancer",
    "cofinancerait": "cofinancer",
    "cofinanceras": "cofinancer",
    "cofinancerez": "cofinancer",
    "cofinanceriez": "cofinancer",
    "cofinancerions": "cofinancer",
    "cofinancerons": "cofinancer",
    "cofinanceront": "cofinancer",
    "cofinances": "cofinancer",
    "cofinancez": "cofinancer",
    "cofinanciez": "cofinancer",
    "cofinancions": "cofinancer",
    "cofinancèrent": "cofinancer",
    "cofinancé": "cofinancer",
    "cofinancée": "cofinancer",
    "cofinancées": "cofinancer",
    "cofinancés": "cofinancer",
    "cofinança": "cofinancer",
    "cofinançai": "cofinancer",
    "cofinançaient": "cofinancer",
    "cofinançais": "cofinancer",
    "cofinançait": "cofinancer",
    "cofinançant": "cofinancer",
    "cofinanças": "cofinancer",
    "cofinançasse": "cofinancer",
    "cofinançassent": "cofinancer",
    "cofinançasses": "cofinancer",
    "cofinançassiez": "cofinancer",
    "cofinançassions": "cofinancer",
    "cofinançons": "cofinancer",
    "cofinançâmes": "cofinancer",
    "cofinançât": "cofinancer",
    "cofinançâtes": "cofinancer",
    "cofondateurs": "cofondateur",
    "cofondatrice": "cofondateur",
    "cofondatrices": "cofondateur",
    "cogestions": "cogestion",
    "cogita": "cogiter",
    "cogitai": "cogiter",
    "cogitaient": "cogiter",
    "cogitais": "cogiter",
    "cogitait": "cogiter",
    "cogitant": "cogiter",
    "cogitas": "cogiter",
    "cogitasse": "cogiter",
    "cogitassent": "cogiter",
    "cogitasses": "cogiter",
    "cogitassiez": "cogiter",
    "cogitassions": "cogiter",
    "cogitations": "cogitation",
    "cogite": "cogiter",
    "cogitent": "cogiter",
    "cogitera": "cogiter",
    "cogiterai": "cogiter",
    "cogiteraient": "cogiter",
    "cogiterais": "cogiter",
    "cogiterait": "cogiter",
    "cogiteras": "cogiter",
    "cogiterez": "cogiter",
    "cogiteriez": "cogiter",
    "cogiterions": "cogiter",
    "cogiterons": "cogiter",
    "cogiteront": "cogiter",
    "cogites": "cogiter",
    "cogitez": "cogiter",
    "cogitiez": "cogiter",
    "cogitions": "cogiter",
    "cogitons": "cogiter",
    "cogitâmes": "cogiter",
    "cogitât": "cogiter",
    "cogitâtes": "cogiter",
    "cogitèrent": "cogiter",
    "cogité": "cogiter",
    "cogitée": "cogiter",
    "cogitées": "cogiter",
    "cogités": "cogiter",
    "cogna": "cogner",
    "cognacs": "cognac",
    "cognai": "cogner",
    "cognaient": "cogner",
    "cognais": "cogner",
    "cognait": "cogner",
    "cognant": "cogner",
    "cognas": "cogner",
    "cognasse": "cogner",
    "cognassent": "cogner",
    "cognasses": "cogner",
    "cognassiers": "cognassier",
    "cognassiez": "cogner",
    "cognassions": "cogner",
    "cogne": "cogner",
    "cognements": "cognement",
    "cognent": "cogner",
    "cognera": "cogner",
    "cognerai": "cogner",
    "cogneraient": "cogner",
    "cognerais": "cogner",
    "cognerait": "cogner",
    "cogneras": "cogner",
    "cognerez": "cogner",
    "cogneriez": "cogner",
    "cognerions": "cogner",
    "cognerons": "cogner",
    "cogneront": "cogner",
    "cognes": "cogner",
    "cogneurs": "cogneur",
    "cogneuse": "cogneur",
    "cognez": "cogner",
    "cogniez": "cogner",
    "cognions": "cogner",
    "cognitifs": "cognitif",
    "cognitions": "cognition",
    "cognitive": "cognitif",
    "cognitives": "cognitif",
    "cognons": "cogner",
    "cognâmes": "cogner",
    "cognât": "cogner",
    "cognâtes": "cogner",
    "cognèrent": "cogner",
    "cogné": "cogner",
    "cognée": "cogner",
    "cognées": "cogner",
    "cognés": "cogner",
    "cogère": "cogérer",
    "cogèrent": "cogérer",
    "cogères": "cogérer",
    "cogéra": "cogérer",
    "cogérai": "cogérer",
    "cogéraient": "cogérer",
    "cogérais": "cogérer",
    "cogérait": "cogérer",
    "cogérant": "cogérer",
    "cogéras": "cogérer",
    "cogérasse": "cogérer",
    "cogérassent": "cogérer",
    "cogérasses": "cogérer",
    "cogérassiez": "cogérer",
    "cogérassions": "cogérer",
    "cogérera": "cogérer",
    "cogérerai": "cogérer",
    "cogéreraient": "cogérer",
    "cogérerais": "cogérer",
    "cogérerait": "cogérer",
    "cogéreras": "cogérer",
    "cogérerez": "cogérer",
    "cogéreriez": "cogérer",
    "cogérerions": "cogérer",
    "cogérerons": "cogérer",
    "cogéreront": "cogérer",
    "cogérez": "cogérer",
    "cogériez": "cogérer",
    "cogérions": "cogérer",
    "cogérons": "cogérer",
    "cogérâmes": "cogérer",
    "cogérât": "cogérer",
    "cogérâtes": "cogérer",
    "cogérèrent": "cogérer",
    "cogéré": "cogérer",
    "cogérée": "cogérer",
    "cogérées": "cogérer",
    "cogérés": "cogérer",
    "cohabita": "cohabiter",
    "cohabitai": "cohabiter",
    "cohabitaient": "cohabiter",
    "cohabitais": "cohabiter",
    "cohabitait": "cohabiter",
    "cohabitant": "cohabiter",
    "cohabitas": "cohabiter",
    "cohabitasse": "cohabiter",
    "cohabitassent": "cohabiter",
    "cohabitasses": "cohabiter",
    "cohabitassiez": "cohabiter",
    "cohabitassions": "cohabiter",
    "cohabitations": "cohabitation",
    "cohabite": "cohabiter",
    "cohabitent": "cohabiter",
    "cohabitera": "cohabiter",
    "cohabiterai": "cohabiter",
    "cohabiteraient": "cohabiter",
    "cohabiterais": "cohabiter",
    "cohabiterait": "cohabiter",
    "cohabiteras": "cohabiter",
    "cohabiterez": "cohabiter",
    "cohabiteriez": "cohabiter",
    "cohabiterions": "cohabiter",
    "cohabiterons": "cohabiter",
    "cohabiteront": "cohabiter",
    "cohabites": "cohabiter",
    "cohabitez": "cohabiter",
    "cohabitiez": "cohabiter",
    "cohabitions": "cohabiter",
    "cohabitons": "cohabiter",
    "cohabitâmes": "cohabiter",
    "cohabitât": "cohabiter",
    "cohabitâtes": "cohabiter",
    "cohabitèrent": "cohabiter",
    "cohabité": "cohabiter",
    "cohortes": "cohorte",
    "cohues": "cohue",
    "cohérences": "cohérence",
    "cohérente": "cohérent",
    "cohérentes": "cohérent",
    "cohérents": "cohérent",
    "cohéreurs": "cohéreur",
    "cohéritiers": "cohéritier",
    "cohéritière": "cohéritier",
    "cohéritières": "cohéritier",
    "cohésifs": "cohésif",
    "cohésions": "cohésion",
    "cohésive": "cohésif",
    "cohésives": "cohésif",
    "coiffa": "coiffer",
    "coiffai": "coiffer",
    "coiffaient": "coiffer",
    "coiffais": "coiffer",
    "coiffait": "coiffer",
    "coiffant": "coiffer",
    "coiffante": "coiffant",
    "coiffas": "coiffer",
    "coiffasse": "coiffer",
    "coiffassent": "coiffer",
    "coiffasses": "coiffer",
    "coiffassiez": "coiffer",
    "coiffassions": "coiffer",
    "coiffe": "coiffer",
    "coiffent": "coiffer",
    "coiffera": "coiffer",
    "coifferai": "coiffer",
    "coifferaient": "coiffer",
    "coifferais": "coiffer",
    "coifferait": "coiffer",
    "coifferas": "coiffer",
    "coifferez": "coiffer",
    "coifferiez": "coiffer",
    "coifferions": "coiffer",
    "coifferons": "coiffer",
    "coifferont": "coiffer",
    "coiffes": "coiffer",
    "coiffeurs": "coiffeur",
    "coiffeuse": "coiffeur",
    "coiffeuses": "coiffeuse",
    "coiffez": "coiffer",
    "coiffiez": "coiffer",
    "coiffions": "coiffer",
    "coiffons": "coiffer",
    "coiffures": "coiffure",
    "coiffâmes": "coiffer",
    "coiffât": "coiffer",
    "coiffâtes": "coiffer",
    "coiffèrent": "coiffer",
    "coiffé": "coiffer",
    "coiffée": "coiffer",
    "coiffées": "coiffer",
    "coiffés": "coiffer",
    "coince": "coincer",
    "coincent": "coincer",
    "coincera": "coincer",
    "coincerai": "coincer",
    "coinceraient": "coincer",
    "coincerais": "coincer",
    "coincerait": "coincer",
    "coinceras": "coincer",
    "coincerez": "coincer",
    "coinceriez": "coincer",
    "coincerions": "coincer",
    "coincerons": "coincer",
    "coinceront": "coincer",
    "coinces": "coincer",
    "coincez": "coincer",
    "coinciez": "coincer",
    "coincions": "coincer",
    "coincèrent": "coincer",
    "coincé": "coincer",
    "coincée": "coincer",
    "coincées": "coincer",
    "coincés": "coincer",
    "coings": "coing",
    "coins": "coin",
    "coinstots": "coinstot",
    "coinça": "coincer",
    "coinçages": "coinçage",
    "coinçai": "coincer",
    "coinçaient": "coincer",
    "coinçais": "coincer",
    "coinçait": "coincer",
    "coinçant": "coincer",
    "coinças": "coincer",
    "coinçasse": "coincer",
    "coinçassent": "coincer",
    "coinçasses": "coincer",
    "coinçassiez": "coincer",
    "coinçassions": "coincer",
    "coinçons": "coincer",
    "coinçâmes": "coincer",
    "coinçât": "coincer",
    "coinçâtes": "coincer",
    "cois": "coi",
    "coite": "coi",
    "coites": "coi",
    "cokes": "coke",
    "cokéfia": "cokéfier",
    "cokéfiai": "cokéfier",
    "cokéfiaient": "cokéfier",
    "cokéfiais": "cokéfier",
    "cokéfiait": "cokéfier",
    "cokéfiant": "cokéfier",
    "cokéfias": "cokéfier",
    "cokéfiasse": "cokéfier",
    "cokéfiassent": "cokéfier",
    "cokéfiasses": "cokéfier",
    "cokéfiassiez": "cokéfier",
    "cokéfiassions": "cokéfier",
    "cokéfie": "cokéfier",
    "cokéfient": "cokéfier",
    "cokéfiera": "cokéfier",
    "cokéfierai": "cokéfier",
    "cokéfieraient": "cokéfier",
    "cokéfierais": "cokéfier",
    "cokéfierait": "cokéfier",
    "cokéfieras": "cokéfier",
    "cokéfierez": "cokéfier",
    "cokéfieriez": "cokéfier",
    "cokéfierions": "cokéfier",
    "cokéfierons": "cokéfier",
    "cokéfieront": "cokéfier",
    "cokéfies": "cokéfier",
    "cokéfiez": "cokéfier",
    "cokéfiiez": "cokéfier",
    "cokéfiions": "cokéfier",
    "cokéfions": "cokéfier",
    "cokéfiâmes": "cokéfier",
    "cokéfiât": "cokéfier",
    "cokéfiâtes": "cokéfier",
    "cokéfièrent": "cokéfier",
    "cokéfié": "cokéfier",
    "cokéfiée": "cokéfier",
    "cokéfiées": "cokéfier",
    "cokéfiés": "cokéfier",
    "colas": "cola",
    "colbacks": "colback",
    "colchiques": "colchique",
    "colcotars": "colcotar",
    "cold-creams": "cold-cream",
    "colibacilles": "colibacille",
    "colibris": "colibri",
    "colifichets": "colifichet",
    "coliformes": "coliforme",
    "colimaçons": "colimaçon",
    "colin-maillards": "colin-maillard",
    "colin-tampons": "colin-tampon",
    "colins": "colin",
    "coliques": "colique",
    "colites": "colite",
    "colla": "coller",
    "collabora": "collaborer",
    "collaborai": "collaborer",
    "collaboraient": "collaborer",
    "collaborais": "collaborer",
    "collaborait": "collaborer",
    "collaborant": "collaborer",
    "collaboras": "collaborer",
    "collaborasse": "collaborer",
    "collaborassent": "collaborer",
    "collaborasses": "collaborer",
    "collaborassiez": "collaborer",
    "collaborassions": "collaborer",
    "collaborateurs": "collaborateur",
    "collaborationnistes": "collaborationniste",
    "collaborations": "collaboration",
    "collaboratrice": "collaborateur",
    "collaboratrices": "collaborateur",
    "collabore": "collaborer",
    "collaborent": "collaborer",
    "collaborera": "collaborer",
    "collaborerai": "collaborer",
    "collaboreraient": "collaborer",
    "collaborerais": "collaborer",
    "collaborerait": "collaborer",
    "collaboreras": "collaborer",
    "collaborerez": "collaborer",
    "collaboreriez": "collaborer",
    "collaborerions": "collaborer",
    "collaborerons": "collaborer",
    "collaboreront": "collaborer",
    "collabores": "collaborer",
    "collaborez": "collaborer",
    "collaboriez": "collaborer",
    "collaborions": "collaborer",
    "collaborons": "collaborer",
    "collaborâmes": "collaborer",
    "collaborât": "collaborer",
    "collaborâtes": "collaborer",
    "collaborèrent": "collaborer",
    "collaboré": "collaborer",
    "collabos": "collabo",
    "collages": "collage",
    "collai": "coller",
    "collaient": "coller",
    "collais": "coller",
    "collait": "coller",
    "collant": "coller",
    "collante": "collant",
    "collantes": "collant",
    "collants": "collant",
    "collapse": "collapser",
    "collapserait": "collapser",
    "collas": "coller",
    "collasse": "coller",
    "collassent": "coller",
    "collasses": "coller",
    "collassiez": "coller",
    "collassions": "coller",
    "collationna": "collationner",
    "collationnai": "collationner",
    "collationnaient": "collationner",
    "collationnais": "collationner",
    "collationnait": "collationner",
    "collationnant": "collationner",
    "collationnas": "collationner",
    "collationnasse": "collationner",
    "collationnassent": "collationner",
    "collationnasses": "collationner",
    "collationnassiez": "collationner",
    "collationnassions": "collationner",
    "collationne": "collationner",
    "collationnent": "collationner",
    "collationnera": "collationner",
    "collationnerai": "collationner",
    "collationneraient": "collationner",
    "collationnerais": "collationner",
    "collationnerait": "collationner",
    "collationneras": "collationner",
    "collationnerez": "collationner",
    "collationneriez": "collationner",
    "collationnerions": "collationner",
    "collationnerons": "collationner",
    "collationneront": "collationner",
    "collationnes": "collationner",
    "collationnez": "collationner",
    "collationniez": "collationner",
    "collationnions": "collationner",
    "collationnons": "collationner",
    "collationnâmes": "collationner",
    "collationnât": "collationner",
    "collationnâtes": "collationner",
    "collationnèrent": "collationner",
    "collationné": "collationner",
    "collationnée": "collationner",
    "collationnées": "collationner",
    "collationnés": "collationner",
    "collations": "collation",
    "collatérale": "collatéral",
    "collatérales": "collatéral",
    "collatéraux": "collatéral",
    "colle": "coller",
    "collecta": "collecter",
    "collectages": "collectage",
    "collectai": "collecter",
    "collectaient": "collecter",
    "collectais": "collecter",
    "collectait": "collecter",
    "collectant": "collecter",
    "collectas": "collecter",
    "collectasse": "collecter",
    "collectassent": "collecter",
    "collectasses": "collecter",
    "collectassiez": "collecter",
    "collectassions": "collecter",
    "collecte": "collecter",
    "collectent": "collecter",
    "collectera": "collecter",
    "collecterai": "collecter",
    "collecteraient": "collecter",
    "collecterais": "collecter",
    "collecterait": "collecter",
    "collecteras": "collecter",
    "collecterez": "collecter",
    "collecteriez": "collecter",
    "collecterions": "collecter",
    "collecterons": "collecter",
    "collecteront": "collecter",
    "collectes": "collecter",
    "collecteurs": "collecteur",
    "collectez": "collecter",
    "collectiez": "collecter",
    "collectifs": "collectif",
    "collectionna": "collectionner",
    "collectionnai": "collectionner",
    "collectionnaient": "collectionner",
    "collectionnais": "collectionner",
    "collectionnait": "collectionner",
    "collectionnant": "collectionner",
    "collectionnas": "collectionner",
    "collectionnasse": "collectionner",
    "collectionnassent": "collectionner",
    "collectionnasses": "collectionner",
    "collectionnassiez": "collectionner",
    "collectionnassions": "collectionner",
    "collectionne": "collectionner",
    "collectionnent": "collectionner",
    "collectionnera": "collectionner",
    "collectionnerai": "collectionner",
    "collectionneraient": "collectionner",
    "collectionnerais": "collectionner",
    "collectionnerait": "collectionner",
    "collectionneras": "collectionner",
    "collectionnerez": "collectionner",
    "collectionneriez": "collectionner",
    "collectionnerions": "collectionner",
    "collectionnerons": "collectionner",
    "collectionneront": "collectionner",
    "collectionnes": "collectionner",
    "collectionneurs": "collectionneur",
    "collectionneuse": "collectionneur",
    "collectionnez": "collectionner",
    "collectionniez": "collectionner",
    "collectionnions": "collectionner",
    "collectionnons": "collectionner",
    "collectionnâmes": "collectionner",
    "collectionnât": "collectionner",
    "collectionnâtes": "collectionner",
    "collectionnèrent": "collectionner",
    "collectionné": "collectionner",
    "collectionnée": "collectionner",
    "collectionnées": "collectionner",
    "collectionnés": "collectionner",
    "collections": "collection",
    "collective": "collectif",
    "collectives": "collectif",
    "collectivisa": "collectiviser",
    "collectivisai": "collectiviser",
    "collectivisaient": "collectiviser",
    "collectivisais": "collectiviser",
    "collectivisait": "collectiviser",
    "collectivisant": "collectiviser",
    "collectivisas": "collectiviser",
    "collectivisasse": "collectiviser",
    "collectivisassent": "collectiviser",
    "collectivisasses": "collectiviser",
    "collectivisassiez": "collectiviser",
    "collectivisassions": "collectiviser",
    "collectivisations": "collectivisation",
    "collectivise": "collectiviser",
    "collectivisent": "collectiviser",
    "collectivisera": "collectiviser",
    "collectiviserai": "collectiviser",
    "collectiviseraient": "collectiviser",
    "collectiviserais": "collectiviser",
    "collectiviserait": "collectiviser",
    "collectiviseras": "collectiviser",
    "collectiviserez": "collectiviser",
    "collectiviseriez": "collectiviser",
    "collectiviserions": "collectiviser",
    "collectiviserons": "collectiviser",
    "collectiviseront": "collectiviser",
    "collectivises": "collectiviser",
    "collectivisez": "collectiviser",
    "collectivisiez": "collectiviser",
    "collectivisions": "collectiviser",
    "collectivisons": "collectiviser",
    "collectivisâmes": "collectiviser",
    "collectivisât": "collectiviser",
    "collectivisâtes": "collectiviser",
    "collectivisèrent": "collectiviser",
    "collectivisé": "collectiviser",
    "collectivisée": "collectiviser",
    "collectivisées": "collectiviser",
    "collectivisés": "collectiviser",
    "collectivités": "collectivité",
    "collectons": "collecter",
    "collectrice": "collecteur",
    "collectâmes": "collecter",
    "collectât": "collecter",
    "collectâtes": "collecter",
    "collectèrent": "collecter",
    "collecté": "collecter",
    "collectée": "collecter",
    "collectées": "collecter",
    "collectés": "collecter",
    "collenchymes": "collenchyme",
    "collent": "coller",
    "collera": "coller",
    "collerai": "coller",
    "colleraient": "coller",
    "collerais": "coller",
    "collerait": "coller",
    "colleras": "coller",
    "collerettes": "collerette",
    "collerez": "coller",
    "colleriez": "coller",
    "collerions": "coller",
    "collerons": "coller",
    "colleront": "coller",
    "colles": "coller",
    "colleta": "colleter",
    "colletai": "colleter",
    "colletaient": "colleter",
    "colletais": "colleter",
    "colletait": "colleter",
    "colletant": "colleter",
    "colletas": "colleter",
    "colletasse": "colleter",
    "colletassent": "colleter",
    "colletasses": "colleter",
    "colletassiez": "colleter",
    "colletassions": "colleter",
    "colletez": "colleter",
    "colletiez": "colleter",
    "colletions": "colleter",
    "colletons": "colleter",
    "collets": "collet",
    "collette": "colleter",
    "collettent": "colleter",
    "collettera": "colleter",
    "colletterai": "colleter",
    "colletteraient": "colleter",
    "colletterais": "colleter",
    "colletterait": "colleter",
    "colletteras": "colleter",
    "colletterez": "colleter",
    "colletteriez": "colleter",
    "colletterions": "colleter",
    "colletterons": "colleter",
    "colletteront": "colleter",
    "collettes": "colleter",
    "colletâmes": "colleter",
    "colletât": "colleter",
    "colletâtes": "colleter",
    "colletèrent": "colleter",
    "colleté": "colleter",
    "colletée": "colleter",
    "colletées": "colleter",
    "colletés": "colleter",
    "colleurs": "colleur",
    "colleys": "colley",
    "collez": "coller",
    "colliers": "collier",
    "colliez": "coller",
    "collige": "colliger",
    "colligea": "colliger",
    "colligeai": "colliger",
    "colligeaient": "colliger",
    "colligeais": "colliger",
    "colligeait": "colliger",
    "colligeant": "colliger",
    "colligeas": "colliger",
    "colligeasse": "colliger",
    "colligeassent": "colliger",
    "colligeasses": "colliger",
    "colligeassiez": "colliger",
    "colligeassions": "colliger",
    "colligent": "colliger",
    "colligeons": "colliger",
    "colligera": "colliger",
    "colligerai": "colliger",
    "colligeraient": "colliger",
    "colligerais": "colliger",
    "colligerait": "colliger",
    "colligeras": "colliger",
    "colligerez": "colliger",
    "colligeriez": "colliger",
    "colligerions": "colliger",
    "colligerons": "colliger",
    "colligeront": "colliger",
    "colliges": "colliger",
    "colligez": "colliger",
    "colligeâmes": "colliger",
    "colligeât": "colliger",
    "colligeâtes": "colliger",
    "colligiez": "colliger",
    "colligions": "colliger",
    "colligèrent": "colliger",
    "colligé": "colliger",
    "colligée": "colliger",
    "colligées": "colliger",
    "colligés": "colliger",
    "collimateurs": "collimateur",
    "collines": "colline",
    "collions": "coller",
    "collisionneurs": "collisionneur",
    "collisions": "collision",
    "collocations": "collocation",
    "collodions": "collodion",
    "collons": "coller",
    "colloquant": "colloquer",
    "colloques": "colloque",
    "colloqué": "colloquer",
    "colloquée": "colloquer",
    "colloïdale": "colloïdal",
    "colloïdales": "colloïdal",
    "colloïdaux": "colloïdal",
    "colloïdes": "colloïde",
    "collusions": "collusion",
    "collutoires": "collutoire",
    "collyres": "collyre",
    "collâmes": "coller",
    "collât": "coller",
    "collâtes": "coller",
    "collèges": "collège",
    "collègues": "collègue",
    "collèrent": "coller",
    "collé": "coller",
    "collée": "coller",
    "collées": "coller",
    "collégiale": "collégial",
    "collégiales": "collégial",
    "collégialités": "collégialité",
    "collégiaux": "collégial",
    "collégienne": "collégien",
    "collégiennes": "collégien",
    "collégiens": "collégien",
    "collés": "coller",
    "colmata": "colmater",
    "colmatai": "colmater",
    "colmataient": "colmater",
    "colmatais": "colmater",
    "colmatait": "colmater",
    "colmatant": "colmater",
    "colmatas": "colmater",
    "colmatasse": "colmater",
    "colmatassent": "colmater",
    "colmatasses": "colmater",
    "colmatassiez": "colmater",
    "colmatassions": "colmater",
    "colmate": "colmater",
    "colmatent": "colmater",
    "colmatera": "colmater",
    "colmaterai": "colmater",
    "colmateraient": "colmater",
    "colmaterais": "colmater",
    "colmaterait": "colmater",
    "colmateras": "colmater",
    "colmaterez": "colmater",
    "colmateriez": "colmater",
    "colmaterions": "colmater",
    "colmaterons": "colmater",
    "colmateront": "colmater",
    "colmates": "colmater",
    "colmatez": "colmater",
    "colmatiez": "colmater",
    "colmations": "colmater",
    "colmatons": "colmater",
    "colmatâmes": "colmater",
    "colmatât": "colmater",
    "colmatâtes": "colmater",
    "colmatèrent": "colmater",
    "colmaté": "colmater",
    "colmatée": "colmater",
    "colmatées": "colmater",
    "colmatés": "colmater",
    "colocataires": "colocataire",
    "colombages": "colombage",
    "colombes": "colombe",
    "colombienne": "colombien",
    "colombiens": "colombien",
    "colombiers": "colombier",
    "colombine": "colombin",
    "colombines": "colombin",
    "colombins": "colombin",
    "colonelle": "colonel",
    "colonelles": "colonel",
    "colonels": "colonel",
    "coloniale": "colonial",
    "coloniales": "colonial",
    "colonialismes": "colonialisme",
    "colonialistes": "colonialiste",
    "coloniaux": "colonial",
    "colonies": "colonie",
    "colonisa": "coloniser",
    "colonisai": "coloniser",
    "colonisaient": "coloniser",
    "colonisais": "coloniser",
    "colonisait": "coloniser",
    "colonisant": "coloniser",
    "colonisas": "coloniser",
    "colonisasse": "coloniser",
    "colonisassent": "coloniser",
    "colonisasses": "coloniser",
    "colonisassiez": "coloniser",
    "colonisassions": "coloniser",
    "colonisateurs": "colonisateur",
    "colonisations": "colonisation",
    "colonisatrice": "colonisateur",
    "colonise": "coloniser",
    "colonisent": "coloniser",
    "colonisera": "coloniser",
    "coloniserai": "coloniser",
    "coloniseraient": "coloniser",
    "coloniserais": "coloniser",
    "coloniserait": "coloniser",
    "coloniseras": "coloniser",
    "coloniserez": "coloniser",
    "coloniseriez": "coloniser",
    "coloniserions": "coloniser",
    "coloniserons": "coloniser",
    "coloniseront": "coloniser",
    "colonises": "coloniser",
    "colonisez": "coloniser",
    "colonisiez": "coloniser",
    "colonisions": "coloniser",
    "colonisons": "coloniser",
    "colonisâmes": "coloniser",
    "colonisât": "coloniser",
    "colonisâtes": "coloniser",
    "colonisèrent": "coloniser",
    "colonisé": "coloniser",
    "colonisée": "coloniser",
    "colonisées": "coloniser",
    "colonisés": "coloniser",
    "colonnades": "colonnade",
    "colonnes": "colonne",
    "colonnettes": "colonnette",
    "colons": "colon",
    "colophanes": "colophane",
    "colophané": "colophaner",
    "coloquintes": "coloquinte",
    "colora": "colorer",
    "colorai": "colorer",
    "coloraient": "colorer",
    "colorais": "colorer",
    "colorait": "colorer",
    "colorant": "colorer",
    "colorante": "colorant",
    "colorantes": "colorant",
    "colorants": "colorant",
    "coloras": "colorer",
    "colorasse": "colorer",
    "colorassent": "colorer",
    "colorasses": "colorer",
    "colorassiez": "colorer",
    "colorassions": "colorer",
    "colorations": "coloration",
    "colore": "colorer",
    "colorent": "colorer",
    "colorera": "colorer",
    "colorerai": "colorer",
    "coloreraient": "colorer",
    "colorerais": "colorer",
    "colorerait": "colorer",
    "coloreras": "colorer",
    "colorerez": "colorer",
    "coloreriez": "colorer",
    "colorerions": "colorer",
    "colorerons": "colorer",
    "coloreront": "colorer",
    "colores": "colorer",
    "colorez": "colorer",
    "coloria": "colorier",
    "coloriages": "coloriage",
    "coloriai": "colorier",
    "coloriaient": "colorier",
    "coloriais": "colorier",
    "coloriait": "colorier",
    "coloriant": "colorier",
    "colorias": "colorier",
    "coloriasse": "colorier",
    "coloriassent": "colorier",
    "coloriasses": "colorier",
    "coloriassiez": "colorier",
    "coloriassions": "colorier",
    "colorie": "colorier",
    "colorient": "colorier",
    "coloriera": "colorier",
    "colorierai": "colorier",
    "colorieraient": "colorier",
    "colorierais": "colorier",
    "colorierait": "colorier",
    "colorieras": "colorier",
    "colorierez": "colorier",
    "colorieriez": "colorier",
    "colorierions": "colorier",
    "colorierons": "colorier",
    "colorieront": "colorier",
    "colories": "colorier",
    "coloriez": "colorier",
    "coloriiez": "colorier",
    "coloriions": "colorier",
    "colorions": "colorier",
    "colorisé": "coloriser",
    "coloriâmes": "colorier",
    "coloriât": "colorier",
    "coloriâtes": "colorier",
    "colorièrent": "colorier",
    "colorié": "colorier",
    "coloriée": "colorier",
    "coloriées": "colorier",
    "coloriés": "colorier",
    "colorons": "colorer",
    "colorâmes": "colorer",
    "colorât": "colorer",
    "colorâtes": "colorer",
    "colorèrent": "colorer",
    "coloré": "colorer",
    "colorée": "colorer",
    "colorées": "colorer",
    "colorés": "colorer",
    "colos": "colo",
    "colossale": "colossal",
    "colossales": "colossal",
    "colossaux": "colossal",
    "colosses": "colosse",
    "colostrums": "colostrum",
    "colporta": "colporter",
    "colportai": "colporter",
    "colportaient": "colporter",
    "colportais": "colporter",
    "colportait": "colporter",
    "colportant": "colporter",
    "colportas": "colporter",
    "colportasse": "colporter",
    "colportassent": "colporter",
    "colportasses": "colporter",
    "colportassiez": "colporter",
    "colportassions": "colporter",
    "colporte": "colporter",
    "colportent": "colporter",
    "colportera": "colporter",
    "colporterai": "colporter",
    "colporteraient": "colporter",
    "colporterais": "colporter",
    "colporterait": "colporter",
    "colporteras": "colporter",
    "colporterez": "colporter",
    "colporteriez": "colporter",
    "colporterions": "colporter",
    "colporterons": "colporter",
    "colporteront": "colporter",
    "colportes": "colporter",
    "colporteurs": "colporteur",
    "colporteuse": "colporteur",
    "colportez": "colporter",
    "colportiez": "colporter",
    "colportions": "colporter",
    "colportons": "colporter",
    "colportâmes": "colporter",
    "colportât": "colporter",
    "colportâtes": "colporter",
    "colportèrent": "colporter",
    "colporté": "colporter",
    "colportée": "colporter",
    "colportées": "colporter",
    "colportés": "colporter",
    "cols": "col",
    "cols-bleus": "col-bleu",
    "cols-de-cygne": "col-de-cygne",
    "cols-verts": "col-vert",
    "coltina": "coltiner",
    "coltinages": "coltinage",
    "coltinai": "coltiner",
    "coltinaient": "coltiner",
    "coltinais": "coltiner",
    "coltinait": "coltiner",
    "coltinant": "coltiner",
    "coltinas": "coltiner",
    "coltinasse": "coltiner",
    "coltinassent": "coltiner",
    "coltinasses": "coltiner",
    "coltinassiez": "coltiner",
    "coltinassions": "coltiner",
    "coltine": "coltiner",
    "coltinent": "coltiner",
    "coltinera": "coltiner",
    "coltinerai": "coltiner",
    "coltineraient": "coltiner",
    "coltinerais": "coltiner",
    "coltinerait": "coltiner",
    "coltineras": "coltiner",
    "coltinerez": "coltiner",
    "coltineriez": "coltiner",
    "coltinerions": "coltiner",
    "coltinerons": "coltiner",
    "coltineront": "coltiner",
    "coltines": "coltiner",
    "coltinez": "coltiner",
    "coltiniez": "coltiner",
    "coltinions": "coltiner",
    "coltinons": "coltiner",
    "coltinâmes": "coltiner",
    "coltinât": "coltiner",
    "coltinâtes": "coltiner",
    "coltinèrent": "coltiner",
    "coltiné": "coltiner",
    "coltinée": "coltiner",
    "coltinées": "coltiner",
    "coltinés": "coltiner",
    "colts": "colt",
    "columbariums": "columbarium",
    "colverts": "colvert",
    "colzas": "colza",
    "colères": "colère",
    "coléoptères": "coléoptère",
    "coléreuse": "coléreux",
    "coléreuses": "coléreux",
    "colériques": "colérique",
    "comacs": "comac",
    "comas": "coma",
    "comateuse": "comateux",
    "comateuses": "comateux",
    "combat": "combattre",
    "combatifs": "combatif",
    "combative": "combatif",
    "combatives": "combatif",
    "combativités": "combativité",
    "combats": "combattre",
    "combattaient": "combattre",
    "combattais": "combattre",
    "combattait": "combattre",
    "combattant": "combattre",
    "combattante": "combattant",
    "combattantes": "combattant",
    "combattants": "combattant",
    "combatte": "combattre",
    "combattent": "combattre",
    "combattes": "combattre",
    "combattez": "combattre",
    "combattiez": "combattre",
    "combattions": "combattre",
    "combattirent": "combattre",
    "combattis": "combattre",
    "combattisse": "combattre",
    "combattissent": "combattre",
    "combattisses": "combattre",
    "combattissiez": "combattre",
    "combattissions": "combattre",
    "combattit": "combattre",
    "combattons": "combattre",
    "combattra": "combattre",
    "combattrai": "combattre",
    "combattraient": "combattre",
    "combattrais": "combattre",
    "combattrait": "combattre",
    "combattras": "combattre",
    "combattrez": "combattre",
    "combattriez": "combattre",
    "combattrions": "combattre",
    "combattrons": "combattre",
    "combattront": "combattre",
    "combattu": "combattre",
    "combattue": "combattre",
    "combattues": "combattre",
    "combattus": "combattre",
    "combattîmes": "combattre",
    "combattît": "combattre",
    "combattîtes": "combattre",
    "combes": "combe",
    "combina": "combiner",
    "combinai": "combiner",
    "combinaient": "combiner",
    "combinais": "combiner",
    "combinaisons": "combinaison",
    "combinait": "combiner",
    "combinant": "combiner",
    "combinards": "combinard",
    "combinas": "combiner",
    "combinasse": "combiner",
    "combinassent": "combiner",
    "combinasses": "combiner",
    "combinassiez": "combiner",
    "combinassions": "combiner",
    "combinatoires": "combinatoire",
    "combinats": "combinat",
    "combine": "combiner",
    "combinent": "combiner",
    "combinera": "combiner",
    "combinerai": "combiner",
    "combineraient": "combiner",
    "combinerais": "combiner",
    "combinerait": "combiner",
    "combineras": "combiner",
    "combinerez": "combiner",
    "combineriez": "combiner",
    "combinerions": "combiner",
    "combinerons": "combiner",
    "combineront": "combiner",
    "combines": "combiner",
    "combinez": "combiner",
    "combiniez": "combiner",
    "combinions": "combiner",
    "combinons": "combiner",
    "combinâmes": "combiner",
    "combinât": "combiner",
    "combinâtes": "combiner",
    "combinèrent": "combiner",
    "combiné": "combiner",
    "combinée": "combiner",
    "combinées": "combiner",
    "combinés": "combiner",
    "combis": "combi",
    "combla": "combler",
    "comblai": "combler",
    "comblaient": "combler",
    "comblais": "combler",
    "comblait": "combler",
    "comblant": "combler",
    "comblants": "comblant",
    "comblas": "combler",
    "comblasse": "combler",
    "comblassent": "combler",
    "comblasses": "combler",
    "comblassiez": "combler",
    "comblassions": "combler",
    "comble": "combler",
    "comblent": "combler",
    "comblera": "combler",
    "comblerai": "combler",
    "combleraient": "combler",
    "comblerais": "combler",
    "comblerait": "combler",
    "combleras": "combler",
    "comblerez": "combler",
    "combleriez": "combler",
    "comblerions": "combler",
    "comblerons": "combler",
    "combleront": "combler",
    "combles": "combler",
    "comblez": "combler",
    "combliez": "combler",
    "comblions": "combler",
    "comblons": "combler",
    "comblâmes": "combler",
    "comblât": "combler",
    "comblâtes": "combler",
    "comblèrent": "combler",
    "comblé": "combler",
    "comblée": "combler",
    "comblées": "combler",
    "comblés": "combler",
    "combustibles": "combustible",
    "combustions": "combustion",
    "comestibles": "comestible",
    "comic books": "comic book",
    "comices": "comice",
    "comiques": "comique",
    "comites": "comite",
    "comitiale": "comitial",
    "comitiales": "comitial",
    "comitiaux": "comitial",
    "comités": "comité",
    "commanda": "commander",
    "commandai": "commander",
    "commandaient": "commander",
    "commandais": "commander",
    "commandait": "commander",
    "commandant": "commander",
    "commandante": "commandant",
    "commandants": "commandant",
    "commandas": "commander",
    "commandasse": "commander",
    "commandassent": "commander",
    "commandasses": "commander",
    "commandassiez": "commander",
    "commandassions": "commander",
    "commande": "commander",
    "commandements": "commandement",
    "commandent": "commander",
    "commandera": "commander",
    "commanderai": "commander",
    "commanderaient": "commander",
    "commanderais": "commander",
    "commanderait": "commander",
    "commanderas": "commander",
    "commanderez": "commander",
    "commanderies": "commanderie",
    "commanderiez": "commander",
    "commanderions": "commander",
    "commanderons": "commander",
    "commanderont": "commander",
    "commandes": "commander",
    "commandeurs": "commandeur",
    "commandez": "commander",
    "commandiez": "commander",
    "commandions": "commander",
    "commandita": "commanditer",
    "commanditai": "commanditer",
    "commanditaient": "commanditer",
    "commanditaires": "commanditaire",
    "commanditais": "commanditer",
    "commanditait": "commanditer",
    "commanditant": "commanditer",
    "commanditas": "commanditer",
    "commanditasse": "commanditer",
    "commanditassent": "commanditer",
    "commanditasses": "commanditer",
    "commanditassiez": "commanditer",
    "commanditassions": "commanditer",
    "commandite": "commanditer",
    "commanditent": "commanditer",
    "commanditera": "commanditer",
    "commanditerai": "commanditer",
    "commanditeraient": "commanditer",
    "commanditerais": "commanditer",
    "commanditerait": "commanditer",
    "commanditeras": "commanditer",
    "commanditerez": "commanditer",
    "commanditeriez": "commanditer",
    "commanditerions": "commanditer",
    "commanditerons": "commanditer",
    "commanditeront": "commanditer",
    "commandites": "commanditer",
    "commanditez": "commanditer",
    "commanditiez": "commanditer",
    "commanditions": "commanditer",
    "commanditons": "commanditer",
    "commanditâmes": "commanditer",
    "commanditât": "commanditer",
    "commanditâtes": "commanditer",
    "commanditèrent": "commanditer",
    "commandité": "commanditer",
    "commanditée": "commanditer",
    "commanditées": "commanditer",
    "commandités": "commanditer",
    "commandons": "commander",
    "commandos": "commando",
    "commandos-suicide": "commando-suicide",
    "commandâmes": "commander",
    "commandât": "commander",
    "commandâtes": "commander",
    "commandèrent": "commander",
    "commandé": "commander",
    "commandée": "commander",
    "commandées": "commander",
    "commandés": "commander",
    "commas": "comma",
    "commence": "commencer",
    "commencements": "commencement",
    "commencent": "commencer",
    "commencera": "commencer",
    "commencerai": "commencer",
    "commenceraient": "commencer",
    "commencerais": "commencer",
    "commencerait": "commencer",
    "commenceras": "commencer",
    "commencerez": "commencer",
    "commenceriez": "commencer",
    "commencerions": "commencer",
    "commencerons": "commencer",
    "commenceront": "commencer",
    "commences": "commencer",
    "commencez": "commencer",
    "commenciez": "commencer",
    "commencions": "commencer",
    "commencèrent": "commencer",
    "commencé": "commencer",
    "commencée": "commencer",
    "commencées": "commencer",
    "commencés": "commencer",
    "commensale": "commensal",
    "commensales": "commensal",
    "commensaux": "commensal",
    "commensurables": "commensurable",
    "commenta": "commenter",
    "commentai": "commenter",
    "commentaient": "commenter",
    "commentaires": "commentaire",
    "commentais": "commenter",
    "commentait": "commenter",
    "commentant": "commenter",
    "commentas": "commenter",
    "commentasse": "commenter",
    "commentassent": "commenter",
    "commentasses": "commenter",
    "commentassiez": "commenter",
    "commentassions": "commenter",
    "commentateurs": "commentateur",
    "commentatrice": "commentateur",
    "commentatrices": "commentateur",
    "commente": "commenter",
    "commentent": "commenter",
    "commentera": "commenter",
    "commenterai": "commenter",
    "commenteraient": "commenter",
    "commenterais": "commenter",
    "commenterait": "commenter",
    "commenteras": "commenter",
    "commenterez": "commenter",
    "commenteriez": "commenter",
    "commenterions": "commenter",
    "commenterons": "commenter",
    "commenteront": "commenter",
    "commentes": "commenter",
    "commentez": "commenter",
    "commentiez": "commenter",
    "commentions": "commenter",
    "commentons": "commenter",
    "commentâmes": "commenter",
    "commentât": "commenter",
    "commentâtes": "commenter",
    "commentèrent": "commenter",
    "commenté": "commenter",
    "commentée": "commenter",
    "commentées": "commenter",
    "commentés": "commenter",
    "commença": "commencer",
    "commençai": "commencer",
    "commençaient": "commencer",
    "commençais": "commencer",
    "commençait": "commencer",
    "commençant": "commencer",
    "commençante": "commençant",
    "commençantes": "commençant",
    "commençants": "commençant",
    "commenças": "commencer",
    "commençasse": "commencer",
    "commençassent": "commencer",
    "commençasses": "commencer",
    "commençassiez": "commencer",
    "commençassions": "commencer",
    "commençons": "commencer",
    "commençâmes": "commencer",
    "commençât": "commencer",
    "commençâtes": "commencer",
    "commerce": "commercer",
    "commercent": "commercer",
    "commercera": "commercer",
    "commercerai": "commercer",
    "commerceraient": "commercer",
    "commercerais": "commercer",
    "commercerait": "commercer",
    "commerceras": "commercer",
    "commercerez": "commercer",
    "commerceriez": "commercer",
    "commercerions": "commercer",
    "commercerons": "commercer",
    "commerceront": "commercer",
    "commerces": "commercer",
    "commercez": "commercer",
    "commerciale": "commercial",
    "commerciales": "commercial",
    "commercialisa": "commercialiser",
    "commercialisables": "commercialisable",
    "commercialisai": "commercialiser",
    "commercialisaient": "commercialiser",
    "commercialisais": "commercialiser",
    "commercialisait": "commercialiser",
    "commercialisant": "commercialiser",
    "commercialisas": "commercialiser",
    "commercialisasse": "commercialiser",
    "commercialisassent": "commercialiser",
    "commercialisasses": "commercialiser",
    "commercialisassiez": "commercialiser",
    "commercialisassions": "commercialiser",
    "commercialisations": "commercialisation",
    "commercialise": "commercialiser",
    "commercialisent": "commercialiser",
    "commercialisera": "commercialiser",
    "commercialiserai": "commercialiser",
    "commercialiseraient": "commercialiser",
    "commercialiserais": "commercialiser",
    "commercialiserait": "commercialiser",
    "commercialiseras": "commercialiser",
    "commercialiserez": "commercialiser",
    "commercialiseriez": "commercialiser",
    "commercialiserions": "commercialiser",
    "commercialiserons": "commercialiser",
    "commercialiseront": "commercialiser",
    "commercialises": "commercialiser",
    "commercialisez": "commercialiser",
    "commercialisiez": "commercialiser",
    "commercialisions": "commercialiser",
    "commercialisons": "commercialiser",
    "commercialisâmes": "commercialiser",
    "commercialisât": "commercialiser",
    "commercialisâtes": "commercialiser",
    "commercialisèrent": "commercialiser",
    "commercialisé": "commercialiser",
    "commercialisée": "commercialiser",
    "commercialisées": "commercialiser",
    "commercialisés": "commercialiser",
    "commerciaux": "commercial",
    "commerciez": "commercer",
    "commercions": "commercer",
    "commercèrent": "commercer",
    "commercé": "commercer",
    "commerça": "commercer",
    "commerçai": "commercer",
    "commerçaient": "commercer",
    "commerçais": "commercer",
    "commerçait": "commercer",
    "commerçant": "commercer",
    "commerçante": "commerçant",
    "commerçantes": "commerçant",
    "commerçants": "commerçant",
    "commerças": "commercer",
    "commerçasse": "commercer",
    "commerçassent": "commercer",
    "commerçasses": "commercer",
    "commerçassiez": "commercer",
    "commerçassions": "commercer",
    "commerçons": "commercer",
    "commerçâmes": "commercer",
    "commerçât": "commercer",
    "commerçâtes": "commercer",
    "commet": "commettre",
    "commets": "commettre",
    "commettaient": "commettre",
    "commettais": "commettre",
    "commettait": "commettre",
    "commettant": "commettre",
    "commettants": "commettant",
    "commette": "commettre",
    "commettent": "commettre",
    "commettes": "commettre",
    "commettez": "commettre",
    "commettiez": "commettre",
    "commettions": "commettre",
    "commettons": "commettre",
    "commettra": "commettre",
    "commettrai": "commettre",
    "commettraient": "commettre",
    "commettrais": "commettre",
    "commettrait": "commettre",
    "commettras": "commettre",
    "commettrez": "commettre",
    "commettriez": "commettre",
    "commettrions": "commettre",
    "commettrons": "commettre",
    "commettront": "commettre",
    "comminatoires": "comminatoire",
    "comminutive": "comminutif",
    "commirent": "commettre",
    "commis": "commettre",
    "commis-voyageurs": "commis-voyageur",
    "commise": "commettre",
    "commises": "commettre",
    "commissaires": "commissaire",
    "commissaires-priseurs": "commissaire-priseur",
    "commissariats": "commissariat",
    "commisse": "commettre",
    "commissent": "commettre",
    "commisses": "commettre",
    "commissiez": "commettre",
    "commissionna": "commissionner",
    "commissionnai": "commissionner",
    "commissionnaient": "commissionner",
    "commissionnaires": "commissionnaire",
    "commissionnais": "commissionner",
    "commissionnait": "commissionner",
    "commissionnant": "commissionner",
    "commissionnas": "commissionner",
    "commissionnasse": "commissionner",
    "commissionnassent": "commissionner",
    "commissionnasses": "commissionner",
    "commissionnassiez": "commissionner",
    "commissionnassions": "commissionner",
    "commissionne": "commissionner",
    "commissionnent": "commissionner",
    "commissionnera": "commissionner",
    "commissionnerai": "commissionner",
    "commissionneraient": "commissionner",
    "commissionnerais": "commissionner",
    "commissionnerait": "commissionner",
    "commissionneras": "commissionner",
    "commissionnerez": "commissionner",
    "commissionneriez": "commissionner",
    "commissionnerions": "commissionner",
    "commissionnerons": "commissionner",
    "commissionneront": "commissionner",
    "commissionnes": "commissionner",
    "commissionnez": "commissionner",
    "commissionniez": "commissionner",
    "commissionnions": "commissionner",
    "commissionnons": "commissionner",
    "commissionnâmes": "commissionner",
    "commissionnât": "commissionner",
    "commissionnâtes": "commissionner",
    "commissionnèrent": "commissionner",
    "commissionné": "commissionner",
    "commissionnée": "commissionner",
    "commissionnées": "commissionner",
    "commissionnés": "commissionner",
    "commissions": "commission",
    "commissoires": "commissoire",
    "commissurale": "commissural",
    "commissures": "commissure",
    "commisérations": "commisération",
    "commit": "commettre",
    "commodes": "commode",
    "commodités": "commodité",
    "commodores": "commodore",
    "commotionna": "commotionner",
    "commotionnai": "commotionner",
    "commotionnaient": "commotionner",
    "commotionnais": "commotionner",
    "commotionnait": "commotionner",
    "commotionnant": "commotionner",
    "commotionnas": "commotionner",
    "commotionnasse": "commotionner",
    "commotionnassent": "commotionner",
    "commotionnasses": "commotionner",
    "commotionnassiez": "commotionner",
    "commotionnassions": "commotionner",
    "commotionne": "commotionner",
    "commotionnent": "commotionner",
    "commotionnera": "commotionner",
    "commotionnerai": "commotionner",
    "commotionneraient": "commotionner",
    "commotionnerais": "commotionner",
    "commotionnerait": "commotionner",
    "commotionneras": "commotionner",
    "commotionnerez": "commotionner",
    "commotionneriez": "commotionner",
    "commotionnerions": "commotionner",
    "commotionnerons": "commotionner",
    "commotionneront": "commotionner",
    "commotionnes": "commotionner",
    "commotionnez": "commotionner",
    "commotionniez": "commotionner",
    "commotionnions": "commotionner",
    "commotionnons": "commotionner",
    "commotionnâmes": "commotionner",
    "commotionnât": "commotionner",
    "commotionnâtes": "commotionner",
    "commotionnèrent": "commotionner",
    "commotionné": "commotionner",
    "commotionnée": "commotionner",
    "commotionnées": "commotionner",
    "commotionnés": "commotionner",
    "commotions": "commotion",
    "commua": "commuer",
    "commuai": "commuer",
    "commuaient": "commuer",
    "commuais": "commuer",
    "commuait": "commuer",
    "commuant": "commuer",
    "commuas": "commuer",
    "commuasse": "commuer",
    "commuassent": "commuer",
    "commuasses": "commuer",
    "commuassiez": "commuer",
    "commuassions": "commuer",
    "commue": "commuer",
    "commuent": "commuer",
    "commuera": "commuer",
    "commuerai": "commuer",
    "commueraient": "commuer",
    "commuerais": "commuer",
    "commuerait": "commuer",
    "commueras": "commuer",
    "commuerez": "commuer",
    "commueriez": "commuer",
    "commuerions": "commuer",
    "commuerons": "commuer",
    "commueront": "commuer",
    "commues": "commuer",
    "commuez": "commuer",
    "commuiez": "commuer",
    "commuions": "commuer",
    "communale": "communal",
    "communales": "communal",
    "communarde": "communard",
    "communardes": "communard",
    "communards": "communard",
    "communautaires": "communautaire",
    "communautés": "communauté",
    "communaux": "communal",
    "commune": "commun",
    "communes": "commune",
    "communia": "communier",
    "communiai": "communier",
    "communiaient": "communier",
    "communiais": "communier",
    "communiait": "communier",
    "communiant": "communier",
    "communiante": "communiant",
    "communiantes": "communiant",
    "communiants": "communiant",
    "communias": "communier",
    "communiasse": "communier",
    "communiassent": "communier",
    "communiasses": "communier",
    "communiassiez": "communier",
    "communiassions": "communier",
    "communicables": "communicable",
    "communicante": "communicant",
    "communicantes": "communicant",
    "communicants": "communicant",
    "communicateurs": "communicateur",
    "communicatifs": "communicatif",
    "communications": "communication",
    "communicative": "communicatif",
    "communie": "communier",
    "communient": "communier",
    "communiera": "communier",
    "communierai": "communier",
    "communieraient": "communier",
    "communierais": "communier",
    "communierait": "communier",
    "communieras": "communier",
    "communierez": "communier",
    "communieriez": "communier",
    "communierions": "communier",
    "communierons": "communier",
    "communieront": "communier",
    "communies": "communier",
    "communiez": "communier",
    "communiiez": "communier",
    "communiions": "communier",
    "communions": "communion",
    "communiqua": "communiquer",
    "communiquai": "communiquer",
    "communiquaient": "communiquer",
    "communiquais": "communiquer",
    "communiquait": "communiquer",
    "communiquant": "communiquer",
    "communiquas": "communiquer",
    "communiquasse": "communiquer",
    "communiquassent": "communiquer",
    "communiquasses": "communiquer",
    "communiquassiez": "communiquer",
    "communiquassions": "communiquer",
    "communique": "communiquer",
    "communiquent": "communiquer",
    "communiquera": "communiquer",
    "communiquerai": "communiquer",
    "communiqueraient": "communiquer",
    "communiquerais": "communiquer",
    "communiquerait": "communiquer",
    "communiqueras": "communiquer",
    "communiquerez": "communiquer",
    "communiqueriez": "communiquer",
    "communiquerions": "communiquer",
    "communiquerons": "communiquer",
    "communiqueront": "communiquer",
    "communiques": "communiquer",
    "communiquez": "communiquer",
    "communiquiez": "communiquer",
    "communiquions": "communiquer",
    "communiquons": "communiquer",
    "communiquâmes": "communiquer",
    "communiquât": "communiquer",
    "communiquâtes": "communiquer",
    "communiquèrent": "communiquer",
    "communiqué": "communiquer",
    "communiquée": "communiquer",
    "communiquées": "communiquer",
    "communiqués": "communiquer",
    "communisante": "communisant",
    "communisantes": "communisant",
    "communisants": "communisant",
    "communismes": "communisme",
    "communistes": "communiste",
    "communisée": "communiser",
    "communiâmes": "communier",
    "communiât": "communier",
    "communiâtes": "communier",
    "communièrent": "communier",
    "communié": "communier",
    "communs": "commun",
    "commuons": "commuer",
    "commuta": "commuter",
    "commutai": "commuter",
    "commutaient": "commuter",
    "commutais": "commuter",
    "commutait": "commuter",
    "commutant": "commuter",
    "commutas": "commuter",
    "commutasse": "commuter",
    "commutassent": "commuter",
    "commutasses": "commuter",
    "commutassiez": "commuter",
    "commutassions": "commuter",
    "commutateurs": "commutateur",
    "commute": "commuter",
    "commutent": "commuter",
    "commutera": "commuter",
    "commuterai": "commuter",
    "commuteraient": "commuter",
    "commuterais": "commuter",
    "commuterait": "commuter",
    "commuteras": "commuter",
    "commuterez": "commuter",
    "commuteriez": "commuter",
    "commuterions": "commuter",
    "commuterons": "commuter",
    "commuteront": "commuter",
    "commutes": "commuter",
    "commutez": "commuter",
    "commutiez": "commuter",
    "commutions": "commuter",
    "commutons": "commuter",
    "commutâmes": "commuter",
    "commutât": "commuter",
    "commutâtes": "commuter",
    "commutèrent": "commuter",
    "commuté": "commuter",
    "commutée": "commuter",
    "commutées": "commuter",
    "commutés": "commuter",
    "commuâmes": "commuer",
    "commuât": "commuer",
    "commuâtes": "commuer",
    "commuèrent": "commuer",
    "commué": "commuer",
    "commuée": "commuer",
    "commuées": "commuer",
    "commués": "commuer",
    "commères": "commère",
    "commémora": "commémorer",
    "commémorai": "commémorer",
    "commémoraient": "commémorer",
    "commémorais": "commémorer",
    "commémorait": "commémorer",
    "commémorant": "commémorer",
    "commémoras": "commémorer",
    "commémorasse": "commémorer",
    "commémorassent": "commémorer",
    "commémorasses": "commémorer",
    "commémorassiez": "commémorer",
    "commémorassions": "commémorer",
    "commémoratifs": "commémoratif",
    "commémorations": "commémoration",
    "commémorative": "commémoratif",
    "commémoratives": "commémoratif",
    "commémore": "commémorer",
    "commémorent": "commémorer",
    "commémorera": "commémorer",
    "commémorerai": "commémorer",
    "commémoreraient": "commémorer",
    "commémorerais": "commémorer",
    "commémorerait": "commémorer",
    "commémoreras": "commémorer",
    "commémorerez": "commémorer",
    "commémoreriez": "commémorer",
    "commémorerions": "commémorer",
    "commémorerons": "commémorer",
    "commémoreront": "commémorer",
    "commémores": "commémorer",
    "commémorez": "commémorer",
    "commémoriez": "commémorer",
    "commémorions": "commémorer",
    "commémorons": "commémorer",
    "commémorâmes": "commémorer",
    "commémorât": "commémorer",
    "commémorâtes": "commémorer",
    "commémorèrent": "commémorer",
    "commémoré": "commémorer",
    "commémorée": "commémorer",
    "commémorées": "commémorer",
    "commémorés": "commémorer",
    "commérages": "commérage",
    "commérait": "commérer",
    "commîmes": "commettre",
    "commît": "commettre",
    "commîtes": "commettre",
    "compacités": "compacité",
    "compacte": "compacter",
    "compactes": "compact",
    "compacteurs": "compacteur",
    "compacts": "compact",
    "compacté": "compacter",
    "compadres": "compadre",
    "compagne": "compagnon",
    "compagnes": "compagnon",
    "compagnies": "compagnie",
    "compagnonnages": "compagnonnage",
    "compagnonnes": "compagnon",
    "compagnons": "compagnon",
    "compara": "comparer",
    "comparabilités": "comparabilité",
    "comparables": "comparable",
    "comparai": "comparer",
    "comparaient": "comparer",
    "comparais": "comparer",
    "comparaisons": "comparaison",
    "comparaissaient": "comparaître",
    "comparaissais": "comparaître",
    "comparaissait": "comparaître",
    "comparaissant": "comparaître",
    "comparaisse": "comparaître",
    "comparaissent": "comparaître",
    "comparaisses": "comparaître",
    "comparaissez": "comparaître",
    "comparaissiez": "comparaître",
    "comparaissions": "comparaître",
    "comparaissons": "comparaître",
    "comparait": "comparer",
    "comparant": "comparer",
    "comparas": "comparer",
    "comparasse": "comparer",
    "comparassent": "comparer",
    "comparasses": "comparer",
    "comparassiez": "comparer",
    "comparassions": "comparer",
    "comparatifs": "comparatif",
    "comparative": "comparatif",
    "comparatives": "comparatif",
    "comparaît": "comparaître",
    "comparaîtra": "comparaître",
    "comparaîtrai": "comparaître",
    "comparaîtraient": "comparaître",
    "comparaîtrais": "comparaître",
    "comparaîtrait": "comparaître",
    "comparaîtras": "comparaître",
    "comparaîtrez": "comparaître",
    "comparaîtriez": "comparaître",
    "comparaîtrions": "comparaître",
    "comparaîtrons": "comparaître",
    "comparaîtront": "comparaître",
    "compare": "comparer",
    "comparent": "comparer",
    "comparera": "comparer",
    "comparerai": "comparer",
    "compareraient": "comparer",
    "comparerais": "comparer",
    "comparerait": "comparer",
    "compareras": "comparer",
    "comparerez": "comparer",
    "compareriez": "comparer",
    "comparerions": "comparer",
    "comparerons": "comparer",
    "compareront": "comparer",
    "compares": "comparer",
    "comparez": "comparer",
    "compariez": "comparer",
    "comparions": "comparer",
    "comparons": "comparer",
    "comparses": "comparse",
    "compartimentaient": "compartimenter",
    "compartimentant": "compartimenter",
    "compartimentations": "compartimentation",
    "compartimente": "compartimenter",
    "compartiments": "compartiment",
    "compartimenté": "compartimenter",
    "compartimentée": "compartimenter",
    "comparu": "comparaître",
    "comparurent": "comparaître",
    "comparus": "comparaître",
    "comparusse": "comparaître",
    "comparussent": "comparaître",
    "comparusses": "comparaître",
    "comparussiez": "comparaître",
    "comparussions": "comparaître",
    "comparut": "comparaître",
    "comparutions": "comparution",
    "comparâmes": "comparer",
    "comparât": "comparer",
    "comparâtes": "comparer",
    "comparèrent": "comparer",
    "comparé": "comparer",
    "comparée": "comparer",
    "comparées": "comparer",
    "comparés": "comparer",
    "comparûmes": "comparaître",
    "comparût": "comparaître",
    "comparûtes": "comparaître",
    "compassa": "compasser",
    "compassai": "compasser",
    "compassaient": "compasser",
    "compassais": "compasser",
    "compassait": "compasser",
    "compassant": "compasser",
    "compassas": "compasser",
    "compassasse": "compasser",
    "compassassent": "compasser",
    "compassasses": "compasser",
    "compassassiez": "compasser",
    "compassassions": "compasser",
    "compasse": "compasser",
    "compassent": "compasser",
    "compassera": "compasser",
    "compasserai": "compasser",
    "compasseraient": "compasser",
    "compasserais": "compasser",
    "compasserait": "compasser",
    "compasseras": "compasser",
    "compasserez": "compasser",
    "compasseriez": "compasser",
    "compasserions": "compasser",
    "compasserons": "compasser",
    "compasseront": "compasser",
    "compasses": "compasser",
    "compassez": "compasser",
    "compassiez": "compasser",
    "compassions": "compassion",
    "compassons": "compasser",
    "compassâmes": "compasser",
    "compassât": "compasser",
    "compassâtes": "compasser",
    "compassèrent": "compasser",
    "compassé": "compasser",
    "compassée": "compasser",
    "compassées": "compasser",
    "compassés": "compasser",
    "compati": "compatir",
    "compatibilités": "compatibilité",
    "compatibles": "compatible",
    "compatie": "compatir",
    "compatira": "compatir",
    "compatirai": "compatir",
    "compatiraient": "compatir",
    "compatirais": "compatir",
    "compatirait": "compatir",
    "compatiras": "compatir",
    "compatirent": "compatir",
    "compatirez": "compatir",
    "compatiriez": "compatir",
    "compatirions": "compatir",
    "compatirons": "compatir",
    "compatiront": "compatir",
    "compatis": "compatir",
    "compatissaient": "compatir",
    "compatissais": "compatir",
    "compatissait": "compatir",
    "compatissant": "compatir",
    "compatissante": "compatissant",
    "compatissantes": "compatissant",
    "compatissants": "compatissant",
    "compatisse": "compatir",
    "compatissent": "compatir",
    "compatisses": "compatir",
    "compatissez": "compatir",
    "compatissiez": "compatir",
    "compatissions": "compatir",
    "compatissons": "compatir",
    "compatit": "compatir",
    "compatriotes": "compatriote",
    "compatîmes": "compatir",
    "compatît": "compatir",
    "compatîtes": "compatir",
    "compendiums": "compendium",
    "compensa": "compenser",
    "compensai": "compenser",
    "compensaient": "compenser",
    "compensais": "compenser",
    "compensait": "compenser",
    "compensant": "compenser",
    "compensas": "compenser",
    "compensasse": "compenser",
    "compensassent": "compenser",
    "compensasses": "compenser",
    "compensassiez": "compenser",
    "compensassions": "compenser",
    "compensateurs": "compensateur",
    "compensations": "compensation",
    "compensatoires": "compensatoire",
    "compensatrice": "compensateur",
    "compensatrices": "compensateur",
    "compense": "compenser",
    "compensent": "compenser",
    "compensera": "compenser",
    "compenserai": "compenser",
    "compenseraient": "compenser",
    "compenserais": "compenser",
    "compenserait": "compenser",
    "compenseras": "compenser",
    "compenserez": "compenser",
    "compenseriez": "compenser",
    "compenserions": "compenser",
    "compenserons": "compenser",
    "compenseront": "compenser",
    "compenses": "compenser",
    "compensez": "compenser",
    "compensiez": "compenser",
    "compensions": "compenser",
    "compensons": "compenser",
    "compensâmes": "compenser",
    "compensât": "compenser",
    "compensâtes": "compenser",
    "compensèrent": "compenser",
    "compensé": "compenser",
    "compensée": "compenser",
    "compensées": "compenser",
    "compensés": "compenser",
    "compila": "compiler",
    "compilai": "compiler",
    "compilaient": "compiler",
    "compilais": "compiler",
    "compilait": "compiler",
    "compilant": "compiler",
    "compilas": "compiler",
    "compilasse": "compiler",
    "compilassent": "compiler",
    "compilasses": "compiler",
    "compilassiez": "compiler",
    "compilassions": "compiler",
    "compilations": "compilation",
    "compile": "compiler",
    "compilent": "compiler",
    "compilera": "compiler",
    "compilerai": "compiler",
    "compileraient": "compiler",
    "compilerais": "compiler",
    "compilerait": "compiler",
    "compileras": "compiler",
    "compilerez": "compiler",
    "compileriez": "compiler",
    "compilerions": "compiler",
    "compilerons": "compiler",
    "compileront": "compiler",
    "compiles": "compiler",
    "compilez": "compiler",
    "compiliez": "compiler",
    "compilions": "compiler",
    "compilons": "compiler",
    "compilâmes": "compiler",
    "compilât": "compiler",
    "compilâtes": "compiler",
    "compilèrent": "compiler",
    "compilé": "compiler",
    "compilée": "compiler",
    "compilées": "compiler",
    "compilés": "compiler",
    "compissait": "compisser",
    "compisse": "compisser",
    "compissé": "compisser",
    "complaintes": "complainte",
    "complaira": "complaire",
    "complairai": "complaire",
    "complairaient": "complaire",
    "complairais": "complaire",
    "complairait": "complaire",
    "complairas": "complaire",
    "complairez": "complaire",
    "complairiez": "complaire",
    "complairions": "complaire",
    "complairons": "complaire",
    "complairont": "complaire",
    "complais": "complaire",
    "complaisaient": "complaire",
    "complaisais": "complaire",
    "complaisait": "complaire",
    "complaisances": "complaisance",
    "complaisant": "complaire",
    "complaisante": "complaisant",
    "complaisantes": "complaisant",
    "complaisants": "complaisant",
    "complaise": "complaire",
    "complaisent": "complaire",
    "complaises": "complaire",
    "complaisez": "complaire",
    "complaisiez": "complaire",
    "complaisions": "complaire",
    "complaisons": "complaire",
    "complaît": "complaire",
    "complets": "complet",
    "complexait": "complexer",
    "complexe": "complexer",
    "complexes": "complexer",
    "complexions": "complexion",
    "complexités": "complexité",
    "complexé": "complexer",
    "complexée": "complexer",
    "complexés": "complexer",
    "complications": "complication",
    "complices": "complice",
    "complicités": "complicité",
    "complimenta": "complimenter",
    "complimentai": "complimenter",
    "complimentaient": "complimenter",
    "complimentais": "complimenter",
    "complimentait": "complimenter",
    "complimentant": "complimenter",
    "complimentas": "complimenter",
    "complimentasse": "complimenter",
    "complimentassent": "complimenter",
    "complimentasses": "complimenter",
    "complimentassiez": "complimenter",
    "complimentassions": "complimenter",
    "complimente": "complimenter",
    "complimentent": "complimenter",
    "complimentera": "complimenter",
    "complimenterai": "complimenter",
    "complimenteraient": "complimenter",
    "complimenterais": "complimenter",
    "complimenterait": "complimenter",
    "complimenteras": "complimenter",
    "complimenterez": "complimenter",
    "complimenteriez": "complimenter",
    "complimenterions": "complimenter",
    "complimenterons": "complimenter",
    "complimenteront": "complimenter",
    "complimentes": "complimenter",
    "complimentez": "complimenter",
    "complimentiez": "complimenter",
    "complimentions": "complimenter",
    "complimentons": "complimenter",
    "compliments": "compliment",
    "complimentâmes": "complimenter",
    "complimentât": "complimenter",
    "complimentâtes": "complimenter",
    "complimentèrent": "complimenter",
    "complimenté": "complimenter",
    "complimentée": "complimenter",
    "complimentées": "complimenter",
    "complimentés": "complimenter",
    "compliqua": "compliquer",
    "compliquai": "compliquer",
    "compliquaient": "compliquer",
    "compliquais": "compliquer",
    "compliquait": "compliquer",
    "compliquant": "compliquer",
    "compliquas": "compliquer",
    "compliquasse": "compliquer",
    "compliquassent": "compliquer",
    "compliquasses": "compliquer",
    "compliquassiez": "compliquer",
    "compliquassions": "compliquer",
    "complique": "compliquer",
    "compliquent": "compliquer",
    "compliquera": "compliquer",
    "compliquerai": "compliquer",
    "compliqueraient": "compliquer",
    "compliquerais": "compliquer",
    "compliquerait": "compliquer",
    "compliqueras": "compliquer",
    "compliquerez": "compliquer",
    "compliqueriez": "compliquer",
    "compliquerions": "compliquer",
    "compliquerons": "compliquer",
    "compliqueront": "compliquer",
    "compliques": "compliquer",
    "compliquez": "compliquer",
    "compliquiez": "compliquer",
    "compliquions": "compliquer",
    "compliquons": "compliquer",
    "compliquâmes": "compliquer",
    "compliquât": "compliquer",
    "compliquâtes": "compliquer",
    "compliquèrent": "compliquer",
    "compliqué": "compliquer",
    "compliquée": "compliquer",
    "compliquées": "compliquer",
    "compliqués": "compliquer",
    "complota": "comploter",
    "complotai": "comploter",
    "complotaient": "comploter",
    "complotais": "comploter",
    "complotait": "comploter",
    "complotant": "comploter",
    "complotas": "comploter",
    "complotasse": "comploter",
    "complotassent": "comploter",
    "complotasses": "comploter",
    "complotassiez": "comploter",
    "complotassions": "comploter",
    "complote": "comploter",
    "complotent": "comploter",
    "complotera": "comploter",
    "comploterai": "comploter",
    "comploteraient": "comploter",
    "comploterais": "comploter",
    "comploterait": "comploter",
    "comploteras": "comploter",
    "comploterez": "comploter",
    "comploteriez": "comploter",
    "comploterions": "comploter",
    "comploterons": "comploter",
    "comploteront": "comploter",
    "complotes": "comploter",
    "comploteurs": "comploteur",
    "comploteuse": "comploteur",
    "complotez": "comploter",
    "complotiez": "comploter",
    "complotions": "comploter",
    "complotons": "comploter",
    "complots": "complot",
    "complotâmes": "comploter",
    "complotât": "comploter",
    "complotâtes": "comploter",
    "complotèrent": "comploter",
    "comploté": "comploter",
    "complotée": "comploter",
    "complotées": "comploter",
    "complotés": "comploter",
    "complu": "complaire",
    "complurent": "complaire",
    "complus": "complaire",
    "complusse": "complaire",
    "complussent": "complaire",
    "complusses": "complaire",
    "complussiez": "complaire",
    "complussions": "complaire",
    "complut": "complaire",
    "complète": "compléter",
    "complètements": "complètement",
    "complètent": "compléter",
    "complètes": "compléter",
    "complémentaires": "complémentaire",
    "complémentarités": "complémentarité",
    "compléments": "complément",
    "compléta": "compléter",
    "complétai": "compléter",
    "complétaient": "compléter",
    "complétais": "compléter",
    "complétait": "compléter",
    "complétant": "compléter",
    "complétas": "compléter",
    "complétasse": "compléter",
    "complétassent": "compléter",
    "complétasses": "compléter",
    "complétassiez": "compléter",
    "complétassions": "compléter",
    "complétera": "compléter",
    "compléterai": "compléter",
    "compléteraient": "compléter",
    "compléterais": "compléter",
    "compléterait": "compléter",
    "compléteras": "compléter",
    "compléterez": "compléter",
    "compléteriez": "compléter",
    "compléterions": "compléter",
    "compléterons": "compléter",
    "compléteront": "compléter",
    "complétez": "compléter",
    "complétiez": "compléter",
    "complétions": "compléter",
    "complétons": "compléter",
    "complétâmes": "compléter",
    "complétât": "compléter",
    "complétâtes": "compléter",
    "complétèrent": "compléter",
    "complété": "compléter",
    "complétée": "compléter",
    "complétées": "compléter",
    "complétés": "compléter",
    "complûmes": "complaire",
    "complût": "complaire",
    "complûtes": "complaire",
    "componctions": "componction",
    "components": "component",
    "comporta": "comporter",
    "comportai": "comporter",
    "comportaient": "comporter",
    "comportais": "comporter",
    "comportait": "comporter",
    "comportant": "comporter",
    "comportas": "comporter",
    "comportasse": "comporter",
    "comportassent": "comporter",
    "comportasses": "comporter",
    "comportassiez": "comporter",
    "comportassions": "comporter",
    "comporte": "comporter",
    "comportementale": "comportemental",
    "comportementales": "comportemental",
    "comportementaux": "comportemental",
    "comportements": "comportement",
    "comportent": "comporter",
    "comportera": "comporter",
    "comporterai": "comporter",
    "comporteraient": "comporter",
    "comporterais": "comporter",
    "comporterait": "comporter",
    "comporteras": "comporter",
    "comporterez": "comporter",
    "comporteriez": "comporter",
    "comporterions": "comporter",
    "comporterons": "comporter",
    "comporteront": "comporter",
    "comportes": "comporter",
    "comportez": "comporter",
    "comportiez": "comporter",
    "comportions": "comporter",
    "comportons": "comporter",
    "comportâmes": "comporter",
    "comportât": "comporter",
    "comportâtes": "comporter",
    "comportèrent": "comporter",
    "comporté": "comporter",
    "comportée": "comporter",
    "comportées": "comporter",
    "comportés": "comporter",
    "composa": "composer",
    "composai": "composer",
    "composaient": "composer",
    "composais": "composer",
    "composait": "composer",
    "composant": "composer",
    "composante": "composant",
    "composantes": "composante",
    "composants": "composant",
    "composas": "composer",
    "composasse": "composer",
    "composassent": "composer",
    "composasses": "composer",
    "composassiez": "composer",
    "composassions": "composer",
    "compose": "composer",
    "composent": "composer",
    "composera": "composer",
    "composerai": "composer",
    "composeraient": "composer",
    "composerais": "composer",
    "composerait": "composer",
    "composeras": "composer",
    "composerez": "composer",
    "composeriez": "composer",
    "composerions": "composer",
    "composerons": "composer",
    "composeront": "composer",
    "composes": "composer",
    "composez": "composer",
    "composiez": "composer",
    "composions": "composer",
    "composites": "composite",
    "compositeurs": "compositeur",
    "compositions": "composition",
    "compositrice": "compositeur",
    "composons": "composer",
    "composta": "composter",
    "compostai": "composter",
    "compostaient": "composter",
    "compostais": "composter",
    "compostait": "composter",
    "compostant": "composter",
    "compostas": "composter",
    "compostasse": "composter",
    "compostassent": "composter",
    "compostasses": "composter",
    "compostassiez": "composter",
    "compostassions": "composter",
    "composte": "composter",
    "compostent": "composter",
    "compostera": "composter",
    "composterai": "composter",
    "composteraient": "composter",
    "composterais": "composter",
    "composterait": "composter",
    "composteras": "composter",
    "composterez": "composter",
    "composteriez": "composter",
    "composterions": "composter",
    "composterons": "composter",
    "composteront": "composter",
    "compostes": "composter",
    "composteurs": "composteur",
    "compostez": "composter",
    "compostiez": "composter",
    "compostions": "composter",
    "compostons": "composter",
    "composts": "compost",
    "compostâmes": "composter",
    "compostât": "composter",
    "compostâtes": "composter",
    "compostèrent": "composter",
    "composté": "composter",
    "compostée": "composter",
    "compostées": "composter",
    "compostés": "composter",
    "composâmes": "composer",
    "composât": "composer",
    "composâtes": "composer",
    "composèrent": "composer",
    "composé": "composer",
    "composée": "composer",
    "composées": "composer",
    "composés": "composer",
    "compotes": "compote",
    "compotiers": "compotier",
    "comprenaient": "comprendre",
    "comprenais": "comprendre",
    "comprenait": "comprendre",
    "comprenant": "comprendre",
    "comprend": "comprendre",
    "comprendra": "comprendre",
    "comprendrai": "comprendre",
    "comprendraient": "comprendre",
    "comprendrais": "comprendre",
    "comprendrait": "comprendre",
    "comprendras": "comprendre",
    "comprendrez": "comprendre",
    "comprendriez": "comprendre",
    "comprendrions": "comprendre",
    "comprendrons": "comprendre",
    "comprendront": "comprendre",
    "comprends": "comprendre",
    "comprenez": "comprendre",
    "compreniez": "comprendre",
    "comprenions": "comprendre",
    "comprenne": "comprendre",
    "comprennent": "comprendre",
    "comprennes": "comprendre",
    "comprenons": "comprendre",
    "compresse": "compresser",
    "compresses": "compresse",
    "compresseurs": "compresseur",
    "compressibles": "compressible",
    "compressions": "compression",
    "compressé": "compresser",
    "compressée": "compresser",
    "compressées": "compressé",
    "compressés": "compresser",
    "comprima": "comprimer",
    "comprimai": "comprimer",
    "comprimaient": "comprimer",
    "comprimais": "comprimer",
    "comprimait": "comprimer",
    "comprimant": "comprimer",
    "comprimas": "comprimer",
    "comprimasse": "comprimer",
    "comprimassent": "comprimer",
    "comprimasses": "comprimer",
    "comprimassiez": "comprimer",
    "comprimassions": "comprimer",
    "comprime": "comprimer",
    "compriment": "comprimer",
    "comprimera": "comprimer",
    "comprimerai": "comprimer",
    "comprimeraient": "comprimer",
    "comprimerais": "comprimer",
    "comprimerait": "comprimer",
    "comprimeras": "comprimer",
    "comprimerez": "comprimer",
    "comprimeriez": "comprimer",
    "comprimerions": "comprimer",
    "comprimerons": "comprimer",
    "comprimeront": "comprimer",
    "comprimes": "comprimer",
    "comprimez": "comprimer",
    "comprimiez": "comprimer",
    "comprimions": "comprimer",
    "comprimons": "comprimer",
    "comprimâmes": "comprimer",
    "comprimât": "comprimer",
    "comprimâtes": "comprimer",
    "comprimèrent": "comprimer",
    "comprimé": "comprimer",
    "comprimée": "comprimer",
    "comprimées": "comprimer",
    "comprimés": "comprimer",
    "comprirent": "comprendre",
    "compris": "comprendre",
    "comprise": "compris",
    "comprises": "compris",
    "comprisse": "comprendre",
    "comprissent": "comprendre",
    "comprisses": "comprendre",
    "comprissiez": "comprendre",
    "comprissions": "comprendre",
    "comprit": "comprendre",
    "compromet": "compromettre",
    "compromets": "compromettre",
    "compromettaient": "compromettre",
    "compromettais": "compromettre",
    "compromettait": "compromettre",
    "compromettant": "compromettre",
    "compromettante": "compromettant",
    "compromettantes": "compromettant",
    "compromettants": "compromettant",
    "compromette": "compromettre",
    "compromettent": "compromettre",
    "compromettes": "compromettre",
    "compromettez": "compromettre",
    "compromettiez": "compromettre",
    "compromettions": "compromettre",
    "compromettons": "compromettre",
    "compromettra": "compromettre",
    "compromettrai": "compromettre",
    "compromettraient": "compromettre",
    "compromettrais": "compromettre",
    "compromettrait": "compromettre",
    "compromettras": "compromettre",
    "compromettrez": "compromettre",
    "compromettriez": "compromettre",
    "compromettrions": "compromettre",
    "compromettrons": "compromettre",
    "compromettront": "compromettre",
    "compromirent": "compromettre",
    "compromis": "compromettre",
    "compromise": "compromettre",
    "compromises": "compromettre",
    "compromisse": "compromettre",
    "compromissent": "compromettre",
    "compromisses": "compromettre",
    "compromissiez": "compromettre",
    "compromissions": "compromission",
    "compromit": "compromettre",
    "compromîmes": "compromettre",
    "compromît": "compromettre",
    "compromîtes": "compromettre",
    "compréhensibles": "compréhensible",
    "compréhensifs": "compréhensif",
    "compréhensions": "compréhension",
    "compréhensive": "compréhensif",
    "compréhensives": "compréhensif",
    "comprîmes": "comprendre",
    "comprît": "comprendre",
    "comprîtes": "comprendre",
    "compta": "compter",
    "comptabilisa": "comptabiliser",
    "comptabilisai": "comptabiliser",
    "comptabilisaient": "comptabiliser",
    "comptabilisais": "comptabiliser",
    "comptabilisait": "comptabiliser",
    "comptabilisant": "comptabiliser",
    "comptabilisas": "comptabiliser",
    "comptabilisasse": "comptabiliser",
    "comptabilisassent": "comptabiliser",
    "comptabilisasses": "comptabiliser",
    "comptabilisassiez": "comptabiliser",
    "comptabilisassions": "comptabiliser",
    "comptabilisations": "comptabilisation",
    "comptabilise": "comptabiliser",
    "comptabilisent": "comptabiliser",
    "comptabilisera": "comptabiliser",
    "comptabiliserai": "comptabiliser",
    "comptabiliseraient": "comptabiliser",
    "comptabiliserais": "comptabiliser",
    "comptabiliserait": "comptabiliser",
    "comptabiliseras": "comptabiliser",
    "comptabiliserez": "comptabiliser",
    "comptabiliseriez": "comptabiliser",
    "comptabiliserions": "comptabiliser",
    "comptabiliserons": "comptabiliser",
    "comptabiliseront": "comptabiliser",
    "comptabilises": "comptabiliser",
    "comptabilisez": "comptabiliser",
    "comptabilisiez": "comptabiliser",
    "comptabilisions": "comptabiliser",
    "comptabilisons": "comptabiliser",
    "comptabilisâmes": "comptabiliser",
    "comptabilisât": "comptabiliser",
    "comptabilisâtes": "comptabiliser",
    "comptabilisèrent": "comptabiliser",
    "comptabilisé": "comptabiliser",
    "comptabilisée": "comptabiliser",
    "comptabilisées": "comptabiliser",
    "comptabilisés": "comptabiliser",
    "comptabilités": "comptabilité",
    "comptables": "comptable",
    "comptages": "comptage",
    "comptai": "compter",
    "comptaient": "compter",
    "comptais": "compter",
    "comptait": "compter",
    "comptant": "compter",
    "comptas": "compter",
    "comptasse": "compter",
    "comptassent": "compter",
    "comptasses": "compter",
    "comptassiez": "compter",
    "comptassions": "compter",
    "compte": "compter",
    "comptent": "compter",
    "comptera": "compter",
    "compterai": "compter",
    "compteraient": "compter",
    "compterais": "compter",
    "compterait": "compter",
    "compteras": "compter",
    "compterez": "compter",
    "compteriez": "compter",
    "compterions": "compter",
    "compterons": "compter",
    "compteront": "compter",
    "comptes": "compter",
    "comptes-chèques": "compte-chèques",
    "comptes-rendus": "compte-rendu",
    "compteurs": "compteur",
    "comptez": "compter",
    "comptiez": "compter",
    "comptines": "comptine",
    "comptions": "compter",
    "comptoirs": "comptoir",
    "comptons": "compter",
    "comptâmes": "compter",
    "comptât": "compter",
    "comptâtes": "compter",
    "comptèrent": "compter",
    "compté": "compter",
    "comptée": "compter",
    "comptées": "compter",
    "comptés": "compter",
    "compulsa": "compulser",
    "compulsai": "compulser",
    "compulsaient": "compulser",
    "compulsais": "compulser",
    "compulsait": "compulser",
    "compulsant": "compulser",
    "compulsas": "compulser",
    "compulsasse": "compulser",
    "compulsassent": "compulser",
    "compulsasses": "compulser",
    "compulsassiez": "compulser",
    "compulsassions": "compulser",
    "compulse": "compulser",
    "compulsent": "compulser",
    "compulsera": "compulser",
    "compulserai": "compulser",
    "compulseraient": "compulser",
    "compulserais": "compulser",
    "compulserait": "compulser",
    "compulseras": "compulser",
    "compulserez": "compulser",
    "compulseriez": "compulser",
    "compulserions": "compulser",
    "compulserons": "compulser",
    "compulseront": "compulser",
    "compulses": "compulser",
    "compulsez": "compulser",
    "compulsiez": "compulser",
    "compulsifs": "compulsif",
    "compulsions": "compulser",
    "compulsive": "compulsif",
    "compulsives": "compulsif",
    "compulsons": "compulser",
    "compulsâmes": "compulser",
    "compulsât": "compulser",
    "compulsâtes": "compulser",
    "compulsèrent": "compulser",
    "compulsé": "compulser",
    "compulsée": "compulser",
    "compulsées": "compulser",
    "compulsés": "compulser",
    "computations": "computation",
    "computers": "computer",
    "computeurs": "computeur",
    "computs": "comput",
    "compères": "compère",
    "compères-loriots": "compère-loriot",
    "compète": "compéter",
    "compètes": "compéter",
    "compérages": "compérage",
    "compétant": "compéter",
    "compétences": "compétence",
    "compétente": "compétent",
    "compétentes": "compétent",
    "compétents": "compétent",
    "compétiteurs": "compétiteur",
    "compétitifs": "compétitif",
    "compétitions": "compétition",
    "compétitive": "compétitif",
    "compétitives": "compétitif",
    "compétitivités": "compétitivité",
    "compétitrice": "compétiteur",
    "comtale": "comtal",
    "comtes": "comte",
    "comtesse": "comte",
    "comtesses": "comte",
    "comtoise": "comtois",
    "comtés": "comté",
    "comètes": "comète",
    "comédienne": "comédien",
    "comédiennes": "comédien",
    "comédiens": "comédien",
    "comédies": "comédie",
    "comédons": "comédon",
    "conarde": "conard",
    "conards": "conard",
    "conasses": "conasse",
    "concassa": "concasser",
    "concassages": "concassage",
    "concassai": "concasser",
    "concassaient": "concasser",
    "concassais": "concasser",
    "concassait": "concasser",
    "concassant": "concasser",
    "concassas": "concasser",
    "concassasse": "concasser",
    "concassassent": "concasser",
    "concassasses": "concasser",
    "concassassiez": "concasser",
    "concassassions": "concasser",
    "concasse": "concasser",
    "concassent": "concasser",
    "concassera": "concasser",
    "concasserai": "concasser",
    "concasseraient": "concasser",
    "concasserais": "concasser",
    "concasserait": "concasser",
    "concasseras": "concasser",
    "concasserez": "concasser",
    "concasseriez": "concasser",
    "concasserions": "concasser",
    "concasserons": "concasser",
    "concasseront": "concasser",
    "concasses": "concasser",
    "concasseurs": "concasseur",
    "concassez": "concasser",
    "concassiez": "concasser",
    "concassions": "concasser",
    "concassons": "concasser",
    "concassâmes": "concasser",
    "concassât": "concasser",
    "concassâtes": "concasser",
    "concassèrent": "concasser",
    "concassé": "concasser",
    "concassée": "concasser",
    "concassées": "concasser",
    "concassés": "concasser",
    "concaves": "concave",
    "concavités": "concavité",
    "concentra": "concentrer",
    "concentrai": "concentrer",
    "concentraient": "concentrer",
    "concentrais": "concentrer",
    "concentrait": "concentrer",
    "concentrant": "concentrer",
    "concentras": "concentrer",
    "concentrasse": "concentrer",
    "concentrassent": "concentrer",
    "concentrasses": "concentrer",
    "concentrassiez": "concentrer",
    "concentrassions": "concentrer",
    "concentratifs": "concentratif",
    "concentrationnaires": "concentrationnaire",
    "concentrations": "concentration",
    "concentratives": "concentratif",
    "concentre": "concentrer",
    "concentrent": "concentrer",
    "concentrera": "concentrer",
    "concentrerai": "concentrer",
    "concentreraient": "concentrer",
    "concentrerais": "concentrer",
    "concentrerait": "concentrer",
    "concentreras": "concentrer",
    "concentrerez": "concentrer",
    "concentreriez": "concentrer",
    "concentrerions": "concentrer",
    "concentrerons": "concentrer",
    "concentreront": "concentrer",
    "concentres": "concentrer",
    "concentrez": "concentrer",
    "concentriez": "concentrer",
    "concentrions": "concentrer",
    "concentriques": "concentrique",
    "concentrons": "concentrer",
    "concentrâmes": "concentrer",
    "concentrât": "concentrer",
    "concentrâtes": "concentrer",
    "concentrèrent": "concentrer",
    "concentré": "concentrer",
    "concentrée": "concentrer",
    "concentrées": "concentrer",
    "concentrés": "concentrer",
    "concepteurs": "concepteur",
    "conceptions": "conception",
    "conceptrice": "concepteur",
    "conceptrices": "concepteur",
    "concepts": "concept",
    "conceptualise": "conceptualiser",
    "conceptualisé": "conceptualiser",
    "conceptuelle": "conceptuel",
    "conceptuelles": "conceptuel",
    "conceptuels": "conceptuel",
    "concerna": "concerner",
    "concernai": "concerner",
    "concernaient": "concerner",
    "concernais": "concerner",
    "concernait": "concerner",
    "concernant": "concerner",
    "concernas": "concerner",
    "concernasse": "concerner",
    "concernassent": "concerner",
    "concernasses": "concerner",
    "concernassiez": "concerner",
    "concernassions": "concerner",
    "concerne": "concerner",
    "concernent": "concerner",
    "concernera": "concerner",
    "concernerai": "concerner",
    "concerneraient": "concerner",
    "concernerais": "concerner",
    "concernerait": "concerner",
    "concerneras": "concerner",
    "concernerez": "concerner",
    "concerneriez": "concerner",
    "concernerions": "concerner",
    "concernerons": "concerner",
    "concerneront": "concerner",
    "concernes": "concerner",
    "concernez": "concerner",
    "concerniez": "concerner",
    "concernions": "concerner",
    "concernons": "concerner",
    "concernâmes": "concerner",
    "concernât": "concerner",
    "concernâtes": "concerner",
    "concernèrent": "concerner",
    "concerné": "concerner",
    "concernée": "concerner",
    "concernées": "concerner",
    "concernés": "concerner",
    "concerta": "concerter",
    "concertai": "concerter",
    "concertaient": "concerter",
    "concertais": "concerter",
    "concertait": "concerter",
    "concertant": "concerter",
    "concertas": "concerter",
    "concertasse": "concerter",
    "concertassent": "concerter",
    "concertasses": "concerter",
    "concertassiez": "concerter",
    "concertassions": "concerter",
    "concertations": "concertation",
    "concerte": "concerter",
    "concertent": "concerter",
    "concertera": "concerter",
    "concerterai": "concerter",
    "concerteraient": "concerter",
    "concerterais": "concerter",
    "concerterait": "concerter",
    "concerteras": "concerter",
    "concerterez": "concerter",
    "concerteriez": "concerter",
    "concerterions": "concerter",
    "concerterons": "concerter",
    "concerteront": "concerter",
    "concertes": "concerter",
    "concertez": "concerter",
    "concertiez": "concerter",
    "concertions": "concerter",
    "concertons": "concerter",
    "concertos": "concerto",
    "concerts": "concert",
    "concertâmes": "concerter",
    "concertât": "concerter",
    "concertâtes": "concerter",
    "concertèrent": "concerter",
    "concerté": "concerter",
    "concertée": "concerter",
    "concertées": "concerter",
    "concertés": "concerter",
    "concessionnaires": "concessionnaire",
    "concessions": "concession",
    "concevables": "concevable",
    "concevaient": "concevoir",
    "concevais": "concevoir",
    "concevait": "concevoir",
    "concevant": "concevoir",
    "concevez": "concevoir",
    "conceviez": "concevoir",
    "concevions": "concevoir",
    "concevons": "concevoir",
    "concevra": "concevoir",
    "concevrai": "concevoir",
    "concevraient": "concevoir",
    "concevrais": "concevoir",
    "concevrait": "concevoir",
    "concevras": "concevoir",
    "concevrez": "concevoir",
    "concevriez": "concevoir",
    "concevrions": "concevoir",
    "concevrons": "concevoir",
    "concevront": "concevoir",
    "conchiaient": "conchier",
    "conchie": "conchier",
    "conchié": "conchier",
    "conchoïdale": "conchoïdal",
    "conchoïdales": "conchoïdal",
    "conchoïdaux": "conchoïdal",
    "conchylicoles": "conchylicole",
    "conchyliculteurs": "conchyliculteur",
    "conchylicultrice": "conchyliculteur",
    "conchylicultrices": "conchyliculteur",
    "conchyliologies": "conchyliologie",
    "conciergeries": "conciergerie",
    "concierges": "concierge",
    "concilations": "concilation",
    "conciles": "concile",
    "concilia": "concilier",
    "conciliables": "conciliable",
    "conciliabules": "conciliabule",
    "conciliai": "concilier",
    "conciliaient": "concilier",
    "conciliaires": "conciliaire",
    "conciliais": "concilier",
    "conciliait": "concilier",
    "conciliant": "concilier",
    "conciliante": "conciliant",
    "conciliantes": "conciliant",
    "conciliants": "conciliant",
    "concilias": "concilier",
    "conciliasse": "concilier",
    "conciliassent": "concilier",
    "conciliasses": "concilier",
    "conciliassiez": "concilier",
    "conciliassions": "concilier",
    "conciliateurs": "conciliateur",
    "conciliations": "conciliation",
    "conciliatrice": "conciliateur",
    "conciliatrices": "conciliateur",
    "concilie": "concilier",
    "concilient": "concilier",
    "conciliera": "concilier",
    "concilierai": "concilier",
    "concilieraient": "concilier",
    "concilierais": "concilier",
    "concilierait": "concilier",
    "concilieras": "concilier",
    "concilierez": "concilier",
    "concilieriez": "concilier",
    "concilierions": "concilier",
    "concilierons": "concilier",
    "concilieront": "concilier",
    "concilies": "concilier",
    "conciliez": "concilier",
    "conciliiez": "concilier",
    "conciliions": "concilier",
    "concilions": "concilier",
    "conciliâmes": "concilier",
    "conciliât": "concilier",
    "conciliâtes": "concilier",
    "concilièrent": "concilier",
    "concilié": "concilier",
    "conciliée": "concilier",
    "conciliées": "concilier",
    "conciliés": "concilier",
    "concise": "concis",
    "concises": "concis",
    "concisions": "concision",
    "concitoyenne": "concitoyen",
    "concitoyennes": "concitoyen",
    "concitoyens": "concitoyen",
    "conclaves": "conclave",
    "conclu": "conclure",
    "concluaient": "conclure",
    "concluais": "conclure",
    "concluait": "conclure",
    "concluant": "conclure",
    "concluante": "concluant",
    "concluantes": "concluant",
    "concluants": "concluant",
    "conclue": "conclure",
    "concluent": "conclure",
    "conclues": "conclure",
    "concluez": "conclure",
    "concluiez": "conclure",
    "concluions": "conclure",
    "concluons": "conclure",
    "conclura": "conclure",
    "conclurai": "conclure",
    "concluraient": "conclure",
    "conclurais": "conclure",
    "conclurait": "conclure",
    "concluras": "conclure",
    "conclurent": "conclure",
    "conclurez": "conclure",
    "concluriez": "conclure",
    "conclurions": "conclure",
    "conclurons": "conclure",
    "concluront": "conclure",
    "conclus": "conclure",
    "conclusions": "conclusion",
    "conclusive": "conclusif",
    "conclusse": "conclure",
    "conclussent": "conclure",
    "conclusses": "conclure",
    "conclussiez": "conclure",
    "conclussions": "conclure",
    "conclut": "conclure",
    "conclûmes": "conclure",
    "conclût": "conclure",
    "conclûtes": "conclure",
    "concocta": "concocter",
    "concoctai": "concocter",
    "concoctaient": "concocter",
    "concoctais": "concocter",
    "concoctait": "concocter",
    "concoctant": "concocter",
    "concoctas": "concocter",
    "concoctasse": "concocter",
    "concoctassent": "concocter",
    "concoctasses": "concocter",
    "concoctassiez": "concocter",
    "concoctassions": "concocter",
    "concocte": "concocter",
    "concoctent": "concocter",
    "concoctera": "concocter",
    "concocterai": "concocter",
    "concocteraient": "concocter",
    "concocterais": "concocter",
    "concocterait": "concocter",
    "concocteras": "concocter",
    "concocterez": "concocter",
    "concocteriez": "concocter",
    "concocterions": "concocter",
    "concocterons": "concocter",
    "concocteront": "concocter",
    "concoctes": "concocter",
    "concoctez": "concocter",
    "concoctiez": "concocter",
    "concoctions": "concocter",
    "concoctons": "concocter",
    "concoctâmes": "concocter",
    "concoctât": "concocter",
    "concoctâtes": "concocter",
    "concoctèrent": "concocter",
    "concocté": "concocter",
    "concoctée": "concocter",
    "concoctées": "concocter",
    "concoctés": "concocter",
    "concombres": "concombre",
    "concomitances": "concomitance",
    "concomitante": "concomitant",
    "concomitantes": "concomitant",
    "concomitants": "concomitant",
    "concorda": "concorder",
    "concordai": "concorder",
    "concordaient": "concorder",
    "concordais": "concorder",
    "concordait": "concorder",
    "concordances": "concordance",
    "concordant": "concorder",
    "concordante": "concordant",
    "concordantes": "concordant",
    "concordants": "concordant",
    "concordas": "concorder",
    "concordasse": "concorder",
    "concordassent": "concorder",
    "concordasses": "concorder",
    "concordassiez": "concorder",
    "concordassions": "concorder",
    "concordats": "concordat",
    "concorde": "concorder",
    "concordent": "concorder",
    "concordera": "concorder",
    "concorderai": "concorder",
    "concorderaient": "concorder",
    "concorderais": "concorder",
    "concorderait": "concorder",
    "concorderas": "concorder",
    "concorderez": "concorder",
    "concorderiez": "concorder",
    "concorderions": "concorder",
    "concorderons": "concorder",
    "concorderont": "concorder",
    "concordes": "concorder",
    "concordez": "concorder",
    "concordiez": "concorder",
    "concordions": "concorder",
    "concordistes": "concordiste",
    "concordons": "concorder",
    "concordâmes": "concorder",
    "concordât": "concorder",
    "concordâtes": "concorder",
    "concordèrent": "concorder",
    "concordé": "concorder",
    "concordée": "concorder",
    "concordées": "concorder",
    "concordés": "concorder",
    "concouraient": "concourir",
    "concourais": "concourir",
    "concourait": "concourir",
    "concourant": "concourir",
    "concoure": "concourir",
    "concourent": "concourir",
    "concoures": "concourir",
    "concourez": "concourir",
    "concouriez": "concourir",
    "concourions": "concourir",
    "concourons": "concourir",
    "concourra": "concourir",
    "concourrai": "concourir",
    "concourraient": "concourir",
    "concourrais": "concourir",
    "concourrait": "concourir",
    "concourras": "concourir",
    "concourrez": "concourir",
    "concourriez": "concourir",
    "concourrions": "concourir",
    "concourrons": "concourir",
    "concourront": "concourir",
    "concours": "concourir",
    "concourt": "concourir",
    "concouru": "concourir",
    "concoururent": "concourir",
    "concourus": "concourir",
    "concourusse": "concourir",
    "concourussent": "concourir",
    "concourusses": "concourir",
    "concourussiez": "concourir",
    "concourussions": "concourir",
    "concourut": "concourir",
    "concourûmes": "concourir",
    "concourût": "concourir",
    "concourûtes": "concourir",
    "concrets": "concret",
    "concrète": "concréter",
    "concrètes": "concret",
    "concrétions": "concrétion",
    "concrétisa": "concrétiser",
    "concrétisai": "concrétiser",
    "concrétisaient": "concrétiser",
    "concrétisais": "concrétiser",
    "concrétisait": "concrétiser",
    "concrétisant": "concrétiser",
    "concrétisas": "concrétiser",
    "concrétisasse": "concrétiser",
    "concrétisassent": "concrétiser",
    "concrétisasses": "concrétiser",
    "concrétisassiez": "concrétiser",
    "concrétisassions": "concrétiser",
    "concrétisations": "concrétisation",
    "concrétise": "concrétiser",
    "concrétisent": "concrétiser",
    "concrétisera": "concrétiser",
    "concrétiserai": "concrétiser",
    "concrétiseraient": "concrétiser",
    "concrétiserais": "concrétiser",
    "concrétiserait": "concrétiser",
    "concrétiseras": "concrétiser",
    "concrétiserez": "concrétiser",
    "concrétiseriez": "concrétiser",
    "concrétiserions": "concrétiser",
    "concrétiserons": "concrétiser",
    "concrétiseront": "concrétiser",
    "concrétises": "concrétiser",
    "concrétisez": "concrétiser",
    "concrétisiez": "concrétiser",
    "concrétisions": "concrétiser",
    "concrétisons": "concrétiser",
    "concrétisâmes": "concrétiser",
    "concrétisât": "concrétiser",
    "concrétisâtes": "concrétiser",
    "concrétisèrent": "concrétiser",
    "concrétisé": "concrétiser",
    "concrétisée": "concrétiser",
    "concrétisées": "concrétiser",
    "concrétisés": "concrétiser",
    "concubinages": "concubinage",
    "concubinait": "concubiner",
    "concubine": "concubin",
    "concubines": "concubin",
    "concubins": "concubin",
    "concupiscences": "concupiscence",
    "concupiscenses": "concupiscense",
    "concupiscente": "concupiscent",
    "concupiscentes": "concupiscent",
    "concupiscents": "concupiscent",
    "concurrence": "concurrencer",
    "concurrencent": "concurrencer",
    "concurrencera": "concurrencer",
    "concurrencerai": "concurrencer",
    "concurrenceraient": "concurrencer",
    "concurrencerais": "concurrencer",
    "concurrencerait": "concurrencer",
    "concurrenceras": "concurrencer",
    "concurrencerez": "concurrencer",
    "concurrenceriez": "concurrencer",
    "concurrencerions": "concurrencer",
    "concurrencerons": "concurrencer",
    "concurrenceront": "concurrencer",
    "concurrences": "concurrencer",
    "concurrencez": "concurrencer",
    "concurrenciez": "concurrencer",
    "concurrencions": "concurrencer",
    "concurrencèrent": "concurrencer",
    "concurrencé": "concurrencer",
    "concurrencée": "concurrencer",
    "concurrencées": "concurrencer",
    "concurrencés": "concurrencer",
    "concurrente": "concurrent",
    "concurrentes": "concurrent",
    "concurrentielle": "concurrentiel",
    "concurrentielles": "concurrentiel",
    "concurrentiels": "concurrentiel",
    "concurrents": "concurrent",
    "concurrença": "concurrencer",
    "concurrençai": "concurrencer",
    "concurrençaient": "concurrencer",
    "concurrençais": "concurrencer",
    "concurrençait": "concurrencer",
    "concurrençant": "concurrencer",
    "concurrenças": "concurrencer",
    "concurrençasse": "concurrencer",
    "concurrençassent": "concurrencer",
    "concurrençasses": "concurrencer",
    "concurrençassiez": "concurrencer",
    "concurrençassions": "concurrencer",
    "concurrençons": "concurrencer",
    "concurrençâmes": "concurrencer",
    "concurrençât": "concurrencer",
    "concurrençâtes": "concurrencer",
    "concussionnaires": "concussionnaire",
    "concussions": "concussion",
    "concède": "concéder",
    "concèdent": "concéder",
    "concèdes": "concéder",
    "concéda": "concéder",
    "concédai": "concéder",
    "concédaient": "concéder",
    "concédais": "concéder",
    "concédait": "concéder",
    "concédant": "concéder",
    "concédas": "concéder",
    "concédasse": "concéder",
    "concédassent": "concéder",
    "concédasses": "concéder",
    "concédassiez": "concéder",
    "concédassions": "concéder",
    "concédera": "concéder",
    "concéderai": "concéder",
    "concéderaient": "concéder",
    "concéderais": "concéder",
    "concéderait": "concéder",
    "concéderas": "concéder",
    "concéderez": "concéder",
    "concéderiez": "concéder",
    "concéderions": "concéder",
    "concéderons": "concéder",
    "concéderont": "concéder",
    "concédez": "concéder",
    "concédiez": "concéder",
    "concédions": "concéder",
    "concédons": "concéder",
    "concédâmes": "concéder",
    "concédât": "concéder",
    "concédâtes": "concéder",
    "concédèrent": "concéder",
    "concédé": "concéder",
    "concédée": "concéder",
    "concédées": "concéder",
    "concédés": "concéder",
    "concélèbre": "concélébrer",
    "concélèbrent": "concélébrer",
    "concélèbres": "concélébrer",
    "concélébra": "concélébrer",
    "concélébrai": "concélébrer",
    "concélébraient": "concélébrer",
    "concélébrais": "concélébrer",
    "concélébrait": "concélébrer",
    "concélébrant": "concélébrer",
    "concélébras": "concélébrer",
    "concélébrasse": "concélébrer",
    "concélébrassent": "concélébrer",
    "concélébrasses": "concélébrer",
    "concélébrassiez": "concélébrer",
    "concélébrassions": "concélébrer",
    "concélébrera": "concélébrer",
    "concélébrerai": "concélébrer",
    "concélébreraient": "concélébrer",
    "concélébrerais": "concélébrer",
    "concélébrerait": "concélébrer",
    "concélébreras": "concélébrer",
    "concélébrerez": "concélébrer",
    "concélébreriez": "concélébrer",
    "concélébrerions": "concélébrer",
    "concélébrerons": "concélébrer",
    "concélébreront": "concélébrer",
    "concélébrez": "concélébrer",
    "concélébriez": "concélébrer",
    "concélébrions": "concélébrer",
    "concélébrons": "concélébrer",
    "concélébrâmes": "concélébrer",
    "concélébrât": "concélébrer",
    "concélébrâtes": "concélébrer",
    "concélébrèrent": "concélébrer",
    "concélébré": "concélébrer",
    "concélébrée": "concélébrer",
    "concélébrées": "concélébrer",
    "concélébrés": "concélébrer",
    "condamna": "condamner",
    "condamnables": "condamnable",
    "condamnai": "condamner",
    "condamnaient": "condamner",
    "condamnais": "condamner",
    "condamnait": "condamner",
    "condamnant": "condamner",
    "condamnas": "condamner",
    "condamnasse": "condamner",
    "condamnassent": "condamner",
    "condamnasses": "condamner",
    "condamnassiez": "condamner",
    "condamnassions": "condamner",
    "condamnations": "condamnation",
    "condamne": "condamner",
    "condamnent": "condamner",
    "condamnera": "condamner",
    "condamnerai": "condamner",
    "condamneraient": "condamner",
    "condamnerais": "condamner",
    "condamnerait": "condamner",
    "condamneras": "condamner",
    "condamnerez": "condamner",
    "condamneriez": "condamner",
    "condamnerions": "condamner",
    "condamnerons": "condamner",
    "condamneront": "condamner",
    "condamnes": "condamner",
    "condamnez": "condamner",
    "condamniez": "condamner",
    "condamnions": "condamner",
    "condamnons": "condamner",
    "condamnâmes": "condamner",
    "condamnât": "condamner",
    "condamnâtes": "condamner",
    "condamnèrent": "condamner",
    "condamné": "condamner",
    "condamnée": "condamner",
    "condamnées": "condamner",
    "condamnés": "condamner",
    "condensa": "condenser",
    "condensai": "condenser",
    "condensaient": "condenser",
    "condensais": "condenser",
    "condensait": "condenser",
    "condensant": "condenser",
    "condensas": "condenser",
    "condensasse": "condenser",
    "condensassent": "condenser",
    "condensasses": "condenser",
    "condensassiez": "condenser",
    "condensassions": "condenser",
    "condensateurs": "condensateur",
    "condensatrice": "condensateur",
    "condensatrices": "condensateur",
    "condense": "condenser",
    "condensent": "condenser",
    "condensera": "condenser",
    "condenserai": "condenser",
    "condenseraient": "condenser",
    "condenserais": "condenser",
    "condenserait": "condenser",
    "condenseras": "condenser",
    "condenserez": "condenser",
    "condenseriez": "condenser",
    "condenserions": "condenser",
    "condenserons": "condenser",
    "condenseront": "condenser",
    "condenses": "condenser",
    "condensez": "condenser",
    "condensiez": "condenser",
    "condensions": "condenser",
    "condensons": "condenser",
    "condensâmes": "condenser",
    "condensât": "condenser",
    "condensâtes": "condenser",
    "condensèrent": "condenser",
    "condensé": "condenser",
    "condensée": "condenser",
    "condensées": "condenser",
    "condensés": "condenser",
    "condescend": "condescendre",
    "condescendaient": "condescendre",
    "condescendais": "condescendre",
    "condescendait": "condescendre",
    "condescendances": "condescendance",
    "condescendant": "condescendre",
    "condescendante": "condescendant",
    "condescendants": "condescendant",
    "condescende": "condescendre",
    "condescendent": "condescendre",
    "condescendes": "condescendre",
    "condescendez": "condescendre",
    "condescendiez": "condescendre",
    "condescendions": "condescendre",
    "condescendirent": "condescendre",
    "condescendis": "condescendre",
    "condescendisse": "condescendre",
    "condescendissent": "condescendre",
    "condescendisses": "condescendre",
    "condescendissiez": "condescendre",
    "condescendissions": "condescendre",
    "condescendit": "condescendre",
    "condescendons": "condescendre",
    "condescendra": "condescendre",
    "condescendrai": "condescendre",
    "condescendraient": "condescendre",
    "condescendrais": "condescendre",
    "condescendrait": "condescendre",
    "condescendras": "condescendre",
    "condescendrez": "condescendre",
    "condescendriez": "condescendre",
    "condescendrions": "condescendre",
    "condescendrons": "condescendre",
    "condescendront": "condescendre",
    "condescends": "condescendre",
    "condescendu": "condescendre",
    "condescendîmes": "condescendre",
    "condescendît": "condescendre",
    "condescendîtes": "condescendre",
    "condiments": "condiment",
    "condisciples": "condisciple",
    "conditionna": "conditionner",
    "conditionnai": "conditionner",
    "conditionnaient": "conditionner",
    "conditionnais": "conditionner",
    "conditionnait": "conditionner",
    "conditionnant": "conditionner",
    "conditionnas": "conditionner",
    "conditionnasse": "conditionner",
    "conditionnassent": "conditionner",
    "conditionnasses": "conditionner",
    "conditionnassiez": "conditionner",
    "conditionnassions": "conditionner",
    "conditionne": "conditionner",
    "conditionnelle": "conditionnel",
    "conditionnelles": "conditionnel",
    "conditionnels": "conditionnel",
    "conditionnements": "conditionnement",
    "conditionnent": "conditionner",
    "conditionnera": "conditionner",
    "conditionnerai": "conditionner",
    "conditionneraient": "conditionner",
    "conditionnerais": "conditionner",
    "conditionnerait": "conditionner",
    "conditionneras": "conditionner",
    "conditionnerez": "conditionner",
    "conditionneriez": "conditionner",
    "conditionnerions": "conditionner",
    "conditionnerons": "conditionner",
    "conditionneront": "conditionner",
    "conditionnes": "conditionner",
    "conditionneurs": "conditionneur",
    "conditionneuses": "conditionneuse",
    "conditionnez": "conditionner",
    "conditionniez": "conditionner",
    "conditionnions": "conditionner",
    "conditionnons": "conditionner",
    "conditionnâmes": "conditionner",
    "conditionnât": "conditionner",
    "conditionnâtes": "conditionner",
    "conditionnèrent": "conditionner",
    "conditionné": "conditionner",
    "conditionnée": "conditionner",
    "conditionnées": "conditionner",
    "conditionnés": "conditionner",
    "conditions": "condition",
    "condoléances": "condoléance",
    "condoléants": "condoléant",
    "condominiums": "condominium",
    "condors": "condor",
    "condos": "condo",
    "condottieres": "condottiere",
    "conducteurs": "conducteur",
    "conductrice": "conducteur",
    "conductrices": "conducteur",
    "conduira": "conduire",
    "conduirai": "conduire",
    "conduiraient": "conduire",
    "conduirais": "conduire",
    "conduirait": "conduire",
    "conduiras": "conduire",
    "conduirez": "conduire",
    "conduiriez": "conduire",
    "conduirions": "conduire",
    "conduirons": "conduire",
    "conduiront": "conduire",
    "conduis": "conduire",
    "conduisaient": "conduire",
    "conduisais": "conduire",
    "conduisait": "conduire",
    "conduisant": "conduire",
    "conduise": "conduire",
    "conduisent": "conduire",
    "conduises": "conduire",
    "conduisez": "conduire",
    "conduisiez": "conduire",
    "conduisions": "conduire",
    "conduisirent": "conduire",
    "conduisis": "conduire",
    "conduisisse": "conduire",
    "conduisissent": "conduire",
    "conduisisses": "conduire",
    "conduisissiez": "conduire",
    "conduisissions": "conduire",
    "conduisit": "conduire",
    "conduisons": "conduire",
    "conduisîmes": "conduire",
    "conduisît": "conduire",
    "conduisîtes": "conduire",
    "conduit": "conduire",
    "conduite": "conduit",
    "conduites": "conduite",
    "conduites-intérieures": "conduite-intérieure",
    "conduits": "conduit",
    "condyles": "condyle",
    "condés": "condé",
    "confabulaient": "confabuler",
    "confectionna": "confectionner",
    "confectionnai": "confectionner",
    "confectionnaient": "confectionner",
    "confectionnais": "confectionner",
    "confectionnait": "confectionner",
    "confectionnant": "confectionner",
    "confectionnas": "confectionner",
    "confectionnasse": "confectionner",
    "confectionnassent": "confectionner",
    "confectionnasses": "confectionner",
    "confectionnassiez": "confectionner",
    "confectionnassions": "confectionner",
    "confectionne": "confectionner",
    "confectionnent": "confectionner",
    "confectionnera": "confectionner",
    "confectionnerai": "confectionner",
    "confectionneraient": "confectionner",
    "confectionnerais": "confectionner",
    "confectionnerait": "confectionner",
    "confectionneras": "confectionner",
    "confectionnerez": "confectionner",
    "confectionneriez": "confectionner",
    "confectionnerions": "confectionner",
    "confectionnerons": "confectionner",
    "confectionneront": "confectionner",
    "confectionnes": "confectionner",
    "confectionneurs": "confectionneur",
    "confectionneuse": "confectionneur",
    "confectionneuses": "confectionneur",
    "confectionnez": "confectionner",
    "confectionniez": "confectionner",
    "confectionnions": "confectionner",
    "confectionnons": "confectionner",
    "confectionnâmes": "confectionner",
    "confectionnât": "confectionner",
    "confectionnâtes": "confectionner",
    "confectionnèrent": "confectionner",
    "confectionné": "confectionner",
    "confectionnée": "confectionner",
    "confectionnées": "confectionner",
    "confectionnés": "confectionner",
    "confections": "confection",
    "confessa": "confesser",
    "confessai": "confesser",
    "confessaient": "confesser",
    "confessais": "confesser",
    "confessait": "confesser",
    "confessant": "confesser",
    "confessas": "confesser",
    "confessasse": "confesser",
    "confessassent": "confesser",
    "confessasses": "confesser",
    "confessassiez": "confesser",
    "confessassions": "confesser",
    "confesse": "confesser",
    "confessent": "confesser",
    "confessera": "confesser",
    "confesserai": "confesser",
    "confesseraient": "confesser",
    "confesserais": "confesser",
    "confesserait": "confesser",
    "confesseras": "confesser",
    "confesserez": "confesser",
    "confesseriez": "confesser",
    "confesserions": "confesser",
    "confesserons": "confesser",
    "confesseront": "confesser",
    "confesses": "confesser",
    "confesseurs": "confesseur",
    "confessez": "confesser",
    "confessiez": "confesser",
    "confessionnalismes": "confessionnalisme",
    "confessionnaux": "confessionnal",
    "confessionnelle": "confessionnel",
    "confessionnelles": "confessionnel",
    "confessionnels": "confessionnel",
    "confessions": "confession",
    "confessons": "confesser",
    "confessâmes": "confesser",
    "confessât": "confesser",
    "confessâtes": "confesser",
    "confessèrent": "confesser",
    "confessé": "confesser",
    "confessée": "confesser",
    "confessées": "confesser",
    "confessés": "confesser",
    "confettis": "confetti",
    "confia": "confier",
    "confiai": "confier",
    "confiaient": "confier",
    "confiais": "confier",
    "confiait": "confier",
    "confiances": "confiance",
    "confiant": "confier",
    "confiante": "confiant",
    "confiantes": "confiant",
    "confiants": "confiant",
    "confias": "confier",
    "confiasse": "confier",
    "confiassent": "confier",
    "confiasses": "confier",
    "confiassiez": "confier",
    "confiassions": "confier",
    "confidences": "confidence",
    "confidentalités": "confidentalité",
    "confidente": "confident",
    "confidentes": "confident",
    "confidentialités": "confidentialité",
    "confidentielle": "confidentiel",
    "confidentielles": "confidentiel",
    "confidentiels": "confidentiel",
    "confidents": "confident",
    "confie": "confier",
    "confient": "confier",
    "confiera": "confier",
    "confierai": "confier",
    "confieraient": "confier",
    "confierais": "confier",
    "confierait": "confier",
    "confieras": "confier",
    "confierez": "confier",
    "confieriez": "confier",
    "confierions": "confier",
    "confierons": "confier",
    "confieront": "confier",
    "confies": "confier",
    "confiez": "confier",
    "configura": "configurer",
    "configurai": "configurer",
    "configuraient": "configurer",
    "configurais": "configurer",
    "configurait": "configurer",
    "configurant": "configurer",
    "configuras": "configurer",
    "configurasse": "configurer",
    "configurassent": "configurer",
    "configurasses": "configurer",
    "configurassiez": "configurer",
    "configurassions": "configurer",
    "configurations": "configuration",
    "configure": "configurer",
    "configurent": "configurer",
    "configurera": "configurer",
    "configurerai": "configurer",
    "configureraient": "configurer",
    "configurerais": "configurer",
    "configurerait": "configurer",
    "configureras": "configurer",
    "configurerez": "configurer",
    "configureriez": "configurer",
    "configurerions": "configurer",
    "configurerons": "configurer",
    "configureront": "configurer",
    "configures": "configurer",
    "configurez": "configurer",
    "configuriez": "configurer",
    "configurions": "configurer",
    "configurons": "configurer",
    "configurâmes": "configurer",
    "configurât": "configurer",
    "configurâtes": "configurer",
    "configurèrent": "configurer",
    "configuré": "configurer",
    "configurée": "configurer",
    "configurées": "configurer",
    "configurés": "configurer",
    "confiiez": "confier",
    "confiions": "confier",
    "confina": "confiner",
    "confinai": "confiner",
    "confinaient": "confiner",
    "confinais": "confiner",
    "confinait": "confiner",
    "confinancements": "confinancement",
    "confinant": "confiner",
    "confinas": "confiner",
    "confinasse": "confiner",
    "confinassent": "confiner",
    "confinasses": "confiner",
    "confinassiez": "confiner",
    "confinassions": "confiner",
    "confine": "confiner",
    "confinements": "confinement",
    "confinent": "confiner",
    "confinera": "confiner",
    "confinerai": "confiner",
    "confineraient": "confiner",
    "confinerais": "confiner",
    "confinerait": "confiner",
    "confineras": "confiner",
    "confinerez": "confiner",
    "confineriez": "confiner",
    "confinerions": "confiner",
    "confinerons": "confiner",
    "confineront": "confiner",
    "confines": "confiner",
    "confinez": "confiner",
    "confiniez": "confiner",
    "confinions": "confiner",
    "confinons": "confiner",
    "confinâmes": "confiner",
    "confinât": "confiner",
    "confinâtes": "confiner",
    "confinèrent": "confiner",
    "confiné": "confiner",
    "confinée": "confiner",
    "confinées": "confiner",
    "confinés": "confiner",
    "confions": "confier",
    "confiotes": "confiote",
    "confira": "confire",
    "confirai": "confire",
    "confiraient": "confire",
    "confirais": "confire",
    "confirait": "confire",
    "confiras": "confire",
    "confirent": "confire",
    "confirez": "confire",
    "confiriez": "confire",
    "confirions": "confire",
    "confirma": "confirmer",
    "confirmai": "confirmer",
    "confirmaient": "confirmer",
    "confirmais": "confirmer",
    "confirmait": "confirmer",
    "confirmant": "confirmer",
    "confirmas": "confirmer",
    "confirmasse": "confirmer",
    "confirmassent": "confirmer",
    "confirmasses": "confirmer",
    "confirmassiez": "confirmer",
    "confirmassions": "confirmer",
    "confirmations": "confirmation",
    "confirme": "confirmer",
    "confirment": "confirmer",
    "confirmera": "confirmer",
    "confirmerai": "confirmer",
    "confirmeraient": "confirmer",
    "confirmerais": "confirmer",
    "confirmerait": "confirmer",
    "confirmeras": "confirmer",
    "confirmerez": "confirmer",
    "confirmeriez": "confirmer",
    "confirmerions": "confirmer",
    "confirmerons": "confirmer",
    "confirmeront": "confirmer",
    "confirmes": "confirmer",
    "confirmez": "confirmer",
    "confirmiez": "confirmer",
    "confirmions": "confirmer",
    "confirmons": "confirmer",
    "confirmâmes": "confirmer",
    "confirmât": "confirmer",
    "confirmâtes": "confirmer",
    "confirmèrent": "confirmer",
    "confirmé": "confirmer",
    "confirmée": "confirmer",
    "confirmées": "confirmer",
    "confirmés": "confirmer",
    "confirons": "confire",
    "confiront": "confire",
    "confis": "confire",
    "confisaient": "confire",
    "confisais": "confire",
    "confisait": "confire",
    "confisant": "confire",
    "confiscations": "confiscation",
    "confise": "confire",
    "confisent": "confire",
    "confiseries": "confiserie",
    "confises": "confire",
    "confiseurs": "confiseur",
    "confiseuse": "confiseur",
    "confiseuses": "confiseur",
    "confisez": "confire",
    "confisiez": "confire",
    "confisions": "confire",
    "confisons": "confire",
    "confisqua": "confisquer",
    "confisquai": "confisquer",
    "confisquaient": "confisquer",
    "confisquais": "confisquer",
    "confisquait": "confisquer",
    "confisquant": "confisquer",
    "confisquas": "confisquer",
    "confisquasse": "confisquer",
    "confisquassent": "confisquer",
    "confisquasses": "confisquer",
    "confisquassiez": "confisquer",
    "confisquassions": "confisquer",
    "confisque": "confisquer",
    "confisquent": "confisquer",
    "confisquera": "confisquer",
    "confisquerai": "confisquer",
    "confisqueraient": "confisquer",
    "confisquerais": "confisquer",
    "confisquerait": "confisquer",
    "confisqueras": "confisquer",
    "confisquerez": "confisquer",
    "confisqueriez": "confisquer",
    "confisquerions": "confisquer",
    "confisquerons": "confisquer",
    "confisqueront": "confisquer",
    "confisques": "confisquer",
    "confisquez": "confisquer",
    "confisquiez": "confisquer",
    "confisquions": "confisquer",
    "confisquons": "confisquer",
    "confisquâmes": "confisquer",
    "confisquât": "confisquer",
    "confisquâtes": "confisquer",
    "confisquèrent": "confisquer",
    "confisqué": "confisquer",
    "confisquée": "confisquer",
    "confisquées": "confisquer",
    "confisqués": "confisquer",
    "confisse": "confire",
    "confissent": "confire",
    "confisses": "confire",
    "confissiez": "confire",
    "confissions": "confire",
    "confit": "confire",
    "confite": "confit",
    "confites": "confit",
    "confits": "confit",
    "confitures": "confiture",
    "confituriers": "confiturier",
    "confiturière": "confiturier",
    "confiâmes": "confier",
    "confiât": "confier",
    "confiâtes": "confier",
    "confièrent": "confier",
    "confié": "confier",
    "confiée": "confier",
    "confiées": "confier",
    "confiés": "confier",
    "conflagrations": "conflagration",
    "conflictuelle": "conflictuel",
    "conflictuelles": "conflictuel",
    "conflictuels": "conflictuel",
    "conflits": "conflit",
    "conflua": "confluer",
    "confluai": "confluer",
    "confluaient": "confluer",
    "confluais": "confluer",
    "confluait": "confluer",
    "confluant": "confluer",
    "confluas": "confluer",
    "confluasse": "confluer",
    "confluassent": "confluer",
    "confluasses": "confluer",
    "confluassiez": "confluer",
    "confluassions": "confluer",
    "conflue": "confluer",
    "confluences": "confluence",
    "confluent": "confluer",
    "confluente": "confluent",
    "confluentes": "confluent",
    "confluents": "confluent",
    "confluera": "confluer",
    "confluerai": "confluer",
    "conflueraient": "confluer",
    "confluerais": "confluer",
    "confluerait": "confluer",
    "conflueras": "confluer",
    "confluerez": "confluer",
    "conflueriez": "confluer",
    "confluerions": "confluer",
    "confluerons": "confluer",
    "conflueront": "confluer",
    "conflues": "confluer",
    "confluez": "confluer",
    "confluiez": "confluer",
    "confluions": "confluer",
    "confluons": "confluer",
    "confluâmes": "confluer",
    "confluât": "confluer",
    "confluâtes": "confluer",
    "confluèrent": "confluer",
    "conflué": "confluer",
    "confluée": "confluer",
    "confluées": "confluer",
    "conflués": "confluer",
    "confond": "confondre",
    "confondaient": "confondre",
    "confondais": "confondre",
    "confondait": "confondre",
    "confondant": "confondre",
    "confondante": "confondant",
    "confondantes": "confondant",
    "confondants": "confondant",
    "confonde": "confondre",
    "confondent": "confondre",
    "confondes": "confondre",
    "confondez": "confondre",
    "confondiez": "confondre",
    "confondions": "confondre",
    "confondirent": "confondre",
    "confondis": "confondre",
    "confondisse": "confondre",
    "confondissent": "confondre",
    "confondisses": "confondre",
    "confondissiez": "confondre",
    "confondissions": "confondre",
    "confondit": "confondre",
    "confondons": "confondre",
    "confondra": "confondre",
    "confondrai": "confondre",
    "confondraient": "confondre",
    "confondrais": "confondre",
    "confondrait": "confondre",
    "confondras": "confondre",
    "confondrez": "confondre",
    "confondriez": "confondre",
    "confondrions": "confondre",
    "confondrons": "confondre",
    "confondront": "confondre",
    "confonds": "confondre",
    "confondu": "confondre",
    "confondue": "confondu",
    "confondues": "confondu",
    "confondus": "confondu",
    "confondîmes": "confondre",
    "confondît": "confondre",
    "confondîtes": "confondre",
    "conforma": "conformer",
    "conformai": "conformer",
    "conformaient": "conformer",
    "conformais": "conformer",
    "conformait": "conformer",
    "conformant": "conformer",
    "conformas": "conformer",
    "conformasse": "conformer",
    "conformassent": "conformer",
    "conformasses": "conformer",
    "conformassiez": "conformer",
    "conformassions": "conformer",
    "conformations": "conformation",
    "conforme": "conformer",
    "conforment": "conformer",
    "conformera": "conformer",
    "conformerai": "conformer",
    "conformeraient": "conformer",
    "conformerais": "conformer",
    "conformerait": "conformer",
    "conformeras": "conformer",
    "conformerez": "conformer",
    "conformeriez": "conformer",
    "conformerions": "conformer",
    "conformerons": "conformer",
    "conformeront": "conformer",
    "conformes": "conformer",
    "conformez": "conformer",
    "conformiez": "conformer",
    "conformions": "conformer",
    "conformismes": "conformisme",
    "conformistes": "conformiste",
    "conformités": "conformité",
    "conformons": "conformer",
    "conformâmes": "conformer",
    "conformât": "conformer",
    "conformâtes": "conformer",
    "conformèrent": "conformer",
    "conformé": "conformer",
    "conformée": "conformer",
    "conformées": "conformer",
    "conformés": "conformer",
    "conforta": "conforter",
    "confortables": "confortable",
    "confortai": "conforter",
    "confortaient": "conforter",
    "confortais": "conforter",
    "confortait": "conforter",
    "confortant": "conforter",
    "confortas": "conforter",
    "confortasse": "conforter",
    "confortassent": "conforter",
    "confortasses": "conforter",
    "confortassiez": "conforter",
    "confortassions": "conforter",
    "conforte": "conforter",
    "confortent": "conforter",
    "confortera": "conforter",
    "conforterai": "conforter",
    "conforteraient": "conforter",
    "conforterais": "conforter",
    "conforterait": "conforter",
    "conforteras": "conforter",
    "conforterez": "conforter",
    "conforteriez": "conforter",
    "conforterions": "conforter",
    "conforterons": "conforter",
    "conforteront": "conforter",
    "confortes": "conforter",
    "confortez": "conforter",
    "confortiez": "conforter",
    "confortions": "conforter",
    "confortons": "conforter",
    "conforts": "confort",
    "confortâmes": "conforter",
    "confortât": "conforter",
    "confortâtes": "conforter",
    "confortèrent": "conforter",
    "conforté": "conforter",
    "confortée": "conforter",
    "confortées": "conforter",
    "confortés": "conforter",
    "confraternelle": "confraternel",
    "confraternelles": "confraternel",
    "confraternels": "confraternel",
    "confraternités": "confraternité",
    "confronta": "confronter",
    "confrontai": "confronter",
    "confrontaient": "confronter",
    "confrontais": "confronter",
    "confrontait": "confronter",
    "confrontant": "confronter",
    "confrontas": "confronter",
    "confrontasse": "confronter",
    "confrontassent": "confronter",
    "confrontasses": "confronter",
    "confrontassiez": "confronter",
    "confrontassions": "confronter",
    "confrontations": "confrontation",
    "confronte": "confronter",
    "confrontent": "confronter",
    "confrontera": "confronter",
    "confronterai": "confronter",
    "confronteraient": "confronter",
    "confronterais": "confronter",
    "confronterait": "confronter",
    "confronteras": "confronter",
    "confronterez": "confronter",
    "confronteriez": "confronter",
    "confronterions": "confronter",
    "confronterons": "confronter",
    "confronteront": "confronter",
    "confrontes": "confronter",
    "confrontez": "confronter",
    "confrontiez": "confronter",
    "confrontions": "confronter",
    "confrontons": "confronter",
    "confrontâmes": "confronter",
    "confrontât": "confronter",
    "confrontâtes": "confronter",
    "confrontèrent": "confronter",
    "confronté": "confronter",
    "confrontée": "confronter",
    "confrontées": "confronter",
    "confrontés": "confronter",
    "confrères": "confrère",
    "confréries": "confrérie",
    "confucéenne": "confucéen",
    "confucéennes": "confucéen",
    "confucéens": "confucéen",
    "confuse": "confus",
    "confuses": "confus",
    "confusions": "confusion",
    "confère": "conférer",
    "confèrent": "conférer",
    "confères": "conférer",
    "confédère": "confédérer",
    "confédèrent": "confédérer",
    "confédères": "confédérer",
    "confédéra": "confédérer",
    "confédérai": "confédérer",
    "confédéraient": "confédérer",
    "confédérais": "confédérer",
    "confédérait": "confédérer",
    "confédérale": "confédéral",
    "confédérales": "confédéral",
    "confédérant": "confédérer",
    "confédéras": "confédérer",
    "confédérasse": "confédérer",
    "confédérassent": "confédérer",
    "confédérasses": "confédérer",
    "confédérassiez": "confédérer",
    "confédérassions": "confédérer",
    "confédérations": "confédération",
    "confédéraux": "confédéral",
    "confédérera": "confédérer",
    "confédérerai": "confédérer",
    "confédéreraient": "confédérer",
    "confédérerais": "confédérer",
    "confédérerait": "confédérer",
    "confédéreras": "confédérer",
    "confédérerez": "confédérer",
    "confédéreriez": "confédérer",
    "confédérerions": "confédérer",
    "confédérerons": "confédérer",
    "confédéreront": "confédérer",
    "confédérez": "confédérer",
    "confédériez": "confédérer",
    "confédérions": "confédérer",
    "confédérons": "confédérer",
    "confédérâmes": "confédérer",
    "confédérât": "confédérer",
    "confédérâtes": "confédérer",
    "confédérèrent": "confédérer",
    "confédéré": "confédérer",
    "confédérée": "confédérer",
    "confédérées": "confédérer",
    "confédérés": "confédérer",
    "conféra": "conférer",
    "conférai": "conférer",
    "conféraient": "conférer",
    "conférais": "conférer",
    "conférait": "conférer",
    "conférant": "conférer",
    "conféras": "conférer",
    "conférasse": "conférer",
    "conférassent": "conférer",
    "conférasses": "conférer",
    "conférassiez": "conférer",
    "conférassions": "conférer",
    "conférences": "conférence",
    "conférences-débats": "conférence-débat",
    "conférenciers": "conférencier",
    "conférencière": "conférencier",
    "conférencières": "conférencier",
    "conférents": "conférent",
    "conférera": "conférer",
    "conférerai": "conférer",
    "conféreraient": "conférer",
    "conférerais": "conférer",
    "conférerait": "conférer",
    "conféreras": "conférer",
    "conférerez": "conférer",
    "conféreriez": "conférer",
    "conférerions": "conférer",
    "conférerons": "conférer",
    "conféreront": "conférer",
    "conférez": "conférer",
    "confériez": "conférer",
    "conférions": "conférer",
    "conférons": "conférer",
    "conférâmes": "conférer",
    "conférât": "conférer",
    "conférâtes": "conférer",
    "conférèrent": "conférer",
    "conféré": "conférer",
    "conférée": "conférer",
    "conférées": "conférer",
    "conférés": "conférer",
    "confîmes": "confire",
    "confît": "confire",
    "confîtes": "confire",
    "congas": "conga",
    "congayes": "congaye",
    "congaïs": "congaï",
    "congela": "congeler",
    "congelai": "congeler",
    "congelaient": "congeler",
    "congelais": "congeler",
    "congelait": "congeler",
    "congelant": "congeler",
    "congelas": "congeler",
    "congelasse": "congeler",
    "congelassent": "congeler",
    "congelasses": "congeler",
    "congelassiez": "congeler",
    "congelassions": "congeler",
    "congelez": "congeler",
    "congeliez": "congeler",
    "congelions": "congeler",
    "congelons": "congeler",
    "congelâmes": "congeler",
    "congelât": "congeler",
    "congelâtes": "congeler",
    "congelèrent": "congeler",
    "congelé": "congeler",
    "congelée": "congeler",
    "congelées": "congeler",
    "congelés": "congeler",
    "congestionna": "congestionner",
    "congestionnai": "congestionner",
    "congestionnaient": "congestionner",
    "congestionnais": "congestionner",
    "congestionnait": "congestionner",
    "congestionnant": "congestionner",
    "congestionnas": "congestionner",
    "congestionnasse": "congestionner",
    "congestionnassent": "congestionner",
    "congestionnasses": "congestionner",
    "congestionnassiez": "congestionner",
    "congestionnassions": "congestionner",
    "congestionne": "congestionner",
    "congestionnent": "congestionner",
    "congestionnera": "congestionner",
    "congestionnerai": "congestionner",
    "congestionneraient": "congestionner",
    "congestionnerais": "congestionner",
    "congestionnerait": "congestionner",
    "congestionneras": "congestionner",
    "congestionnerez": "congestionner",
    "congestionneriez": "congestionner",
    "congestionnerions": "congestionner",
    "congestionnerons": "congestionner",
    "congestionneront": "congestionner",
    "congestionnes": "congestionner",
    "congestionnez": "congestionner",
    "congestionniez": "congestionner",
    "congestionnions": "congestionner",
    "congestionnons": "congestionner",
    "congestionnâmes": "congestionner",
    "congestionnât": "congestionner",
    "congestionnâtes": "congestionner",
    "congestionnèrent": "congestionner",
    "congestionné": "congestionner",
    "congestionnée": "congestionner",
    "congestionnées": "congestionner",
    "congestionnés": "congestionner",
    "congestions": "congestion",
    "congestive": "congestif",
    "conglomère": "conglomérer",
    "conglomèrent": "conglomérer",
    "conglomères": "conglomérer",
    "congloméra": "conglomérer",
    "conglomérai": "conglomérer",
    "congloméraient": "conglomérer",
    "conglomérais": "conglomérer",
    "conglomérait": "conglomérer",
    "conglomérant": "conglomérer",
    "congloméras": "conglomérer",
    "conglomérasse": "conglomérer",
    "conglomérassent": "conglomérer",
    "conglomérasses": "conglomérer",
    "conglomérassiez": "conglomérer",
    "conglomérassions": "conglomérer",
    "conglomérats": "conglomérat",
    "conglomérera": "conglomérer",
    "conglomérerai": "conglomérer",
    "congloméreraient": "conglomérer",
    "conglomérerais": "conglomérer",
    "conglomérerait": "conglomérer",
    "congloméreras": "conglomérer",
    "conglomérerez": "conglomérer",
    "congloméreriez": "conglomérer",
    "conglomérerions": "conglomérer",
    "conglomérerons": "conglomérer",
    "congloméreront": "conglomérer",
    "conglomérez": "conglomérer",
    "conglomériez": "conglomérer",
    "conglomérions": "conglomérer",
    "conglomérons": "conglomérer",
    "conglomérâmes": "conglomérer",
    "conglomérât": "conglomérer",
    "conglomérâtes": "conglomérer",
    "conglomérèrent": "conglomérer",
    "congloméré": "conglomérer",
    "conglomérée": "conglomérer",
    "conglomérées": "conglomérer",
    "conglomérés": "conglomérer",
    "conglutina": "conglutiner",
    "conglutinai": "conglutiner",
    "conglutinaient": "conglutiner",
    "conglutinais": "conglutiner",
    "conglutinait": "conglutiner",
    "conglutinant": "conglutiner",
    "conglutinas": "conglutiner",
    "conglutinasse": "conglutiner",
    "conglutinassent": "conglutiner",
    "conglutinasses": "conglutiner",
    "conglutinassiez": "conglutiner",
    "conglutinassions": "conglutiner",
    "conglutine": "conglutiner",
    "conglutinent": "conglutiner",
    "conglutinera": "conglutiner",
    "conglutinerai": "conglutiner",
    "conglutineraient": "conglutiner",
    "conglutinerais": "conglutiner",
    "conglutinerait": "conglutiner",
    "conglutineras": "conglutiner",
    "conglutinerez": "conglutiner",
    "conglutineriez": "conglutiner",
    "conglutinerions": "conglutiner",
    "conglutinerons": "conglutiner",
    "conglutineront": "conglutiner",
    "conglutines": "conglutiner",
    "conglutinez": "conglutiner",
    "conglutiniez": "conglutiner",
    "conglutinions": "conglutiner",
    "conglutinons": "conglutiner",
    "conglutinâmes": "conglutiner",
    "conglutinât": "conglutiner",
    "conglutinâtes": "conglutiner",
    "conglutinèrent": "conglutiner",
    "conglutiné": "conglutiner",
    "conglutinée": "conglutiner",
    "conglutinées": "conglutiner",
    "conglutinés": "conglutiner",
    "congolaise": "congolais",
    "congolaises": "congolais",
    "congratula": "congratuler",
    "congratulai": "congratuler",
    "congratulaient": "congratuler",
    "congratulais": "congratuler",
    "congratulait": "congratuler",
    "congratulant": "congratuler",
    "congratulas": "congratuler",
    "congratulasse": "congratuler",
    "congratulassent": "congratuler",
    "congratulasses": "congratuler",
    "congratulassiez": "congratuler",
    "congratulassions": "congratuler",
    "congratulations": "congratulation",
    "congratule": "congratuler",
    "congratulent": "congratuler",
    "congratulera": "congratuler",
    "congratulerai": "congratuler",
    "congratuleraient": "congratuler",
    "congratulerais": "congratuler",
    "congratulerait": "congratuler",
    "congratuleras": "congratuler",
    "congratulerez": "congratuler",
    "congratuleriez": "congratuler",
    "congratulerions": "congratuler",
    "congratulerons": "congratuler",
    "congratuleront": "congratuler",
    "congratules": "congratuler",
    "congratulez": "congratuler",
    "congratuliez": "congratuler",
    "congratulions": "congratuler",
    "congratulons": "congratuler",
    "congratulâmes": "congratuler",
    "congratulât": "congratuler",
    "congratulâtes": "congratuler",
    "congratulèrent": "congratuler",
    "congratulé": "congratuler",
    "congratulée": "congratuler",
    "congratulées": "congratuler",
    "congratulés": "congratuler",
    "congres": "congre",
    "congressistes": "congressiste",
    "congrue": "congru",
    "congrues": "congru",
    "congrus": "congru",
    "congréganistes": "congréganiste",
    "congrégations": "congrégation",
    "congèle": "congeler",
    "congèlent": "congeler",
    "congèlera": "congeler",
    "congèlerai": "congeler",
    "congèleraient": "congeler",
    "congèlerais": "congeler",
    "congèlerait": "congeler",
    "congèleras": "congeler",
    "congèlerez": "congeler",
    "congèleriez": "congeler",
    "congèlerions": "congeler",
    "congèlerons": "congeler",
    "congèleront": "congeler",
    "congèles": "congeler",
    "congères": "congère",
    "congédia": "congédier",
    "congédiai": "congédier",
    "congédiaient": "congédier",
    "congédiais": "congédier",
    "congédiait": "congédier",
    "congédiant": "congédier",
    "congédias": "congédier",
    "congédiasse": "congédier",
    "congédiassent": "congédier",
    "congédiasses": "congédier",
    "congédiassiez": "congédier",
    "congédiassions": "congédier",
    "congédie": "congédier",
    "congédiements": "congédiement",
    "congédient": "congédier",
    "congédiera": "congédier",
    "congédierai": "congédier",
    "congédieraient": "congédier",
    "congédierais": "congédier",
    "congédierait": "congédier",
    "congédieras": "congédier",
    "congédierez": "congédier",
    "congédieriez": "congédier",
    "congédierions": "congédier",
    "congédierons": "congédier",
    "congédieront": "congédier",
    "congédies": "congédier",
    "congédiez": "congédier",
    "congédiiez": "congédier",
    "congédiions": "congédier",
    "congédions": "congédier",
    "congédiâmes": "congédier",
    "congédiât": "congédier",
    "congédiâtes": "congédier",
    "congédièrent": "congédier",
    "congédié": "congédier",
    "congédiée": "congédier",
    "congédiées": "congédier",
    "congédiés": "congédier",
    "congélateurs": "congélateur",
    "congélations": "congélation",
    "congénitale": "congénital",
    "congénitales": "congénital",
    "congénitaux": "congénital",
    "congénères": "congénère",
    "congés": "congé",
    "conifères": "conifère",
    "coniques": "conique",
    "conjecturai": "conjecturer",
    "conjecturale": "conjectural",
    "conjecturales": "conjectural",
    "conjecturaux": "conjectural",
    "conjecture": "conjecturer",
    "conjecturent": "conjecturer",
    "conjectures": "conjecturer",
    "conjoignaient": "conjoindre",
    "conjoignais": "conjoindre",
    "conjoignait": "conjoindre",
    "conjoignant": "conjoindre",
    "conjoigne": "conjoindre",
    "conjoignent": "conjoindre",
    "conjoignes": "conjoindre",
    "conjoignez": "conjoindre",
    "conjoigniez": "conjoindre",
    "conjoignions": "conjoindre",
    "conjoignirent": "conjoindre",
    "conjoignis": "conjoindre",
    "conjoignisse": "conjoindre",
    "conjoignissent": "conjoindre",
    "conjoignisses": "conjoindre",
    "conjoignissiez": "conjoindre",
    "conjoignissions": "conjoindre",
    "conjoignit": "conjoindre",
    "conjoignons": "conjoindre",
    "conjoignîmes": "conjoindre",
    "conjoignît": "conjoindre",
    "conjoignîtes": "conjoindre",
    "conjoindra": "conjoindre",
    "conjoindrai": "conjoindre",
    "conjoindraient": "conjoindre",
    "conjoindrais": "conjoindre",
    "conjoindrait": "conjoindre",
    "conjoindras": "conjoindre",
    "conjoindrez": "conjoindre",
    "conjoindriez": "conjoindre",
    "conjoindrions": "conjoindre",
    "conjoindrons": "conjoindre",
    "conjoindront": "conjoindre",
    "conjoins": "conjoindre",
    "conjoint": "conjoindre",
    "conjointe": "conjoint",
    "conjointes": "conjoint",
    "conjoints": "conjoint",
    "conjonctifs": "conjonctif",
    "conjonctions": "conjonction",
    "conjonctive": "conjonctif",
    "conjonctives": "conjonctive",
    "conjonctivites": "conjonctivite",
    "conjoncturelle": "conjoncturel",
    "conjoncturelles": "conjoncturel",
    "conjoncturels": "conjoncturel",
    "conjonctures": "conjoncture",
    "conjoncturistes": "conjoncturiste",
    "conjugaisons": "conjugaison",
    "conjugale": "conjugal",
    "conjugales": "conjugal",
    "conjugaux": "conjugal",
    "conjugua": "conjuguer",
    "conjuguai": "conjuguer",
    "conjuguaient": "conjuguer",
    "conjuguais": "conjuguer",
    "conjuguait": "conjuguer",
    "conjuguant": "conjuguer",
    "conjuguas": "conjuguer",
    "conjuguasse": "conjuguer",
    "conjuguassent": "conjuguer",
    "conjuguasses": "conjuguer",
    "conjuguassiez": "conjuguer",
    "conjuguassions": "conjuguer",
    "conjugue": "conjuguer",
    "conjuguent": "conjuguer",
    "conjuguera": "conjuguer",
    "conjuguerai": "conjuguer",
    "conjugueraient": "conjuguer",
    "conjuguerais": "conjuguer",
    "conjuguerait": "conjuguer",
    "conjugueras": "conjuguer",
    "conjuguerez": "conjuguer",
    "conjugueriez": "conjuguer",
    "conjuguerions": "conjuguer",
    "conjuguerons": "conjuguer",
    "conjugueront": "conjuguer",
    "conjugues": "conjuguer",
    "conjuguez": "conjuguer",
    "conjuguiez": "conjuguer",
    "conjuguions": "conjuguer",
    "conjuguons": "conjuguer",
    "conjuguâmes": "conjuguer",
    "conjuguât": "conjuguer",
    "conjuguâtes": "conjuguer",
    "conjuguèrent": "conjuguer",
    "conjugué": "conjuguer",
    "conjuguée": "conjuguer",
    "conjuguées": "conjuguer",
    "conjugués": "conjuguer",
    "conjungos": "conjungo",
    "conjura": "conjurer",
    "conjurai": "conjurer",
    "conjuraient": "conjurer",
    "conjurais": "conjurer",
    "conjurait": "conjurer",
    "conjurant": "conjurer",
    "conjuras": "conjurer",
    "conjurasse": "conjurer",
    "conjurassent": "conjurer",
    "conjurasses": "conjurer",
    "conjurassiez": "conjurer",
    "conjurassions": "conjurer",
    "conjurations": "conjuration",
    "conjure": "conjurer",
    "conjurent": "conjurer",
    "conjurera": "conjurer",
    "conjurerai": "conjurer",
    "conjureraient": "conjurer",
    "conjurerais": "conjurer",
    "conjurerait": "conjurer",
    "conjureras": "conjurer",
    "conjurerez": "conjurer",
    "conjureriez": "conjurer",
    "conjurerions": "conjurer",
    "conjurerons": "conjurer",
    "conjureront": "conjurer",
    "conjures": "conjurer",
    "conjurez": "conjurer",
    "conjuriez": "conjurer",
    "conjurions": "conjurer",
    "conjurons": "conjurer",
    "conjurâmes": "conjurer",
    "conjurât": "conjurer",
    "conjurâtes": "conjurer",
    "conjurèrent": "conjurer",
    "conjuré": "conjurer",
    "conjurée": "conjurer",
    "conjurées": "conjurer",
    "conjurés": "conjurer",
    "connais": "connaître",
    "connaissables": "connaissable",
    "connaissaient": "connaître",
    "connaissais": "connaître",
    "connaissait": "connaître",
    "connaissances": "connaissance",
    "connaissant": "connaître",
    "connaisse": "connaître",
    "connaissements": "connaissement",
    "connaissent": "connaître",
    "connaisses": "connaître",
    "connaisseurs": "connaisseur",
    "connaisseuse": "connaisseur",
    "connaisseuses": "connaisseur",
    "connaissez": "connaître",
    "connaissiez": "connaître",
    "connaissions": "connaître",
    "connaissons": "connaître",
    "connards": "connard",
    "connasses": "connasse",
    "connaît": "connaître",
    "connaîtra": "connaître",
    "connaîtrai": "connaître",
    "connaîtraient": "connaître",
    "connaîtrais": "connaître",
    "connaîtrait": "connaître",
    "connaîtras": "connaître",
    "connaîtrez": "connaître",
    "connaîtriez": "connaître",
    "connaîtrions": "connaître",
    "connaîtrons": "connaître",
    "connaîtront": "connaître",
    "conne": "con",
    "conneaux": "conneau",
    "connecta": "connecter",
    "connectai": "connecter",
    "connectaient": "connecter",
    "connectais": "connecter",
    "connectait": "connecter",
    "connectant": "connecter",
    "connectas": "connecter",
    "connectasse": "connecter",
    "connectassent": "connecter",
    "connectasses": "connecter",
    "connectassiez": "connecter",
    "connectassions": "connecter",
    "connecte": "connecter",
    "connectent": "connecter",
    "connectera": "connecter",
    "connecterai": "connecter",
    "connecteraient": "connecter",
    "connecterais": "connecter",
    "connecterait": "connecter",
    "connecteras": "connecter",
    "connecterez": "connecter",
    "connecteriez": "connecter",
    "connecterions": "connecter",
    "connecterons": "connecter",
    "connecteront": "connecter",
    "connectes": "connecter",
    "connectez": "connecter",
    "connectiez": "connecter",
    "connections": "connection",
    "connectons": "connecter",
    "connectâmes": "connecter",
    "connectât": "connecter",
    "connectâtes": "connecter",
    "connectèrent": "connecter",
    "connecté": "connecter",
    "connectée": "connecter",
    "connectées": "connecter",
    "connectés": "connecter",
    "conneries": "connerie",
    "connes": "con",
    "connexes": "connexe",
    "connexions": "connexion",
    "connils": "connil",
    "connivences": "connivence",
    "connotations": "connotation",
    "connu": "connaître",
    "connue": "connu",
    "connues": "connu",
    "connurent": "connaître",
    "connus": "connu",
    "connusse": "connaître",
    "connussent": "connaître",
    "connusses": "connaître",
    "connussiez": "connaître",
    "connussions": "connaître",
    "connut": "connaître",
    "connétables": "connétable",
    "connûmes": "connaître",
    "connût": "connaître",
    "connûtes": "connaître",
    "conoïdaux": "conoïdal",
    "conquerra": "conquérir",
    "conquerrai": "conquérir",
    "conquerraient": "conquérir",
    "conquerrais": "conquérir",
    "conquerrait": "conquérir",
    "conquerras": "conquérir",
    "conquerrez": "conquérir",
    "conquerriez": "conquérir",
    "conquerrions": "conquérir",
    "conquerrons": "conquérir",
    "conquerront": "conquérir",
    "conques": "conque",
    "conquiers": "conquérir",
    "conquiert": "conquérir",
    "conquirent": "conquérir",
    "conquis": "conquérir",
    "conquise": "conquis",
    "conquises": "conquis",
    "conquisse": "conquérir",
    "conquissent": "conquérir",
    "conquisses": "conquérir",
    "conquissiez": "conquérir",
    "conquissions": "conquérir",
    "conquistadores": "conquistador",
    "conquistadors": "conquistador",
    "conquit": "conquérir",
    "conquière": "conquérir",
    "conquièrent": "conquérir",
    "conquières": "conquérir",
    "conquéraient": "conquérir",
    "conquérais": "conquérir",
    "conquérait": "conquérir",
    "conquérant": "conquérir",
    "conquérante": "conquérant",
    "conquérantes": "conquérant",
    "conquérants": "conquérant",
    "conquérez": "conquérir",
    "conquériez": "conquérir",
    "conquérions": "conquérir",
    "conquérons": "conquérir",
    "conquêtes": "conquête",
    "conquîmes": "conquérir",
    "conquît": "conquérir",
    "conquîtes": "conquérir",
    "cons": "con",
    "consacra": "consacrer",
    "consacrai": "consacrer",
    "consacraient": "consacrer",
    "consacrais": "consacrer",
    "consacrait": "consacrer",
    "consacrant": "consacrer",
    "consacras": "consacrer",
    "consacrasse": "consacrer",
    "consacrassent": "consacrer",
    "consacrasses": "consacrer",
    "consacrassiez": "consacrer",
    "consacrassions": "consacrer",
    "consacre": "consacrer",
    "consacrent": "consacrer",
    "consacrera": "consacrer",
    "consacrerai": "consacrer",
    "consacreraient": "consacrer",
    "consacrerais": "consacrer",
    "consacrerait": "consacrer",
    "consacreras": "consacrer",
    "consacrerez": "consacrer",
    "consacreriez": "consacrer",
    "consacrerions": "consacrer",
    "consacrerons": "consacrer",
    "consacreront": "consacrer",
    "consacres": "consacrer",
    "consacrez": "consacrer",
    "consacriez": "consacrer",
    "consacrions": "consacrer",
    "consacrons": "consacrer",
    "consacrâmes": "consacrer",
    "consacrât": "consacrer",
    "consacrâtes": "consacrer",
    "consacrèrent": "consacrer",
    "consacré": "consacrer",
    "consacrée": "consacrer",
    "consacrées": "consacrer",
    "consacrés": "consacrer",
    "consanguine": "consanguin",
    "consanguines": "consanguin",
    "consanguinités": "consanguinité",
    "consanguins": "consanguin",
    "consciences": "conscience",
    "consciencieuse": "consciencieux",
    "consciencieuses": "consciencieux",
    "consciente": "conscient",
    "conscientes": "conscient",
    "conscients": "conscient",
    "conscriptions": "conscription",
    "conscrits": "conscrit",
    "conseilla": "conseiller",
    "conseillai": "conseiller",
    "conseillaient": "conseiller",
    "conseillais": "conseiller",
    "conseillait": "conseiller",
    "conseillant": "conseiller",
    "conseillas": "conseiller",
    "conseillasse": "conseiller",
    "conseillassent": "conseiller",
    "conseillasses": "conseiller",
    "conseillassiez": "conseiller",
    "conseillassions": "conseiller",
    "conseille": "conseiller",
    "conseillent": "conseiller",
    "conseillera": "conseiller",
    "conseillerai": "conseiller",
    "conseilleraient": "conseiller",
    "conseillerais": "conseiller",
    "conseillerait": "conseiller",
    "conseilleras": "conseiller",
    "conseillerez": "conseiller",
    "conseilleriez": "conseiller",
    "conseillerions": "conseiller",
    "conseillerons": "conseiller",
    "conseilleront": "conseiller",
    "conseillers": "conseiller",
    "conseilles": "conseiller",
    "conseilleurs": "conseilleur",
    "conseilleuse": "conseilleur",
    "conseilleuses": "conseilleur",
    "conseillez": "conseiller",
    "conseilliez": "conseiller",
    "conseillions": "conseiller",
    "conseillons": "conseiller",
    "conseillâmes": "conseiller",
    "conseillât": "conseiller",
    "conseillâtes": "conseiller",
    "conseillère": "conseiller",
    "conseillèrent": "conseiller",
    "conseillères": "conseiller",
    "conseillé": "conseiller",
    "conseillée": "conseiller",
    "conseillées": "conseiller",
    "conseillés": "conseiller",
    "conseils": "conseil",
    "consens": "consentir",
    "consensuelle": "consensuel",
    "consensuelles": "consensuel",
    "consensuels": "consensuel",
    "consent": "consentir",
    "consentaient": "consentir",
    "consentais": "consentir",
    "consentait": "consentir",
    "consentant": "consentir",
    "consentante": "consentant",
    "consentantes": "consentant",
    "consentants": "consentant",
    "consente": "consentir",
    "consentements": "consentement",
    "consentent": "consentir",
    "consentes": "consentir",
    "consentez": "consentir",
    "consenti": "consentir",
    "consentie": "consentir",
    "consenties": "consentir",
    "consentiez": "consentir",
    "consentions": "consentir",
    "consentira": "consentir",
    "consentirai": "consentir",
    "consentiraient": "consentir",
    "consentirais": "consentir",
    "consentirait": "consentir",
    "consentiras": "consentir",
    "consentirent": "consentir",
    "consentirez": "consentir",
    "consentiriez": "consentir",
    "consentirions": "consentir",
    "consentirons": "consentir",
    "consentiront": "consentir",
    "consentis": "consentir",
    "consentisse": "consentir",
    "consentissent": "consentir",
    "consentisses": "consentir",
    "consentissiez": "consentir",
    "consentissions": "consentir",
    "consentit": "consentir",
    "consentons": "consentir",
    "consentîmes": "consentir",
    "consentît": "consentir",
    "consentîtes": "consentir",
    "conserva": "conserver",
    "conservai": "conserver",
    "conservaient": "conserver",
    "conservais": "conserver",
    "conservait": "conserver",
    "conservant": "conserver",
    "conservas": "conserver",
    "conservasse": "conserver",
    "conservassent": "conserver",
    "conservasses": "conserver",
    "conservassiez": "conserver",
    "conservassions": "conserver",
    "conservateurs": "conservateur",
    "conservations": "conservation",
    "conservatismes": "conservatisme",
    "conservatoires": "conservatoire",
    "conservatrice": "conservateur",
    "conservatrices": "conservatrice",
    "conserve": "conserver",
    "conservent": "conserver",
    "conservera": "conserver",
    "conserverai": "conserver",
    "conserveraient": "conserver",
    "conserverais": "conserver",
    "conserverait": "conserver",
    "conserveras": "conserver",
    "conserverez": "conserver",
    "conserveries": "conserverie",
    "conserveriez": "conserver",
    "conserverions": "conserver",
    "conserverons": "conserver",
    "conserveront": "conserver",
    "conserves": "conserver",
    "conservez": "conserver",
    "conserviez": "conserver",
    "conservions": "conserver",
    "conservons": "conserver",
    "conservâmes": "conserver",
    "conservât": "conserver",
    "conservâtes": "conserver",
    "conservèrent": "conserver",
    "conservé": "conserver",
    "conservée": "conserver",
    "conservées": "conserver",
    "conservés": "conserver",
    "considère": "considérer",
    "considèrent": "considérer",
    "considères": "considérer",
    "considéra": "considérer",
    "considérables": "considérable",
    "considérai": "considérer",
    "considéraient": "considérer",
    "considérais": "considérer",
    "considérait": "considérer",
    "considérant": "considérer",
    "considérants": "considérant",
    "considéras": "considérer",
    "considérasse": "considérer",
    "considérassent": "considérer",
    "considérasses": "considérer",
    "considérassiez": "considérer",
    "considérassions": "considérer",
    "considérations": "considération",
    "considérera": "considérer",
    "considérerai": "considérer",
    "considéreraient": "considérer",
    "considérerais": "considérer",
    "considérerait": "considérer",
    "considéreras": "considérer",
    "considérerez": "considérer",
    "considéreriez": "considérer",
    "considérerions": "considérer",
    "considérerons": "considérer",
    "considéreront": "considérer",
    "considérez": "considérer",
    "considériez": "considérer",
    "considérions": "considérer",
    "considérons": "considérer",
    "considérâmes": "considérer",
    "considérât": "considérer",
    "considérâtes": "considérer",
    "considérèrent": "considérer",
    "considéré": "considérer",
    "considérée": "considérer",
    "considérées": "considérer",
    "considérés": "considérer",
    "consigna": "consigner",
    "consignai": "consigner",
    "consignaient": "consigner",
    "consignais": "consigner",
    "consignait": "consigner",
    "consignant": "consigner",
    "consignas": "consigner",
    "consignasse": "consigner",
    "consignassent": "consigner",
    "consignasses": "consigner",
    "consignassiez": "consigner",
    "consignassions": "consigner",
    "consignataires": "consignataire",
    "consignations": "consignation",
    "consigne": "consigner",
    "consignent": "consigner",
    "consignera": "consigner",
    "consignerai": "consigner",
    "consigneraient": "consigner",
    "consignerais": "consigner",
    "consignerait": "consigner",
    "consigneras": "consigner",
    "consignerez": "consigner",
    "consigneriez": "consigner",
    "consignerions": "consigner",
    "consignerons": "consigner",
    "consigneront": "consigner",
    "consignes": "consigner",
    "consignez": "consigner",
    "consigniez": "consigner",
    "consignions": "consigner",
    "consignons": "consigner",
    "consignâmes": "consigner",
    "consignât": "consigner",
    "consignâtes": "consigner",
    "consignèrent": "consigner",
    "consigné": "consigner",
    "consignée": "consigner",
    "consignées": "consigner",
    "consignés": "consigner",
    "consista": "consister",
    "consistai": "consister",
    "consistaient": "consister",
    "consistais": "consister",
    "consistait": "consister",
    "consistances": "consistance",
    "consistant": "consister",
    "consistante": "consistant",
    "consistantes": "consistant",
    "consistants": "consistant",
    "consistas": "consister",
    "consistasse": "consister",
    "consistassent": "consister",
    "consistasses": "consister",
    "consistassiez": "consister",
    "consistassions": "consister",
    "consiste": "consister",
    "consistent": "consister",
    "consistera": "consister",
    "consisterai": "consister",
    "consisteraient": "consister",
    "consisterais": "consister",
    "consisterait": "consister",
    "consisteras": "consister",
    "consisterez": "consister",
    "consisteriez": "consister",
    "consisterions": "consister",
    "consisterons": "consister",
    "consisteront": "consister",
    "consistes": "consister",
    "consistez": "consister",
    "consistiez": "consister",
    "consistions": "consister",
    "consistoires": "consistoire",
    "consistons": "consister",
    "consistoriales": "consistorial",
    "consistâmes": "consister",
    "consistât": "consister",
    "consistâtes": "consister",
    "consistèrent": "consister",
    "consisté": "consister",
    "consoeurs": "consoeur",
    "consola": "consoler",
    "consolai": "consoler",
    "consolaient": "consoler",
    "consolais": "consoler",
    "consolait": "consoler",
    "consolant": "consoler",
    "consolante": "consolant",
    "consolantes": "consolant",
    "consolants": "consolant",
    "consolas": "consoler",
    "consolasse": "consoler",
    "consolassent": "consoler",
    "consolasses": "consoler",
    "consolassiez": "consoler",
    "consolassions": "consoler",
    "consolateurs": "consolateur",
    "consolations": "consolation",
    "consolatrice": "consolateur",
    "consolatrices": "consolateur",
    "console": "consoler",
    "consolent": "consoler",
    "consolera": "consoler",
    "consolerai": "consoler",
    "consoleraient": "consoler",
    "consolerais": "consoler",
    "consolerait": "consoler",
    "consoleras": "consoler",
    "consolerez": "consoler",
    "consoleriez": "consoler",
    "consolerions": "consoler",
    "consolerons": "consoler",
    "consoleront": "consoler",
    "consoles": "consoler",
    "consolez": "consoler",
    "consolida": "consolider",
    "consolidai": "consolider",
    "consolidaient": "consolider",
    "consolidais": "consolider",
    "consolidait": "consolider",
    "consolidant": "consolider",
    "consolidas": "consolider",
    "consolidasse": "consolider",
    "consolidassent": "consolider",
    "consolidasses": "consolider",
    "consolidassiez": "consolider",
    "consolidassions": "consolider",
    "consolidations": "consolidation",
    "consolide": "consolider",
    "consolident": "consolider",
    "consolidera": "consolider",
    "consoliderai": "consolider",
    "consolideraient": "consolider",
    "consoliderais": "consolider",
    "consoliderait": "consolider",
    "consolideras": "consolider",
    "consoliderez": "consolider",
    "consolideriez": "consolider",
    "consoliderions": "consolider",
    "consoliderons": "consolider",
    "consolideront": "consolider",
    "consolides": "consolider",
    "consolidez": "consolider",
    "consolidiez": "consolider",
    "consolidions": "consolider",
    "consolidons": "consolider",
    "consolidâmes": "consolider",
    "consolidât": "consolider",
    "consolidâtes": "consolider",
    "consolidèrent": "consolider",
    "consolidé": "consolider",
    "consolidée": "consolider",
    "consolidées": "consolider",
    "consolidés": "consolider",
    "consoliez": "consoler",
    "consolions": "consoler",
    "consolons": "consoler",
    "consolâmes": "consoler",
    "consolât": "consoler",
    "consolâtes": "consoler",
    "consolèrent": "consoler",
    "consolé": "consoler",
    "consolée": "consoler",
    "consolées": "consoler",
    "consolés": "consoler",
    "consomma": "consommer",
    "consommables": "consommable",
    "consommai": "consommer",
    "consommaient": "consommer",
    "consommais": "consommer",
    "consommait": "consommer",
    "consommant": "consommer",
    "consommas": "consommer",
    "consommasse": "consommer",
    "consommassent": "consommer",
    "consommasses": "consommer",
    "consommassiez": "consommer",
    "consommassions": "consommer",
    "consommateurs": "consommateur",
    "consommations": "consommation",
    "consommatrice": "consommateur",
    "consommatrices": "consommateur",
    "consomme": "consommer",
    "consomment": "consommer",
    "consommera": "consommer",
    "consommerai": "consommer",
    "consommeraient": "consommer",
    "consommerais": "consommer",
    "consommerait": "consommer",
    "consommeras": "consommer",
    "consommerez": "consommer",
    "consommeriez": "consommer",
    "consommerions": "consommer",
    "consommerons": "consommer",
    "consommeront": "consommer",
    "consommes": "consommer",
    "consommez": "consommer",
    "consommiez": "consommer",
    "consommions": "consommer",
    "consommons": "consommer",
    "consommâmes": "consommer",
    "consommât": "consommer",
    "consommâtes": "consommer",
    "consommèrent": "consommer",
    "consommé": "consommer",
    "consommée": "consommer",
    "consommées": "consommer",
    "consommés": "consommer",
    "consomptibles": "consomptible",
    "consomptions": "consomption",
    "consomptive": "consomptif",
    "consonances": "consonance",
    "consonante": "consonant",
    "consonantes": "consonant",
    "consonantiques": "consonantique",
    "consonants": "consonant",
    "consonnes": "consonne",
    "consortia": "consortium",
    "consortiums": "consortium",
    "consorts": "consort",
    "consos": "conso",
    "conspira": "conspirer",
    "conspirai": "conspirer",
    "conspiraient": "conspirer",
    "conspirais": "conspirer",
    "conspirait": "conspirer",
    "conspirant": "conspirer",
    "conspiras": "conspirer",
    "conspirasse": "conspirer",
    "conspirassent": "conspirer",
    "conspirasses": "conspirer",
    "conspirassiez": "conspirer",
    "conspirassions": "conspirer",
    "conspirateurs": "conspirateur",
    "conspirations": "conspiration",
    "conspiratrice": "conspirateur",
    "conspiratrices": "conspirateur",
    "conspire": "conspirer",
    "conspirent": "conspirer",
    "conspirera": "conspirer",
    "conspirerai": "conspirer",
    "conspireraient": "conspirer",
    "conspirerais": "conspirer",
    "conspirerait": "conspirer",
    "conspireras": "conspirer",
    "conspirerez": "conspirer",
    "conspireriez": "conspirer",
    "conspirerions": "conspirer",
    "conspirerons": "conspirer",
    "conspireront": "conspirer",
    "conspires": "conspirer",
    "conspirez": "conspirer",
    "conspiriez": "conspirer",
    "conspirions": "conspirer",
    "conspirons": "conspirer",
    "conspirâmes": "conspirer",
    "conspirât": "conspirer",
    "conspirâtes": "conspirer",
    "conspirèrent": "conspirer",
    "conspiré": "conspirer",
    "conspirée": "conspirer",
    "conspirées": "conspirer",
    "conspirés": "conspirer",
    "conspua": "conspuer",
    "conspuai": "conspuer",
    "conspuaient": "conspuer",
    "conspuais": "conspuer",
    "conspuait": "conspuer",
    "conspuant": "conspuer",
    "conspuas": "conspuer",
    "conspuasse": "conspuer",
    "conspuassent": "conspuer",
    "conspuasses": "conspuer",
    "conspuassiez": "conspuer",
    "conspuassions": "conspuer",
    "conspue": "conspuer",
    "conspuent": "conspuer",
    "conspuera": "conspuer",
    "conspuerai": "conspuer",
    "conspueraient": "conspuer",
    "conspuerais": "conspuer",
    "conspuerait": "conspuer",
    "conspueras": "conspuer",
    "conspuerez": "conspuer",
    "conspueriez": "conspuer",
    "conspuerions": "conspuer",
    "conspuerons": "conspuer",
    "conspueront": "conspuer",
    "conspues": "conspuer",
    "conspuez": "conspuer",
    "conspuiez": "conspuer",
    "conspuions": "conspuer",
    "conspuons": "conspuer",
    "conspuâmes": "conspuer",
    "conspuât": "conspuer",
    "conspuâtes": "conspuer",
    "conspuèrent": "conspuer",
    "conspué": "conspuer",
    "conspuée": "conspuer",
    "conspuées": "conspuer",
    "conspués": "conspuer",
    "constances": "constance",
    "constante": "constant",
    "constantes": "constante",
    "constants": "constant",
    "constata": "constater",
    "constatai": "constater",
    "constataient": "constater",
    "constatais": "constater",
    "constatait": "constater",
    "constatant": "constater",
    "constatas": "constater",
    "constatasse": "constater",
    "constatassent": "constater",
    "constatasses": "constater",
    "constatassiez": "constater",
    "constatassions": "constater",
    "constatations": "constatation",
    "constate": "constater",
    "constatent": "constater",
    "constatera": "constater",
    "constaterai": "constater",
    "constateraient": "constater",
    "constaterais": "constater",
    "constaterait": "constater",
    "constateras": "constater",
    "constaterez": "constater",
    "constateriez": "constater",
    "constaterions": "constater",
    "constaterons": "constater",
    "constateront": "constater",
    "constates": "constater",
    "constatez": "constater",
    "constatiez": "constater",
    "constations": "constater",
    "constatons": "constater",
    "constats": "constat",
    "constatâmes": "constater",
    "constatât": "constater",
    "constatâtes": "constater",
    "constatèrent": "constater",
    "constaté": "constater",
    "constatée": "constater",
    "constatées": "constater",
    "constatés": "constater",
    "constella": "consteller",
    "constellai": "consteller",
    "constellaient": "consteller",
    "constellais": "consteller",
    "constellait": "consteller",
    "constellant": "consteller",
    "constellas": "consteller",
    "constellasse": "consteller",
    "constellassent": "consteller",
    "constellasses": "consteller",
    "constellassiez": "consteller",
    "constellassions": "consteller",
    "constellations": "constellation",
    "constelle": "consteller",
    "constellent": "consteller",
    "constellera": "consteller",
    "constellerai": "consteller",
    "constelleraient": "consteller",
    "constellerais": "consteller",
    "constellerait": "consteller",
    "constelleras": "consteller",
    "constellerez": "consteller",
    "constelleriez": "consteller",
    "constellerions": "consteller",
    "constellerons": "consteller",
    "constelleront": "consteller",
    "constelles": "consteller",
    "constellez": "consteller",
    "constelliez": "consteller",
    "constellions": "consteller",
    "constellons": "consteller",
    "constellâmes": "consteller",
    "constellât": "consteller",
    "constellâtes": "consteller",
    "constellèrent": "consteller",
    "constellé": "consteller",
    "constellée": "consteller",
    "constellées": "consteller",
    "constellés": "consteller",
    "consterna": "consterner",
    "consternai": "consterner",
    "consternaient": "consterner",
    "consternais": "consterner",
    "consternait": "consterner",
    "consternant": "consterner",
    "consternante": "consternant",
    "consternantes": "consternant",
    "consternants": "consternant",
    "consternas": "consterner",
    "consternasse": "consterner",
    "consternassent": "consterner",
    "consternasses": "consterner",
    "consternassiez": "consterner",
    "consternassions": "consterner",
    "consternations": "consternation",
    "consterne": "consterner",
    "consternent": "consterner",
    "consternera": "consterner",
    "consternerai": "consterner",
    "consterneraient": "consterner",
    "consternerais": "consterner",
    "consternerait": "consterner",
    "consterneras": "consterner",
    "consternerez": "consterner",
    "consterneriez": "consterner",
    "consternerions": "consterner",
    "consternerons": "consterner",
    "consterneront": "consterner",
    "consternes": "consterner",
    "consternez": "consterner",
    "consterniez": "consterner",
    "consternions": "consterner",
    "consternons": "consterner",
    "consternâmes": "consterner",
    "consternât": "consterner",
    "consternâtes": "consterner",
    "consternèrent": "consterner",
    "consterné": "consterner",
    "consternée": "consterner",
    "consternées": "consterner",
    "consternés": "consterner",
    "constipa": "constiper",
    "constipai": "constiper",
    "constipaient": "constiper",
    "constipais": "constiper",
    "constipait": "constiper",
    "constipant": "constiper",
    "constipas": "constiper",
    "constipasse": "constiper",
    "constipassent": "constiper",
    "constipasses": "constiper",
    "constipassiez": "constiper",
    "constipassions": "constiper",
    "constipations": "constipation",
    "constipe": "constiper",
    "constipent": "constiper",
    "constipera": "constiper",
    "constiperai": "constiper",
    "constiperaient": "constiper",
    "constiperais": "constiper",
    "constiperait": "constiper",
    "constiperas": "constiper",
    "constiperez": "constiper",
    "constiperiez": "constiper",
    "constiperions": "constiper",
    "constiperons": "constiper",
    "constiperont": "constiper",
    "constipes": "constiper",
    "constipez": "constiper",
    "constipiez": "constiper",
    "constipions": "constiper",
    "constipons": "constiper",
    "constipâmes": "constiper",
    "constipât": "constiper",
    "constipâtes": "constiper",
    "constipèrent": "constiper",
    "constipé": "constiper",
    "constipée": "constiper",
    "constipées": "constiper",
    "constipés": "constiper",
    "constitua": "constituer",
    "constituai": "constituer",
    "constituaient": "constituer",
    "constituais": "constituer",
    "constituait": "constituer",
    "constituant": "constituer",
    "constituante": "constituant",
    "constituantes": "constituant",
    "constituants": "constituant",
    "constituas": "constituer",
    "constituasse": "constituer",
    "constituassent": "constituer",
    "constituasses": "constituer",
    "constituassiez": "constituer",
    "constituassions": "constituer",
    "constitue": "constituer",
    "constituent": "constituer",
    "constituera": "constituer",
    "constituerai": "constituer",
    "constitueraient": "constituer",
    "constituerais": "constituer",
    "constituerait": "constituer",
    "constitueras": "constituer",
    "constituerez": "constituer",
    "constitueriez": "constituer",
    "constituerions": "constituer",
    "constituerons": "constituer",
    "constitueront": "constituer",
    "constitues": "constituer",
    "constituez": "constituer",
    "constituiez": "constituer",
    "constituions": "constituer",
    "constituons": "constituer",
    "constitutifs": "constitutif",
    "constitutionnalités": "constitutionnalité",
    "constitutionnelle": "constitutionnel",
    "constitutionnelles": "constitutionnel",
    "constitutionnels": "constitutionnel",
    "constitutions": "constitution",
    "constitutive": "constitutif",
    "constitutives": "constitutif",
    "constituâmes": "constituer",
    "constituât": "constituer",
    "constituâtes": "constituer",
    "constituèrent": "constituer",
    "constitué": "constituer",
    "constituée": "constituer",
    "constituées": "constituer",
    "constitués": "constituer",
    "constricteurs": "constricteur",
    "constrictions": "constriction",
    "constrictive": "constrictif",
    "constrictors": "constrictor",
    "constructeurs": "constructeur",
    "constructibles": "constructible",
    "constructifs": "constructif",
    "constructions": "construction",
    "constructive": "constructif",
    "constructives": "constructif",
    "constructrice": "constructeur",
    "constructrices": "constructeur",
    "construira": "construire",
    "construirai": "construire",
    "construiraient": "construire",
    "construirais": "construire",
    "construirait": "construire",
    "construiras": "construire",
    "construirez": "construire",
    "construiriez": "construire",
    "construirions": "construire",
    "construirons": "construire",
    "construiront": "construire",
    "construis": "construire",
    "construisaient": "construire",
    "construisais": "construire",
    "construisait": "construire",
    "construisant": "construire",
    "construise": "construire",
    "construisent": "construire",
    "construises": "construire",
    "construisez": "construire",
    "construisiez": "construire",
    "construisions": "construire",
    "construisirent": "construire",
    "construisis": "construire",
    "construisisse": "construire",
    "construisissent": "construire",
    "construisisses": "construire",
    "construisissiez": "construire",
    "construisissions": "construire",
    "construisit": "construire",
    "construisons": "construire",
    "construisîmes": "construire",
    "construisît": "construire",
    "construisîtes": "construire",
    "construit": "construire",
    "construite": "construire",
    "construites": "construire",
    "construits": "construire",
    "consubstantielle": "consubstantiel",
    "consubstantielles": "consubstantiel",
    "consubstantiels": "consubstantiel",
    "consulaires": "consulaire",
    "consulations": "consulation",
    "consulats": "consulat",
    "consuls": "consul",
    "consulta": "consulter",
    "consultables": "consultable",
    "consultai": "consulter",
    "consultaient": "consulter",
    "consultais": "consulter",
    "consultait": "consulter",
    "consultant": "consulter",
    "consultante": "consultant",
    "consultantes": "consultant",
    "consultants": "consultant",
    "consultas": "consulter",
    "consultasse": "consulter",
    "consultassent": "consulter",
    "consultasses": "consulter",
    "consultassiez": "consulter",
    "consultassions": "consulter",
    "consultatifs": "consultatif",
    "consultations": "consultation",
    "consultative": "consultatif",
    "consultatives": "consultatif",
    "consulte": "consulter",
    "consultent": "consulter",
    "consultera": "consulter",
    "consulterai": "consulter",
    "consulteraient": "consulter",
    "consulterais": "consulter",
    "consulterait": "consulter",
    "consulteras": "consulter",
    "consulterez": "consulter",
    "consulteriez": "consulter",
    "consulterions": "consulter",
    "consulterons": "consulter",
    "consulteront": "consulter",
    "consultes": "consulter",
    "consultez": "consulter",
    "consultiez": "consulter",
    "consultions": "consulter",
    "consultons": "consulter",
    "consultâmes": "consulter",
    "consultât": "consulter",
    "consultâtes": "consulter",
    "consultèrent": "consulter",
    "consulté": "consulter",
    "consultée": "consulter",
    "consultées": "consulter",
    "consultés": "consulter",
    "consuma": "consumer",
    "consumai": "consumer",
    "consumaient": "consumer",
    "consumais": "consumer",
    "consumait": "consumer",
    "consumant": "consumer",
    "consumas": "consumer",
    "consumasse": "consumer",
    "consumassent": "consumer",
    "consumasses": "consumer",
    "consumassiez": "consumer",
    "consumassions": "consumer",
    "consume": "consumer",
    "consument": "consumer",
    "consumera": "consumer",
    "consumerai": "consumer",
    "consumeraient": "consumer",
    "consumerais": "consumer",
    "consumerait": "consumer",
    "consumeras": "consumer",
    "consumerez": "consumer",
    "consumeriez": "consumer",
    "consumerions": "consumer",
    "consumerons": "consumer",
    "consumeront": "consumer",
    "consumes": "consumer",
    "consumez": "consumer",
    "consumiez": "consumer",
    "consumions": "consumer",
    "consumons": "consumer",
    "consumâmes": "consumer",
    "consumât": "consumer",
    "consumâtes": "consumer",
    "consumèrent": "consumer",
    "consumé": "consumer",
    "consumée": "consumer",
    "consumées": "consumer",
    "consumés": "consumer",
    "consécrations": "consécration",
    "consécutifs": "consécutif",
    "consécutive": "consécutif",
    "consécutives": "consécutif",
    "conséquences": "conséquence",
    "conséquente": "conséquent",
    "conséquentes": "conséquent",
    "conséquents": "conséquent",
    "conta": "conter",
    "contacta": "contacter",
    "contactai": "contacter",
    "contactaient": "contacter",
    "contactais": "contacter",
    "contactait": "contacter",
    "contactant": "contacter",
    "contactas": "contacter",
    "contactasse": "contacter",
    "contactassent": "contacter",
    "contactasses": "contacter",
    "contactassiez": "contacter",
    "contactassions": "contacter",
    "contacte": "contacter",
    "contactent": "contacter",
    "contactera": "contacter",
    "contacterai": "contacter",
    "contacteraient": "contacter",
    "contacterais": "contacter",
    "contacterait": "contacter",
    "contacteras": "contacter",
    "contacterez": "contacter",
    "contacteriez": "contacter",
    "contacterions": "contacter",
    "contacterons": "contacter",
    "contacteront": "contacter",
    "contactes": "contacter",
    "contactez": "contacter",
    "contactiez": "contacter",
    "contactions": "contacter",
    "contactons": "contacter",
    "contacts": "contact",
    "contactâmes": "contacter",
    "contactât": "contacter",
    "contactâtes": "contacter",
    "contactèrent": "contacter",
    "contacté": "contacter",
    "contactée": "contacter",
    "contactées": "contacter",
    "contactés": "contacter",
    "contagieuse": "contagieux",
    "contagieuses": "contagieux",
    "contagions": "contagion",
    "contai": "conter",
    "contaient": "conter",
    "containers": "container",
    "contais": "conter",
    "contait": "conter",
    "contamina": "contaminer",
    "contaminai": "contaminer",
    "contaminaient": "contaminer",
    "contaminais": "contaminer",
    "contaminait": "contaminer",
    "contaminant": "contaminer",
    "contaminante": "contaminant",
    "contaminantes": "contaminant",
    "contaminants": "contaminant",
    "contaminas": "contaminer",
    "contaminasse": "contaminer",
    "contaminassent": "contaminer",
    "contaminasses": "contaminer",
    "contaminassiez": "contaminer",
    "contaminassions": "contaminer",
    "contaminateurs": "contaminateur",
    "contaminations": "contamination",
    "contaminatrice": "contaminateur",
    "contaminatrices": "contaminateur",
    "contamine": "contaminer",
    "contaminent": "contaminer",
    "contaminera": "contaminer",
    "contaminerai": "contaminer",
    "contamineraient": "contaminer",
    "contaminerais": "contaminer",
    "contaminerait": "contaminer",
    "contamineras": "contaminer",
    "contaminerez": "contaminer",
    "contamineriez": "contaminer",
    "contaminerions": "contaminer",
    "contaminerons": "contaminer",
    "contamineront": "contaminer",
    "contamines": "contaminer",
    "contaminez": "contaminer",
    "contaminiez": "contaminer",
    "contaminions": "contaminer",
    "contaminons": "contaminer",
    "contaminâmes": "contaminer",
    "contaminât": "contaminer",
    "contaminâtes": "contaminer",
    "contaminèrent": "contaminer",
    "contaminé": "contaminer",
    "contaminée": "contaminer",
    "contaminées": "contaminer",
    "contaminés": "contaminer",
    "contant": "conter",
    "contas": "conter",
    "contasse": "conter",
    "contassent": "conter",
    "contasses": "conter",
    "contassiez": "conter",
    "contassions": "conter",
    "conte": "conter",
    "contempla": "contempler",
    "contemplai": "contempler",
    "contemplaient": "contempler",
    "contemplais": "contempler",
    "contemplait": "contempler",
    "contemplant": "contempler",
    "contemplas": "contempler",
    "contemplasse": "contempler",
    "contemplassent": "contempler",
    "contemplasses": "contempler",
    "contemplassiez": "contempler",
    "contemplassions": "contempler",
    "contemplatifs": "contemplatif",
    "contemplations": "contemplation",
    "contemplative": "contemplatif",
    "contemplatives": "contemplatif",
    "contemplatrice": "contemplateur",
    "contemple": "contempler",
    "contemplent": "contempler",
    "contemplera": "contempler",
    "contemplerai": "contempler",
    "contempleraient": "contempler",
    "contemplerais": "contempler",
    "contemplerait": "contempler",
    "contempleras": "contempler",
    "contemplerez": "contempler",
    "contempleriez": "contempler",
    "contemplerions": "contempler",
    "contemplerons": "contempler",
    "contempleront": "contempler",
    "contemples": "contempler",
    "contemplez": "contempler",
    "contempliez": "contempler",
    "contemplions": "contempler",
    "contemplons": "contempler",
    "contemplâmes": "contempler",
    "contemplât": "contempler",
    "contemplâtes": "contempler",
    "contemplèrent": "contempler",
    "contemplé": "contempler",
    "contemplée": "contempler",
    "contemplées": "contempler",
    "contemplés": "contempler",
    "contemporaine": "contemporain",
    "contemporaines": "contemporain",
    "contemporains": "contemporain",
    "contempteurs": "contempteur",
    "contemptrice": "contempteur",
    "contemptrices": "contempteur",
    "contenaient": "contenir",
    "contenais": "contenir",
    "contenait": "contenir",
    "contenances": "contenance",
    "contenant": "contenir",
    "contenants": "contenant",
    "conteneurs": "conteneur",
    "contenez": "contenir",
    "conteniez": "contenir",
    "contenions": "contenir",
    "contenons": "contenir",
    "content": "conter",
    "contenta": "contenter",
    "contentai": "contenter",
    "contentaient": "contenter",
    "contentais": "contenter",
    "contentait": "contenter",
    "contentant": "contenter",
    "contentas": "contenter",
    "contentasse": "contenter",
    "contentassent": "contenter",
    "contentasses": "contenter",
    "contentassiez": "contenter",
    "contentassions": "contenter",
    "contente": "contenter",
    "contentements": "contentement",
    "contentent": "contenter",
    "contentera": "contenter",
    "contenterai": "contenter",
    "contenteraient": "contenter",
    "contenterais": "contenter",
    "contenterait": "contenter",
    "contenteras": "contenter",
    "contenterez": "contenter",
    "contenteriez": "contenter",
    "contenterions": "contenter",
    "contenterons": "contenter",
    "contenteront": "contenter",
    "contentes": "contenter",
    "contentez": "contenter",
    "contentieuse": "contentieux",
    "contentieuses": "contentieux",
    "contentiez": "contenter",
    "contentions": "contention",
    "contentons": "contenter",
    "contents": "content",
    "contentâmes": "contenter",
    "contentât": "contenter",
    "contentâtes": "contenter",
    "contentèrent": "contenter",
    "contenté": "contenter",
    "contentée": "contenter",
    "contentées": "contenter",
    "contentés": "contenter",
    "contenu": "contenir",
    "contenue": "contenu",
    "contenues": "contenu",
    "contenus": "contenu",
    "contera": "conter",
    "conterai": "conter",
    "conteraient": "conter",
    "conterais": "conter",
    "conterait": "conter",
    "conteras": "conter",
    "conterez": "conter",
    "conteriez": "conter",
    "conterions": "conter",
    "conterons": "conter",
    "conteront": "conter",
    "contes": "conter",
    "contesta": "contester",
    "contestables": "contestable",
    "contestai": "contester",
    "contestaient": "contester",
    "contestais": "contester",
    "contestait": "contester",
    "contestant": "contester",
    "contestas": "contester",
    "contestasse": "contester",
    "contestassent": "contester",
    "contestasses": "contester",
    "contestassiez": "contester",
    "contestassions": "contester",
    "contestataires": "contestataire",
    "contestations": "contestation",
    "conteste": "contester",
    "contestent": "contester",
    "contestera": "contester",
    "contesterai": "contester",
    "contesteraient": "contester",
    "contesterais": "contester",
    "contesterait": "contester",
    "contesteras": "contester",
    "contesterez": "contester",
    "contesteriez": "contester",
    "contesterions": "contester",
    "contesterons": "contester",
    "contesteront": "contester",
    "contestes": "contester",
    "contestez": "contester",
    "contestiez": "contester",
    "contestions": "contester",
    "contestons": "contester",
    "contestâmes": "contester",
    "contestât": "contester",
    "contestâtes": "contester",
    "contestèrent": "contester",
    "contesté": "contester",
    "contestée": "contester",
    "contestées": "contester",
    "contestés": "contester",
    "conteurs": "conteur",
    "conteuse": "conteur",
    "conteuses": "conteur",
    "contextes": "contexte",
    "contez": "conter",
    "contiendra": "contenir",
    "contiendrai": "contenir",
    "contiendraient": "contenir",
    "contiendrais": "contenir",
    "contiendrait": "contenir",
    "contiendras": "contenir",
    "contiendrez": "contenir",
    "contiendriez": "contenir",
    "contiendrions": "contenir",
    "contiendrons": "contenir",
    "contiendront": "contenir",
    "contienne": "contenir",
    "contiennent": "contenir",
    "contiennes": "contenir",
    "contiens": "contenir",
    "contient": "contenir",
    "contiez": "conter",
    "contigus": "contigu",
    "contiguë": "contigu",
    "contiguës": "contigu",
    "contiguïtés": "contiguïté",
    "continences": "continence",
    "continentale": "continental",
    "continentales": "continental",
    "continentaux": "continental",
    "continente": "continent",
    "continentes": "continent",
    "continents": "continent",
    "contingences": "contingence",
    "contingentaires": "contingentaire",
    "contingente": "contingent",
    "contingentements": "contingentement",
    "contingentes": "contingent",
    "contingents": "contingent",
    "contingenté": "contingenter",
    "continrent": "contenir",
    "contins": "contenir",
    "continsse": "contenir",
    "continssent": "contenir",
    "continsses": "contenir",
    "continssiez": "contenir",
    "continssions": "contenir",
    "contint": "contenir",
    "continua": "continuer",
    "continuai": "continuer",
    "continuaient": "continuer",
    "continuais": "continuer",
    "continuait": "continuer",
    "continuant": "continuer",
    "continuas": "continuer",
    "continuasse": "continuer",
    "continuassent": "continuer",
    "continuasses": "continuer",
    "continuassiez": "continuer",
    "continuassions": "continuer",
    "continuateurs": "continuateur",
    "continuations": "continuation",
    "continue": "continuer",
    "continuelle": "continuel",
    "continuelles": "continuel",
    "continuels": "continuel",
    "continuent": "continuer",
    "continuera": "continuer",
    "continuerai": "continuer",
    "continueraient": "continuer",
    "continuerais": "continuer",
    "continuerait": "continuer",
    "continueras": "continuer",
    "continuerez": "continuer",
    "continueriez": "continuer",
    "continuerions": "continuer",
    "continuerons": "continuer",
    "continueront": "continuer",
    "continues": "continuer",
    "continuez": "continuer",
    "continuiez": "continuer",
    "continuions": "continuer",
    "continuités": "continuité",
    "continuons": "continuer",
    "continuos": "continuo",
    "continus": "continu",
    "continuâmes": "continuer",
    "continuât": "continuer",
    "continuâtes": "continuer",
    "continuèrent": "continuer",
    "continué": "continuer",
    "continuée": "continuer",
    "continuées": "continuer",
    "continués": "continuer",
    "contions": "conter",
    "contondante": "contondant",
    "contondantes": "contondant",
    "contondants": "contondant",
    "contons": "conter",
    "contorsionna": "contorsionner",
    "contorsionnai": "contorsionner",
    "contorsionnaient": "contorsionner",
    "contorsionnais": "contorsionner",
    "contorsionnait": "contorsionner",
    "contorsionnant": "contorsionner",
    "contorsionnas": "contorsionner",
    "contorsionnasse": "contorsionner",
    "contorsionnassent": "contorsionner",
    "contorsionnasses": "contorsionner",
    "contorsionnassiez": "contorsionner",
    "contorsionnassions": "contorsionner",
    "contorsionne": "contorsionner",
    "contorsionnent": "contorsionner",
    "contorsionnera": "contorsionner",
    "contorsionnerai": "contorsionner",
    "contorsionneraient": "contorsionner",
    "contorsionnerais": "contorsionner",
    "contorsionnerait": "contorsionner",
    "contorsionneras": "contorsionner",
    "contorsionnerez": "contorsionner",
    "contorsionneriez": "contorsionner",
    "contorsionnerions": "contorsionner",
    "contorsionnerons": "contorsionner",
    "contorsionneront": "contorsionner",
    "contorsionnes": "contorsionner",
    "contorsionnez": "contorsionner",
    "contorsionniez": "contorsionner",
    "contorsionnions": "contorsionner",
    "contorsionnistes": "contorsionniste",
    "contorsionnons": "contorsionner",
    "contorsionnâmes": "contorsionner",
    "contorsionnât": "contorsionner",
    "contorsionnâtes": "contorsionner",
    "contorsionnèrent": "contorsionner",
    "contorsionné": "contorsionner",
    "contorsionnée": "contorsionner",
    "contorsionnées": "contorsionner",
    "contorsionnés": "contorsionner",
    "contorsions": "contorsion",
    "contourna": "contourner",
    "contournai": "contourner",
    "contournaient": "contourner",
    "contournais": "contourner",
    "contournait": "contourner",
    "contournant": "contourner",
    "contournas": "contourner",
    "contournasse": "contourner",
    "contournassent": "contourner",
    "contournasses": "contourner",
    "contournassiez": "contourner",
    "contournassions": "contourner",
    "contourne": "contourner",
    "contournements": "contournement",
    "contournent": "contourner",
    "contournera": "contourner",
    "contournerai": "contourner",
    "contourneraient": "contourner",
    "contournerais": "contourner",
    "contournerait": "contourner",
    "contourneras": "contourner",
    "contournerez": "contourner",
    "contourneriez": "contourner",
    "contournerions": "contourner",
    "contournerons": "contourner",
    "contourneront": "contourner",
    "contournes": "contourner",
    "contournez": "contourner",
    "contourniez": "contourner",
    "contournions": "contourner",
    "contournons": "contourner",
    "contournâmes": "contourner",
    "contournât": "contourner",
    "contournâtes": "contourner",
    "contournèrent": "contourner",
    "contourné": "contourner",
    "contournée": "contourner",
    "contournées": "contourner",
    "contournés": "contourner",
    "contours": "contour",
    "contra": "contrer",
    "contraceptifs": "contraceptif",
    "contraceptions": "contraception",
    "contraceptive": "contraceptif",
    "contraceptives": "contraceptif",
    "contracta": "contracter",
    "contractai": "contracter",
    "contractaient": "contracter",
    "contractais": "contracter",
    "contractait": "contracter",
    "contractant": "contracter",
    "contractante": "contractant",
    "contractantes": "contractant",
    "contractants": "contractant",
    "contractas": "contracter",
    "contractasse": "contracter",
    "contractassent": "contracter",
    "contractasses": "contracter",
    "contractassiez": "contracter",
    "contractassions": "contracter",
    "contracte": "contracter",
    "contractent": "contracter",
    "contractera": "contracter",
    "contracterai": "contracter",
    "contracteraient": "contracter",
    "contracterais": "contracter",
    "contracterait": "contracter",
    "contracteras": "contracter",
    "contracterez": "contracter",
    "contracteriez": "contracter",
    "contracterions": "contracter",
    "contracterons": "contracter",
    "contracteront": "contracter",
    "contractes": "contracter",
    "contractez": "contracter",
    "contractiez": "contracter",
    "contractions": "contraction",
    "contractons": "contracter",
    "contractuelle": "contractuel",
    "contractuelles": "contractuel",
    "contractuels": "contractuel",
    "contractures": "contracture",
    "contractâmes": "contracter",
    "contractât": "contracter",
    "contractâtes": "contracter",
    "contractèrent": "contracter",
    "contracté": "contracter",
    "contractée": "contracter",
    "contractées": "contracter",
    "contractés": "contracter",
    "contradicteurs": "contradicteur",
    "contradictions": "contradiction",
    "contradictoires": "contradictoire",
    "contradictrice": "contradicteur",
    "contradictrices": "contradicteur",
    "contrai": "contrer",
    "contraient": "contrer",
    "contraignaient": "contraindre",
    "contraignais": "contraindre",
    "contraignait": "contraindre",
    "contraignant": "contraindre",
    "contraignante": "contraignant",
    "contraignantes": "contraignant",
    "contraignants": "contraignant",
    "contraigne": "contraindre",
    "contraignent": "contraindre",
    "contraignes": "contraindre",
    "contraignez": "contraindre",
    "contraigniez": "contraindre",
    "contraignions": "contraindre",
    "contraignirent": "contraindre",
    "contraignis": "contraindre",
    "contraignisse": "contraindre",
    "contraignissent": "contraindre",
    "contraignisses": "contraindre",
    "contraignissiez": "contraindre",
    "contraignissions": "contraindre",
    "contraignit": "contraindre",
    "contraignons": "contraindre",
    "contraignîmes": "contraindre",
    "contraignît": "contraindre",
    "contraignîtes": "contraindre",
    "contraindra": "contraindre",
    "contraindrai": "contraindre",
    "contraindraient": "contraindre",
    "contraindrais": "contraindre",
    "contraindrait": "contraindre",
    "contraindras": "contraindre",
    "contraindrez": "contraindre",
    "contraindriez": "contraindre",
    "contraindrions": "contraindre",
    "contraindrons": "contraindre",
    "contraindront": "contraindre",
    "contrains": "contraindre",
    "contraint": "contraindre",
    "contrainte": "contraint",
    "contraintes": "contrainte",
    "contraints": "contraint",
    "contraires": "contraire",
    "contrais": "contrer",
    "contrait": "contrer",
    "contraltos": "contralto",
    "contrant": "contrer",
    "contraria": "contrarier",
    "contrariai": "contrarier",
    "contrariaient": "contrarier",
    "contrariais": "contrarier",
    "contrariait": "contrarier",
    "contrariant": "contrarier",
    "contrariante": "contrariant",
    "contrariantes": "contrariant",
    "contrariants": "contrariant",
    "contrarias": "contrarier",
    "contrariasse": "contrarier",
    "contrariassent": "contrarier",
    "contrariasses": "contrarier",
    "contrariassiez": "contrarier",
    "contrariassions": "contrarier",
    "contrarie": "contrarier",
    "contrarient": "contrarier",
    "contrariera": "contrarier",
    "contrarierai": "contrarier",
    "contrarieraient": "contrarier",
    "contrarierais": "contrarier",
    "contrarierait": "contrarier",
    "contrarieras": "contrarier",
    "contrarierez": "contrarier",
    "contrarieriez": "contrarier",
    "contrarierions": "contrarier",
    "contrarierons": "contrarier",
    "contrarieront": "contrarier",
    "contraries": "contrarier",
    "contrariez": "contrarier",
    "contrariiez": "contrarier",
    "contrariions": "contrarier",
    "contrarions": "contrarier",
    "contrariâmes": "contrarier",
    "contrariât": "contrarier",
    "contrariâtes": "contrarier",
    "contrarièrent": "contrarier",
    "contrarié": "contrarier",
    "contrariée": "contrarier",
    "contrariées": "contrarier",
    "contrariés": "contrarier",
    "contrariétés": "contrariété",
    "contras": "contrer",
    "contrasse": "contrer",
    "contrassent": "contrer",
    "contrasses": "contrer",
    "contrassiez": "contrer",
    "contrassions": "contrer",
    "contrasta": "contraster",
    "contrastai": "contraster",
    "contrastaient": "contraster",
    "contrastais": "contraster",
    "contrastait": "contraster",
    "contrastant": "contraster",
    "contrastante": "contrastant",
    "contrastantes": "contrastant",
    "contrastants": "contrastant",
    "contrastas": "contraster",
    "contrastasse": "contraster",
    "contrastassent": "contraster",
    "contrastasses": "contraster",
    "contrastassiez": "contraster",
    "contrastassions": "contraster",
    "contraste": "contraster",
    "contrastent": "contraster",
    "contrastera": "contraster",
    "contrasterai": "contraster",
    "contrasteraient": "contraster",
    "contrasterais": "contraster",
    "contrasterait": "contraster",
    "contrasteras": "contraster",
    "contrasterez": "contraster",
    "contrasteriez": "contraster",
    "contrasterions": "contraster",
    "contrasterons": "contraster",
    "contrasteront": "contraster",
    "contrastes": "contraster",
    "contrastez": "contraster",
    "contrastiez": "contraster",
    "contrastions": "contraster",
    "contrastons": "contraster",
    "contrastâmes": "contraster",
    "contrastât": "contraster",
    "contrastâtes": "contraster",
    "contrastèrent": "contraster",
    "contrasté": "contraster",
    "contrastée": "contraster",
    "contrastées": "contraster",
    "contrastés": "contraster",
    "contrats": "contrat",
    "contraventions": "contravention",
    "contre": "contrer",
    "contre-accusations": "contre-accusation",
    "contre-alizés": "contre-alizé",
    "contre-allées": "contre-allée",
    "contre-amiraux": "contre-amiral",
    "contre-appels": "contre-appel",
    "contre-attaqua": "contre-attaquer",
    "contre-attaquai": "contre-attaquer",
    "contre-attaquaient": "contre-attaquer",
    "contre-attaquais": "contre-attaquer",
    "contre-attaquait": "contre-attaquer",
    "contre-attaquant": "contre-attaquer",
    "contre-attaquas": "contre-attaquer",
    "contre-attaquasse": "contre-attaquer",
    "contre-attaquassent": "contre-attaquer",
    "contre-attaquasses": "contre-attaquer",
    "contre-attaquassiez": "contre-attaquer",
    "contre-attaquassions": "contre-attaquer",
    "contre-attaque": "contre-attaquer",
    "contre-attaquent": "contre-attaquer",
    "contre-attaquera": "contre-attaquer",
    "contre-attaquerai": "contre-attaquer",
    "contre-attaqueraient": "contre-attaquer",
    "contre-attaquerais": "contre-attaquer",
    "contre-attaquerait": "contre-attaquer",
    "contre-attaqueras": "contre-attaquer",
    "contre-attaquerez": "contre-attaquer",
    "contre-attaqueriez": "contre-attaquer",
    "contre-attaquerions": "contre-attaquer",
    "contre-attaquerons": "contre-attaquer",
    "contre-attaqueront": "contre-attaquer",
    "contre-attaques": "contre-attaquer",
    "contre-attaquez": "contre-attaquer",
    "contre-attaquiez": "contre-attaquer",
    "contre-attaquions": "contre-attaquer",
    "contre-attaquons": "contre-attaquer",
    "contre-attaquâmes": "contre-attaquer",
    "contre-attaquât": "contre-attaquer",
    "contre-attaquâtes": "contre-attaquer",
    "contre-attaquèrent": "contre-attaquer",
    "contre-attaqué": "contre-attaquer",
    "contre-attaquée": "contre-attaquer",
    "contre-attaquées": "contre-attaquer",
    "contre-attaqués": "contre-attaquer",
    "contre-bas": "contre-ba",
    "contre-chants": "contre-chant",
    "contre-chocs": "contre-choc",
    "contre-clés": "contre-clé",
    "contre-courants": "contre-courant",
    "contre-enquêtes": "contre-enquête",
    "contre-espionnages": "contre-espionnage",
    "contre-essais": "contre-essai",
    "contre-exemples": "contre-exemple",
    "contre-expertises": "contre-expertise",
    "contre-fenêtres": "contre-fenêtre",
    "contre-feux": "contre-feu",
    "contre-fiches": "contre-fiche",
    "contre-filets": "contre-filet",
    "contre-fils": "contre-fil",
    "contre-indications": "contre-indication",
    "contre-indiqua": "contre-indiquer",
    "contre-indiquai": "contre-indiquer",
    "contre-indiquaient": "contre-indiquer",
    "contre-indiquais": "contre-indiquer",
    "contre-indiquait": "contre-indiquer",
    "contre-indiquant": "contre-indiquer",
    "contre-indiquas": "contre-indiquer",
    "contre-indiquasse": "contre-indiquer",
    "contre-indiquassent": "contre-indiquer",
    "contre-indiquasses": "contre-indiquer",
    "contre-indiquassiez": "contre-indiquer",
    "contre-indiquassions": "contre-indiquer",
    "contre-indique": "contre-indiquer",
    "contre-indiquent": "contre-indiquer",
    "contre-indiquera": "contre-indiquer",
    "contre-indiquerai": "contre-indiquer",
    "contre-indiqueraient": "contre-indiquer",
    "contre-indiquerais": "contre-indiquer",
    "contre-indiquerait": "contre-indiquer",
    "contre-indiqueras": "contre-indiquer",
    "contre-indiquerez": "contre-indiquer",
    "contre-indiqueriez": "contre-indiquer",
    "contre-indiquerions": "contre-indiquer",
    "contre-indiquerons": "contre-indiquer",
    "contre-indiqueront": "contre-indiquer",
    "contre-indiques": "contre-indiquer",
    "contre-indiquez": "contre-indiquer",
    "contre-indiquiez": "contre-indiquer",
    "contre-indiquions": "contre-indiquer",
    "contre-indiquons": "contre-indiquer",
    "contre-indiquâmes": "contre-indiquer",
    "contre-indiquât": "contre-indiquer",
    "contre-indiquâtes": "contre-indiquer",
    "contre-indiquèrent": "contre-indiquer",
    "contre-indiqué": "contre-indiquer",
    "contre-indiquée": "contre-indiquer",
    "contre-indiquées": "contre-indiquer",
    "contre-indiqués": "contre-indiquer",
    "contre-interrogatoires": "contre-interrogatoire",
    "contre-jours": "contre-jour",
    "contre-lettres": "contre-lettre",
    "contre-manifestante": "contre-manifestant",
    "contre-manifestantes": "contre-manifestant",
    "contre-manifestants": "contre-manifestant",
    "contre-manifestations": "contre-manifestation",
    "contre-manifestent": "contre-manifester",
    "contre-mesures": "contre-mesure",
    "contre-mines": "contre-mine",
    "contre-miné": "contre-miner",
    "contre-offensives": "contre-offensive",
    "contre-ordres": "contre-ordre",
    "contre-passa": "contre-passer",
    "contre-passai": "contre-passer",
    "contre-passaient": "contre-passer",
    "contre-passais": "contre-passer",
    "contre-passait": "contre-passer",
    "contre-passant": "contre-passer",
    "contre-passas": "contre-passer",
    "contre-passasse": "contre-passer",
    "contre-passassent": "contre-passer",
    "contre-passasses": "contre-passer",
    "contre-passassiez": "contre-passer",
    "contre-passassions": "contre-passer",
    "contre-passe": "contre-passer",
    "contre-passent": "contre-passer",
    "contre-passera": "contre-passer",
    "contre-passerai": "contre-passer",
    "contre-passeraient": "contre-passer",
    "contre-passerais": "contre-passer",
    "contre-passerait": "contre-passer",
    "contre-passeras": "contre-passer",
    "contre-passerez": "contre-passer",
    "contre-passeriez": "contre-passer",
    "contre-passerions": "contre-passer",
    "contre-passerons": "contre-passer",
    "contre-passeront": "contre-passer",
    "contre-passes": "contre-passer",
    "contre-passez": "contre-passer",
    "contre-passiez": "contre-passer",
    "contre-passions": "contre-passer",
    "contre-passons": "contre-passer",
    "contre-passâmes": "contre-passer",
    "contre-passât": "contre-passer",
    "contre-passâtes": "contre-passer",
    "contre-passèrent": "contre-passer",
    "contre-passé": "contre-passer",
    "contre-passée": "contre-passer",
    "contre-passées": "contre-passer",
    "contre-passés": "contre-passer",
    "contre-pentes": "contre-pente",
    "contre-performances": "contre-performance",
    "contre-pieds": "contre-pied",
    "contre-plaqués": "contre-plaqué",
    "contre-pouvoirs": "contre-pouvoir",
    "contre-productive": "contre-productif",
    "contre-projets": "contre-projet",
    "contre-propositions": "contre-proposition",
    "contre-rails": "contre-rail",
    "contre-révolutionnaires": "contre-révolutionnaire",
    "contre-révolutions": "contre-révolution",
    "contre-tira": "contre-tirer",
    "contre-tirai": "contre-tirer",
    "contre-tiraient": "contre-tirer",
    "contre-tirais": "contre-tirer",
    "contre-tirait": "contre-tirer",
    "contre-tirant": "contre-tirer",
    "contre-tiras": "contre-tirer",
    "contre-tirasse": "contre-tirer",
    "contre-tirassent": "contre-tirer",
    "contre-tirasses": "contre-tirer",
    "contre-tirassiez": "contre-tirer",
    "contre-tirassions": "contre-tirer",
    "contre-tire": "contre-tirer",
    "contre-tirent": "contre-tirer",
    "contre-tirera": "contre-tirer",
    "contre-tirerai": "contre-tirer",
    "contre-tireraient": "contre-tirer",
    "contre-tirerais": "contre-tirer",
    "contre-tirerait": "contre-tirer",
    "contre-tireras": "contre-tirer",
    "contre-tirerez": "contre-tirer",
    "contre-tireriez": "contre-tirer",
    "contre-tirerions": "contre-tirer",
    "contre-tirerons": "contre-tirer",
    "contre-tireront": "contre-tirer",
    "contre-tires": "contre-tirer",
    "contre-tirez": "contre-tirer",
    "contre-tiriez": "contre-tirer",
    "contre-tirions": "contre-tirer",
    "contre-tirons": "contre-tirer",
    "contre-tirâmes": "contre-tirer",
    "contre-tirât": "contre-tirer",
    "contre-tirâtes": "contre-tirer",
    "contre-tirèrent": "contre-tirer",
    "contre-tiré": "contre-tirer",
    "contre-tirée": "contre-tirer",
    "contre-tirées": "contre-tirer",
    "contre-tirés": "contre-tirer",
    "contre-torpilleurs": "contre-torpilleur",
    "contre-valeurs": "contre-valeur",
    "contre-vapeurs": "contre-vapeur",
    "contre-visites": "contre-visite",
    "contre-voies": "contre-voie",
    "contre-écrous": "contre-écrou",
    "contre-épreuves": "contre-épreuve",
    "contrebalance": "contrebalancer",
    "contrebalancent": "contrebalancer",
    "contrebalancera": "contrebalancer",
    "contrebalancerai": "contrebalancer",
    "contrebalanceraient": "contrebalancer",
    "contrebalancerais": "contrebalancer",
    "contrebalancerait": "contrebalancer",
    "contrebalanceras": "contrebalancer",
    "contrebalancerez": "contrebalancer",
    "contrebalanceriez": "contrebalancer",
    "contrebalancerions": "contrebalancer",
    "contrebalancerons": "contrebalancer",
    "contrebalanceront": "contrebalancer",
    "contrebalances": "contrebalancer",
    "contrebalancez": "contrebalancer",
    "contrebalanciez": "contrebalancer",
    "contrebalancions": "contrebalancer",
    "contrebalancèrent": "contrebalancer",
    "contrebalancé": "contrebalancer",
    "contrebalancée": "contrebalancer",
    "contrebalancées": "contrebalancer",
    "contrebalancés": "contrebalancer",
    "contrebalança": "contrebalancer",
    "contrebalançai": "contrebalancer",
    "contrebalançaient": "contrebalancer",
    "contrebalançais": "contrebalancer",
    "contrebalançait": "contrebalancer",
    "contrebalançant": "contrebalancer",
    "contrebalanças": "contrebalancer",
    "contrebalançasse": "contrebalancer",
    "contrebalançassent": "contrebalancer",
    "contrebalançasses": "contrebalancer",
    "contrebalançassiez": "contrebalancer",
    "contrebalançassions": "contrebalancer",
    "contrebalançons": "contrebalancer",
    "contrebalançâmes": "contrebalancer",
    "contrebalançât": "contrebalancer",
    "contrebalançâtes": "contrebalancer",
    "contrebandes": "contrebande",
    "contrebandiers": "contrebandier",
    "contrebandière": "contrebandier",
    "contrebandières": "contrebandier",
    "contrebasses": "contrebasse",
    "contrebassistes": "contrebassiste",
    "contrebat": "contrebattre",
    "contrebats": "contrebattre",
    "contrebattaient": "contrebattre",
    "contrebattais": "contrebattre",
    "contrebattait": "contrebattre",
    "contrebattant": "contrebattre",
    "contrebatte": "contrebattre",
    "contrebattent": "contrebattre",
    "contrebattes": "contrebattre",
    "contrebattez": "contrebattre",
    "contrebattiez": "contrebattre",
    "contrebattions": "contrebattre",
    "contrebattirent": "contrebattre",
    "contrebattis": "contrebattre",
    "contrebattisse": "contrebattre",
    "contrebattissent": "contrebattre",
    "contrebattisses": "contrebattre",
    "contrebattissiez": "contrebattre",
    "contrebattissions": "contrebattre",
    "contrebattit": "contrebattre",
    "contrebattons": "contrebattre",
    "contrebattra": "contrebattre",
    "contrebattrai": "contrebattre",
    "contrebattraient": "contrebattre",
    "contrebattrais": "contrebattre",
    "contrebattrait": "contrebattre",
    "contrebattras": "contrebattre",
    "contrebattrez": "contrebattre",
    "contrebattriez": "contrebattre",
    "contrebattrions": "contrebattre",
    "contrebattrons": "contrebattre",
    "contrebattront": "contrebattre",
    "contrebattu": "contrebattre",
    "contrebattue": "contrebattre",
    "contrebattues": "contrebattre",
    "contrebattus": "contrebattre",
    "contrebattîmes": "contrebattre",
    "contrebattît": "contrebattre",
    "contrebattîtes": "contrebattre",
    "contrebraque": "contrebraquer",
    "contrebuta": "contrebuter",
    "contrebutai": "contrebuter",
    "contrebutaient": "contrebuter",
    "contrebutais": "contrebuter",
    "contrebutait": "contrebuter",
    "contrebutant": "contrebuter",
    "contrebutas": "contrebuter",
    "contrebutasse": "contrebuter",
    "contrebutassent": "contrebuter",
    "contrebutasses": "contrebuter",
    "contrebutassiez": "contrebuter",
    "contrebutassions": "contrebuter",
    "contrebute": "contrebuter",
    "contrebutent": "contrebuter",
    "contrebutera": "contrebuter",
    "contrebuterai": "contrebuter",
    "contrebuteraient": "contrebuter",
    "contrebuterais": "contrebuter",
    "contrebuterait": "contrebuter",
    "contrebuteras": "contrebuter",
    "contrebuterez": "contrebuter",
    "contrebuteriez": "contrebuter",
    "contrebuterions": "contrebuter",
    "contrebuterons": "contrebuter",
    "contrebuteront": "contrebuter",
    "contrebutes": "contrebuter",
    "contrebutez": "contrebuter",
    "contrebutiez": "contrebuter",
    "contrebutions": "contrebuter",
    "contrebutons": "contrebuter",
    "contrebutâmes": "contrebuter",
    "contrebutât": "contrebuter",
    "contrebutâtes": "contrebuter",
    "contrebutèrent": "contrebuter",
    "contrebuté": "contrebuter",
    "contrebutée": "contrebuter",
    "contrebutées": "contrebuter",
    "contrebutés": "contrebuter",
    "contrecarra": "contrecarrer",
    "contrecarrai": "contrecarrer",
    "contrecarraient": "contrecarrer",
    "contrecarrais": "contrecarrer",
    "contrecarrait": "contrecarrer",
    "contrecarrant": "contrecarrer",
    "contrecarras": "contrecarrer",
    "contrecarrasse": "contrecarrer",
    "contrecarrassent": "contrecarrer",
    "contrecarrasses": "contrecarrer",
    "contrecarrassiez": "contrecarrer",
    "contrecarrassions": "contrecarrer",
    "contrecarre": "contrecarrer",
    "contrecarrent": "contrecarrer",
    "contrecarrera": "contrecarrer",
    "contrecarrerai": "contrecarrer",
    "contrecarreraient": "contrecarrer",
    "contrecarrerais": "contrecarrer",
    "contrecarrerait": "contrecarrer",
    "contrecarreras": "contrecarrer",
    "contrecarrerez": "contrecarrer",
    "contrecarreriez": "contrecarrer",
    "contrecarrerions": "contrecarrer",
    "contrecarrerons": "contrecarrer",
    "contrecarreront": "contrecarrer",
    "contrecarres": "contrecarrer",
    "contrecarrez": "contrecarrer",
    "contrecarriez": "contrecarrer",
    "contrecarrions": "contrecarrer",
    "contrecarrons": "contrecarrer",
    "contrecarrâmes": "contrecarrer",
    "contrecarrât": "contrecarrer",
    "contrecarrâtes": "contrecarrer",
    "contrecarrèrent": "contrecarrer",
    "contrecarré": "contrecarrer",
    "contrecarrée": "contrecarrer",
    "contrecarrées": "contrecarrer",
    "contrecarrés": "contrecarrer",
    "contrechamps": "contrechamp",
    "contrecoups": "contrecoup",
    "contredanses": "contredanse",
    "contredira": "contredire",
    "contredirai": "contredire",
    "contrediraient": "contredire",
    "contredirais": "contredire",
    "contredirait": "contredire",
    "contrediras": "contredire",
    "contredirent": "contredire",
    "contredirez": "contredire",
    "contrediriez": "contredire",
    "contredirions": "contredire",
    "contredirons": "contredire",
    "contrediront": "contredire",
    "contredis": "contredire",
    "contredisaient": "contredire",
    "contredisais": "contredire",
    "contredisait": "contredire",
    "contredisant": "contredire",
    "contredise": "contredire",
    "contredisent": "contredire",
    "contredises": "contredire",
    "contredisez": "contredire",
    "contredisiez": "contredire",
    "contredisions": "contredire",
    "contredisons": "contredire",
    "contredisse": "contredire",
    "contredissent": "contredire",
    "contredisses": "contredire",
    "contredissiez": "contredire",
    "contredissions": "contredire",
    "contredit": "contredire",
    "contredite": "contredire",
    "contredites": "contredire",
    "contredits": "contredit",
    "contredîmes": "contredire",
    "contredît": "contredire",
    "contredîtes": "contredire",
    "contrefacteurs": "contrefacteur",
    "contrefais": "contrefaire",
    "contrefaisaient": "contrefaire",
    "contrefaisais": "contrefaire",
    "contrefaisait": "contrefaire",
    "contrefaisant": "contrefaire",
    "contrefaisiez": "contrefaire",
    "contrefaisions": "contrefaire",
    "contrefaisons": "contrefaire",
    "contrefait": "contrefaire",
    "contrefaite": "contrefait",
    "contrefaites": "contrefaire",
    "contrefaits": "contrefait",
    "contrefasse": "contrefaire",
    "contrefassent": "contrefaire",
    "contrefasses": "contrefaire",
    "contrefassiez": "contrefaire",
    "contrefassions": "contrefaire",
    "contrefaçons": "contrefaçon",
    "contrefera": "contrefaire",
    "contreferai": "contrefaire",
    "contreferaient": "contrefaire",
    "contreferais": "contrefaire",
    "contreferait": "contrefaire",
    "contreferas": "contrefaire",
    "contreferez": "contrefaire",
    "contreferiez": "contrefaire",
    "contreferions": "contrefaire",
    "contreferons": "contrefaire",
    "contreferont": "contrefaire",
    "contrefichais": "contreficher",
    "contrefichait": "contreficher",
    "contrefiche": "contreficher",
    "contrefiches": "contrefiche",
    "contrefirent": "contrefaire",
    "contrefis": "contrefaire",
    "contrefisse": "contrefaire",
    "contrefissent": "contrefaire",
    "contrefisses": "contrefaire",
    "contrefissiez": "contrefaire",
    "contrefissions": "contrefaire",
    "contrefit": "contrefaire",
    "contrefont": "contrefaire",
    "contreforts": "contrefort",
    "contrefous": "contrefoutre",
    "contrefout": "contrefoutre",
    "contrefoutait": "contrefoutre",
    "contrefîmes": "contrefaire",
    "contrefît": "contrefaire",
    "contrefîtes": "contrefaire",
    "contremarches": "contremarche",
    "contremarqua": "contremarquer",
    "contremarquai": "contremarquer",
    "contremarquaient": "contremarquer",
    "contremarquais": "contremarquer",
    "contremarquait": "contremarquer",
    "contremarquant": "contremarquer",
    "contremarquas": "contremarquer",
    "contremarquasse": "contremarquer",
    "contremarquassent": "contremarquer",
    "contremarquasses": "contremarquer",
    "contremarquassiez": "contremarquer",
    "contremarquassions": "contremarquer",
    "contremarque": "contremarquer",
    "contremarquent": "contremarquer",
    "contremarquera": "contremarquer",
    "contremarquerai": "contremarquer",
    "contremarqueraient": "contremarquer",
    "contremarquerais": "contremarquer",
    "contremarquerait": "contremarquer",
    "contremarqueras": "contremarquer",
    "contremarquerez": "contremarquer",
    "contremarqueriez": "contremarquer",
    "contremarquerions": "contremarquer",
    "contremarquerons": "contremarquer",
    "contremarqueront": "contremarquer",
    "contremarques": "contremarquer",
    "contremarquez": "contremarquer",
    "contremarquiez": "contremarquer",
    "contremarquions": "contremarquer",
    "contremarquons": "contremarquer",
    "contremarquâmes": "contremarquer",
    "contremarquât": "contremarquer",
    "contremarquâtes": "contremarquer",
    "contremarquèrent": "contremarquer",
    "contremarqué": "contremarquer",
    "contremarquée": "contremarquer",
    "contremarquées": "contremarquer",
    "contremarqués": "contremarquer",
    "contremaîtres": "contremaître",
    "contremaîtresse": "contremaître",
    "contremaîtresses": "contremaître",
    "contrent": "contrer",
    "contreparties": "contrepartie",
    "contrepartistes": "contrepartiste",
    "contrepieds": "contrepied",
    "contreplaqués": "contreplaqué",
    "contrepoints": "contrepoint",
    "contrepoisons": "contrepoison",
    "contrepèteries": "contrepèterie",
    "contrera": "contrer",
    "contrerai": "contrer",
    "contreraient": "contrer",
    "contrerais": "contrer",
    "contrerait": "contrer",
    "contreras": "contrer",
    "contrerez": "contrer",
    "contreriez": "contrer",
    "contrerions": "contrer",
    "contrerons": "contrer",
    "contreront": "contrer",
    "contres": "contrer",
    "contrescarpes": "contrescarpe",
    "contreseings": "contreseing",
    "contresigna": "contresigner",
    "contresignai": "contresigner",
    "contresignaient": "contresigner",
    "contresignais": "contresigner",
    "contresignait": "contresigner",
    "contresignant": "contresigner",
    "contresignas": "contresigner",
    "contresignasse": "contresigner",
    "contresignassent": "contresigner",
    "contresignasses": "contresigner",
    "contresignassiez": "contresigner",
    "contresignassions": "contresigner",
    "contresigne": "contresigner",
    "contresignent": "contresigner",
    "contresignera": "contresigner",
    "contresignerai": "contresigner",
    "contresigneraient": "contresigner",
    "contresignerais": "contresigner",
    "contresignerait": "contresigner",
    "contresigneras": "contresigner",
    "contresignerez": "contresigner",
    "contresigneriez": "contresigner",
    "contresignerions": "contresigner",
    "contresignerons": "contresigner",
    "contresigneront": "contresigner",
    "contresignes": "contresigner",
    "contresignez": "contresigner",
    "contresigniez": "contresigner",
    "contresignions": "contresigner",
    "contresignons": "contresigner",
    "contresignâmes": "contresigner",
    "contresignât": "contresigner",
    "contresignâtes": "contresigner",
    "contresignèrent": "contresigner",
    "contresigné": "contresigner",
    "contresignée": "contresigner",
    "contresignées": "contresigner",
    "contresignés": "contresigner",
    "contretypes": "contretype",
    "contretypés": "contretyper",
    "contrevenaient": "contrevenir",
    "contrevenais": "contrevenir",
    "contrevenait": "contrevenir",
    "contrevenant": "contrevenir",
    "contrevenante": "contrevenant",
    "contrevenantes": "contrevenant",
    "contrevenants": "contrevenant",
    "contrevenez": "contrevenir",
    "contreveniez": "contrevenir",
    "contrevenions": "contrevenir",
    "contrevenons": "contrevenir",
    "contrevents": "contrevent",
    "contrevenu": "contrevenir",
    "contreviendra": "contrevenir",
    "contreviendrai": "contrevenir",
    "contreviendraient": "contrevenir",
    "contreviendrais": "contrevenir",
    "contreviendrait": "contrevenir",
    "contreviendras": "contrevenir",
    "contreviendrez": "contrevenir",
    "contreviendriez": "contrevenir",
    "contreviendrions": "contrevenir",
    "contreviendrons": "contrevenir",
    "contreviendront": "contrevenir",
    "contrevienne": "contrevenir",
    "contreviennent": "contrevenir",
    "contreviennes": "contrevenir",
    "contreviens": "contrevenir",
    "contrevient": "contrevenir",
    "contrevinrent": "contrevenir",
    "contrevins": "contrevenir",
    "contrevinsse": "contrevenir",
    "contrevinssent": "contrevenir",
    "contrevinsses": "contrevenir",
    "contrevinssiez": "contrevenir",
    "contrevinssions": "contrevenir",
    "contrevint": "contrevenir",
    "contrevérités": "contrevérité",
    "contrevînmes": "contrevenir",
    "contrevînt": "contrevenir",
    "contrevîntes": "contrevenir",
    "contrez": "contrer",
    "contribua": "contribuer",
    "contribuables": "contribuable",
    "contribuai": "contribuer",
    "contribuaient": "contribuer",
    "contribuais": "contribuer",
    "contribuait": "contribuer",
    "contribuant": "contribuer",
    "contribuas": "contribuer",
    "contribuasse": "contribuer",
    "contribuassent": "contribuer",
    "contribuasses": "contribuer",
    "contribuassiez": "contribuer",
    "contribuassions": "contribuer",
    "contribue": "contribuer",
    "contribuent": "contribuer",
    "contribuera": "contribuer",
    "contribuerai": "contribuer",
    "contribueraient": "contribuer",
    "contribuerais": "contribuer",
    "contribuerait": "contribuer",
    "contribueras": "contribuer",
    "contribuerez": "contribuer",
    "contribueriez": "contribuer",
    "contribuerions": "contribuer",
    "contribuerons": "contribuer",
    "contribueront": "contribuer",
    "contribues": "contribuer",
    "contribuez": "contribuer",
    "contribuiez": "contribuer",
    "contribuions": "contribuer",
    "contribuons": "contribuer",
    "contributeurs": "contributeur",
    "contributions": "contribution",
    "contributrice": "contributeur",
    "contributrices": "contributeur",
    "contribuâmes": "contribuer",
    "contribuât": "contribuer",
    "contribuâtes": "contribuer",
    "contribuèrent": "contribuer",
    "contribué": "contribuer",
    "contriez": "contrer",
    "contrions": "contrer",
    "contrista": "contrister",
    "contristant": "contrister",
    "contristées": "contrister",
    "contrite": "contrit",
    "contrites": "contrit",
    "contritions": "contrition",
    "contrits": "contrit",
    "controns": "contrer",
    "contrordres": "contrordre",
    "controuva": "controuver",
    "controuvai": "controuver",
    "controuvaient": "controuver",
    "controuvais": "controuver",
    "controuvait": "controuver",
    "controuvant": "controuver",
    "controuvas": "controuver",
    "controuvasse": "controuver",
    "controuvassent": "controuver",
    "controuvasses": "controuver",
    "controuvassiez": "controuver",
    "controuvassions": "controuver",
    "controuve": "controuver",
    "controuvent": "controuver",
    "controuvera": "controuver",
    "controuverai": "controuver",
    "controuveraient": "controuver",
    "controuverais": "controuver",
    "controuverait": "controuver",
    "controuveras": "controuver",
    "controuverez": "controuver",
    "controuveriez": "controuver",
    "controuverions": "controuver",
    "controuverons": "controuver",
    "controuveront": "controuver",
    "controuves": "controuver",
    "controuvez": "controuver",
    "controuviez": "controuver",
    "controuvions": "controuver",
    "controuvons": "controuver",
    "controuvâmes": "controuver",
    "controuvât": "controuver",
    "controuvâtes": "controuver",
    "controuvèrent": "controuver",
    "controuvé": "controuver",
    "controuvée": "controuver",
    "controuvées": "controuver",
    "controuvés": "controuver",
    "controverses": "controverse",
    "controversé": "controverser",
    "controversée": "controverser",
    "controversées": "controverser",
    "controversés": "controverser",
    "contrâmes": "contrer",
    "contrât": "contrer",
    "contrâtes": "contrer",
    "contrèrent": "contrer",
    "contré": "contrer",
    "contrée": "contrer",
    "contrées": "contrer",
    "contrés": "contrer",
    "contrôla": "contrôler",
    "contrôlables": "contrôlable",
    "contrôlai": "contrôler",
    "contrôlaient": "contrôler",
    "contrôlais": "contrôler",
    "contrôlait": "contrôler",
    "contrôlant": "contrôler",
    "contrôlas": "contrôler",
    "contrôlasse": "contrôler",
    "contrôlassent": "contrôler",
    "contrôlasses": "contrôler",
    "contrôlassiez": "contrôler",
    "contrôlassions": "contrôler",
    "contrôle": "contrôler",
    "contrôlent": "contrôler",
    "contrôler": "chuter",
    "contrôlera": "contrôler",
    "contrôlerai": "contrôler",
    "contrôleraient": "contrôler",
    "contrôlerais": "contrôler",
    "contrôlerait": "contrôler",
    "contrôleras": "contrôler",
    "contrôlerez": "contrôler",
    "contrôleriez": "contrôler",
    "contrôlerions": "contrôler",
    "contrôlerons": "contrôler",
    "contrôleront": "contrôler",
    "contrôles": "contrôler",
    "contrôleurs": "contrôleur",
    "contrôleuse": "contrôleur",
    "contrôleuses": "contrôleur",
    "contrôlez": "contrôler",
    "contrôliez": "contrôler",
    "contrôlions": "contrôler",
    "contrôlons": "contrôler",
    "contrôlâmes": "contrôler",
    "contrôlât": "contrôler",
    "contrôlâtes": "contrôler",
    "contrôlèrent": "contrôler",
    "contrôlé": "contrôler",
    "contrôlée": "contrôler",
    "contrôlées": "contrôler",
    "contrôlés": "contrôler",
    "contumaces": "contumace",
    "contuse": "contus",
    "contusionna": "contusionner",
    "contusionnai": "contusionner",
    "contusionnaient": "contusionner",
    "contusionnais": "contusionner",
    "contusionnait": "contusionner",
    "contusionnant": "contusionner",
    "contusionnas": "contusionner",
    "contusionnasse": "contusionner",
    "contusionnassent": "contusionner",
    "contusionnasses": "contusionner",
    "contusionnassiez": "contusionner",
    "contusionnassions": "contusionner",
    "contusionne": "contusionner",
    "contusionnent": "contusionner",
    "contusionnera": "contusionner",
    "contusionnerai": "contusionner",
    "contusionneraient": "contusionner",
    "contusionnerais": "contusionner",
    "contusionnerait": "contusionner",
    "contusionneras": "contusionner",
    "contusionnerez": "contusionner",
    "contusionneriez": "contusionner",
    "contusionnerions": "contusionner",
    "contusionnerons": "contusionner",
    "contusionneront": "contusionner",
    "contusionnes": "contusionner",
    "contusionnez": "contusionner",
    "contusionniez": "contusionner",
    "contusionnions": "contusionner",
    "contusionnons": "contusionner",
    "contusionnâmes": "contusionner",
    "contusionnât": "contusionner",
    "contusionnâtes": "contusionner",
    "contusionnèrent": "contusionner",
    "contusionné": "contusionner",
    "contusionnée": "contusionner",
    "contusionnées": "contusionner",
    "contusionnés": "contusionner",
    "contusions": "contusion",
    "contâmes": "conter",
    "contât": "conter",
    "contâtes": "conter",
    "contèrent": "conter",
    "conté": "conter",
    "contée": "conter",
    "contées": "conter",
    "contés": "conter",
    "contînmes": "contenir",
    "contînt": "contenir",
    "contîntes": "contenir",
    "convainc": "convaincre",
    "convaincante": "convaincant",
    "convaincantes": "convaincant",
    "convaincants": "convaincant",
    "convaincra": "convaincre",
    "convaincrai": "convaincre",
    "convaincraient": "convaincre",
    "convaincrais": "convaincre",
    "convaincrait": "convaincre",
    "convaincras": "convaincre",
    "convaincrez": "convaincre",
    "convaincriez": "convaincre",
    "convaincrions": "convaincre",
    "convaincrons": "convaincre",
    "convaincront": "convaincre",
    "convaincs": "convaincre",
    "convaincu": "convaincre",
    "convaincue": "convaincu",
    "convaincues": "convaincu",
    "convaincus": "convaincu",
    "convainquaient": "convaincre",
    "convainquais": "convaincre",
    "convainquait": "convaincre",
    "convainquant": "convaincre",
    "convainque": "convaincre",
    "convainquent": "convaincre",
    "convainques": "convaincre",
    "convainquez": "convaincre",
    "convainquiez": "convaincre",
    "convainquions": "convaincre",
    "convainquirent": "convaincre",
    "convainquis": "convaincre",
    "convainquisse": "convaincre",
    "convainquissent": "convaincre",
    "convainquisses": "convaincre",
    "convainquissiez": "convaincre",
    "convainquissions": "convaincre",
    "convainquit": "convaincre",
    "convainquons": "convaincre",
    "convainquîmes": "convaincre",
    "convainquît": "convaincre",
    "convainquîtes": "convaincre",
    "convalescences": "convalescence",
    "convalescente": "convalescent",
    "convalescentes": "convalescent",
    "convalescents": "convalescent",
    "convalos": "convalo",
    "convections": "convection",
    "convenables": "convenable",
    "convenaient": "convenir",
    "convenais": "convenir",
    "convenait": "convenir",
    "convenances": "convenance",
    "convenant": "convenir",
    "convenez": "convenir",
    "conveniez": "convenir",
    "convenions": "convenir",
    "convenons": "convenir",
    "conventionna": "conventionner",
    "conventionnai": "conventionner",
    "conventionnaient": "conventionner",
    "conventionnais": "conventionner",
    "conventionnait": "conventionner",
    "conventionnant": "conventionner",
    "conventionnas": "conventionner",
    "conventionnasse": "conventionner",
    "conventionnassent": "conventionner",
    "conventionnasses": "conventionner",
    "conventionnassiez": "conventionner",
    "conventionnassions": "conventionner",
    "conventionne": "conventionner",
    "conventionnelle": "conventionnel",
    "conventionnelles": "conventionnel",
    "conventionnels": "conventionnel",
    "conventionnent": "conventionner",
    "conventionnera": "conventionner",
    "conventionnerai": "conventionner",
    "conventionneraient": "conventionner",
    "conventionnerais": "conventionner",
    "conventionnerait": "conventionner",
    "conventionneras": "conventionner",
    "conventionnerez": "conventionner",
    "conventionneriez": "conventionner",
    "conventionnerions": "conventionner",
    "conventionnerons": "conventionner",
    "conventionneront": "conventionner",
    "conventionnes": "conventionner",
    "conventionnez": "conventionner",
    "conventionniez": "conventionner",
    "conventionnions": "conventionner",
    "conventionnons": "conventionner",
    "conventionnâmes": "conventionner",
    "conventionnât": "conventionner",
    "conventionnâtes": "conventionner",
    "conventionnèrent": "conventionner",
    "conventionné": "conventionner",
    "conventionnée": "conventionner",
    "conventionnées": "conventionner",
    "conventionnés": "conventionner",
    "conventions": "convention",
    "convents": "convent",
    "conventuelle": "conventuel",
    "conventuelles": "conventuel",
    "conventuels": "conventuel",
    "convenu": "convenir",
    "convenue": "convenu",
    "convenues": "convenu",
    "convenus": "convenu",
    "converge": "converger",
    "convergea": "converger",
    "convergeai": "converger",
    "convergeaient": "converger",
    "convergeais": "converger",
    "convergeait": "converger",
    "convergeant": "converger",
    "convergeas": "converger",
    "convergeasse": "converger",
    "convergeassent": "converger",
    "convergeasses": "converger",
    "convergeassiez": "converger",
    "convergeassions": "converger",
    "convergences": "convergence",
    "convergent": "converger",
    "convergente": "convergent",
    "convergentes": "convergent",
    "convergents": "convergent",
    "convergeons": "converger",
    "convergera": "converger",
    "convergerai": "converger",
    "convergeraient": "converger",
    "convergerais": "converger",
    "convergerait": "converger",
    "convergeras": "converger",
    "convergerez": "converger",
    "convergeriez": "converger",
    "convergerions": "converger",
    "convergerons": "converger",
    "convergeront": "converger",
    "converges": "converger",
    "convergez": "converger",
    "convergeâmes": "converger",
    "convergeât": "converger",
    "convergeâtes": "converger",
    "convergiez": "converger",
    "convergions": "converger",
    "convergèrent": "converger",
    "convergé": "converger",
    "conversa": "converser",
    "conversai": "converser",
    "conversaient": "converser",
    "conversais": "converser",
    "conversait": "converser",
    "conversant": "converser",
    "conversas": "converser",
    "conversasse": "converser",
    "conversassent": "converser",
    "conversasses": "converser",
    "conversassiez": "converser",
    "conversassions": "converser",
    "conversations": "conversation",
    "converse": "converser",
    "conversent": "converser",
    "conversera": "converser",
    "converserai": "converser",
    "converseraient": "converser",
    "converserais": "converser",
    "converserait": "converser",
    "converseras": "converser",
    "converserez": "converser",
    "converseriez": "converser",
    "converserions": "converser",
    "converserons": "converser",
    "converseront": "converser",
    "converses": "converser",
    "conversez": "converser",
    "conversiez": "converser",
    "conversions": "conversion",
    "conversons": "converser",
    "conversâmes": "converser",
    "conversât": "converser",
    "conversâtes": "converser",
    "conversèrent": "converser",
    "conversé": "converser",
    "converti": "convertir",
    "convertibilités": "convertibilité",
    "convertibles": "convertible",
    "convertie": "convertir",
    "converties": "convertir",
    "convertira": "convertir",
    "convertirai": "convertir",
    "convertiraient": "convertir",
    "convertirais": "convertir",
    "convertirait": "convertir",
    "convertiras": "convertir",
    "convertirent": "convertir",
    "convertirez": "convertir",
    "convertiriez": "convertir",
    "convertirions": "convertir",
    "convertirons": "convertir",
    "convertiront": "convertir",
    "convertis": "convertir",
    "convertissaient": "convertir",
    "convertissais": "convertir",
    "convertissait": "convertir",
    "convertissant": "convertir",
    "convertisse": "convertir",
    "convertissent": "convertir",
    "convertisses": "convertir",
    "convertisseurs": "convertisseur",
    "convertissez": "convertir",
    "convertissiez": "convertir",
    "convertissions": "convertir",
    "convertissons": "convertir",
    "convertit": "convertir",
    "convertîmes": "convertir",
    "convertît": "convertir",
    "convertîtes": "convertir",
    "convexes": "convexe",
    "convia": "convier",
    "conviai": "convier",
    "conviaient": "convier",
    "conviais": "convier",
    "conviait": "convier",
    "conviant": "convier",
    "convias": "convier",
    "conviasse": "convier",
    "conviassent": "convier",
    "conviasses": "convier",
    "conviassiez": "convier",
    "conviassions": "convier",
    "convictions": "conviction",
    "convicts": "convict",
    "convie": "convier",
    "conviendra": "convenir",
    "conviendrai": "convenir",
    "conviendraient": "convenir",
    "conviendrais": "convenir",
    "conviendrait": "convenir",
    "conviendras": "convenir",
    "conviendrez": "convenir",
    "conviendriez": "convenir",
    "conviendrions": "convenir",
    "conviendrons": "convenir",
    "conviendront": "convenir",
    "convienne": "convenir",
    "conviennent": "convenir",
    "conviennes": "convenir",
    "conviens": "convenir",
    "convient": "convier",
    "conviera": "convier",
    "convierai": "convier",
    "convieraient": "convier",
    "convierais": "convier",
    "convierait": "convier",
    "convieras": "convier",
    "convierez": "convier",
    "convieriez": "convier",
    "convierions": "convier",
    "convierons": "convier",
    "convieront": "convier",
    "convies": "convier",
    "conviez": "convier",
    "conviiez": "convier",
    "conviions": "convier",
    "convinrent": "convenir",
    "convins": "convenir",
    "convinsse": "convenir",
    "convinssent": "convenir",
    "convinsses": "convenir",
    "convinssiez": "convenir",
    "convinssions": "convenir",
    "convint": "convenir",
    "convions": "convier",
    "convives": "convive",
    "conviviale": "convivial",
    "conviviales": "convivial",
    "convivialisez": "convivialiser",
    "convivialités": "convivialité",
    "conviviaux": "convivial",
    "conviâmes": "convier",
    "conviât": "convier",
    "conviâtes": "convier",
    "convièrent": "convier",
    "convié": "convier",
    "conviée": "convier",
    "conviées": "convier",
    "conviés": "convier",
    "convocations": "convocation",
    "convoie": "convoyer",
    "convoient": "convoyer",
    "convoiera": "convoyer",
    "convoierai": "convoyer",
    "convoieraient": "convoyer",
    "convoierais": "convoyer",
    "convoierait": "convoyer",
    "convoieras": "convoyer",
    "convoierez": "convoyer",
    "convoieriez": "convoyer",
    "convoierions": "convoyer",
    "convoierons": "convoyer",
    "convoieront": "convoyer",
    "convoies": "convoyer",
    "convois": "convoi",
    "convoita": "convoiter",
    "convoitai": "convoiter",
    "convoitaient": "convoiter",
    "convoitais": "convoiter",
    "convoitait": "convoiter",
    "convoitant": "convoiter",
    "convoitas": "convoiter",
    "convoitasse": "convoiter",
    "convoitassent": "convoiter",
    "convoitasses": "convoiter",
    "convoitassiez": "convoiter",
    "convoitassions": "convoiter",
    "convoite": "convoiter",
    "convoitent": "convoiter",
    "convoitera": "convoiter",
    "convoiterai": "convoiter",
    "convoiteraient": "convoiter",
    "convoiterais": "convoiter",
    "convoiterait": "convoiter",
    "convoiteras": "convoiter",
    "convoiterez": "convoiter",
    "convoiteriez": "convoiter",
    "convoiterions": "convoiter",
    "convoiterons": "convoiter",
    "convoiteront": "convoiter",
    "convoites": "convoiter",
    "convoitez": "convoiter",
    "convoitiez": "convoiter",
    "convoitions": "convoiter",
    "convoitises": "convoitise",
    "convoitons": "convoiter",
    "convoitâmes": "convoiter",
    "convoitât": "convoiter",
    "convoitâtes": "convoiter",
    "convoitèrent": "convoiter",
    "convoité": "convoiter",
    "convoitée": "convoiter",
    "convoitées": "convoiter",
    "convoités": "convoiter",
    "convola": "convoler",
    "convolai": "convoler",
    "convolaient": "convoler",
    "convolais": "convoler",
    "convolait": "convoler",
    "convolant": "convoler",
    "convolas": "convoler",
    "convolasse": "convoler",
    "convolassent": "convoler",
    "convolasses": "convoler",
    "convolassiez": "convoler",
    "convolassions": "convoler",
    "convole": "convoler",
    "convolent": "convoler",
    "convolera": "convoler",
    "convolerai": "convoler",
    "convoleraient": "convoler",
    "convolerais": "convoler",
    "convolerait": "convoler",
    "convoleras": "convoler",
    "convolerez": "convoler",
    "convoleriez": "convoler",
    "convolerions": "convoler",
    "convolerons": "convoler",
    "convoleront": "convoler",
    "convoles": "convoler",
    "convolez": "convoler",
    "convoliez": "convoler",
    "convolions": "convoler",
    "convolons": "convoler",
    "convolâmes": "convoler",
    "convolât": "convoler",
    "convolâtes": "convoler",
    "convolèrent": "convoler",
    "convolé": "convoler",
    "convoqua": "convoquer",
    "convoquai": "convoquer",
    "convoquaient": "convoquer",
    "convoquais": "convoquer",
    "convoquait": "convoquer",
    "convoquant": "convoquer",
    "convoquas": "convoquer",
    "convoquasse": "convoquer",
    "convoquassent": "convoquer",
    "convoquasses": "convoquer",
    "convoquassiez": "convoquer",
    "convoquassions": "convoquer",
    "convoque": "convoquer",
    "convoquent": "convoquer",
    "convoquera": "convoquer",
    "convoquerai": "convoquer",
    "convoqueraient": "convoquer",
    "convoquerais": "convoquer",
    "convoquerait": "convoquer",
    "convoqueras": "convoquer",
    "convoquerez": "convoquer",
    "convoqueriez": "convoquer",
    "convoquerions": "convoquer",
    "convoquerons": "convoquer",
    "convoqueront": "convoquer",
    "convoques": "convoquer",
    "convoquez": "convoquer",
    "convoquiez": "convoquer",
    "convoquions": "convoquer",
    "convoquons": "convoquer",
    "convoquâmes": "convoquer",
    "convoquât": "convoquer",
    "convoquâtes": "convoquer",
    "convoquèrent": "convoquer",
    "convoqué": "convoquer",
    "convoquée": "convoquer",
    "convoquées": "convoquer",
    "convoqués": "convoquer",
    "convoya": "convoyer",
    "convoyages": "convoyage",
    "convoyai": "convoyer",
    "convoyaient": "convoyer",
    "convoyais": "convoyer",
    "convoyait": "convoyer",
    "convoyant": "convoyer",
    "convoyas": "convoyer",
    "convoyasse": "convoyer",
    "convoyassent": "convoyer",
    "convoyasses": "convoyer",
    "convoyassiez": "convoyer",
    "convoyassions": "convoyer",
    "convoyeurs": "convoyeur",
    "convoyeuse": "convoyeur",
    "convoyez": "convoyer",
    "convoyiez": "convoyer",
    "convoyions": "convoyer",
    "convoyons": "convoyer",
    "convoyâmes": "convoyer",
    "convoyât": "convoyer",
    "convoyâtes": "convoyer",
    "convoyèrent": "convoyer",
    "convoyé": "convoyer",
    "convoyée": "convoyer",
    "convoyées": "convoyer",
    "convoyés": "convoyer",
    "convulsa": "convulser",
    "convulsai": "convulser",
    "convulsaient": "convulser",
    "convulsais": "convulser",
    "convulsait": "convulser",
    "convulsant": "convulser",
    "convulsas": "convulser",
    "convulsasse": "convulser",
    "convulsassent": "convulser",
    "convulsasses": "convulser",
    "convulsassiez": "convulser",
    "convulsassions": "convulser",
    "convulse": "convulser",
    "convulsent": "convulser",
    "convulsera": "convulser",
    "convulserai": "convulser",
    "convulseraient": "convulser",
    "convulserais": "convulser",
    "convulserait": "convulser",
    "convulseras": "convulser",
    "convulserez": "convulser",
    "convulseriez": "convulser",
    "convulserions": "convulser",
    "convulserons": "convulser",
    "convulseront": "convulser",
    "convulses": "convulser",
    "convulsez": "convulser",
    "convulsiez": "convulser",
    "convulsifs": "convulsif",
    "convulsionne": "convulsionner",
    "convulsionnée": "convulsionner",
    "convulsions": "convulsion",
    "convulsive": "convulsif",
    "convulsives": "convulsif",
    "convulsons": "convulser",
    "convulsâmes": "convulser",
    "convulsât": "convulser",
    "convulsâtes": "convulser",
    "convulsèrent": "convulser",
    "convulsé": "convulser",
    "convulsée": "convulser",
    "convulsées": "convulser",
    "convulsés": "convulser",
    "convînmes": "convenir",
    "convînt": "convenir",
    "convîntes": "convenir",
    "conçois": "concevoir",
    "conçoit": "concevoir",
    "conçoive": "concevoir",
    "conçoivent": "concevoir",
    "conçoives": "concevoir",
    "conçu": "concevoir",
    "conçue": "conçu",
    "conçues": "conçu",
    "conçurent": "concevoir",
    "conçus": "conçu",
    "conçusse": "concevoir",
    "conçussent": "concevoir",
    "conçusses": "concevoir",
    "conçussiez": "concevoir",
    "conçussions": "concevoir",
    "conçut": "concevoir",
    "conçûmes": "concevoir",
    "conçût": "concevoir",
    "conçûtes": "concevoir",
    "cookies": "cookie",
    "coolies": "coolie",
    "cooptant": "coopter",
    "coopté": "coopter",
    "coopère": "coopérer",
    "coopèrent": "coopérer",
    "coopères": "coopérer",
    "coopéra": "coopérer",
    "coopérai": "coopérer",
    "coopéraient": "coopérer",
    "coopérais": "coopérer",
    "coopérait": "coopérer",
    "coopérant": "coopérer",
    "coopérante": "coopérant",
    "coopérantes": "coopérant",
    "coopérants": "coopérant",
    "coopéras": "coopérer",
    "coopérasse": "coopérer",
    "coopérassent": "coopérer",
    "coopérasses": "coopérer",
    "coopérassiez": "coopérer",
    "coopérassions": "coopérer",
    "coopérateurs": "coopérateur",
    "coopératifs": "coopératif",
    "coopérations": "coopération",
    "coopératismes": "coopératisme",
    "coopérative": "coopératif",
    "coopératives": "coopérative",
    "coopératrice": "coopérateur",
    "coopératrices": "coopérateur",
    "coopérera": "coopérer",
    "coopérerai": "coopérer",
    "coopéreraient": "coopérer",
    "coopérerais": "coopérer",
    "coopérerait": "coopérer",
    "coopéreras": "coopérer",
    "coopérerez": "coopérer",
    "coopéreriez": "coopérer",
    "coopérerions": "coopérer",
    "coopérerons": "coopérer",
    "coopéreront": "coopérer",
    "coopérez": "coopérer",
    "coopériez": "coopérer",
    "coopérions": "coopérer",
    "coopérons": "coopérer",
    "coopérâmes": "coopérer",
    "coopérât": "coopérer",
    "coopérâtes": "coopérer",
    "coopérèrent": "coopérer",
    "coopéré": "coopérer",
    "coordinateurs": "coordinateur",
    "coordinations": "coordination",
    "coordinatrice": "coordinateur",
    "coordinatrices": "coordinateur",
    "coordonna": "coordonner",
    "coordonnai": "coordonner",
    "coordonnaient": "coordonner",
    "coordonnais": "coordonner",
    "coordonnait": "coordonner",
    "coordonnant": "coordonner",
    "coordonnas": "coordonner",
    "coordonnasse": "coordonner",
    "coordonnassent": "coordonner",
    "coordonnasses": "coordonner",
    "coordonnassiez": "coordonner",
    "coordonnassions": "coordonner",
    "coordonnateurs": "coordonnateur",
    "coordonnatrice": "coordonnateur",
    "coordonnatrices": "coordonnateur",
    "coordonne": "coordonner",
    "coordonnent": "coordonner",
    "coordonnera": "coordonner",
    "coordonnerai": "coordonner",
    "coordonneraient": "coordonner",
    "coordonnerais": "coordonner",
    "coordonnerait": "coordonner",
    "coordonneras": "coordonner",
    "coordonnerez": "coordonner",
    "coordonneriez": "coordonner",
    "coordonnerions": "coordonner",
    "coordonnerons": "coordonner",
    "coordonneront": "coordonner",
    "coordonnes": "coordonner",
    "coordonnez": "coordonner",
    "coordonniez": "coordonner",
    "coordonnions": "coordonner",
    "coordonnons": "coordonner",
    "coordonnâmes": "coordonner",
    "coordonnât": "coordonner",
    "coordonnâtes": "coordonner",
    "coordonnèrent": "coordonner",
    "coordonné": "coordonner",
    "coordonnée": "coordonner",
    "coordonnées": "coordonner",
    "coordonnés": "coordonner",
    "coorganisateurs": "coorganisateur",
    "coorganisatrice": "coorganisateur",
    "coorganisatrices": "coorganisateur",
    "copains": "copain",
    "copals": "copal",
    "coparrainée": "coparrainé",
    "coparrainées": "coparrainé",
    "coparrainés": "coparrainé",
    "copartage": "copartager",
    "copartagea": "copartager",
    "copartageai": "copartager",
    "copartageaient": "copartager",
    "copartageais": "copartager",
    "copartageait": "copartager",
    "copartageant": "copartager",
    "copartageas": "copartager",
    "copartageasse": "copartager",
    "copartageassent": "copartager",
    "copartageasses": "copartager",
    "copartageassiez": "copartager",
    "copartageassions": "copartager",
    "copartagent": "copartager",
    "copartageons": "copartager",
    "copartagera": "copartager",
    "copartagerai": "copartager",
    "copartageraient": "copartager",
    "copartagerais": "copartager",
    "copartagerait": "copartager",
    "copartageras": "copartager",
    "copartagerez": "copartager",
    "copartageriez": "copartager",
    "copartagerions": "copartager",
    "copartagerons": "copartager",
    "copartageront": "copartager",
    "copartages": "copartager",
    "copartagez": "copartager",
    "copartageâmes": "copartager",
    "copartageât": "copartager",
    "copartageâtes": "copartager",
    "copartagiez": "copartager",
    "copartagions": "copartager",
    "copartagèrent": "copartager",
    "copartagé": "copartager",
    "copartagée": "copartager",
    "copartagées": "copartager",
    "copartagés": "copartager",
    "copeaux": "copeau",
    "copernicienne": "copernicien",
    "copia": "copier",
    "copiai": "copier",
    "copiaient": "copier",
    "copiais": "copier",
    "copiait": "copier",
    "copiant": "copier",
    "copias": "copier",
    "copiasse": "copier",
    "copiassent": "copier",
    "copiasses": "copier",
    "copiassiez": "copier",
    "copiassions": "copier",
    "copie": "copier",
    "copient": "copier",
    "copiera": "copier",
    "copierai": "copier",
    "copieraient": "copier",
    "copierais": "copier",
    "copierait": "copier",
    "copieras": "copier",
    "copierez": "copier",
    "copieriez": "copier",
    "copierions": "copier",
    "copierons": "copier",
    "copieront": "copier",
    "copies": "copier",
    "copieurs": "copieur",
    "copieuse": "copieux",
    "copieuses": "copieux",
    "copiez": "copier",
    "copiiez": "copier",
    "copiions": "copier",
    "copilotes": "copilote",
    "copinait": "copiner",
    "copine": "copain",
    "copines": "copain",
    "copineurs": "copineur",
    "copineuse": "copineur",
    "copiniez": "copiner",
    "copiné": "copiner",
    "copions": "copier",
    "copistes": "copiste",
    "copiâmes": "copier",
    "copiât": "copier",
    "copiâtes": "copier",
    "copièrent": "copier",
    "copié": "copier",
    "copiée": "copier",
    "copiées": "copier",
    "copiés": "copier",
    "copossède": "coposséder",
    "copossèdent": "coposséder",
    "copossèdes": "coposséder",
    "coposséda": "coposséder",
    "copossédai": "coposséder",
    "copossédaient": "coposséder",
    "copossédais": "coposséder",
    "copossédait": "coposséder",
    "copossédant": "coposséder",
    "copossédas": "coposséder",
    "copossédasse": "coposséder",
    "copossédassent": "coposséder",
    "copossédasses": "coposséder",
    "copossédassiez": "coposséder",
    "copossédassions": "coposséder",
    "copossédera": "coposséder",
    "coposséderai": "coposséder",
    "coposséderaient": "coposséder",
    "coposséderais": "coposséder",
    "coposséderait": "coposséder",
    "coposséderas": "coposséder",
    "coposséderez": "coposséder",
    "coposséderiez": "coposséder",
    "coposséderions": "coposséder",
    "coposséderons": "coposséder",
    "coposséderont": "coposséder",
    "copossédez": "coposséder",
    "copossédiez": "coposséder",
    "copossédions": "coposséder",
    "copossédons": "coposséder",
    "copossédâmes": "coposséder",
    "copossédât": "coposséder",
    "copossédâtes": "coposséder",
    "copossédèrent": "coposséder",
    "copossédé": "coposséder",
    "copossédée": "coposséder",
    "copossédées": "coposséder",
    "copossédés": "coposséder",
    "coprahs": "coprah",
    "copras": "copra",
    "coprins": "coprin",
    "coproducteurs": "coproducteur",
    "coproductions": "coproduction",
    "coproductrice": "coproducteur",
    "coproductrices": "coproducteur",
    "coproduira": "coproduire",
    "coproduirai": "coproduire",
    "coproduiraient": "coproduire",
    "coproduirais": "coproduire",
    "coproduirait": "coproduire",
    "coproduiras": "coproduire",
    "coproduirez": "coproduire",
    "coproduiriez": "coproduire",
    "coproduirions": "coproduire",
    "coproduirons": "coproduire",
    "coproduiront": "coproduire",
    "coproduis": "coproduire",
    "coproduisaient": "coproduire",
    "coproduisais": "coproduire",
    "coproduisait": "coproduire",
    "coproduisant": "coproduire",
    "coproduise": "coproduire",
    "coproduisent": "coproduire",
    "coproduises": "coproduire",
    "coproduisez": "coproduire",
    "coproduisiez": "coproduire",
    "coproduisions": "coproduire",
    "coproduisirent": "coproduire",
    "coproduisis": "coproduire",
    "coproduisisse": "coproduire",
    "coproduisissent": "coproduire",
    "coproduisisses": "coproduire",
    "coproduisissiez": "coproduire",
    "coproduisissions": "coproduire",
    "coproduisit": "coproduire",
    "coproduisons": "coproduire",
    "coproduisîmes": "coproduire",
    "coproduisît": "coproduire",
    "coproduisîtes": "coproduire",
    "coproduit": "coproduire",
    "coproduite": "coproduire",
    "coproduites": "coproduire",
    "coproduits": "coproduire",
    "coprophages": "coprophage",
    "copropriétaires": "copropriétaire",
    "copropriétés": "copropriété",
    "coprésida": "coprésider",
    "coprésidai": "coprésider",
    "coprésidaient": "coprésider",
    "coprésidais": "coprésider",
    "coprésidait": "coprésider",
    "coprésidant": "coprésider",
    "coprésidas": "coprésider",
    "coprésidasse": "coprésider",
    "coprésidassent": "coprésider",
    "coprésidasses": "coprésider",
    "coprésidassiez": "coprésider",
    "coprésidassions": "coprésider",
    "copréside": "coprésider",
    "coprésident": "coprésider",
    "coprésidente": "coprésident",
    "coprésidentes": "coprésident",
    "coprésidents": "coprésident",
    "coprésidera": "coprésider",
    "coprésiderai": "coprésider",
    "coprésideraient": "coprésider",
    "coprésiderais": "coprésider",
    "coprésiderait": "coprésider",
    "coprésideras": "coprésider",
    "coprésiderez": "coprésider",
    "coprésideriez": "coprésider",
    "coprésiderions": "coprésider",
    "coprésiderons": "coprésider",
    "coprésideront": "coprésider",
    "coprésides": "coprésider",
    "coprésidez": "coprésider",
    "coprésidiez": "coprésider",
    "coprésidions": "coprésider",
    "coprésidons": "coprésider",
    "coprésidâmes": "coprésider",
    "coprésidât": "coprésider",
    "coprésidâtes": "coprésider",
    "coprésidèrent": "coprésider",
    "coprésidé": "coprésider",
    "coprésidée": "coprésider",
    "coprésidées": "coprésider",
    "coprésidés": "coprésider",
    "coptes": "copte",
    "copula": "copuler",
    "copulait": "copuler",
    "copulant": "copuler",
    "copulations": "copulation",
    "copulent": "copuler",
    "copules": "copule",
    "copulez": "copuler",
    "copulé": "copuler",
    "copyrights": "copyright",
    "coqs": "coq",
    "coquards": "coquard",
    "coquarts": "coquart",
    "coquelets": "coquelet",
    "coquelicots": "coquelicot",
    "coqueluches": "coqueluche",
    "coquemars": "coquemar",
    "coques": "coque",
    "coquetiers": "coquetier",
    "coquets": "coquet",
    "coquette": "coquet",
    "coquetteries": "coquetterie",
    "coquettes": "coquette",
    "coquillages": "coquillage",
    "coquillards": "coquillard",
    "coquilles": "coquille",
    "coquillettes": "coquillette",
    "coquine": "coquin",
    "coquineries": "coquinerie",
    "coquines": "coquin",
    "coquins": "coquin",
    "coralliaires": "coralliaire",
    "corallienne": "corallien",
    "coralliennes": "corallien",
    "coralliens": "corallien",
    "coralline": "corallin",
    "corallines": "corallin",
    "corallins": "corallin",
    "coraniques": "coranique",
    "coras": "cora",
    "coraux": "corail",
    "corbeaux": "corbeau",
    "corbeilles": "corbeille",
    "corbillards": "corbillard",
    "corbillons": "corbillon",
    "corbins": "corbin",
    "cordages": "cordage",
    "corde": "corder",
    "cordeaux": "cordeau",
    "cordelettes": "cordelette",
    "cordeliers": "cordelier",
    "cordelière": "cordelier",
    "cordelières": "cordelier",
    "cordelle": "cordeau",
    "cordes": "corder",
    "cordiale": "cordial",
    "cordiales": "cordial",
    "cordialités": "cordialité",
    "cordiaux": "cordial",
    "cordiers": "cordier",
    "cordiformes": "cordiforme",
    "cordillères": "cordillère",
    "cordobas": "cordoba",
    "cordonnets": "cordonnet",
    "cordonniers": "cordonnier",
    "cordonnière": "cordonnier",
    "cordonnières": "cordonnier",
    "cordonnées": "cordonner",
    "cordons": "cordon",
    "cordons-bleus": "cordon-bleu",
    "cordé": "corder",
    "cordées": "corder",
    "cordés": "cordé",
    "coreligionnaires": "coreligionnaire",
    "corelliens": "corellien",
    "coriaces": "coriace",
    "coriandres": "coriandre",
    "corindons": "corindon",
    "corinthiennes": "corinthien",
    "corinthiens": "corinthien",
    "cormorans": "cormoran",
    "corna": "corner",
    "cornacs": "cornac",
    "cornages": "cornage",
    "cornai": "corner",
    "cornaient": "corner",
    "cornais": "corner",
    "cornait": "corner",
    "cornalines": "cornaline",
    "cornant": "corner",
    "cornaquaient": "cornaquer",
    "cornaquée": "cornaquer",
    "cornards": "cornard",
    "cornas": "corner",
    "cornasse": "corner",
    "cornassent": "corner",
    "cornasses": "corner",
    "cornassiez": "corner",
    "cornassions": "corner",
    "corne": "corner",
    "corneilles": "corneille",
    "cornemuses": "cornemuse",
    "cornent": "corner",
    "cornera": "corner",
    "cornerai": "corner",
    "corneraient": "corner",
    "cornerais": "corner",
    "cornerait": "corner",
    "corneras": "corner",
    "cornerez": "corner",
    "corneriez": "corner",
    "cornerions": "corner",
    "cornerons": "corner",
    "corneront": "corner",
    "corners": "corner",
    "cornes": "corner",
    "cornets": "cornet",
    "cornettes": "cornette",
    "cornez": "corner",
    "corniauds": "corniaud",
    "corniches": "corniche",
    "cornichons": "cornichon",
    "corniez": "corner",
    "cornions": "corner",
    "corniots": "corniot",
    "cornistes": "corniste",
    "cornières": "cornière",
    "cornons": "corner",
    "cornouillers": "cornouiller",
    "cornouilles": "cornouille",
    "cornue": "cornu",
    "cornues": "cornue",
    "cornus": "cornu",
    "cornâmes": "corner",
    "cornât": "corner",
    "cornâtes": "corner",
    "cornèrent": "corner",
    "corné": "corner",
    "cornée": "corner",
    "cornéenne": "cornéen",
    "cornées": "corner",
    "cornélienne": "cornélien",
    "cornéliennes": "cornélien",
    "cornéliens": "cornélien",
    "cornés": "corner",
    "corollaires": "corollaire",
    "corolles": "corolle",
    "coronaires": "coronaire",
    "coronale": "coronal",
    "coronales": "coronal",
    "coronarienne": "coronarien",
    "coronariennes": "coronarien",
    "coronariens": "coronarien",
    "coronarites": "coronarite",
    "coroners": "coroner",
    "coronilles": "coronille",
    "corons": "coron",
    "corozos": "corozo",
    "corporalisés": "corporaliser",
    "corporatifs": "corporatif",
    "corporations": "corporation",
    "corporatismes": "corporatisme",
    "corporatistes": "corporatiste",
    "corporative": "corporatif",
    "corporatives": "corporatif",
    "corporaux": "corporal",
    "corporelle": "corporel",
    "corporelles": "corporel",
    "corporels": "corporel",
    "corps-morts": "corps-mort",
    "corpulences": "corpulence",
    "corpulente": "corpulent",
    "corpulentes": "corpulent",
    "corpulents": "corpulent",
    "corpuscules": "corpuscule",
    "corrals": "corral",
    "correcte": "correct",
    "correctes": "correct",
    "correcteurs": "correcteur",
    "correctifs": "correctif",
    "correctionnalisa": "correctionnaliser",
    "correctionnalisai": "correctionnaliser",
    "correctionnalisaient": "correctionnaliser",
    "correctionnalisais": "correctionnaliser",
    "correctionnalisait": "correctionnaliser",
    "correctionnalisant": "correctionnaliser",
    "correctionnalisas": "correctionnaliser",
    "correctionnalisasse": "correctionnaliser",
    "correctionnalisassent": "correctionnaliser",
    "correctionnalisasses": "correctionnaliser",
    "correctionnalisassiez": "correctionnaliser",
    "correctionnalisassions": "correctionnaliser",
    "correctionnalise": "correctionnaliser",
    "correctionnalisent": "correctionnaliser",
    "correctionnalisera": "correctionnaliser",
    "correctionnaliserai": "correctionnaliser",
    "correctionnaliseraient": "correctionnaliser",
    "correctionnaliserais": "correctionnaliser",
    "correctionnaliserait": "correctionnaliser",
    "correctionnaliseras": "correctionnaliser",
    "correctionnaliserez": "correctionnaliser",
    "correctionnaliseriez": "correctionnaliser",
    "correctionnaliserions": "correctionnaliser",
    "correctionnaliserons": "correctionnaliser",
    "correctionnaliseront": "correctionnaliser",
    "correctionnalises": "correctionnaliser",
    "correctionnalisez": "correctionnaliser",
    "correctionnalisiez": "correctionnaliser",
    "correctionnalisions": "correctionnaliser",
    "correctionnalisons": "correctionnaliser",
    "correctionnalisâmes": "correctionnaliser",
    "correctionnalisât": "correctionnaliser",
    "correctionnalisâtes": "correctionnaliser",
    "correctionnalisèrent": "correctionnaliser",
    "correctionnalisé": "correctionnaliser",
    "correctionnalisée": "correctionnaliser",
    "correctionnalisées": "correctionnaliser",
    "correctionnalisés": "correctionnaliser",
    "correctionnelle": "correctionnel",
    "correctionnelles": "correctionnel",
    "correctionnels": "correctionnel",
    "corrections": "correction",
    "corrective": "correctif",
    "correctives": "correctif",
    "correctrice": "correcteur",
    "correctrices": "correcteur",
    "corrects": "correct",
    "correspond": "correspondre",
    "correspondaient": "correspondre",
    "correspondais": "correspondre",
    "correspondait": "correspondre",
    "correspondances": "correspondance",
    "correspondant": "correspondre",
    "correspondante": "correspondant",
    "correspondantes": "correspondant",
    "correspondants": "correspondant",
    "corresponde": "correspondre",
    "correspondent": "correspondre",
    "correspondes": "correspondre",
    "correspondez": "correspondre",
    "correspondiez": "correspondre",
    "correspondions": "correspondre",
    "correspondirent": "correspondre",
    "correspondis": "correspondre",
    "correspondisse": "correspondre",
    "correspondissent": "correspondre",
    "correspondisses": "correspondre",
    "correspondissiez": "correspondre",
    "correspondissions": "correspondre",
    "correspondit": "correspondre",
    "correspondons": "correspondre",
    "correspondra": "correspondre",
    "correspondrai": "correspondre",
    "correspondraient": "correspondre",
    "correspondrais": "correspondre",
    "correspondrait": "correspondre",
    "correspondras": "correspondre",
    "correspondrez": "correspondre",
    "correspondriez": "correspondre",
    "correspondrions": "correspondre",
    "correspondrons": "correspondre",
    "correspondront": "correspondre",
    "corresponds": "correspondre",
    "correspondu": "correspondre",
    "correspondîmes": "correspondre",
    "correspondît": "correspondre",
    "correspondîtes": "correspondre",
    "corridas": "corrida",
    "corridors": "corridor",
    "corrige": "corriger",
    "corrigea": "corriger",
    "corrigeai": "corriger",
    "corrigeaient": "corriger",
    "corrigeais": "corriger",
    "corrigeait": "corriger",
    "corrigeant": "corriger",
    "corrigeas": "corriger",
    "corrigeasse": "corriger",
    "corrigeassent": "corriger",
    "corrigeasses": "corriger",
    "corrigeassiez": "corriger",
    "corrigeassions": "corriger",
    "corrigent": "corriger",
    "corrigeons": "corriger",
    "corrigera": "corriger",
    "corrigerai": "corriger",
    "corrigeraient": "corriger",
    "corrigerais": "corriger",
    "corrigerait": "corriger",
    "corrigeras": "corriger",
    "corrigerez": "corriger",
    "corrigeriez": "corriger",
    "corrigerions": "corriger",
    "corrigerons": "corriger",
    "corrigeront": "corriger",
    "corriges": "corriger",
    "corrigez": "corriger",
    "corrigeâmes": "corriger",
    "corrigeât": "corriger",
    "corrigeâtes": "corriger",
    "corrigiez": "corriger",
    "corrigions": "corriger",
    "corrigèrent": "corriger",
    "corrigé": "corriger",
    "corrigée": "corriger",
    "corrigées": "corriger",
    "corrigés": "corriger",
    "corrobora": "corroborer",
    "corroborai": "corroborer",
    "corroboraient": "corroborer",
    "corroborais": "corroborer",
    "corroborait": "corroborer",
    "corroborant": "corroborer",
    "corroboras": "corroborer",
    "corroborasse": "corroborer",
    "corroborassent": "corroborer",
    "corroborasses": "corroborer",
    "corroborassiez": "corroborer",
    "corroborassions": "corroborer",
    "corrobore": "corroborer",
    "corroborent": "corroborer",
    "corroborera": "corroborer",
    "corroborerai": "corroborer",
    "corroboreraient": "corroborer",
    "corroborerais": "corroborer",
    "corroborerait": "corroborer",
    "corroboreras": "corroborer",
    "corroborerez": "corroborer",
    "corroboreriez": "corroborer",
    "corroborerions": "corroborer",
    "corroborerons": "corroborer",
    "corroboreront": "corroborer",
    "corrobores": "corroborer",
    "corroborez": "corroborer",
    "corroboriez": "corroborer",
    "corroborions": "corroborer",
    "corroborons": "corroborer",
    "corroborâmes": "corroborer",
    "corroborât": "corroborer",
    "corroborâtes": "corroborer",
    "corroborèrent": "corroborer",
    "corroboré": "corroborer",
    "corroborée": "corroborer",
    "corroborées": "corroborer",
    "corroborés": "corroborer",
    "corroda": "corroder",
    "corrodai": "corroder",
    "corrodaient": "corroder",
    "corrodais": "corroder",
    "corrodait": "corroder",
    "corrodant": "corroder",
    "corrodante": "corrodant",
    "corrodas": "corroder",
    "corrodasse": "corroder",
    "corrodassent": "corroder",
    "corrodasses": "corroder",
    "corrodassiez": "corroder",
    "corrodassions": "corroder",
    "corrode": "corroder",
    "corrodent": "corroder",
    "corrodera": "corroder",
    "corroderai": "corroder",
    "corroderaient": "corroder",
    "corroderais": "corroder",
    "corroderait": "corroder",
    "corroderas": "corroder",
    "corroderez": "corroder",
    "corroderiez": "corroder",
    "corroderions": "corroder",
    "corroderons": "corroder",
    "corroderont": "corroder",
    "corrodes": "corroder",
    "corrodez": "corroder",
    "corrodiez": "corroder",
    "corrodions": "corroder",
    "corrodons": "corroder",
    "corrodâmes": "corroder",
    "corrodât": "corroder",
    "corrodâtes": "corroder",
    "corrodèrent": "corroder",
    "corrodé": "corroder",
    "corrodée": "corroder",
    "corrodées": "corroder",
    "corrodés": "corroder",
    "corroie": "corroyer",
    "corroient": "corroyer",
    "corroiera": "corroyer",
    "corroierai": "corroyer",
    "corroieraient": "corroyer",
    "corroierais": "corroyer",
    "corroierait": "corroyer",
    "corroieras": "corroyer",
    "corroierez": "corroyer",
    "corroieriez": "corroyer",
    "corroierions": "corroyer",
    "corroierons": "corroyer",
    "corroieront": "corroyer",
    "corroies": "corroyer",
    "corrois": "corroi",
    "corrompaient": "corrompre",
    "corrompais": "corrompre",
    "corrompait": "corrompre",
    "corrompant": "corrompre",
    "corrompe": "corrompre",
    "corrompent": "corrompre",
    "corrompes": "corrompre",
    "corrompez": "corrompre",
    "corrompiez": "corrompre",
    "corrompions": "corrompre",
    "corrompirent": "corrompre",
    "corrompis": "corrompre",
    "corrompisse": "corrompre",
    "corrompissent": "corrompre",
    "corrompisses": "corrompre",
    "corrompissiez": "corrompre",
    "corrompissions": "corrompre",
    "corrompit": "corrompre",
    "corrompons": "corrompre",
    "corrompra": "corrompre",
    "corromprai": "corrompre",
    "corrompraient": "corrompre",
    "corromprais": "corrompre",
    "corromprait": "corrompre",
    "corrompras": "corrompre",
    "corromprez": "corrompre",
    "corrompriez": "corrompre",
    "corromprions": "corrompre",
    "corromprons": "corrompre",
    "corrompront": "corrompre",
    "corromps": "corrompre",
    "corrompt": "corrompre",
    "corrompu": "corrompre",
    "corrompue": "corrompre",
    "corrompues": "corrompre",
    "corrompus": "corrompu",
    "corrompîmes": "corrompre",
    "corrompît": "corrompre",
    "corrompîtes": "corrompre",
    "corrosifs": "corrosif",
    "corrosive": "corrosif",
    "corrosives": "corrosif",
    "corroya": "corroyer",
    "corroyai": "corroyer",
    "corroyaient": "corroyer",
    "corroyais": "corroyer",
    "corroyait": "corroyer",
    "corroyant": "corroyer",
    "corroyas": "corroyer",
    "corroyasse": "corroyer",
    "corroyassent": "corroyer",
    "corroyasses": "corroyer",
    "corroyassiez": "corroyer",
    "corroyassions": "corroyer",
    "corroyez": "corroyer",
    "corroyiez": "corroyer",
    "corroyions": "corroyer",
    "corroyons": "corroyer",
    "corroyâmes": "corroyer",
    "corroyât": "corroyer",
    "corroyâtes": "corroyer",
    "corroyèrent": "corroyer",
    "corroyé": "corroyer",
    "corroyée": "corroyer",
    "corroyées": "corroyer",
    "corroyés": "corroyer",
    "corrupteurs": "corrupteur",
    "corruptibles": "corruptible",
    "corruptions": "corruption",
    "corruptrice": "corrupteur",
    "corruptrices": "corrupteur",
    "corrèle": "corréler",
    "corrèlent": "corréler",
    "corrèles": "corréler",
    "corréla": "corréler",
    "corrélai": "corréler",
    "corrélaient": "corréler",
    "corrélais": "corréler",
    "corrélait": "corréler",
    "corrélant": "corréler",
    "corrélas": "corréler",
    "corrélasse": "corréler",
    "corrélassent": "corréler",
    "corrélasses": "corréler",
    "corrélassiez": "corréler",
    "corrélassions": "corréler",
    "corrélatifs": "corrélatif",
    "corrélations": "corrélation",
    "corrélative": "corrélatif",
    "corrélatives": "corrélatif",
    "corrélera": "corréler",
    "corrélerai": "corréler",
    "corréleraient": "corréler",
    "corrélerais": "corréler",
    "corrélerait": "corréler",
    "corréleras": "corréler",
    "corrélerez": "corréler",
    "corréleriez": "corréler",
    "corrélerions": "corréler",
    "corrélerons": "corréler",
    "corréleront": "corréler",
    "corrélez": "corréler",
    "corréliez": "corréler",
    "corrélions": "corréler",
    "corrélons": "corréler",
    "corrélâmes": "corréler",
    "corrélât": "corréler",
    "corrélâtes": "corréler",
    "corrélèrent": "corréler",
    "corrélé": "corréler",
    "corrélée": "corréler",
    "corrélées": "corréler",
    "corrélés": "corréler",
    "corrézienne": "corrézien",
    "corréziennes": "corrézien",
    "corréziens": "corrézien",
    "cors": "cor",
    "corsa": "corser",
    "corsages": "corsage",
    "corsai": "corser",
    "corsaient": "corser",
    "corsaires": "corsaire",
    "corsais": "corser",
    "corsait": "corser",
    "corsant": "corser",
    "corsas": "corser",
    "corsasse": "corser",
    "corsassent": "corser",
    "corsasses": "corser",
    "corsassiez": "corser",
    "corsassions": "corser",
    "corse": "corser",
    "corselets": "corselet",
    "corsent": "corser",
    "corsera": "corser",
    "corserai": "corser",
    "corseraient": "corser",
    "corserais": "corser",
    "corserait": "corser",
    "corseras": "corser",
    "corserez": "corser",
    "corseriez": "corser",
    "corserions": "corser",
    "corserons": "corser",
    "corseront": "corser",
    "corses": "corser",
    "corseta": "corseter",
    "corsetai": "corseter",
    "corsetaient": "corseter",
    "corsetais": "corseter",
    "corsetait": "corseter",
    "corsetant": "corseter",
    "corsetas": "corseter",
    "corsetasse": "corseter",
    "corsetassent": "corseter",
    "corsetasses": "corseter",
    "corsetassiez": "corseter",
    "corsetassions": "corseter",
    "corsetez": "corseter",
    "corsetiez": "corseter",
    "corsetions": "corseter",
    "corsetière": "corsetier",
    "corsetons": "corseter",
    "corsets": "corset",
    "corsetâmes": "corseter",
    "corsetât": "corseter",
    "corsetâtes": "corseter",
    "corsetèrent": "corseter",
    "corseté": "corseter",
    "corsetée": "corseter",
    "corsetées": "corseter",
    "corsetés": "corseter",
    "corsez": "corser",
    "corsiez": "corser",
    "corsions": "corser",
    "corsons": "corser",
    "corsos": "corso",
    "corsâmes": "corser",
    "corsât": "corser",
    "corsâtes": "corser",
    "corsèrent": "corser",
    "corsète": "corseter",
    "corsètent": "corseter",
    "corsètera": "corseter",
    "corsèterai": "corseter",
    "corsèteraient": "corseter",
    "corsèterais": "corseter",
    "corsèterait": "corseter",
    "corsèteras": "corseter",
    "corsèterez": "corseter",
    "corsèteriez": "corseter",
    "corsèterions": "corseter",
    "corsèterons": "corseter",
    "corsèteront": "corseter",
    "corsètes": "corseter",
    "corsé": "corser",
    "corsée": "corser",
    "corsées": "corser",
    "corsés": "corser",
    "cortes": "corte",
    "corticale": "cortical",
    "corticales": "cortical",
    "corticaux": "cortical",
    "cortisones": "cortisone",
    "cortèges": "cortège",
    "cortégeant": "cortéger",
    "coruscante": "coruscant",
    "coruscants": "coruscant",
    "corvettes": "corvette",
    "corvées": "corvée",
    "corybantes": "corybante",
    "corymbes": "corymbe",
    "coryphées": "coryphée",
    "coryzas": "coryza",
    "coréalisations": "coréalisation",
    "coréenne": "coréen",
    "coréennes": "coréen",
    "coréens": "coréen",
    "cosaques": "cosaque",
    "coseigneurs": "coseigneur",
    "cosigna": "cosigner",
    "cosignai": "cosigner",
    "cosignaient": "cosigner",
    "cosignais": "cosigner",
    "cosignait": "cosigner",
    "cosignant": "cosigner",
    "cosignas": "cosigner",
    "cosignasse": "cosigner",
    "cosignassent": "cosigner",
    "cosignasses": "cosigner",
    "cosignassiez": "cosigner",
    "cosignassions": "cosigner",
    "cosignataires": "cosignataire",
    "cosigne": "cosigner",
    "cosignent": "cosigner",
    "cosignera": "cosigner",
    "cosignerai": "cosigner",
    "cosigneraient": "cosigner",
    "cosignerais": "cosigner",
    "cosignerait": "cosigner",
    "cosigneras": "cosigner",
    "cosignerez": "cosigner",
    "cosigneriez": "cosigner",
    "cosignerions": "cosigner",
    "cosignerons": "cosigner",
    "cosigneront": "cosigner",
    "cosignes": "cosigner",
    "cosignez": "cosigner",
    "cosigniez": "cosigner",
    "cosignions": "cosigner",
    "cosignons": "cosigner",
    "cosignâmes": "cosigner",
    "cosignât": "cosigner",
    "cosignâtes": "cosigner",
    "cosignèrent": "cosigner",
    "cosigné": "cosigner",
    "cosignée": "cosigner",
    "cosignées": "cosigner",
    "cosignés": "cosigner",
    "cosmiques": "cosmique",
    "cosmodromes": "cosmodrome",
    "cosmogonies": "cosmogonie",
    "cosmographies": "cosmographie",
    "cosmologies": "cosmologie",
    "cosmologiques": "cosmologique",
    "cosmonautes": "cosmonaute",
    "cosmopolites": "cosmopolite",
    "cosmopolitismes": "cosmopolitisme",
    "cosméticienne": "cosméticien",
    "cosmétiques": "cosmétique",
    "cosmétiqué": "cosmétiquer",
    "cosmétiquée": "cosmétiquer",
    "cosmétiquées": "cosmétiquer",
    "cosmétiqués": "cosmétiquer",
    "cosmétologies": "cosmétologie",
    "cossa": "cosser",
    "cossai": "cosser",
    "cossaient": "cosser",
    "cossais": "cosser",
    "cossait": "cosser",
    "cossant": "cosser",
    "cossarde": "cossard",
    "cossards": "cossard",
    "cossas": "cosser",
    "cossasse": "cosser",
    "cossassent": "cosser",
    "cossasses": "cosser",
    "cossassiez": "cosser",
    "cossassions": "cosser",
    "cosse": "cosser",
    "cossent": "cosser",
    "cossera": "cosser",
    "cosserai": "cosser",
    "cosseraient": "cosser",
    "cosserais": "cosser",
    "cosserait": "cosser",
    "cosseras": "cosser",
    "cosserez": "cosser",
    "cosseriez": "cosser",
    "cosserions": "cosser",
    "cosserons": "cosser",
    "cosseront": "cosser",
    "cosses": "cosser",
    "cossez": "cosser",
    "cossiez": "cosser",
    "cossions": "cosser",
    "cossons": "cosser",
    "cossue": "cossu",
    "cossues": "cossu",
    "cossus": "cossu",
    "cossâmes": "cosser",
    "cossât": "cosser",
    "cossâtes": "cosser",
    "cossèrent": "cosser",
    "cossé": "cosser",
    "costale": "costal",
    "costales": "costal",
    "costards": "costard",
    "costaricaine": "costaricain",
    "costaricains": "costaricain",
    "costariciennes": "costaricien",
    "costaude": "costaud",
    "costaudes": "costaud",
    "costauds": "costaud",
    "costaux": "costal",
    "costuma": "costumer",
    "costumai": "costumer",
    "costumaient": "costumer",
    "costumais": "costumer",
    "costumait": "costumer",
    "costumant": "costumer",
    "costumas": "costumer",
    "costumasse": "costumer",
    "costumassent": "costumer",
    "costumasses": "costumer",
    "costumassiez": "costumer",
    "costumassions": "costumer",
    "costume": "costumer",
    "costument": "costumer",
    "costumera": "costumer",
    "costumerai": "costumer",
    "costumeraient": "costumer",
    "costumerais": "costumer",
    "costumerait": "costumer",
    "costumeras": "costumer",
    "costumerez": "costumer",
    "costumeriez": "costumer",
    "costumerions": "costumer",
    "costumerons": "costumer",
    "costumeront": "costumer",
    "costumes": "costumer",
    "costumez": "costumer",
    "costumiers": "costumier",
    "costumiez": "costumer",
    "costumions": "costumer",
    "costumière": "costumier",
    "costumières": "costumier",
    "costumons": "costumer",
    "costumâmes": "costumer",
    "costumât": "costumer",
    "costumâtes": "costumer",
    "costumèrent": "costumer",
    "costumé": "costumer",
    "costumée": "costumer",
    "costumées": "costumer",
    "costumés": "costumer",
    "cosy-corners": "cosy-corner",
    "cosys": "cosy",
    "cota": "coter",
    "cotai": "coter",
    "cotaient": "coter",
    "cotais": "coter",
    "cotait": "coter",
    "cotant": "coter",
    "cotas": "coter",
    "cotasse": "coter",
    "cotassent": "coter",
    "cotasses": "coter",
    "cotassiez": "coter",
    "cotassions": "coter",
    "cotations": "cotation",
    "cote": "coter",
    "coteaux": "coteau",
    "cotent": "coter",
    "cotera": "coter",
    "coterai": "coter",
    "coteraient": "coter",
    "coterais": "coter",
    "coterait": "coter",
    "coteras": "coter",
    "coterez": "coter",
    "coteries": "coterie",
    "coteriez": "coter",
    "coterions": "coter",
    "coterons": "coter",
    "coteront": "coter",
    "cotes": "coter",
    "cotez": "coter",
    "cothurnes": "cothurne",
    "coti": "cotir",
    "cotie": "cotir",
    "coties": "cotir",
    "cotiez": "coter",
    "cotignacs": "cotignac",
    "cotillons": "cotillon",
    "cotions": "coter",
    "cotira": "cotir",
    "cotirai": "cotir",
    "cotiraient": "cotir",
    "cotirais": "cotir",
    "cotirait": "cotir",
    "cotiras": "cotir",
    "cotirent": "cotir",
    "cotirez": "cotir",
    "cotiriez": "cotir",
    "cotirions": "cotir",
    "cotirons": "cotir",
    "cotiront": "cotir",
    "cotis": "cotir",
    "cotisa": "cotiser",
    "cotisai": "cotiser",
    "cotisaient": "cotiser",
    "cotisais": "cotiser",
    "cotisait": "cotiser",
    "cotisant": "cotiser",
    "cotisante": "cotisant",
    "cotisantes": "cotisant",
    "cotisants": "cotisant",
    "cotisas": "cotiser",
    "cotisasse": "cotiser",
    "cotisassent": "cotiser",
    "cotisasses": "cotiser",
    "cotisassiez": "cotiser",
    "cotisassions": "cotiser",
    "cotisations": "cotisation",
    "cotise": "cotiser",
    "cotisent": "cotiser",
    "cotisera": "cotiser",
    "cotiserai": "cotiser",
    "cotiseraient": "cotiser",
    "cotiserais": "cotiser",
    "cotiserait": "cotiser",
    "cotiseras": "cotiser",
    "cotiserez": "cotiser",
    "cotiseriez": "cotiser",
    "cotiserions": "cotiser",
    "cotiserons": "cotiser",
    "cotiseront": "cotiser",
    "cotises": "cotiser",
    "cotisez": "cotiser",
    "cotisiez": "cotiser",
    "cotisions": "cotiser",
    "cotisons": "cotiser",
    "cotissaient": "cotir",
    "cotissais": "cotir",
    "cotissait": "cotir",
    "cotissant": "cotir",
    "cotisse": "cotir",
    "cotissent": "cotir",
    "cotisses": "cotir",
    "cotissez": "cotir",
    "cotissiez": "cotir",
    "cotissions": "cotir",
    "cotissons": "cotir",
    "cotisâmes": "cotiser",
    "cotisât": "cotiser",
    "cotisâtes": "cotiser",
    "cotisèrent": "cotiser",
    "cotisé": "cotiser",
    "cotisée": "cotiser",
    "cotisées": "cotiser",
    "cotisés": "cotiser",
    "cotit": "cotir",
    "cotonnades": "cotonnade",
    "cotonnait": "cotonner",
    "cotonnant": "cotonner",
    "cotonneuse": "cotonneux",
    "cotonneuses": "cotonneux",
    "cotonniers": "cotonnier",
    "cotonnière": "cotonnier",
    "cotonnières": "cotonnier",
    "cotons": "coton",
    "cotons-poudres": "coton-poudre",
    "cotons-tiges": "coton-tige",
    "cotonéasters": "cotonéaster",
    "cotres": "cotre",
    "cotrets": "cotret",
    "cottages": "cottage",
    "cottes": "cotte",
    "cotylédons": "cotylédon",
    "cotâmes": "coter",
    "cotât": "coter",
    "cotâtes": "coter",
    "cotèrent": "coter",
    "coté": "coter",
    "cotée": "coter",
    "cotées": "coter",
    "cotés": "coter",
    "cotîmes": "cotir",
    "cotît": "cotir",
    "cotîtes": "cotir",
    "couacs": "couac",
    "couaquait": "couaquer",
    "couarde": "couard",
    "couardes": "couard",
    "couards": "couard",
    "coucha": "coucher",
    "couchai": "coucher",
    "couchaient": "coucher",
    "couchais": "coucher",
    "couchait": "coucher",
    "couchant": "coucher",
    "couchants": "couchant",
    "couchas": "coucher",
    "couchasse": "coucher",
    "couchassent": "coucher",
    "couchasses": "coucher",
    "couchassiez": "coucher",
    "couchassions": "coucher",
    "couche": "coucher",
    "couchent": "coucher",
    "couchera": "coucher",
    "coucherai": "coucher",
    "coucheraient": "coucher",
    "coucherais": "coucher",
    "coucherait": "coucher",
    "coucheras": "coucher",
    "coucherez": "coucher",
    "coucheries": "coucherie",
    "coucheriez": "coucher",
    "coucherions": "coucher",
    "coucherons": "coucher",
    "coucheront": "coucher",
    "couchers": "coucher",
    "couches": "coucher",
    "couches-culottes": "couche-culotte",
    "couchettes": "couchette",
    "coucheurs": "coucheur",
    "coucheuse": "coucheur",
    "couchez": "coucher",
    "couchiez": "coucher",
    "couchions": "coucher",
    "couchons": "coucher",
    "couchâmes": "coucher",
    "couchât": "coucher",
    "couchâtes": "coucher",
    "couchèrent": "coucher",
    "couché": "coucher",
    "couchée": "coucher",
    "couchées": "coucher",
    "couchés": "coucher",
    "coucous": "coucou",
    "coud": "coudre",
    "coudent": "couder",
    "coudes": "coude",
    "coudoie": "coudoyer",
    "coudoiements": "coudoiement",
    "coudoient": "coudoyer",
    "coudoiera": "coudoyer",
    "coudoierai": "coudoyer",
    "coudoieraient": "coudoyer",
    "coudoierais": "coudoyer",
    "coudoierait": "coudoyer",
    "coudoieras": "coudoyer",
    "coudoierez": "coudoyer",
    "coudoieriez": "coudoyer",
    "coudoierions": "coudoyer",
    "coudoierons": "coudoyer",
    "coudoieront": "coudoyer",
    "coudoies": "coudoyer",
    "coudoya": "coudoyer",
    "coudoyai": "coudoyer",
    "coudoyaient": "coudoyer",
    "coudoyais": "coudoyer",
    "coudoyait": "coudoyer",
    "coudoyant": "coudoyer",
    "coudoyas": "coudoyer",
    "coudoyasse": "coudoyer",
    "coudoyassent": "coudoyer",
    "coudoyasses": "coudoyer",
    "coudoyassiez": "coudoyer",
    "coudoyassions": "coudoyer",
    "coudoyez": "coudoyer",
    "coudoyiez": "coudoyer",
    "coudoyions": "coudoyer",
    "coudoyons": "coudoyer",
    "coudoyâmes": "coudoyer",
    "coudoyât": "coudoyer",
    "coudoyâtes": "coudoyer",
    "coudoyèrent": "coudoyer",
    "coudoyé": "coudoyer",
    "coudoyée": "coudoyer",
    "coudoyées": "coudoyer",
    "coudoyés": "coudoyer",
    "coudra": "coudre",
    "coudrai": "coudre",
    "coudraient": "coudre",
    "coudraies": "coudraie",
    "coudrais": "coudre",
    "coudrait": "coudre",
    "coudras": "coudre",
    "coudrez": "coudre",
    "coudriers": "coudrier",
    "coudriez": "coudre",
    "coudrions": "coudre",
    "coudrons": "coudre",
    "coudront": "coudre",
    "couds": "coudre",
    "coudé": "couder",
    "coudée": "couder",
    "coudées": "couder",
    "couennes": "couenne",
    "couettes": "couette",
    "couffins": "couffin",
    "cougouars": "cougouar",
    "couguars": "couguar",
    "couilles": "couille",
    "couillettes": "couillette",
    "couillonnades": "couillonnade",
    "couillonne": "couillonner",
    "couillonnent": "couillonner",
    "couillonné": "couillonner",
    "couillonnée": "couillonner",
    "couillonnés": "couillonner",
    "couillons": "couillon",
    "couillus": "couillu",
    "couina": "couiner",
    "couinaient": "couiner",
    "couinais": "couiner",
    "couinait": "couiner",
    "couinant": "couiner",
    "couine": "couiner",
    "couinements": "couinement",
    "couinent": "couiner",
    "couinerais": "couiner",
    "couineras": "couiner",
    "couineront": "couiner",
    "couines": "couiner",
    "couinez": "couiner",
    "couiné": "couiner",
    "coula": "couler",
    "coulai": "couler",
    "coulaient": "couler",
    "coulais": "couler",
    "coulait": "couler",
    "coulant": "couler",
    "coulante": "coulant",
    "coulantes": "coulant",
    "coulants": "coulant",
    "coulas": "couler",
    "coulasse": "couler",
    "coulassent": "couler",
    "coulasses": "couler",
    "coulassiez": "couler",
    "coulassions": "couler",
    "coule": "couler",
    "coulemelles": "coulemelle",
    "coulent": "couler",
    "coulera": "couler",
    "coulerai": "couler",
    "couleraient": "couler",
    "coulerais": "couler",
    "coulerait": "couler",
    "couleras": "couler",
    "coulerez": "couler",
    "couleriez": "couler",
    "coulerions": "couler",
    "coulerons": "couler",
    "couleront": "couler",
    "coules": "couler",
    "couleurs": "couleur",
    "couleuvreaux": "couleuvreau",
    "couleuvres": "couleuvre",
    "couleuvrines": "couleuvrine",
    "coulez": "couler",
    "couliez": "couler",
    "coulions": "couler",
    "coulissa": "coulisser",
    "coulissages": "coulissage",
    "coulissai": "coulisser",
    "coulissaient": "coulisser",
    "coulissais": "coulisser",
    "coulissait": "coulisser",
    "coulissant": "coulisser",
    "coulissante": "coulissant",
    "coulissantes": "coulissant",
    "coulissants": "coulissant",
    "coulissas": "coulisser",
    "coulissasse": "coulisser",
    "coulissassent": "coulisser",
    "coulissasses": "coulisser",
    "coulissassiez": "coulisser",
    "coulissassions": "coulisser",
    "coulisse": "coulisser",
    "coulisseaux": "coulisseau",
    "coulissements": "coulissement",
    "coulissent": "coulisser",
    "coulissera": "coulisser",
    "coulisserai": "coulisser",
    "coulisseraient": "coulisser",
    "coulisserais": "coulisser",
    "coulisserait": "coulisser",
    "coulisseras": "coulisser",
    "coulisserez": "coulisser",
    "coulisseriez": "coulisser",
    "coulisserions": "coulisser",
    "coulisserons": "coulisser",
    "coulisseront": "coulisser",
    "coulisses": "coulisser",
    "coulissez": "coulisser",
    "coulissiez": "coulisser",
    "coulissions": "coulisser",
    "coulissons": "coulisser",
    "coulissâmes": "coulisser",
    "coulissât": "coulisser",
    "coulissâtes": "coulisser",
    "coulissèrent": "coulisser",
    "coulissé": "coulisser",
    "coulissée": "coulisser",
    "coulissées": "coulisser",
    "coulissés": "coulisser",
    "couloirs": "couloir",
    "coulombs": "coulomb",
    "coulons": "couler",
    "coulpes": "coulpe",
    "coulures": "coulure",
    "coulâmes": "couler",
    "coulât": "couler",
    "coulâtes": "couler",
    "coulèrent": "couler",
    "coulé": "couler",
    "coulée": "couler",
    "coulées": "couler",
    "coulés": "couler",
    "coupa": "couper",
    "coupables": "coupable",
    "coupages": "coupage",
    "coupai": "couper",
    "coupaient": "couper",
    "coupais": "couper",
    "coupait": "couper",
    "coupant": "couper",
    "coupante": "coupant",
    "coupantes": "coupant",
    "coupants": "coupant",
    "coupas": "couper",
    "coupasse": "couper",
    "coupassent": "couper",
    "coupasses": "couper",
    "coupassiez": "couper",
    "coupassions": "couper",
    "coupe": "couper",
    "coupe-choux": "coupe-chou",
    "coupe-cigares": "coupe-cigare",
    "coupe-circuits": "coupe-circuit",
    "coupe-coupes": "coupe-coupe",
    "coupe-faims": "coupe-faim",
    "coupe-jarrets": "coupe-jarret",
    "coupe-racines": "coupe-racine",
    "coupellations": "coupellation",
    "coupelles": "coupelle",
    "coupent": "couper",
    "coupera": "couper",
    "couperai": "couper",
    "couperaient": "couper",
    "couperais": "couper",
    "couperait": "couper",
    "couperas": "couper",
    "couperets": "couperet",
    "couperez": "couper",
    "couperiez": "couper",
    "couperions": "couper",
    "couperons": "couper",
    "couperont": "couper",
    "couperoses": "couperose",
    "couperosé": "couperoser",
    "couperosée": "couperosé",
    "couperosées": "couperosé",
    "coupes": "couper",
    "coupeurs": "coupeur",
    "coupeuse": "coupeur",
    "coupeuses": "coupeur",
    "coupez": "couper",
    "coupiez": "couper",
    "coupions": "couper",
    "coupla": "coupler",
    "couplages": "couplage",
    "couplai": "coupler",
    "couplaient": "coupler",
    "couplais": "coupler",
    "couplait": "coupler",
    "couplant": "coupler",
    "couplas": "coupler",
    "couplasse": "coupler",
    "couplassent": "coupler",
    "couplasses": "coupler",
    "couplassiez": "coupler",
    "couplassions": "coupler",
    "couple": "coupler",
    "couplent": "coupler",
    "couplera": "coupler",
    "couplerai": "coupler",
    "coupleraient": "coupler",
    "couplerais": "coupler",
    "couplerait": "coupler",
    "coupleras": "coupler",
    "couplerez": "coupler",
    "coupleriez": "coupler",
    "couplerions": "coupler",
    "couplerons": "coupler",
    "coupleront": "coupler",
    "couples": "coupler",
    "couplets": "couplet",
    "coupleurs": "coupleur",
    "couplez": "coupler",
    "coupliez": "coupler",
    "couplions": "coupler",
    "couplons": "coupler",
    "couplâmes": "coupler",
    "couplât": "coupler",
    "couplâtes": "coupler",
    "couplèrent": "coupler",
    "couplé": "coupler",
    "couplée": "coupler",
    "couplées": "coupler",
    "couplés": "coupler",
    "coupoles": "coupole",
    "coupons": "coupon",
    "coups": "coup",
    "coups-de-poing": "coup-de-poing",
    "coupures": "coupure",
    "coupâmes": "couper",
    "coupât": "couper",
    "coupâtes": "couper",
    "coupèrent": "couper",
    "coupé": "couper",
    "coupée": "couper",
    "coupées": "couper",
    "coupés": "couper",
    "couques": "couque",
    "courages": "courage",
    "courageuse": "courageux",
    "courageuses": "courageux",
    "couraient": "courir",
    "courais": "courir",
    "courait": "courir",
    "courant": "courir",
    "courante": "courant",
    "courantes": "courante",
    "courants": "courant",
    "courba": "courber",
    "courbai": "courber",
    "courbaient": "courber",
    "courbais": "courber",
    "courbait": "courber",
    "courbant": "courber",
    "courbas": "courber",
    "courbasse": "courber",
    "courbassent": "courber",
    "courbasses": "courber",
    "courbassiez": "courber",
    "courbassions": "courber",
    "courbatu": "courbaturer",
    "courbatue": "courbaturer",
    "courbatues": "courbaturer",
    "courbatura": "courbaturer",
    "courbaturai": "courbaturer",
    "courbaturaient": "courbaturer",
    "courbaturais": "courbaturer",
    "courbaturait": "courbaturer",
    "courbaturant": "courbaturer",
    "courbaturas": "courbaturer",
    "courbaturasse": "courbaturer",
    "courbaturassent": "courbaturer",
    "courbaturasses": "courbaturer",
    "courbaturassiez": "courbaturer",
    "courbaturassions": "courbaturer",
    "courbature": "courbaturer",
    "courbaturent": "courbaturer",
    "courbaturera": "courbaturer",
    "courbaturerai": "courbaturer",
    "courbatureraient": "courbaturer",
    "courbaturerais": "courbaturer",
    "courbaturerait": "courbaturer",
    "courbatureras": "courbaturer",
    "courbaturerez": "courbaturer",
    "courbatureriez": "courbaturer",
    "courbaturerions": "courbaturer",
    "courbaturerons": "courbaturer",
    "courbatureront": "courbaturer",
    "courbatures": "courbaturer",
    "courbaturez": "courbaturer",
    "courbaturiez": "courbaturer",
    "courbaturions": "courbaturer",
    "courbaturons": "courbaturer",
    "courbaturâmes": "courbaturer",
    "courbaturât": "courbaturer",
    "courbaturâtes": "courbaturer",
    "courbaturèrent": "courbaturer",
    "courbaturé": "courbaturer",
    "courbaturée": "courbaturer",
    "courbaturées": "courbaturer",
    "courbaturés": "courbaturer",
    "courbatus": "courbaturer",
    "courbe": "courber",
    "courbent": "courber",
    "courbera": "courber",
    "courberai": "courber",
    "courberaient": "courber",
    "courberais": "courber",
    "courberait": "courber",
    "courberas": "courber",
    "courberez": "courber",
    "courberiez": "courber",
    "courberions": "courber",
    "courberons": "courber",
    "courberont": "courber",
    "courbes": "courber",
    "courbettes": "courbette",
    "courbez": "courber",
    "courbiez": "courber",
    "courbions": "courber",
    "courbons": "courber",
    "courbures": "courbure",
    "courbâmes": "courber",
    "courbât": "courber",
    "courbâtes": "courber",
    "courbèrent": "courber",
    "courbé": "courber",
    "courbée": "courber",
    "courbées": "courber",
    "courbés": "courber",
    "coure": "courir",
    "courent": "courir",
    "coures": "courir",
    "courettes": "courette",
    "coureurs": "coureur",
    "coureuse": "coureur",
    "coureuses": "coureur",
    "courez": "courir",
    "courges": "courge",
    "courgettes": "courgette",
    "couriez": "courir",
    "courions": "courir",
    "couronna": "couronner",
    "couronnai": "couronner",
    "couronnaient": "couronner",
    "couronnais": "couronner",
    "couronnait": "couronner",
    "couronnant": "couronner",
    "couronnas": "couronner",
    "couronnasse": "couronner",
    "couronnassent": "couronner",
    "couronnasses": "couronner",
    "couronnassiez": "couronner",
    "couronnassions": "couronner",
    "couronne": "couronner",
    "couronnements": "couronnement",
    "couronnent": "couronner",
    "couronnera": "couronner",
    "couronnerai": "couronner",
    "couronneraient": "couronner",
    "couronnerais": "couronner",
    "couronnerait": "couronner",
    "couronneras": "couronner",
    "couronnerez": "couronner",
    "couronneriez": "couronner",
    "couronnerions": "couronner",
    "couronnerons": "couronner",
    "couronneront": "couronner",
    "couronnes": "couronner",
    "couronnez": "couronner",
    "couronniez": "couronner",
    "couronnions": "couronner",
    "couronnons": "couronner",
    "couronnâmes": "couronner",
    "couronnât": "couronner",
    "couronnâtes": "couronner",
    "couronnèrent": "couronner",
    "couronné": "couronner",
    "couronnée": "couronner",
    "couronnées": "couronner",
    "couronnés": "couronner",
    "courons": "courir",
    "courra": "courir",
    "courrai": "courir",
    "courraient": "courir",
    "courrais": "courir",
    "courrait": "courir",
    "courras": "courir",
    "courrez": "courir",
    "courriers": "courrier",
    "courriez": "courir",
    "courrions": "courir",
    "courriéristes": "courriériste",
    "courroies": "courroie",
    "courrons": "courir",
    "courront": "courir",
    "courrouce": "courroucer",
    "courroucent": "courroucer",
    "courroucera": "courroucer",
    "courroucerai": "courroucer",
    "courrouceraient": "courroucer",
    "courroucerais": "courroucer",
    "courroucerait": "courroucer",
    "courrouceras": "courroucer",
    "courroucerez": "courroucer",
    "courrouceriez": "courroucer",
    "courroucerions": "courroucer",
    "courroucerons": "courroucer",
    "courrouceront": "courroucer",
    "courrouces": "courroucer",
    "courroucez": "courroucer",
    "courrouciez": "courroucer",
    "courroucions": "courroucer",
    "courroucèrent": "courroucer",
    "courroucé": "courroucer",
    "courroucée": "courroucer",
    "courroucées": "courroucer",
    "courroucés": "courroucer",
    "courrouça": "courroucer",
    "courrouçai": "courroucer",
    "courrouçaient": "courroucer",
    "courrouçais": "courroucer",
    "courrouçait": "courroucer",
    "courrouçant": "courroucer",
    "courrouças": "courroucer",
    "courrouçasse": "courroucer",
    "courrouçassent": "courroucer",
    "courrouçasses": "courroucer",
    "courrouçassiez": "courroucer",
    "courrouçassions": "courroucer",
    "courrouçons": "courroucer",
    "courrouçâmes": "courroucer",
    "courrouçât": "courroucer",
    "courrouçâtes": "courroucer",
    "cours": "courir",
    "coursaient": "courser",
    "coursais": "courser",
    "coursait": "courser",
    "coursant": "courser",
    "course": "courser",
    "coursent": "courser",
    "courserais": "courser",
    "courses": "course",
    "coursiers": "coursier",
    "coursives": "coursive",
    "coursière": "coursier",
    "coursé": "courser",
    "coursée": "courser",
    "coursés": "courser",
    "court": "courir",
    "court-circuitait": "court-circuiter",
    "court-circuitant": "court-circuiter",
    "court-circuite": "court-circuiter",
    "court-circuits": "court-circuit",
    "court-circuité": "court-circuiter",
    "court-circuitée": "court-circuiter",
    "court-circuitées": "court-circuiter",
    "court-courriers": "court-courrier",
    "court-jointée": "court-jointé",
    "court-jointées": "court-jointé",
    "court-jointés": "court-jointé",
    "court-vêtue": "court-vêtu",
    "court-vêtues": "court-vêtu",
    "court-vêtus": "court-vêtu",
    "courtages": "courtage",
    "courtaude": "courtaud",
    "courtaudes": "courtaud",
    "courtauds": "courtaud",
    "courte": "courter",
    "courtelinesques": "courtelinesque",
    "courtepointes": "courtepointe",
    "courtes": "court",
    "courtiers": "courtier",
    "courtilières": "courtilière",
    "courtils": "courtil",
    "courtines": "courtine",
    "courtisa": "courtiser",
    "courtisai": "courtiser",
    "courtisaient": "courtiser",
    "courtisais": "courtiser",
    "courtisait": "courtiser",
    "courtisane": "courtisan",
    "courtisaneries": "courtisanerie",
    "courtisanes": "courtisan",
    "courtisans": "courtisan",
    "courtisant": "courtiser",
    "courtisas": "courtiser",
    "courtisasse": "courtiser",
    "courtisassent": "courtiser",
    "courtisasses": "courtiser",
    "courtisassiez": "courtiser",
    "courtisassions": "courtiser",
    "courtise": "courtiser",
    "courtisent": "courtiser",
    "courtisera": "courtiser",
    "courtiserai": "courtiser",
    "courtiseraient": "courtiser",
    "courtiserais": "courtiser",
    "courtiserait": "courtiser",
    "courtiseras": "courtiser",
    "courtiserez": "courtiser",
    "courtiseriez": "courtiser",
    "courtiserions": "courtiser",
    "courtiserons": "courtiser",
    "courtiseront": "courtiser",
    "courtises": "courtiser",
    "courtisez": "courtiser",
    "courtisiez": "courtiser",
    "courtisions": "courtiser",
    "courtisons": "courtiser",
    "courtisâmes": "courtiser",
    "courtisât": "courtiser",
    "courtisâtes": "courtiser",
    "courtisèrent": "courtiser",
    "courtisé": "courtiser",
    "courtisée": "courtiser",
    "courtisées": "courtiser",
    "courtisés": "courtiser",
    "courtière": "courtier",
    "courtières": "courtier",
    "courtoise": "courtois",
    "courtoises": "courtois",
    "courtoisies": "courtoisie",
    "courts": "court",
    "courts-bouillons": "court-bouillon",
    "courts-circuits": "court-circuit",
    "courts-jus": "court-jus",
    "couru": "courir",
    "courue": "couru",
    "courues": "couru",
    "coururent": "courir",
    "courus": "couru",
    "courusse": "courir",
    "courussent": "courir",
    "courusses": "courir",
    "courussiez": "courir",
    "courussions": "courir",
    "courut": "courir",
    "courûmes": "courir",
    "courût": "courir",
    "courûtes": "courir",
    "cous": "cou",
    "cous-de-pied": "cou-de-pied",
    "cousaient": "coudre",
    "cousais": "coudre",
    "cousait": "coudre",
    "cousant": "coudre",
    "couscoussiers": "couscoussier",
    "couse": "coudre",
    "cousent": "coudre",
    "couses": "coudre",
    "cousettes": "cousette",
    "couseuse": "couseur",
    "cousez": "coudre",
    "cousiez": "coudre",
    "cousinages": "cousinage",
    "cousinant": "cousiner",
    "cousine": "cousin",
    "cousines": "cousin",
    "cousins": "cousin",
    "cousions": "coudre",
    "cousirent": "coudre",
    "cousis": "coudre",
    "cousisse": "coudre",
    "cousissent": "coudre",
    "cousisses": "coudre",
    "cousissiez": "coudre",
    "cousissions": "coudre",
    "cousit": "coudre",
    "cousons": "coudre",
    "coussinets": "coussinet",
    "coussins": "coussin",
    "cousu": "coudre",
    "cousue": "cousu",
    "cousues": "cousu",
    "cousus": "cousu",
    "cousîmes": "coudre",
    "cousît": "coudre",
    "cousîtes": "coudre",
    "couteaux": "couteau",
    "couteliers": "coutelier",
    "coutelleries": "coutellerie",
    "coutils": "coutil",
    "coutres": "coutre",
    "coutumes": "coutume",
    "coutumiers": "coutumier",
    "coutumière": "coutumier",
    "coutumières": "coutumier",
    "couturaient": "couturer",
    "coutures": "couture",
    "couturiers": "couturier",
    "couturière": "couturier",
    "couturières": "couturier",
    "couturé": "couturer",
    "couturée": "couturer",
    "couturées": "couturer",
    "couturés": "couturer",
    "couva": "couver",
    "couvai": "couver",
    "couvaient": "couver",
    "couvains": "couvain",
    "couvais": "couver",
    "couvaisons": "couvaison",
    "couvait": "couver",
    "couvant": "couver",
    "couvas": "couver",
    "couvasse": "couver",
    "couvassent": "couver",
    "couvasses": "couver",
    "couvassiez": "couver",
    "couvassions": "couver",
    "couve": "couver",
    "couvent": "couver",
    "couventines": "couventine",
    "couvents": "couvent",
    "couvera": "couver",
    "couverai": "couver",
    "couveraient": "couver",
    "couverais": "couver",
    "couverait": "couver",
    "couveras": "couver",
    "couvercles": "couvercle",
    "couverez": "couver",
    "couveriez": "couver",
    "couverions": "couver",
    "couverons": "couver",
    "couveront": "couver",
    "couvert": "couvrir",
    "couverte": "couvrir",
    "couvertes": "couvrir",
    "couverts": "couvrir",
    "couvertures": "couverture",
    "couves": "couver",
    "couveuses": "couveuse",
    "couvez": "couver",
    "couviez": "couver",
    "couvions": "couver",
    "couvis": "couvi",
    "couvons": "couver",
    "couvraient": "couvrir",
    "couvrais": "couvrir",
    "couvrait": "couvrir",
    "couvrant": "couvrir",
    "couvrante": "couvrant",
    "couvrantes": "couvrant",
    "couvre": "couvrir",
    "couvre-chefs": "couvre-chef",
    "couvre-feux": "couvre-feu",
    "couvre-joints": "couvre-joint",
    "couvre-lits": "couvre-lit",
    "couvre-nuques": "couvre-nuque",
    "couvre-plats": "couvre-plat",
    "couvrent": "couvrir",
    "couvres": "couvrir",
    "couvreurs": "couvreur",
    "couvrez": "couvrir",
    "couvriez": "couvrir",
    "couvrions": "couvrir",
    "couvrira": "couvrir",
    "couvrirai": "couvrir",
    "couvriraient": "couvrir",
    "couvrirais": "couvrir",
    "couvrirait": "couvrir",
    "couvriras": "couvrir",
    "couvrirent": "couvrir",
    "couvrirez": "couvrir",
    "couvririez": "couvrir",
    "couvririons": "couvrir",
    "couvrirons": "couvrir",
    "couvriront": "couvrir",
    "couvris": "couvrir",
    "couvrisse": "couvrir",
    "couvrissent": "couvrir",
    "couvrisses": "couvrir",
    "couvrissiez": "couvrir",
    "couvrissions": "couvrir",
    "couvrit": "couvrir",
    "couvrons": "couvrir",
    "couvrîmes": "couvrir",
    "couvrît": "couvrir",
    "couvrîtes": "couvrir",
    "couvâmes": "couver",
    "couvât": "couver",
    "couvâtes": "couver",
    "couvèrent": "couver",
    "couvé": "couver",
    "couvée": "couver",
    "couvées": "couver",
    "couvés": "couver",
    "covalente": "covalent",
    "covenants": "covenant",
    "cover-girls": "cover-girl",
    "cow-boys": "cow-boy",
    "coxalgies": "coxalgie",
    "coxarthroses": "coxarthrose",
    "coyotes": "coyote",
    "coédita": "coéditer",
    "coéditai": "coéditer",
    "coéditaient": "coéditer",
    "coéditais": "coéditer",
    "coéditait": "coéditer",
    "coéditant": "coéditer",
    "coéditas": "coéditer",
    "coéditasse": "coéditer",
    "coéditassent": "coéditer",
    "coéditasses": "coéditer",
    "coéditassiez": "coéditer",
    "coéditassions": "coéditer",
    "coédite": "coéditer",
    "coéditent": "coéditer",
    "coéditera": "coéditer",
    "coéditerai": "coéditer",
    "coéditeraient": "coéditer",
    "coéditerais": "coéditer",
    "coéditerait": "coéditer",
    "coéditeras": "coéditer",
    "coéditerez": "coéditer",
    "coéditeriez": "coéditer",
    "coéditerions": "coéditer",
    "coéditerons": "coéditer",
    "coéditeront": "coéditer",
    "coédites": "coéditer",
    "coéditez": "coéditer",
    "coéditiez": "coéditer",
    "coéditions": "coédition",
    "coéditons": "coéditer",
    "coéditâmes": "coéditer",
    "coéditât": "coéditer",
    "coéditâtes": "coéditer",
    "coéditèrent": "coéditer",
    "coédité": "coéditer",
    "coéditée": "coéditer",
    "coéditées": "coéditer",
    "coédités": "coéditer",
    "coéquipiers": "coéquipier",
    "coéquipière": "coéquipier",
    "coéquipières": "coéquipier",
    "coïncida": "coïncider",
    "coïncidai": "coïncider",
    "coïncidaient": "coïncider",
    "coïncidais": "coïncider",
    "coïncidait": "coïncider",
    "coïncidant": "coïncider",
    "coïncidas": "coïncider",
    "coïncidasse": "coïncider",
    "coïncidassent": "coïncider",
    "coïncidasses": "coïncider",
    "coïncidassiez": "coïncider",
    "coïncidassions": "coïncider",
    "coïncide": "coïncider",
    "coïncidences": "coïncidence",
    "coïncident": "coïncider",
    "coïncidente": "coïncident",
    "coïncidentes": "coïncident",
    "coïncidents": "coïncident",
    "coïncidera": "coïncider",
    "coïnciderai": "coïncider",
    "coïncideraient": "coïncider",
    "coïnciderais": "coïncider",
    "coïnciderait": "coïncider",
    "coïncideras": "coïncider",
    "coïnciderez": "coïncider",
    "coïncideriez": "coïncider",
    "coïnciderions": "coïncider",
    "coïnciderons": "coïncider",
    "coïncideront": "coïncider",
    "coïncides": "coïncider",
    "coïncidez": "coïncider",
    "coïncidiez": "coïncider",
    "coïncidions": "coïncider",
    "coïncidons": "coïncider",
    "coïncidâmes": "coïncider",
    "coïncidât": "coïncider",
    "coïncidâtes": "coïncider",
    "coïncidèrent": "coïncider",
    "coïncidé": "coïncider",
    "coïnculpée": "coïnculpé",
    "coïnculpées": "coïnculpé",
    "coïnculpés": "coïnculpé",
    "coïts": "coït",
    "coïté": "coïter",
    "coûta": "coûter",
    "coûtai": "coûter",
    "coûtaient": "coûter",
    "coûtais": "coûter",
    "coûtait": "coûter",
    "coûtant": "coûter",
    "coûtas": "coûter",
    "coûtasse": "coûter",
    "coûtassent": "coûter",
    "coûtasses": "coûter",
    "coûtassiez": "coûter",
    "coûtassions": "coûter",
    "coûte": "coûter",
    "coûtent": "coûter",
    "coûtera": "coûter",
    "coûterai": "coûter",
    "coûteraient": "coûter",
    "coûterais": "coûter",
    "coûterait": "coûter",
    "coûteras": "coûter",
    "coûterez": "coûter",
    "coûteriez": "coûter",
    "coûterions": "coûter",
    "coûterons": "coûter",
    "coûteront": "coûter",
    "coûtes": "coûter",
    "coûteuse": "coûteux",
    "coûteuses": "coûteux",
    "coûtez": "coûter",
    "coûtiez": "coûter",
    "coûtions": "coûter",
    "coûtons": "coûter",
    "coûts": "coût",
    "coûtâmes": "coûter",
    "coûtât": "coûter",
    "coûtâtes": "coûter",
    "coûtèrent": "coûter",
    "coûté": "coûter",
    "coûtée": "coûter",
    "coûtées": "coûter",
    "coûtés": "coûter",
    "crabes": "crabe",
    "crabillons": "crabillon",
    "cracha": "cracher",
    "crachai": "cracher",
    "crachaient": "cracher",
    "crachais": "cracher",
    "crachait": "cracher",
    "crachant": "cracher",
    "crachas": "cracher",
    "crachasse": "cracher",
    "crachassent": "cracher",
    "crachasses": "cracher",
    "crachassiez": "cracher",
    "crachassions": "cracher",
    "crachats": "crachat",
    "crache": "cracher",
    "crachements": "crachement",
    "crachent": "cracher",
    "crachera": "cracher",
    "cracherai": "cracher",
    "cracheraient": "cracher",
    "cracherais": "cracher",
    "cracherait": "cracher",
    "cracheras": "cracher",
    "cracherez": "cracher",
    "cracheriez": "cracher",
    "cracherions": "cracher",
    "cracherons": "cracher",
    "cracheront": "cracher",
    "craches": "cracher",
    "cracheurs": "cracheur",
    "cracheuse": "cracheur",
    "cracheuses": "cracheur",
    "crachez": "cracher",
    "crachiez": "cracher",
    "crachine": "crachiner",
    "crachins": "crachin",
    "crachions": "cracher",
    "crachoirs": "crachoir",
    "crachons": "cracher",
    "crachota": "crachoter",
    "crachotai": "crachoter",
    "crachotaient": "crachoter",
    "crachotais": "crachoter",
    "crachotait": "crachoter",
    "crachotant": "crachoter",
    "crachotantes": "crachotant",
    "crachotants": "crachotant",
    "crachotas": "crachoter",
    "crachotasse": "crachoter",
    "crachotassent": "crachoter",
    "crachotasses": "crachoter",
    "crachotassiez": "crachoter",
    "crachotassions": "crachoter",
    "crachote": "crachoter",
    "crachotements": "crachotement",
    "crachotent": "crachoter",
    "crachotera": "crachoter",
    "crachoterai": "crachoter",
    "crachoteraient": "crachoter",
    "crachoterais": "crachoter",
    "crachoterait": "crachoter",
    "crachoteras": "crachoter",
    "crachoterez": "crachoter",
    "crachoteriez": "crachoter",
    "crachoterions": "crachoter",
    "crachoterons": "crachoter",
    "crachoteront": "crachoter",
    "crachotes": "crachoter",
    "crachoteuse": "crachoteux",
    "crachotez": "crachoter",
    "crachotiez": "crachoter",
    "crachotions": "crachoter",
    "crachotons": "crachoter",
    "crachotâmes": "crachoter",
    "crachotât": "crachoter",
    "crachotâtes": "crachoter",
    "crachotèrent": "crachoter",
    "crachoté": "crachoter",
    "crachouilla": "crachouiller",
    "crachouille": "crachouiller",
    "crachâmes": "cracher",
    "crachât": "cracher",
    "crachâtes": "cracher",
    "crachèrent": "cracher",
    "craché": "cracher",
    "crachée": "cracher",
    "crachées": "cracher",
    "crachés": "cracher",
    "crackers": "cracker",
    "crackings": "cracking",
    "cracks": "crack",
    "crades": "crade",
    "cradingues": "cradingue",
    "crados": "crado",
    "craies": "craie",
    "craignaient": "craindre",
    "craignais": "craindre",
    "craignait": "craindre",
    "craignant": "craindre",
    "craigne": "craindre",
    "craignent": "craindre",
    "craignes": "craindre",
    "craignez": "craindre",
    "craigniez": "craindre",
    "craignions": "craindre",
    "craignirent": "craindre",
    "craignis": "craindre",
    "craignisse": "craindre",
    "craignissent": "craindre",
    "craignisses": "craindre",
    "craignissiez": "craindre",
    "craignissions": "craindre",
    "craignit": "craindre",
    "craignons": "craindre",
    "craignîmes": "craindre",
    "craignît": "craindre",
    "craignîtes": "craindre",
    "craillaient": "crailler",
    "craillent": "crailler",
    "craindra": "craindre",
    "craindrai": "craindre",
    "craindraient": "craindre",
    "craindrais": "craindre",
    "craindrait": "craindre",
    "craindras": "craindre",
    "craindrez": "craindre",
    "craindriez": "craindre",
    "craindrions": "craindre",
    "craindrons": "craindre",
    "craindront": "craindre",
    "crains": "craindre",
    "craint": "craindre",
    "crainte": "craindre",
    "craintes": "crainte",
    "craintifs": "craintif",
    "craintive": "craintif",
    "craintives": "craintif",
    "craints": "craindre",
    "crama": "cramer",
    "cramaient": "cramer",
    "cramait": "cramer",
    "cramant": "cramer",
    "crame": "cramer",
    "crament": "cramer",
    "crameraient": "cramer",
    "cramerais": "cramer",
    "crameras": "cramer",
    "cramez": "cramer",
    "cramoisi": "cramoisir",
    "cramoisie": "cramoisir",
    "cramoisies": "cramoisi",
    "cramoisis": "cramoisir",
    "cramouilles": "cramouille",
    "crampes": "crampe",
    "crampettes": "crampette",
    "cramponna": "cramponner",
    "cramponnai": "cramponner",
    "cramponnaient": "cramponner",
    "cramponnais": "cramponner",
    "cramponnait": "cramponner",
    "cramponnant": "cramponner",
    "cramponnas": "cramponner",
    "cramponnasse": "cramponner",
    "cramponnassent": "cramponner",
    "cramponnasses": "cramponner",
    "cramponnassiez": "cramponner",
    "cramponnassions": "cramponner",
    "cramponne": "cramponner",
    "cramponnent": "cramponner",
    "cramponnera": "cramponner",
    "cramponnerai": "cramponner",
    "cramponneraient": "cramponner",
    "cramponnerais": "cramponner",
    "cramponnerait": "cramponner",
    "cramponneras": "cramponner",
    "cramponnerez": "cramponner",
    "cramponneriez": "cramponner",
    "cramponnerions": "cramponner",
    "cramponnerons": "cramponner",
    "cramponneront": "cramponner",
    "cramponnes": "cramponner",
    "cramponnez": "cramponner",
    "cramponniez": "cramponner",
    "cramponnions": "cramponner",
    "cramponnons": "cramponner",
    "cramponnâmes": "cramponner",
    "cramponnât": "cramponner",
    "cramponnâtes": "cramponner",
    "cramponnèrent": "cramponner",
    "cramponné": "cramponner",
    "cramponnée": "cramponner",
    "cramponnées": "cramponner",
    "cramponnés": "cramponner",
    "crampons": "crampon",
    "cramé": "cramer",
    "cramée": "cramer",
    "cramées": "cramer",
    "cramés": "cramer",
    "crans": "cran",
    "cranté": "cranter",
    "crantées": "cranter",
    "crantés": "cranter",
    "craonnaise": "craonnais",
    "craonnaises": "craonnais",
    "crapahutait": "crapahuter",
    "crapahutant": "crapahuter",
    "crapahute": "crapahuter",
    "crapahutons": "crapahuter",
    "crapahuté": "crapahuter",
    "crapaudines": "crapaudine",
    "crapauds": "crapaud",
    "crapauds-buffles": "crapaud-buffle",
    "crapoteuse": "crapoteux",
    "crapoteuses": "crapoteux",
    "crapouillots": "crapouillot",
    "crapules": "crapule",
    "crapuleuse": "crapuleux",
    "crapuleuses": "crapuleux",
    "craqua": "craquer",
    "craquai": "craquer",
    "craquaient": "craquer",
    "craquais": "craquer",
    "craquait": "craquer",
    "craquant": "craquer",
    "craquante": "craquant",
    "craquantes": "craquant",
    "craquants": "craquant",
    "craquas": "craquer",
    "craquasse": "craquer",
    "craquassent": "craquer",
    "craquasses": "craquer",
    "craquassiez": "craquer",
    "craquassions": "craquer",
    "craque": "craquer",
    "craquela": "craqueler",
    "craquelai": "craqueler",
    "craquelaient": "craqueler",
    "craquelais": "craqueler",
    "craquelait": "craqueler",
    "craquelant": "craqueler",
    "craquelas": "craqueler",
    "craquelasse": "craqueler",
    "craquelassent": "craqueler",
    "craquelasses": "craqueler",
    "craquelassiez": "craqueler",
    "craquelassions": "craqueler",
    "craquelez": "craqueler",
    "craqueliez": "craqueler",
    "craquelins": "craquelin",
    "craquelions": "craqueler",
    "craquelle": "craqueler",
    "craquellent": "craqueler",
    "craquellera": "craqueler",
    "craquellerai": "craqueler",
    "craquelleraient": "craqueler",
    "craquellerais": "craqueler",
    "craquellerait": "craqueler",
    "craquelleras": "craqueler",
    "craquellerez": "craqueler",
    "craquelleriez": "craqueler",
    "craquellerions": "craqueler",
    "craquellerons": "craqueler",
    "craquelleront": "craqueler",
    "craquelles": "craqueler",
    "craquelons": "craqueler",
    "craquelures": "craquelure",
    "craquelâmes": "craqueler",
    "craquelât": "craqueler",
    "craquelâtes": "craqueler",
    "craquelèrent": "craqueler",
    "craquelé": "craqueler",
    "craquelée": "craqueler",
    "craquelées": "craqueler",
    "craquelés": "craqueler",
    "craquements": "craquement",
    "craquent": "craquer",
    "craquera": "craquer",
    "craquerai": "craquer",
    "craqueraient": "craquer",
    "craquerais": "craquer",
    "craquerait": "craquer",
    "craqueras": "craquer",
    "craquerez": "craquer",
    "craqueriez": "craquer",
    "craquerions": "craquer",
    "craquerons": "craquer",
    "craqueront": "craquer",
    "craques": "craquer",
    "craqueta": "craqueter",
    "craquetai": "craqueter",
    "craquetaient": "craqueter",
    "craquetais": "craqueter",
    "craquetait": "craqueter",
    "craquetant": "craqueter",
    "craquetas": "craqueter",
    "craquetasse": "craqueter",
    "craquetassent": "craqueter",
    "craquetasses": "craqueter",
    "craquetassiez": "craqueter",
    "craquetassions": "craqueter",
    "craquetez": "craqueter",
    "craquetiez": "craqueter",
    "craquetions": "craqueter",
    "craquetons": "craqueter",
    "craquette": "craqueter",
    "craquettent": "craqueter",
    "craquettera": "craqueter",
    "craquetterai": "craqueter",
    "craquetteraient": "craqueter",
    "craquetterais": "craqueter",
    "craquetterait": "craqueter",
    "craquetteras": "craqueter",
    "craquetterez": "craqueter",
    "craquetteriez": "craqueter",
    "craquetterions": "craqueter",
    "craquetterons": "craqueter",
    "craquetteront": "craqueter",
    "craquettes": "craqueter",
    "craquetâmes": "craqueter",
    "craquetât": "craqueter",
    "craquetâtes": "craqueter",
    "craquetèrent": "craqueter",
    "craqueté": "craqueter",
    "craquetée": "craqueter",
    "craquetées": "craqueter",
    "craquetés": "craqueter",
    "craquez": "craquer",
    "craquiez": "craquer",
    "craquions": "craquer",
    "craquons": "craquer",
    "craquâmes": "craquer",
    "craquât": "craquer",
    "craquâtes": "craquer",
    "craquèrent": "craquer",
    "craquètements": "craquètement",
    "craqué": "craquer",
    "craquée": "craquer",
    "craquées": "craquer",
    "craqués": "craquer",
    "crases": "crase",
    "crashe": "crasher",
    "crashes": "crashe",
    "crashs": "crash",
    "crashé": "crasher",
    "crashée": "crasher",
    "crassanes": "crassane",
    "crasses": "crasse",
    "crasseuse": "crasseux",
    "crasseuses": "crasseux",
    "crassiers": "crassier",
    "cratères": "cratère",
    "cravachais": "cravacher",
    "cravachait": "cravacher",
    "cravachant": "cravacher",
    "cravache": "cravacher",
    "cravaches": "cravache",
    "cravaché": "cravacher",
    "cravachées": "cravacher",
    "cravants": "cravant",
    "cravatait": "cravater",
    "cravate": "cravater",
    "cravates": "cravater",
    "cravatière": "cravatier",
    "cravaté": "cravater",
    "cravatée": "cravater",
    "cravatées": "cravater",
    "cravatés": "cravater",
    "crawlait": "crawler",
    "crawlant": "crawler",
    "crawls": "crawl",
    "crayeuse": "crayeux",
    "crayeuses": "crayeux",
    "crayonna": "crayonner",
    "crayonnages": "crayonnage",
    "crayonnai": "crayonner",
    "crayonnaient": "crayonner",
    "crayonnais": "crayonner",
    "crayonnait": "crayonner",
    "crayonnant": "crayonner",
    "crayonnas": "crayonner",
    "crayonnasse": "crayonner",
    "crayonnassent": "crayonner",
    "crayonnasses": "crayonner",
    "crayonnassiez": "crayonner",
    "crayonnassions": "crayonner",
    "crayonne": "crayonner",
    "crayonnent": "crayonner",
    "crayonnera": "crayonner",
    "crayonnerai": "crayonner",
    "crayonneraient": "crayonner",
    "crayonnerais": "crayonner",
    "crayonnerait": "crayonner",
    "crayonneras": "crayonner",
    "crayonnerez": "crayonner",
    "crayonneriez": "crayonner",
    "crayonnerions": "crayonner",
    "crayonnerons": "crayonner",
    "crayonneront": "crayonner",
    "crayonnes": "crayonner",
    "crayonneurs": "crayonneur",
    "crayonnez": "crayonner",
    "crayonniez": "crayonner",
    "crayonnions": "crayonner",
    "crayonnons": "crayonner",
    "crayonnâmes": "crayonner",
    "crayonnât": "crayonner",
    "crayonnâtes": "crayonner",
    "crayonnèrent": "crayonner",
    "crayonné": "crayonner",
    "crayonnée": "crayonner",
    "crayonnées": "crayonner",
    "crayonnés": "crayonner",
    "crayons": "crayon",
    "crayons-feutres": "crayon-feutre",
    "creeks": "creek",
    "crescendos": "crescendo",
    "cressonnières": "cressonnière",
    "cressons": "cresson",
    "cretonne": "creton",
    "cretonnes": "cretonne",
    "cretons": "creton",
    "creusa": "creuser",
    "creusai": "creuser",
    "creusaient": "creuser",
    "creusais": "creuser",
    "creusait": "creuser",
    "creusant": "creuser",
    "creusas": "creuser",
    "creusasse": "creuser",
    "creusassent": "creuser",
    "creusasses": "creuser",
    "creusassiez": "creuser",
    "creusassions": "creuser",
    "creuse": "creux",
    "creusements": "creusement",
    "creusent": "creuser",
    "creusera": "creuser",
    "creuserai": "creuser",
    "creuseraient": "creuser",
    "creuserais": "creuser",
    "creuserait": "creuser",
    "creuseras": "creuser",
    "creuserez": "creuser",
    "creuseriez": "creuser",
    "creuserions": "creuser",
    "creuserons": "creuser",
    "creuseront": "creuser",
    "creuses": "creux",
    "creusets": "creuset",
    "creusez": "creuser",
    "creusiez": "creuser",
    "creusions": "creuser",
    "creusons": "creuser",
    "creusâmes": "creuser",
    "creusât": "creuser",
    "creusâtes": "creuser",
    "creusèrent": "creuser",
    "creusé": "creuser",
    "creusée": "creuser",
    "creusées": "creuser",
    "creusés": "creuser",
    "creva": "crever",
    "crevai": "crever",
    "crevaient": "crever",
    "crevais": "crever",
    "crevaisons": "crevaison",
    "crevait": "crever",
    "crevant": "crever",
    "crevante": "crevant",
    "crevants": "crevant",
    "crevarde": "crevard",
    "crevards": "crevard",
    "crevas": "crever",
    "crevasse": "crever",
    "crevassent": "crever",
    "crevasses": "crever",
    "crevassiez": "crever",
    "crevassions": "crever",
    "crevassé": "crevasser",
    "crevassée": "crevasser",
    "crevassées": "crevasser",
    "crevassés": "crevasser",
    "crevettes": "crevette",
    "crevettiers": "crevettier",
    "crevez": "crever",
    "creviez": "crever",
    "crevions": "crever",
    "crevons": "crever",
    "crevotant": "crevoter",
    "crevures": "crevure",
    "crevâmes": "crever",
    "crevât": "crever",
    "crevâtes": "crever",
    "crevèrent": "crever",
    "crevé": "crever",
    "crevée": "crever",
    "crevées": "crever",
    "crevés": "crever",
    "cria": "crier",
    "criai": "crier",
    "criaient": "crier",
    "criailla": "criailler",
    "criaillai": "criailler",
    "criaillaient": "criailler",
    "criaillais": "criailler",
    "criaillait": "criailler",
    "criaillant": "criailler",
    "criaillas": "criailler",
    "criaillasse": "criailler",
    "criaillassent": "criailler",
    "criaillasses": "criailler",
    "criaillassiez": "criailler",
    "criaillassions": "criailler",
    "criaille": "criailler",
    "criaillent": "criailler",
    "criaillera": "criailler",
    "criaillerai": "criailler",
    "criailleraient": "criailler",
    "criaillerais": "criailler",
    "criaillerait": "criailler",
    "criailleras": "criailler",
    "criaillerez": "criailler",
    "criailleries": "criaillerie",
    "criailleriez": "criailler",
    "criaillerions": "criailler",
    "criaillerons": "criailler",
    "criailleront": "criailler",
    "criailles": "criailler",
    "criaillez": "criailler",
    "criailliez": "criailler",
    "criaillions": "criailler",
    "criaillons": "criailler",
    "criaillâmes": "criailler",
    "criaillât": "criailler",
    "criaillâtes": "criailler",
    "criaillèrent": "criailler",
    "criaillé": "criailler",
    "criais": "crier",
    "criait": "crier",
    "criant": "crier",
    "criante": "criant",
    "criantes": "criant",
    "criants": "criant",
    "criarde": "criard",
    "criardes": "criard",
    "criards": "criard",
    "crias": "crier",
    "criasse": "crier",
    "criassent": "crier",
    "criasses": "crier",
    "criassiez": "crier",
    "criassions": "crier",
    "cribla": "cribler",
    "criblai": "cribler",
    "criblaient": "cribler",
    "criblais": "cribler",
    "criblait": "cribler",
    "criblant": "cribler",
    "criblas": "cribler",
    "criblasse": "cribler",
    "criblassent": "cribler",
    "criblasses": "cribler",
    "criblassiez": "cribler",
    "criblassions": "cribler",
    "crible": "cribler",
    "criblent": "cribler",
    "criblera": "cribler",
    "criblerai": "cribler",
    "cribleraient": "cribler",
    "criblerais": "cribler",
    "criblerait": "cribler",
    "cribleras": "cribler",
    "criblerez": "cribler",
    "cribleriez": "cribler",
    "criblerions": "cribler",
    "criblerons": "cribler",
    "cribleront": "cribler",
    "cribles": "cribler",
    "criblez": "cribler",
    "cribliez": "cribler",
    "criblions": "cribler",
    "criblons": "cribler",
    "criblâmes": "cribler",
    "criblât": "cribler",
    "criblâtes": "cribler",
    "criblèrent": "cribler",
    "criblé": "cribler",
    "criblée": "cribler",
    "criblées": "cribler",
    "criblés": "cribler",
    "crickets": "cricket",
    "cricris": "cricri",
    "crics": "cric",
    "crie": "crier",
    "crient": "crier",
    "criera": "crier",
    "crierai": "crier",
    "crieraient": "crier",
    "crierais": "crier",
    "crierait": "crier",
    "crieras": "crier",
    "crierez": "crier",
    "crieriez": "crier",
    "crierions": "crier",
    "crierons": "crier",
    "crieront": "crier",
    "cries": "crier",
    "crieurs": "crieur",
    "crieuse": "crieur",
    "criez": "crier",
    "criiez": "crier",
    "criions": "crier",
    "crimes": "crime",
    "criminalités": "criminalité",
    "criminelle": "criminel",
    "criminelles": "criminel",
    "criminels": "criminel",
    "criminologies": "criminologie",
    "criminologues": "criminologue",
    "crincrins": "crincrin",
    "crinières": "crinière",
    "crinolines": "crinoline",
    "crins": "crin",
    "crions": "crier",
    "criques": "crique",
    "criquets": "criquet",
    "cris": "cri",
    "crises": "crise",
    "crispa": "crisper",
    "crispai": "crisper",
    "crispaient": "crisper",
    "crispais": "crisper",
    "crispait": "crisper",
    "crispant": "crisper",
    "crispante": "crispant",
    "crispantes": "crispant",
    "crispas": "crisper",
    "crispasse": "crisper",
    "crispassent": "crisper",
    "crispasses": "crisper",
    "crispassiez": "crisper",
    "crispassions": "crisper",
    "crispations": "crispation",
    "crispe": "crisper",
    "crispent": "crisper",
    "crispera": "crisper",
    "crisperai": "crisper",
    "crisperaient": "crisper",
    "crisperais": "crisper",
    "crisperait": "crisper",
    "crisperas": "crisper",
    "crisperez": "crisper",
    "crisperiez": "crisper",
    "crisperions": "crisper",
    "crisperons": "crisper",
    "crisperont": "crisper",
    "crispes": "crisper",
    "crispez": "crisper",
    "crispiez": "crisper",
    "crispions": "crisper",
    "crispons": "crisper",
    "crispâmes": "crisper",
    "crispât": "crisper",
    "crispâtes": "crisper",
    "crispèrent": "crisper",
    "crispé": "crisper",
    "crispée": "crisper",
    "crispées": "crisper",
    "crispés": "crisper",
    "crissa": "crisser",
    "crissai": "crisser",
    "crissaient": "crisser",
    "crissais": "crisser",
    "crissait": "crisser",
    "crissant": "crisser",
    "crissas": "crisser",
    "crissasse": "crisser",
    "crissassent": "crisser",
    "crissasses": "crisser",
    "crissassiez": "crisser",
    "crissassions": "crisser",
    "crisse": "crisser",
    "crissements": "crissement",
    "crissent": "crisser",
    "crissera": "crisser",
    "crisserai": "crisser",
    "crisseraient": "crisser",
    "crisserais": "crisser",
    "crisserait": "crisser",
    "crisseras": "crisser",
    "crisserez": "crisser",
    "crisseriez": "crisser",
    "crisserions": "crisser",
    "crisserons": "crisser",
    "crisseront": "crisser",
    "crisses": "crisser",
    "crissez": "crisser",
    "crissiez": "crisser",
    "crissions": "crisser",
    "crissons": "crisser",
    "crissâmes": "crisser",
    "crissât": "crisser",
    "crissâtes": "crisser",
    "crissèrent": "crisser",
    "crissé": "crisser",
    "cristalleries": "cristallerie",
    "cristalline": "cristallin",
    "cristallines": "cristallin",
    "cristallins": "cristallin",
    "cristallisa": "cristalliser",
    "cristallisai": "cristalliser",
    "cristallisaient": "cristalliser",
    "cristallisais": "cristalliser",
    "cristallisait": "cristalliser",
    "cristallisant": "cristalliser",
    "cristallisas": "cristalliser",
    "cristallisasse": "cristalliser",
    "cristallisassent": "cristalliser",
    "cristallisasses": "cristalliser",
    "cristallisassiez": "cristalliser",
    "cristallisassions": "cristalliser",
    "cristallisations": "cristallisation",
    "cristallise": "cristalliser",
    "cristallisent": "cristalliser",
    "cristallisera": "cristalliser",
    "cristalliserai": "cristalliser",
    "cristalliseraient": "cristalliser",
    "cristalliserais": "cristalliser",
    "cristalliserait": "cristalliser",
    "cristalliseras": "cristalliser",
    "cristalliserez": "cristalliser",
    "cristalliseriez": "cristalliser",
    "cristalliserions": "cristalliser",
    "cristalliserons": "cristalliser",
    "cristalliseront": "cristalliser",
    "cristallises": "cristalliser",
    "cristallisez": "cristalliser",
    "cristallisiez": "cristalliser",
    "cristallisions": "cristalliser",
    "cristallisons": "cristalliser",
    "cristallisâmes": "cristalliser",
    "cristallisât": "cristalliser",
    "cristallisâtes": "cristalliser",
    "cristallisèrent": "cristalliser",
    "cristallisé": "cristalliser",
    "cristallisée": "cristalliser",
    "cristallisées": "cristalliser",
    "cristallisés": "cristalliser",
    "cristaux": "cristal",
    "cristes-marines": "criste-marine",
    "criticaillent": "criticailler",
    "critiqua": "critiquer",
    "critiquables": "critiquable",
    "critiquai": "critiquer",
    "critiquaient": "critiquer",
    "critiquais": "critiquer",
    "critiquait": "critiquer",
    "critiquant": "critiquer",
    "critiquas": "critiquer",
    "critiquasse": "critiquer",
    "critiquassent": "critiquer",
    "critiquasses": "critiquer",
    "critiquassiez": "critiquer",
    "critiquassions": "critiquer",
    "critique": "critiquer",
    "critiquent": "critiquer",
    "critiquera": "critiquer",
    "critiquerai": "critiquer",
    "critiqueraient": "critiquer",
    "critiquerais": "critiquer",
    "critiquerait": "critiquer",
    "critiqueras": "critiquer",
    "critiquerez": "critiquer",
    "critiqueriez": "critiquer",
    "critiquerions": "critiquer",
    "critiquerons": "critiquer",
    "critiqueront": "critiquer",
    "critiques": "critiquer",
    "critiquez": "critiquer",
    "critiquiez": "critiquer",
    "critiquions": "critiquer",
    "critiquons": "critiquer",
    "critiquâmes": "critiquer",
    "critiquât": "critiquer",
    "critiquâtes": "critiquer",
    "critiquèrent": "critiquer",
    "critiqué": "critiquer",
    "critiquée": "critiquer",
    "critiquées": "critiquer",
    "critiqués": "critiquer",
    "critères": "critère",
    "critériums": "critérium",
    "criâmes": "crier",
    "criât": "crier",
    "criâtes": "crier",
    "crièrent": "crier",
    "crié": "crier",
    "criée": "crier",
    "criées": "crier",
    "criés": "crier",
    "croa croa": "croa-croa",
    "croassa": "croasser",
    "croassai": "croasser",
    "croassaient": "croasser",
    "croassais": "croasser",
    "croassait": "croasser",
    "croassant": "croasser",
    "croassas": "croasser",
    "croassasse": "croasser",
    "croassassent": "croasser",
    "croassasses": "croasser",
    "croassassiez": "croasser",
    "croassassions": "croasser",
    "croasse": "croasser",
    "croassements": "croassement",
    "croassent": "croasser",
    "croassera": "croasser",
    "croasserai": "croasser",
    "croasseraient": "croasser",
    "croasserais": "croasser",
    "croasserait": "croasser",
    "croasseras": "croasser",
    "croasserez": "croasser",
    "croasseriez": "croasser",
    "croasserions": "croasser",
    "croasserons": "croasser",
    "croasseront": "croasser",
    "croasses": "croasser",
    "croassez": "croasser",
    "croassiez": "croasser",
    "croassions": "croasser",
    "croassons": "croasser",
    "croassâmes": "croasser",
    "croassât": "croasser",
    "croassâtes": "croasser",
    "croassèrent": "croasser",
    "croassé": "croasser",
    "croates": "croate",
    "crocha": "crocher",
    "crochaient": "crocher",
    "crochait": "crocher",
    "croche-pieds": "croche-pied",
    "crochent": "crocher",
    "croches": "croche",
    "crocheta": "crocheter",
    "crochetai": "crocheter",
    "crochetaient": "crocheter",
    "crochetais": "crocheter",
    "crochetait": "crocheter",
    "crochetant": "crocheter",
    "crochetas": "crocheter",
    "crochetasse": "crocheter",
    "crochetassent": "crocheter",
    "crochetasses": "crocheter",
    "crochetassiez": "crocheter",
    "crochetassions": "crocheter",
    "crocheteurs": "crocheteur",
    "crochetez": "crocheter",
    "crochetiez": "crocheter",
    "crochetions": "crocheter",
    "crochetons": "crocheter",
    "crochets": "crochet",
    "crochetâmes": "crocheter",
    "crochetât": "crocheter",
    "crochetâtes": "crocheter",
    "crochetèrent": "crocheter",
    "crocheté": "crocheter",
    "crochetée": "crocheter",
    "crochetées": "crocheter",
    "crochetés": "crocheter",
    "crochue": "crochu",
    "crochues": "crochu",
    "crochus": "crochu",
    "crochète": "crocheter",
    "crochètent": "crocheter",
    "crochètera": "crocheter",
    "crochèterai": "crocheter",
    "crochèteraient": "crocheter",
    "crochèterais": "crocheter",
    "crochèterait": "crocheter",
    "crochèteras": "crocheter",
    "crochèterez": "crocheter",
    "crochèteriez": "crocheter",
    "crochèterions": "crocheter",
    "crochèterons": "crocheter",
    "crochèteront": "crocheter",
    "crochètes": "crocheter",
    "croché": "crocher",
    "crochées": "crocher",
    "crocodiles": "crocodile",
    "crocos": "croco",
    "crocs": "croc",
    "crocs-en-jambe": "croc-en-jambe",
    "croie": "croire",
    "croient": "croire",
    "croies": "croire",
    "croira": "croire",
    "croirai": "croire",
    "croiraient": "croire",
    "croirais": "croire",
    "croirait": "croire",
    "croiras": "croire",
    "croirez": "croire",
    "croiriez": "croire",
    "croirions": "croire",
    "croirons": "croire",
    "croiront": "croire",
    "crois": "croire",
    "croisa": "croiser",
    "croisades": "croisade",
    "croisai": "croiser",
    "croisaient": "croiser",
    "croisais": "croiser",
    "croisait": "croiser",
    "croisant": "croiser",
    "croisas": "croiser",
    "croisasse": "croiser",
    "croisassent": "croiser",
    "croisasses": "croiser",
    "croisassiez": "croiser",
    "croisassions": "croiser",
    "croise": "croiser",
    "croisements": "croisement",
    "croisent": "croiser",
    "croisera": "croiser",
    "croiserai": "croiser",
    "croiseraient": "croiser",
    "croiserais": "croiser",
    "croiserait": "croiser",
    "croiseras": "croiser",
    "croiserez": "croiser",
    "croiseriez": "croiser",
    "croiserions": "croiser",
    "croiserons": "croiser",
    "croiseront": "croiser",
    "croises": "croiser",
    "croiseurs": "croiseur",
    "croisez": "croiser",
    "croisiez": "croiser",
    "croisillons": "croisillon",
    "croisions": "croiser",
    "croisières": "croisière",
    "croisons": "croiser",
    "croissaient": "croître",
    "croissais": "croître",
    "croissait": "croître",
    "croissances": "croissance",
    "croissant": "croître",
    "croissante": "croissant",
    "croissantes": "croissant",
    "croissants": "croissant",
    "croisse": "croître",
    "croissent": "croître",
    "croisses": "croître",
    "croissez": "croître",
    "croissiez": "croître",
    "croissions": "croître",
    "croissons": "croître",
    "croisâmes": "croiser",
    "croisât": "croiser",
    "croisâtes": "croiser",
    "croisèrent": "croiser",
    "croisé": "croiser",
    "croisée": "croiser",
    "croisées": "croiser",
    "croisés": "croiser",
    "croit": "croire",
    "cromlechs": "cromlech",
    "crooners": "crooner",
    "croqua": "croquer",
    "croquai": "croquer",
    "croquaient": "croquer",
    "croquais": "croquer",
    "croquait": "croquer",
    "croquant": "croquer",
    "croquante": "croquant",
    "croquantes": "croquant",
    "croquants": "croquant",
    "croquas": "croquer",
    "croquasse": "croquer",
    "croquassent": "croquer",
    "croquasses": "croquer",
    "croquassiez": "croquer",
    "croquassions": "croquer",
    "croque": "croquer",
    "croque-mitaines": "croque-mitaine",
    "croque-morts": "croque-mort",
    "croquemitaines": "croquemitaine",
    "croquemorts": "croquemort",
    "croquenots": "croquenot",
    "croquent": "croquer",
    "croquera": "croquer",
    "croquerai": "croquer",
    "croqueraient": "croquer",
    "croquerais": "croquer",
    "croquerait": "croquer",
    "croqueras": "croquer",
    "croquerez": "croquer",
    "croqueriez": "croquer",
    "croquerions": "croquer",
    "croquerons": "croquer",
    "croqueront": "croquer",
    "croques": "croquer",
    "croquetons": "croqueton",
    "croquets": "croquet",
    "croquettes": "croquette",
    "croqueuse": "croqueur",
    "croquez": "croquer",
    "croquiez": "croquer",
    "croquignoles": "croquignole",
    "croquignolets": "croquignolet",
    "croquions": "croquer",
    "croquons": "croquer",
    "croquâmes": "croquer",
    "croquât": "croquer",
    "croquâtes": "croquer",
    "croquèrent": "croquer",
    "croqué": "croquer",
    "croquée": "croquer",
    "croquées": "croquer",
    "croqués": "croquer",
    "crosnes": "crosne",
    "crosses": "crosse",
    "crotales": "crotale",
    "crotons": "croton",
    "crottait": "crotter",
    "crottes": "crotte",
    "crottins": "crottin",
    "crotté": "crotter",
    "crottée": "crotter",
    "crottées": "crotter",
    "crottés": "crotter",
    "crouillats": "crouillat",
    "croula": "crouler",
    "croulai": "crouler",
    "croulaient": "crouler",
    "croulais": "crouler",
    "croulait": "crouler",
    "croulant": "crouler",
    "croulante": "croulant",
    "croulantes": "croulant",
    "croulants": "croulant",
    "croulas": "crouler",
    "croulasse": "crouler",
    "croulassent": "crouler",
    "croulasses": "crouler",
    "croulassiez": "crouler",
    "croulassions": "crouler",
    "croule": "crouler",
    "croulent": "crouler",
    "croulera": "crouler",
    "croulerai": "crouler",
    "crouleraient": "crouler",
    "croulerais": "crouler",
    "croulerait": "crouler",
    "crouleras": "crouler",
    "croulerez": "crouler",
    "crouleriez": "crouler",
    "croulerions": "crouler",
    "croulerons": "crouler",
    "crouleront": "crouler",
    "croules": "crouler",
    "croulez": "crouler",
    "crouliez": "crouler",
    "croulions": "crouler",
    "croulons": "crouler",
    "croulâmes": "crouler",
    "croulât": "crouler",
    "croulâtes": "crouler",
    "croulèrent": "crouler",
    "croulé": "crouler",
    "croulée": "crouler",
    "croulés": "crouler",
    "croupes": "croupe",
    "croupi": "croupir",
    "croupie": "croupir",
    "croupiers": "croupier",
    "croupies": "croupir",
    "croupionne": "croupionner",
    "croupions": "croupion",
    "croupira": "croupir",
    "croupirai": "croupir",
    "croupiraient": "croupir",
    "croupirais": "croupir",
    "croupirait": "croupir",
    "croupiras": "croupir",
    "croupirent": "croupir",
    "croupirez": "croupir",
    "croupiriez": "croupir",
    "croupirions": "croupir",
    "croupirons": "croupir",
    "croupiront": "croupir",
    "croupis": "croupir",
    "croupissaient": "croupir",
    "croupissais": "croupir",
    "croupissait": "croupir",
    "croupissant": "croupir",
    "croupissante": "croupissant",
    "croupissantes": "croupissant",
    "croupisse": "croupir",
    "croupissent": "croupir",
    "croupisses": "croupir",
    "croupissez": "croupir",
    "croupissiez": "croupir",
    "croupissions": "croupir",
    "croupissons": "croupir",
    "croupit": "croupir",
    "croupières": "croupière",
    "croups": "croup",
    "croupîmes": "croupir",
    "croupît": "croupir",
    "croupîtes": "croupir",
    "croustades": "croustade",
    "croustilla": "croustiller",
    "croustillai": "croustiller",
    "croustillaient": "croustiller",
    "croustillais": "croustiller",
    "croustillait": "croustiller",
    "croustillant": "croustiller",
    "croustillante": "croustillant",
    "croustillantes": "croustillant",
    "croustillants": "croustillant",
    "croustillas": "croustiller",
    "croustillasse": "croustiller",
    "croustillassent": "croustiller",
    "croustillasses": "croustiller",
    "croustillassiez": "croustiller",
    "croustillassions": "croustiller",
    "croustille": "croustiller",
    "croustillent": "croustiller",
    "croustillera": "croustiller",
    "croustillerai": "croustiller",
    "croustilleraient": "croustiller",
    "croustillerais": "croustiller",
    "croustillerait": "croustiller",
    "croustilleras": "croustiller",
    "croustillerez": "croustiller",
    "croustilleriez": "croustiller",
    "croustillerions": "croustiller",
    "croustillerons": "croustiller",
    "croustilleront": "croustiller",
    "croustilles": "croustiller",
    "croustillez": "croustiller",
    "croustilliez": "croustiller",
    "croustillions": "croustiller",
    "croustillons": "croustillon",
    "croustillâmes": "croustiller",
    "croustillât": "croustiller",
    "croustillâtes": "croustiller",
    "croustillèrent": "croustiller",
    "croustillé": "croustiller",
    "croyables": "croyable",
    "croyaient": "croire",
    "croyais": "croire",
    "croyait": "croire",
    "croyances": "croyance",
    "croyant": "croire",
    "croyante": "croyant",
    "croyantes": "croyant",
    "croyants": "croyant",
    "croyez": "croire",
    "croyiez": "croire",
    "croyions": "croire",
    "croyons": "croire",
    "croîs": "croître",
    "croît": "croître",
    "croîtra": "croître",
    "croîtrai": "croître",
    "croîtraient": "croître",
    "croîtrais": "croître",
    "croîtrait": "croître",
    "croîtras": "croître",
    "croîtrez": "croître",
    "croîtriez": "croître",
    "croîtrions": "croître",
    "croîtrons": "croître",
    "croîtront": "croître",
    "croîts": "croît",
    "croûte": "croûter",
    "croûtes": "croûter",
    "croûteuse": "croûteux",
    "croûteuses": "croûteux",
    "croûtonnais": "croûtonner",
    "croûtons": "croûton",
    "croûté": "croûter",
    "croûtée": "croûter",
    "croûtées": "croûter",
    "cru": "croire",
    "cruautés": "cruauté",
    "cruches": "cruche",
    "cruchons": "cruchon",
    "cruciale": "crucial",
    "cruciales": "crucial",
    "cruciaux": "crucial",
    "crucifia": "crucifier",
    "crucifiai": "crucifier",
    "crucifiaient": "crucifier",
    "crucifiais": "crucifier",
    "crucifiait": "crucifier",
    "crucifiant": "crucifier",
    "crucifiante": "crucifiant",
    "crucifias": "crucifier",
    "crucifiasse": "crucifier",
    "crucifiassent": "crucifier",
    "crucifiasses": "crucifier",
    "crucifiassiez": "crucifier",
    "crucifiassions": "crucifier",
    "crucifie": "crucifier",
    "crucifiements": "crucifiement",
    "crucifient": "crucifier",
    "crucifiera": "crucifier",
    "crucifierai": "crucifier",
    "crucifieraient": "crucifier",
    "crucifierais": "crucifier",
    "crucifierait": "crucifier",
    "crucifieras": "crucifier",
    "crucifierez": "crucifier",
    "crucifieriez": "crucifier",
    "crucifierions": "crucifier",
    "crucifierons": "crucifier",
    "crucifieront": "crucifier",
    "crucifies": "crucifier",
    "crucifiez": "crucifier",
    "crucifiiez": "crucifier",
    "crucifiions": "crucifier",
    "crucifions": "crucifier",
    "crucifixions": "crucifixion",
    "crucifiâmes": "crucifier",
    "crucifiât": "crucifier",
    "crucifiâtes": "crucifier",
    "crucifièrent": "crucifier",
    "crucifié": "crucifier",
    "crucifiée": "crucifier",
    "crucifiées": "crucifier",
    "crucifiés": "crucifier",
    "cruciformes": "cruciforme",
    "crucifères": "crucifère",
    "cruciverbistes": "cruciverbiste",
    "crudités": "crudité",
    "crue": "cru",
    "cruelle": "cruel",
    "cruelles": "cruel",
    "cruels": "cruel",
    "crues": "crue",
    "cruors": "cruor",
    "crurale": "crural",
    "crurales": "crural",
    "cruraux": "crural",
    "crurent": "croire",
    "crus": "cru",
    "crusse": "croire",
    "crussent": "croire",
    "crusses": "croire",
    "crussiez": "croire",
    "crussions": "croire",
    "crustacés": "crustacé",
    "crut": "croire",
    "cruzeiros": "cruzeiro",
    "cryogéniques": "cryogénique",
    "cryoscopies": "cryoscopie",
    "crypta": "crypter",
    "cryptages": "cryptage",
    "cryptai": "crypter",
    "cryptaient": "crypter",
    "cryptais": "crypter",
    "cryptait": "crypter",
    "cryptant": "crypter",
    "cryptas": "crypter",
    "cryptasse": "crypter",
    "cryptassent": "crypter",
    "cryptasses": "crypter",
    "cryptassiez": "crypter",
    "cryptassions": "crypter",
    "crypte": "crypter",
    "cryptent": "crypter",
    "cryptera": "crypter",
    "crypterai": "crypter",
    "crypteraient": "crypter",
    "crypterais": "crypter",
    "crypterait": "crypter",
    "crypteras": "crypter",
    "crypterez": "crypter",
    "crypteriez": "crypter",
    "crypterions": "crypter",
    "crypterons": "crypter",
    "crypteront": "crypter",
    "cryptes": "crypter",
    "cryptez": "crypter",
    "cryptiez": "crypter",
    "cryptions": "crypter",
    "cryptiques": "cryptique",
    "cryptocommunistes": "cryptocommuniste",
    "cryptogames": "cryptogame",
    "cryptogrammes": "cryptogramme",
    "cryptographies": "cryptographie",
    "cryptons": "crypter",
    "cryptosporidies": "cryptosporidie",
    "cryptâmes": "crypter",
    "cryptât": "crypter",
    "cryptâtes": "crypter",
    "cryptèrent": "crypter",
    "crypté": "crypter",
    "cryptée": "crypter",
    "cryptées": "crypter",
    "cryptés": "crypter",
    "crâna": "crâner",
    "crânai": "crâner",
    "crânaient": "crâner",
    "crânais": "crâner",
    "crânait": "crâner",
    "crânant": "crâner",
    "crânas": "crâner",
    "crânasse": "crâner",
    "crânassent": "crâner",
    "crânasses": "crâner",
    "crânassiez": "crâner",
    "crânassions": "crâner",
    "crâne": "crâner",
    "crânent": "crâner",
    "crânera": "crâner",
    "crânerai": "crâner",
    "crâneraient": "crâner",
    "crânerais": "crâner",
    "crânerait": "crâner",
    "crâneras": "crâner",
    "crânerez": "crâner",
    "crâneriez": "crâner",
    "crânerions": "crâner",
    "crânerons": "crâner",
    "crâneront": "crâner",
    "crânes": "crâner",
    "crâneurs": "crâneur",
    "crâneuse": "crâneur",
    "crâneuses": "crâneur",
    "crânez": "crâner",
    "crânienne": "crânien",
    "crâniennes": "crânien",
    "crâniens": "crânien",
    "crâniez": "crâner",
    "crânions": "crâner",
    "crânons": "crâner",
    "crânâmes": "crâner",
    "crânât": "crâner",
    "crânâtes": "crâner",
    "crânèrent": "crâner",
    "crâné": "crâner",
    "crânée": "crâner",
    "crânées": "crâner",
    "crânés": "crâner",
    "crèche": "crécher",
    "crèchent": "crécher",
    "crèches": "crécher",
    "crèmes": "crème",
    "crène": "créner",
    "crènent": "créner",
    "crènes": "créner",
    "crève": "crever",
    "crèvent": "crever",
    "crèvera": "crever",
    "crèverai": "crever",
    "crèveraient": "crever",
    "crèverais": "crever",
    "crèverait": "crever",
    "crèveras": "crever",
    "crèverez": "crever",
    "crèveriez": "crever",
    "crèverions": "crever",
    "crèverons": "crever",
    "crèveront": "crever",
    "crèves": "crever",
    "créa": "créer",
    "créai": "créer",
    "créaient": "créer",
    "créais": "créer",
    "créait": "créer",
    "créances": "créance",
    "créanciers": "créancier",
    "créancière": "créancier",
    "créancières": "créancier",
    "créant": "créer",
    "créas": "créer",
    "créasse": "créer",
    "créassent": "créer",
    "créasses": "créer",
    "créassiez": "créer",
    "créassions": "créer",
    "créateurs": "créateur",
    "créatifs": "créatif",
    "créations": "création",
    "créative": "créatif",
    "créatives": "créatif",
    "créativités": "créativité",
    "créatrice": "créateur",
    "créatrices": "créateur",
    "créatures": "créature",
    "crécelles": "crécelle",
    "crécerelles": "crécerelle",
    "créchaient": "crécher",
    "créchait": "crécher",
    "créchant": "crécher",
    "crédences": "crédence",
    "crédibilités": "crédibilité",
    "crédibles": "crédible",
    "crédita": "créditer",
    "créditai": "créditer",
    "créditaient": "créditer",
    "créditais": "créditer",
    "créditait": "créditer",
    "créditant": "créditer",
    "créditas": "créditer",
    "créditasse": "créditer",
    "créditassent": "créditer",
    "créditasses": "créditer",
    "créditassiez": "créditer",
    "créditassions": "créditer",
    "crédite": "créditer",
    "créditent": "créditer",
    "créditera": "créditer",
    "créditerai": "créditer",
    "créditeraient": "créditer",
    "créditerais": "créditer",
    "créditerait": "créditer",
    "créditeras": "créditer",
    "créditerez": "créditer",
    "créditeriez": "créditer",
    "créditerions": "créditer",
    "créditerons": "créditer",
    "créditeront": "créditer",
    "crédites": "créditer",
    "créditeurs": "créditeur",
    "créditez": "créditer",
    "créditiez": "créditer",
    "créditions": "créditer",
    "créditons": "créditer",
    "créditrice": "créditeur",
    "créditrices": "créditeur",
    "crédits": "crédit",
    "créditâmes": "créditer",
    "créditât": "créditer",
    "créditâtes": "créditer",
    "créditèrent": "créditer",
    "crédité": "créditer",
    "créditée": "créditer",
    "créditées": "créditer",
    "crédités": "créditer",
    "crédules": "crédule",
    "crédulités": "crédulité",
    "crée": "créer",
    "créent": "créer",
    "créera": "créer",
    "créerai": "créer",
    "créeraient": "créer",
    "créerais": "créer",
    "créerait": "créer",
    "créeras": "créer",
    "créerez": "créer",
    "créeriez": "créer",
    "créerions": "créer",
    "créerons": "créer",
    "créeront": "créer",
    "crées": "créer",
    "créez": "créer",
    "créiez": "créer",
    "créions": "créer",
    "crémaillères": "crémaillère",
    "crémants": "crémant",
    "crémateurs": "crémateur",
    "crémations": "crémation",
    "crématoires": "crématoire",
    "crémeries": "crémerie",
    "crémeuse": "crémeux",
    "crémeuses": "crémeux",
    "crémiers": "crémier",
    "crémière": "crémier",
    "crémières": "crémier",
    "crémones": "crémone",
    "crémés": "crémer",
    "créna": "créner",
    "crénai": "créner",
    "crénaient": "créner",
    "crénais": "créner",
    "crénait": "créner",
    "crénant": "créner",
    "crénas": "créner",
    "crénasse": "créner",
    "crénassent": "créner",
    "crénasses": "créner",
    "crénassiez": "créner",
    "crénassions": "créner",
    "créneaux": "créneau",
    "crénela": "créneler",
    "crénelai": "créneler",
    "crénelaient": "créneler",
    "crénelais": "créneler",
    "crénelait": "créneler",
    "crénelant": "créneler",
    "crénelas": "créneler",
    "crénelasse": "créneler",
    "crénelassent": "créneler",
    "crénelasses": "créneler",
    "crénelassiez": "créneler",
    "crénelassions": "créneler",
    "crénelez": "créneler",
    "créneliez": "créneler",
    "crénelions": "créneler",
    "crénelle": "créneler",
    "crénellent": "créneler",
    "crénellera": "créneler",
    "crénellerai": "créneler",
    "crénelleraient": "créneler",
    "crénellerais": "créneler",
    "crénellerait": "créneler",
    "crénelleras": "créneler",
    "crénellerez": "créneler",
    "crénelleriez": "créneler",
    "crénellerions": "créneler",
    "crénellerons": "créneler",
    "crénelleront": "créneler",
    "crénelles": "créneler",
    "crénelons": "créneler",
    "crénelâmes": "créneler",
    "crénelât": "créneler",
    "crénelâtes": "créneler",
    "crénelèrent": "créneler",
    "crénelé": "créneler",
    "crénelée": "créneler",
    "crénelées": "créneler",
    "crénelés": "créneler",
    "crénera": "créner",
    "crénerai": "créner",
    "créneraient": "créner",
    "crénerais": "créner",
    "crénerait": "créner",
    "créneras": "créner",
    "crénerez": "créner",
    "créneriez": "créner",
    "crénerions": "créner",
    "crénerons": "créner",
    "créneront": "créner",
    "crénez": "créner",
    "créniez": "créner",
    "crénions": "créner",
    "crénons": "créner",
    "crénâmes": "créner",
    "crénât": "créner",
    "crénâtes": "créner",
    "crénèrent": "créner",
    "créné": "créner",
    "crénée": "créner",
    "crénées": "créner",
    "crénés": "créner",
    "créoles": "créole",
    "créons": "créer",
    "créosotes": "créosote",
    "créosotée": "créosoter",
    "crépi": "crépir",
    "crépie": "crépir",
    "crépies": "crépir",
    "crépines": "crépine",
    "crépinettes": "crépinette",
    "crépins": "crépin",
    "crépira": "crépir",
    "crépirai": "crépir",
    "crépiraient": "crépir",
    "crépirais": "crépir",
    "crépirait": "crépir",
    "crépiras": "crépir",
    "crépirent": "crépir",
    "crépirez": "crépir",
    "crépiriez": "crépir",
    "crépirions": "crépir",
    "crépirons": "crépir",
    "crépiront": "crépir",
    "crépis": "crépir",
    "crépissaient": "crépir",
    "crépissais": "crépir",
    "crépissait": "crépir",
    "crépissant": "crépir",
    "crépisse": "crépir",
    "crépissent": "crépir",
    "crépisses": "crépir",
    "crépissez": "crépir",
    "crépissiez": "crépir",
    "crépissions": "crépir",
    "crépissons": "crépir",
    "crépit": "crépir",
    "crépita": "crépiter",
    "crépitai": "crépiter",
    "crépitaient": "crépiter",
    "crépitais": "crépiter",
    "crépitait": "crépiter",
    "crépitant": "crépiter",
    "crépitante": "crépitant",
    "crépitantes": "crépitant",
    "crépitants": "crépitant",
    "crépitas": "crépiter",
    "crépitasse": "crépiter",
    "crépitassent": "crépiter",
    "crépitasses": "crépiter",
    "crépitassiez": "crépiter",
    "crépitassions": "crépiter",
    "crépite": "crépiter",
    "crépitements": "crépitement",
    "crépitent": "crépiter",
    "crépitera": "crépiter",
    "crépiterai": "crépiter",
    "crépiteraient": "crépiter",
    "crépiterais": "crépiter",
    "crépiterait": "crépiter",
    "crépiteras": "crépiter",
    "crépiterez": "crépiter",
    "crépiteriez": "crépiter",
    "crépiterions": "crépiter",
    "crépiterons": "crépiter",
    "crépiteront": "crépiter",
    "crépites": "crépiter",
    "crépitez": "crépiter",
    "crépitiez": "crépiter",
    "crépitions": "crépiter",
    "crépitons": "crépiter",
    "crépitâmes": "crépiter",
    "crépitât": "crépiter",
    "crépitâtes": "crépiter",
    "crépitèrent": "crépiter",
    "crépité": "crépiter",
    "crépons": "crépon",
    "crépue": "crépu",
    "crépues": "crépu",
    "crépus": "crépu",
    "crépusculaires": "crépusculaire",
    "crépuscules": "crépuscule",
    "crépîmes": "crépir",
    "crépît": "crépir",
    "crépîtes": "crépir",
    "crésylée": "crésylé",
    "crétacée": "crétacé",
    "crétacées": "crétacé",
    "crétacés": "crétacé",
    "crétine": "crétin",
    "crétineries": "crétinerie",
    "crétines": "crétin",
    "crétinismes": "crétinisme",
    "crétinisé": "crétiniser",
    "crétins": "crétin",
    "crétoise": "crétois",
    "crétoises": "crétois",
    "créâmes": "créer",
    "créât": "créer",
    "créâtes": "créer",
    "créèrent": "créer",
    "créé": "créer",
    "créée": "créer",
    "créées": "créer",
    "créés": "créer",
    "crêpa": "crêper",
    "crêpages": "crêpage",
    "crêpai": "crêper",
    "crêpaient": "crêper",
    "crêpais": "crêper",
    "crêpait": "crêper",
    "crêpant": "crêper",
    "crêpas": "crêper",
    "crêpasse": "crêper",
    "crêpassent": "crêper",
    "crêpasses": "crêper",
    "crêpassiez": "crêper",
    "crêpassions": "crêper",
    "crêpe": "crêper",
    "crêpelait": "crêpeler",
    "crêpelées": "crêpelé",
    "crêpelés": "crêpelé",
    "crêpent": "crêper",
    "crêpera": "crêper",
    "crêperai": "crêper",
    "crêperaient": "crêper",
    "crêperais": "crêper",
    "crêperait": "crêper",
    "crêperas": "crêper",
    "crêperez": "crêper",
    "crêperies": "crêperie",
    "crêperiez": "crêper",
    "crêperions": "crêper",
    "crêperons": "crêper",
    "crêperont": "crêper",
    "crêpes": "crêper",
    "crêpez": "crêper",
    "crêpiez": "crêper",
    "crêpions": "crêper",
    "crêpons": "crêper",
    "crêpâmes": "crêper",
    "crêpât": "crêper",
    "crêpâtes": "crêper",
    "crêpèrent": "crêper",
    "crêpé": "crêper",
    "crêpée": "crêper",
    "crêpées": "crêper",
    "crêpés": "crêper",
    "crêtaient": "crêter",
    "crêtes": "crête",
    "crêtes-de-coq": "crête-de-coq",
    "crêtions": "crêter",
    "crêté": "crêter",
    "crêtée": "crêter",
    "crêtées": "crêter",
    "crêtés": "crêter",
    "crû": "croître",
    "crûmes": "croître",
    "crûrent": "croître",
    "crûs": "croître",
    "crûsse": "croître",
    "crûssent": "croître",
    "crûsses": "croître",
    "crûssiez": "croître",
    "crûssions": "croître",
    "crût": "croître",
    "crûtes": "croître",
    "cuadrillas": "cuadrilla",
    "cubages": "cubage",
    "cubaine": "cubain",
    "cubaines": "cubain",
    "cubains": "cubain",
    "cubait": "cuber",
    "cubasse": "cuber",
    "cube": "cuber",
    "cubes": "cuber",
    "cubiques": "cubique",
    "cubismes": "cubisme",
    "cubistes": "cubiste",
    "cubitale": "cubital",
    "cubitales": "cubital",
    "cubitaux": "cubital",
    "cubitières": "cubitière",
    "cucurbites": "cucurbite",
    "cueillaient": "cueillir",
    "cueillais": "cueillir",
    "cueillait": "cueillir",
    "cueillant": "cueillir",
    "cueille": "cueillir",
    "cueillent": "cueillir",
    "cueillera": "cueillir",
    "cueillerai": "cueillir",
    "cueilleraient": "cueillir",
    "cueillerais": "cueillir",
    "cueillerait": "cueillir",
    "cueilleras": "cueillir",
    "cueillerez": "cueillir",
    "cueilleriez": "cueillir",
    "cueillerions": "cueillir",
    "cueillerons": "cueillir",
    "cueilleront": "cueillir",
    "cueilles": "cueillir",
    "cueillettes": "cueillette",
    "cueilleurs": "cueilleur",
    "cueilleuse": "cueilleur",
    "cueilleuses": "cueilleur",
    "cueillez": "cueillir",
    "cueilli": "cueillir",
    "cueillie": "cueillir",
    "cueillies": "cueillir",
    "cueilliez": "cueillir",
    "cueillions": "cueillir",
    "cueillirent": "cueillir",
    "cueillis": "cueillir",
    "cueillisse": "cueillir",
    "cueillissent": "cueillir",
    "cueillisses": "cueillir",
    "cueillissiez": "cueillir",
    "cueillissions": "cueillir",
    "cueillit": "cueillir",
    "cueillons": "cueillir",
    "cueillîmes": "cueillir",
    "cueillît": "cueillir",
    "cueillîtes": "cueillir",
    "cuevas": "cueva",
    "cuillerons": "cuilleron",
    "cuillers": "cuiller",
    "cuillerées": "cuillerée",
    "cuillères": "cuillère",
    "cuira": "cuire",
    "cuirai": "cuire",
    "cuiraient": "cuire",
    "cuirais": "cuire",
    "cuirait": "cuire",
    "cuiras": "cuire",
    "cuirassaient": "cuirasser",
    "cuirassait": "cuirasser",
    "cuirasse": "cuirasser",
    "cuirassements": "cuirassement",
    "cuirassent": "cuirasser",
    "cuirasses": "cuirasse",
    "cuirassiers": "cuirassier",
    "cuirassé": "cuirasser",
    "cuirassée": "cuirasser",
    "cuirassées": "cuirasser",
    "cuirassés": "cuirasser",
    "cuirez": "cuire",
    "cuiriez": "cuire",
    "cuirions": "cuire",
    "cuirons": "cuire",
    "cuiront": "cuire",
    "cuirs": "cuir",
    "cuis": "cuire",
    "cuisaient": "cuire",
    "cuisais": "cuire",
    "cuisait": "cuire",
    "cuisant": "cuire",
    "cuisante": "cuisant",
    "cuisantes": "cuisant",
    "cuisants": "cuisant",
    "cuise": "cuire",
    "cuisent": "cuire",
    "cuises": "cuire",
    "cuiseurs": "cuiseur",
    "cuisez": "cuire",
    "cuisiez": "cuire",
    "cuisina": "cuisiner",
    "cuisinai": "cuisiner",
    "cuisinaient": "cuisiner",
    "cuisinais": "cuisiner",
    "cuisinait": "cuisiner",
    "cuisinant": "cuisiner",
    "cuisinas": "cuisiner",
    "cuisinasse": "cuisiner",
    "cuisinassent": "cuisiner",
    "cuisinasses": "cuisiner",
    "cuisinassiez": "cuisiner",
    "cuisinassions": "cuisiner",
    "cuisine": "cuisiner",
    "cuisinent": "cuisiner",
    "cuisinera": "cuisiner",
    "cuisinerai": "cuisiner",
    "cuisineraient": "cuisiner",
    "cuisinerais": "cuisiner",
    "cuisinerait": "cuisiner",
    "cuisineras": "cuisiner",
    "cuisinerez": "cuisiner",
    "cuisineriez": "cuisiner",
    "cuisinerions": "cuisiner",
    "cuisinerons": "cuisiner",
    "cuisineront": "cuisiner",
    "cuisines": "cuisiner",
    "cuisinez": "cuisiner",
    "cuisiniers": "cuisinier",
    "cuisiniez": "cuisiner",
    "cuisinions": "cuisiner",
    "cuisinière": "cuisinier",
    "cuisinières": "cuisinier",
    "cuisinons": "cuisiner",
    "cuisinâmes": "cuisiner",
    "cuisinât": "cuisiner",
    "cuisinâtes": "cuisiner",
    "cuisinèrent": "cuisiner",
    "cuisiné": "cuisiner",
    "cuisinée": "cuisiner",
    "cuisinées": "cuisiner",
    "cuisinés": "cuisiner",
    "cuisions": "cuire",
    "cuisirent": "cuire",
    "cuisis": "cuire",
    "cuisisse": "cuire",
    "cuisissent": "cuire",
    "cuisisses": "cuire",
    "cuisissiez": "cuire",
    "cuisissions": "cuire",
    "cuisit": "cuire",
    "cuisons": "cuire",
    "cuissardes": "cuissarde",
    "cuissards": "cuissard",
    "cuisseaux": "cuisseau",
    "cuisses": "cuisse",
    "cuissettes": "cuissette",
    "cuissons": "cuisson",
    "cuissots": "cuissot",
    "cuistances": "cuistance",
    "cuistots": "cuistot",
    "cuistreries": "cuistrerie",
    "cuistres": "cuistre",
    "cuisîmes": "cuire",
    "cuisît": "cuire",
    "cuisîtes": "cuire",
    "cuit": "cuire",
    "cuitant": "cuiter",
    "cuite": "cuit",
    "cuites": "cuite",
    "cuits": "cuit",
    "cuité": "cuiter",
    "cuivra": "cuivrer",
    "cuivrai": "cuivrer",
    "cuivraient": "cuivrer",
    "cuivrais": "cuivrer",
    "cuivrait": "cuivrer",
    "cuivrant": "cuivrer",
    "cuivras": "cuivrer",
    "cuivrasse": "cuivrer",
    "cuivrassent": "cuivrer",
    "cuivrasses": "cuivrer",
    "cuivrassiez": "cuivrer",
    "cuivrassions": "cuivrer",
    "cuivre": "cuivrer",
    "cuivrent": "cuivrer",
    "cuivrera": "cuivrer",
    "cuivrerai": "cuivrer",
    "cuivreraient": "cuivrer",
    "cuivrerais": "cuivrer",
    "cuivrerait": "cuivrer",
    "cuivreras": "cuivrer",
    "cuivrerez": "cuivrer",
    "cuivreriez": "cuivrer",
    "cuivrerions": "cuivrer",
    "cuivrerons": "cuivrer",
    "cuivreront": "cuivrer",
    "cuivres": "cuivrer",
    "cuivrez": "cuivrer",
    "cuivriez": "cuivrer",
    "cuivrions": "cuivrer",
    "cuivrons": "cuivrer",
    "cuivrâmes": "cuivrer",
    "cuivrât": "cuivrer",
    "cuivrâtes": "cuivrer",
    "cuivrèrent": "cuivrer",
    "cuivré": "cuivrer",
    "cuivrée": "cuivrer",
    "cuivrées": "cuivrer",
    "cuivrés": "cuivrer",
    "culasses": "culasse",
    "culbuta": "culbuter",
    "culbutages": "culbutage",
    "culbutai": "culbuter",
    "culbutaient": "culbuter",
    "culbutais": "culbuter",
    "culbutait": "culbuter",
    "culbutant": "culbuter",
    "culbutas": "culbuter",
    "culbutasse": "culbuter",
    "culbutassent": "culbuter",
    "culbutasses": "culbuter",
    "culbutassiez": "culbuter",
    "culbutassions": "culbuter",
    "culbute": "culbuter",
    "culbutent": "culbuter",
    "culbutera": "culbuter",
    "culbuterai": "culbuter",
    "culbuteraient": "culbuter",
    "culbuterais": "culbuter",
    "culbuterait": "culbuter",
    "culbuteras": "culbuter",
    "culbuterez": "culbuter",
    "culbuteriez": "culbuter",
    "culbuterions": "culbuter",
    "culbuterons": "culbuter",
    "culbuteront": "culbuter",
    "culbutes": "culbuter",
    "culbuteurs": "culbuteur",
    "culbutez": "culbuter",
    "culbutiez": "culbuter",
    "culbutions": "culbuter",
    "culbutons": "culbuter",
    "culbutâmes": "culbuter",
    "culbutât": "culbuter",
    "culbutâtes": "culbuter",
    "culbutèrent": "culbuter",
    "culbuté": "culbuter",
    "culbutée": "culbuter",
    "culbutées": "culbuter",
    "culbutés": "culbuter",
    "cule": "culer",
    "culinaires": "culinaire",
    "culmina": "culminer",
    "culminai": "culminer",
    "culminaient": "culminer",
    "culminais": "culminer",
    "culminait": "culminer",
    "culminant": "culminer",
    "culminants": "culminant",
    "culminas": "culminer",
    "culminasse": "culminer",
    "culminassent": "culminer",
    "culminasses": "culminer",
    "culminassiez": "culminer",
    "culminassions": "culminer",
    "culmine": "culminer",
    "culminent": "culminer",
    "culminera": "culminer",
    "culminerai": "culminer",
    "culmineraient": "culminer",
    "culminerais": "culminer",
    "culminerait": "culminer",
    "culmineras": "culminer",
    "culminerez": "culminer",
    "culmineriez": "culminer",
    "culminerions": "culminer",
    "culminerons": "culminer",
    "culmineront": "culminer",
    "culmines": "culminer",
    "culminez": "culminer",
    "culminiez": "culminer",
    "culminions": "culminer",
    "culminons": "culminer",
    "culminâmes": "culminer",
    "culminât": "culminer",
    "culminâtes": "culminer",
    "culminèrent": "culminer",
    "culminé": "culminer",
    "culons": "culer",
    "culots": "culot",
    "culotta": "culotter",
    "culottai": "culotter",
    "culottaient": "culotter",
    "culottais": "culotter",
    "culottait": "culotter",
    "culottant": "culotter",
    "culottas": "culotter",
    "culottasse": "culotter",
    "culottassent": "culotter",
    "culottasses": "culotter",
    "culottassiez": "culotter",
    "culottassions": "culotter",
    "culotte": "culotter",
    "culottent": "culotter",
    "culottera": "culotter",
    "culotterai": "culotter",
    "culotteraient": "culotter",
    "culotterais": "culotter",
    "culotterait": "culotter",
    "culotteras": "culotter",
    "culotterez": "culotter",
    "culotteriez": "culotter",
    "culotterions": "culotter",
    "culotterons": "culotter",
    "culotteront": "culotter",
    "culottes": "culotter",
    "culottez": "culotter",
    "culottiers": "culottier",
    "culottiez": "culotter",
    "culottions": "culotter",
    "culottière": "culottier",
    "culottières": "culottier",
    "culottons": "culotter",
    "culottâmes": "culotter",
    "culottât": "culotter",
    "culottâtes": "culotter",
    "culottèrent": "culotter",
    "culotté": "culotter",
    "culottée": "culotter",
    "culottées": "culotter",
    "culottés": "culotter",
    "culpabilisa": "culpabiliser",
    "culpabilisai": "culpabiliser",
    "culpabilisaient": "culpabiliser",
    "culpabilisais": "culpabiliser",
    "culpabilisait": "culpabiliser",
    "culpabilisant": "culpabiliser",
    "culpabilisas": "culpabiliser",
    "culpabilisasse": "culpabiliser",
    "culpabilisassent": "culpabiliser",
    "culpabilisasses": "culpabiliser",
    "culpabilisassiez": "culpabiliser",
    "culpabilisassions": "culpabiliser",
    "culpabilise": "culpabiliser",
    "culpabilisent": "culpabiliser",
    "culpabilisera": "culpabiliser",
    "culpabiliserai": "culpabiliser",
    "culpabiliseraient": "culpabiliser",
    "culpabiliserais": "culpabiliser",
    "culpabiliserait": "culpabiliser",
    "culpabiliseras": "culpabiliser",
    "culpabiliserez": "culpabiliser",
    "culpabiliseriez": "culpabiliser",
    "culpabiliserions": "culpabiliser",
    "culpabiliserons": "culpabiliser",
    "culpabiliseront": "culpabiliser",
    "culpabilises": "culpabiliser",
    "culpabilisez": "culpabiliser",
    "culpabilisiez": "culpabiliser",
    "culpabilisions": "culpabiliser",
    "culpabilisons": "culpabiliser",
    "culpabilisâmes": "culpabiliser",
    "culpabilisât": "culpabiliser",
    "culpabilisâtes": "culpabiliser",
    "culpabilisèrent": "culpabiliser",
    "culpabilisé": "culpabiliser",
    "culpabilisée": "culpabiliser",
    "culpabilisées": "culpabiliser",
    "culpabilisés": "culpabiliser",
    "culpabilités": "culpabilité",
    "culs": "cul",
    "culs-blancs": "cul-blanc",
    "culs-bénits": "cul-bénit",
    "culs-de-basse-fosse": "cul-de-basse-fosse",
    "culs-de-jatte": "cul-de-jatte",
    "culs-de-lampe": "cul-de-lampe",
    "culs-de-sac": "cul-de-sac",
    "culs-terreux": "cul-terreux",
    "cultes": "culte",
    "cultiva": "cultiver",
    "cultivables": "cultivable",
    "cultivai": "cultiver",
    "cultivaient": "cultiver",
    "cultivais": "cultiver",
    "cultivait": "cultiver",
    "cultivant": "cultiver",
    "cultivas": "cultiver",
    "cultivasse": "cultiver",
    "cultivassent": "cultiver",
    "cultivasses": "cultiver",
    "cultivassiez": "cultiver",
    "cultivassions": "cultiver",
    "cultivateurs": "cultivateur",
    "cultivatrice": "cultivateur",
    "cultivatrices": "cultivateur",
    "cultive": "cultiver",
    "cultivent": "cultiver",
    "cultivera": "cultiver",
    "cultiverai": "cultiver",
    "cultiveraient": "cultiver",
    "cultiverais": "cultiver",
    "cultiverait": "cultiver",
    "cultiveras": "cultiver",
    "cultiverez": "cultiver",
    "cultiveriez": "cultiver",
    "cultiverions": "cultiver",
    "cultiverons": "cultiver",
    "cultiveront": "cultiver",
    "cultives": "cultiver",
    "cultivez": "cultiver",
    "cultiviez": "cultiver",
    "cultivions": "cultiver",
    "cultivons": "cultiver",
    "cultivâmes": "cultiver",
    "cultivât": "cultiver",
    "cultivâtes": "cultiver",
    "cultivèrent": "cultiver",
    "cultivé": "cultiver",
    "cultivée": "cultiver",
    "cultivées": "cultiver",
    "cultivés": "cultiver",
    "culturalismes": "culturalisme",
    "culturelle": "culturel",
    "culturelles": "culturel",
    "culturels": "culturel",
    "cultures": "culture",
    "culturistes": "culturiste",
    "culé": "culer",
    "cumins": "cumin",
    "cumula": "cumuler",
    "cumulai": "cumuler",
    "cumulaient": "cumuler",
    "cumulais": "cumuler",
    "cumulait": "cumuler",
    "cumulant": "cumuler",
    "cumulas": "cumuler",
    "cumulasse": "cumuler",
    "cumulassent": "cumuler",
    "cumulasses": "cumuler",
    "cumulassiez": "cumuler",
    "cumulassions": "cumuler",
    "cumulatifs": "cumulatif",
    "cumulative": "cumulatif",
    "cumulatives": "cumulatif",
    "cumule": "cumuler",
    "cumulent": "cumuler",
    "cumulera": "cumuler",
    "cumulerai": "cumuler",
    "cumuleraient": "cumuler",
    "cumulerais": "cumuler",
    "cumulerait": "cumuler",
    "cumuleras": "cumuler",
    "cumulerez": "cumuler",
    "cumuleriez": "cumuler",
    "cumulerions": "cumuler",
    "cumulerons": "cumuler",
    "cumuleront": "cumuler",
    "cumules": "cumuler",
    "cumulez": "cumuler",
    "cumuliez": "cumuler",
    "cumulions": "cumuler",
    "cumulons": "cumuler",
    "cumuls": "cumul",
    "cumulâmes": "cumuler",
    "cumulât": "cumuler",
    "cumulâtes": "cumuler",
    "cumulèrent": "cumuler",
    "cumulé": "cumuler",
    "cumulée": "cumuler",
    "cumulées": "cumuler",
    "cumulés": "cumuler",
    "cunéiformes": "cunéiforme",
    "cupides": "cupide",
    "cupidités": "cupidité",
    "cupidons": "cupidon",
    "cuprifères": "cuprifère",
    "cupriques": "cuprique",
    "cupules": "cupule",
    "cura": "curer",
    "curables": "curable",
    "curai": "curer",
    "curaient": "curer",
    "curais": "curer",
    "curait": "curer",
    "curant": "curer",
    "curares": "curare",
    "curas": "curer",
    "curasse": "curer",
    "curassent": "curer",
    "curasses": "curer",
    "curassiez": "curer",
    "curassions": "curer",
    "curatelles": "curatelle",
    "curateurs": "curateur",
    "curatifs": "curatif",
    "curative": "curatif",
    "curatives": "curatif",
    "curatrice": "curateur",
    "curatrices": "curateur",
    "curaçaos": "curaçao",
    "cure": "curer",
    "cure-dents": "cure-dent",
    "cure-oreilles": "cure-oreille",
    "cure-pipes": "cure-pipe",
    "curent": "curer",
    "curera": "curer",
    "curerai": "curer",
    "cureraient": "curer",
    "curerais": "curer",
    "curerait": "curer",
    "cureras": "curer",
    "curerez": "curer",
    "cureriez": "curer",
    "curerions": "curer",
    "curerons": "curer",
    "cureront": "curer",
    "cures": "curer",
    "cureta": "cureter",
    "curetai": "cureter",
    "curetaient": "cureter",
    "curetais": "cureter",
    "curetait": "cureter",
    "curetant": "cureter",
    "curetas": "cureter",
    "curetasse": "cureter",
    "curetassent": "cureter",
    "curetasses": "cureter",
    "curetassiez": "cureter",
    "curetassions": "cureter",
    "curetez": "cureter",
    "curetiez": "cureter",
    "curetions": "cureter",
    "curetons": "cureton",
    "curette": "cureter",
    "curettent": "cureter",
    "curettera": "cureter",
    "curetterai": "cureter",
    "curetteraient": "cureter",
    "curetterais": "cureter",
    "curetterait": "cureter",
    "curetteras": "cureter",
    "curetterez": "cureter",
    "curetteriez": "cureter",
    "curetterions": "cureter",
    "curetterons": "cureter",
    "curetteront": "cureter",
    "curettes": "curette",
    "curetâmes": "cureter",
    "curetât": "cureter",
    "curetâtes": "cureter",
    "curetèrent": "cureter",
    "cureté": "cureter",
    "curetée": "cureter",
    "curetées": "cureter",
    "curetés": "cureter",
    "curez": "curer",
    "curiales": "curial",
    "curies": "curie",
    "curieuse": "curieux",
    "curieuses": "curieux",
    "curiez": "curer",
    "curions": "curer",
    "curiosités": "curiosité",
    "curistes": "curiste",
    "curlings": "curling",
    "curons": "curer",
    "curricula": "curriculum",
    "curriculums": "curriculum",
    "currys": "curry",
    "curseurs": "curseur",
    "cursifs": "cursif",
    "cursive": "cursif",
    "cursives": "cursif",
    "curvilignes": "curviligne",
    "curvimètres": "curvimètre",
    "curâmes": "curer",
    "curât": "curer",
    "curâtes": "curer",
    "curèrent": "curer",
    "curé": "curer",
    "curée": "curer",
    "curées": "curer",
    "curés": "curer",
    "cuscutes": "cuscute",
    "custodes": "custode",
    "customisé": "customiser",
    "cut-backs": "cut-back",
    "cutanée": "cutané",
    "cutanées": "cutané",
    "cutanés": "cutané",
    "cuti-réactions": "cuti-réaction",
    "cuticules": "cuticule",
    "cutines": "cutine",
    "cutis": "cuti",
    "cutters": "cutter",
    "cuva": "cuver",
    "cuvai": "cuver",
    "cuvaient": "cuver",
    "cuvais": "cuver",
    "cuvait": "cuver",
    "cuvant": "cuver",
    "cuvas": "cuver",
    "cuvasse": "cuver",
    "cuvassent": "cuver",
    "cuvasses": "cuver",
    "cuvassiez": "cuver",
    "cuvassions": "cuver",
    "cuve": "cuver",
    "cuveaux": "cuveau",
    "cuvent": "cuver",
    "cuvera": "cuver",
    "cuverai": "cuver",
    "cuveraient": "cuver",
    "cuverais": "cuver",
    "cuverait": "cuver",
    "cuveras": "cuver",
    "cuverez": "cuver",
    "cuveriez": "cuver",
    "cuverions": "cuver",
    "cuverons": "cuver",
    "cuveront": "cuver",
    "cuves": "cuver",
    "cuvettes": "cuvette",
    "cuvez": "cuver",
    "cuviers": "cuvier",
    "cuviez": "cuver",
    "cuvions": "cuver",
    "cuvons": "cuver",
    "cuvâmes": "cuver",
    "cuvât": "cuver",
    "cuvâtes": "cuver",
    "cuvèrent": "cuver",
    "cuvé": "cuver",
    "cuvée": "cuver",
    "cuvées": "cuver",
    "cuvés": "cuver",
    "cyanhydriques": "cyanhydrique",
    "cyanogènes": "cyanogène",
    "cyanoses": "cyanose",
    "cyanosé": "cyanoser",
    "cyanosée": "cyanoser",
    "cyanures": "cyanure",
    "cybernautes": "cybernaute",
    "cybernétiques": "cybernétique",
    "cyclables": "cyclable",
    "cyclamens": "cyclamen",
    "cycles": "cycle",
    "cycliques": "cyclique",
    "cyclismes": "cyclisme",
    "cyclistes": "cycliste",
    "cyclomoteurs": "cyclomoteur",
    "cyclones": "cyclone",
    "cyclopes": "cyclope",
    "cyclopousses": "cyclopousse",
    "cyclopéenne": "cyclopéen",
    "cyclopéennes": "cyclopéen",
    "cyclopéens": "cyclopéen",
    "cyclostomes": "cyclostome",
    "cyclothymies": "cyclothymie",
    "cyclothymiques": "cyclothymique",
    "cyclotrons": "cyclotron",
    "cyclées": "cycler",
    "cygnes": "cygne",
    "cylindre": "cylindrer",
    "cylindres": "cylindrer",
    "cylindriques": "cylindrique",
    "cylindré": "cylindrer",
    "cylindrées": "cylindrée",
    "cylindrés": "cylindrer",
    "cymbales": "cymbale",
    "cymbalistes": "cymbaliste",
    "cymbalums": "cymbalum",
    "cymes": "cyme",
    "cyniques": "cynique",
    "cynismes": "cynisme",
    "cynocéphales": "cynocéphale",
    "cynodromes": "cynodrome",
    "cynos": "cyno",
    "cynégétiques": "cynégétique",
    "cyprinicoles": "cyprinicole",
    "cyprinidés": "cyprinidé",
    "cyprins": "cyprin",
    "cypriotes": "cypriote",
    "cyrards": "cyrard",
    "cyrilliques": "cyrillique",
    "cystites": "cystite",
    "cytises": "cytise",
    "cytologies": "cytologie",
    "cytologiques": "cytologique",
    "cytologistes": "cytologiste",
    "czars": "czar",
    "câbla": "câbler",
    "câblages": "câblage",
    "câblai": "câbler",
    "câblaient": "câbler",
    "câblais": "câbler",
    "câblait": "câbler",
    "câblant": "câbler",
    "câblas": "câbler",
    "câblasse": "câbler",
    "câblassent": "câbler",
    "câblasses": "câbler",
    "câblassiez": "câbler",
    "câblassions": "câbler",
    "câble": "câbler",
    "câbleaux": "câbleau",
    "câblent": "câbler",
    "câblera": "câbler",
    "câblerai": "câbler",
    "câbleraient": "câbler",
    "câblerais": "câbler",
    "câblerait": "câbler",
    "câbleras": "câbler",
    "câblerez": "câbler",
    "câbleriez": "câbler",
    "câblerions": "câbler",
    "câblerons": "câbler",
    "câbleront": "câbler",
    "câbles": "câbler",
    "câbleurs": "câbleur",
    "câblez": "câbler",
    "câbliez": "câbler",
    "câblions": "câbler",
    "câblons": "câbler",
    "câblots": "câblot",
    "câblâmes": "câbler",
    "câblât": "câbler",
    "câblâtes": "câbler",
    "câblèrent": "câbler",
    "câblé": "câbler",
    "câblée": "câbler",
    "câblées": "câbler",
    "câblés": "câbler",
    "câlina": "câliner",
    "câlinai": "câliner",
    "câlinaient": "câliner",
    "câlinais": "câliner",
    "câlinait": "câliner",
    "câlinant": "câliner",
    "câlinas": "câliner",
    "câlinasse": "câliner",
    "câlinassent": "câliner",
    "câlinasses": "câliner",
    "câlinassiez": "câliner",
    "câlinassions": "câliner",
    "câline": "câliner",
    "câlinent": "câliner",
    "câlinera": "câliner",
    "câlinerai": "câliner",
    "câlineraient": "câliner",
    "câlinerais": "câliner",
    "câlinerait": "câliner",
    "câlineras": "câliner",
    "câlinerez": "câliner",
    "câlineries": "câlinerie",
    "câlineriez": "câliner",
    "câlinerions": "câliner",
    "câlinerons": "câliner",
    "câlineront": "câliner",
    "câlines": "câliner",
    "câlinez": "câliner",
    "câliniez": "câliner",
    "câlinions": "câliner",
    "câlinons": "câliner",
    "câlins": "câlin",
    "câlinâmes": "câliner",
    "câlinât": "câliner",
    "câlinâtes": "câliner",
    "câlinèrent": "câliner",
    "câliné": "câliner",
    "câlinée": "câliner",
    "câlinées": "câliner",
    "câlinés": "câliner",
    "câpres": "câpre",
    "câpriers": "câprier",
    "cède": "céder",
    "cèdent": "céder",
    "cèdes": "céder",
    "cèdres": "cèdre",
    "cèdules": "cèdule",
    "cèle": "celer",
    "cèlent": "celer",
    "cèlera": "celer",
    "cèlerai": "celer",
    "cèleraient": "celer",
    "cèlerais": "celer",
    "cèlerait": "celer",
    "cèleras": "celer",
    "cèlerez": "celer",
    "cèleriez": "celer",
    "cèlerions": "celer",
    "cèlerons": "celer",
    "cèleront": "celer",
    "cèles": "celer",
    "cènes": "cène",
    "cèpes": "cèpe",
    "cécidomyies": "cécidomyie",
    "cécités": "cécité",
    "céda": "céder",
    "cédai": "céder",
    "cédaient": "céder",
    "cédais": "céder",
    "cédait": "céder",
    "cédant": "céder",
    "cédas": "céder",
    "cédasse": "céder",
    "cédassent": "céder",
    "cédasses": "céder",
    "cédassiez": "céder",
    "cédassions": "céder",
    "cédera": "céder",
    "céderai": "céder",
    "céderaient": "céder",
    "céderais": "céder",
    "céderait": "céder",
    "céderas": "céder",
    "céderez": "céder",
    "céderiez": "céder",
    "céderions": "céder",
    "céderons": "céder",
    "céderont": "céder",
    "cédez": "céder",
    "cédiez": "céder",
    "cédilles": "cédille",
    "cédions": "céder",
    "cédons": "céder",
    "cédrats": "cédrat",
    "cédâmes": "céder",
    "cédât": "céder",
    "cédâtes": "céder",
    "cédèrent": "céder",
    "cédé": "céder",
    "cédée": "céder",
    "cédées": "céder",
    "cédés": "céder",
    "cédétistes": "cédétiste",
    "cégétistes": "cégétiste",
    "céladons": "céladon",
    "céleris": "céleri",
    "célestes": "céleste",
    "célestins": "célestin",
    "célibataires": "célibataire",
    "célibats": "célibat",
    "célinienne": "célinien",
    "célèbre": "célébrer",
    "célèbrent": "célébrer",
    "célèbres": "célébrer",
    "célébra": "célébrer",
    "célébrai": "célébrer",
    "célébraient": "célébrer",
    "célébrais": "célébrer",
    "célébrait": "célébrer",
    "célébrant": "célébrer",
    "célébrants": "célébrant",
    "célébras": "célébrer",
    "célébrasse": "célébrer",
    "célébrassent": "célébrer",
    "célébrasses": "célébrer",
    "célébrassiez": "célébrer",
    "célébrassions": "célébrer",
    "célébrations": "célébration",
    "célébrera": "célébrer",
    "célébrerai": "célébrer",
    "célébreraient": "célébrer",
    "célébrerais": "célébrer",
    "célébrerait": "célébrer",
    "célébreras": "célébrer",
    "célébrerez": "célébrer",
    "célébreriez": "célébrer",
    "célébrerions": "célébrer",
    "célébrerons": "célébrer",
    "célébreront": "célébrer",
    "célébrez": "célébrer",
    "célébriez": "célébrer",
    "célébrions": "célébrer",
    "célébrités": "célébrité",
    "célébrons": "célébrer",
    "célébrâmes": "célébrer",
    "célébrât": "célébrer",
    "célébrâtes": "célébrer",
    "célébrèrent": "célébrer",
    "célébré": "célébrer",
    "célébrée": "célébrer",
    "célébrées": "célébrer",
    "célébrés": "célébrer",
    "célérités": "célérité",
    "céments": "cément",
    "cénacles": "cénacle",
    "cénobites": "cénobite",
    "cénotaphes": "cénotaphe",
    "cépages": "cépage",
    "céphalopodes": "céphalopode",
    "céphalée": "céphalé",
    "céphalées": "céphalée",
    "cépées": "cépée",
    "cérames": "cérame",
    "céramiques": "céramique",
    "cérats": "cérat",
    "cériums": "cérium",
    "céruléenne": "céruléen",
    "céruléennes": "céruléen",
    "céruléens": "céruléen",
    "cérumens": "cérumen",
    "céruses": "céruse",
    "céréales": "céréale",
    "céréaliers": "céréalier",
    "céréalière": "céréalier",
    "céréalières": "céréalier",
    "cérébelleuse": "cérébelleux",
    "cérébelleuses": "cérébelleux",
    "cérébrale": "cérébral",
    "cérébrales": "cérébral",
    "cérébraux": "cérébral",
    "cérébro-spinale": "cérébro-spinal",
    "cérébro-spinales": "cérébro-spinal",
    "cérébro-spinaux": "cérébro-spinal",
    "cérémoniaires": "cérémoniaire",
    "cérémoniale": "cérémonial",
    "cérémonials": "cérémonial",
    "cérémonielle": "cérémoniel",
    "cérémoniels": "cérémoniel",
    "cérémonies": "cérémonie",
    "cérémonieuse": "cérémonieux",
    "cérémonieuses": "cérémonieux",
    "césariennes": "césarienne",
    "césariens": "césarien",
    "césars": "césar",
    "césures": "césure",
    "cétacés": "cétacé",
    "cétoines": "cétoine",
    "côlons": "côlon",
    "cônes": "cône",
    "côtelettes": "côtelette",
    "côtelée": "côtelé",
    "côtelées": "côtelé",
    "côtelés": "côtelé",
    "côtes": "côte",
    "côtiers": "côtier",
    "côtière": "côtier",
    "côtières": "côtier",
    "côtoie": "côtoyer",
    "côtoiements": "côtoiement",
    "côtoient": "côtoyer",
    "côtoiera": "côtoyer",
    "côtoierai": "côtoyer",
    "côtoieraient": "côtoyer",
    "côtoierais": "côtoyer",
    "côtoierait": "côtoyer",
    "côtoieras": "côtoyer",
    "côtoierez": "côtoyer",
    "côtoieriez": "côtoyer",
    "côtoierions": "côtoyer",
    "côtoierons": "côtoyer",
    "côtoieront": "côtoyer",
    "côtoies": "côtoyer",
    "côtoya": "côtoyer",
    "côtoyai": "côtoyer",
    "côtoyaient": "côtoyer",
    "côtoyais": "côtoyer",
    "côtoyait": "côtoyer",
    "côtoyant": "côtoyer",
    "côtoyas": "côtoyer",
    "côtoyasse": "côtoyer",
    "côtoyassent": "côtoyer",
    "côtoyasses": "côtoyer",
    "côtoyassiez": "côtoyer",
    "côtoyassions": "côtoyer",
    "côtoyez": "côtoyer",
    "côtoyiez": "côtoyer",
    "côtoyions": "côtoyer",
    "côtoyons": "côtoyer",
    "côtoyâmes": "côtoyer",
    "côtoyât": "côtoyer",
    "côtoyâtes": "côtoyer",
    "côtoyèrent": "côtoyer",
    "côtoyé": "côtoyer",
    "côtoyée": "côtoyer",
    "côtoyées": "côtoyer",
    "côtoyés": "côtoyer",
    "côtés": "côté",
    "d'": "de",
    "d'emblée": "d'embléee",
    "dabs": "dab",
    "dabuches": "dabuche",
    "daces": "dace",
    "dactyles": "dactyle",
    "dactylographes": "dactylographe",
    "dactylographia": "dactylographier",
    "dactylographiai": "dactylographier",
    "dactylographiaient": "dactylographier",
    "dactylographiais": "dactylographier",
    "dactylographiait": "dactylographier",
    "dactylographiant": "dactylographier",
    "dactylographias": "dactylographier",
    "dactylographiasse": "dactylographier",
    "dactylographiassent": "dactylographier",
    "dactylographiasses": "dactylographier",
    "dactylographiassiez": "dactylographier",
    "dactylographiassions": "dactylographier",
    "dactylographie": "dactylographier",
    "dactylographient": "dactylographier",
    "dactylographiera": "dactylographier",
    "dactylographierai": "dactylographier",
    "dactylographieraient": "dactylographier",
    "dactylographierais": "dactylographier",
    "dactylographierait": "dactylographier",
    "dactylographieras": "dactylographier",
    "dactylographierez": "dactylographier",
    "dactylographieriez": "dactylographier",
    "dactylographierions": "dactylographier",
    "dactylographierons": "dactylographier",
    "dactylographieront": "dactylographier",
    "dactylographies": "dactylographier",
    "dactylographiez": "dactylographier",
    "dactylographiiez": "dactylographier",
    "dactylographiions": "dactylographier",
    "dactylographions": "dactylographier",
    "dactylographiâmes": "dactylographier",
    "dactylographiât": "dactylographier",
    "dactylographiâtes": "dactylographier",
    "dactylographièrent": "dactylographier",
    "dactylographié": "dactylographier",
    "dactylographiée": "dactylographier",
    "dactylographiées": "dactylographier",
    "dactylographiés": "dactylographier",
    "dactyloptères": "dactyloptère",
    "dactylos": "dactylo",
    "dadas": "dada",
    "dadaïsmes": "dadaïsme",
    "dadaïstes": "dadaïste",
    "daguerréotypes": "daguerréotype",
    "dagues": "dague",
    "daguets": "daguet",
    "dagué": "daguer",
    "dahlias": "dahlia",
    "dahoméenne": "dahoméen",
    "dahus": "dahu",
    "daigna": "daigner",
    "daignai": "daigner",
    "daignaient": "daigner",
    "daignais": "daigner",
    "daignait": "daigner",
    "daignant": "daigner",
    "daignas": "daigner",
    "daignasse": "daigner",
    "daignassent": "daigner",
    "daignasses": "daigner",
    "daignassiez": "daigner",
    "daignassions": "daigner",
    "daigne": "daigner",
    "daignent": "daigner",
    "daignera": "daigner",
    "daignerai": "daigner",
    "daigneraient": "daigner",
    "daignerais": "daigner",
    "daignerait": "daigner",
    "daigneras": "daigner",
    "daignerez": "daigner",
    "daigneriez": "daigner",
    "daignerions": "daigner",
    "daignerons": "daigner",
    "daigneront": "daigner",
    "daignes": "daigner",
    "daignez": "daigner",
    "daigniez": "daigner",
    "daignions": "daigner",
    "daignons": "daigner",
    "daignâmes": "daigner",
    "daignât": "daigner",
    "daignâtes": "daigner",
    "daignèrent": "daigner",
    "daigné": "daigner",
    "daims": "daim",
    "daines": "daine",
    "daiquiris": "daiquiri",
    "dakaroise": "dakarois",
    "dakotas": "dakota",
    "dalinienne": "dalinien",
    "dallages": "dallage",
    "dalle": "daller",
    "dalles": "dalle",
    "dallé": "daller",
    "dallée": "daller",
    "dallées": "daller",
    "dallés": "daller",
    "dalmates": "dalmate",
    "dalmatienne": "dalmatien",
    "dalmatiennes": "dalmatien",
    "dalmatiens": "dalmatien",
    "dalmatiques": "dalmatique",
    "dalots": "dalot",
    "daltonienne": "daltonien",
    "daltoniennes": "daltonien",
    "daltoniens": "daltonien",
    "daltons": "dalton",
    "dama": "damer",
    "damai": "damer",
    "damaient": "damer",
    "damais": "damer",
    "damait": "damer",
    "damant": "damer",
    "damas": "damer",
    "damasquina": "damasquiner",
    "damasquinai": "damasquiner",
    "damasquinaient": "damasquiner",
    "damasquinais": "damasquiner",
    "damasquinait": "damasquiner",
    "damasquinant": "damasquiner",
    "damasquinas": "damasquiner",
    "damasquinasse": "damasquiner",
    "damasquinassent": "damasquiner",
    "damasquinasses": "damasquiner",
    "damasquinassiez": "damasquiner",
    "damasquinassions": "damasquiner",
    "damasquine": "damasquiner",
    "damasquinent": "damasquiner",
    "damasquinera": "damasquiner",
    "damasquinerai": "damasquiner",
    "damasquineraient": "damasquiner",
    "damasquinerais": "damasquiner",
    "damasquinerait": "damasquiner",
    "damasquineras": "damasquiner",
    "damasquinerez": "damasquiner",
    "damasquineriez": "damasquiner",
    "damasquinerions": "damasquiner",
    "damasquinerons": "damasquiner",
    "damasquineront": "damasquiner",
    "damasquines": "damasquiner",
    "damasquinez": "damasquiner",
    "damasquiniez": "damasquiner",
    "damasquinions": "damasquiner",
    "damasquinons": "damasquiner",
    "damasquins": "damasquin",
    "damasquinâmes": "damasquiner",
    "damasquinât": "damasquiner",
    "damasquinâtes": "damasquiner",
    "damasquinèrent": "damasquiner",
    "damasquiné": "damasquiner",
    "damasquinée": "damasquiner",
    "damasquinées": "damasquiner",
    "damasquinés": "damasquiner",
    "damassa": "damasser",
    "damassai": "damasser",
    "damassaient": "damasser",
    "damassais": "damasser",
    "damassait": "damasser",
    "damassant": "damasser",
    "damassas": "damasser",
    "damassasse": "damasser",
    "damassassent": "damasser",
    "damassasses": "damasser",
    "damassassiez": "damasser",
    "damassassions": "damasser",
    "damasse": "damer",
    "damassent": "damer",
    "damassera": "damasser",
    "damasserai": "damasser",
    "damasseraient": "damasser",
    "damasserais": "damasser",
    "damasserait": "damasser",
    "damasseras": "damasser",
    "damasserez": "damasser",
    "damasseriez": "damasser",
    "damasserions": "damasser",
    "damasserons": "damasser",
    "damasseront": "damasser",
    "damasses": "damer",
    "damassez": "damasser",
    "damassiez": "damer",
    "damassions": "damer",
    "damassons": "damasser",
    "damassâmes": "damasser",
    "damassât": "damasser",
    "damassâtes": "damasser",
    "damassèrent": "damasser",
    "damassé": "damasser",
    "damassée": "damasser",
    "damassées": "damasser",
    "damassés": "damasser",
    "dame": "damer",
    "dament": "damer",
    "damera": "damer",
    "damerai": "damer",
    "dameraient": "damer",
    "damerais": "damer",
    "damerait": "damer",
    "dameras": "damer",
    "damerez": "damer",
    "dameriez": "damer",
    "damerions": "damer",
    "damerons": "damer",
    "dameront": "damer",
    "dames": "damer",
    "dames-d'onze-heures": "dame-d'onze-heures",
    "dames-jeannes": "dame-jeanne",
    "damez": "damer",
    "damiers": "damier",
    "damiez": "damer",
    "damions": "damer",
    "damna": "damner",
    "damnables": "damnable",
    "damnai": "damner",
    "damnaient": "damner",
    "damnais": "damner",
    "damnait": "damner",
    "damnant": "damner",
    "damnas": "damner",
    "damnasse": "damner",
    "damnassent": "damner",
    "damnasses": "damner",
    "damnassiez": "damner",
    "damnassions": "damner",
    "damnations": "damnation",
    "damne": "damner",
    "damnent": "damner",
    "damnera": "damner",
    "damnerai": "damner",
    "damneraient": "damner",
    "damnerais": "damner",
    "damnerait": "damner",
    "damneras": "damner",
    "damnerez": "damner",
    "damneriez": "damner",
    "damnerions": "damner",
    "damnerons": "damner",
    "damneront": "damner",
    "damnes": "damner",
    "damnez": "damner",
    "damniez": "damner",
    "damnions": "damner",
    "damnons": "damner",
    "damnâmes": "damner",
    "damnât": "damner",
    "damnâtes": "damner",
    "damnèrent": "damner",
    "damné": "damner",
    "damnée": "damner",
    "damnées": "damner",
    "damnés": "damner",
    "damoiseaux": "damoiseau",
    "damoiselle": "damoiseau",
    "damoiselles": "damoiselle",
    "damons": "damer",
    "dams": "dam",
    "damâmes": "damer",
    "damât": "damer",
    "damâtes": "damer",
    "damèrent": "damer",
    "damé": "damer",
    "damée": "damer",
    "damées": "damer",
    "damés": "damer",
    "danaïdes": "danaïde",
    "dancings": "dancing",
    "dandina": "dandiner",
    "dandinai": "dandiner",
    "dandinaient": "dandiner",
    "dandinais": "dandiner",
    "dandinait": "dandiner",
    "dandinant": "dandiner",
    "dandinas": "dandiner",
    "dandinasse": "dandiner",
    "dandinassent": "dandiner",
    "dandinasses": "dandiner",
    "dandinassiez": "dandiner",
    "dandinassions": "dandiner",
    "dandine": "dandiner",
    "dandinements": "dandinement",
    "dandinent": "dandiner",
    "dandinera": "dandiner",
    "dandinerai": "dandiner",
    "dandineraient": "dandiner",
    "dandinerais": "dandiner",
    "dandinerait": "dandiner",
    "dandineras": "dandiner",
    "dandinerez": "dandiner",
    "dandineriez": "dandiner",
    "dandinerions": "dandiner",
    "dandinerons": "dandiner",
    "dandineront": "dandiner",
    "dandines": "dandiner",
    "dandinez": "dandiner",
    "dandiniez": "dandiner",
    "dandinions": "dandiner",
    "dandinons": "dandiner",
    "dandins": "dandin",
    "dandinâmes": "dandiner",
    "dandinât": "dandiner",
    "dandinâtes": "dandiner",
    "dandinèrent": "dandiner",
    "dandiné": "dandiner",
    "dandinée": "dandiner",
    "dandinées": "dandiner",
    "dandinés": "dandiner",
    "dandys": "dandy",
    "dangereuse": "dangereux",
    "dangereuses": "dangereux",
    "dangerosités": "dangerosité",
    "dangers": "danger",
    "danoise": "danois",
    "danoises": "danois",
    "dans": "dan",
    "dansa": "danser",
    "dansai": "danser",
    "dansaient": "danser",
    "dansais": "danser",
    "dansait": "danser",
    "dansant": "danser",
    "dansante": "dansant",
    "dansantes": "dansant",
    "dansants": "dansant",
    "dansas": "danser",
    "dansasse": "danser",
    "dansassent": "danser",
    "dansasses": "danser",
    "dansassiez": "danser",
    "dansassions": "danser",
    "danse": "danser",
    "dansent": "danser",
    "dansera": "danser",
    "danserai": "danser",
    "danseraient": "danser",
    "danserais": "danser",
    "danserait": "danser",
    "danseras": "danser",
    "danserez": "danser",
    "danseriez": "danser",
    "danserions": "danser",
    "danserons": "danser",
    "danseront": "danser",
    "danses": "danser",
    "danseurs": "danseur",
    "danseuse": "danseur",
    "danseuses": "danseur",
    "dansez": "danser",
    "dansiez": "danser",
    "dansions": "danser",
    "dansons": "danser",
    "dansota": "dansoter",
    "dansotait": "dansoter",
    "dansâmes": "danser",
    "dansât": "danser",
    "dansâtes": "danser",
    "dansèrent": "danser",
    "dansé": "danser",
    "dansée": "danser",
    "dansées": "danser",
    "dansés": "danser",
    "dantesques": "dantesque",
    "danubienne": "danubien",
    "danubiennes": "danubien",
    "danubiens": "danubien",
    "daphnies": "daphnie",
    "daphnés": "daphné",
    "darda": "darder",
    "dardai": "darder",
    "dardaient": "darder",
    "dardais": "darder",
    "dardait": "darder",
    "dardant": "darder",
    "dardas": "darder",
    "dardasse": "darder",
    "dardassent": "darder",
    "dardasses": "darder",
    "dardassiez": "darder",
    "dardassions": "darder",
    "darde": "darder",
    "dardent": "darder",
    "dardera": "darder",
    "darderai": "darder",
    "darderaient": "darder",
    "darderais": "darder",
    "darderait": "darder",
    "darderas": "darder",
    "darderez": "darder",
    "darderiez": "darder",
    "darderions": "darder",
    "darderons": "darder",
    "darderont": "darder",
    "dardes": "darder",
    "dardez": "darder",
    "dardiez": "darder",
    "dardillonnaient": "dardillonner",
    "dardillonne": "dardillonner",
    "dardions": "darder",
    "dardons": "darder",
    "dards": "dard",
    "dardâmes": "darder",
    "dardât": "darder",
    "dardâtes": "darder",
    "dardèrent": "darder",
    "dardé": "darder",
    "dardée": "darder",
    "dardées": "darder",
    "dardés": "darder",
    "dare dare": "dare-dare",
    "darioles": "dariole",
    "darnes": "darne",
    "daronne": "daron",
    "daronnes": "daron",
    "darons": "daron",
    "darses": "darse",
    "dartres": "dartre",
    "dartreuses": "dartreux",
    "darwinismes": "darwinisme",
    "data": "dater",
    "datai": "dater",
    "dataient": "dater",
    "datais": "dater",
    "datait": "dater",
    "datant": "dater",
    "datas": "dater",
    "datasse": "dater",
    "datassent": "dater",
    "datasses": "dater",
    "datassiez": "dater",
    "datassions": "dater",
    "datchas": "datcha",
    "date": "dater",
    "datent": "dater",
    "datera": "dater",
    "daterai": "dater",
    "dateraient": "dater",
    "daterais": "dater",
    "daterait": "dater",
    "dateras": "dater",
    "daterez": "dater",
    "dateriez": "dater",
    "daterions": "dater",
    "daterons": "dater",
    "dateront": "dater",
    "dates": "dater",
    "datez": "dater",
    "datiez": "dater",
    "datifs": "datif",
    "dations": "dation",
    "datons": "dater",
    "dattes": "datte",
    "dattiers": "dattier",
    "daturas": "datura",
    "datâmes": "dater",
    "datât": "dater",
    "datâtes": "dater",
    "datèrent": "dater",
    "daté": "dater",
    "datée": "dater",
    "datées": "dater",
    "datés": "dater",
    "dauba": "dauber",
    "daubai": "dauber",
    "daubaient": "dauber",
    "daubais": "dauber",
    "daubait": "dauber",
    "daubant": "dauber",
    "daubas": "dauber",
    "daubasse": "dauber",
    "daubassent": "dauber",
    "daubasses": "dauber",
    "daubassiez": "dauber",
    "daubassions": "dauber",
    "daube": "dauber",
    "daubent": "dauber",
    "daubera": "dauber",
    "dauberai": "dauber",
    "dauberaient": "dauber",
    "dauberais": "dauber",
    "dauberait": "dauber",
    "dauberas": "dauber",
    "dauberez": "dauber",
    "dauberiez": "dauber",
    "dauberions": "dauber",
    "dauberons": "dauber",
    "dauberont": "dauber",
    "daubes": "dauber",
    "daubez": "dauber",
    "daubiez": "dauber",
    "daubions": "dauber",
    "daubons": "dauber",
    "daubâmes": "dauber",
    "daubât": "dauber",
    "daubâtes": "dauber",
    "daubèrent": "dauber",
    "daubé": "dauber",
    "daubée": "dauber",
    "daubées": "dauber",
    "daubés": "dauber",
    "dauphine": "dauphin",
    "dauphines": "dauphin",
    "dauphinoise": "dauphinois",
    "dauphinoises": "dauphinois",
    "dauphins": "dauphin",
    "daurades": "daurade",
    "daviers": "davier",
    "daïmios": "daïmio",
    "daïquiris": "daïquiri",
    "dealaient": "dealer",
    "dealais": "dealer",
    "dealait": "dealer",
    "dealant": "dealer",
    "deale": "dealer",
    "dealent": "dealer",
    "dealera": "dealer",
    "dealeront": "dealer",
    "dealers": "dealer",
    "deales": "dealer",
    "dealez": "dealer",
    "deals": "deal",
    "dealé": "dealer",
    "decrescendos": "decrescendo",
    "definitifs": "definitif",
    "definitives": "definitif",
    "degrés": "degré",
    "delphinidés": "delphinidé",
    "delphiniums": "delphinium",
    "deltaplanes": "deltaplane",
    "deltas": "delta",
    "deltoïdes": "deltoïde",
    "demains": "demain",
    "demanda": "demander",
    "demandai": "demander",
    "demandaient": "demander",
    "demandais": "demander",
    "demandait": "demander",
    "demandant": "demander",
    "demandas": "demander",
    "demandasse": "demander",
    "demandassent": "demander",
    "demandasses": "demander",
    "demandassiez": "demander",
    "demandassions": "demander",
    "demande": "demander",
    "demandent": "demander",
    "demandera": "demander",
    "demanderai": "demander",
    "demanderaient": "demander",
    "demanderais": "demander",
    "demanderait": "demander",
    "demanderas": "demander",
    "demanderesse": "demandeur",
    "demanderesses": "demandeur",
    "demanderez": "demander",
    "demanderiez": "demander",
    "demanderions": "demander",
    "demanderons": "demander",
    "demanderont": "demander",
    "demandes": "demander",
    "demandeurs": "demandeur",
    "demandeuse": "demandeur",
    "demandeuses": "demandeur",
    "demandez": "demander",
    "demandiez": "demander",
    "demandions": "demander",
    "demandons": "demander",
    "demandâmes": "demander",
    "demandât": "demander",
    "demandâtes": "demander",
    "demandèrent": "demander",
    "demandé": "demander",
    "demandée": "demander",
    "demandées": "demander",
    "demandés": "demander",
    "demeura": "demeurer",
    "demeurai": "demeurer",
    "demeuraient": "demeurer",
    "demeurais": "demeurer",
    "demeurait": "demeurer",
    "demeurant": "demeurer",
    "demeuras": "demeurer",
    "demeurasse": "demeurer",
    "demeurassent": "demeurer",
    "demeurasses": "demeurer",
    "demeurassiez": "demeurer",
    "demeurassions": "demeurer",
    "demeure": "demeurer",
    "demeurent": "demeurer",
    "demeurera": "demeurer",
    "demeurerai": "demeurer",
    "demeureraient": "demeurer",
    "demeurerais": "demeurer",
    "demeurerait": "demeurer",
    "demeureras": "demeurer",
    "demeurerez": "demeurer",
    "demeureriez": "demeurer",
    "demeurerions": "demeurer",
    "demeurerons": "demeurer",
    "demeureront": "demeurer",
    "demeures": "demeurer",
    "demeurez": "demeurer",
    "demeuriez": "demeurer",
    "demeurions": "demeurer",
    "demeurons": "demeurer",
    "demeurâmes": "demeurer",
    "demeurât": "demeurer",
    "demeurâtes": "demeurer",
    "demeurèrent": "demeurer",
    "demeuré": "demeurer",
    "demeurée": "demeurer",
    "demeurées": "demeurer",
    "demeurés": "demeurer",
    "demi-bottes": "demi-botte",
    "demi-brigades": "demi-brigade",
    "demi-cercles": "demi-cercle",
    "demi-dieux": "demi-dieu",
    "demi-douzaines": "demi-douzaine",
    "demi-dévêtue": "demi-dévêtu",
    "demi-finales": "demi-finale",
    "demi-fous": "demi-fou",
    "demi-frères": "demi-frère",
    "demi-heure": "heur",
    "demi-heures": "heur",
    "demi-journées": "demi-journée",
    "demi-jours": "demi-jour",
    "demi-lunes": "demi-lune",
    "demi-maux": "demi-mal",
    "demi-mesures": "demi-mesure",
    "demi-mondaine": "demi-mondain",
    "demi-mondaines": "demi-mondain",
    "demi-mondains": "demi-mondain",
    "demi-morte": "demi-mort",
    "demi-mortes": "demi-mort",
    "demi-morts": "demi-mort",
    "demi-ouverte": "demi-ouvert",
    "demi-pauses": "demi-pause",
    "demi-pensionnaires": "demi-pensionnaire",
    "demi-pensions": "demi-pension",
    "demi-pièces": "demi-pièce",
    "demi-places": "demi-place",
    "demi-pointes": "demi-pointe",
    "demi-portions": "demi-portion",
    "demi-reliures": "demi-reliure",
    "demi-ronde": "demi-rond",
    "demi-régiments": "demi-régiment",
    "demi-saisons": "demi-saison",
    "demi-sangs": "demi-sang",
    "demi-sels": "demi-sel",
    "demi-siècles": "demi-siècle",
    "demi-soeurs": "demi-soeur",
    "demi-soldes": "demi-solde",
    "demi-sommeils": "demi-sommeil",
    "demi-sourires": "demi-sourire",
    "demi-tarifs": "demi-tarif",
    "demi-tasses": "demi-tasse",
    "demi-teintes": "demi-teinte",
    "demi-tonne": "demi-ton",
    "demi-tons": "demi-ton",
    "demi-tours": "demi-tour",
    "demi-vierges": "demi-vierge",
    "demi-vies": "demi-vie",
    "demi-voltes": "demi-volte",
    "demie": "demi",
    "demies": "demi",
    "demis": "demi",
    "demoiselle": "damoiseau",
    "demoiselles": "demoiselle",
    "dendrites": "dendrite",
    "deniers": "denier",
    "denims": "denim",
    "denrées": "denrée",
    "denses": "dense",
    "densifia": "densifier",
    "densifie": "densifier",
    "densifié": "densifier",
    "densités": "densité",
    "dentaires": "dentaire",
    "dentale": "dental",
    "dentales": "dental",
    "dentaux": "dental",
    "dentela": "denteler",
    "dentelai": "denteler",
    "dentelaient": "denteler",
    "dentelais": "denteler",
    "dentelait": "denteler",
    "dentelant": "denteler",
    "dentelas": "denteler",
    "dentelasse": "denteler",
    "dentelassent": "denteler",
    "dentelasses": "denteler",
    "dentelassiez": "denteler",
    "dentelassions": "denteler",
    "dentelez": "denteler",
    "denteliez": "denteler",
    "dentelions": "denteler",
    "dentelle": "denteler",
    "dentellent": "denteler",
    "dentellera": "denteler",
    "dentellerai": "denteler",
    "dentelleraient": "denteler",
    "dentellerais": "denteler",
    "dentellerait": "denteler",
    "dentelleras": "denteler",
    "dentellerez": "denteler",
    "dentelleriez": "denteler",
    "dentellerions": "denteler",
    "dentellerons": "denteler",
    "dentelleront": "denteler",
    "dentelles": "dentelle",
    "dentelliers": "dentellier",
    "dentellière": "dentellier",
    "dentellières": "dentellier",
    "dentelons": "denteler",
    "dentelures": "dentelure",
    "dentelâmes": "denteler",
    "dentelât": "denteler",
    "dentelâtes": "denteler",
    "dentelèrent": "denteler",
    "dentelé": "denteler",
    "dentelée": "denteler",
    "dentelées": "denteler",
    "dentelés": "denteler",
    "dentiers": "dentier",
    "dentifrices": "dentifrice",
    "dentistes": "dentiste",
    "dentitions": "dentition",
    "dents": "dent",
    "dents-de-lion": "dent-de-lion",
    "dentures": "denture",
    "dentée": "denter",
    "dentées": "denter",
    "dentés": "denté",
    "derbies": "derby",
    "derbys": "derby",
    "derches": "derche",
    "dermatoglyphes": "dermatoglyphe",
    "dermatologiques": "dermatologique",
    "dermatoses": "dermatose",
    "dermes": "derme",
    "dermiques": "dermique",
    "dermites": "dermite",
    "derniers": "dernier",
    "derniers-nés": "dernier-né",
    "dernière": "dernier",
    "dernière-née": "dernier-né",
    "dernières": "dernier",
    "dernières-nées": "dernier-né",
    "derricks": "derrick",
    "derrières": "derrière",
    "ders": "der",
    "derviches": "derviche",
    "des": "un",
    "descamisados": "descamisado",
    "descella": "desceller",
    "descellai": "desceller",
    "descellaient": "desceller",
    "descellais": "desceller",
    "descellait": "desceller",
    "descellant": "desceller",
    "descellas": "desceller",
    "descellasse": "desceller",
    "descellassent": "desceller",
    "descellasses": "desceller",
    "descellassiez": "desceller",
    "descellassions": "desceller",
    "descelle": "desceller",
    "descellent": "desceller",
    "descellera": "desceller",
    "descellerai": "desceller",
    "descelleraient": "desceller",
    "descellerais": "desceller",
    "descellerait": "desceller",
    "descelleras": "desceller",
    "descellerez": "desceller",
    "descelleriez": "desceller",
    "descellerions": "desceller",
    "descellerons": "desceller",
    "descelleront": "desceller",
    "descelles": "desceller",
    "descellez": "desceller",
    "descelliez": "desceller",
    "descellions": "desceller",
    "descellons": "desceller",
    "descellâmes": "desceller",
    "descellât": "desceller",
    "descellâtes": "desceller",
    "descellèrent": "desceller",
    "descellé": "desceller",
    "descellée": "desceller",
    "descellées": "desceller",
    "descellés": "desceller",
    "descend": "descendre",
    "descendaient": "descendre",
    "descendais": "descendre",
    "descendait": "descendre",
    "descendances": "descendance",
    "descendant": "descendre",
    "descendante": "descendant",
    "descendantes": "descendant",
    "descendants": "descendant",
    "descende": "descendre",
    "descendent": "descendre",
    "descendes": "descendre",
    "descendeurs": "descendeur",
    "descendez": "descendre",
    "descendiez": "descendre",
    "descendions": "descendre",
    "descendirent": "descendre",
    "descendis": "descendre",
    "descendisse": "descendre",
    "descendissent": "descendre",
    "descendisses": "descendre",
    "descendissiez": "descendre",
    "descendissions": "descendre",
    "descendit": "descendre",
    "descendons": "descendre",
    "descendra": "descendre",
    "descendrai": "descendre",
    "descendraient": "descendre",
    "descendrais": "descendre",
    "descendrait": "descendre",
    "descendras": "descendre",
    "descendrez": "descendre",
    "descendriez": "descendre",
    "descendrions": "descendre",
    "descendrons": "descendre",
    "descendront": "descendre",
    "descends": "descendre",
    "descendu": "descendre",
    "descendue": "descendre",
    "descendues": "descendre",
    "descendus": "descendre",
    "descendîmes": "descendre",
    "descendît": "descendre",
    "descendîtes": "descendre",
    "descentes": "descente",
    "descriptibles": "descriptible",
    "descriptifs": "descriptif",
    "descriptions": "description",
    "descriptive": "descriptif",
    "descriptives": "descriptif",
    "designers": "designer",
    "designs": "design",
    "desperados": "desperado",
    "despotes": "despote",
    "despotiques": "despotique",
    "despotismes": "despotisme",
    "desquama": "desquamer",
    "desquamai": "desquamer",
    "desquamaient": "desquamer",
    "desquamais": "desquamer",
    "desquamait": "desquamer",
    "desquamant": "desquamer",
    "desquamante": "desquamant",
    "desquamas": "desquamer",
    "desquamasse": "desquamer",
    "desquamassent": "desquamer",
    "desquamasses": "desquamer",
    "desquamassiez": "desquamer",
    "desquamassions": "desquamer",
    "desquame": "desquamer",
    "desquament": "desquamer",
    "desquamera": "desquamer",
    "desquamerai": "desquamer",
    "desquameraient": "desquamer",
    "desquamerais": "desquamer",
    "desquamerait": "desquamer",
    "desquameras": "desquamer",
    "desquamerez": "desquamer",
    "desquameriez": "desquamer",
    "desquamerions": "desquamer",
    "desquamerons": "desquamer",
    "desquameront": "desquamer",
    "desquames": "desquamer",
    "desquamez": "desquamer",
    "desquamiez": "desquamer",
    "desquamions": "desquamer",
    "desquamons": "desquamer",
    "desquamâmes": "desquamer",
    "desquamât": "desquamer",
    "desquamâtes": "desquamer",
    "desquamèrent": "desquamer",
    "desquamé": "desquamer",
    "desquamée": "desquamer",
    "desquamées": "desquamer",
    "desquamés": "desquamer",
    "dessabla": "dessabler",
    "dessablai": "dessabler",
    "dessablaient": "dessabler",
    "dessablais": "dessabler",
    "dessablait": "dessabler",
    "dessablant": "dessabler",
    "dessablas": "dessabler",
    "dessablasse": "dessabler",
    "dessablassent": "dessabler",
    "dessablasses": "dessabler",
    "dessablassiez": "dessabler",
    "dessablassions": "dessabler",
    "dessable": "dessabler",
    "dessablent": "dessabler",
    "dessablera": "dessabler",
    "dessablerai": "dessabler",
    "dessableraient": "dessabler",
    "dessablerais": "dessabler",
    "dessablerait": "dessabler",
    "dessableras": "dessabler",
    "dessablerez": "dessabler",
    "dessableriez": "dessabler",
    "dessablerions": "dessabler",
    "dessablerons": "dessabler",
    "dessableront": "dessabler",
    "dessables": "dessabler",
    "dessablez": "dessabler",
    "dessabliez": "dessabler",
    "dessablions": "dessabler",
    "dessablons": "dessabler",
    "dessablâmes": "dessabler",
    "dessablât": "dessabler",
    "dessablâtes": "dessabler",
    "dessablèrent": "dessabler",
    "dessablé": "dessabler",
    "dessablée": "dessabler",
    "dessablées": "dessabler",
    "dessablés": "dessabler",
    "dessaisi": "dessaisir",
    "dessaisie": "dessaisir",
    "dessaisies": "dessaisir",
    "dessaisira": "dessaisir",
    "dessaisirai": "dessaisir",
    "dessaisiraient": "dessaisir",
    "dessaisirais": "dessaisir",
    "dessaisirait": "dessaisir",
    "dessaisiras": "dessaisir",
    "dessaisirent": "dessaisir",
    "dessaisirez": "dessaisir",
    "dessaisiriez": "dessaisir",
    "dessaisirions": "dessaisir",
    "dessaisirons": "dessaisir",
    "dessaisiront": "dessaisir",
    "dessaisis": "dessaisir",
    "dessaisissaient": "dessaisir",
    "dessaisissais": "dessaisir",
    "dessaisissait": "dessaisir",
    "dessaisissant": "dessaisir",
    "dessaisisse": "dessaisir",
    "dessaisissent": "dessaisir",
    "dessaisisses": "dessaisir",
    "dessaisissez": "dessaisir",
    "dessaisissiez": "dessaisir",
    "dessaisissions": "dessaisir",
    "dessaisissons": "dessaisir",
    "dessaisit": "dessaisir",
    "dessaisîmes": "dessaisir",
    "dessaisît": "dessaisir",
    "dessaisîtes": "dessaisir",
    "dessala": "dessaler",
    "dessalai": "dessaler",
    "dessalaient": "dessaler",
    "dessalais": "dessaler",
    "dessalait": "dessaler",
    "dessalant": "dessaler",
    "dessalas": "dessaler",
    "dessalasse": "dessaler",
    "dessalassent": "dessaler",
    "dessalasses": "dessaler",
    "dessalassiez": "dessaler",
    "dessalassions": "dessaler",
    "dessale": "dessaler",
    "dessalements": "dessalement",
    "dessalent": "dessaler",
    "dessalera": "dessaler",
    "dessalerai": "dessaler",
    "dessaleraient": "dessaler",
    "dessalerais": "dessaler",
    "dessalerait": "dessaler",
    "dessaleras": "dessaler",
    "dessalerez": "dessaler",
    "dessaleriez": "dessaler",
    "dessalerions": "dessaler",
    "dessalerons": "dessaler",
    "dessaleront": "dessaler",
    "dessales": "dessaler",
    "dessalez": "dessaler",
    "dessaliez": "dessaler",
    "dessalions": "dessaler",
    "dessalons": "dessaler",
    "dessalâmes": "dessaler",
    "dessalât": "dessaler",
    "dessalâtes": "dessaler",
    "dessalèrent": "dessaler",
    "dessalé": "dessaler",
    "dessalée": "dessaler",
    "dessalées": "dessaler",
    "dessalés": "dessaler",
    "dessangla": "dessangler",
    "dessanglai": "dessangler",
    "dessanglaient": "dessangler",
    "dessanglais": "dessangler",
    "dessanglait": "dessangler",
    "dessanglant": "dessangler",
    "dessanglas": "dessangler",
    "dessanglasse": "dessangler",
    "dessanglassent": "dessangler",
    "dessanglasses": "dessangler",
    "dessanglassiez": "dessangler",
    "dessanglassions": "dessangler",
    "dessangle": "dessangler",
    "dessanglent": "dessangler",
    "dessanglera": "dessangler",
    "dessanglerai": "dessangler",
    "dessangleraient": "dessangler",
    "dessanglerais": "dessangler",
    "dessanglerait": "dessangler",
    "dessangleras": "dessangler",
    "dessanglerez": "dessangler",
    "dessangleriez": "dessangler",
    "dessanglerions": "dessangler",
    "dessanglerons": "dessangler",
    "dessangleront": "dessangler",
    "dessangles": "dessangler",
    "dessanglez": "dessangler",
    "dessangliez": "dessangler",
    "dessanglions": "dessangler",
    "dessanglons": "dessangler",
    "dessanglâmes": "dessangler",
    "dessanglât": "dessangler",
    "dessanglâtes": "dessangler",
    "dessanglèrent": "dessangler",
    "dessanglé": "dessangler",
    "dessanglée": "dessangler",
    "dessanglées": "dessangler",
    "dessanglés": "dessangler",
    "dessaoulais": "dessaouler",
    "dessaoule": "dessaouler",
    "dessaoulent": "dessaouler",
    "dessaoulé": "dessaouler",
    "dessaoulée": "dessaouler",
    "dessaoulés": "dessaouler",
    "dessape": "dessaper",
    "desseins": "dessein",
    "dessella": "desseller",
    "dessellai": "desseller",
    "dessellaient": "desseller",
    "dessellais": "desseller",
    "dessellait": "desseller",
    "dessellant": "desseller",
    "dessellas": "desseller",
    "dessellasse": "desseller",
    "dessellassent": "desseller",
    "dessellasses": "desseller",
    "dessellassiez": "desseller",
    "dessellassions": "desseller",
    "desselle": "desseller",
    "dessellent": "desseller",
    "dessellera": "desseller",
    "dessellerai": "desseller",
    "desselleraient": "desseller",
    "dessellerais": "desseller",
    "dessellerait": "desseller",
    "desselleras": "desseller",
    "dessellerez": "desseller",
    "desselleriez": "desseller",
    "dessellerions": "desseller",
    "dessellerons": "desseller",
    "desselleront": "desseller",
    "desselles": "desseller",
    "dessellez": "desseller",
    "desselliez": "desseller",
    "dessellions": "desseller",
    "dessellons": "desseller",
    "dessellâmes": "desseller",
    "dessellât": "desseller",
    "dessellâtes": "desseller",
    "dessellèrent": "desseller",
    "dessellé": "desseller",
    "dessellée": "desseller",
    "dessellées": "desseller",
    "dessellés": "desseller",
    "desserra": "desserrer",
    "desserrai": "desserrer",
    "desserraient": "desserrer",
    "desserrais": "desserrer",
    "desserrait": "desserrer",
    "desserrant": "desserrer",
    "desserras": "desserrer",
    "desserrasse": "desserrer",
    "desserrassent": "desserrer",
    "desserrasses": "desserrer",
    "desserrassiez": "desserrer",
    "desserrassions": "desserrer",
    "desserre": "desserrer",
    "desserrent": "desserrer",
    "desserrera": "desserrer",
    "desserrerai": "desserrer",
    "desserreraient": "desserrer",
    "desserrerais": "desserrer",
    "desserrerait": "desserrer",
    "desserreras": "desserrer",
    "desserrerez": "desserrer",
    "desserreriez": "desserrer",
    "desserrerions": "desserrer",
    "desserrerons": "desserrer",
    "desserreront": "desserrer",
    "desserres": "desserrer",
    "desserrez": "desserrer",
    "desserriez": "desserrer",
    "desserrions": "desserrer",
    "desserrons": "desserrer",
    "desserrâmes": "desserrer",
    "desserrât": "desserrer",
    "desserrâtes": "desserrer",
    "desserrèrent": "desserrer",
    "desserré": "desserrer",
    "desserrée": "desserrer",
    "desserrées": "desserrer",
    "desserrés": "desserrer",
    "dessers": "desservir",
    "dessert": "desservir",
    "dessertes": "desserte",
    "desserti": "dessertir",
    "dessertie": "dessertir",
    "desserties": "dessertir",
    "dessertira": "dessertir",
    "dessertirai": "dessertir",
    "dessertiraient": "dessertir",
    "dessertirais": "dessertir",
    "dessertirait": "dessertir",
    "dessertiras": "dessertir",
    "dessertirent": "dessertir",
    "dessertirez": "dessertir",
    "dessertiriez": "dessertir",
    "dessertirions": "dessertir",
    "dessertirons": "dessertir",
    "dessertiront": "dessertir",
    "dessertis": "dessertir",
    "dessertissaient": "dessertir",
    "dessertissais": "dessertir",
    "dessertissait": "dessertir",
    "dessertissant": "dessertir",
    "dessertisse": "dessertir",
    "dessertissent": "dessertir",
    "dessertisses": "dessertir",
    "dessertissez": "dessertir",
    "dessertissiez": "dessertir",
    "dessertissions": "dessertir",
    "dessertissons": "dessertir",
    "dessertit": "dessertir",
    "desserts": "dessert",
    "dessertîmes": "dessertir",
    "dessertît": "dessertir",
    "dessertîtes": "dessertir",
    "desservaient": "desservir",
    "desservais": "desservir",
    "desservait": "desservir",
    "desservant": "desservir",
    "desserve": "desservir",
    "desservent": "desservir",
    "desserves": "desservir",
    "desservez": "desservir",
    "desservi": "desservir",
    "desservie": "desservir",
    "desservies": "desservir",
    "desserviez": "desservir",
    "desservions": "desservir",
    "desservira": "desservir",
    "desservirai": "desservir",
    "desserviraient": "desservir",
    "desservirais": "desservir",
    "desservirait": "desservir",
    "desserviras": "desservir",
    "desservirent": "desservir",
    "desservirez": "desservir",
    "desserviriez": "desservir",
    "desservirions": "desservir",
    "desservirons": "desservir",
    "desserviront": "desservir",
    "desservis": "desservir",
    "desservisse": "desservir",
    "desservissent": "desservir",
    "desservisses": "desservir",
    "desservissiez": "desservir",
    "desservissions": "desservir",
    "desservit": "desservir",
    "desservons": "desservir",
    "desservîmes": "desservir",
    "desservît": "desservir",
    "desservîtes": "desservir",
    "dessiccations": "dessiccation",
    "dessilla": "dessiller",
    "dessillai": "dessiller",
    "dessillaient": "dessiller",
    "dessillais": "dessiller",
    "dessillait": "dessiller",
    "dessillant": "dessiller",
    "dessillas": "dessiller",
    "dessillasse": "dessiller",
    "dessillassent": "dessiller",
    "dessillasses": "dessiller",
    "dessillassiez": "dessiller",
    "dessillassions": "dessiller",
    "dessille": "dessiller",
    "dessillent": "dessiller",
    "dessillera": "dessiller",
    "dessillerai": "dessiller",
    "dessilleraient": "dessiller",
    "dessillerais": "dessiller",
    "dessillerait": "dessiller",
    "dessilleras": "dessiller",
    "dessillerez": "dessiller",
    "dessilleriez": "dessiller",
    "dessillerions": "dessiller",
    "dessillerons": "dessiller",
    "dessilleront": "dessiller",
    "dessilles": "dessiller",
    "dessillez": "dessiller",
    "dessilliez": "dessiller",
    "dessillions": "dessiller",
    "dessillons": "dessiller",
    "dessillâmes": "dessiller",
    "dessillât": "dessiller",
    "dessillâtes": "dessiller",
    "dessillèrent": "dessiller",
    "dessillé": "dessiller",
    "dessillée": "dessiller",
    "dessillées": "dessiller",
    "dessillés": "dessiller",
    "dessina": "dessiner",
    "dessinai": "dessiner",
    "dessinaient": "dessiner",
    "dessinais": "dessiner",
    "dessinait": "dessiner",
    "dessinant": "dessiner",
    "dessinas": "dessiner",
    "dessinasse": "dessiner",
    "dessinassent": "dessiner",
    "dessinasses": "dessiner",
    "dessinassiez": "dessiner",
    "dessinassions": "dessiner",
    "dessinateurs": "dessinateur",
    "dessinatrice": "dessinateur",
    "dessinatrices": "dessinateur",
    "dessine": "dessiner",
    "dessinent": "dessiner",
    "dessinera": "dessiner",
    "dessinerai": "dessiner",
    "dessineraient": "dessiner",
    "dessinerais": "dessiner",
    "dessinerait": "dessiner",
    "dessineras": "dessiner",
    "dessinerez": "dessiner",
    "dessineriez": "dessiner",
    "dessinerions": "dessiner",
    "dessinerons": "dessiner",
    "dessineront": "dessiner",
    "dessines": "dessiner",
    "dessinez": "dessiner",
    "dessiniez": "dessiner",
    "dessinions": "dessiner",
    "dessinons": "dessiner",
    "dessins": "dessin",
    "dessinâmes": "dessiner",
    "dessinât": "dessiner",
    "dessinâtes": "dessiner",
    "dessinèrent": "dessiner",
    "dessiné": "dessiner",
    "dessinée": "dessiner",
    "dessinées": "dessiner",
    "dessinés": "dessiner",
    "dessola": "dessoler",
    "dessolai": "dessoler",
    "dessolaient": "dessoler",
    "dessolais": "dessoler",
    "dessolait": "dessoler",
    "dessolant": "dessoler",
    "dessolas": "dessoler",
    "dessolasse": "dessoler",
    "dessolassent": "dessoler",
    "dessolasses": "dessoler",
    "dessolassiez": "dessoler",
    "dessolassions": "dessoler",
    "dessole": "dessoler",
    "dessolent": "dessoler",
    "dessolera": "dessoler",
    "dessolerai": "dessoler",
    "dessoleraient": "dessoler",
    "dessolerais": "dessoler",
    "dessolerait": "dessoler",
    "dessoleras": "dessoler",
    "dessolerez": "dessoler",
    "dessoleriez": "dessoler",
    "dessolerions": "dessoler",
    "dessolerons": "dessoler",
    "dessoleront": "dessoler",
    "dessoles": "dessoler",
    "dessolez": "dessoler",
    "dessoliez": "dessoler",
    "dessolions": "dessoler",
    "dessolons": "dessoler",
    "dessolâmes": "dessoler",
    "dessolât": "dessoler",
    "dessolâtes": "dessoler",
    "dessolèrent": "dessoler",
    "dessolé": "dessoler",
    "dessolée": "dessoler",
    "dessolées": "dessoler",
    "dessolés": "dessoler",
    "dessoucha": "dessoucher",
    "dessouchée": "dessoucher",
    "dessouda": "dessouder",
    "dessoudai": "dessouder",
    "dessoudaient": "dessouder",
    "dessoudais": "dessouder",
    "dessoudait": "dessouder",
    "dessoudant": "dessouder",
    "dessoudas": "dessouder",
    "dessoudasse": "dessouder",
    "dessoudassent": "dessouder",
    "dessoudasses": "dessouder",
    "dessoudassiez": "dessouder",
    "dessoudassions": "dessouder",
    "dessoude": "dessouder",
    "dessoudent": "dessouder",
    "dessoudera": "dessouder",
    "dessouderai": "dessouder",
    "dessouderaient": "dessouder",
    "dessouderais": "dessouder",
    "dessouderait": "dessouder",
    "dessouderas": "dessouder",
    "dessouderez": "dessouder",
    "dessouderiez": "dessouder",
    "dessouderions": "dessouder",
    "dessouderons": "dessouder",
    "dessouderont": "dessouder",
    "dessoudes": "dessouder",
    "dessoudez": "dessouder",
    "dessoudiez": "dessouder",
    "dessoudions": "dessouder",
    "dessoudons": "dessouder",
    "dessoudâmes": "dessouder",
    "dessoudât": "dessouder",
    "dessoudâtes": "dessouder",
    "dessoudèrent": "dessouder",
    "dessoudé": "dessouder",
    "dessoudée": "dessouder",
    "dessoudées": "dessouder",
    "dessoudés": "dessouder",
    "dessoula": "dessouler",
    "dessoulai": "dessouler",
    "dessoulaient": "dessouler",
    "dessoulais": "dessouler",
    "dessoulait": "dessouler",
    "dessoulant": "dessouler",
    "dessoulas": "dessouler",
    "dessoulasse": "dessouler",
    "dessoulassent": "dessouler",
    "dessoulasses": "dessouler",
    "dessoulassiez": "dessouler",
    "dessoulassions": "dessouler",
    "dessoule": "dessouler",
    "dessoulent": "dessouler",
    "dessoulera": "dessouler",
    "dessoulerai": "dessouler",
    "dessouleraient": "dessouler",
    "dessoulerais": "dessouler",
    "dessoulerait": "dessouler",
    "dessouleras": "dessouler",
    "dessoulerez": "dessouler",
    "dessouleriez": "dessouler",
    "dessoulerions": "dessouler",
    "dessoulerons": "dessouler",
    "dessouleront": "dessouler",
    "dessoules": "dessouler",
    "dessoulez": "dessouler",
    "dessouliez": "dessouler",
    "dessoulions": "dessouler",
    "dessoulons": "dessouler",
    "dessoulâmes": "dessouler",
    "dessoulât": "dessouler",
    "dessoulâtes": "dessouler",
    "dessoulèrent": "dessouler",
    "dessoulé": "dessouler",
    "dessoulée": "dessouler",
    "dessoulées": "dessouler",
    "dessoulés": "dessouler",
    "dessoûla": "dessoûler",
    "dessoûlai": "dessoûler",
    "dessoûlaient": "dessoûler",
    "dessoûlais": "dessoûler",
    "dessoûlait": "dessoûler",
    "dessoûlant": "dessoûler",
    "dessoûlas": "dessoûler",
    "dessoûlasse": "dessoûler",
    "dessoûlassent": "dessoûler",
    "dessoûlasses": "dessoûler",
    "dessoûlassiez": "dessoûler",
    "dessoûlassions": "dessoûler",
    "dessoûle": "dessoûler",
    "dessoûlent": "dessoûler",
    "dessoûlera": "dessoûler",
    "dessoûlerai": "dessoûler",
    "dessoûleraient": "dessoûler",
    "dessoûlerais": "dessoûler",
    "dessoûlerait": "dessoûler",
    "dessoûleras": "dessoûler",
    "dessoûlerez": "dessoûler",
    "dessoûleriez": "dessoûler",
    "dessoûlerions": "dessoûler",
    "dessoûlerons": "dessoûler",
    "dessoûleront": "dessoûler",
    "dessoûles": "dessoûler",
    "dessoûlez": "dessoûler",
    "dessoûliez": "dessoûler",
    "dessoûlions": "dessoûler",
    "dessoûlons": "dessoûler",
    "dessoûlâmes": "dessoûler",
    "dessoûlât": "dessoûler",
    "dessoûlâtes": "dessoûler",
    "dessoûlèrent": "dessoûler",
    "dessoûlé": "dessoûler",
    "dessoûlée": "dessoûler",
    "dessoûlées": "dessoûler",
    "dessoûlés": "dessoûler",
    "dessuintée": "dessuinter",
    "dessèche": "dessécher",
    "dessèchements": "dessèchement",
    "dessèchent": "dessécher",
    "dessèches": "dessécher",
    "dessécha": "dessécher",
    "desséchai": "dessécher",
    "desséchaient": "dessécher",
    "desséchais": "dessécher",
    "desséchait": "dessécher",
    "desséchant": "dessécher",
    "desséchante": "desséchant",
    "desséchas": "dessécher",
    "desséchasse": "dessécher",
    "desséchassent": "dessécher",
    "desséchasses": "dessécher",
    "desséchassiez": "dessécher",
    "desséchassions": "dessécher",
    "desséchera": "dessécher",
    "dessécherai": "dessécher",
    "dessécheraient": "dessécher",
    "dessécherais": "dessécher",
    "dessécherait": "dessécher",
    "dessécheras": "dessécher",
    "dessécherez": "dessécher",
    "dessécheriez": "dessécher",
    "dessécherions": "dessécher",
    "dessécherons": "dessécher",
    "dessécheront": "dessécher",
    "desséchez": "dessécher",
    "desséchiez": "dessécher",
    "desséchions": "dessécher",
    "desséchons": "dessécher",
    "desséchâmes": "dessécher",
    "desséchât": "dessécher",
    "desséchâtes": "dessécher",
    "desséchèrent": "dessécher",
    "desséché": "dessécher",
    "desséchée": "dessécher",
    "desséchées": "dessécher",
    "desséchés": "dessécher",
    "destina": "destiner",
    "destinai": "destiner",
    "destinaient": "destiner",
    "destinais": "destiner",
    "destinait": "destiner",
    "destinant": "destiner",
    "destinas": "destiner",
    "destinasse": "destiner",
    "destinassent": "destiner",
    "destinasses": "destiner",
    "destinassiez": "destiner",
    "destinassions": "destiner",
    "destinataires": "destinataire",
    "destinations": "destination",
    "destinatrice": "destinateur",
    "destine": "destiner",
    "destinent": "destiner",
    "destinera": "destiner",
    "destinerai": "destiner",
    "destineraient": "destiner",
    "destinerais": "destiner",
    "destinerait": "destiner",
    "destineras": "destiner",
    "destinerez": "destiner",
    "destineriez": "destiner",
    "destinerions": "destiner",
    "destinerons": "destiner",
    "destineront": "destiner",
    "destines": "destiner",
    "destinez": "destiner",
    "destiniez": "destiner",
    "destinions": "destiner",
    "destinons": "destiner",
    "destins": "destin",
    "destinâmes": "destiner",
    "destinât": "destiner",
    "destinâtes": "destiner",
    "destinèrent": "destiner",
    "destiné": "destiner",
    "destinée": "destiner",
    "destinées": "destiner",
    "destinés": "destiner",
    "destitua": "destituer",
    "destituai": "destituer",
    "destituaient": "destituer",
    "destituais": "destituer",
    "destituait": "destituer",
    "destituant": "destituer",
    "destituas": "destituer",
    "destituasse": "destituer",
    "destituassent": "destituer",
    "destituasses": "destituer",
    "destituassiez": "destituer",
    "destituassions": "destituer",
    "destitue": "destituer",
    "destituent": "destituer",
    "destituera": "destituer",
    "destituerai": "destituer",
    "destitueraient": "destituer",
    "destituerais": "destituer",
    "destituerait": "destituer",
    "destitueras": "destituer",
    "destituerez": "destituer",
    "destitueriez": "destituer",
    "destituerions": "destituer",
    "destituerons": "destituer",
    "destitueront": "destituer",
    "destitues": "destituer",
    "destituez": "destituer",
    "destituiez": "destituer",
    "destituions": "destituer",
    "destituons": "destituer",
    "destitutions": "destitution",
    "destituâmes": "destituer",
    "destituât": "destituer",
    "destituâtes": "destituer",
    "destituèrent": "destituer",
    "destitué": "destituer",
    "destituée": "destituer",
    "destituées": "destituer",
    "destitués": "destituer",
    "destriers": "destrier",
    "destroyers": "destroyer",
    "destructeurs": "destructeur",
    "destructifs": "destructif",
    "destructions": "destruction",
    "destructive": "destructif",
    "destructrice": "destructeur",
    "destructrices": "destructeur",
    "dettes": "dette",
    "deuils": "deuil",
    "deutschemarks": "deutschemark",
    "deuxièmes": "deuxième",
    "devaient": "devoir",
    "devais": "devoir",
    "devait": "devoir",
    "devance": "devancer",
    "devancent": "devancer",
    "devancera": "devancer",
    "devancerai": "devancer",
    "devanceraient": "devancer",
    "devancerais": "devancer",
    "devancerait": "devancer",
    "devanceras": "devancer",
    "devancerez": "devancer",
    "devanceriez": "devancer",
    "devancerions": "devancer",
    "devancerons": "devancer",
    "devanceront": "devancer",
    "devances": "devancer",
    "devancez": "devancer",
    "devanciers": "devancier",
    "devanciez": "devancer",
    "devancions": "devancer",
    "devancière": "devancier",
    "devancières": "devancier",
    "devancèrent": "devancer",
    "devancé": "devancer",
    "devancée": "devancer",
    "devancées": "devancer",
    "devancés": "devancer",
    "devant": "devoir",
    "devants": "devant",
    "devantures": "devanture",
    "devança": "devancer",
    "devançai": "devancer",
    "devançaient": "devancer",
    "devançais": "devancer",
    "devançait": "devancer",
    "devançant": "devancer",
    "devanças": "devancer",
    "devançasse": "devancer",
    "devançassent": "devancer",
    "devançasses": "devancer",
    "devançassiez": "devancer",
    "devançassions": "devancer",
    "devançons": "devancer",
    "devançâmes": "devancer",
    "devançât": "devancer",
    "devançâtes": "devancer",
    "devenaient": "devenir",
    "devenais": "devenir",
    "devenait": "devenir",
    "devenant": "devenir",
    "devenez": "devenir",
    "deveniez": "devenir",
    "devenions": "devenir",
    "devenons": "devenir",
    "devenu": "devenir",
    "devenue": "devenir",
    "devenues": "devenir",
    "devenus": "devenir",
    "devez": "devoir",
    "deviendra": "devenir",
    "deviendrai": "devenir",
    "deviendraient": "devenir",
    "deviendrais": "devenir",
    "deviendrait": "devenir",
    "deviendras": "devenir",
    "deviendrez": "devenir",
    "deviendriez": "devenir",
    "deviendrions": "devenir",
    "deviendrons": "devenir",
    "deviendront": "devenir",
    "devienne": "devenir",
    "deviennent": "devenir",
    "deviennes": "devenir",
    "deviens": "devenir",
    "devient": "devenir",
    "deviez": "devoir",
    "devina": "deviner",
    "devinai": "deviner",
    "devinaient": "deviner",
    "devinais": "deviner",
    "devinait": "deviner",
    "devinant": "deviner",
    "devinas": "deviner",
    "devinasse": "deviner",
    "devinassent": "deviner",
    "devinasses": "deviner",
    "devinassiez": "deviner",
    "devinassions": "deviner",
    "devine": "deviner",
    "devinent": "deviner",
    "devinera": "deviner",
    "devinerai": "deviner",
    "devineraient": "deviner",
    "devinerais": "deviner",
    "devinerait": "deviner",
    "devineras": "deviner",
    "devineresse": "devineur",
    "devineresses": "devineur",
    "devinerez": "deviner",
    "devineriez": "deviner",
    "devinerions": "deviner",
    "devinerons": "deviner",
    "devineront": "deviner",
    "devines": "deviner",
    "devinettes": "devinette",
    "devinez": "deviner",
    "deviniez": "deviner",
    "devinions": "deviner",
    "devinons": "deviner",
    "devinrent": "devenir",
    "devins": "devin",
    "devinsse": "devenir",
    "devinssent": "devenir",
    "devinsses": "devenir",
    "devinssiez": "devenir",
    "devinssions": "devenir",
    "devint": "devenir",
    "devinâmes": "deviner",
    "devinât": "deviner",
    "devinâtes": "deviner",
    "devinèrent": "deviner",
    "deviné": "deviner",
    "devinée": "deviner",
    "devinées": "deviner",
    "devinés": "deviner",
    "devions": "devoir",
    "devisa": "deviser",
    "devisai": "deviser",
    "devisaient": "deviser",
    "devisais": "deviser",
    "devisait": "deviser",
    "devisant": "deviser",
    "devisas": "deviser",
    "devisasse": "deviser",
    "devisassent": "deviser",
    "devisasses": "deviser",
    "devisassiez": "deviser",
    "devisassions": "deviser",
    "devise": "deviser",
    "devisent": "deviser",
    "devisera": "deviser",
    "deviserai": "deviser",
    "deviseraient": "deviser",
    "deviserais": "deviser",
    "deviserait": "deviser",
    "deviseras": "deviser",
    "deviserez": "deviser",
    "deviseriez": "deviser",
    "deviserions": "deviser",
    "deviserons": "deviser",
    "deviseront": "deviser",
    "devises": "deviser",
    "devisez": "deviser",
    "devisiez": "deviser",
    "devisions": "deviser",
    "devisons": "deviser",
    "devisâmes": "deviser",
    "devisât": "deviser",
    "devisâtes": "deviser",
    "devisèrent": "deviser",
    "devisé": "deviser",
    "devoirs": "devoir",
    "devons": "devon",
    "devra": "devoir",
    "devrai": "devoir",
    "devraient": "devoir",
    "devrais": "devoir",
    "devrait": "devoir",
    "devras": "devoir",
    "devrez": "devoir",
    "devriez": "devoir",
    "devrions": "devoir",
    "devrons": "devoir",
    "devront": "devoir",
    "devînmes": "devenir",
    "devînt": "devenir",
    "devîntes": "devenir",
    "dextérités": "dextérité",
    "deys": "dey",
    "diableries": "diablerie",
    "diables": "diable",
    "diablesse": "diable",
    "diablesses": "diablesse",
    "diablotins": "diablotin",
    "diaboliques": "diabolique",
    "diabolisent": "diaboliser",
    "diabolisé": "diaboliser",
    "diabolisée": "diaboliser",
    "diabolos": "diabolo",
    "diabètes": "diabète",
    "diabétiques": "diabétique",
    "diaconats": "diaconat",
    "diaconesses": "diaconesse",
    "diacres": "diacre",
    "diacritiques": "diacritique",
    "diadèmes": "diadème",
    "diagnostics": "diagnostic",
    "diagnostiqua": "diagnostiquer",
    "diagnostiquai": "diagnostiquer",
    "diagnostiquaient": "diagnostiquer",
    "diagnostiquais": "diagnostiquer",
    "diagnostiquait": "diagnostiquer",
    "diagnostiquant": "diagnostiquer",
    "diagnostiquas": "diagnostiquer",
    "diagnostiquasse": "diagnostiquer",
    "diagnostiquassent": "diagnostiquer",
    "diagnostiquasses": "diagnostiquer",
    "diagnostiquassiez": "diagnostiquer",
    "diagnostiquassions": "diagnostiquer",
    "diagnostique": "diagnostiquer",
    "diagnostiquent": "diagnostiquer",
    "diagnostiquera": "diagnostiquer",
    "diagnostiquerai": "diagnostiquer",
    "diagnostiqueraient": "diagnostiquer",
    "diagnostiquerais": "diagnostiquer",
    "diagnostiquerait": "diagnostiquer",
    "diagnostiqueras": "diagnostiquer",
    "diagnostiquerez": "diagnostiquer",
    "diagnostiqueriez": "diagnostiquer",
    "diagnostiquerions": "diagnostiquer",
    "diagnostiquerons": "diagnostiquer",
    "diagnostiqueront": "diagnostiquer",
    "diagnostiques": "diagnostiquer",
    "diagnostiquez": "diagnostiquer",
    "diagnostiquiez": "diagnostiquer",
    "diagnostiquions": "diagnostiquer",
    "diagnostiquons": "diagnostiquer",
    "diagnostiquâmes": "diagnostiquer",
    "diagnostiquât": "diagnostiquer",
    "diagnostiquâtes": "diagnostiquer",
    "diagnostiquèrent": "diagnostiquer",
    "diagnostiqué": "diagnostiquer",
    "diagnostiquée": "diagnostiquer",
    "diagnostiquées": "diagnostiquer",
    "diagnostiqués": "diagnostiquer",
    "diagonale": "diagonal",
    "diagonales": "diagonale",
    "diagonaux": "diagonal",
    "diagrammes": "diagramme",
    "dialectale": "dialectal",
    "dialectales": "dialectal",
    "dialectaux": "dialectal",
    "dialectes": "dialecte",
    "dialecticienne": "dialecticien",
    "dialecticiens": "dialecticien",
    "dialectiques": "dialectique",
    "dialogua": "dialoguer",
    "dialoguai": "dialoguer",
    "dialoguaient": "dialoguer",
    "dialoguais": "dialoguer",
    "dialoguait": "dialoguer",
    "dialoguant": "dialoguer",
    "dialoguas": "dialoguer",
    "dialoguasse": "dialoguer",
    "dialoguassent": "dialoguer",
    "dialoguasses": "dialoguer",
    "dialoguassiez": "dialoguer",
    "dialoguassions": "dialoguer",
    "dialogue": "dialoguer",
    "dialoguent": "dialoguer",
    "dialoguera": "dialoguer",
    "dialoguerai": "dialoguer",
    "dialogueraient": "dialoguer",
    "dialoguerais": "dialoguer",
    "dialoguerait": "dialoguer",
    "dialogueras": "dialoguer",
    "dialoguerez": "dialoguer",
    "dialogueriez": "dialoguer",
    "dialoguerions": "dialoguer",
    "dialoguerons": "dialoguer",
    "dialogueront": "dialoguer",
    "dialogues": "dialoguer",
    "dialoguez": "dialoguer",
    "dialoguiez": "dialoguer",
    "dialoguions": "dialoguer",
    "dialoguistes": "dialoguiste",
    "dialoguons": "dialoguer",
    "dialoguâmes": "dialoguer",
    "dialoguât": "dialoguer",
    "dialoguâtes": "dialoguer",
    "dialoguèrent": "dialoguer",
    "dialogué": "dialoguer",
    "dialoguée": "dialoguer",
    "dialoguées": "dialoguer",
    "dialogués": "dialoguer",
    "dialysa": "dialyser",
    "dialysai": "dialyser",
    "dialysaient": "dialyser",
    "dialysais": "dialyser",
    "dialysait": "dialyser",
    "dialysant": "dialyser",
    "dialysas": "dialyser",
    "dialysasse": "dialyser",
    "dialysassent": "dialyser",
    "dialysasses": "dialyser",
    "dialysassiez": "dialyser",
    "dialysassions": "dialyser",
    "dialyse": "dialyser",
    "dialysent": "dialyser",
    "dialysera": "dialyser",
    "dialyserai": "dialyser",
    "dialyseraient": "dialyser",
    "dialyserais": "dialyser",
    "dialyserait": "dialyser",
    "dialyseras": "dialyser",
    "dialyserez": "dialyser",
    "dialyseriez": "dialyser",
    "dialyserions": "dialyser",
    "dialyserons": "dialyser",
    "dialyseront": "dialyser",
    "dialyses": "dialyser",
    "dialysez": "dialyser",
    "dialysiez": "dialyser",
    "dialysions": "dialyser",
    "dialysons": "dialyser",
    "dialysâmes": "dialyser",
    "dialysât": "dialyser",
    "dialysâtes": "dialyser",
    "dialysèrent": "dialyser",
    "dialysé": "dialyser",
    "dialysée": "dialyser",
    "dialysées": "dialyser",
    "dialysés": "dialyser",
    "diamantaires": "diamantaire",
    "diamante": "diamanter",
    "diamantine": "diamantin",
    "diamantines": "diamantin",
    "diamantins": "diamantin",
    "diamants": "diamant",
    "diamanté": "diamanter",
    "diamantée": "diamanter",
    "diamantés": "diamanté",
    "diams": "diam",
    "diamètres": "diamètre",
    "diamétrale": "diamétral",
    "diamétrales": "diamétral",
    "diamétraux": "diamétral",
    "dianes": "diane",
    "diapasons": "diapason",
    "diaphanes": "diaphane",
    "diaphragma": "diaphragmer",
    "diaphragmes": "diaphragme",
    "diaporamas": "diaporama",
    "diapos": "diapo",
    "diapositifs": "diapositif",
    "diapositive": "diapositif",
    "diapositives": "diapositive",
    "diapra": "diaprer",
    "diaprai": "diaprer",
    "diapraient": "diaprer",
    "diaprais": "diaprer",
    "diaprait": "diaprer",
    "diaprant": "diaprer",
    "diapras": "diaprer",
    "diaprasse": "diaprer",
    "diaprassent": "diaprer",
    "diaprasses": "diaprer",
    "diaprassiez": "diaprer",
    "diaprassions": "diaprer",
    "diapre": "diaprer",
    "diaprent": "diaprer",
    "diaprera": "diaprer",
    "diaprerai": "diaprer",
    "diapreraient": "diaprer",
    "diaprerais": "diaprer",
    "diaprerait": "diaprer",
    "diapreras": "diaprer",
    "diaprerez": "diaprer",
    "diapreriez": "diaprer",
    "diaprerions": "diaprer",
    "diaprerons": "diaprer",
    "diapreront": "diaprer",
    "diapres": "diaprer",
    "diaprez": "diaprer",
    "diapriez": "diaprer",
    "diaprions": "diaprer",
    "diaprons": "diaprer",
    "diaprures": "diaprure",
    "diaprâmes": "diaprer",
    "diaprât": "diaprer",
    "diaprâtes": "diaprer",
    "diaprèrent": "diaprer",
    "diapré": "diaprer",
    "diaprée": "diaprer",
    "diaprées": "diaprer",
    "diaprés": "diaprer",
    "diapédèses": "diapédèse",
    "diarrhées": "diarrhée",
    "diasporas": "diaspora",
    "diastases": "diastase",
    "diastoles": "diastole",
    "diastoliques": "diastolique",
    "diatomées": "diatomée",
    "diatribes": "diatribe",
    "dicastères": "dicastère",
    "dichotomies": "dichotomie",
    "dicos": "dico",
    "dicotylédones": "dicotylédone",
    "dicta": "dicter",
    "dictai": "dicter",
    "dictaient": "dicter",
    "dictais": "dicter",
    "dictait": "dicter",
    "dictames": "dictame",
    "dictant": "dicter",
    "dictaphones": "dictaphone",
    "dictas": "dicter",
    "dictasse": "dicter",
    "dictassent": "dicter",
    "dictasses": "dicter",
    "dictassiez": "dicter",
    "dictassions": "dicter",
    "dictateurs": "dictateur",
    "dictatoriale": "dictatorial",
    "dictatoriales": "dictatorial",
    "dictatoriaux": "dictatorial",
    "dictatrice": "dictateur",
    "dictats": "dictat",
    "dictatures": "dictature",
    "dicte": "dicter",
    "dictent": "dicter",
    "dictera": "dicter",
    "dicterai": "dicter",
    "dicteraient": "dicter",
    "dicterais": "dicter",
    "dicterait": "dicter",
    "dicteras": "dicter",
    "dicterez": "dicter",
    "dicteriez": "dicter",
    "dicterions": "dicter",
    "dicterons": "dicter",
    "dicteront": "dicter",
    "dictes": "dicter",
    "dictez": "dicter",
    "dictiez": "dicter",
    "dictionnaires": "dictionnaire",
    "dictions": "diction",
    "dictons": "dicton",
    "dictâmes": "dicter",
    "dictât": "dicter",
    "dictâtes": "dicter",
    "dictèrent": "dicter",
    "dicté": "dicter",
    "dictée": "dicter",
    "dictées": "dicter",
    "dictés": "dicter",
    "didactiques": "didactique",
    "didanosines": "didanosine",
    "dieppoise": "dieppois",
    "dieppoises": "dieppois",
    "diesels": "diesel",
    "dieux": "dieu",
    "diffama": "diffamer",
    "diffamai": "diffamer",
    "diffamaient": "diffamer",
    "diffamais": "diffamer",
    "diffamait": "diffamer",
    "diffamant": "diffamer",
    "diffamas": "diffamer",
    "diffamasse": "diffamer",
    "diffamassent": "diffamer",
    "diffamasses": "diffamer",
    "diffamassiez": "diffamer",
    "diffamassions": "diffamer",
    "diffamateurs": "diffamateur",
    "diffamations": "diffamation",
    "diffamatoires": "diffamatoire",
    "diffamatrice": "diffamateur",
    "diffame": "diffamer",
    "diffament": "diffamer",
    "diffamera": "diffamer",
    "diffamerai": "diffamer",
    "diffameraient": "diffamer",
    "diffamerais": "diffamer",
    "diffamerait": "diffamer",
    "diffameras": "diffamer",
    "diffamerez": "diffamer",
    "diffameriez": "diffamer",
    "diffamerions": "diffamer",
    "diffamerons": "diffamer",
    "diffameront": "diffamer",
    "diffames": "diffamer",
    "diffamez": "diffamer",
    "diffamiez": "diffamer",
    "diffamions": "diffamer",
    "diffamons": "diffamer",
    "diffamâmes": "diffamer",
    "diffamât": "diffamer",
    "diffamâtes": "diffamer",
    "diffamèrent": "diffamer",
    "diffamé": "diffamer",
    "diffamée": "diffamer",
    "diffamées": "diffamer",
    "diffamés": "diffamer",
    "difficiles": "difficile",
    "difficultés": "difficulté",
    "difforma": "difformer",
    "difformai": "difformer",
    "difformaient": "difformer",
    "difformais": "difformer",
    "difformait": "difformer",
    "difformant": "difformer",
    "difformas": "difformer",
    "difformasse": "difformer",
    "difformassent": "difformer",
    "difformasses": "difformer",
    "difformassiez": "difformer",
    "difformassions": "difformer",
    "difforme": "difformer",
    "difforment": "difformer",
    "difformera": "difformer",
    "difformerai": "difformer",
    "difformeraient": "difformer",
    "difformerais": "difformer",
    "difformerait": "difformer",
    "difformeras": "difformer",
    "difformerez": "difformer",
    "difformeriez": "difformer",
    "difformerions": "difformer",
    "difformerons": "difformer",
    "difformeront": "difformer",
    "difformes": "difformer",
    "difformez": "difformer",
    "difformiez": "difformer",
    "difformions": "difformer",
    "difformités": "difformité",
    "difformons": "difformer",
    "difformâmes": "difformer",
    "difformât": "difformer",
    "difformâtes": "difformer",
    "difformèrent": "difformer",
    "difformé": "difformer",
    "difformée": "difformer",
    "difformées": "difformer",
    "difformés": "difformer",
    "diffracta": "diffracter",
    "diffractai": "diffracter",
    "diffractaient": "diffracter",
    "diffractais": "diffracter",
    "diffractait": "diffracter",
    "diffractant": "diffracter",
    "diffractas": "diffracter",
    "diffractasse": "diffracter",
    "diffractassent": "diffracter",
    "diffractasses": "diffracter",
    "diffractassiez": "diffracter",
    "diffractassions": "diffracter",
    "diffracte": "diffracter",
    "diffractent": "diffracter",
    "diffractera": "diffracter",
    "diffracterai": "diffracter",
    "diffracteraient": "diffracter",
    "diffracterais": "diffracter",
    "diffracterait": "diffracter",
    "diffracteras": "diffracter",
    "diffracterez": "diffracter",
    "diffracteriez": "diffracter",
    "diffracterions": "diffracter",
    "diffracterons": "diffracter",
    "diffracteront": "diffracter",
    "diffractes": "diffracter",
    "diffractez": "diffracter",
    "diffractiez": "diffracter",
    "diffractions": "diffracter",
    "diffractons": "diffracter",
    "diffractâmes": "diffracter",
    "diffractât": "diffracter",
    "diffractâtes": "diffracter",
    "diffractèrent": "diffracter",
    "diffracté": "diffracter",
    "diffractée": "diffracter",
    "diffractées": "diffracter",
    "diffractés": "diffracter",
    "diffusa": "diffuser",
    "diffusai": "diffuser",
    "diffusaient": "diffuser",
    "diffusais": "diffuser",
    "diffusait": "diffuser",
    "diffusant": "diffuser",
    "diffusas": "diffuser",
    "diffusasse": "diffuser",
    "diffusassent": "diffuser",
    "diffusasses": "diffuser",
    "diffusassiez": "diffuser",
    "diffusassions": "diffuser",
    "diffuse": "diffuser",
    "diffusent": "diffuser",
    "diffusera": "diffuser",
    "diffuserai": "diffuser",
    "diffuseraient": "diffuser",
    "diffuserais": "diffuser",
    "diffuserait": "diffuser",
    "diffuseras": "diffuser",
    "diffuserez": "diffuser",
    "diffuseriez": "diffuser",
    "diffuserions": "diffuser",
    "diffuserons": "diffuser",
    "diffuseront": "diffuser",
    "diffuses": "diffuser",
    "diffuseurs": "diffuseur",
    "diffusez": "diffuser",
    "diffusiez": "diffuser",
    "diffusions": "diffusion",
    "diffusons": "diffuser",
    "diffusâmes": "diffuser",
    "diffusât": "diffuser",
    "diffusâtes": "diffuser",
    "diffusèrent": "diffuser",
    "diffusé": "diffuser",
    "diffusée": "diffuser",
    "diffusées": "diffuser",
    "diffusés": "diffuser",
    "diffère": "différer",
    "diffèrent": "différer",
    "diffères": "différer",
    "différa": "différer",
    "différai": "différer",
    "différaient": "différer",
    "différais": "différer",
    "différait": "différer",
    "différant": "différer",
    "différas": "différer",
    "différasse": "différer",
    "différassent": "différer",
    "différasses": "différer",
    "différassiez": "différer",
    "différassions": "différer",
    "différences": "différence",
    "différencia": "différencier",
    "différenciables": "différenciable",
    "différenciai": "différencier",
    "différenciaient": "différencier",
    "différenciais": "différencier",
    "différenciait": "différencier",
    "différenciant": "différencier",
    "différencias": "différencier",
    "différenciasse": "différencier",
    "différenciassent": "différencier",
    "différenciasses": "différencier",
    "différenciassiez": "différencier",
    "différenciassions": "différencier",
    "différenciations": "différenciation",
    "différencie": "différencier",
    "différencient": "différencier",
    "différenciera": "différencier",
    "différencierai": "différencier",
    "différencieraient": "différencier",
    "différencierais": "différencier",
    "différencierait": "différencier",
    "différencieras": "différencier",
    "différencierez": "différencier",
    "différencieriez": "différencier",
    "différencierions": "différencier",
    "différencierons": "différencier",
    "différencieront": "différencier",
    "différencies": "différencier",
    "différenciez": "différencier",
    "différenciiez": "différencier",
    "différenciions": "différencier",
    "différencions": "différencier",
    "différenciâmes": "différencier",
    "différenciât": "différencier",
    "différenciâtes": "différencier",
    "différencièrent": "différencier",
    "différencié": "différencier",
    "différenciée": "différencier",
    "différenciées": "différencier",
    "différenciés": "différencier",
    "différends": "différend",
    "différente": "différent",
    "différentes": "différents",
    "différentie": "différentier",
    "différentielle": "différentiel",
    "différentielles": "différentiel",
    "différentiels": "différentiel",
    "différents": "différent",
    "différera": "différer",
    "différerai": "différer",
    "différeraient": "différer",
    "différerais": "différer",
    "différerait": "différer",
    "différeras": "différer",
    "différerez": "différer",
    "différeriez": "différer",
    "différerions": "différer",
    "différerons": "différer",
    "différeront": "différer",
    "différez": "différer",
    "différiez": "différer",
    "différions": "différer",
    "différons": "différer",
    "différâmes": "différer",
    "différât": "différer",
    "différâtes": "différer",
    "différèrent": "différer",
    "différé": "différer",
    "différée": "différer",
    "différées": "différer",
    "différés": "différer",
    "digestes": "digeste",
    "digestibles": "digestible",
    "digestifs": "digestif",
    "digestions": "digestion",
    "digestive": "digestif",
    "digestives": "digestif",
    "digests": "digest",
    "digitale": "digital",
    "digitales": "digitale",
    "digitalisée": "digitaliser",
    "digitalisées": "digitaliser",
    "digitaux": "digital",
    "digitée": "digité",
    "dignes": "digne",
    "dignitaires": "dignitaire",
    "dignités": "dignité",
    "digresse": "digresser",
    "digressions": "digression",
    "digues": "digue",
    "digère": "digérer",
    "digèrent": "digérer",
    "digères": "digérer",
    "digéra": "digérer",
    "digérai": "digérer",
    "digéraient": "digérer",
    "digérais": "digérer",
    "digérait": "digérer",
    "digérant": "digérer",
    "digéras": "digérer",
    "digérasse": "digérer",
    "digérassent": "digérer",
    "digérasses": "digérer",
    "digérassiez": "digérer",
    "digérassions": "digérer",
    "digérera": "digérer",
    "digérerai": "digérer",
    "digéreraient": "digérer",
    "digérerais": "digérer",
    "digérerait": "digérer",
    "digéreras": "digérer",
    "digérerez": "digérer",
    "digéreriez": "digérer",
    "digérerions": "digérer",
    "digérerons": "digérer",
    "digéreront": "digérer",
    "digérez": "digérer",
    "digériez": "digérer",
    "digérions": "digérer",
    "digérons": "digérer",
    "digérâmes": "digérer",
    "digérât": "digérer",
    "digérâtes": "digérer",
    "digérèrent": "digérer",
    "digéré": "digérer",
    "digérée": "digérer",
    "digérées": "digérer",
    "digérés": "digérer",
    "dijonnaise": "dijonnais",
    "dijonnaises": "dijonnais",
    "diktats": "diktat",
    "dilacère": "dilacérer",
    "dilacèrent": "dilacérer",
    "dilacères": "dilacérer",
    "dilacéra": "dilacérer",
    "dilacérai": "dilacérer",
    "dilacéraient": "dilacérer",
    "dilacérais": "dilacérer",
    "dilacérait": "dilacérer",
    "dilacérant": "dilacérer",
    "dilacéras": "dilacérer",
    "dilacérasse": "dilacérer",
    "dilacérassent": "dilacérer",
    "dilacérasses": "dilacérer",
    "dilacérassiez": "dilacérer",
    "dilacérassions": "dilacérer",
    "dilacérera": "dilacérer",
    "dilacérerai": "dilacérer",
    "dilacéreraient": "dilacérer",
    "dilacérerais": "dilacérer",
    "dilacérerait": "dilacérer",
    "dilacéreras": "dilacérer",
    "dilacérerez": "dilacérer",
    "dilacéreriez": "dilacérer",
    "dilacérerions": "dilacérer",
    "dilacérerons": "dilacérer",
    "dilacéreront": "dilacérer",
    "dilacérez": "dilacérer",
    "dilacériez": "dilacérer",
    "dilacérions": "dilacérer",
    "dilacérons": "dilacérer",
    "dilacérâmes": "dilacérer",
    "dilacérât": "dilacérer",
    "dilacérâtes": "dilacérer",
    "dilacérèrent": "dilacérer",
    "dilacéré": "dilacérer",
    "dilacérée": "dilacérer",
    "dilacérées": "dilacérer",
    "dilacérés": "dilacérer",
    "dilapida": "dilapider",
    "dilapidai": "dilapider",
    "dilapidaient": "dilapider",
    "dilapidais": "dilapider",
    "dilapidait": "dilapider",
    "dilapidant": "dilapider",
    "dilapidas": "dilapider",
    "dilapidasse": "dilapider",
    "dilapidassent": "dilapider",
    "dilapidasses": "dilapider",
    "dilapidassiez": "dilapider",
    "dilapidassions": "dilapider",
    "dilapidations": "dilapidation",
    "dilapide": "dilapider",
    "dilapident": "dilapider",
    "dilapidera": "dilapider",
    "dilapiderai": "dilapider",
    "dilapideraient": "dilapider",
    "dilapiderais": "dilapider",
    "dilapiderait": "dilapider",
    "dilapideras": "dilapider",
    "dilapiderez": "dilapider",
    "dilapideriez": "dilapider",
    "dilapiderions": "dilapider",
    "dilapiderons": "dilapider",
    "dilapideront": "dilapider",
    "dilapides": "dilapider",
    "dilapidez": "dilapider",
    "dilapidiez": "dilapider",
    "dilapidions": "dilapider",
    "dilapidons": "dilapider",
    "dilapidâmes": "dilapider",
    "dilapidât": "dilapider",
    "dilapidâtes": "dilapider",
    "dilapidèrent": "dilapider",
    "dilapidé": "dilapider",
    "dilapidée": "dilapider",
    "dilapidées": "dilapider",
    "dilapidés": "dilapider",
    "dilata": "dilater",
    "dilatai": "dilater",
    "dilataient": "dilater",
    "dilatais": "dilater",
    "dilatait": "dilater",
    "dilatant": "dilater",
    "dilatas": "dilater",
    "dilatasse": "dilater",
    "dilatassent": "dilater",
    "dilatasses": "dilater",
    "dilatassiez": "dilater",
    "dilatassions": "dilater",
    "dilatateurs": "dilatateur",
    "dilatations": "dilatation",
    "dilate": "dilater",
    "dilatent": "dilater",
    "dilatera": "dilater",
    "dilaterai": "dilater",
    "dilateraient": "dilater",
    "dilaterais": "dilater",
    "dilaterait": "dilater",
    "dilateras": "dilater",
    "dilaterez": "dilater",
    "dilateriez": "dilater",
    "dilaterions": "dilater",
    "dilaterons": "dilater",
    "dilateront": "dilater",
    "dilates": "dilater",
    "dilatez": "dilater",
    "dilatiez": "dilater",
    "dilations": "dilater",
    "dilatoires": "dilatoire",
    "dilatons": "dilater",
    "dilatâmes": "dilater",
    "dilatât": "dilater",
    "dilatâtes": "dilater",
    "dilatèrent": "dilater",
    "dilaté": "dilater",
    "dilatée": "dilater",
    "dilatées": "dilater",
    "dilatés": "dilater",
    "dilections": "dilection",
    "dilemmes": "dilemme",
    "dilettantes": "dilettante",
    "dilettantismes": "dilettantisme",
    "diligences": "diligence",
    "diligente": "diligent",
    "diligentes": "diligent",
    "diligents": "diligent",
    "dilua": "diluer",
    "diluai": "diluer",
    "diluaient": "diluer",
    "diluais": "diluer",
    "diluait": "diluer",
    "diluant": "diluer",
    "diluas": "diluer",
    "diluasse": "diluer",
    "diluassent": "diluer",
    "diluasses": "diluer",
    "diluassiez": "diluer",
    "diluassions": "diluer",
    "dilue": "diluer",
    "diluent": "diluer",
    "diluera": "diluer",
    "diluerai": "diluer",
    "dilueraient": "diluer",
    "diluerais": "diluer",
    "diluerait": "diluer",
    "dilueras": "diluer",
    "diluerez": "diluer",
    "dilueriez": "diluer",
    "diluerions": "diluer",
    "diluerons": "diluer",
    "dilueront": "diluer",
    "dilues": "diluer",
    "diluez": "diluer",
    "diluiez": "diluer",
    "diluions": "diluer",
    "diluons": "diluer",
    "dilutions": "dilution",
    "diluvienne": "diluvien",
    "diluviennes": "diluvien",
    "diluviens": "diluvien",
    "diluâmes": "diluer",
    "diluât": "diluer",
    "diluâtes": "diluer",
    "diluèrent": "diluer",
    "dilué": "diluer",
    "diluée": "diluer",
    "diluées": "diluer",
    "dilués": "diluer",
    "dimanches": "dimanche",
    "dimensionnelle": "dimensionnel",
    "dimensionnelles": "dimensionnel",
    "dimensionnels": "dimensionnel",
    "dimensions": "dimension",
    "diminua": "diminuer",
    "diminuai": "diminuer",
    "diminuaient": "diminuer",
    "diminuais": "diminuer",
    "diminuait": "diminuer",
    "diminuant": "diminuer",
    "diminuas": "diminuer",
    "diminuasse": "diminuer",
    "diminuassent": "diminuer",
    "diminuasses": "diminuer",
    "diminuassiez": "diminuer",
    "diminuassions": "diminuer",
    "diminue": "diminuer",
    "diminuent": "diminuer",
    "diminuera": "diminuer",
    "diminuerai": "diminuer",
    "diminueraient": "diminuer",
    "diminuerais": "diminuer",
    "diminuerait": "diminuer",
    "diminueras": "diminuer",
    "diminuerez": "diminuer",
    "diminueriez": "diminuer",
    "diminuerions": "diminuer",
    "diminuerons": "diminuer",
    "diminueront": "diminuer",
    "diminues": "diminuer",
    "diminuez": "diminuer",
    "diminuiez": "diminuer",
    "diminuions": "diminuer",
    "diminuons": "diminuer",
    "diminutifs": "diminutif",
    "diminutions": "diminution",
    "diminuâmes": "diminuer",
    "diminuât": "diminuer",
    "diminuâtes": "diminuer",
    "diminuèrent": "diminuer",
    "diminué": "diminuer",
    "diminuée": "diminuer",
    "diminuées": "diminuer",
    "diminués": "diminuer",
    "dinamiteros": "dinamitero",
    "dinars": "dinar",
    "dindes": "dinde",
    "dindonne": "dindonner",
    "dindonneaux": "dindonneau",
    "dindonné": "dindonner",
    "dindons": "dindon",
    "dinghies": "dinghy",
    "dinghys": "dinghy",
    "dingos": "dingo",
    "dingue": "dinguer",
    "dinguent": "dinguer",
    "dingueries": "dinguerie",
    "dingues": "dingue",
    "dingué": "dinguer",
    "dinosaures": "dinosaure",
    "dioclétienne": "dioclétien",
    "dioclétiennes": "dioclétien",
    "diocèses": "diocèse",
    "diocésaine": "diocésain",
    "diocésaines": "diocésain",
    "diocésains": "diocésain",
    "dionysiaques": "dionysiaque",
    "dioptries": "dioptrie",
    "dioramas": "diorama",
    "diorites": "diorite",
    "dioxines": "dioxine",
    "dioxydes": "dioxyde",
    "diphtongaisons": "diphtongaison",
    "diphtongua": "diphtonguer",
    "diphtonguai": "diphtonguer",
    "diphtonguaient": "diphtonguer",
    "diphtonguais": "diphtonguer",
    "diphtonguait": "diphtonguer",
    "diphtonguant": "diphtonguer",
    "diphtonguas": "diphtonguer",
    "diphtonguasse": "diphtonguer",
    "diphtonguassent": "diphtonguer",
    "diphtonguasses": "diphtonguer",
    "diphtonguassiez": "diphtonguer",
    "diphtonguassions": "diphtonguer",
    "diphtongue": "diphtonguer",
    "diphtonguent": "diphtonguer",
    "diphtonguera": "diphtonguer",
    "diphtonguerai": "diphtonguer",
    "diphtongueraient": "diphtonguer",
    "diphtonguerais": "diphtonguer",
    "diphtonguerait": "diphtonguer",
    "diphtongueras": "diphtonguer",
    "diphtonguerez": "diphtonguer",
    "diphtongueriez": "diphtonguer",
    "diphtonguerions": "diphtonguer",
    "diphtonguerons": "diphtonguer",
    "diphtongueront": "diphtonguer",
    "diphtongues": "diphtonguer",
    "diphtonguez": "diphtonguer",
    "diphtonguiez": "diphtonguer",
    "diphtonguions": "diphtonguer",
    "diphtonguons": "diphtonguer",
    "diphtonguâmes": "diphtonguer",
    "diphtonguât": "diphtonguer",
    "diphtonguâtes": "diphtonguer",
    "diphtonguèrent": "diphtonguer",
    "diphtongué": "diphtonguer",
    "diphtonguée": "diphtonguer",
    "diphtonguées": "diphtonguer",
    "diphtongués": "diphtonguer",
    "diphtéries": "diphtérie",
    "diplomates": "diplomate",
    "diplomaties": "diplomatie",
    "diplomatiques": "diplomatique",
    "diplômes": "diplôme",
    "diplômé": "diplômer",
    "diplômée": "diplômer",
    "diplômées": "diplômer",
    "diplômés": "diplômer",
    "dipneustes": "dipneuste",
    "dipsomanes": "dipsomane",
    "diptyques": "diptyque",
    "diptères": "diptère",
    "dira": "dire",
    "dirai": "dire",
    "diraient": "dire",
    "dirais": "dire",
    "dirait": "dire",
    "diras": "dire",
    "directe": "direct",
    "directes": "direct",
    "directeurs": "directeur",
    "directifs": "directif",
    "directionnelle": "directionnel",
    "directionnelles": "directionnel",
    "directionnels": "directionnel",
    "directions": "direction",
    "directive": "directif",
    "directives": "directive",
    "directoires": "directoire",
    "directorats": "directorat",
    "directoriale": "directorial",
    "directoriales": "directorial",
    "directoriaux": "directorial",
    "directrice": "directeur",
    "directrices": "directeur",
    "directs": "direct",
    "dirent": "dire",
    "dires": "dire",
    "direz": "dire",
    "dirhams": "dirham",
    "diriez": "dire",
    "dirige": "diriger",
    "dirigea": "diriger",
    "dirigeables": "dirigeable",
    "dirigeai": "diriger",
    "dirigeaient": "diriger",
    "dirigeais": "diriger",
    "dirigeait": "diriger",
    "dirigeant": "diriger",
    "dirigeante": "dirigeant",
    "dirigeantes": "dirigeant",
    "dirigeants": "dirigeant",
    "dirigeas": "diriger",
    "dirigeasse": "diriger",
    "dirigeassent": "diriger",
    "dirigeasses": "diriger",
    "dirigeassiez": "diriger",
    "dirigeassions": "diriger",
    "dirigent": "diriger",
    "dirigeons": "diriger",
    "dirigera": "diriger",
    "dirigerai": "diriger",
    "dirigeraient": "diriger",
    "dirigerais": "diriger",
    "dirigerait": "diriger",
    "dirigeras": "diriger",
    "dirigerez": "diriger",
    "dirigeriez": "diriger",
    "dirigerions": "diriger",
    "dirigerons": "diriger",
    "dirigeront": "diriger",
    "diriges": "diriger",
    "dirigez": "diriger",
    "dirigeâmes": "diriger",
    "dirigeât": "diriger",
    "dirigeâtes": "diriger",
    "dirigiez": "diriger",
    "dirigions": "diriger",
    "dirigismes": "dirigisme",
    "dirigistes": "dirigiste",
    "dirigèrent": "diriger",
    "dirigé": "diriger",
    "dirigée": "diriger",
    "dirigées": "diriger",
    "dirigés": "diriger",
    "dirimante": "dirimant",
    "dirimantes": "dirimant",
    "dirimants": "dirimant",
    "dirions": "dire",
    "dirlos": "dirlo",
    "dirons": "dire",
    "diront": "dire",
    "dis": "dire",
    "disaient": "dire",
    "disais": "dire",
    "disait": "dire",
    "disant": "dire",
    "disante": "disant",
    "disantes": "disant",
    "disants": "disant",
    "disc-jockeys": "disc-jockey",
    "discale": "discal",
    "discales": "discal",
    "discaux": "discal",
    "discerna": "discerner",
    "discernables": "discernable",
    "discernai": "discerner",
    "discernaient": "discerner",
    "discernais": "discerner",
    "discernait": "discerner",
    "discernant": "discerner",
    "discernas": "discerner",
    "discernasse": "discerner",
    "discernassent": "discerner",
    "discernasses": "discerner",
    "discernassiez": "discerner",
    "discernassions": "discerner",
    "discerne": "discerner",
    "discernements": "discernement",
    "discernent": "discerner",
    "discernera": "discerner",
    "discernerai": "discerner",
    "discerneraient": "discerner",
    "discernerais": "discerner",
    "discernerait": "discerner",
    "discerneras": "discerner",
    "discernerez": "discerner",
    "discerneriez": "discerner",
    "discernerions": "discerner",
    "discernerons": "discerner",
    "discerneront": "discerner",
    "discernes": "discerner",
    "discernez": "discerner",
    "discerniez": "discerner",
    "discernions": "discerner",
    "discernons": "discerner",
    "discernâmes": "discerner",
    "discernât": "discerner",
    "discernâtes": "discerner",
    "discernèrent": "discerner",
    "discerné": "discerner",
    "discernée": "discerner",
    "discernées": "discerner",
    "discernés": "discerner",
    "disciples": "disciple",
    "disciplina": "discipliner",
    "disciplinai": "discipliner",
    "disciplinaient": "discipliner",
    "disciplinaires": "disciplinaire",
    "disciplinais": "discipliner",
    "disciplinait": "discipliner",
    "disciplinant": "discipliner",
    "disciplinas": "discipliner",
    "disciplinasse": "discipliner",
    "disciplinassent": "discipliner",
    "disciplinasses": "discipliner",
    "disciplinassiez": "discipliner",
    "disciplinassions": "discipliner",
    "discipline": "discipliner",
    "disciplinent": "discipliner",
    "disciplinera": "discipliner",
    "disciplinerai": "discipliner",
    "disciplineraient": "discipliner",
    "disciplinerais": "discipliner",
    "disciplinerait": "discipliner",
    "disciplineras": "discipliner",
    "disciplinerez": "discipliner",
    "disciplineriez": "discipliner",
    "disciplinerions": "discipliner",
    "disciplinerons": "discipliner",
    "disciplineront": "discipliner",
    "disciplines": "discipliner",
    "disciplinez": "discipliner",
    "discipliniez": "discipliner",
    "disciplinions": "discipliner",
    "disciplinons": "discipliner",
    "disciplinâmes": "discipliner",
    "disciplinât": "discipliner",
    "disciplinâtes": "discipliner",
    "disciplinèrent": "discipliner",
    "discipliné": "discipliner",
    "disciplinée": "discipliner",
    "disciplinées": "discipliner",
    "disciplinés": "discipliner",
    "discoboles": "discobole",
    "discographiques": "discographique",
    "discontinua": "discontinuer",
    "discontinuai": "discontinuer",
    "discontinuaient": "discontinuer",
    "discontinuais": "discontinuer",
    "discontinuait": "discontinuer",
    "discontinuant": "discontinuer",
    "discontinuas": "discontinuer",
    "discontinuasse": "discontinuer",
    "discontinuassent": "discontinuer",
    "discontinuasses": "discontinuer",
    "discontinuassiez": "discontinuer",
    "discontinuassions": "discontinuer",
    "discontinue": "discontinuer",
    "discontinuent": "discontinuer",
    "discontinuera": "discontinuer",
    "discontinuerai": "discontinuer",
    "discontinueraient": "discontinuer",
    "discontinuerais": "discontinuer",
    "discontinuerait": "discontinuer",
    "discontinueras": "discontinuer",
    "discontinuerez": "discontinuer",
    "discontinueriez": "discontinuer",
    "discontinuerions": "discontinuer",
    "discontinuerons": "discontinuer",
    "discontinueront": "discontinuer",
    "discontinues": "discontinuer",
    "discontinuez": "discontinuer",
    "discontinuiez": "discontinuer",
    "discontinuions": "discontinuer",
    "discontinuons": "discontinuer",
    "discontinus": "discontinu",
    "discontinuâmes": "discontinuer",
    "discontinuât": "discontinuer",
    "discontinuâtes": "discontinuer",
    "discontinuèrent": "discontinuer",
    "discontinué": "discontinuer",
    "discontinuée": "discontinuer",
    "discontinuées": "discontinuer",
    "discontinués": "discontinuer",
    "disconvenaient": "disconvenir",
    "disconvenais": "disconvenir",
    "disconvenait": "disconvenir",
    "disconvenant": "disconvenir",
    "disconvenez": "disconvenir",
    "disconveniez": "disconvenir",
    "disconvenions": "disconvenir",
    "disconvenons": "disconvenir",
    "disconvenu": "disconvenir",
    "disconviendra": "disconvenir",
    "disconviendrai": "disconvenir",
    "disconviendraient": "disconvenir",
    "disconviendrais": "disconvenir",
    "disconviendrait": "disconvenir",
    "disconviendras": "disconvenir",
    "disconviendrez": "disconvenir",
    "disconviendriez": "disconvenir",
    "disconviendrions": "disconvenir",
    "disconviendrons": "disconvenir",
    "disconviendront": "disconvenir",
    "disconvienne": "disconvenir",
    "disconviennent": "disconvenir",
    "disconviennes": "disconvenir",
    "disconviens": "disconvenir",
    "disconvient": "disconvenir",
    "disconvinrent": "disconvenir",
    "disconvins": "disconvenir",
    "disconvinsse": "disconvenir",
    "disconvinssent": "disconvenir",
    "disconvinsses": "disconvenir",
    "disconvinssiez": "disconvenir",
    "disconvinssions": "disconvenir",
    "disconvint": "disconvenir",
    "disconvînmes": "disconvenir",
    "disconvînt": "disconvenir",
    "disconvîntes": "disconvenir",
    "discophiles": "discophile",
    "discordances": "discordance",
    "discordant": "discorder",
    "discordante": "discordant",
    "discordantes": "discordant",
    "discordants": "discordant",
    "discordes": "discorde",
    "discos": "disco",
    "discothèques": "discothèque",
    "discounts": "discount",
    "discouraient": "discourir",
    "discourais": "discourir",
    "discourait": "discourir",
    "discourant": "discourir",
    "discoure": "discourir",
    "discourent": "discourir",
    "discoures": "discourir",
    "discoureurs": "discoureur",
    "discourez": "discourir",
    "discouriez": "discourir",
    "discourions": "discourir",
    "discourons": "discourir",
    "discourra": "discourir",
    "discourrai": "discourir",
    "discourraient": "discourir",
    "discourrais": "discourir",
    "discourrait": "discourir",
    "discourras": "discourir",
    "discourrez": "discourir",
    "discourriez": "discourir",
    "discourrions": "discourir",
    "discourrons": "discourir",
    "discourront": "discourir",
    "discours": "discourir",
    "discourt": "discourir",
    "discourtoise": "discourtois",
    "discourtoises": "discourtois",
    "discouru": "discourir",
    "discoururent": "discourir",
    "discourus": "discourir",
    "discourusse": "discourir",
    "discourussent": "discourir",
    "discourusses": "discourir",
    "discourussiez": "discourir",
    "discourussions": "discourir",
    "discourut": "discourir",
    "discourûmes": "discourir",
    "discourût": "discourir",
    "discourûtes": "discourir",
    "discrets": "discret",
    "discrimina": "discriminer",
    "discriminai": "discriminer",
    "discriminaient": "discriminer",
    "discriminais": "discriminer",
    "discriminait": "discriminer",
    "discriminant": "discriminer",
    "discriminants": "discriminant",
    "discriminas": "discriminer",
    "discriminasse": "discriminer",
    "discriminassent": "discriminer",
    "discriminasses": "discriminer",
    "discriminassiez": "discriminer",
    "discriminassions": "discriminer",
    "discriminations": "discrimination",
    "discriminatoires": "discriminatoire",
    "discrimine": "discriminer",
    "discriminent": "discriminer",
    "discriminera": "discriminer",
    "discriminerai": "discriminer",
    "discrimineraient": "discriminer",
    "discriminerais": "discriminer",
    "discriminerait": "discriminer",
    "discrimineras": "discriminer",
    "discriminerez": "discriminer",
    "discrimineriez": "discriminer",
    "discriminerions": "discriminer",
    "discriminerons": "discriminer",
    "discrimineront": "discriminer",
    "discrimines": "discriminer",
    "discriminez": "discriminer",
    "discriminiez": "discriminer",
    "discriminions": "discriminer",
    "discriminons": "discriminer",
    "discriminâmes": "discriminer",
    "discriminât": "discriminer",
    "discriminâtes": "discriminer",
    "discriminèrent": "discriminer",
    "discriminé": "discriminer",
    "discriminée": "discriminer",
    "discriminées": "discriminer",
    "discriminés": "discriminer",
    "discrète": "discret",
    "discrètes": "discret",
    "discrédita": "discréditer",
    "discréditai": "discréditer",
    "discréditaient": "discréditer",
    "discréditais": "discréditer",
    "discréditait": "discréditer",
    "discréditant": "discréditer",
    "discréditas": "discréditer",
    "discréditasse": "discréditer",
    "discréditassent": "discréditer",
    "discréditasses": "discréditer",
    "discréditassiez": "discréditer",
    "discréditassions": "discréditer",
    "discrédite": "discréditer",
    "discréditent": "discréditer",
    "discréditera": "discréditer",
    "discréditerai": "discréditer",
    "discréditeraient": "discréditer",
    "discréditerais": "discréditer",
    "discréditerait": "discréditer",
    "discréditeras": "discréditer",
    "discréditerez": "discréditer",
    "discréditeriez": "discréditer",
    "discréditerions": "discréditer",
    "discréditerons": "discréditer",
    "discréditeront": "discréditer",
    "discrédites": "discréditer",
    "discréditez": "discréditer",
    "discréditiez": "discréditer",
    "discréditions": "discréditer",
    "discréditons": "discréditer",
    "discrédits": "discrédit",
    "discréditâmes": "discréditer",
    "discréditât": "discréditer",
    "discréditâtes": "discréditer",
    "discréditèrent": "discréditer",
    "discrédité": "discréditer",
    "discréditée": "discréditer",
    "discréditées": "discréditer",
    "discrédités": "discréditer",
    "discrétionnaires": "discrétionnaire",
    "discrétions": "discrétion",
    "disculpa": "disculper",
    "disculpai": "disculper",
    "disculpaient": "disculper",
    "disculpais": "disculper",
    "disculpait": "disculper",
    "disculpant": "disculper",
    "disculpas": "disculper",
    "disculpasse": "disculper",
    "disculpassent": "disculper",
    "disculpasses": "disculper",
    "disculpassiez": "disculper",
    "disculpassions": "disculper",
    "disculpe": "disculper",
    "disculpent": "disculper",
    "disculpera": "disculper",
    "disculperai": "disculper",
    "disculperaient": "disculper",
    "disculperais": "disculper",
    "disculperait": "disculper",
    "disculperas": "disculper",
    "disculperez": "disculper",
    "disculperiez": "disculper",
    "disculperions": "disculper",
    "disculperons": "disculper",
    "disculperont": "disculper",
    "disculpes": "disculper",
    "disculpez": "disculper",
    "disculpiez": "disculper",
    "disculpions": "disculper",
    "disculpons": "disculper",
    "disculpâmes": "disculper",
    "disculpât": "disculper",
    "disculpâtes": "disculper",
    "disculpèrent": "disculper",
    "disculpé": "disculper",
    "disculpée": "disculper",
    "disculpées": "disculper",
    "disculpés": "disculper",
    "discursifs": "discursif",
    "discursive": "discursif",
    "discursives": "discursif",
    "discussions": "discussion",
    "discuta": "discuter",
    "discutables": "discutable",
    "discutai": "discuter",
    "discutaient": "discuter",
    "discutaillaient": "discutailler",
    "discutaillait": "discutailler",
    "discutaille": "discutailler",
    "discutaillent": "discutailler",
    "discutailleries": "discutaillerie",
    "discutailleuse": "discutailleur",
    "discutais": "discuter",
    "discutait": "discuter",
    "discutant": "discuter",
    "discutas": "discuter",
    "discutasse": "discuter",
    "discutassent": "discuter",
    "discutasses": "discuter",
    "discutassiez": "discuter",
    "discutassions": "discuter",
    "discute": "discuter",
    "discutent": "discuter",
    "discutera": "discuter",
    "discuterai": "discuter",
    "discuteraient": "discuter",
    "discuterais": "discuter",
    "discuterait": "discuter",
    "discuteras": "discuter",
    "discuterez": "discuter",
    "discuteriez": "discuter",
    "discuterions": "discuter",
    "discuterons": "discuter",
    "discuteront": "discuter",
    "discutes": "discuter",
    "discutez": "discuter",
    "discutiez": "discuter",
    "discutions": "discuter",
    "discutons": "discuter",
    "discutâmes": "discuter",
    "discutât": "discuter",
    "discutâtes": "discuter",
    "discutèrent": "discuter",
    "discuté": "discuter",
    "discutée": "discuter",
    "discutées": "discuter",
    "discutés": "discuter",
    "dise": "dire",
    "disent": "dire",
    "diserte": "disert",
    "disertes": "disert",
    "diserts": "disert",
    "dises": "dire",
    "disettes": "disette",
    "diseurs": "diseur",
    "diseuse": "diseur",
    "diseuses": "diseur",
    "disgracia": "disgracier",
    "disgraciai": "disgracier",
    "disgraciaient": "disgracier",
    "disgraciais": "disgracier",
    "disgraciait": "disgracier",
    "disgraciant": "disgracier",
    "disgracias": "disgracier",
    "disgraciasse": "disgracier",
    "disgraciassent": "disgracier",
    "disgraciasses": "disgracier",
    "disgraciassiez": "disgracier",
    "disgraciassions": "disgracier",
    "disgracie": "disgracier",
    "disgracient": "disgracier",
    "disgraciera": "disgracier",
    "disgracierai": "disgracier",
    "disgracieraient": "disgracier",
    "disgracierais": "disgracier",
    "disgracierait": "disgracier",
    "disgracieras": "disgracier",
    "disgracierez": "disgracier",
    "disgracieriez": "disgracier",
    "disgracierions": "disgracier",
    "disgracierons": "disgracier",
    "disgracieront": "disgracier",
    "disgracies": "disgracier",
    "disgracieuse": "disgracieux",
    "disgracieuses": "disgracieux",
    "disgraciez": "disgracier",
    "disgraciiez": "disgracier",
    "disgraciions": "disgracier",
    "disgracions": "disgracier",
    "disgraciâmes": "disgracier",
    "disgraciât": "disgracier",
    "disgraciâtes": "disgracier",
    "disgracièrent": "disgracier",
    "disgracié": "disgracier",
    "disgraciée": "disgracier",
    "disgraciées": "disgracier",
    "disgraciés": "disgracier",
    "disgrâces": "disgrâce",
    "disiez": "dire",
    "disions": "dire",
    "disjoignaient": "disjoindre",
    "disjoignais": "disjoindre",
    "disjoignait": "disjoindre",
    "disjoignant": "disjoindre",
    "disjoigne": "disjoindre",
    "disjoignent": "disjoindre",
    "disjoignes": "disjoindre",
    "disjoignez": "disjoindre",
    "disjoigniez": "disjoindre",
    "disjoignions": "disjoindre",
    "disjoignirent": "disjoindre",
    "disjoignis": "disjoindre",
    "disjoignisse": "disjoindre",
    "disjoignissent": "disjoindre",
    "disjoignisses": "disjoindre",
    "disjoignissiez": "disjoindre",
    "disjoignissions": "disjoindre",
    "disjoignit": "disjoindre",
    "disjoignons": "disjoindre",
    "disjoignîmes": "disjoindre",
    "disjoignît": "disjoindre",
    "disjoignîtes": "disjoindre",
    "disjoindra": "disjoindre",
    "disjoindrai": "disjoindre",
    "disjoindraient": "disjoindre",
    "disjoindrais": "disjoindre",
    "disjoindrait": "disjoindre",
    "disjoindras": "disjoindre",
    "disjoindrez": "disjoindre",
    "disjoindriez": "disjoindre",
    "disjoindrions": "disjoindre",
    "disjoindrons": "disjoindre",
    "disjoindront": "disjoindre",
    "disjoins": "disjoindre",
    "disjoint": "disjoindre",
    "disjointe": "disjoint",
    "disjointes": "disjoint",
    "disjoints": "disjoint",
    "disjoncta": "disjoncter",
    "disjonctai": "disjoncter",
    "disjonctaient": "disjoncter",
    "disjonctais": "disjoncter",
    "disjonctait": "disjoncter",
    "disjonctant": "disjoncter",
    "disjonctas": "disjoncter",
    "disjonctasse": "disjoncter",
    "disjonctassent": "disjoncter",
    "disjonctasses": "disjoncter",
    "disjonctassiez": "disjoncter",
    "disjonctassions": "disjoncter",
    "disjoncte": "disjoncter",
    "disjonctent": "disjoncter",
    "disjonctera": "disjoncter",
    "disjoncterai": "disjoncter",
    "disjoncteraient": "disjoncter",
    "disjoncterais": "disjoncter",
    "disjoncterait": "disjoncter",
    "disjoncteras": "disjoncter",
    "disjoncterez": "disjoncter",
    "disjoncteriez": "disjoncter",
    "disjoncterions": "disjoncter",
    "disjoncterons": "disjoncter",
    "disjoncteront": "disjoncter",
    "disjonctes": "disjoncter",
    "disjoncteurs": "disjoncteur",
    "disjonctez": "disjoncter",
    "disjonctiez": "disjoncter",
    "disjonctions": "disjonction",
    "disjonctons": "disjoncter",
    "disjonctâmes": "disjoncter",
    "disjonctât": "disjoncter",
    "disjonctâtes": "disjoncter",
    "disjonctèrent": "disjoncter",
    "disjoncté": "disjoncter",
    "disjonctée": "disjoncter",
    "disjonctées": "disjoncter",
    "disjonctés": "disjoncter",
    "dislocations": "dislocation",
    "disloqua": "disloquer",
    "disloquai": "disloquer",
    "disloquaient": "disloquer",
    "disloquais": "disloquer",
    "disloquait": "disloquer",
    "disloquant": "disloquer",
    "disloquas": "disloquer",
    "disloquasse": "disloquer",
    "disloquassent": "disloquer",
    "disloquasses": "disloquer",
    "disloquassiez": "disloquer",
    "disloquassions": "disloquer",
    "disloque": "disloquer",
    "disloquent": "disloquer",
    "disloquera": "disloquer",
    "disloquerai": "disloquer",
    "disloqueraient": "disloquer",
    "disloquerais": "disloquer",
    "disloquerait": "disloquer",
    "disloqueras": "disloquer",
    "disloquerez": "disloquer",
    "disloqueriez": "disloquer",
    "disloquerions": "disloquer",
    "disloquerons": "disloquer",
    "disloqueront": "disloquer",
    "disloques": "disloquer",
    "disloquez": "disloquer",
    "disloquiez": "disloquer",
    "disloquions": "disloquer",
    "disloquons": "disloquer",
    "disloquâmes": "disloquer",
    "disloquât": "disloquer",
    "disloquâtes": "disloquer",
    "disloquèrent": "disloquer",
    "disloqué": "disloquer",
    "disloquée": "disloquer",
    "disloquées": "disloquer",
    "disloqués": "disloquer",
    "disons": "dire",
    "disparais": "disparaître",
    "disparaissaient": "disparaître",
    "disparaissais": "disparaître",
    "disparaissait": "disparaître",
    "disparaissant": "disparaître",
    "disparaissante": "disparaissant",
    "disparaisse": "disparaître",
    "disparaissent": "disparaître",
    "disparaisses": "disparaître",
    "disparaissez": "disparaître",
    "disparaissiez": "disparaître",
    "disparaissions": "disparaître",
    "disparaissons": "disparaître",
    "disparates": "disparate",
    "disparaît": "disparaître",
    "disparaîtra": "disparaître",
    "disparaîtrai": "disparaître",
    "disparaîtraient": "disparaître",
    "disparaîtrais": "disparaître",
    "disparaîtrait": "disparaître",
    "disparaîtras": "disparaître",
    "disparaîtrez": "disparaître",
    "disparaîtriez": "disparaître",
    "disparaîtrions": "disparaître",
    "disparaîtrons": "disparaître",
    "disparaîtront": "disparaître",
    "disparitions": "disparition",
    "disparités": "disparité",
    "disparu": "disparaître",
    "disparue": "disparu",
    "disparues": "disparu",
    "disparurent": "disparaître",
    "disparus": "disparu",
    "disparusse": "disparaître",
    "disparussent": "disparaître",
    "disparusses": "disparaître",
    "disparussiez": "disparaître",
    "disparussions": "disparaître",
    "disparut": "disparaître",
    "disparûmes": "disparaître",
    "disparût": "disparaître",
    "disparûtes": "disparaître",
    "dispatchais": "dispatcher",
    "dispatchait": "dispatcher",
    "dispatche": "dispatcher",
    "dispatchings": "dispatching",
    "dispendieuse": "dispendieux",
    "dispendieuses": "dispendieux",
    "dispensa": "dispenser",
    "dispensai": "dispenser",
    "dispensaient": "dispenser",
    "dispensaires": "dispensaire",
    "dispensais": "dispenser",
    "dispensait": "dispenser",
    "dispensant": "dispenser",
    "dispensas": "dispenser",
    "dispensasse": "dispenser",
    "dispensassent": "dispenser",
    "dispensasses": "dispenser",
    "dispensassiez": "dispenser",
    "dispensassions": "dispenser",
    "dispensateurs": "dispensateur",
    "dispensatrice": "dispensateur",
    "dispensatrices": "dispensateur",
    "dispense": "dispenser",
    "dispensent": "dispenser",
    "dispensera": "dispenser",
    "dispenserai": "dispenser",
    "dispenseraient": "dispenser",
    "dispenserais": "dispenser",
    "dispenserait": "dispenser",
    "dispenseras": "dispenser",
    "dispenserez": "dispenser",
    "dispenseriez": "dispenser",
    "dispenserions": "dispenser",
    "dispenserons": "dispenser",
    "dispenseront": "dispenser",
    "dispenses": "dispenser",
    "dispensez": "dispenser",
    "dispensiez": "dispenser",
    "dispensions": "dispenser",
    "dispensons": "dispenser",
    "dispensâmes": "dispenser",
    "dispensât": "dispenser",
    "dispensâtes": "dispenser",
    "dispensèrent": "dispenser",
    "dispensé": "dispenser",
    "dispensée": "dispenser",
    "dispensées": "dispenser",
    "dispensés": "dispenser",
    "dispersa": "disperser",
    "dispersai": "disperser",
    "dispersaient": "disperser",
    "dispersais": "disperser",
    "dispersait": "disperser",
    "dispersant": "disperser",
    "dispersante": "dispersant",
    "dispersantes": "dispersant",
    "dispersants": "dispersant",
    "dispersas": "disperser",
    "dispersasse": "disperser",
    "dispersassent": "disperser",
    "dispersasses": "disperser",
    "dispersassiez": "disperser",
    "dispersassions": "disperser",
    "disperse": "disperser",
    "dispersent": "disperser",
    "dispersera": "disperser",
    "disperserai": "disperser",
    "disperseraient": "disperser",
    "disperserais": "disperser",
    "disperserait": "disperser",
    "disperseras": "disperser",
    "disperserez": "disperser",
    "disperseriez": "disperser",
    "disperserions": "disperser",
    "disperserons": "disperser",
    "disperseront": "disperser",
    "disperses": "disperser",
    "dispersez": "disperser",
    "dispersiez": "disperser",
    "dispersions": "dispersion",
    "dispersons": "disperser",
    "dispersâmes": "disperser",
    "dispersât": "disperser",
    "dispersâtes": "disperser",
    "dispersèrent": "disperser",
    "dispersé": "disperser",
    "dispersée": "disperser",
    "dispersées": "disperser",
    "dispersés": "disperser",
    "disponibilités": "disponibilité",
    "disponibles": "disponible",
    "disposa": "disposer",
    "disposai": "disposer",
    "disposaient": "disposer",
    "disposais": "disposer",
    "disposait": "disposer",
    "disposant": "disposer",
    "disposas": "disposer",
    "disposasse": "disposer",
    "disposassent": "disposer",
    "disposasses": "disposer",
    "disposassiez": "disposer",
    "disposassions": "disposer",
    "dispose": "disposer",
    "disposent": "disposer",
    "disposera": "disposer",
    "disposerai": "disposer",
    "disposeraient": "disposer",
    "disposerais": "disposer",
    "disposerait": "disposer",
    "disposeras": "disposer",
    "disposerez": "disposer",
    "disposeriez": "disposer",
    "disposerions": "disposer",
    "disposerons": "disposer",
    "disposeront": "disposer",
    "disposes": "disposer",
    "disposez": "disposer",
    "disposiez": "disposer",
    "disposions": "disposer",
    "dispositifs": "dispositif",
    "dispositions": "disposition",
    "disposons": "disposer",
    "disposâmes": "disposer",
    "disposât": "disposer",
    "disposâtes": "disposer",
    "disposèrent": "disposer",
    "disposé": "disposer",
    "disposée": "disposer",
    "disposées": "disposer",
    "disposés": "disposer",
    "disproportionnelle": "disproportionnel",
    "disproportionné": "disproportionner",
    "disproportionnée": "disproportionner",
    "disproportionnées": "disproportionner",
    "disproportionnés": "disproportionné",
    "disproportions": "disproportion",
    "disputa": "disputer",
    "disputai": "disputer",
    "disputaient": "disputer",
    "disputais": "disputer",
    "disputait": "disputer",
    "disputant": "disputer",
    "disputas": "disputer",
    "disputasse": "disputer",
    "disputassent": "disputer",
    "disputasses": "disputer",
    "disputassiez": "disputer",
    "disputassions": "disputer",
    "dispute": "disputer",
    "disputent": "disputer",
    "disputera": "disputer",
    "disputerai": "disputer",
    "disputeraient": "disputer",
    "disputerais": "disputer",
    "disputerait": "disputer",
    "disputeras": "disputer",
    "disputerez": "disputer",
    "disputeriez": "disputer",
    "disputerions": "disputer",
    "disputerons": "disputer",
    "disputeront": "disputer",
    "disputes": "disputer",
    "disputez": "disputer",
    "disputiez": "disputer",
    "disputions": "disputer",
    "disputons": "disputer",
    "disputâmes": "disputer",
    "disputât": "disputer",
    "disputâtes": "disputer",
    "disputèrent": "disputer",
    "disputé": "disputer",
    "disputée": "disputer",
    "disputées": "disputer",
    "disputés": "disputer",
    "disquaires": "disquaire",
    "disqualifia": "disqualifier",
    "disqualifiai": "disqualifier",
    "disqualifiaient": "disqualifier",
    "disqualifiais": "disqualifier",
    "disqualifiait": "disqualifier",
    "disqualifiant": "disqualifier",
    "disqualifias": "disqualifier",
    "disqualifiasse": "disqualifier",
    "disqualifiassent": "disqualifier",
    "disqualifiasses": "disqualifier",
    "disqualifiassiez": "disqualifier",
    "disqualifiassions": "disqualifier",
    "disqualifications": "disqualification",
    "disqualifie": "disqualifier",
    "disqualifient": "disqualifier",
    "disqualifiera": "disqualifier",
    "disqualifierai": "disqualifier",
    "disqualifieraient": "disqualifier",
    "disqualifierais": "disqualifier",
    "disqualifierait": "disqualifier",
    "disqualifieras": "disqualifier",
    "disqualifierez": "disqualifier",
    "disqualifieriez": "disqualifier",
    "disqualifierions": "disqualifier",
    "disqualifierons": "disqualifier",
    "disqualifieront": "disqualifier",
    "disqualifies": "disqualifier",
    "disqualifiez": "disqualifier",
    "disqualifiiez": "disqualifier",
    "disqualifiions": "disqualifier",
    "disqualifions": "disqualifier",
    "disqualifiâmes": "disqualifier",
    "disqualifiât": "disqualifier",
    "disqualifiâtes": "disqualifier",
    "disqualifièrent": "disqualifier",
    "disqualifié": "disqualifier",
    "disqualifiée": "disqualifier",
    "disqualifiées": "disqualifier",
    "disqualifiés": "disqualifier",
    "disques": "disque",
    "disquettes": "disquette",
    "disse": "dire",
    "dissections": "dissection",
    "dissemblables": "dissemblable",
    "dissemblances": "dissemblance",
    "dissensions": "dissension",
    "dissent": "dire",
    "dissentiments": "dissentiment",
    "disserta": "disserter",
    "dissertai": "disserter",
    "dissertaient": "disserter",
    "dissertais": "disserter",
    "dissertait": "disserter",
    "dissertant": "disserter",
    "dissertas": "disserter",
    "dissertasse": "disserter",
    "dissertassent": "disserter",
    "dissertasses": "disserter",
    "dissertassiez": "disserter",
    "dissertassions": "disserter",
    "dissertations": "dissertation",
    "disserte": "disserter",
    "dissertent": "disserter",
    "dissertera": "disserter",
    "disserterai": "disserter",
    "disserteraient": "disserter",
    "disserterais": "disserter",
    "disserterait": "disserter",
    "disserteras": "disserter",
    "disserterez": "disserter",
    "disserteriez": "disserter",
    "disserterions": "disserter",
    "disserterons": "disserter",
    "disserteront": "disserter",
    "dissertes": "disserter",
    "dissertez": "disserter",
    "dissertiez": "disserter",
    "dissertions": "disserter",
    "dissertons": "disserter",
    "dissertâmes": "disserter",
    "dissertât": "disserter",
    "dissertâtes": "disserter",
    "dissertèrent": "disserter",
    "disserté": "disserter",
    "disses": "dire",
    "dissidences": "dissidence",
    "dissidente": "dissident",
    "dissidentes": "dissident",
    "dissidents": "dissident",
    "dissiez": "dire",
    "dissimilaires": "dissimilaire",
    "dissimilitudes": "dissimilitude",
    "dissimula": "dissimuler",
    "dissimulables": "dissimulable",
    "dissimulai": "dissimuler",
    "dissimulaient": "dissimuler",
    "dissimulais": "dissimuler",
    "dissimulait": "dissimuler",
    "dissimulant": "dissimuler",
    "dissimulas": "dissimuler",
    "dissimulasse": "dissimuler",
    "dissimulassent": "dissimuler",
    "dissimulasses": "dissimuler",
    "dissimulassiez": "dissimuler",
    "dissimulassions": "dissimuler",
    "dissimulateurs": "dissimulateur",
    "dissimulations": "dissimulation",
    "dissimulatrice": "dissimulateur",
    "dissimulatrices": "dissimulateur",
    "dissimule": "dissimuler",
    "dissimulent": "dissimuler",
    "dissimulera": "dissimuler",
    "dissimulerai": "dissimuler",
    "dissimuleraient": "dissimuler",
    "dissimulerais": "dissimuler",
    "dissimulerait": "dissimuler",
    "dissimuleras": "dissimuler",
    "dissimulerez": "dissimuler",
    "dissimuleriez": "dissimuler",
    "dissimulerions": "dissimuler",
    "dissimulerons": "dissimuler",
    "dissimuleront": "dissimuler",
    "dissimules": "dissimuler",
    "dissimulez": "dissimuler",
    "dissimuliez": "dissimuler",
    "dissimulions": "dissimuler",
    "dissimulons": "dissimuler",
    "dissimulâmes": "dissimuler",
    "dissimulât": "dissimuler",
    "dissimulâtes": "dissimuler",
    "dissimulèrent": "dissimuler",
    "dissimulé": "dissimuler",
    "dissimulée": "dissimuler",
    "dissimulées": "dissimuler",
    "dissimulés": "dissimuler",
    "dissions": "dire",
    "dissipa": "dissiper",
    "dissipai": "dissiper",
    "dissipaient": "dissiper",
    "dissipais": "dissiper",
    "dissipait": "dissiper",
    "dissipant": "dissiper",
    "dissipas": "dissiper",
    "dissipasse": "dissiper",
    "dissipassent": "dissiper",
    "dissipasses": "dissiper",
    "dissipassiez": "dissiper",
    "dissipassions": "dissiper",
    "dissipateurs": "dissipateur",
    "dissipations": "dissipation",
    "dissipe": "dissiper",
    "dissipent": "dissiper",
    "dissipera": "dissiper",
    "dissiperai": "dissiper",
    "dissiperaient": "dissiper",
    "dissiperais": "dissiper",
    "dissiperait": "dissiper",
    "dissiperas": "dissiper",
    "dissiperez": "dissiper",
    "dissiperiez": "dissiper",
    "dissiperions": "dissiper",
    "dissiperons": "dissiper",
    "dissiperont": "dissiper",
    "dissipes": "dissiper",
    "dissipez": "dissiper",
    "dissipiez": "dissiper",
    "dissipions": "dissiper",
    "dissipons": "dissiper",
    "dissipâmes": "dissiper",
    "dissipât": "dissiper",
    "dissipâtes": "dissiper",
    "dissipèrent": "dissiper",
    "dissipé": "dissiper",
    "dissipée": "dissiper",
    "dissipées": "dissiper",
    "dissipés": "dissiper",
    "dissocia": "dissocier",
    "dissociai": "dissocier",
    "dissociaient": "dissocier",
    "dissociais": "dissocier",
    "dissociait": "dissocier",
    "dissociant": "dissocier",
    "dissocias": "dissocier",
    "dissociasse": "dissocier",
    "dissociassent": "dissocier",
    "dissociasses": "dissocier",
    "dissociassiez": "dissocier",
    "dissociassions": "dissocier",
    "dissociatifs": "dissociatif",
    "dissociations": "dissociation",
    "dissociative": "dissociatif",
    "dissocie": "dissocier",
    "dissocient": "dissocier",
    "dissociera": "dissocier",
    "dissocierai": "dissocier",
    "dissocieraient": "dissocier",
    "dissocierais": "dissocier",
    "dissocierait": "dissocier",
    "dissocieras": "dissocier",
    "dissocierez": "dissocier",
    "dissocieriez": "dissocier",
    "dissocierions": "dissocier",
    "dissocierons": "dissocier",
    "dissocieront": "dissocier",
    "dissocies": "dissocier",
    "dissociez": "dissocier",
    "dissociiez": "dissocier",
    "dissociions": "dissocier",
    "dissocions": "dissocier",
    "dissociâmes": "dissocier",
    "dissociât": "dissocier",
    "dissociâtes": "dissocier",
    "dissocièrent": "dissocier",
    "dissocié": "dissocier",
    "dissociée": "dissocier",
    "dissociées": "dissocier",
    "dissociés": "dissocier",
    "dissolue": "dissolu",
    "dissolues": "dissolu",
    "dissolus": "dissolu",
    "dissolutions": "dissolution",
    "dissolvaient": "dissoudre",
    "dissolvais": "dissoudre",
    "dissolvait": "dissoudre",
    "dissolvant": "dissoudre",
    "dissolvante": "dissolvant",
    "dissolvantes": "dissolvant",
    "dissolvants": "dissolvant",
    "dissolve": "dissoudre",
    "dissolvent": "dissoudre",
    "dissolves": "dissoudre",
    "dissolvez": "dissoudre",
    "dissolviez": "dissoudre",
    "dissolvions": "dissoudre",
    "dissolvons": "dissoudre",
    "dissona": "dissoner",
    "dissonai": "dissoner",
    "dissonaient": "dissoner",
    "dissonais": "dissoner",
    "dissonait": "dissoner",
    "dissonances": "dissonance",
    "dissonant": "dissoner",
    "dissonante": "dissonant",
    "dissonantes": "dissonant",
    "dissonants": "dissonant",
    "dissonas": "dissoner",
    "dissonasse": "dissoner",
    "dissonassent": "dissoner",
    "dissonasses": "dissoner",
    "dissonassiez": "dissoner",
    "dissonassions": "dissoner",
    "dissone": "dissoner",
    "dissonent": "dissoner",
    "dissonera": "dissoner",
    "dissonerai": "dissoner",
    "dissoneraient": "dissoner",
    "dissonerais": "dissoner",
    "dissonerait": "dissoner",
    "dissoneras": "dissoner",
    "dissonerez": "dissoner",
    "dissoneriez": "dissoner",
    "dissonerions": "dissoner",
    "dissonerons": "dissoner",
    "dissoneront": "dissoner",
    "dissones": "dissoner",
    "dissonez": "dissoner",
    "dissoniez": "dissoner",
    "dissonions": "dissoner",
    "dissonons": "dissoner",
    "dissonâmes": "dissoner",
    "dissonât": "dissoner",
    "dissonâtes": "dissoner",
    "dissonèrent": "dissoner",
    "dissoné": "dissoner",
    "dissoudra": "dissoudre",
    "dissoudrai": "dissoudre",
    "dissoudraient": "dissoudre",
    "dissoudrais": "dissoudre",
    "dissoudrait": "dissoudre",
    "dissoudras": "dissoudre",
    "dissoudrez": "dissoudre",
    "dissoudriez": "dissoudre",
    "dissoudrions": "dissoudre",
    "dissoudrons": "dissoudre",
    "dissoudront": "dissoudre",
    "dissous": "dissoudre",
    "dissout": "dissoudre",
    "dissoute": "dissoudre",
    "dissoutes": "dissoute",
    "dissuada": "dissuader",
    "dissuadai": "dissuader",
    "dissuadaient": "dissuader",
    "dissuadais": "dissuader",
    "dissuadait": "dissuader",
    "dissuadant": "dissuader",
    "dissuadas": "dissuader",
    "dissuadasse": "dissuader",
    "dissuadassent": "dissuader",
    "dissuadasses": "dissuader",
    "dissuadassiez": "dissuader",
    "dissuadassions": "dissuader",
    "dissuade": "dissuader",
    "dissuadent": "dissuader",
    "dissuadera": "dissuader",
    "dissuaderai": "dissuader",
    "dissuaderaient": "dissuader",
    "dissuaderais": "dissuader",
    "dissuaderait": "dissuader",
    "dissuaderas": "dissuader",
    "dissuaderez": "dissuader",
    "dissuaderiez": "dissuader",
    "dissuaderions": "dissuader",
    "dissuaderons": "dissuader",
    "dissuaderont": "dissuader",
    "dissuades": "dissuader",
    "dissuadez": "dissuader",
    "dissuadiez": "dissuader",
    "dissuadions": "dissuader",
    "dissuadons": "dissuader",
    "dissuadâmes": "dissuader",
    "dissuadât": "dissuader",
    "dissuadâtes": "dissuader",
    "dissuadèrent": "dissuader",
    "dissuadé": "dissuader",
    "dissuadée": "dissuader",
    "dissuadées": "dissuader",
    "dissuadés": "dissuader",
    "dissuasifs": "dissuasif",
    "dissuasions": "dissuasion",
    "dissuasive": "dissuasif",
    "dissuasives": "dissuasif",
    "dissyllabes": "dissyllabe",
    "dissyllabiques": "dissyllabique",
    "dissymétries": "dissymétrie",
    "dissymétriques": "dissymétrique",
    "dissèque": "disséquer",
    "dissèquent": "disséquer",
    "dissèques": "disséquer",
    "dissémina": "disséminer",
    "disséminai": "disséminer",
    "disséminaient": "disséminer",
    "disséminais": "disséminer",
    "disséminait": "disséminer",
    "disséminant": "disséminer",
    "disséminas": "disséminer",
    "disséminasse": "disséminer",
    "disséminassent": "disséminer",
    "disséminasses": "disséminer",
    "disséminassiez": "disséminer",
    "disséminassions": "disséminer",
    "disséminations": "dissémination",
    "dissémine": "disséminer",
    "disséminent": "disséminer",
    "disséminera": "disséminer",
    "disséminerai": "disséminer",
    "dissémineraient": "disséminer",
    "disséminerais": "disséminer",
    "disséminerait": "disséminer",
    "dissémineras": "disséminer",
    "disséminerez": "disséminer",
    "dissémineriez": "disséminer",
    "disséminerions": "disséminer",
    "disséminerons": "disséminer",
    "dissémineront": "disséminer",
    "dissémines": "disséminer",
    "disséminez": "disséminer",
    "disséminiez": "disséminer",
    "disséminions": "disséminer",
    "disséminons": "disséminer",
    "disséminâmes": "disséminer",
    "disséminât": "disséminer",
    "disséminâtes": "disséminer",
    "disséminèrent": "disséminer",
    "disséminé": "disséminer",
    "disséminée": "disséminer",
    "disséminées": "disséminer",
    "disséminés": "disséminer",
    "disséqua": "disséquer",
    "disséquai": "disséquer",
    "disséquaient": "disséquer",
    "disséquais": "disséquer",
    "disséquait": "disséquer",
    "disséquant": "disséquer",
    "disséquas": "disséquer",
    "disséquasse": "disséquer",
    "disséquassent": "disséquer",
    "disséquasses": "disséquer",
    "disséquassiez": "disséquer",
    "disséquassions": "disséquer",
    "disséquera": "disséquer",
    "disséquerai": "disséquer",
    "disséqueraient": "disséquer",
    "disséquerais": "disséquer",
    "disséquerait": "disséquer",
    "disséqueras": "disséquer",
    "disséquerez": "disséquer",
    "disséqueriez": "disséquer",
    "disséquerions": "disséquer",
    "disséquerons": "disséquer",
    "disséqueront": "disséquer",
    "disséquez": "disséquer",
    "disséquiez": "disséquer",
    "disséquions": "disséquer",
    "disséquons": "disséquer",
    "disséquâmes": "disséquer",
    "disséquât": "disséquer",
    "disséquâtes": "disséquer",
    "disséquèrent": "disséquer",
    "disséqué": "disséquer",
    "disséquée": "disséquer",
    "disséquées": "disséquer",
    "disséqués": "disséquer",
    "distale": "distal",
    "distance": "distancer",
    "distancent": "distancer",
    "distancera": "distancer",
    "distancerai": "distancer",
    "distanceraient": "distancer",
    "distancerais": "distancer",
    "distancerait": "distancer",
    "distanceras": "distancer",
    "distancerez": "distancer",
    "distanceriez": "distancer",
    "distancerions": "distancer",
    "distancerons": "distancer",
    "distanceront": "distancer",
    "distances": "distancer",
    "distancez": "distancer",
    "distancia": "distancier",
    "distanciai": "distancier",
    "distanciaient": "distancier",
    "distanciais": "distancier",
    "distanciait": "distancier",
    "distanciant": "distancier",
    "distancias": "distancier",
    "distanciasse": "distancier",
    "distanciassent": "distancier",
    "distanciasses": "distancier",
    "distanciassiez": "distancier",
    "distanciassions": "distancier",
    "distancie": "distancier",
    "distancient": "distancier",
    "distanciera": "distancier",
    "distancierai": "distancier",
    "distancieraient": "distancier",
    "distancierais": "distancier",
    "distancierait": "distancier",
    "distancieras": "distancier",
    "distancierez": "distancier",
    "distancieriez": "distancier",
    "distancierions": "distancier",
    "distancierons": "distancier",
    "distancieront": "distancier",
    "distancies": "distancier",
    "distanciez": "distancier",
    "distanciiez": "distancier",
    "distanciions": "distancier",
    "distancions": "distancier",
    "distanciâmes": "distancier",
    "distanciât": "distancier",
    "distanciâtes": "distancier",
    "distancièrent": "distancier",
    "distancié": "distancier",
    "distanciée": "distancier",
    "distanciées": "distancier",
    "distanciés": "distancier",
    "distancèrent": "distancer",
    "distancé": "distancer",
    "distancée": "distancer",
    "distancées": "distancer",
    "distancés": "distancer",
    "distante": "distant",
    "distantes": "distant",
    "distants": "distant",
    "distança": "distancer",
    "distançai": "distancer",
    "distançaient": "distancer",
    "distançais": "distancer",
    "distançait": "distancer",
    "distançant": "distancer",
    "distanças": "distancer",
    "distançasse": "distancer",
    "distançassent": "distancer",
    "distançasses": "distancer",
    "distançassiez": "distancer",
    "distançassions": "distancer",
    "distançons": "distancer",
    "distançâmes": "distancer",
    "distançât": "distancer",
    "distançâtes": "distancer",
    "distaux": "distal",
    "distend": "distendre",
    "distendaient": "distendre",
    "distendais": "distendre",
    "distendait": "distendre",
    "distendant": "distendre",
    "distende": "distendre",
    "distendent": "distendre",
    "distendes": "distendre",
    "distendez": "distendre",
    "distendiez": "distendre",
    "distendions": "distendre",
    "distendirent": "distendre",
    "distendis": "distendre",
    "distendisse": "distendre",
    "distendissent": "distendre",
    "distendisses": "distendre",
    "distendissiez": "distendre",
    "distendissions": "distendre",
    "distendit": "distendre",
    "distendons": "distendre",
    "distendra": "distendre",
    "distendrai": "distendre",
    "distendraient": "distendre",
    "distendrais": "distendre",
    "distendrait": "distendre",
    "distendras": "distendre",
    "distendrez": "distendre",
    "distendriez": "distendre",
    "distendrions": "distendre",
    "distendrons": "distendre",
    "distendront": "distendre",
    "distends": "distendre",
    "distendu": "distendre",
    "distendue": "distendu",
    "distendues": "distendu",
    "distendus": "distendu",
    "distendîmes": "distendre",
    "distendît": "distendre",
    "distendîtes": "distendre",
    "distilla": "distiller",
    "distillai": "distiller",
    "distillaient": "distiller",
    "distillais": "distiller",
    "distillait": "distiller",
    "distillant": "distiller",
    "distillas": "distiller",
    "distillasse": "distiller",
    "distillassent": "distiller",
    "distillasses": "distiller",
    "distillassiez": "distiller",
    "distillassions": "distiller",
    "distillateurs": "distillateur",
    "distillations": "distillation",
    "distille": "distiller",
    "distillent": "distiller",
    "distillera": "distiller",
    "distillerai": "distiller",
    "distilleraient": "distiller",
    "distillerais": "distiller",
    "distillerait": "distiller",
    "distilleras": "distiller",
    "distillerez": "distiller",
    "distilleries": "distillerie",
    "distilleriez": "distiller",
    "distillerions": "distiller",
    "distillerons": "distiller",
    "distilleront": "distiller",
    "distilles": "distiller",
    "distillez": "distiller",
    "distilliez": "distiller",
    "distillions": "distiller",
    "distillons": "distiller",
    "distillâmes": "distiller",
    "distillât": "distiller",
    "distillâtes": "distiller",
    "distillèrent": "distiller",
    "distillé": "distiller",
    "distillée": "distiller",
    "distillées": "distiller",
    "distillés": "distiller",
    "distincte": "distinct",
    "distinctes": "distinct",
    "distinctifs": "distinctif",
    "distinctions": "distinction",
    "distinctive": "distinctif",
    "distinctives": "distinctif",
    "distincts": "distinct",
    "distingua": "distinguer",
    "distinguai": "distinguer",
    "distinguaient": "distinguer",
    "distinguais": "distinguer",
    "distinguait": "distinguer",
    "distinguant": "distinguer",
    "distinguas": "distinguer",
    "distinguasse": "distinguer",
    "distinguassent": "distinguer",
    "distinguasses": "distinguer",
    "distinguassiez": "distinguer",
    "distinguassions": "distinguer",
    "distingue": "distinguer",
    "distinguent": "distinguer",
    "distinguera": "distinguer",
    "distinguerai": "distinguer",
    "distingueraient": "distinguer",
    "distinguerais": "distinguer",
    "distinguerait": "distinguer",
    "distingueras": "distinguer",
    "distinguerez": "distinguer",
    "distingueriez": "distinguer",
    "distinguerions": "distinguer",
    "distinguerons": "distinguer",
    "distingueront": "distinguer",
    "distingues": "distinguer",
    "distinguez": "distinguer",
    "distinguiez": "distinguer",
    "distinguions": "distinguer",
    "distinguons": "distinguer",
    "distinguos": "distinguo",
    "distinguâmes": "distinguer",
    "distinguât": "distinguer",
    "distinguâtes": "distinguer",
    "distinguèrent": "distinguer",
    "distingué": "distinguer",
    "distinguée": "distinguer",
    "distinguées": "distinguer",
    "distingués": "distinguer",
    "distiques": "distique",
    "distord": "distordre",
    "distordaient": "distordre",
    "distordais": "distordre",
    "distordait": "distordre",
    "distordant": "distordre",
    "distorde": "distordre",
    "distordent": "distordre",
    "distordes": "distordre",
    "distordez": "distordre",
    "distordiez": "distordre",
    "distordions": "distordre",
    "distordirent": "distordre",
    "distordis": "distordre",
    "distordisse": "distordre",
    "distordissent": "distordre",
    "distordisses": "distordre",
    "distordissiez": "distordre",
    "distordissions": "distordre",
    "distordit": "distordre",
    "distordons": "distordre",
    "distordra": "distordre",
    "distordrai": "distordre",
    "distordraient": "distordre",
    "distordrais": "distordre",
    "distordrait": "distordre",
    "distordras": "distordre",
    "distordrez": "distordre",
    "distordriez": "distordre",
    "distordrions": "distordre",
    "distordrons": "distordre",
    "distordront": "distordre",
    "distords": "distordre",
    "distordu": "distordre",
    "distordue": "distordre",
    "distordues": "distordre",
    "distordus": "distordre",
    "distordîmes": "distordre",
    "distordît": "distordre",
    "distordîtes": "distordre",
    "distorsions": "distorsion",
    "distortions": "distortion",
    "distractions": "distraction",
    "distractives": "distractif",
    "distraie": "distraire",
    "distraient": "distraire",
    "distraies": "distraire",
    "distraira": "distraire",
    "distrairai": "distraire",
    "distrairaient": "distraire",
    "distrairais": "distraire",
    "distrairait": "distraire",
    "distrairas": "distraire",
    "distrairez": "distraire",
    "distrairiez": "distraire",
    "distrairions": "distraire",
    "distrairons": "distraire",
    "distrairont": "distraire",
    "distrais": "distraire",
    "distrait": "distraire",
    "distraite": "distrait",
    "distraites": "distrait",
    "distraits": "distrait",
    "distrayaient": "distraire",
    "distrayais": "distraire",
    "distrayait": "distraire",
    "distrayant": "distraire",
    "distrayante": "distrayant",
    "distrayantes": "distrayant",
    "distrayants": "distrayant",
    "distrayez": "distraire",
    "distrayiez": "distraire",
    "distrayions": "distraire",
    "distrayons": "distraire",
    "distribua": "distribuer",
    "distribuai": "distribuer",
    "distribuaient": "distribuer",
    "distribuais": "distribuer",
    "distribuait": "distribuer",
    "distribuant": "distribuer",
    "distribuas": "distribuer",
    "distribuasse": "distribuer",
    "distribuassent": "distribuer",
    "distribuasses": "distribuer",
    "distribuassiez": "distribuer",
    "distribuassions": "distribuer",
    "distribue": "distribuer",
    "distribuent": "distribuer",
    "distribuera": "distribuer",
    "distribuerai": "distribuer",
    "distribueraient": "distribuer",
    "distribuerais": "distribuer",
    "distribuerait": "distribuer",
    "distribueras": "distribuer",
    "distribuerez": "distribuer",
    "distribueriez": "distribuer",
    "distribuerions": "distribuer",
    "distribuerons": "distribuer",
    "distribueront": "distribuer",
    "distribues": "distribuer",
    "distribuez": "distribuer",
    "distribuiez": "distribuer",
    "distribuions": "distribuer",
    "distribuons": "distribuer",
    "distributeurs": "distributeur",
    "distributionnalismes": "distributionnalisme",
    "distributionnelle": "distributionnel",
    "distributionnelles": "distributionnel",
    "distributionnels": "distributionnel",
    "distributions": "distribution",
    "distributive": "distributif",
    "distributrice": "distributeur",
    "distribuâmes": "distribuer",
    "distribuât": "distribuer",
    "distribuâtes": "distribuer",
    "distribuèrent": "distribuer",
    "distribué": "distribuer",
    "distribuée": "distribuer",
    "distribuées": "distribuer",
    "distribués": "distribuer",
    "districts": "district",
    "dit": "dire",
    "dite": "dit",
    "dites": "dit",
    "dithyrambes": "dithyrambe",
    "dithyrambiques": "dithyrambique",
    "dits": "dit",
    "diurnes": "diurne",
    "diurèses": "diurèse",
    "diurétiques": "diurétique",
    "divagants": "divagant",
    "divagations": "divagation",
    "divagua": "divaguer",
    "divaguai": "divaguer",
    "divaguaient": "divaguer",
    "divaguais": "divaguer",
    "divaguait": "divaguer",
    "divaguant": "divaguer",
    "divaguas": "divaguer",
    "divaguasse": "divaguer",
    "divaguassent": "divaguer",
    "divaguasses": "divaguer",
    "divaguassiez": "divaguer",
    "divaguassions": "divaguer",
    "divague": "divaguer",
    "divaguent": "divaguer",
    "divaguera": "divaguer",
    "divaguerai": "divaguer",
    "divagueraient": "divaguer",
    "divaguerais": "divaguer",
    "divaguerait": "divaguer",
    "divagueras": "divaguer",
    "divaguerez": "divaguer",
    "divagueriez": "divaguer",
    "divaguerions": "divaguer",
    "divaguerons": "divaguer",
    "divagueront": "divaguer",
    "divagues": "divaguer",
    "divaguez": "divaguer",
    "divaguiez": "divaguer",
    "divaguions": "divaguer",
    "divaguons": "divaguer",
    "divaguâmes": "divaguer",
    "divaguât": "divaguer",
    "divaguâtes": "divaguer",
    "divaguèrent": "divaguer",
    "divagué": "divaguer",
    "divans": "divan",
    "divas": "diva",
    "diverge": "diverger",
    "divergea": "diverger",
    "divergeai": "diverger",
    "divergeaient": "diverger",
    "divergeais": "diverger",
    "divergeait": "diverger",
    "divergeant": "diverger",
    "divergeas": "diverger",
    "divergeasse": "diverger",
    "divergeassent": "diverger",
    "divergeasses": "diverger",
    "divergeassiez": "diverger",
    "divergeassions": "diverger",
    "divergences": "divergence",
    "divergent": "diverger",
    "divergente": "divergent",
    "divergentes": "divergent",
    "divergents": "divergent",
    "divergeons": "diverger",
    "divergera": "diverger",
    "divergerai": "diverger",
    "divergeraient": "diverger",
    "divergerais": "diverger",
    "divergerait": "diverger",
    "divergeras": "diverger",
    "divergerez": "diverger",
    "divergeriez": "diverger",
    "divergerions": "diverger",
    "divergerons": "diverger",
    "divergeront": "diverger",
    "diverges": "diverger",
    "divergez": "diverger",
    "divergeâmes": "diverger",
    "divergeât": "diverger",
    "divergeâtes": "diverger",
    "divergiez": "diverger",
    "divergions": "diverger",
    "divergèrent": "diverger",
    "divergé": "diverger",
    "diverse": "divers",
    "diverses": "divers",
    "diversifia": "diversifier",
    "diversifiai": "diversifier",
    "diversifiaient": "diversifier",
    "diversifiais": "diversifier",
    "diversifiait": "diversifier",
    "diversifiant": "diversifier",
    "diversifias": "diversifier",
    "diversifiasse": "diversifier",
    "diversifiassent": "diversifier",
    "diversifiasses": "diversifier",
    "diversifiassiez": "diversifier",
    "diversifiassions": "diversifier",
    "diversifications": "diversification",
    "diversifie": "diversifier",
    "diversifient": "diversifier",
    "diversifiera": "diversifier",
    "diversifierai": "diversifier",
    "diversifieraient": "diversifier",
    "diversifierais": "diversifier",
    "diversifierait": "diversifier",
    "diversifieras": "diversifier",
    "diversifierez": "diversifier",
    "diversifieriez": "diversifier",
    "diversifierions": "diversifier",
    "diversifierons": "diversifier",
    "diversifieront": "diversifier",
    "diversifies": "diversifier",
    "diversifiez": "diversifier",
    "diversifiiez": "diversifier",
    "diversifiions": "diversifier",
    "diversifions": "diversifier",
    "diversifiâmes": "diversifier",
    "diversifiât": "diversifier",
    "diversifiâtes": "diversifier",
    "diversifièrent": "diversifier",
    "diversifié": "diversifier",
    "diversifiée": "diversifier",
    "diversifiées": "diversifier",
    "diversifiés": "diversifier",
    "diversions": "diversion",
    "diversités": "diversité",
    "diverti": "divertir",
    "divertie": "divertir",
    "diverties": "divertir",
    "divertira": "divertir",
    "divertirai": "divertir",
    "divertiraient": "divertir",
    "divertirais": "divertir",
    "divertirait": "divertir",
    "divertiras": "divertir",
    "divertirent": "divertir",
    "divertirez": "divertir",
    "divertiriez": "divertir",
    "divertirions": "divertir",
    "divertirons": "divertir",
    "divertiront": "divertir",
    "divertis": "divertir",
    "divertissaient": "divertir",
    "divertissais": "divertir",
    "divertissait": "divertir",
    "divertissant": "divertir",
    "divertissante": "divertissant",
    "divertissantes": "divertissant",
    "divertissants": "divertissant",
    "divertisse": "divertir",
    "divertissements": "divertissement",
    "divertissent": "divertir",
    "divertisses": "divertir",
    "divertissez": "divertir",
    "divertissiez": "divertir",
    "divertissions": "divertir",
    "divertissons": "divertir",
    "divertit": "divertir",
    "divertîmes": "divertir",
    "divertît": "divertir",
    "divertîtes": "divertir",
    "dividendes": "dividende",
    "divinations": "divination",
    "divinatoires": "divinatoire",
    "divinatrice": "divinateur",
    "divinatrices": "divinateur",
    "divine": "divin",
    "divines": "divin",
    "divinisa": "diviniser",
    "divinisai": "diviniser",
    "divinisaient": "diviniser",
    "divinisais": "diviniser",
    "divinisait": "diviniser",
    "divinisant": "diviniser",
    "divinisas": "diviniser",
    "divinisasse": "diviniser",
    "divinisassent": "diviniser",
    "divinisasses": "diviniser",
    "divinisassiez": "diviniser",
    "divinisassions": "diviniser",
    "divinise": "diviniser",
    "divinisent": "diviniser",
    "divinisera": "diviniser",
    "diviniserai": "diviniser",
    "diviniseraient": "diviniser",
    "diviniserais": "diviniser",
    "diviniserait": "diviniser",
    "diviniseras": "diviniser",
    "diviniserez": "diviniser",
    "diviniseriez": "diviniser",
    "diviniserions": "diviniser",
    "diviniserons": "diviniser",
    "diviniseront": "diviniser",
    "divinises": "diviniser",
    "divinisez": "diviniser",
    "divinisiez": "diviniser",
    "divinisions": "diviniser",
    "divinisons": "diviniser",
    "divinisâmes": "diviniser",
    "divinisât": "diviniser",
    "divinisâtes": "diviniser",
    "divinisèrent": "diviniser",
    "divinisé": "diviniser",
    "divinisée": "diviniser",
    "divinisées": "diviniser",
    "divinisés": "diviniser",
    "divinités": "divinité",
    "divins": "divin",
    "divisa": "diviser",
    "divisai": "diviser",
    "divisaient": "diviser",
    "divisais": "diviser",
    "divisait": "diviser",
    "divisant": "diviser",
    "divisas": "diviser",
    "divisasse": "diviser",
    "divisassent": "diviser",
    "divisasses": "diviser",
    "divisassiez": "diviser",
    "divisassions": "diviser",
    "divise": "diviser",
    "divisent": "diviser",
    "divisera": "diviser",
    "diviserai": "diviser",
    "diviseraient": "diviser",
    "diviserais": "diviser",
    "diviserait": "diviser",
    "diviseras": "diviser",
    "diviserez": "diviser",
    "diviseriez": "diviser",
    "diviserions": "diviser",
    "diviserons": "diviser",
    "diviseront": "diviser",
    "divises": "diviser",
    "diviseuse": "diviseur",
    "divisez": "diviser",
    "divisibles": "divisible",
    "divisiez": "diviser",
    "divisionnaires": "divisionnaire",
    "divisions": "division",
    "divisons": "diviser",
    "divisâmes": "diviser",
    "divisât": "diviser",
    "divisâtes": "diviser",
    "divisèrent": "diviser",
    "divisé": "diviser",
    "divisée": "diviser",
    "divisées": "diviser",
    "divisés": "diviser",
    "divorce": "divorcer",
    "divorcent": "divorcer",
    "divorcera": "divorcer",
    "divorcerai": "divorcer",
    "divorceraient": "divorcer",
    "divorcerais": "divorcer",
    "divorcerait": "divorcer",
    "divorceras": "divorcer",
    "divorcerez": "divorcer",
    "divorceriez": "divorcer",
    "divorcerions": "divorcer",
    "divorcerons": "divorcer",
    "divorceront": "divorcer",
    "divorces": "divorcer",
    "divorcez": "divorcer",
    "divorciez": "divorcer",
    "divorcions": "divorcer",
    "divorcèrent": "divorcer",
    "divorcé": "divorcer",
    "divorcée": "divorcer",
    "divorcées": "divorcer",
    "divorcés": "divorcer",
    "divorça": "divorcer",
    "divorçai": "divorcer",
    "divorçaient": "divorcer",
    "divorçais": "divorcer",
    "divorçait": "divorcer",
    "divorçant": "divorcer",
    "divorças": "divorcer",
    "divorçasse": "divorcer",
    "divorçassent": "divorcer",
    "divorçasses": "divorcer",
    "divorçassiez": "divorcer",
    "divorçassions": "divorcer",
    "divorçons": "divorcer",
    "divorçâmes": "divorcer",
    "divorçât": "divorcer",
    "divorçâtes": "divorcer",
    "divulgations": "divulgation",
    "divulgua": "divulguer",
    "divulguai": "divulguer",
    "divulguaient": "divulguer",
    "divulguais": "divulguer",
    "divulguait": "divulguer",
    "divulguant": "divulguer",
    "divulguas": "divulguer",
    "divulguasse": "divulguer",
    "divulguassent": "divulguer",
    "divulguasses": "divulguer",
    "divulguassiez": "divulguer",
    "divulguassions": "divulguer",
    "divulgue": "divulguer",
    "divulguent": "divulguer",
    "divulguera": "divulguer",
    "divulguerai": "divulguer",
    "divulgueraient": "divulguer",
    "divulguerais": "divulguer",
    "divulguerait": "divulguer",
    "divulgueras": "divulguer",
    "divulguerez": "divulguer",
    "divulgueriez": "divulguer",
    "divulguerions": "divulguer",
    "divulguerons": "divulguer",
    "divulgueront": "divulguer",
    "divulgues": "divulguer",
    "divulguez": "divulguer",
    "divulguiez": "divulguer",
    "divulguions": "divulguer",
    "divulguons": "divulguer",
    "divulguâmes": "divulguer",
    "divulguât": "divulguer",
    "divulguâtes": "divulguer",
    "divulguèrent": "divulguer",
    "divulgué": "divulguer",
    "divulguée": "divulguer",
    "divulguées": "divulguer",
    "divulgués": "divulguer",
    "dix-huitièmes": "dix-huitième",
    "dix-neuvièmes": "dix-neuvième",
    "dix-septièmes": "dix-septième",
    "dixièmes": "dixième",
    "dizaines": "dizaine",
    "dizains": "dizain",
    "dièdres": "dièdre",
    "dièse": "diéser",
    "dièses": "diéser",
    "diètes": "diète",
    "diérèses": "diérèse",
    "diététicienne": "diététicien",
    "diététiciens": "diététicien",
    "diététiques": "diététique",
    "djebels": "djebel",
    "djellabas": "djellaba",
    "djiboutienne": "djiboutien",
    "djiboutiennes": "djiboutien",
    "djiboutiens": "djiboutien",
    "djihads": "djihad",
    "djinns": "djinn",
    "dobermans": "doberman",
    "doc.": "document",
    "dociles": "docile",
    "docilités": "docilité",
    "dockers": "docker",
    "docks": "dock",
    "doctes": "docte",
    "docteurs": "docteur",
    "doctorale": "doctoral",
    "doctorales": "doctoral",
    "doctorats": "doctorat",
    "doctoraux": "doctoral",
    "doctoresse": "docteur",
    "doctoresses": "docteur",
    "doctrina": "doctriner",
    "doctrinaires": "doctrinaire",
    "doctrinale": "doctrinal",
    "doctrinales": "doctrinal",
    "doctrinals": "doctrinal",
    "doctrinauxs": "doctrinal",
    "doctrines": "doctrine",
    "documenta": "documenter",
    "documentai": "documenter",
    "documentaient": "documenter",
    "documentaires": "documentaire",
    "documentais": "documenter",
    "documentait": "documenter",
    "documentalistes": "documentaliste",
    "documentant": "documenter",
    "documentaristes": "documentariste",
    "documentas": "documenter",
    "documentasse": "documenter",
    "documentassent": "documenter",
    "documentasses": "documenter",
    "documentassiez": "documenter",
    "documentassions": "documenter",
    "documentations": "documentation",
    "documente": "documenter",
    "documentent": "documenter",
    "documentera": "documenter",
    "documenterai": "documenter",
    "documenteraient": "documenter",
    "documenterais": "documenter",
    "documenterait": "documenter",
    "documenteras": "documenter",
    "documenterez": "documenter",
    "documenteriez": "documenter",
    "documenterions": "documenter",
    "documenterons": "documenter",
    "documenteront": "documenter",
    "documentes": "documenter",
    "documentez": "documenter",
    "documentiez": "documenter",
    "documentions": "documenter",
    "documentons": "documenter",
    "documents": "document",
    "documentâmes": "documenter",
    "documentât": "documenter",
    "documentâtes": "documenter",
    "documentèrent": "documenter",
    "documenté": "documenter",
    "documentée": "documenter",
    "documentées": "documenter",
    "documentés": "documenter",
    "dodelina": "dodeliner",
    "dodelinai": "dodeliner",
    "dodelinaient": "dodeliner",
    "dodelinais": "dodeliner",
    "dodelinait": "dodeliner",
    "dodelinant": "dodeliner",
    "dodelinante": "dodelinant",
    "dodelinantes": "dodelinant",
    "dodelinas": "dodeliner",
    "dodelinasse": "dodeliner",
    "dodelinassent": "dodeliner",
    "dodelinasses": "dodeliner",
    "dodelinassiez": "dodeliner",
    "dodelinassions": "dodeliner",
    "dodeline": "dodeliner",
    "dodelinent": "dodeliner",
    "dodelinera": "dodeliner",
    "dodelinerai": "dodeliner",
    "dodelineraient": "dodeliner",
    "dodelinerais": "dodeliner",
    "dodelinerait": "dodeliner",
    "dodelineras": "dodeliner",
    "dodelinerez": "dodeliner",
    "dodelineriez": "dodeliner",
    "dodelinerions": "dodeliner",
    "dodelinerons": "dodeliner",
    "dodelineront": "dodeliner",
    "dodelines": "dodeliner",
    "dodelinez": "dodeliner",
    "dodeliniez": "dodeliner",
    "dodelinions": "dodeliner",
    "dodelinons": "dodeliner",
    "dodelinâmes": "dodeliner",
    "dodelinât": "dodeliner",
    "dodelinâtes": "dodeliner",
    "dodelinèrent": "dodeliner",
    "dodeliné": "dodeliner",
    "dodine": "dodiner",
    "dodos": "dodo",
    "dodue": "dodu",
    "dodues": "dodu",
    "dodus": "dodu",
    "dodécaphonismes": "dodécaphonisme",
    "dodécasyllabes": "dodécasyllabe",
    "dog-carts": "dog-cart",
    "dogaresses": "dogaresse",
    "doges": "doge",
    "dogmatiques": "dogmatique",
    "dogmatismes": "dogmatisme",
    "dogmes": "dogme",
    "dogues": "dogue",
    "doigta": "doigter",
    "doigtait": "doigter",
    "doigts": "doigt",
    "doigté": "doigter",
    "doigtés": "doigté",
    "dois": "devoir",
    "doit": "devoir",
    "doive": "devoir",
    "doivent": "devoir",
    "doives": "devoir",
    "dola": "doler",
    "dolai": "doler",
    "dolaient": "doler",
    "dolais": "doler",
    "dolait": "doler",
    "dolant": "doler",
    "dolas": "doler",
    "dolasse": "doler",
    "dolassent": "doler",
    "dolasses": "doler",
    "dolassiez": "doler",
    "dolassions": "doler",
    "dole": "doler",
    "dolent": "doler",
    "dolente": "dolent",
    "dolentes": "dolent",
    "dolents": "dolent",
    "dolera": "doler",
    "dolerai": "doler",
    "doleraient": "doler",
    "dolerais": "doler",
    "dolerait": "doler",
    "doleras": "doler",
    "dolerez": "doler",
    "doleriez": "doler",
    "dolerions": "doler",
    "dolerons": "doler",
    "doleront": "doler",
    "doles": "doler",
    "dolez": "doler",
    "dolichocéphales": "dolichocéphale",
    "doliez": "doler",
    "dolions": "doler",
    "dollars": "dollar",
    "dolmans": "dolman",
    "dolmens": "dolmen",
    "doloires": "doloire",
    "dolomies": "dolomie",
    "dolons": "doler",
    "dols": "dol",
    "dolâmes": "doler",
    "dolât": "doler",
    "dolâtes": "doler",
    "dolèrent": "doler",
    "dolé": "doler",
    "doléances": "doléance",
    "dolée": "doler",
    "dolées": "doler",
    "dolés": "doler",
    "domaines": "domaine",
    "domaniale": "domanial",
    "domaniales": "domanial",
    "domaniaux": "domanial",
    "domestications": "domestication",
    "domestiqua": "domestiquer",
    "domestiquai": "domestiquer",
    "domestiquaient": "domestiquer",
    "domestiquais": "domestiquer",
    "domestiquait": "domestiquer",
    "domestiquant": "domestiquer",
    "domestiquas": "domestiquer",
    "domestiquasse": "domestiquer",
    "domestiquassent": "domestiquer",
    "domestiquasses": "domestiquer",
    "domestiquassiez": "domestiquer",
    "domestiquassions": "domestiquer",
    "domestique": "domestiquer",
    "domestiquent": "domestiquer",
    "domestiquera": "domestiquer",
    "domestiquerai": "domestiquer",
    "domestiqueraient": "domestiquer",
    "domestiquerais": "domestiquer",
    "domestiquerait": "domestiquer",
    "domestiqueras": "domestiquer",
    "domestiquerez": "domestiquer",
    "domestiqueriez": "domestiquer",
    "domestiquerions": "domestiquer",
    "domestiquerons": "domestiquer",
    "domestiqueront": "domestiquer",
    "domestiques": "domestiquer",
    "domestiquez": "domestiquer",
    "domestiquiez": "domestiquer",
    "domestiquions": "domestiquer",
    "domestiquons": "domestiquer",
    "domestiquâmes": "domestiquer",
    "domestiquât": "domestiquer",
    "domestiquâtes": "domestiquer",
    "domestiquèrent": "domestiquer",
    "domestiqué": "domestiquer",
    "domestiquée": "domestiquer",
    "domestiquées": "domestiquer",
    "domestiqués": "domestiquer",
    "domiciles": "domicile",
    "domicilia": "domicilier",
    "domiciliai": "domicilier",
    "domiciliaient": "domicilier",
    "domiciliaires": "domiciliaire",
    "domiciliais": "domicilier",
    "domiciliait": "domicilier",
    "domiciliant": "domicilier",
    "domicilias": "domicilier",
    "domiciliasse": "domicilier",
    "domiciliassent": "domicilier",
    "domiciliasses": "domicilier",
    "domiciliassiez": "domicilier",
    "domiciliassions": "domicilier",
    "domicilie": "domicilier",
    "domicilient": "domicilier",
    "domiciliera": "domicilier",
    "domicilierai": "domicilier",
    "domicilieraient": "domicilier",
    "domicilierais": "domicilier",
    "domicilierait": "domicilier",
    "domicilieras": "domicilier",
    "domicilierez": "domicilier",
    "domicilieriez": "domicilier",
    "domicilierions": "domicilier",
    "domicilierons": "domicilier",
    "domicilieront": "domicilier",
    "domicilies": "domicilier",
    "domiciliez": "domicilier",
    "domiciliiez": "domicilier",
    "domiciliions": "domicilier",
    "domicilions": "domicilier",
    "domiciliâmes": "domicilier",
    "domiciliât": "domicilier",
    "domiciliâtes": "domicilier",
    "domicilièrent": "domicilier",
    "domicilié": "domicilier",
    "domiciliée": "domicilier",
    "domiciliées": "domicilier",
    "domiciliés": "domicilier",
    "domina": "dominer",
    "dominai": "dominer",
    "dominaient": "dominer",
    "dominais": "dominer",
    "dominait": "dominer",
    "dominances": "dominance",
    "dominant": "dominer",
    "dominante": "dominant",
    "dominantes": "dominante",
    "dominants": "dominant",
    "dominas": "dominer",
    "dominasse": "dominer",
    "dominassent": "dominer",
    "dominasses": "dominer",
    "dominassiez": "dominer",
    "dominassions": "dominer",
    "dominateurs": "dominateur",
    "dominations": "domination",
    "dominatrice": "dominateur",
    "dominatrices": "dominateur",
    "domine": "dominer",
    "dominent": "dominer",
    "dominera": "dominer",
    "dominerai": "dominer",
    "domineraient": "dominer",
    "dominerais": "dominer",
    "dominerait": "dominer",
    "domineras": "dominer",
    "dominerez": "dominer",
    "domineriez": "dominer",
    "dominerions": "dominer",
    "dominerons": "dominer",
    "domineront": "dominer",
    "domines": "dominer",
    "dominez": "dominer",
    "dominicaine": "dominicain",
    "dominicaines": "dominicain",
    "dominicains": "dominicain",
    "dominicale": "dominical",
    "dominicales": "dominical",
    "dominicaux": "dominical",
    "dominiez": "dominer",
    "dominions": "dominion",
    "dominons": "dominer",
    "dominos": "domino",
    "dominoteries": "dominoterie",
    "dominâmes": "dominer",
    "dominât": "dominer",
    "dominâtes": "dominer",
    "dominèrent": "dominer",
    "dominé": "dominer",
    "dominée": "dominer",
    "dominées": "dominer",
    "dominés": "dominer",
    "dommageables": "dommageable",
    "dommages": "dommage",
    "domoticienne": "domoticien",
    "domoticiennes": "domoticien",
    "domoticiens": "domoticien",
    "domotiques": "domotique",
    "dompta": "dompter",
    "domptai": "dompter",
    "domptaient": "dompter",
    "domptais": "dompter",
    "domptait": "dompter",
    "domptant": "dompter",
    "domptas": "dompter",
    "domptasse": "dompter",
    "domptassent": "dompter",
    "domptasses": "dompter",
    "domptassiez": "dompter",
    "domptassions": "dompter",
    "dompte": "dompter",
    "domptent": "dompter",
    "domptera": "dompter",
    "dompterai": "dompter",
    "dompteraient": "dompter",
    "dompterais": "dompter",
    "dompterait": "dompter",
    "dompteras": "dompter",
    "dompterez": "dompter",
    "dompteriez": "dompter",
    "dompterions": "dompter",
    "dompterons": "dompter",
    "dompteront": "dompter",
    "domptes": "dompter",
    "dompteurs": "dompteur",
    "dompteuse": "dompteur",
    "dompteuses": "dompteur",
    "domptez": "dompter",
    "domptiez": "dompter",
    "domptions": "dompter",
    "domptons": "dompter",
    "domptâmes": "dompter",
    "domptât": "dompter",
    "domptâtes": "dompter",
    "domptèrent": "dompter",
    "dompté": "dompter",
    "domptée": "dompter",
    "domptées": "dompter",
    "domptés": "dompter",
    "donataires": "donataire",
    "donateurs": "donateur",
    "donations": "donation",
    "donatrice": "donateur",
    "donatrices": "donateur",
    "dondaines": "dondaine",
    "dondons": "dondon",
    "donjons": "donjon",
    "donna": "donner",
    "donnai": "donner",
    "donnaient": "donner",
    "donnais": "donner",
    "donnait": "donner",
    "donnant": "donner",
    "donnas": "donner",
    "donnasse": "donner",
    "donnassent": "donner",
    "donnasses": "donner",
    "donnassiez": "donner",
    "donnassions": "donner",
    "donne": "donner",
    "donnent": "donner",
    "donnera": "donner",
    "donnerai": "donner",
    "donneraient": "donner",
    "donnerais": "donner",
    "donnerait": "donner",
    "donneras": "donner",
    "donnerez": "donner",
    "donneriez": "donner",
    "donnerions": "donner",
    "donnerons": "donner",
    "donneront": "donner",
    "donnes": "donner",
    "donneurs": "donneur",
    "donneuse": "donneur",
    "donneuses": "donneur",
    "donnez": "donner",
    "donniez": "donner",
    "donnions": "donner",
    "donnons": "donner",
    "donnâmes": "donner",
    "donnât": "donner",
    "donnâtes": "donner",
    "donnèrent": "donner",
    "donné": "donner",
    "donnée": "donner",
    "données": "donner",
    "donnés": "donner",
    "donquichottesques": "donquichottesque",
    "donquichottismes": "donquichottisme",
    "dons": "don",
    "donzelles": "donzelle",
    "dopa": "doper",
    "dopages": "dopage",
    "dopai": "doper",
    "dopaient": "doper",
    "dopais": "doper",
    "dopait": "doper",
    "dopant": "doper",
    "dopants": "dopant",
    "dopas": "doper",
    "dopasse": "doper",
    "dopassent": "doper",
    "dopasses": "doper",
    "dopassiez": "doper",
    "dopassions": "doper",
    "dope": "doper",
    "dopent": "doper",
    "dopera": "doper",
    "doperai": "doper",
    "doperaient": "doper",
    "doperais": "doper",
    "doperait": "doper",
    "doperas": "doper",
    "doperez": "doper",
    "doperiez": "doper",
    "doperions": "doper",
    "doperons": "doper",
    "doperont": "doper",
    "dopes": "doper",
    "dopez": "doper",
    "dopiez": "doper",
    "dopings": "doping",
    "dopions": "doper",
    "dopons": "doper",
    "dopâmes": "doper",
    "dopât": "doper",
    "dopâtes": "doper",
    "dopèrent": "doper",
    "dopé": "doper",
    "dopée": "doper",
    "dopées": "doper",
    "dopés": "doper",
    "dora": "dorer",
    "dorades": "dorade",
    "dorai": "dorer",
    "doraient": "dorer",
    "dorais": "dorer",
    "dorait": "dorer",
    "dorant": "dorer",
    "doras": "dorer",
    "dorasse": "dorer",
    "dorassent": "dorer",
    "dorasses": "dorer",
    "dorassiez": "dorer",
    "dorassions": "dorer",
    "dorcades": "dorcade",
    "dore": "dorer",
    "dorent": "dorer",
    "dorera": "dorer",
    "dorerai": "dorer",
    "doreraient": "dorer",
    "dorerais": "dorer",
    "dorerait": "dorer",
    "doreras": "dorer",
    "dorerez": "dorer",
    "doreriez": "dorer",
    "dorerions": "dorer",
    "dorerons": "dorer",
    "doreront": "dorer",
    "dores": "dorer",
    "doreurs": "doreur",
    "dorez": "dorer",
    "doriennes": "dorien",
    "doriens": "dorien",
    "doriez": "dorer",
    "dorions": "dorer",
    "doriques": "dorique",
    "dorlota": "dorloter",
    "dorlotai": "dorloter",
    "dorlotaient": "dorloter",
    "dorlotais": "dorloter",
    "dorlotait": "dorloter",
    "dorlotant": "dorloter",
    "dorlotas": "dorloter",
    "dorlotasse": "dorloter",
    "dorlotassent": "dorloter",
    "dorlotasses": "dorloter",
    "dorlotassiez": "dorloter",
    "dorlotassions": "dorloter",
    "dorlote": "dorloter",
    "dorlotent": "dorloter",
    "dorlotera": "dorloter",
    "dorloterai": "dorloter",
    "dorloteraient": "dorloter",
    "dorloterais": "dorloter",
    "dorloterait": "dorloter",
    "dorloteras": "dorloter",
    "dorloterez": "dorloter",
    "dorloteriez": "dorloter",
    "dorloterions": "dorloter",
    "dorloterons": "dorloter",
    "dorloteront": "dorloter",
    "dorlotes": "dorloter",
    "dorlotez": "dorloter",
    "dorlotiez": "dorloter",
    "dorlotions": "dorloter",
    "dorlotons": "dorloter",
    "dorlotâmes": "dorloter",
    "dorlotât": "dorloter",
    "dorlotâtes": "dorloter",
    "dorlotèrent": "dorloter",
    "dorloté": "dorloter",
    "dorlotée": "dorloter",
    "dorlotées": "dorloter",
    "dorlotés": "dorloter",
    "dormaient": "dormir",
    "dormais": "dormir",
    "dormait": "dormir",
    "dormant": "dormir",
    "dormante": "dormant",
    "dormantes": "dormant",
    "dormants": "dormant",
    "dorme": "dormir",
    "dorment": "dormir",
    "dormes": "dormir",
    "dormeurs": "dormeur",
    "dormeuse": "dormeur",
    "dormeuses": "dormeur",
    "dormez": "dormir",
    "dormi": "dormir",
    "dormiez": "dormir",
    "dormions": "dormir",
    "dormira": "dormir",
    "dormirai": "dormir",
    "dormiraient": "dormir",
    "dormirais": "dormir",
    "dormirait": "dormir",
    "dormiras": "dormir",
    "dormirent": "dormir",
    "dormirez": "dormir",
    "dormiriez": "dormir",
    "dormirions": "dormir",
    "dormirons": "dormir",
    "dormiront": "dormir",
    "dormis": "dormir",
    "dormisse": "dormir",
    "dormissent": "dormir",
    "dormisses": "dormir",
    "dormissiez": "dormir",
    "dormissions": "dormir",
    "dormit": "dormir",
    "dormons": "dormir",
    "dormîmes": "dormir",
    "dormît": "dormir",
    "dormîtes": "dormir",
    "dorons": "dorer",
    "dors": "dormir",
    "dorsale": "dorsal",
    "dorsales": "dorsal",
    "dorsaux": "dorsal",
    "dort": "dormir",
    "dortoirs": "dortoir",
    "dorures": "dorure",
    "doryphores": "doryphore",
    "dorâmes": "dorer",
    "dorât": "dorer",
    "dorâtes": "dorer",
    "dorèrent": "dorer",
    "doré": "dorer",
    "dorée": "dorer",
    "dorées": "dorer",
    "dorés": "dorer",
    "dosa": "doser",
    "dosages": "dosage",
    "dosai": "doser",
    "dosaient": "doser",
    "dosais": "doser",
    "dosait": "doser",
    "dosant": "doser",
    "dosas": "doser",
    "dosasse": "doser",
    "dosassent": "doser",
    "dosasses": "doser",
    "dosassiez": "doser",
    "dosassions": "doser",
    "dose": "doser",
    "dosent": "doser",
    "dosera": "doser",
    "doserai": "doser",
    "doseraient": "doser",
    "doserais": "doser",
    "doserait": "doser",
    "doseras": "doser",
    "doserez": "doser",
    "doseriez": "doser",
    "doserions": "doser",
    "doserons": "doser",
    "doseront": "doser",
    "doses": "doser",
    "doseurs": "doseur",
    "dosez": "doser",
    "dosiez": "doser",
    "dosimètres": "dosimètre",
    "dosions": "doser",
    "dosons": "doser",
    "dossards": "dossard",
    "dossiers": "dossier",
    "dossières": "dossière",
    "dostoïevskiens": "dostoïevskien",
    "dosâmes": "doser",
    "dosât": "doser",
    "dosâtes": "doser",
    "dosèrent": "doser",
    "dosé": "doser",
    "dosée": "doser",
    "dosées": "doser",
    "dosés": "doser",
    "dota": "doter",
    "dotai": "doter",
    "dotaient": "doter",
    "dotais": "doter",
    "dotait": "doter",
    "dotant": "doter",
    "dotas": "doter",
    "dotasse": "doter",
    "dotassent": "doter",
    "dotasses": "doter",
    "dotassiez": "doter",
    "dotassions": "doter",
    "dotations": "dotation",
    "dote": "doter",
    "dotent": "doter",
    "dotera": "doter",
    "doterai": "doter",
    "doteraient": "doter",
    "doterais": "doter",
    "doterait": "doter",
    "doteras": "doter",
    "doterez": "doter",
    "doteriez": "doter",
    "doterions": "doter",
    "doterons": "doter",
    "doteront": "doter",
    "dotes": "doter",
    "dotez": "doter",
    "dotiez": "doter",
    "dotions": "doter",
    "dotons": "doter",
    "dots": "dot",
    "dotâmes": "doter",
    "dotât": "doter",
    "dotâtes": "doter",
    "dotèrent": "doter",
    "doté": "doter",
    "dotée": "doter",
    "dotées": "doter",
    "dotés": "doter",
    "douaires": "douaire",
    "douairière": "douairier",
    "douairières": "douairière",
    "douait": "douer",
    "douanes": "douane",
    "douaniers": "douanier",
    "douanière": "douanier",
    "douanières": "douanier",
    "douars": "douar",
    "doubla": "doubler",
    "doublages": "doublage",
    "doublai": "doubler",
    "doublaient": "doubler",
    "doublais": "doubler",
    "doublait": "doubler",
    "doublant": "doubler",
    "doublards": "doublard",
    "doublas": "doubler",
    "doublasse": "doubler",
    "doublassent": "doubler",
    "doublasses": "doubler",
    "doublassiez": "doubler",
    "doublassions": "doubler",
    "double": "doubler",
    "double-cliqué": "double-cliquer",
    "doubleaux": "doubleau",
    "doublent": "doubler",
    "doublera": "doubler",
    "doublerai": "doubler",
    "doubleraient": "doubler",
    "doublerais": "doubler",
    "doublerait": "doubler",
    "doubleras": "doubler",
    "doublerez": "doubler",
    "doubleriez": "doubler",
    "doublerions": "doubler",
    "doublerons": "doubler",
    "doubleront": "doubler",
    "doubles": "doubler",
    "doublets": "doublet",
    "doubleuse": "doubleur",
    "doubleuses": "doubleur",
    "doublez": "doubler",
    "doubliez": "doubler",
    "doublions": "doubler",
    "doublonnages": "doublonnage",
    "doublons": "doublon",
    "doublures": "doublure",
    "doublâmes": "doubler",
    "doublât": "doubler",
    "doublâtes": "doubler",
    "doublèrent": "doubler",
    "doublé": "doubler",
    "doublée": "doubler",
    "doublées": "doubler",
    "doublés": "doubler",
    "douce": "doux",
    "doucereuse": "doucereux",
    "doucereuses": "doucereux",
    "douces": "doux",
    "douces-amères": "douce-amère",
    "doucette": "doucet",
    "douceurs": "douceur",
    "douceâtres": "douceâtre",
    "doucha": "doucher",
    "douchai": "doucher",
    "douchaient": "doucher",
    "douchais": "doucher",
    "douchait": "doucher",
    "douchant": "doucher",
    "douchas": "doucher",
    "douchasse": "doucher",
    "douchassent": "doucher",
    "douchasses": "doucher",
    "douchassiez": "doucher",
    "douchassions": "doucher",
    "douche": "doucher",
    "douchent": "doucher",
    "douchera": "doucher",
    "doucherai": "doucher",
    "doucheraient": "doucher",
    "doucherais": "doucher",
    "doucherait": "doucher",
    "doucheras": "doucher",
    "doucherez": "doucher",
    "doucheriez": "doucher",
    "doucherions": "doucher",
    "doucherons": "doucher",
    "doucheront": "doucher",
    "douches": "doucher",
    "douchez": "doucher",
    "douchiez": "doucher",
    "douchions": "doucher",
    "douchons": "doucher",
    "douchâmes": "doucher",
    "douchât": "doucher",
    "douchâtes": "doucher",
    "douchèrent": "doucher",
    "douché": "doucher",
    "douchée": "doucher",
    "douchées": "doucher",
    "douchés": "doucher",
    "douci": "doucir",
    "doucie": "doucir",
    "doucies": "doucir",
    "doucins": "doucin",
    "doucira": "doucir",
    "doucirai": "doucir",
    "douciraient": "doucir",
    "doucirais": "doucir",
    "doucirait": "doucir",
    "douciras": "doucir",
    "doucirent": "doucir",
    "doucirez": "doucir",
    "douciriez": "doucir",
    "doucirions": "doucir",
    "doucirons": "doucir",
    "douciront": "doucir",
    "doucis": "doucir",
    "doucissaient": "doucir",
    "doucissais": "doucir",
    "doucissait": "doucir",
    "doucissant": "doucir",
    "doucisse": "doucir",
    "doucissent": "doucir",
    "doucisses": "doucir",
    "doucissez": "doucir",
    "doucissiez": "doucir",
    "doucissions": "doucir",
    "doucissons": "doucir",
    "doucit": "doucir",
    "doucîmes": "doucir",
    "doucît": "doucir",
    "doucîtes": "doucir",
    "doudounes": "doudoune",
    "douelles": "douelle",
    "douillait": "douiller",
    "douille": "douiller",
    "douillent": "douiller",
    "douillera": "douiller",
    "douilles": "douiller",
    "douillets": "douillet",
    "douillette": "douillet",
    "douillettes": "douillette",
    "douillons": "douillon",
    "douillé": "douiller",
    "douillée": "douiller",
    "douleurs": "douleur",
    "douloureuse": "douloureux",
    "douloureuses": "douloureux",
    "douros": "douro",
    "douta": "douter",
    "doutai": "douter",
    "doutaient": "douter",
    "doutais": "douter",
    "doutait": "douter",
    "doutances": "doutance",
    "doutant": "douter",
    "doutas": "douter",
    "doutasse": "douter",
    "doutassent": "douter",
    "doutasses": "douter",
    "doutassiez": "douter",
    "doutassions": "douter",
    "doute": "douter",
    "doutent": "douter",
    "doutera": "douter",
    "douterai": "douter",
    "douteraient": "douter",
    "douterais": "douter",
    "douterait": "douter",
    "douteras": "douter",
    "douterez": "douter",
    "douteriez": "douter",
    "douterions": "douter",
    "douterons": "douter",
    "douteront": "douter",
    "doutes": "douter",
    "douteurs": "douteur",
    "douteuse": "douteux",
    "douteuses": "douteux",
    "doutez": "douter",
    "doutiez": "douter",
    "doutions": "douter",
    "doutons": "douter",
    "doutâmes": "douter",
    "doutât": "douter",
    "doutâtes": "douter",
    "doutèrent": "douter",
    "douté": "douter",
    "doutée": "douter",
    "doutés": "douter",
    "douves": "douve",
    "douzaines": "douzaine",
    "douzièmes": "douzième",
    "doué": "douer",
    "douée": "douer",
    "douées": "douer",
    "doués": "douer",
    "doyenne": "doyen",
    "doyennes": "doyen",
    "doyennés": "doyenné",
    "doyens": "doyen",
    "doñas": "doña",
    "drache": "dracher",
    "drachmes": "drachme",
    "draconienne": "draconien",
    "draconiennes": "draconien",
    "draconiens": "draconien",
    "dragages": "dragage",
    "drageoirs": "drageoir",
    "drageons": "drageon",
    "dragonnades": "dragonnade",
    "dragonne": "dragon",
    "dragonnes": "dragonne",
    "dragons": "dragon",
    "drags": "drag",
    "dragua": "draguer",
    "draguai": "draguer",
    "draguaient": "draguer",
    "draguais": "draguer",
    "draguait": "draguer",
    "draguant": "draguer",
    "draguas": "draguer",
    "draguasse": "draguer",
    "draguassent": "draguer",
    "draguasses": "draguer",
    "draguassiez": "draguer",
    "draguassions": "draguer",
    "drague": "draguer",
    "draguent": "draguer",
    "draguera": "draguer",
    "draguerai": "draguer",
    "dragueraient": "draguer",
    "draguerais": "draguer",
    "draguerait": "draguer",
    "dragueras": "draguer",
    "draguerez": "draguer",
    "dragueriez": "draguer",
    "draguerions": "draguer",
    "draguerons": "draguer",
    "dragueront": "draguer",
    "dragues": "draguer",
    "dragueurs": "dragueur",
    "dragueuse": "dragueur",
    "draguez": "draguer",
    "draguiez": "draguer",
    "draguions": "draguer",
    "draguons": "draguer",
    "draguâmes": "draguer",
    "draguât": "draguer",
    "draguâtes": "draguer",
    "draguèrent": "draguer",
    "dragué": "draguer",
    "draguée": "draguer",
    "draguées": "draguer",
    "dragués": "draguer",
    "dragées": "dragée",
    "drailles": "draille",
    "draina": "drainer",
    "drainages": "drainage",
    "drainai": "drainer",
    "drainaient": "drainer",
    "drainais": "drainer",
    "drainait": "drainer",
    "drainant": "drainer",
    "drainas": "drainer",
    "drainasse": "drainer",
    "drainassent": "drainer",
    "drainasses": "drainer",
    "drainassiez": "drainer",
    "drainassions": "drainer",
    "draine": "drainer",
    "drainent": "drainer",
    "drainera": "drainer",
    "drainerai": "drainer",
    "draineraient": "drainer",
    "drainerais": "drainer",
    "drainerait": "drainer",
    "draineras": "drainer",
    "drainerez": "drainer",
    "draineriez": "drainer",
    "drainerions": "drainer",
    "drainerons": "drainer",
    "draineront": "drainer",
    "draines": "drainer",
    "drainez": "drainer",
    "drainiez": "drainer",
    "drainions": "drainer",
    "drainons": "drainer",
    "drains": "drain",
    "drainâmes": "drainer",
    "drainât": "drainer",
    "drainâtes": "drainer",
    "drainèrent": "drainer",
    "drainé": "drainer",
    "drainée": "drainer",
    "drainées": "drainer",
    "drainés": "drainer",
    "drakkars": "drakkar",
    "dramatiques": "dramatique",
    "dramatisa": "dramatiser",
    "dramatisai": "dramatiser",
    "dramatisaient": "dramatiser",
    "dramatisais": "dramatiser",
    "dramatisait": "dramatiser",
    "dramatisant": "dramatiser",
    "dramatisas": "dramatiser",
    "dramatisasse": "dramatiser",
    "dramatisassent": "dramatiser",
    "dramatisasses": "dramatiser",
    "dramatisassiez": "dramatiser",
    "dramatisassions": "dramatiser",
    "dramatisations": "dramatisation",
    "dramatise": "dramatiser",
    "dramatisent": "dramatiser",
    "dramatisera": "dramatiser",
    "dramatiserai": "dramatiser",
    "dramatiseraient": "dramatiser",
    "dramatiserais": "dramatiser",
    "dramatiserait": "dramatiser",
    "dramatiseras": "dramatiser",
    "dramatiserez": "dramatiser",
    "dramatiseriez": "dramatiser",
    "dramatiserions": "dramatiser",
    "dramatiserons": "dramatiser",
    "dramatiseront": "dramatiser",
    "dramatises": "dramatiser",
    "dramatisez": "dramatiser",
    "dramatisiez": "dramatiser",
    "dramatisions": "dramatiser",
    "dramatisons": "dramatiser",
    "dramatisâmes": "dramatiser",
    "dramatisât": "dramatiser",
    "dramatisâtes": "dramatiser",
    "dramatisèrent": "dramatiser",
    "dramatisé": "dramatiser",
    "dramatisée": "dramatiser",
    "dramatisées": "dramatiser",
    "dramatisés": "dramatiser",
    "dramaturges": "dramaturge",
    "dramaturgies": "dramaturgie",
    "drames": "drame",
    "drapa": "draper",
    "drapai": "draper",
    "drapaient": "draper",
    "drapais": "draper",
    "drapait": "draper",
    "drapant": "draper",
    "drapas": "draper",
    "drapasse": "draper",
    "drapassent": "draper",
    "drapasses": "draper",
    "drapassiez": "draper",
    "drapassions": "draper",
    "drape": "draper",
    "drapeaux": "drapeau",
    "drapelets": "drapelet",
    "drapent": "draper",
    "drapera": "draper",
    "draperai": "draper",
    "draperaient": "draper",
    "draperais": "draper",
    "draperait": "draper",
    "draperas": "draper",
    "draperez": "draper",
    "draperies": "draperie",
    "draperiez": "draper",
    "draperions": "draper",
    "draperons": "draper",
    "draperont": "draper",
    "drapes": "draper",
    "drapez": "draper",
    "drapiers": "drapier",
    "drapiez": "draper",
    "drapions": "draper",
    "drapons": "draper",
    "draps": "drap",
    "drapâmes": "draper",
    "drapât": "draper",
    "drapâtes": "draper",
    "drapèrent": "draper",
    "drapé": "draper",
    "drapée": "draper",
    "drapées": "draper",
    "drapés": "draper",
    "drastiques": "drastique",
    "draveurs": "draveur",
    "drawbacks": "drawback",
    "dressa": "dresser",
    "dressages": "dressage",
    "dressai": "dresser",
    "dressaient": "dresser",
    "dressais": "dresser",
    "dressait": "dresser",
    "dressant": "dresser",
    "dressas": "dresser",
    "dressasse": "dresser",
    "dressassent": "dresser",
    "dressasses": "dresser",
    "dressassiez": "dresser",
    "dressassions": "dresser",
    "dresse": "dresser",
    "dressent": "dresser",
    "dressera": "dresser",
    "dresserai": "dresser",
    "dresseraient": "dresser",
    "dresserais": "dresser",
    "dresserait": "dresser",
    "dresseras": "dresser",
    "dresserez": "dresser",
    "dresseriez": "dresser",
    "dresserions": "dresser",
    "dresserons": "dresser",
    "dresseront": "dresser",
    "dresses": "dresser",
    "dresseurs": "dresseur",
    "dresseuse": "dresseur",
    "dressez": "dresser",
    "dressiez": "dresser",
    "dressions": "dresser",
    "dressoirs": "dressoir",
    "dressons": "dresser",
    "dressâmes": "dresser",
    "dressât": "dresser",
    "dressâtes": "dresser",
    "dressèrent": "dresser",
    "dressé": "dresser",
    "dressée": "dresser",
    "dressées": "dresser",
    "dressés": "dresser",
    "dreyfusards": "dreyfusard",
    "dribbla": "dribbler",
    "dribblai": "dribbler",
    "dribblaient": "dribbler",
    "dribblais": "dribbler",
    "dribblait": "dribbler",
    "dribblant": "dribbler",
    "dribblas": "dribbler",
    "dribblasse": "dribbler",
    "dribblassent": "dribbler",
    "dribblasses": "dribbler",
    "dribblassiez": "dribbler",
    "dribblassions": "dribbler",
    "dribble": "dribbler",
    "dribblent": "dribbler",
    "dribblera": "dribbler",
    "dribblerai": "dribbler",
    "dribbleraient": "dribbler",
    "dribblerais": "dribbler",
    "dribblerait": "dribbler",
    "dribbleras": "dribbler",
    "dribblerez": "dribbler",
    "dribbleriez": "dribbler",
    "dribblerions": "dribbler",
    "dribblerons": "dribbler",
    "dribbleront": "dribbler",
    "dribbles": "dribbler",
    "dribblez": "dribbler",
    "dribbliez": "dribbler",
    "dribblions": "dribbler",
    "dribblons": "dribbler",
    "dribblâmes": "dribbler",
    "dribblât": "dribbler",
    "dribblâtes": "dribbler",
    "dribblèrent": "dribbler",
    "dribblé": "dribbler",
    "dribblée": "dribbler",
    "dribblées": "dribbler",
    "dribblés": "dribbler",
    "drible": "dribler",
    "drifters": "drifter",
    "drilles": "drille",
    "drills": "drill",
    "drinks": "drink",
    "drisses": "drisse",
    "driva": "driver",
    "drivai": "driver",
    "drivaient": "driver",
    "drivais": "driver",
    "drivait": "driver",
    "drivant": "driver",
    "drivas": "driver",
    "drivasse": "driver",
    "drivassent": "driver",
    "drivasses": "driver",
    "drivassiez": "driver",
    "drivassions": "driver",
    "drive": "driver",
    "drivent": "driver",
    "drivera": "driver",
    "driverai": "driver",
    "driveraient": "driver",
    "driverais": "driver",
    "driverait": "driver",
    "driveras": "driver",
    "driverez": "driver",
    "driveriez": "driver",
    "driverions": "driver",
    "driverons": "driver",
    "driveront": "driver",
    "drivers": "driver",
    "drives": "driver",
    "drivez": "driver",
    "driviez": "driver",
    "drivions": "driver",
    "drivons": "driver",
    "drivâmes": "driver",
    "drivât": "driver",
    "drivâtes": "driver",
    "drivèrent": "driver",
    "drivé": "driver",
    "drivée": "driver",
    "drivées": "driver",
    "drivés": "driver",
    "drogmans": "drogman",
    "droguaient": "droguer",
    "droguais": "droguer",
    "droguait": "droguer",
    "droguant": "droguer",
    "drogue": "droguer",
    "droguent": "droguer",
    "drogueries": "droguerie",
    "drogues": "droguer",
    "droguets": "droguet",
    "droguez": "droguer",
    "droguiez": "droguer",
    "droguistes": "droguiste",
    "drogué": "droguer",
    "droguée": "droguer",
    "droguées": "droguer",
    "drogués": "droguer",
    "droicos": "droico",
    "droite": "droit",
    "droites": "droite",
    "droitiers": "droitier",
    "droitisations": "droitisation",
    "droitière": "droitier",
    "droitières": "droitier",
    "droits": "droit",
    "drolatiques": "drolatique",
    "dromadaires": "dromadaire",
    "dromes": "drome",
    "drones": "drone",
    "drop-goals": "drop-goal",
    "dropa": "droper",
    "dropai": "droper",
    "dropaient": "droper",
    "dropais": "droper",
    "dropait": "droper",
    "dropant": "droper",
    "dropas": "droper",
    "dropasse": "droper",
    "dropassent": "droper",
    "dropasses": "droper",
    "dropassiez": "droper",
    "dropassions": "droper",
    "drope": "droper",
    "dropent": "droper",
    "dropera": "droper",
    "droperai": "droper",
    "droperaient": "droper",
    "droperais": "droper",
    "droperait": "droper",
    "droperas": "droper",
    "droperez": "droper",
    "droperiez": "droper",
    "droperions": "droper",
    "droperons": "droper",
    "droperont": "droper",
    "dropes": "droper",
    "dropez": "droper",
    "dropiez": "droper",
    "dropions": "droper",
    "dropons": "droper",
    "droppa": "dropper",
    "droppages": "droppage",
    "droppai": "dropper",
    "droppaient": "dropper",
    "droppais": "dropper",
    "droppait": "dropper",
    "droppant": "dropper",
    "droppas": "dropper",
    "droppasse": "dropper",
    "droppassent": "dropper",
    "droppasses": "dropper",
    "droppassiez": "dropper",
    "droppassions": "dropper",
    "droppe": "dropper",
    "droppent": "dropper",
    "droppera": "dropper",
    "dropperai": "dropper",
    "dropperaient": "dropper",
    "dropperais": "dropper",
    "dropperait": "dropper",
    "dropperas": "dropper",
    "dropperez": "dropper",
    "dropperiez": "dropper",
    "dropperions": "dropper",
    "dropperons": "dropper",
    "dropperont": "dropper",
    "droppes": "dropper",
    "droppez": "dropper",
    "droppiez": "dropper",
    "droppions": "dropper",
    "droppons": "dropper",
    "droppâmes": "dropper",
    "droppât": "dropper",
    "droppâtes": "dropper",
    "droppèrent": "dropper",
    "droppé": "dropper",
    "droppée": "dropper",
    "droppées": "dropper",
    "droppés": "dropper",
    "dropâmes": "droper",
    "dropât": "droper",
    "dropâtes": "droper",
    "dropèrent": "droper",
    "dropé": "droper",
    "dropée": "droper",
    "dropées": "droper",
    "dropés": "droper",
    "drosophiles": "drosophile",
    "drossa": "drosser",
    "drossai": "drosser",
    "drossaient": "drosser",
    "drossais": "drosser",
    "drossait": "drosser",
    "drossant": "drosser",
    "drossas": "drosser",
    "drossasse": "drosser",
    "drossassent": "drosser",
    "drossasses": "drosser",
    "drossassiez": "drosser",
    "drossassions": "drosser",
    "drosse": "drosser",
    "drossent": "drosser",
    "drossera": "drosser",
    "drosserai": "drosser",
    "drosseraient": "drosser",
    "drosserais": "drosser",
    "drosserait": "drosser",
    "drosseras": "drosser",
    "drosserez": "drosser",
    "drosseriez": "drosser",
    "drosserions": "drosser",
    "drosserons": "drosser",
    "drosseront": "drosser",
    "drosses": "drosser",
    "drossez": "drosser",
    "drossiez": "drosser",
    "drossions": "drosser",
    "drossons": "drosser",
    "drossâmes": "drosser",
    "drossât": "drosser",
    "drossâtes": "drosser",
    "drossèrent": "drosser",
    "drossé": "drosser",
    "drossée": "drosser",
    "drossées": "drosser",
    "drossés": "drosser",
    "drue": "dru",
    "drues": "dru",
    "drugstores": "drugstore",
    "druides": "druide",
    "druidesse": "druide",
    "druidesses": "druidesse",
    "druidiques": "druidique",
    "drupes": "drupe",
    "drus": "dru",
    "druzes": "druze",
    "dryades": "dryade",
    "drôlatiques": "drôlatique",
    "drôleries": "drôlerie",
    "drôles": "drôle",
    "drôlesse": "drôle",
    "drôlesses": "drôlesse",
    "drôlette": "drôlet",
    "duale": "dual",
    "duales": "dual",
    "dualismes": "dualisme",
    "dualités": "dualité",
    "duaux": "dual",
    "dubitatifs": "dubitatif",
    "dubitations": "dubitation",
    "dubitative": "dubitatif",
    "dubitatives": "dubitatif",
    "dubs": "dub",
    "ducale": "ducal",
    "ducales": "ducal",
    "ducasses": "ducasse",
    "ducats": "ducat",
    "ducaux": "ducal",
    "ducauxs": "ducal",
    "duces": "duce",
    "duchesse": "duc",
    "duchesses": "duc",
    "ducs": "duc",
    "ducs-d'albe": "duc-d'albe",
    "ductiles": "ductile",
    "due": "dû",
    "duellistes": "duelliste",
    "duels": "duel",
    "dues": "dû",
    "duettistes": "duettiste",
    "duffle-coats": "duffle-coat",
    "dugongs": "dugong",
    "dulcifiant": "dulcifier",
    "dumpings": "dumping",
    "dundees": "dundee",
    "dunes": "dune",
    "dunettes": "dunette",
    "duodécimale": "duodécimal",
    "duodécimales": "duodécimal",
    "duodécimaux": "duodécimal",
    "duodénale": "duodénal",
    "duodénales": "duodénal",
    "duodénaux": "duodénal",
    "duodénums": "duodénum",
    "duos": "duo",
    "dupait": "duper",
    "dupant": "duper",
    "dupe": "duper",
    "dupent": "duper",
    "dupera": "duper",
    "duperas": "duper",
    "duperies": "duperie",
    "dupes": "duper",
    "dupez": "duper",
    "duplicatas": "duplicata",
    "duplicateurs": "duplicateur",
    "duplicités": "duplicité",
    "dupliqué": "dupliquer",
    "dupliqués": "dupliquer",
    "dupons": "duper",
    "dupé": "duper",
    "dupée": "duper",
    "dupées": "dupé",
    "dupés": "duper",
    "dura": "durer",
    "durabilités": "durabilité",
    "durables": "durable",
    "durai": "durer",
    "duraient": "durer",
    "durailles": "duraille",
    "durais": "durer",
    "durait": "durer",
    "durale": "dural",
    "durant": "durer",
    "duras": "durer",
    "durasse": "durer",
    "durassent": "durer",
    "durasses": "durer",
    "durassiez": "durer",
    "durassions": "durer",
    "durci": "durcir",
    "durcie": "durcir",
    "durcies": "durcir",
    "durcira": "durcir",
    "durcirai": "durcir",
    "durciraient": "durcir",
    "durcirais": "durcir",
    "durcirait": "durcir",
    "durciras": "durcir",
    "durcirent": "durcir",
    "durcirez": "durcir",
    "durciriez": "durcir",
    "durcirions": "durcir",
    "durcirons": "durcir",
    "durciront": "durcir",
    "durcis": "durcir",
    "durcissaient": "durcir",
    "durcissais": "durcir",
    "durcissait": "durcir",
    "durcissant": "durcir",
    "durcisse": "durcir",
    "durcissements": "durcissement",
    "durcissent": "durcir",
    "durcisses": "durcir",
    "durcissez": "durcir",
    "durcissiez": "durcir",
    "durcissions": "durcir",
    "durcissons": "durcir",
    "durcit": "durcir",
    "durcîmes": "durcir",
    "durcît": "durcir",
    "durcîtes": "durcir",
    "dure": "durer",
    "durent": "durer",
    "durera": "durer",
    "durerai": "durer",
    "dureraient": "durer",
    "durerais": "durer",
    "durerait": "durer",
    "dureras": "durer",
    "durerez": "durer",
    "dureriez": "durer",
    "durerions": "durer",
    "durerons": "durer",
    "dureront": "durer",
    "dures": "durer",
    "dures-mères": "dure-mère",
    "duretés": "dureté",
    "durez": "durer",
    "duriez": "durer",
    "durillons": "durillon",
    "durions": "durer",
    "durites": "durite",
    "durons": "durer",
    "durs": "dur",
    "durâmes": "durer",
    "durât": "durer",
    "durâtes": "durer",
    "durèrent": "durer",
    "duré": "durer",
    "durée": "durer",
    "durées": "durer",
    "dus": "dû",
    "dusse": "devoir",
    "dussent": "devoir",
    "dusses": "devoir",
    "dussiez": "devoir",
    "dussions": "devoir",
    "dut": "devoir",
    "duumviri": "duumvir",
    "duumvirs": "duumvir",
    "duveteuse": "duveteux",
    "duveteuses": "duveteux",
    "duvets": "duvet",
    "duveté": "duveter",
    "duvetée": "duveté",
    "duvetées": "duveter",
    "duvetés": "duveter",
    "duègnes": "duègne",
    "dykes": "dyke",
    "dynamiques": "dynamique",
    "dynamisa": "dynamiser",
    "dynamisai": "dynamiser",
    "dynamisaient": "dynamiser",
    "dynamisais": "dynamiser",
    "dynamisait": "dynamiser",
    "dynamisant": "dynamiser",
    "dynamisas": "dynamiser",
    "dynamisasse": "dynamiser",
    "dynamisassent": "dynamiser",
    "dynamisasses": "dynamiser",
    "dynamisassiez": "dynamiser",
    "dynamisassions": "dynamiser",
    "dynamise": "dynamiser",
    "dynamisent": "dynamiser",
    "dynamisera": "dynamiser",
    "dynamiserai": "dynamiser",
    "dynamiseraient": "dynamiser",
    "dynamiserais": "dynamiser",
    "dynamiserait": "dynamiser",
    "dynamiseras": "dynamiser",
    "dynamiserez": "dynamiser",
    "dynamiseriez": "dynamiser",
    "dynamiserions": "dynamiser",
    "dynamiserons": "dynamiser",
    "dynamiseront": "dynamiser",
    "dynamises": "dynamiser",
    "dynamisez": "dynamiser",
    "dynamisiez": "dynamiser",
    "dynamisions": "dynamiser",
    "dynamismes": "dynamisme",
    "dynamisons": "dynamiser",
    "dynamisâmes": "dynamiser",
    "dynamisât": "dynamiser",
    "dynamisâtes": "dynamiser",
    "dynamisèrent": "dynamiser",
    "dynamisé": "dynamiser",
    "dynamisée": "dynamiser",
    "dynamisées": "dynamiser",
    "dynamisés": "dynamiser",
    "dynamita": "dynamiter",
    "dynamitages": "dynamitage",
    "dynamitai": "dynamiter",
    "dynamitaient": "dynamiter",
    "dynamitais": "dynamiter",
    "dynamitait": "dynamiter",
    "dynamitant": "dynamiter",
    "dynamitas": "dynamiter",
    "dynamitasse": "dynamiter",
    "dynamitassent": "dynamiter",
    "dynamitasses": "dynamiter",
    "dynamitassiez": "dynamiter",
    "dynamitassions": "dynamiter",
    "dynamite": "dynamiter",
    "dynamitent": "dynamiter",
    "dynamitera": "dynamiter",
    "dynamiterai": "dynamiter",
    "dynamiteraient": "dynamiter",
    "dynamiterais": "dynamiter",
    "dynamiterait": "dynamiter",
    "dynamiteras": "dynamiter",
    "dynamiterez": "dynamiter",
    "dynamiteriez": "dynamiter",
    "dynamiterions": "dynamiter",
    "dynamiterons": "dynamiter",
    "dynamiteront": "dynamiter",
    "dynamites": "dynamiter",
    "dynamiteurs": "dynamiteur",
    "dynamitez": "dynamiter",
    "dynamitiez": "dynamiter",
    "dynamitions": "dynamiter",
    "dynamitons": "dynamiter",
    "dynamitâmes": "dynamiter",
    "dynamitât": "dynamiter",
    "dynamitâtes": "dynamiter",
    "dynamitèrent": "dynamiter",
    "dynamité": "dynamiter",
    "dynamitée": "dynamiter",
    "dynamitées": "dynamiter",
    "dynamités": "dynamiter",
    "dynamos": "dynamo",
    "dynasties": "dynastie",
    "dynes": "dyne",
    "dysenteries": "dysenterie",
    "dysentériques": "dysentérique",
    "dysfonctionnements": "dysfonctionnement",
    "dyslexies": "dyslexie",
    "dyspnées": "dyspnée",
    "dyspnéiques": "dyspnéique",
    "dyssociale": "dyssocial",
    "dyssociales": "dyssocial",
    "dyssociaux": "dyssocial",
    "dèches": "dèche",
    "dèmes": "dème",
    "déambula": "déambuler",
    "déambulai": "déambuler",
    "déambulaient": "déambuler",
    "déambulais": "déambuler",
    "déambulait": "déambuler",
    "déambulant": "déambuler",
    "déambulante": "déambulant",
    "déambulantes": "déambulant",
    "déambulants": "déambulant",
    "déambulas": "déambuler",
    "déambulasse": "déambuler",
    "déambulassent": "déambuler",
    "déambulasses": "déambuler",
    "déambulassiez": "déambuler",
    "déambulassions": "déambuler",
    "déambulations": "déambulation",
    "déambulatoires": "déambulatoire",
    "déambule": "déambuler",
    "déambulent": "déambuler",
    "déambulera": "déambuler",
    "déambulerai": "déambuler",
    "déambuleraient": "déambuler",
    "déambulerais": "déambuler",
    "déambulerait": "déambuler",
    "déambuleras": "déambuler",
    "déambulerez": "déambuler",
    "déambuleriez": "déambuler",
    "déambulerions": "déambuler",
    "déambulerons": "déambuler",
    "déambuleront": "déambuler",
    "déambules": "déambuler",
    "déambulez": "déambuler",
    "déambuliez": "déambuler",
    "déambulions": "déambuler",
    "déambulons": "déambuler",
    "déambulâmes": "déambuler",
    "déambulât": "déambuler",
    "déambulâtes": "déambuler",
    "déambulèrent": "déambuler",
    "déambulé": "déambuler",
    "débagoule": "débagouler",
    "débagoulerait": "débagouler",
    "débagoules": "débagouler",
    "déballa": "déballer",
    "déballages": "déballage",
    "déballai": "déballer",
    "déballaient": "déballer",
    "déballais": "déballer",
    "déballait": "déballer",
    "déballant": "déballer",
    "déballas": "déballer",
    "déballasse": "déballer",
    "déballassent": "déballer",
    "déballasses": "déballer",
    "déballassiez": "déballer",
    "déballassions": "déballer",
    "déballe": "déballer",
    "déballent": "déballer",
    "déballera": "déballer",
    "déballerai": "déballer",
    "déballeraient": "déballer",
    "déballerais": "déballer",
    "déballerait": "déballer",
    "déballeras": "déballer",
    "déballerez": "déballer",
    "déballeriez": "déballer",
    "déballerions": "déballer",
    "déballerons": "déballer",
    "déballeront": "déballer",
    "déballes": "déballer",
    "déballez": "déballer",
    "déballiez": "déballer",
    "déballions": "déballer",
    "déballonnerais": "déballonner",
    "déballonneront": "déballonner",
    "déballonné": "déballonner",
    "déballons": "déballer",
    "déballâmes": "déballer",
    "déballât": "déballer",
    "déballâtes": "déballer",
    "déballèrent": "déballer",
    "déballé": "déballer",
    "déballée": "déballer",
    "déballées": "déballer",
    "déballés": "déballer",
    "débanda": "débander",
    "débandades": "débandade",
    "débandai": "débander",
    "débandaient": "débander",
    "débandais": "débander",
    "débandait": "débander",
    "débandant": "débander",
    "débandas": "débander",
    "débandasse": "débander",
    "débandassent": "débander",
    "débandasses": "débander",
    "débandassiez": "débander",
    "débandassions": "débander",
    "débande": "débander",
    "débandent": "débander",
    "débandera": "débander",
    "débanderai": "débander",
    "débanderaient": "débander",
    "débanderais": "débander",
    "débanderait": "débander",
    "débanderas": "débander",
    "débanderez": "débander",
    "débanderiez": "débander",
    "débanderions": "débander",
    "débanderons": "débander",
    "débanderont": "débander",
    "débandes": "débander",
    "débandez": "débander",
    "débandiez": "débander",
    "débandions": "débander",
    "débandons": "débander",
    "débandâmes": "débander",
    "débandât": "débander",
    "débandâtes": "débander",
    "débandèrent": "débander",
    "débandé": "débander",
    "débandée": "débander",
    "débandées": "débander",
    "débandés": "débander",
    "débaptisa": "débaptiser",
    "débaptisai": "débaptiser",
    "débaptisaient": "débaptiser",
    "débaptisais": "débaptiser",
    "débaptisait": "débaptiser",
    "débaptisant": "débaptiser",
    "débaptisas": "débaptiser",
    "débaptisasse": "débaptiser",
    "débaptisassent": "débaptiser",
    "débaptisasses": "débaptiser",
    "débaptisassiez": "débaptiser",
    "débaptisassions": "débaptiser",
    "débaptise": "débaptiser",
    "débaptisent": "débaptiser",
    "débaptisera": "débaptiser",
    "débaptiserai": "débaptiser",
    "débaptiseraient": "débaptiser",
    "débaptiserais": "débaptiser",
    "débaptiserait": "débaptiser",
    "débaptiseras": "débaptiser",
    "débaptiserez": "débaptiser",
    "débaptiseriez": "débaptiser",
    "débaptiserions": "débaptiser",
    "débaptiserons": "débaptiser",
    "débaptiseront": "débaptiser",
    "débaptises": "débaptiser",
    "débaptisez": "débaptiser",
    "débaptisiez": "débaptiser",
    "débaptisions": "débaptiser",
    "débaptisons": "débaptiser",
    "débaptisâmes": "débaptiser",
    "débaptisât": "débaptiser",
    "débaptisâtes": "débaptiser",
    "débaptisèrent": "débaptiser",
    "débaptisé": "débaptiser",
    "débaptisée": "débaptiser",
    "débaptisées": "débaptiser",
    "débaptisés": "débaptiser",
    "débarbots": "débarbot",
    "débarbouilla": "débarbouiller",
    "débarbouillai": "débarbouiller",
    "débarbouillaient": "débarbouiller",
    "débarbouillais": "débarbouiller",
    "débarbouillait": "débarbouiller",
    "débarbouillant": "débarbouiller",
    "débarbouillas": "débarbouiller",
    "débarbouillasse": "débarbouiller",
    "débarbouillassent": "débarbouiller",
    "débarbouillasses": "débarbouiller",
    "débarbouillassiez": "débarbouiller",
    "débarbouillassions": "débarbouiller",
    "débarbouille": "débarbouiller",
    "débarbouillent": "débarbouiller",
    "débarbouillera": "débarbouiller",
    "débarbouillerai": "débarbouiller",
    "débarbouilleraient": "débarbouiller",
    "débarbouillerais": "débarbouiller",
    "débarbouillerait": "débarbouiller",
    "débarbouilleras": "débarbouiller",
    "débarbouillerez": "débarbouiller",
    "débarbouilleriez": "débarbouiller",
    "débarbouillerions": "débarbouiller",
    "débarbouillerons": "débarbouiller",
    "débarbouilleront": "débarbouiller",
    "débarbouilles": "débarbouiller",
    "débarbouillez": "débarbouiller",
    "débarbouilliez": "débarbouiller",
    "débarbouillions": "débarbouiller",
    "débarbouillons": "débarbouiller",
    "débarbouillâmes": "débarbouiller",
    "débarbouillât": "débarbouiller",
    "débarbouillâtes": "débarbouiller",
    "débarbouillèrent": "débarbouiller",
    "débarbouillé": "débarbouiller",
    "débarbouillée": "débarbouiller",
    "débarbouillées": "débarbouiller",
    "débarbouillés": "débarbouiller",
    "débarcadères": "débarcadère",
    "débarcardères": "débarcardère",
    "débarda": "débarder",
    "débardages": "débardage",
    "débardai": "débarder",
    "débardaient": "débarder",
    "débardais": "débarder",
    "débardait": "débarder",
    "débardant": "débarder",
    "débardas": "débarder",
    "débardasse": "débarder",
    "débardassent": "débarder",
    "débardasses": "débarder",
    "débardassiez": "débarder",
    "débardassions": "débarder",
    "débarde": "débarder",
    "débardent": "débarder",
    "débardera": "débarder",
    "débarderai": "débarder",
    "débarderaient": "débarder",
    "débarderais": "débarder",
    "débarderait": "débarder",
    "débarderas": "débarder",
    "débarderez": "débarder",
    "débarderiez": "débarder",
    "débarderions": "débarder",
    "débarderons": "débarder",
    "débarderont": "débarder",
    "débardes": "débarder",
    "débardeurs": "débardeur",
    "débardez": "débarder",
    "débardiez": "débarder",
    "débardions": "débarder",
    "débardons": "débarder",
    "débardâmes": "débarder",
    "débardât": "débarder",
    "débardâtes": "débarder",
    "débardèrent": "débarder",
    "débardé": "débarder",
    "débardée": "débarder",
    "débardées": "débarder",
    "débardés": "débarder",
    "débaroule": "débarouler",
    "débaroulent": "débarouler",
    "débarqua": "débarquer",
    "débarquai": "débarquer",
    "débarquaient": "débarquer",
    "débarquais": "débarquer",
    "débarquait": "débarquer",
    "débarquant": "débarquer",
    "débarquas": "débarquer",
    "débarquasse": "débarquer",
    "débarquassent": "débarquer",
    "débarquasses": "débarquer",
    "débarquassiez": "débarquer",
    "débarquassions": "débarquer",
    "débarque": "débarquer",
    "débarquements": "débarquement",
    "débarquent": "débarquer",
    "débarquera": "débarquer",
    "débarquerai": "débarquer",
    "débarqueraient": "débarquer",
    "débarquerais": "débarquer",
    "débarquerait": "débarquer",
    "débarqueras": "débarquer",
    "débarquerez": "débarquer",
    "débarqueriez": "débarquer",
    "débarquerions": "débarquer",
    "débarquerons": "débarquer",
    "débarqueront": "débarquer",
    "débarques": "débarquer",
    "débarquez": "débarquer",
    "débarquiez": "débarquer",
    "débarquions": "débarquer",
    "débarquons": "débarquer",
    "débarquâmes": "débarquer",
    "débarquât": "débarquer",
    "débarquâtes": "débarquer",
    "débarquèrent": "débarquer",
    "débarqué": "débarquer",
    "débarquée": "débarquer",
    "débarquées": "débarquer",
    "débarqués": "débarquer",
    "débarra": "débarrer",
    "débarrai": "débarrer",
    "débarraient": "débarrer",
    "débarrais": "débarrer",
    "débarrait": "débarrer",
    "débarrant": "débarrer",
    "débarras": "débarrer",
    "débarrassa": "débarrasser",
    "débarrassai": "débarrasser",
    "débarrassaient": "débarrasser",
    "débarrassais": "débarrasser",
    "débarrassait": "débarrasser",
    "débarrassant": "débarrasser",
    "débarrassas": "débarrasser",
    "débarrassasse": "débarrasser",
    "débarrassassent": "débarrasser",
    "débarrassasses": "débarrasser",
    "débarrassassiez": "débarrasser",
    "débarrassassions": "débarrasser",
    "débarrasse": "débarrer",
    "débarrassent": "débarrer",
    "débarrassera": "débarrasser",
    "débarrasserai": "débarrasser",
    "débarrasseraient": "débarrasser",
    "débarrasserais": "débarrasser",
    "débarrasserait": "débarrasser",
    "débarrasseras": "débarrasser",
    "débarrasserez": "débarrasser",
    "débarrasseriez": "débarrasser",
    "débarrasserions": "débarrasser",
    "débarrasserons": "débarrasser",
    "débarrasseront": "débarrasser",
    "débarrasses": "débarrer",
    "débarrassez": "débarrasser",
    "débarrassiez": "débarrer",
    "débarrassions": "débarrer",
    "débarrassons": "débarrasser",
    "débarrassâmes": "débarrasser",
    "débarrassât": "débarrasser",
    "débarrassâtes": "débarrasser",
    "débarrassèrent": "débarrasser",
    "débarrassé": "débarrasser",
    "débarrassée": "débarrasser",
    "débarrassées": "débarrasser",
    "débarrassés": "débarrasser",
    "débarre": "débarrer",
    "débarrent": "débarrer",
    "débarrera": "débarrer",
    "débarrerai": "débarrer",
    "débarreraient": "débarrer",
    "débarrerais": "débarrer",
    "débarrerait": "débarrer",
    "débarreras": "débarrer",
    "débarrerez": "débarrer",
    "débarreriez": "débarrer",
    "débarrerions": "débarrer",
    "débarrerons": "débarrer",
    "débarreront": "débarrer",
    "débarres": "débarrer",
    "débarrez": "débarrer",
    "débarriez": "débarrer",
    "débarrions": "débarrer",
    "débarrons": "débarrer",
    "débarrâmes": "débarrer",
    "débarrât": "débarrer",
    "débarrâtes": "débarrer",
    "débarrèrent": "débarrer",
    "débarré": "débarrer",
    "débarrée": "débarrer",
    "débarrées": "débarrer",
    "débarrés": "débarrer",
    "débat": "débattre",
    "débats": "débattre",
    "débattaient": "débattre",
    "débattais": "débattre",
    "débattait": "débattre",
    "débattant": "débattre",
    "débatte": "débattre",
    "débattent": "débattre",
    "débattes": "débattre",
    "débattez": "débattre",
    "débattiez": "débattre",
    "débattions": "débattre",
    "débattirent": "débattre",
    "débattis": "débattre",
    "débattisse": "débattre",
    "débattissent": "débattre",
    "débattisses": "débattre",
    "débattissiez": "débattre",
    "débattissions": "débattre",
    "débattit": "débattre",
    "débattons": "débattre",
    "débattra": "débattre",
    "débattrai": "débattre",
    "débattraient": "débattre",
    "débattrais": "débattre",
    "débattrait": "débattre",
    "débattras": "débattre",
    "débattrez": "débattre",
    "débattriez": "débattre",
    "débattrions": "débattre",
    "débattrons": "débattre",
    "débattront": "débattre",
    "débattu": "débattre",
    "débattue": "débattre",
    "débattues": "débattre",
    "débattus": "débattre",
    "débattîmes": "débattre",
    "débattît": "débattre",
    "débattîtes": "débattre",
    "débaucha": "débaucher",
    "débauchages": "débauchage",
    "débauchai": "débaucher",
    "débauchaient": "débaucher",
    "débauchais": "débaucher",
    "débauchait": "débaucher",
    "débauchant": "débaucher",
    "débauchas": "débaucher",
    "débauchasse": "débaucher",
    "débauchassent": "débaucher",
    "débauchasses": "débaucher",
    "débauchassiez": "débaucher",
    "débauchassions": "débaucher",
    "débauche": "débaucher",
    "débauchent": "débaucher",
    "débauchera": "débaucher",
    "débaucherai": "débaucher",
    "débaucheraient": "débaucher",
    "débaucherais": "débaucher",
    "débaucherait": "débaucher",
    "débaucheras": "débaucher",
    "débaucherez": "débaucher",
    "débaucheriez": "débaucher",
    "débaucherions": "débaucher",
    "débaucherons": "débaucher",
    "débaucheront": "débaucher",
    "débauches": "débaucher",
    "débaucheurs": "débaucheur",
    "débauchez": "débaucher",
    "débauchiez": "débaucher",
    "débauchions": "débaucher",
    "débauchons": "débaucher",
    "débauchâmes": "débaucher",
    "débauchât": "débaucher",
    "débauchâtes": "débaucher",
    "débauchèrent": "débaucher",
    "débauché": "débaucher",
    "débauchée": "débaucher",
    "débauchées": "débaucher",
    "débauchés": "débaucher",
    "débecquetait": "débecqueter",
    "débectait": "débecter",
    "débectant": "débecter",
    "débecte": "débecter",
    "débectent": "débecter",
    "débecterais": "débecter",
    "débectez": "débecter",
    "débecté": "débecter",
    "débectée": "débecter",
    "débectés": "débecter",
    "débets": "débet",
    "débiffé": "débiffer",
    "débiles": "débile",
    "débilitaient": "débiliter",
    "débilitant": "débiliter",
    "débilitante": "débilitant",
    "débilitantes": "débilitant",
    "débilite": "débiliter",
    "débilité": "débiliter",
    "débilitée": "débiliter",
    "débilités": "débiliter",
    "débina": "débiner",
    "débinai": "débiner",
    "débinaient": "débiner",
    "débinais": "débiner",
    "débinait": "débiner",
    "débinant": "débiner",
    "débinas": "débiner",
    "débinasse": "débiner",
    "débinassent": "débiner",
    "débinasses": "débiner",
    "débinassiez": "débiner",
    "débinassions": "débiner",
    "débine": "débiner",
    "débinent": "débiner",
    "débinera": "débiner",
    "débinerai": "débiner",
    "débineraient": "débiner",
    "débinerais": "débiner",
    "débinerait": "débiner",
    "débineras": "débiner",
    "débinerez": "débiner",
    "débineriez": "débiner",
    "débinerions": "débiner",
    "débinerons": "débiner",
    "débineront": "débiner",
    "débines": "débiner",
    "débineurs": "débineur",
    "débineuses": "débineur",
    "débinez": "débiner",
    "débiniez": "débiner",
    "débinions": "débiner",
    "débinons": "débiner",
    "débinâmes": "débiner",
    "débinât": "débiner",
    "débinâtes": "débiner",
    "débinèrent": "débiner",
    "débiné": "débiner",
    "débinée": "débiner",
    "débinées": "débiner",
    "débinés": "débiner",
    "débita": "débiter",
    "débitai": "débiter",
    "débitaient": "débiter",
    "débitais": "débiter",
    "débitait": "débiter",
    "débitant": "débiter",
    "débitants": "débitant",
    "débitas": "débiter",
    "débitasse": "débiter",
    "débitassent": "débiter",
    "débitasses": "débiter",
    "débitassiez": "débiter",
    "débitassions": "débiter",
    "débite": "débiter",
    "débitent": "débiter",
    "débitera": "débiter",
    "débiterai": "débiter",
    "débiteraient": "débiter",
    "débiterais": "débiter",
    "débiterait": "débiter",
    "débiteras": "débiter",
    "débiterez": "débiter",
    "débiteriez": "débiter",
    "débiterions": "débiter",
    "débiterons": "débiter",
    "débiteront": "débiter",
    "débites": "débiter",
    "débiteurs": "débiteur",
    "débiteuse": "débiteur",
    "débiteuses": "débiteur",
    "débitez": "débiter",
    "débitiez": "débiter",
    "débitions": "débiter",
    "débitmètres": "débitmètre",
    "débitons": "débiter",
    "débitrice": "débiteur",
    "débitrices": "débiteur",
    "débits": "débit",
    "débitâmes": "débiter",
    "débitât": "débiter",
    "débitâtes": "débiter",
    "débitèrent": "débiter",
    "débité": "débiter",
    "débitée": "débiter",
    "débitées": "débiter",
    "débités": "débiter",
    "déblaie": "déblayer",
    "déblaiements": "déblaiement",
    "déblaient": "déblayer",
    "déblaiera": "déblayer",
    "déblaierai": "déblayer",
    "déblaieraient": "déblayer",
    "déblaierais": "déblayer",
    "déblaierait": "déblayer",
    "déblaieras": "déblayer",
    "déblaierez": "déblayer",
    "déblaieriez": "déblayer",
    "déblaierions": "déblayer",
    "déblaierons": "déblayer",
    "déblaieront": "déblayer",
    "déblaies": "déblayer",
    "déblais": "déblai",
    "déblatère": "déblatérer",
    "déblatèrent": "déblatérer",
    "déblatères": "déblatérer",
    "déblatéra": "déblatérer",
    "déblatérai": "déblatérer",
    "déblatéraient": "déblatérer",
    "déblatérais": "déblatérer",
    "déblatérait": "déblatérer",
    "déblatérant": "déblatérer",
    "déblatéras": "déblatérer",
    "déblatérasse": "déblatérer",
    "déblatérassent": "déblatérer",
    "déblatérasses": "déblatérer",
    "déblatérassiez": "déblatérer",
    "déblatérassions": "déblatérer",
    "déblatérations": "déblatération",
    "déblatérera": "déblatérer",
    "déblatérerai": "déblatérer",
    "déblatéreraient": "déblatérer",
    "déblatérerais": "déblatérer",
    "déblatérerait": "déblatérer",
    "déblatéreras": "déblatérer",
    "déblatérerez": "déblatérer",
    "déblatéreriez": "déblatérer",
    "déblatérerions": "déblatérer",
    "déblatérerons": "déblatérer",
    "déblatéreront": "déblatérer",
    "déblatérez": "déblatérer",
    "déblatériez": "déblatérer",
    "déblatérions": "déblatérer",
    "déblatérons": "déblatérer",
    "déblatérâmes": "déblatérer",
    "déblatérât": "déblatérer",
    "déblatérâtes": "déblatérer",
    "déblatérèrent": "déblatérer",
    "déblatéré": "déblatérer",
    "déblaya": "déblayer",
    "déblayai": "déblayer",
    "déblayaient": "déblayer",
    "déblayais": "déblayer",
    "déblayait": "déblayer",
    "déblayant": "déblayer",
    "déblayas": "déblayer",
    "déblayasse": "déblayer",
    "déblayassent": "déblayer",
    "déblayasses": "déblayer",
    "déblayassiez": "déblayer",
    "déblayassions": "déblayer",
    "déblaye": "déblayer",
    "déblayent": "déblayer",
    "déblayera": "déblayer",
    "déblayerai": "déblayer",
    "déblayeraient": "déblayer",
    "déblayerais": "déblayer",
    "déblayerait": "déblayer",
    "déblayeras": "déblayer",
    "déblayerez": "déblayer",
    "déblayeriez": "déblayer",
    "déblayerions": "déblayer",
    "déblayerons": "déblayer",
    "déblayeront": "déblayer",
    "déblayes": "déblayer",
    "déblayeurs": "déblayeur",
    "déblayez": "déblayer",
    "déblayiez": "déblayer",
    "déblayions": "déblayer",
    "déblayons": "déblayer",
    "déblayâmes": "déblayer",
    "déblayât": "déblayer",
    "déblayâtes": "déblayer",
    "déblayèrent": "déblayer",
    "déblayé": "déblayer",
    "déblayée": "déblayer",
    "déblayées": "déblayer",
    "déblayés": "déblayer",
    "déblocages": "déblocage",
    "débloqua": "débloquer",
    "débloquai": "débloquer",
    "débloquaient": "débloquer",
    "débloquais": "débloquer",
    "débloquait": "débloquer",
    "débloquant": "débloquer",
    "débloquas": "débloquer",
    "débloquasse": "débloquer",
    "débloquassent": "débloquer",
    "débloquasses": "débloquer",
    "débloquassiez": "débloquer",
    "débloquassions": "débloquer",
    "débloque": "débloquer",
    "débloquent": "débloquer",
    "débloquera": "débloquer",
    "débloquerai": "débloquer",
    "débloqueraient": "débloquer",
    "débloquerais": "débloquer",
    "débloquerait": "débloquer",
    "débloqueras": "débloquer",
    "débloquerez": "débloquer",
    "débloqueriez": "débloquer",
    "débloquerions": "débloquer",
    "débloquerons": "débloquer",
    "débloqueront": "débloquer",
    "débloques": "débloquer",
    "débloquez": "débloquer",
    "débloquiez": "débloquer",
    "débloquions": "débloquer",
    "débloquons": "débloquer",
    "débloquâmes": "débloquer",
    "débloquât": "débloquer",
    "débloquâtes": "débloquer",
    "débloquèrent": "débloquer",
    "débloqué": "débloquer",
    "débloquée": "débloquer",
    "débloquées": "débloquer",
    "débloqués": "débloquer",
    "déboires": "déboire",
    "déboisa": "déboiser",
    "déboisai": "déboiser",
    "déboisaient": "déboiser",
    "déboisais": "déboiser",
    "déboisait": "déboiser",
    "déboisant": "déboiser",
    "déboisas": "déboiser",
    "déboisasse": "déboiser",
    "déboisassent": "déboiser",
    "déboisasses": "déboiser",
    "déboisassiez": "déboiser",
    "déboisassions": "déboiser",
    "déboise": "déboiser",
    "déboisements": "déboisement",
    "déboisent": "déboiser",
    "déboisera": "déboiser",
    "déboiserai": "déboiser",
    "déboiseraient": "déboiser",
    "déboiserais": "déboiser",
    "déboiserait": "déboiser",
    "déboiseras": "déboiser",
    "déboiserez": "déboiser",
    "déboiseriez": "déboiser",
    "déboiserions": "déboiser",
    "déboiserons": "déboiser",
    "déboiseront": "déboiser",
    "déboises": "déboiser",
    "déboisez": "déboiser",
    "déboisiez": "déboiser",
    "déboisions": "déboiser",
    "déboisons": "déboiser",
    "déboisâmes": "déboiser",
    "déboisât": "déboiser",
    "déboisâtes": "déboiser",
    "déboisèrent": "déboiser",
    "déboisé": "déboiser",
    "déboisée": "déboiser",
    "déboisées": "déboiser",
    "déboisés": "déboiser",
    "débonda": "débonder",
    "débondait": "débonder",
    "débondant": "débonder",
    "débondé": "débonder",
    "débonnaires": "débonnaire",
    "déborda": "déborder",
    "débordai": "déborder",
    "débordaient": "déborder",
    "débordais": "déborder",
    "débordait": "déborder",
    "débordant": "déborder",
    "débordante": "débordant",
    "débordantes": "débordant",
    "débordants": "débordant",
    "débordas": "déborder",
    "débordasse": "déborder",
    "débordassent": "déborder",
    "débordasses": "déborder",
    "débordassiez": "déborder",
    "débordassions": "déborder",
    "déborde": "déborder",
    "débordements": "débordement",
    "débordent": "déborder",
    "débordera": "déborder",
    "déborderai": "déborder",
    "déborderaient": "déborder",
    "déborderais": "déborder",
    "déborderait": "déborder",
    "déborderas": "déborder",
    "déborderez": "déborder",
    "déborderiez": "déborder",
    "déborderions": "déborder",
    "déborderons": "déborder",
    "déborderont": "déborder",
    "débordes": "déborder",
    "débordez": "déborder",
    "débordiez": "déborder",
    "débordions": "déborder",
    "débordons": "déborder",
    "débordâmes": "déborder",
    "débordât": "déborder",
    "débordâtes": "déborder",
    "débordèrent": "déborder",
    "débordé": "déborder",
    "débordée": "déborder",
    "débordées": "déborder",
    "débordés": "déborder",
    "débotta": "débotter",
    "débottai": "débotter",
    "débottaient": "débotter",
    "débottais": "débotter",
    "débottait": "débotter",
    "débottant": "débotter",
    "débottas": "débotter",
    "débottasse": "débotter",
    "débottassent": "débotter",
    "débottasses": "débotter",
    "débottassiez": "débotter",
    "débottassions": "débotter",
    "débotte": "débotter",
    "débottelons": "débotteler",
    "débottent": "débotter",
    "débottera": "débotter",
    "débotterai": "débotter",
    "débotteraient": "débotter",
    "débotterais": "débotter",
    "débotterait": "débotter",
    "débotteras": "débotter",
    "débotterez": "débotter",
    "débotteriez": "débotter",
    "débotterions": "débotter",
    "débotterons": "débotter",
    "débotteront": "débotter",
    "débottes": "débotter",
    "débottez": "débotter",
    "débottiez": "débotter",
    "débottions": "débotter",
    "débottons": "débotter",
    "débottâmes": "débotter",
    "débottât": "débotter",
    "débottâtes": "débotter",
    "débottèrent": "débotter",
    "débotté": "débotter",
    "débottée": "débotter",
    "débottées": "débotter",
    "débottés": "débotter",
    "déboucha": "déboucher",
    "débouchai": "déboucher",
    "débouchaient": "déboucher",
    "débouchais": "déboucher",
    "débouchait": "déboucher",
    "débouchant": "déboucher",
    "débouchas": "déboucher",
    "débouchasse": "déboucher",
    "débouchassent": "déboucher",
    "débouchasses": "déboucher",
    "débouchassiez": "déboucher",
    "débouchassions": "déboucher",
    "débouche": "déboucher",
    "débouchent": "déboucher",
    "débouchera": "déboucher",
    "déboucherai": "déboucher",
    "déboucheraient": "déboucher",
    "déboucherais": "déboucher",
    "déboucherait": "déboucher",
    "déboucheras": "déboucher",
    "déboucherez": "déboucher",
    "déboucheriez": "déboucher",
    "déboucherions": "déboucher",
    "déboucherons": "déboucher",
    "déboucheront": "déboucher",
    "débouches": "déboucher",
    "déboucheurs": "déboucheur",
    "débouchez": "déboucher",
    "débouchiez": "déboucher",
    "débouchions": "déboucher",
    "débouchoirs": "débouchoir",
    "débouchons": "déboucher",
    "débouchâmes": "déboucher",
    "débouchât": "déboucher",
    "débouchâtes": "déboucher",
    "débouchèrent": "déboucher",
    "débouché": "déboucher",
    "débouchée": "déboucher",
    "débouchées": "déboucher",
    "débouchés": "déboucher",
    "déboucla": "déboucler",
    "débouclai": "déboucler",
    "débouclaient": "déboucler",
    "débouclais": "déboucler",
    "débouclait": "déboucler",
    "débouclant": "déboucler",
    "débouclas": "déboucler",
    "débouclasse": "déboucler",
    "débouclassent": "déboucler",
    "débouclasses": "déboucler",
    "débouclassiez": "déboucler",
    "débouclassions": "déboucler",
    "déboucle": "déboucler",
    "débouclent": "déboucler",
    "débouclera": "déboucler",
    "débouclerai": "déboucler",
    "déboucleraient": "déboucler",
    "débouclerais": "déboucler",
    "débouclerait": "déboucler",
    "déboucleras": "déboucler",
    "débouclerez": "déboucler",
    "déboucleriez": "déboucler",
    "débouclerions": "déboucler",
    "débouclerons": "déboucler",
    "déboucleront": "déboucler",
    "déboucles": "déboucler",
    "débouclez": "déboucler",
    "déboucliez": "déboucler",
    "débouclions": "déboucler",
    "débouclons": "déboucler",
    "débouclâmes": "déboucler",
    "débouclât": "déboucler",
    "débouclâtes": "déboucler",
    "débouclèrent": "déboucler",
    "débouclé": "déboucler",
    "débouclée": "déboucler",
    "débouclées": "déboucler",
    "débouclés": "déboucler",
    "débouillaient": "débouillir",
    "débouillais": "débouillir",
    "débouillait": "débouillir",
    "débouillant": "débouillir",
    "débouille": "débouillir",
    "débouillent": "débouillir",
    "débouilles": "débouillir",
    "débouillez": "débouillir",
    "débouilli": "débouillir",
    "débouillie": "débouillir",
    "débouillies": "débouillir",
    "débouilliez": "débouillir",
    "débouillions": "débouillir",
    "débouillira": "débouillir",
    "débouillirai": "débouillir",
    "débouilliraient": "débouillir",
    "débouillirais": "débouillir",
    "débouillirait": "débouillir",
    "débouilliras": "débouillir",
    "débouillirent": "débouillir",
    "débouillirez": "débouillir",
    "débouilliriez": "débouillir",
    "débouillirions": "débouillir",
    "débouillirons": "débouillir",
    "débouilliront": "débouillir",
    "débouillis": "débouillir",
    "débouillisse": "débouillir",
    "débouillissent": "débouillir",
    "débouillisses": "débouillir",
    "débouillissiez": "débouillir",
    "débouillissions": "débouillir",
    "débouillit": "débouillir",
    "débouillons": "débouillir",
    "débouillîmes": "débouillir",
    "débouillît": "débouillir",
    "débouillîtes": "débouillir",
    "déboula": "débouler",
    "déboulai": "débouler",
    "déboulaient": "débouler",
    "déboulais": "débouler",
    "déboulait": "débouler",
    "déboulant": "débouler",
    "déboulas": "débouler",
    "déboulasse": "débouler",
    "déboulassent": "débouler",
    "déboulasses": "débouler",
    "déboulassiez": "débouler",
    "déboulassions": "débouler",
    "déboule": "débouler",
    "déboulements": "déboulement",
    "déboulent": "débouler",
    "déboulera": "débouler",
    "déboulerai": "débouler",
    "débouleraient": "débouler",
    "déboulerais": "débouler",
    "déboulerait": "débouler",
    "débouleras": "débouler",
    "déboulerez": "débouler",
    "débouleriez": "débouler",
    "déboulerions": "débouler",
    "déboulerons": "débouler",
    "débouleront": "débouler",
    "déboules": "débouler",
    "déboulez": "débouler",
    "débouliez": "débouler",
    "déboulions": "débouler",
    "déboulonna": "déboulonner",
    "déboulonnages": "déboulonnage",
    "déboulonnai": "déboulonner",
    "déboulonnaient": "déboulonner",
    "déboulonnais": "déboulonner",
    "déboulonnait": "déboulonner",
    "déboulonnant": "déboulonner",
    "déboulonnas": "déboulonner",
    "déboulonnasse": "déboulonner",
    "déboulonnassent": "déboulonner",
    "déboulonnasses": "déboulonner",
    "déboulonnassiez": "déboulonner",
    "déboulonnassions": "déboulonner",
    "déboulonne": "déboulonner",
    "déboulonnent": "déboulonner",
    "déboulonnera": "déboulonner",
    "déboulonnerai": "déboulonner",
    "déboulonneraient": "déboulonner",
    "déboulonnerais": "déboulonner",
    "déboulonnerait": "déboulonner",
    "déboulonneras": "déboulonner",
    "déboulonnerez": "déboulonner",
    "déboulonneriez": "déboulonner",
    "déboulonnerions": "déboulonner",
    "déboulonnerons": "déboulonner",
    "déboulonneront": "déboulonner",
    "déboulonnes": "déboulonner",
    "déboulonnez": "déboulonner",
    "déboulonniez": "déboulonner",
    "déboulonnions": "déboulonner",
    "déboulonnons": "déboulonner",
    "déboulonnâmes": "déboulonner",
    "déboulonnât": "déboulonner",
    "déboulonnâtes": "déboulonner",
    "déboulonnèrent": "déboulonner",
    "déboulonné": "déboulonner",
    "déboulonnée": "déboulonner",
    "déboulonnées": "déboulonner",
    "déboulonnés": "déboulonner",
    "déboulons": "débouler",
    "déboulâmes": "débouler",
    "déboulât": "débouler",
    "déboulâtes": "débouler",
    "déboulèrent": "débouler",
    "déboulé": "débouler",
    "déboulée": "débouler",
    "déboulées": "débouler",
    "déboulés": "débouler",
    "débouquaient": "débouquer",
    "débouqué": "débouquer",
    "débourba": "débourber",
    "débourbai": "débourber",
    "débourbaient": "débourber",
    "débourbais": "débourber",
    "débourbait": "débourber",
    "débourbant": "débourber",
    "débourbas": "débourber",
    "débourbasse": "débourber",
    "débourbassent": "débourber",
    "débourbasses": "débourber",
    "débourbassiez": "débourber",
    "débourbassions": "débourber",
    "débourbe": "débourber",
    "débourbent": "débourber",
    "débourbera": "débourber",
    "débourberai": "débourber",
    "débourberaient": "débourber",
    "débourberais": "débourber",
    "débourberait": "débourber",
    "débourberas": "débourber",
    "débourberez": "débourber",
    "débourberiez": "débourber",
    "débourberions": "débourber",
    "débourberons": "débourber",
    "débourberont": "débourber",
    "débourbes": "débourber",
    "débourbez": "débourber",
    "débourbiez": "débourber",
    "débourbions": "débourber",
    "débourbons": "débourber",
    "débourbâmes": "débourber",
    "débourbât": "débourber",
    "débourbâtes": "débourber",
    "débourbèrent": "débourber",
    "débourbé": "débourber",
    "débourbée": "débourber",
    "débourbées": "débourber",
    "débourbés": "débourber",
    "débourra": "débourrer",
    "débourrai": "débourrer",
    "débourraient": "débourrer",
    "débourrais": "débourrer",
    "débourrait": "débourrer",
    "débourrant": "débourrer",
    "débourras": "débourrer",
    "débourrasse": "débourrer",
    "débourrassent": "débourrer",
    "débourrasses": "débourrer",
    "débourrassiez": "débourrer",
    "débourrassions": "débourrer",
    "débourre": "débourrer",
    "débourrent": "débourrer",
    "débourrera": "débourrer",
    "débourrerai": "débourrer",
    "débourreraient": "débourrer",
    "débourrerais": "débourrer",
    "débourrerait": "débourrer",
    "débourreras": "débourrer",
    "débourrerez": "débourrer",
    "débourreriez": "débourrer",
    "débourrerions": "débourrer",
    "débourrerons": "débourrer",
    "débourreront": "débourrer",
    "débourres": "débourrer",
    "débourrez": "débourrer",
    "débourriez": "débourrer",
    "débourrions": "débourrer",
    "débourrons": "débourrer",
    "débourrâmes": "débourrer",
    "débourrât": "débourrer",
    "débourrâtes": "débourrer",
    "débourrèrent": "débourrer",
    "débourré": "débourrer",
    "débourrée": "débourrer",
    "débourrées": "débourrer",
    "débourrés": "débourrer",
    "déboursa": "débourser",
    "déboursai": "débourser",
    "déboursaient": "débourser",
    "déboursais": "débourser",
    "déboursait": "débourser",
    "déboursant": "débourser",
    "déboursas": "débourser",
    "déboursasse": "débourser",
    "déboursassent": "débourser",
    "déboursasses": "débourser",
    "déboursassiez": "débourser",
    "déboursassions": "débourser",
    "débourse": "débourser",
    "déboursements": "déboursement",
    "déboursent": "débourser",
    "déboursera": "débourser",
    "débourserai": "débourser",
    "débourseraient": "débourser",
    "débourserais": "débourser",
    "débourserait": "débourser",
    "débourseras": "débourser",
    "débourserez": "débourser",
    "débourseriez": "débourser",
    "débourserions": "débourser",
    "débourserons": "débourser",
    "débourseront": "débourser",
    "débourses": "débourser",
    "déboursez": "débourser",
    "déboursiez": "débourser",
    "déboursions": "débourser",
    "déboursons": "débourser",
    "déboursâmes": "débourser",
    "déboursât": "débourser",
    "déboursâtes": "débourser",
    "déboursèrent": "débourser",
    "déboursé": "débourser",
    "déboursée": "débourser",
    "déboursées": "débourser",
    "déboursés": "débourser",
    "débous": "débouillir",
    "déboussola": "déboussoler",
    "déboussolai": "déboussoler",
    "déboussolaient": "déboussoler",
    "déboussolais": "déboussoler",
    "déboussolait": "déboussoler",
    "déboussolant": "déboussoler",
    "déboussolantes": "déboussolant",
    "déboussolas": "déboussoler",
    "déboussolasse": "déboussoler",
    "déboussolassent": "déboussoler",
    "déboussolasses": "déboussoler",
    "déboussolassiez": "déboussoler",
    "déboussolassions": "déboussoler",
    "déboussole": "déboussoler",
    "déboussolent": "déboussoler",
    "déboussolera": "déboussoler",
    "déboussolerai": "déboussoler",
    "déboussoleraient": "déboussoler",
    "déboussolerais": "déboussoler",
    "déboussolerait": "déboussoler",
    "déboussoleras": "déboussoler",
    "déboussolerez": "déboussoler",
    "déboussoleriez": "déboussoler",
    "déboussolerions": "déboussoler",
    "déboussolerons": "déboussoler",
    "déboussoleront": "déboussoler",
    "déboussoles": "déboussoler",
    "déboussolez": "déboussoler",
    "déboussoliez": "déboussoler",
    "déboussolions": "déboussoler",
    "déboussolons": "déboussoler",
    "déboussolâmes": "déboussoler",
    "déboussolât": "déboussoler",
    "déboussolâtes": "déboussoler",
    "déboussolèrent": "déboussoler",
    "déboussolé": "déboussoler",
    "déboussolée": "déboussoler",
    "déboussolées": "déboussoler",
    "déboussolés": "déboussoler",
    "débout": "débouillir",
    "débouta": "débouter",
    "déboutai": "débouter",
    "déboutaient": "débouter",
    "déboutais": "débouter",
    "déboutait": "débouter",
    "déboutant": "débouter",
    "déboutas": "débouter",
    "déboutasse": "débouter",
    "déboutassent": "débouter",
    "déboutasses": "débouter",
    "déboutassiez": "débouter",
    "déboutassions": "débouter",
    "déboute": "débouter",
    "déboutent": "débouter",
    "déboutera": "débouter",
    "débouterai": "débouter",
    "débouteraient": "débouter",
    "débouterais": "débouter",
    "débouterait": "débouter",
    "débouteras": "débouter",
    "débouterez": "débouter",
    "débouteriez": "débouter",
    "débouterions": "débouter",
    "débouterons": "débouter",
    "débouteront": "débouter",
    "déboutes": "débouter",
    "déboutez": "débouter",
    "déboutiez": "débouter",
    "déboutions": "débouter",
    "déboutonna": "déboutonner",
    "déboutonnai": "déboutonner",
    "déboutonnaient": "déboutonner",
    "déboutonnais": "déboutonner",
    "déboutonnait": "déboutonner",
    "déboutonnant": "déboutonner",
    "déboutonnas": "déboutonner",
    "déboutonnasse": "déboutonner",
    "déboutonnassent": "déboutonner",
    "déboutonnasses": "déboutonner",
    "déboutonnassiez": "déboutonner",
    "déboutonnassions": "déboutonner",
    "déboutonne": "déboutonner",
    "déboutonnent": "déboutonner",
    "déboutonnera": "déboutonner",
    "déboutonnerai": "déboutonner",
    "déboutonneraient": "déboutonner",
    "déboutonnerais": "déboutonner",
    "déboutonnerait": "déboutonner",
    "déboutonneras": "déboutonner",
    "déboutonnerez": "déboutonner",
    "déboutonneriez": "déboutonner",
    "déboutonnerions": "déboutonner",
    "déboutonnerons": "déboutonner",
    "déboutonneront": "déboutonner",
    "déboutonnes": "déboutonner",
    "déboutonnez": "déboutonner",
    "déboutonniez": "déboutonner",
    "déboutonnions": "déboutonner",
    "déboutonnons": "déboutonner",
    "déboutonnâmes": "déboutonner",
    "déboutonnât": "déboutonner",
    "déboutonnâtes": "déboutonner",
    "déboutonnèrent": "déboutonner",
    "déboutonné": "déboutonner",
    "déboutonnée": "déboutonner",
    "déboutonnées": "déboutonner",
    "déboutonnés": "déboutonner",
    "déboutons": "débouter",
    "déboutâmes": "débouter",
    "déboutât": "débouter",
    "déboutâtes": "débouter",
    "déboutèrent": "débouter",
    "débouté": "débouter",
    "déboutée": "débouter",
    "déboutées": "débouter",
    "déboutés": "débouter",
    "déboîta": "déboîter",
    "déboîtai": "déboîter",
    "déboîtaient": "déboîter",
    "déboîtais": "déboîter",
    "déboîtait": "déboîter",
    "déboîtant": "déboîter",
    "déboîtas": "déboîter",
    "déboîtasse": "déboîter",
    "déboîtassent": "déboîter",
    "déboîtasses": "déboîter",
    "déboîtassiez": "déboîter",
    "déboîtassions": "déboîter",
    "déboîte": "déboîter",
    "déboîtent": "déboîter",
    "déboîtera": "déboîter",
    "déboîterai": "déboîter",
    "déboîteraient": "déboîter",
    "déboîterais": "déboîter",
    "déboîterait": "déboîter",
    "déboîteras": "déboîter",
    "déboîterez": "déboîter",
    "déboîteriez": "déboîter",
    "déboîterions": "déboîter",
    "déboîterons": "déboîter",
    "déboîteront": "déboîter",
    "déboîtes": "déboîter",
    "déboîtez": "déboîter",
    "déboîtiez": "déboîter",
    "déboîtions": "déboîter",
    "déboîtons": "déboîter",
    "déboîtâmes": "déboîter",
    "déboîtât": "déboîter",
    "déboîtâtes": "déboîter",
    "déboîtèrent": "déboîter",
    "déboîté": "déboîter",
    "déboîtée": "déboîter",
    "déboîtées": "déboîter",
    "déboîtés": "déboîter",
    "débraguette": "débraguetter",
    "débraguettent": "débraguetter",
    "débraguetté": "débraguetter",
    "débraguettés": "débraguetter",
    "débraie": "débrayer",
    "débraient": "débrayer",
    "débraiera": "débrayer",
    "débraierai": "débrayer",
    "débraieraient": "débrayer",
    "débraierais": "débrayer",
    "débraierait": "débrayer",
    "débraieras": "débrayer",
    "débraierez": "débrayer",
    "débraieriez": "débrayer",
    "débraierions": "débrayer",
    "débraierons": "débrayer",
    "débraieront": "débrayer",
    "débraies": "débrayer",
    "débraillé": "débrailler",
    "débraillée": "débrailler",
    "débraillées": "débrailler",
    "débraillés": "débrailler",
    "débrancha": "débrancher",
    "débranchai": "débrancher",
    "débranchaient": "débrancher",
    "débranchais": "débrancher",
    "débranchait": "débrancher",
    "débranchant": "débrancher",
    "débranchas": "débrancher",
    "débranchasse": "débrancher",
    "débranchassent": "débrancher",
    "débranchasses": "débrancher",
    "débranchassiez": "débrancher",
    "débranchassions": "débrancher",
    "débranche": "débrancher",
    "débranchent": "débrancher",
    "débranchera": "débrancher",
    "débrancherai": "débrancher",
    "débrancheraient": "débrancher",
    "débrancherais": "débrancher",
    "débrancherait": "débrancher",
    "débrancheras": "débrancher",
    "débrancherez": "débrancher",
    "débrancheriez": "débrancher",
    "débrancherions": "débrancher",
    "débrancherons": "débrancher",
    "débrancheront": "débrancher",
    "débranches": "débrancher",
    "débranchez": "débrancher",
    "débranchiez": "débrancher",
    "débranchions": "débrancher",
    "débranchons": "débrancher",
    "débranchâmes": "débrancher",
    "débranchât": "débrancher",
    "débranchâtes": "débrancher",
    "débranchèrent": "débrancher",
    "débranché": "débrancher",
    "débranchée": "débrancher",
    "débranchées": "débrancher",
    "débranchés": "débrancher",
    "débraya": "débrayer",
    "débrayages": "débrayage",
    "débrayai": "débrayer",
    "débrayaient": "débrayer",
    "débrayais": "débrayer",
    "débrayait": "débrayer",
    "débrayant": "débrayer",
    "débrayas": "débrayer",
    "débrayasse": "débrayer",
    "débrayassent": "débrayer",
    "débrayasses": "débrayer",
    "débrayassiez": "débrayer",
    "débrayassions": "débrayer",
    "débraye": "débrayer",
    "débrayent": "débrayer",
    "débrayera": "débrayer",
    "débrayerai": "débrayer",
    "débrayeraient": "débrayer",
    "débrayerais": "débrayer",
    "débrayerait": "débrayer",
    "débrayeras": "débrayer",
    "débrayerez": "débrayer",
    "débrayeriez": "débrayer",
    "débrayerions": "débrayer",
    "débrayerons": "débrayer",
    "débrayeront": "débrayer",
    "débrayes": "débrayer",
    "débrayez": "débrayer",
    "débrayiez": "débrayer",
    "débrayions": "débrayer",
    "débrayons": "débrayer",
    "débrayâmes": "débrayer",
    "débrayât": "débrayer",
    "débrayâtes": "débrayer",
    "débrayèrent": "débrayer",
    "débrayé": "débrayer",
    "débrayée": "débrayer",
    "débrayées": "débrayer",
    "débrayés": "débrayer",
    "débrida": "débrider",
    "débridai": "débrider",
    "débridaient": "débrider",
    "débridais": "débrider",
    "débridait": "débrider",
    "débridant": "débrider",
    "débridas": "débrider",
    "débridasse": "débrider",
    "débridassent": "débrider",
    "débridasses": "débrider",
    "débridassiez": "débrider",
    "débridassions": "débrider",
    "débride": "débrider",
    "débrident": "débrider",
    "débridera": "débrider",
    "débriderai": "débrider",
    "débrideraient": "débrider",
    "débriderais": "débrider",
    "débriderait": "débrider",
    "débrideras": "débrider",
    "débriderez": "débrider",
    "débrideriez": "débrider",
    "débriderions": "débrider",
    "débriderons": "débrider",
    "débrideront": "débrider",
    "débrides": "débrider",
    "débridez": "débrider",
    "débridiez": "débrider",
    "débridions": "débrider",
    "débridons": "débrider",
    "débridâmes": "débrider",
    "débridât": "débrider",
    "débridâtes": "débrider",
    "débridèrent": "débrider",
    "débridé": "débrider",
    "débridée": "débrider",
    "débridées": "débrider",
    "débridés": "débrider",
    "débriefé": "débriefer",
    "débriefée": "débriefer",
    "débrouilla": "débrouiller",
    "débrouillai": "débrouiller",
    "débrouillaient": "débrouiller",
    "débrouillais": "débrouiller",
    "débrouillait": "débrouiller",
    "débrouillant": "débrouiller",
    "débrouillarde": "débrouillard",
    "débrouillardes": "débrouillard",
    "débrouillards": "débrouillard",
    "débrouillas": "débrouiller",
    "débrouillasse": "débrouiller",
    "débrouillassent": "débrouiller",
    "débrouillasses": "débrouiller",
    "débrouillassiez": "débrouiller",
    "débrouillassions": "débrouiller",
    "débrouille": "débrouiller",
    "débrouillent": "débrouiller",
    "débrouillera": "débrouiller",
    "débrouillerai": "débrouiller",
    "débrouilleraient": "débrouiller",
    "débrouillerais": "débrouiller",
    "débrouillerait": "débrouiller",
    "débrouilleras": "débrouiller",
    "débrouillerez": "débrouiller",
    "débrouilleriez": "débrouiller",
    "débrouillerions": "débrouiller",
    "débrouillerons": "débrouiller",
    "débrouilleront": "débrouiller",
    "débrouilles": "débrouiller",
    "débrouilleurs": "débrouilleur",
    "débrouillez": "débrouiller",
    "débrouilliez": "débrouiller",
    "débrouillions": "débrouiller",
    "débrouillons": "débrouiller",
    "débrouillâmes": "débrouiller",
    "débrouillât": "débrouiller",
    "débrouillâtes": "débrouiller",
    "débrouillèrent": "débrouiller",
    "débrouillé": "débrouiller",
    "débrouillée": "débrouiller",
    "débrouillées": "débrouiller",
    "débrouillés": "débrouiller",
    "débroussailla": "débroussailler",
    "débroussaillages": "débroussaillage",
    "débroussaillai": "débroussailler",
    "débroussaillaient": "débroussailler",
    "débroussaillais": "débroussailler",
    "débroussaillait": "débroussailler",
    "débroussaillant": "débroussailler",
    "débroussaillas": "débroussailler",
    "débroussaillasse": "débroussailler",
    "débroussaillassent": "débroussailler",
    "débroussaillasses": "débroussailler",
    "débroussaillassiez": "débroussailler",
    "débroussaillassions": "débroussailler",
    "débroussaille": "débroussailler",
    "débroussaillements": "débroussaillement",
    "débroussaillent": "débroussailler",
    "débroussaillera": "débroussailler",
    "débroussaillerai": "débroussailler",
    "débroussailleraient": "débroussailler",
    "débroussaillerais": "débroussailler",
    "débroussaillerait": "débroussailler",
    "débroussailleras": "débroussailler",
    "débroussaillerez": "débroussailler",
    "débroussailleriez": "débroussailler",
    "débroussaillerions": "débroussailler",
    "débroussaillerons": "débroussailler",
    "débroussailleront": "débroussailler",
    "débroussailles": "débroussailler",
    "débroussailleuse": "débroussailleur",
    "débroussaillez": "débroussailler",
    "débroussailliez": "débroussailler",
    "débroussaillions": "débroussailler",
    "débroussaillons": "débroussailler",
    "débroussaillâmes": "débroussailler",
    "débroussaillât": "débroussailler",
    "débroussaillâtes": "débroussailler",
    "débroussaillèrent": "débroussailler",
    "débroussaillé": "débroussailler",
    "débroussaillée": "débroussailler",
    "débroussaillées": "débroussailler",
    "débroussaillés": "débroussailler",
    "débucha": "débucher",
    "débuchai": "débucher",
    "débuchaient": "débucher",
    "débuchais": "débucher",
    "débuchait": "débucher",
    "débuchant": "débucher",
    "débuchas": "débucher",
    "débuchasse": "débucher",
    "débuchassent": "débucher",
    "débuchasses": "débucher",
    "débuchassiez": "débucher",
    "débuchassions": "débucher",
    "débuche": "débucher",
    "débuchent": "débucher",
    "débuchera": "débucher",
    "débucherai": "débucher",
    "débucheraient": "débucher",
    "débucherais": "débucher",
    "débucherait": "débucher",
    "débucheras": "débucher",
    "débucherez": "débucher",
    "débucheriez": "débucher",
    "débucherions": "débucher",
    "débucherons": "débucher",
    "débucheront": "débucher",
    "débuches": "débucher",
    "débuchez": "débucher",
    "débuchiez": "débucher",
    "débuchions": "débucher",
    "débuchons": "débucher",
    "débuchâmes": "débucher",
    "débuchât": "débucher",
    "débuchâtes": "débucher",
    "débuchèrent": "débucher",
    "débuché": "débucher",
    "débuchée": "débucher",
    "débuchées": "débucher",
    "débuchés": "débucher",
    "débusqua": "débusquer",
    "débusquai": "débusquer",
    "débusquaient": "débusquer",
    "débusquais": "débusquer",
    "débusquait": "débusquer",
    "débusquant": "débusquer",
    "débusquas": "débusquer",
    "débusquasse": "débusquer",
    "débusquassent": "débusquer",
    "débusquasses": "débusquer",
    "débusquassiez": "débusquer",
    "débusquassions": "débusquer",
    "débusque": "débusquer",
    "débusquent": "débusquer",
    "débusquera": "débusquer",
    "débusquerai": "débusquer",
    "débusqueraient": "débusquer",
    "débusquerais": "débusquer",
    "débusquerait": "débusquer",
    "débusqueras": "débusquer",
    "débusquerez": "débusquer",
    "débusqueriez": "débusquer",
    "débusquerions": "débusquer",
    "débusquerons": "débusquer",
    "débusqueront": "débusquer",
    "débusques": "débusquer",
    "débusquez": "débusquer",
    "débusquiez": "débusquer",
    "débusquions": "débusquer",
    "débusquons": "débusquer",
    "débusquâmes": "débusquer",
    "débusquât": "débusquer",
    "débusquâtes": "débusquer",
    "débusquèrent": "débusquer",
    "débusqué": "débusquer",
    "débusquée": "débusquer",
    "débusquées": "débusquer",
    "débusqués": "débusquer",
    "débuta": "débuter",
    "débutai": "débuter",
    "débutaient": "débuter",
    "débutais": "débuter",
    "débutait": "débuter",
    "débutant": "débuter",
    "débutante": "débutant",
    "débutantes": "débutant",
    "débutants": "débutant",
    "débutas": "débuter",
    "débutasse": "débuter",
    "débutassent": "débuter",
    "débutasses": "débuter",
    "débutassiez": "débuter",
    "débutassions": "débuter",
    "débute": "débuter",
    "débutent": "débuter",
    "débutera": "débuter",
    "débuterai": "débuter",
    "débuteraient": "débuter",
    "débuterais": "débuter",
    "débuterait": "débuter",
    "débuteras": "débuter",
    "débuterez": "débuter",
    "débuteriez": "débuter",
    "débuterions": "débuter",
    "débuterons": "débuter",
    "débuteront": "débuter",
    "débutes": "débuter",
    "débutez": "débuter",
    "débutiez": "débuter",
    "débutions": "débuter",
    "débutons": "débuter",
    "débuts": "début",
    "débutâmes": "débuter",
    "débutât": "débuter",
    "débutâtes": "débuter",
    "débutèrent": "débuter",
    "débuté": "débuter",
    "débutée": "débuter",
    "débutées": "débuter",
    "débutés": "débuter",
    "débâcles": "débâcle",
    "débâillonné": "débâillonner",
    "débâti": "débâtir",
    "débâtie": "débâtir",
    "débâties": "débâtir",
    "débâtira": "débâtir",
    "débâtirai": "débâtir",
    "débâtiraient": "débâtir",
    "débâtirais": "débâtir",
    "débâtirait": "débâtir",
    "débâtiras": "débâtir",
    "débâtirent": "débâtir",
    "débâtirez": "débâtir",
    "débâtiriez": "débâtir",
    "débâtirions": "débâtir",
    "débâtirons": "débâtir",
    "débâtiront": "débâtir",
    "débâtis": "débâtir",
    "débâtissaient": "débâtir",
    "débâtissais": "débâtir",
    "débâtissait": "débâtir",
    "débâtissant": "débâtir",
    "débâtisse": "débâtir",
    "débâtissent": "débâtir",
    "débâtisses": "débâtir",
    "débâtissez": "débâtir",
    "débâtissiez": "débâtir",
    "débâtissions": "débâtir",
    "débâtissons": "débâtir",
    "débâtit": "débâtir",
    "débâté": "débâter",
    "débâtées": "débâter",
    "débâtîmes": "débâtir",
    "débâtît": "débâtir",
    "débâtîtes": "débâtir",
    "décacheta": "décacheter",
    "décachetai": "décacheter",
    "décachetaient": "décacheter",
    "décachetais": "décacheter",
    "décachetait": "décacheter",
    "décachetant": "décacheter",
    "décachetas": "décacheter",
    "décachetasse": "décacheter",
    "décachetassent": "décacheter",
    "décachetasses": "décacheter",
    "décachetassiez": "décacheter",
    "décachetassions": "décacheter",
    "décachetez": "décacheter",
    "décachetiez": "décacheter",
    "décachetions": "décacheter",
    "décachetons": "décacheter",
    "décachette": "décacheter",
    "décachettent": "décacheter",
    "décachettera": "décacheter",
    "décachetterai": "décacheter",
    "décachetteraient": "décacheter",
    "décachetterais": "décacheter",
    "décachetterait": "décacheter",
    "décachetteras": "décacheter",
    "décachetterez": "décacheter",
    "décachetteriez": "décacheter",
    "décachetterions": "décacheter",
    "décachetterons": "décacheter",
    "décachetteront": "décacheter",
    "décachettes": "décacheter",
    "décachetâmes": "décacheter",
    "décachetât": "décacheter",
    "décachetâtes": "décacheter",
    "décachetèrent": "décacheter",
    "décacheté": "décacheter",
    "décachetée": "décacheter",
    "décachetées": "décacheter",
    "décachetés": "décacheter",
    "décadences": "décadence",
    "décadente": "décadent",
    "décadentes": "décadent",
    "décadents": "décadent",
    "décades": "décade",
    "décadis": "décadi",
    "décadra": "décadrer",
    "décadrai": "décadrer",
    "décadraient": "décadrer",
    "décadrais": "décadrer",
    "décadrait": "décadrer",
    "décadrant": "décadrer",
    "décadras": "décadrer",
    "décadrasse": "décadrer",
    "décadrassent": "décadrer",
    "décadrasses": "décadrer",
    "décadrassiez": "décadrer",
    "décadrassions": "décadrer",
    "décadre": "décadrer",
    "décadrent": "décadrer",
    "décadrera": "décadrer",
    "décadrerai": "décadrer",
    "décadreraient": "décadrer",
    "décadrerais": "décadrer",
    "décadrerait": "décadrer",
    "décadreras": "décadrer",
    "décadrerez": "décadrer",
    "décadreriez": "décadrer",
    "décadrerions": "décadrer",
    "décadrerons": "décadrer",
    "décadreront": "décadrer",
    "décadres": "décadrer",
    "décadrez": "décadrer",
    "décadriez": "décadrer",
    "décadrions": "décadrer",
    "décadrons": "décadrer",
    "décadrâmes": "décadrer",
    "décadrât": "décadrer",
    "décadrâtes": "décadrer",
    "décadrèrent": "décadrer",
    "décadré": "décadrer",
    "décadrée": "décadrer",
    "décadrées": "décadrer",
    "décadrés": "décadrer",
    "décaféiné": "décaféiner",
    "décaféinée": "décaféiner",
    "décaféinées": "décaféiné",
    "décaféinés": "décaféiné",
    "décaissa": "décaisser",
    "décaissai": "décaisser",
    "décaissaient": "décaisser",
    "décaissais": "décaisser",
    "décaissait": "décaisser",
    "décaissant": "décaisser",
    "décaissas": "décaisser",
    "décaissasse": "décaisser",
    "décaissassent": "décaisser",
    "décaissasses": "décaisser",
    "décaissassiez": "décaisser",
    "décaissassions": "décaisser",
    "décaisse": "décaisser",
    "décaissent": "décaisser",
    "décaissera": "décaisser",
    "décaisserai": "décaisser",
    "décaisseraient": "décaisser",
    "décaisserais": "décaisser",
    "décaisserait": "décaisser",
    "décaisseras": "décaisser",
    "décaisserez": "décaisser",
    "décaisseriez": "décaisser",
    "décaisserions": "décaisser",
    "décaisserons": "décaisser",
    "décaisseront": "décaisser",
    "décaisses": "décaisser",
    "décaissez": "décaisser",
    "décaissiez": "décaisser",
    "décaissions": "décaisser",
    "décaissons": "décaisser",
    "décaissâmes": "décaisser",
    "décaissât": "décaisser",
    "décaissâtes": "décaisser",
    "décaissèrent": "décaisser",
    "décaissé": "décaisser",
    "décaissée": "décaisser",
    "décaissées": "décaisser",
    "décaissés": "décaisser",
    "décala": "décaler",
    "décalages": "décalage",
    "décalai": "décaler",
    "décalaient": "décaler",
    "décalais": "décaler",
    "décalait": "décaler",
    "décalamina": "décalaminer",
    "décalaminai": "décalaminer",
    "décalaminaient": "décalaminer",
    "décalaminais": "décalaminer",
    "décalaminait": "décalaminer",
    "décalaminant": "décalaminer",
    "décalaminas": "décalaminer",
    "décalaminasse": "décalaminer",
    "décalaminassent": "décalaminer",
    "décalaminasses": "décalaminer",
    "décalaminassiez": "décalaminer",
    "décalaminassions": "décalaminer",
    "décalamine": "décalaminer",
    "décalaminent": "décalaminer",
    "décalaminera": "décalaminer",
    "décalaminerai": "décalaminer",
    "décalamineraient": "décalaminer",
    "décalaminerais": "décalaminer",
    "décalaminerait": "décalaminer",
    "décalamineras": "décalaminer",
    "décalaminerez": "décalaminer",
    "décalamineriez": "décalaminer",
    "décalaminerions": "décalaminer",
    "décalaminerons": "décalaminer",
    "décalamineront": "décalaminer",
    "décalamines": "décalaminer",
    "décalaminez": "décalaminer",
    "décalaminiez": "décalaminer",
    "décalaminions": "décalaminer",
    "décalaminons": "décalaminer",
    "décalaminâmes": "décalaminer",
    "décalaminât": "décalaminer",
    "décalaminâtes": "décalaminer",
    "décalaminèrent": "décalaminer",
    "décalaminé": "décalaminer",
    "décalaminée": "décalaminer",
    "décalaminées": "décalaminer",
    "décalaminés": "décalaminer",
    "décalant": "décaler",
    "décalas": "décaler",
    "décalasse": "décaler",
    "décalassent": "décaler",
    "décalasses": "décaler",
    "décalassiez": "décaler",
    "décalassions": "décaler",
    "décalcifia": "décalcifier",
    "décalcifiai": "décalcifier",
    "décalcifiaient": "décalcifier",
    "décalcifiais": "décalcifier",
    "décalcifiait": "décalcifier",
    "décalcifiant": "décalcifier",
    "décalcifias": "décalcifier",
    "décalcifiasse": "décalcifier",
    "décalcifiassent": "décalcifier",
    "décalcifiasses": "décalcifier",
    "décalcifiassiez": "décalcifier",
    "décalcifiassions": "décalcifier",
    "décalcifie": "décalcifier",
    "décalcifient": "décalcifier",
    "décalcifiera": "décalcifier",
    "décalcifierai": "décalcifier",
    "décalcifieraient": "décalcifier",
    "décalcifierais": "décalcifier",
    "décalcifierait": "décalcifier",
    "décalcifieras": "décalcifier",
    "décalcifierez": "décalcifier",
    "décalcifieriez": "décalcifier",
    "décalcifierions": "décalcifier",
    "décalcifierons": "décalcifier",
    "décalcifieront": "décalcifier",
    "décalcifies": "décalcifier",
    "décalcifiez": "décalcifier",
    "décalcifiiez": "décalcifier",
    "décalcifiions": "décalcifier",
    "décalcifions": "décalcifier",
    "décalcifiâmes": "décalcifier",
    "décalcifiât": "décalcifier",
    "décalcifiâtes": "décalcifier",
    "décalcifièrent": "décalcifier",
    "décalcifié": "décalcifier",
    "décalcifiée": "décalcifier",
    "décalcifiées": "décalcifier",
    "décalcifiés": "décalcifier",
    "décalcomanies": "décalcomanie",
    "décale": "décaler",
    "décalent": "décaler",
    "décalera": "décaler",
    "décalerai": "décaler",
    "décaleraient": "décaler",
    "décalerais": "décaler",
    "décalerait": "décaler",
    "décaleras": "décaler",
    "décalerez": "décaler",
    "décaleriez": "décaler",
    "décalerions": "décaler",
    "décalerons": "décaler",
    "décaleront": "décaler",
    "décales": "décaler",
    "décalez": "décaler",
    "décaliez": "décaler",
    "décalions": "décaler",
    "décalitres": "décalitre",
    "décalons": "décaler",
    "décalotta": "décalotter",
    "décalottai": "décalotter",
    "décalottaient": "décalotter",
    "décalottais": "décalotter",
    "décalottait": "décalotter",
    "décalottant": "décalotter",
    "décalottas": "décalotter",
    "décalottasse": "décalotter",
    "décalottassent": "décalotter",
    "décalottasses": "décalotter",
    "décalottassiez": "décalotter",
    "décalottassions": "décalotter",
    "décalotte": "décalotter",
    "décalottent": "décalotter",
    "décalottera": "décalotter",
    "décalotterai": "décalotter",
    "décalotteraient": "décalotter",
    "décalotterais": "décalotter",
    "décalotterait": "décalotter",
    "décalotteras": "décalotter",
    "décalotterez": "décalotter",
    "décalotteriez": "décalotter",
    "décalotterions": "décalotter",
    "décalotterons": "décalotter",
    "décalotteront": "décalotter",
    "décalottes": "décalotter",
    "décalottez": "décalotter",
    "décalottiez": "décalotter",
    "décalottions": "décalotter",
    "décalottons": "décalotter",
    "décalottâmes": "décalotter",
    "décalottât": "décalotter",
    "décalottâtes": "décalotter",
    "décalottèrent": "décalotter",
    "décalotté": "décalotter",
    "décalottée": "décalotter",
    "décalottées": "décalotter",
    "décalottés": "décalotter",
    "décalqua": "décalquer",
    "décalquages": "décalquage",
    "décalquai": "décalquer",
    "décalquaient": "décalquer",
    "décalquais": "décalquer",
    "décalquait": "décalquer",
    "décalquant": "décalquer",
    "décalquas": "décalquer",
    "décalquasse": "décalquer",
    "décalquassent": "décalquer",
    "décalquasses": "décalquer",
    "décalquassiez": "décalquer",
    "décalquassions": "décalquer",
    "décalque": "décalquer",
    "décalquent": "décalquer",
    "décalquera": "décalquer",
    "décalquerai": "décalquer",
    "décalqueraient": "décalquer",
    "décalquerais": "décalquer",
    "décalquerait": "décalquer",
    "décalqueras": "décalquer",
    "décalquerez": "décalquer",
    "décalqueriez": "décalquer",
    "décalquerions": "décalquer",
    "décalquerons": "décalquer",
    "décalqueront": "décalquer",
    "décalques": "décalquer",
    "décalquez": "décalquer",
    "décalquiez": "décalquer",
    "décalquions": "décalquer",
    "décalquons": "décalquer",
    "décalquâmes": "décalquer",
    "décalquât": "décalquer",
    "décalquâtes": "décalquer",
    "décalquèrent": "décalquer",
    "décalqué": "décalquer",
    "décalquée": "décalquer",
    "décalquées": "décalquer",
    "décalqués": "décalquer",
    "décalâmes": "décaler",
    "décalât": "décaler",
    "décalâtes": "décaler",
    "décalèrent": "décaler",
    "décalé": "décaler",
    "décalée": "décaler",
    "décalées": "décaler",
    "décalés": "décaler",
    "décampa": "décamper",
    "décampai": "décamper",
    "décampaient": "décamper",
    "décampais": "décamper",
    "décampait": "décamper",
    "décampant": "décamper",
    "décampas": "décamper",
    "décampasse": "décamper",
    "décampassent": "décamper",
    "décampasses": "décamper",
    "décampassiez": "décamper",
    "décampassions": "décamper",
    "décampe": "décamper",
    "décampent": "décamper",
    "décampera": "décamper",
    "décamperai": "décamper",
    "décamperaient": "décamper",
    "décamperais": "décamper",
    "décamperait": "décamper",
    "décamperas": "décamper",
    "décamperez": "décamper",
    "décamperiez": "décamper",
    "décamperions": "décamper",
    "décamperons": "décamper",
    "décamperont": "décamper",
    "décampes": "décamper",
    "décampez": "décamper",
    "décampiez": "décamper",
    "décampions": "décamper",
    "décampons": "décamper",
    "décampâmes": "décamper",
    "décampât": "décamper",
    "décampâtes": "décamper",
    "décampèrent": "décamper",
    "décampé": "décamper",
    "décamètres": "décamètre",
    "décanats": "décanat",
    "décanillant": "décaniller",
    "décanille": "décaniller",
    "décanillerait": "décaniller",
    "décanillez": "décaniller",
    "décans": "décan",
    "décanta": "décanter",
    "décantai": "décanter",
    "décantaient": "décanter",
    "décantais": "décanter",
    "décantait": "décanter",
    "décantant": "décanter",
    "décantas": "décanter",
    "décantasse": "décanter",
    "décantassent": "décanter",
    "décantasses": "décanter",
    "décantassiez": "décanter",
    "décantassions": "décanter",
    "décantations": "décantation",
    "décante": "décanter",
    "décantent": "décanter",
    "décantera": "décanter",
    "décanterai": "décanter",
    "décanteraient": "décanter",
    "décanterais": "décanter",
    "décanterait": "décanter",
    "décanteras": "décanter",
    "décanterez": "décanter",
    "décanteriez": "décanter",
    "décanterions": "décanter",
    "décanterons": "décanter",
    "décanteront": "décanter",
    "décantes": "décanter",
    "décantez": "décanter",
    "décantiez": "décanter",
    "décantions": "décanter",
    "décantons": "décanter",
    "décantâmes": "décanter",
    "décantât": "décanter",
    "décantâtes": "décanter",
    "décantèrent": "décanter",
    "décanté": "décanter",
    "décantée": "décanter",
    "décantées": "décanter",
    "décantés": "décanter",
    "décapa": "décaper",
    "décapages": "décapage",
    "décapai": "décaper",
    "décapaient": "décaper",
    "décapais": "décaper",
    "décapait": "décaper",
    "décapant": "décaper",
    "décapante": "décapant",
    "décapantes": "décapant",
    "décapants": "décapant",
    "décapas": "décaper",
    "décapasse": "décaper",
    "décapassent": "décaper",
    "décapasses": "décaper",
    "décapassiez": "décaper",
    "décapassions": "décaper",
    "décape": "décaper",
    "décapent": "décaper",
    "décapera": "décaper",
    "décaperai": "décaper",
    "décaperaient": "décaper",
    "décaperais": "décaper",
    "décaperait": "décaper",
    "décaperas": "décaper",
    "décaperez": "décaper",
    "décaperiez": "décaper",
    "décaperions": "décaper",
    "décaperons": "décaper",
    "décaperont": "décaper",
    "décapes": "décaper",
    "décapez": "décaper",
    "décapiez": "décaper",
    "décapions": "décaper",
    "décapita": "décapiter",
    "décapitai": "décapiter",
    "décapitaient": "décapiter",
    "décapitais": "décapiter",
    "décapitait": "décapiter",
    "décapitant": "décapiter",
    "décapitas": "décapiter",
    "décapitasse": "décapiter",
    "décapitassent": "décapiter",
    "décapitasses": "décapiter",
    "décapitassiez": "décapiter",
    "décapitassions": "décapiter",
    "décapitations": "décapitation",
    "décapite": "décapiter",
    "décapitent": "décapiter",
    "décapitera": "décapiter",
    "décapiterai": "décapiter",
    "décapiteraient": "décapiter",
    "décapiterais": "décapiter",
    "décapiterait": "décapiter",
    "décapiteras": "décapiter",
    "décapiterez": "décapiter",
    "décapiteriez": "décapiter",
    "décapiterions": "décapiter",
    "décapiterons": "décapiter",
    "décapiteront": "décapiter",
    "décapites": "décapiter",
    "décapitez": "décapiter",
    "décapitiez": "décapiter",
    "décapitions": "décapiter",
    "décapitons": "décapiter",
    "décapitâmes": "décapiter",
    "décapitât": "décapiter",
    "décapitâtes": "décapiter",
    "décapitèrent": "décapiter",
    "décapité": "décapiter",
    "décapitée": "décapiter",
    "décapitées": "décapiter",
    "décapités": "décapiter",
    "décapodes": "décapode",
    "décapons": "décaper",
    "décapota": "décapoter",
    "décapotables": "décapotable",
    "décapotai": "décapoter",
    "décapotaient": "décapoter",
    "décapotais": "décapoter",
    "décapotait": "décapoter",
    "décapotant": "décapoter",
    "décapotas": "décapoter",
    "décapotasse": "décapoter",
    "décapotassent": "décapoter",
    "décapotasses": "décapoter",
    "décapotassiez": "décapoter",
    "décapotassions": "décapoter",
    "décapote": "décapoter",
    "décapotent": "décapoter",
    "décapotera": "décapoter",
    "décapoterai": "décapoter",
    "décapoteraient": "décapoter",
    "décapoterais": "décapoter",
    "décapoterait": "décapoter",
    "décapoteras": "décapoter",
    "décapoterez": "décapoter",
    "décapoteriez": "décapoter",
    "décapoterions": "décapoter",
    "décapoterons": "décapoter",
    "décapoteront": "décapoter",
    "décapotes": "décapoter",
    "décapotez": "décapoter",
    "décapotiez": "décapoter",
    "décapotions": "décapoter",
    "décapotons": "décapoter",
    "décapotâmes": "décapoter",
    "décapotât": "décapoter",
    "décapotâtes": "décapoter",
    "décapotèrent": "décapoter",
    "décapoté": "décapoter",
    "décapotée": "décapoter",
    "décapotées": "décapoter",
    "décapotés": "décapoter",
    "décapsula": "décapsuler",
    "décapsulai": "décapsuler",
    "décapsulaient": "décapsuler",
    "décapsulais": "décapsuler",
    "décapsulait": "décapsuler",
    "décapsulant": "décapsuler",
    "décapsulas": "décapsuler",
    "décapsulasse": "décapsuler",
    "décapsulassent": "décapsuler",
    "décapsulasses": "décapsuler",
    "décapsulassiez": "décapsuler",
    "décapsulassions": "décapsuler",
    "décapsule": "décapsuler",
    "décapsulent": "décapsuler",
    "décapsulera": "décapsuler",
    "décapsulerai": "décapsuler",
    "décapsuleraient": "décapsuler",
    "décapsulerais": "décapsuler",
    "décapsulerait": "décapsuler",
    "décapsuleras": "décapsuler",
    "décapsulerez": "décapsuler",
    "décapsuleriez": "décapsuler",
    "décapsulerions": "décapsuler",
    "décapsulerons": "décapsuler",
    "décapsuleront": "décapsuler",
    "décapsules": "décapsuler",
    "décapsulez": "décapsuler",
    "décapsuliez": "décapsuler",
    "décapsulions": "décapsuler",
    "décapsulons": "décapsuler",
    "décapsulâmes": "décapsuler",
    "décapsulât": "décapsuler",
    "décapsulâtes": "décapsuler",
    "décapsulèrent": "décapsuler",
    "décapsulé": "décapsuler",
    "décapsulée": "décapsuler",
    "décapsulées": "décapsuler",
    "décapsulés": "décapsuler",
    "décapuchonna": "décapuchonner",
    "décapuchonne": "décapuchonner",
    "décapuchonnèrent": "décapuchonner",
    "décapâmes": "décaper",
    "décapât": "décaper",
    "décapâtes": "décaper",
    "décapèrent": "décaper",
    "décapé": "décaper",
    "décapée": "décaper",
    "décapées": "décaper",
    "décapés": "décaper",
    "décarcassais": "décarcasser",
    "décarcassait": "décarcasser",
    "décarcassent": "décarcasser",
    "décarcassé": "décarcasser",
    "décarcassée": "décarcasser",
    "décarcassées": "décarcasser",
    "décarpillé": "décarpiller",
    "décarrades": "décarrade",
    "décarraient": "décarrer",
    "décarrais": "décarrer",
    "décarrait": "décarrer",
    "décarrant": "décarrer",
    "décarre": "décarrer",
    "décarrela": "décarreler",
    "décarrelai": "décarreler",
    "décarrelaient": "décarreler",
    "décarrelais": "décarreler",
    "décarrelait": "décarreler",
    "décarrelant": "décarreler",
    "décarrelas": "décarreler",
    "décarrelasse": "décarreler",
    "décarrelassent": "décarreler",
    "décarrelasses": "décarreler",
    "décarrelassiez": "décarreler",
    "décarrelassions": "décarreler",
    "décarrelez": "décarreler",
    "décarreliez": "décarreler",
    "décarrelions": "décarreler",
    "décarrelle": "décarreler",
    "décarrellent": "décarreler",
    "décarrellera": "décarreler",
    "décarrellerai": "décarreler",
    "décarrelleraient": "décarreler",
    "décarrellerais": "décarreler",
    "décarrellerait": "décarreler",
    "décarrelleras": "décarreler",
    "décarrellerez": "décarreler",
    "décarrelleriez": "décarreler",
    "décarrellerions": "décarreler",
    "décarrellerons": "décarreler",
    "décarrelleront": "décarreler",
    "décarrelles": "décarreler",
    "décarrelons": "décarreler",
    "décarrelâmes": "décarreler",
    "décarrelât": "décarreler",
    "décarrelâtes": "décarreler",
    "décarrelèrent": "décarreler",
    "décarrelé": "décarreler",
    "décarrelée": "décarreler",
    "décarrelées": "décarreler",
    "décarrelés": "décarreler",
    "décarrent": "décarrer",
    "décarrerait": "décarrer",
    "décarres": "décarrer",
    "décarré": "décarrer",
    "décarrés": "décarrer",
    "décasyllabes": "décasyllabe",
    "décathloniens": "décathlonien",
    "décathlons": "décathlon",
    "décati": "décatir",
    "décatie": "décatir",
    "décaties": "décatir",
    "décatira": "décatir",
    "décatirai": "décatir",
    "décatiraient": "décatir",
    "décatirais": "décatir",
    "décatirait": "décatir",
    "décatiras": "décatir",
    "décatirent": "décatir",
    "décatirez": "décatir",
    "décatiriez": "décatir",
    "décatirions": "décatir",
    "décatirons": "décatir",
    "décatiront": "décatir",
    "décatis": "décatir",
    "décatissaient": "décatir",
    "décatissais": "décatir",
    "décatissait": "décatir",
    "décatissant": "décatir",
    "décatisse": "décatir",
    "décatissent": "décatir",
    "décatisses": "décatir",
    "décatissez": "décatir",
    "décatissiez": "décatir",
    "décatissions": "décatir",
    "décatissons": "décatir",
    "décatit": "décatir",
    "décatîmes": "décatir",
    "décatît": "décatir",
    "décatîtes": "décatir",
    "décavée": "décavé",
    "décavées": "décavé",
    "décavés": "décavé",
    "déceint": "déceindre",
    "décela": "déceler",
    "décelables": "décelable",
    "décelai": "déceler",
    "décelaient": "déceler",
    "décelais": "déceler",
    "décelait": "déceler",
    "décelant": "déceler",
    "décelas": "déceler",
    "décelasse": "déceler",
    "décelassent": "déceler",
    "décelasses": "déceler",
    "décelassiez": "déceler",
    "décelassions": "déceler",
    "décelez": "déceler",
    "déceliez": "déceler",
    "décelions": "déceler",
    "décelons": "déceler",
    "décelâmes": "déceler",
    "décelât": "déceler",
    "décelâtes": "déceler",
    "décelèrent": "déceler",
    "décelé": "déceler",
    "décelée": "déceler",
    "décelées": "déceler",
    "décelés": "déceler",
    "décembres": "décembre",
    "décembristes": "décembriste",
    "décemvirs": "décemvir",
    "décences": "décence",
    "décennale": "décennal",
    "décennales": "décennal",
    "décennaux": "décennal",
    "décennies": "décennie",
    "décente": "décent",
    "décentes": "décent",
    "décentra": "décentrer",
    "décentrai": "décentrer",
    "décentraient": "décentrer",
    "décentrais": "décentrer",
    "décentrait": "décentrer",
    "décentralisa": "décentraliser",
    "décentralisai": "décentraliser",
    "décentralisaient": "décentraliser",
    "décentralisais": "décentraliser",
    "décentralisait": "décentraliser",
    "décentralisant": "décentraliser",
    "décentralisas": "décentraliser",
    "décentralisasse": "décentraliser",
    "décentralisassent": "décentraliser",
    "décentralisasses": "décentraliser",
    "décentralisassiez": "décentraliser",
    "décentralisassions": "décentraliser",
    "décentralisations": "décentralisation",
    "décentralise": "décentraliser",
    "décentralisent": "décentraliser",
    "décentralisera": "décentraliser",
    "décentraliserai": "décentraliser",
    "décentraliseraient": "décentraliser",
    "décentraliserais": "décentraliser",
    "décentraliserait": "décentraliser",
    "décentraliseras": "décentraliser",
    "décentraliserez": "décentraliser",
    "décentraliseriez": "décentraliser",
    "décentraliserions": "décentraliser",
    "décentraliserons": "décentraliser",
    "décentraliseront": "décentraliser",
    "décentralises": "décentraliser",
    "décentralisez": "décentraliser",
    "décentralisiez": "décentraliser",
    "décentralisions": "décentraliser",
    "décentralisons": "décentraliser",
    "décentralisâmes": "décentraliser",
    "décentralisât": "décentraliser",
    "décentralisâtes": "décentraliser",
    "décentralisèrent": "décentraliser",
    "décentralisé": "décentraliser",
    "décentralisée": "décentraliser",
    "décentralisées": "décentraliser",
    "décentralisés": "décentraliser",
    "décentrant": "décentrer",
    "décentras": "décentrer",
    "décentrasse": "décentrer",
    "décentrassent": "décentrer",
    "décentrasses": "décentrer",
    "décentrassiez": "décentrer",
    "décentrassions": "décentrer",
    "décentre": "décentrer",
    "décentrent": "décentrer",
    "décentrera": "décentrer",
    "décentrerai": "décentrer",
    "décentreraient": "décentrer",
    "décentrerais": "décentrer",
    "décentrerait": "décentrer",
    "décentreras": "décentrer",
    "décentrerez": "décentrer",
    "décentreriez": "décentrer",
    "décentrerions": "décentrer",
    "décentrerons": "décentrer",
    "décentreront": "décentrer",
    "décentres": "décentrer",
    "décentrez": "décentrer",
    "décentriez": "décentrer",
    "décentrions": "décentrer",
    "décentrons": "décentrer",
    "décentrâmes": "décentrer",
    "décentrât": "décentrer",
    "décentrâtes": "décentrer",
    "décentrèrent": "décentrer",
    "décentré": "décentrer",
    "décentrée": "décentrer",
    "décentrées": "décentrer",
    "décentrés": "décentrer",
    "décents": "décent",
    "déceptions": "déception",
    "décerna": "décerner",
    "décernai": "décerner",
    "décernaient": "décerner",
    "décernais": "décerner",
    "décernait": "décerner",
    "décernant": "décerner",
    "décernas": "décerner",
    "décernasse": "décerner",
    "décernassent": "décerner",
    "décernasses": "décerner",
    "décernassiez": "décerner",
    "décernassions": "décerner",
    "décerne": "décerner",
    "décernent": "décerner",
    "décernera": "décerner",
    "décernerai": "décerner",
    "décerneraient": "décerner",
    "décernerais": "décerner",
    "décernerait": "décerner",
    "décerneras": "décerner",
    "décernerez": "décerner",
    "décerneriez": "décerner",
    "décernerions": "décerner",
    "décernerons": "décerner",
    "décerneront": "décerner",
    "décernes": "décerner",
    "décernez": "décerner",
    "décerniez": "décerner",
    "décernions": "décerner",
    "décernons": "décerner",
    "décernâmes": "décerner",
    "décernât": "décerner",
    "décernâtes": "décerner",
    "décernèrent": "décerner",
    "décerné": "décerner",
    "décernée": "décerner",
    "décernées": "décerner",
    "décernés": "décerner",
    "décervelle": "décerveler",
    "décervelé": "décerveler",
    "décessa": "décesser",
    "décessai": "décesser",
    "décessaient": "décesser",
    "décessais": "décesser",
    "décessait": "décesser",
    "décessant": "décesser",
    "décessas": "décesser",
    "décessasse": "décesser",
    "décessassent": "décesser",
    "décessasses": "décesser",
    "décessassiez": "décesser",
    "décessassions": "décesser",
    "décesse": "décesser",
    "décessent": "décesser",
    "décessera": "décesser",
    "décesserai": "décesser",
    "décesseraient": "décesser",
    "décesserais": "décesser",
    "décesserait": "décesser",
    "décesseras": "décesser",
    "décesserez": "décesser",
    "décesseriez": "décesser",
    "décesserions": "décesser",
    "décesserons": "décesser",
    "décesseront": "décesser",
    "décesses": "décesser",
    "décessez": "décesser",
    "décessiez": "décesser",
    "décessions": "décesser",
    "décessons": "décesser",
    "décessâmes": "décesser",
    "décessât": "décesser",
    "décessâtes": "décesser",
    "décessèrent": "décesser",
    "décessé": "décesser",
    "décessée": "décesser",
    "décessées": "décesser",
    "décessés": "décesser",
    "décevaient": "décevoir",
    "décevais": "décevoir",
    "décevait": "décevoir",
    "décevant": "décevoir",
    "décevante": "décevant",
    "décevantes": "décevant",
    "décevants": "décevant",
    "décevez": "décevoir",
    "déceviez": "décevoir",
    "décevions": "décevoir",
    "décevons": "décevoir",
    "décevra": "décevoir",
    "décevrai": "décevoir",
    "décevraient": "décevoir",
    "décevrais": "décevoir",
    "décevrait": "décevoir",
    "décevras": "décevoir",
    "décevrez": "décevoir",
    "décevriez": "décevoir",
    "décevrions": "décevoir",
    "décevrons": "décevoir",
    "décevront": "décevoir",
    "déchait": "décher",
    "déchanta": "déchanter",
    "déchantai": "déchanter",
    "déchantaient": "déchanter",
    "déchantais": "déchanter",
    "déchantait": "déchanter",
    "déchantant": "déchanter",
    "déchantas": "déchanter",
    "déchantasse": "déchanter",
    "déchantassent": "déchanter",
    "déchantasses": "déchanter",
    "déchantassiez": "déchanter",
    "déchantassions": "déchanter",
    "déchante": "déchanter",
    "déchantent": "déchanter",
    "déchantera": "déchanter",
    "déchanterai": "déchanter",
    "déchanteraient": "déchanter",
    "déchanterais": "déchanter",
    "déchanterait": "déchanter",
    "déchanteras": "déchanter",
    "déchanterez": "déchanter",
    "déchanteriez": "déchanter",
    "déchanterions": "déchanter",
    "déchanterons": "déchanter",
    "déchanteront": "déchanter",
    "déchantes": "déchanter",
    "déchantez": "déchanter",
    "déchantiez": "déchanter",
    "déchantions": "déchanter",
    "déchantons": "déchanter",
    "déchantâmes": "déchanter",
    "déchantât": "déchanter",
    "déchantâtes": "déchanter",
    "déchantèrent": "déchanter",
    "déchanté": "déchanter",
    "déchards": "déchard",
    "décharge": "décharger",
    "déchargea": "décharger",
    "déchargeai": "décharger",
    "déchargeaient": "décharger",
    "déchargeais": "décharger",
    "déchargeait": "décharger",
    "déchargeant": "décharger",
    "déchargeas": "décharger",
    "déchargeasse": "décharger",
    "déchargeassent": "décharger",
    "déchargeasses": "décharger",
    "déchargeassiez": "décharger",
    "déchargeassions": "décharger",
    "déchargements": "déchargement",
    "déchargent": "décharger",
    "déchargeons": "décharger",
    "déchargera": "décharger",
    "déchargerai": "décharger",
    "déchargeraient": "décharger",
    "déchargerais": "décharger",
    "déchargerait": "décharger",
    "déchargeras": "décharger",
    "déchargerez": "décharger",
    "déchargeriez": "décharger",
    "déchargerions": "décharger",
    "déchargerons": "décharger",
    "déchargeront": "décharger",
    "décharges": "décharger",
    "déchargeurs": "déchargeur",
    "déchargez": "décharger",
    "déchargeâmes": "décharger",
    "déchargeât": "décharger",
    "déchargeâtes": "décharger",
    "déchargiez": "décharger",
    "déchargions": "décharger",
    "déchargèrent": "décharger",
    "déchargé": "décharger",
    "déchargée": "décharger",
    "déchargées": "décharger",
    "déchargés": "décharger",
    "décharne": "décharner",
    "décharnent": "décharner",
    "décharnerait": "décharner",
    "décharné": "décharner",
    "décharnée": "décharner",
    "décharnées": "décharner",
    "décharnés": "décharner",
    "déchassé": "déchasser",
    "déchaumaient": "déchaumer",
    "déchaumée": "déchaumer",
    "déchaussa": "déchausser",
    "déchaussai": "déchausser",
    "déchaussaient": "déchausser",
    "déchaussais": "déchausser",
    "déchaussait": "déchausser",
    "déchaussant": "déchausser",
    "déchaussas": "déchausser",
    "déchaussasse": "déchausser",
    "déchaussassent": "déchausser",
    "déchaussasses": "déchausser",
    "déchaussassiez": "déchausser",
    "déchaussassions": "déchausser",
    "déchausse": "déchausser",
    "déchaussent": "déchausser",
    "déchaussera": "déchausser",
    "déchausserai": "déchausser",
    "déchausseraient": "déchausser",
    "déchausserais": "déchausser",
    "déchausserait": "déchausser",
    "déchausseras": "déchausser",
    "déchausserez": "déchausser",
    "déchausseriez": "déchausser",
    "déchausserions": "déchausser",
    "déchausserons": "déchausser",
    "déchausseront": "déchausser",
    "déchausses": "déchausser",
    "déchaussez": "déchausser",
    "déchaussiez": "déchausser",
    "déchaussions": "déchausser",
    "déchaussons": "déchausser",
    "déchaussâmes": "déchausser",
    "déchaussât": "déchausser",
    "déchaussâtes": "déchausser",
    "déchaussèrent": "déchausser",
    "déchaussé": "déchausser",
    "déchaussée": "déchausser",
    "déchaussées": "déchausser",
    "déchaussés": "déchausser",
    "déchaîna": "déchaîner",
    "déchaînai": "déchaîner",
    "déchaînaient": "déchaîner",
    "déchaînais": "déchaîner",
    "déchaînait": "déchaîner",
    "déchaînant": "déchaîner",
    "déchaînas": "déchaîner",
    "déchaînasse": "déchaîner",
    "déchaînassent": "déchaîner",
    "déchaînasses": "déchaîner",
    "déchaînassiez": "déchaîner",
    "déchaînassions": "déchaîner",
    "déchaîne": "déchaîner",
    "déchaînements": "déchaînement",
    "déchaînent": "déchaîner",
    "déchaînera": "déchaîner",
    "déchaînerai": "déchaîner",
    "déchaîneraient": "déchaîner",
    "déchaînerais": "déchaîner",
    "déchaînerait": "déchaîner",
    "déchaîneras": "déchaîner",
    "déchaînerez": "déchaîner",
    "déchaîneriez": "déchaîner",
    "déchaînerions": "déchaîner",
    "déchaînerons": "déchaîner",
    "déchaîneront": "déchaîner",
    "déchaînes": "déchaîner",
    "déchaînez": "déchaîner",
    "déchaîniez": "déchaîner",
    "déchaînions": "déchaîner",
    "déchaînons": "déchaîner",
    "déchaînâmes": "déchaîner",
    "déchaînât": "déchaîner",
    "déchaînâtes": "déchaîner",
    "déchaînèrent": "déchaîner",
    "déchaîné": "déchaîner",
    "déchaînée": "déchaîner",
    "déchaînées": "déchaîner",
    "déchaînés": "déchaîner",
    "décherra": "déchoir",
    "décherrai": "déchoir",
    "décherraient": "déchoir",
    "décherrais": "déchoir",
    "décherrait": "déchoir",
    "décherras": "déchoir",
    "décherrez": "déchoir",
    "décherriez": "déchoir",
    "décherrions": "déchoir",
    "décherrons": "déchoir",
    "décherront": "déchoir",
    "déchet": "déchoir",
    "déchets": "déchet",
    "déchiffra": "déchiffrer",
    "déchiffrables": "déchiffrable",
    "déchiffrai": "déchiffrer",
    "déchiffraient": "déchiffrer",
    "déchiffrais": "déchiffrer",
    "déchiffrait": "déchiffrer",
    "déchiffrant": "déchiffrer",
    "déchiffras": "déchiffrer",
    "déchiffrasse": "déchiffrer",
    "déchiffrassent": "déchiffrer",
    "déchiffrasses": "déchiffrer",
    "déchiffrassiez": "déchiffrer",
    "déchiffrassions": "déchiffrer",
    "déchiffre": "déchiffrer",
    "déchiffrent": "déchiffrer",
    "déchiffrera": "déchiffrer",
    "déchiffrerai": "déchiffrer",
    "déchiffreraient": "déchiffrer",
    "déchiffrerais": "déchiffrer",
    "déchiffrerait": "déchiffrer",
    "déchiffreras": "déchiffrer",
    "déchiffrerez": "déchiffrer",
    "déchiffreriez": "déchiffrer",
    "déchiffrerions": "déchiffrer",
    "déchiffrerons": "déchiffrer",
    "déchiffreront": "déchiffrer",
    "déchiffres": "déchiffrer",
    "déchiffrez": "déchiffrer",
    "déchiffriez": "déchiffrer",
    "déchiffrions": "déchiffrer",
    "déchiffrons": "déchiffrer",
    "déchiffrâmes": "déchiffrer",
    "déchiffrât": "déchiffrer",
    "déchiffrâtes": "déchiffrer",
    "déchiffrèrent": "déchiffrer",
    "déchiffré": "déchiffrer",
    "déchiffrée": "déchiffrer",
    "déchiffrées": "déchiffrer",
    "déchiffrés": "déchiffrer",
    "déchiqueta": "déchiqueter",
    "déchiquetai": "déchiqueter",
    "déchiquetaient": "déchiqueter",
    "déchiquetais": "déchiqueter",
    "déchiquetait": "déchiqueter",
    "déchiquetant": "déchiqueter",
    "déchiquetas": "déchiqueter",
    "déchiquetasse": "déchiqueter",
    "déchiquetassent": "déchiqueter",
    "déchiquetasses": "déchiqueter",
    "déchiquetassiez": "déchiqueter",
    "déchiquetassions": "déchiqueter",
    "déchiqueteurs": "déchiqueteur",
    "déchiqueteuse": "déchiqueteur",
    "déchiqueteuses": "déchiqueteur",
    "déchiquetez": "déchiqueter",
    "déchiquetiez": "déchiqueter",
    "déchiquetions": "déchiqueter",
    "déchiquetons": "déchiqueter",
    "déchiquette": "déchiqueter",
    "déchiquettent": "déchiqueter",
    "déchiquettera": "déchiqueter",
    "déchiquetterai": "déchiqueter",
    "déchiquetteraient": "déchiqueter",
    "déchiquetterais": "déchiqueter",
    "déchiquetterait": "déchiqueter",
    "déchiquetteras": "déchiqueter",
    "déchiquetterez": "déchiqueter",
    "déchiquetteriez": "déchiqueter",
    "déchiquetterions": "déchiqueter",
    "déchiquetterons": "déchiqueter",
    "déchiquetteront": "déchiqueter",
    "déchiquettes": "déchiqueter",
    "déchiquetâmes": "déchiqueter",
    "déchiquetât": "déchiqueter",
    "déchiquetâtes": "déchiqueter",
    "déchiquetèrent": "déchiqueter",
    "déchiqueté": "déchiqueter",
    "déchiquetée": "déchiqueter",
    "déchiquetées": "déchiqueter",
    "déchiquetés": "déchiqueter",
    "déchira": "déchirer",
    "déchirages": "déchirage",
    "déchirai": "déchirer",
    "déchiraient": "déchirer",
    "déchirais": "déchirer",
    "déchirait": "déchirer",
    "déchirant": "déchirer",
    "déchirante": "déchirant",
    "déchirantes": "déchirant",
    "déchirants": "déchirant",
    "déchiras": "déchirer",
    "déchirasse": "déchirer",
    "déchirassent": "déchirer",
    "déchirasses": "déchirer",
    "déchirassiez": "déchirer",
    "déchirassions": "déchirer",
    "déchire": "déchirer",
    "déchirements": "déchirement",
    "déchirent": "déchirer",
    "déchirera": "déchirer",
    "déchirerai": "déchirer",
    "déchireraient": "déchirer",
    "déchirerais": "déchirer",
    "déchirerait": "déchirer",
    "déchireras": "déchirer",
    "déchirerez": "déchirer",
    "déchireriez": "déchirer",
    "déchirerions": "déchirer",
    "déchirerons": "déchirer",
    "déchireront": "déchirer",
    "déchires": "déchirer",
    "déchirez": "déchirer",
    "déchiriez": "déchirer",
    "déchirions": "déchirer",
    "déchirons": "déchirer",
    "déchirures": "déchirure",
    "déchirâmes": "déchirer",
    "déchirât": "déchirer",
    "déchirâtes": "déchirer",
    "déchirèrent": "déchirer",
    "déchiré": "déchirer",
    "déchirée": "déchirer",
    "déchirées": "déchirer",
    "déchirés": "déchirer",
    "déchoie": "déchoir",
    "déchoient": "déchoir",
    "déchoies": "déchoir",
    "déchoira": "déchoir",
    "déchoirai": "déchoir",
    "déchoiraient": "déchoir",
    "déchoirais": "déchoir",
    "déchoirait": "déchoir",
    "déchoiras": "déchoir",
    "déchoirez": "déchoir",
    "déchoiriez": "déchoir",
    "déchoirions": "déchoir",
    "déchoirons": "déchoir",
    "déchoiront": "déchoir",
    "déchois": "déchoir",
    "déchoit": "déchoir",
    "déchoyez": "déchoir",
    "déchoyiez": "déchoir",
    "déchoyions": "déchoir",
    "déchoyons": "déchoir",
    "déchristianisa": "déchristianiser",
    "déchristianisai": "déchristianiser",
    "déchristianisaient": "déchristianiser",
    "déchristianisais": "déchristianiser",
    "déchristianisait": "déchristianiser",
    "déchristianisant": "déchristianiser",
    "déchristianisas": "déchristianiser",
    "déchristianisasse": "déchristianiser",
    "déchristianisassent": "déchristianiser",
    "déchristianisasses": "déchristianiser",
    "déchristianisassiez": "déchristianiser",
    "déchristianisassions": "déchristianiser",
    "déchristianise": "déchristianiser",
    "déchristianisent": "déchristianiser",
    "déchristianisera": "déchristianiser",
    "déchristianiserai": "déchristianiser",
    "déchristianiseraient": "déchristianiser",
    "déchristianiserais": "déchristianiser",
    "déchristianiserait": "déchristianiser",
    "déchristianiseras": "déchristianiser",
    "déchristianiserez": "déchristianiser",
    "déchristianiseriez": "déchristianiser",
    "déchristianiserions": "déchristianiser",
    "déchristianiserons": "déchristianiser",
    "déchristianiseront": "déchristianiser",
    "déchristianises": "déchristianiser",
    "déchristianisez": "déchristianiser",
    "déchristianisiez": "déchristianiser",
    "déchristianisions": "déchristianiser",
    "déchristianisons": "déchristianiser",
    "déchristianisâmes": "déchristianiser",
    "déchristianisât": "déchristianiser",
    "déchristianisâtes": "déchristianiser",
    "déchristianisèrent": "déchristianiser",
    "déchristianisé": "déchristianiser",
    "déchristianisée": "déchristianiser",
    "déchristianisées": "déchristianiser",
    "déchristianisés": "déchristianiser",
    "déchu": "déchoir",
    "déchue": "déchu",
    "déchues": "déchu",
    "déchurent": "déchoir",
    "déchus": "déchu",
    "déchusse": "déchoir",
    "déchussent": "déchoir",
    "déchusses": "déchoir",
    "déchussiez": "déchoir",
    "déchussions": "déchoir",
    "déchut": "déchoir",
    "déché": "décher",
    "déchéances": "déchéance",
    "déchûmes": "déchoir",
    "déchût": "déchoir",
    "déchûtes": "déchoir",
    "décibels": "décibel",
    "décida": "décider",
    "décidai": "décider",
    "décidaient": "décider",
    "décidais": "décider",
    "décidait": "décider",
    "décidant": "décider",
    "décidas": "décider",
    "décidasse": "décider",
    "décidassent": "décider",
    "décidasses": "décider",
    "décidassiez": "décider",
    "décidassions": "décider",
    "décide": "décider",
    "décident": "décider",
    "décidera": "décider",
    "déciderai": "décider",
    "décideraient": "décider",
    "déciderais": "décider",
    "déciderait": "décider",
    "décideras": "décider",
    "déciderez": "décider",
    "décideriez": "décider",
    "déciderions": "décider",
    "déciderons": "décider",
    "décideront": "décider",
    "décides": "décider",
    "décideurs": "décideur",
    "décideuse": "décideur",
    "décideuses": "décideur",
    "décidez": "décider",
    "décidiez": "décider",
    "décidions": "décider",
    "décidons": "décider",
    "décidâmes": "décider",
    "décidât": "décider",
    "décidâtes": "décider",
    "décidèrent": "décider",
    "décidé": "décider",
    "décidée": "décider",
    "décidées": "décider",
    "décidés": "décider",
    "décigrammes": "décigramme",
    "décima": "décimer",
    "décimai": "décimer",
    "décimaient": "décimer",
    "décimais": "décimer",
    "décimait": "décimer",
    "décimale": "décimal",
    "décimales": "décimal",
    "décimant": "décimer",
    "décimas": "décimer",
    "décimasse": "décimer",
    "décimassent": "décimer",
    "décimasses": "décimer",
    "décimassiez": "décimer",
    "décimassions": "décimer",
    "décimaux": "décimal",
    "décime": "décimer",
    "déciment": "décimer",
    "décimera": "décimer",
    "décimerai": "décimer",
    "décimeraient": "décimer",
    "décimerais": "décimer",
    "décimerait": "décimer",
    "décimeras": "décimer",
    "décimerez": "décimer",
    "décimeriez": "décimer",
    "décimerions": "décimer",
    "décimerons": "décimer",
    "décimeront": "décimer",
    "décimes": "décimer",
    "décimez": "décimer",
    "décimiez": "décimer",
    "décimions": "décimer",
    "décimons": "décimer",
    "décimâmes": "décimer",
    "décimât": "décimer",
    "décimâtes": "décimer",
    "décimèrent": "décimer",
    "décimètres": "décimètre",
    "décimé": "décimer",
    "décimée": "décimer",
    "décimées": "décimer",
    "décimés": "décimer",
    "décisifs": "décisif",
    "décisionnelle": "décisionnel",
    "décisionnelles": "décisionnel",
    "décisionnels": "décisionnel",
    "décisions": "décision",
    "décisive": "décisif",
    "décisives": "décisif",
    "décivilisés": "déciviliser",
    "déclama": "déclamer",
    "déclamai": "déclamer",
    "déclamaient": "déclamer",
    "déclamais": "déclamer",
    "déclamait": "déclamer",
    "déclamant": "déclamer",
    "déclamas": "déclamer",
    "déclamasse": "déclamer",
    "déclamassent": "déclamer",
    "déclamasses": "déclamer",
    "déclamassiez": "déclamer",
    "déclamassions": "déclamer",
    "déclamations": "déclamation",
    "déclamatoires": "déclamatoire",
    "déclamatrice": "déclamateur",
    "déclame": "déclamer",
    "déclament": "déclamer",
    "déclamera": "déclamer",
    "déclamerai": "déclamer",
    "déclameraient": "déclamer",
    "déclamerais": "déclamer",
    "déclamerait": "déclamer",
    "déclameras": "déclamer",
    "déclamerez": "déclamer",
    "déclameriez": "déclamer",
    "déclamerions": "déclamer",
    "déclamerons": "déclamer",
    "déclameront": "déclamer",
    "déclames": "déclamer",
    "déclamez": "déclamer",
    "déclamiez": "déclamer",
    "déclamions": "déclamer",
    "déclamons": "déclamer",
    "déclamâmes": "déclamer",
    "déclamât": "déclamer",
    "déclamâtes": "déclamer",
    "déclamèrent": "déclamer",
    "déclamé": "déclamer",
    "déclamée": "déclamer",
    "déclamées": "déclamer",
    "déclamés": "déclamer",
    "déclanche": "déclancher",
    "déclanchera": "déclancher",
    "déclanché": "déclancher",
    "déclara": "déclarer",
    "déclarai": "déclarer",
    "déclaraient": "déclarer",
    "déclarais": "déclarer",
    "déclarait": "déclarer",
    "déclarant": "déclarer",
    "déclaras": "déclarer",
    "déclarasse": "déclarer",
    "déclarassent": "déclarer",
    "déclarasses": "déclarer",
    "déclarassiez": "déclarer",
    "déclarassions": "déclarer",
    "déclarations": "déclaration",
    "déclarative": "déclaratif",
    "déclaratoires": "déclaratoire",
    "déclare": "déclarer",
    "déclarent": "déclarer",
    "déclarera": "déclarer",
    "déclarerai": "déclarer",
    "déclareraient": "déclarer",
    "déclarerais": "déclarer",
    "déclarerait": "déclarer",
    "déclareras": "déclarer",
    "déclarerez": "déclarer",
    "déclareriez": "déclarer",
    "déclarerions": "déclarer",
    "déclarerons": "déclarer",
    "déclareront": "déclarer",
    "déclares": "déclarer",
    "déclarez": "déclarer",
    "déclariez": "déclarer",
    "déclarions": "déclarer",
    "déclarons": "déclarer",
    "déclarâmes": "déclarer",
    "déclarât": "déclarer",
    "déclarâtes": "déclarer",
    "déclarèrent": "déclarer",
    "déclaré": "déclarer",
    "déclarée": "déclarer",
    "déclarées": "déclarer",
    "déclarés": "déclarer",
    "déclassa": "déclasser",
    "déclassai": "déclasser",
    "déclassaient": "déclasser",
    "déclassais": "déclasser",
    "déclassait": "déclasser",
    "déclassant": "déclasser",
    "déclassas": "déclasser",
    "déclassasse": "déclasser",
    "déclassassent": "déclasser",
    "déclassasses": "déclasser",
    "déclassassiez": "déclasser",
    "déclassassions": "déclasser",
    "déclasse": "déclasser",
    "déclassements": "déclassement",
    "déclassent": "déclasser",
    "déclassera": "déclasser",
    "déclasserai": "déclasser",
    "déclasseraient": "déclasser",
    "déclasserais": "déclasser",
    "déclasserait": "déclasser",
    "déclasseras": "déclasser",
    "déclasserez": "déclasser",
    "déclasseriez": "déclasser",
    "déclasserions": "déclasser",
    "déclasserons": "déclasser",
    "déclasseront": "déclasser",
    "déclasses": "déclasser",
    "déclassez": "déclasser",
    "déclassiez": "déclasser",
    "déclassions": "déclasser",
    "déclassons": "déclasser",
    "déclassâmes": "déclasser",
    "déclassât": "déclasser",
    "déclassâtes": "déclasser",
    "déclassèrent": "déclasser",
    "déclassé": "déclasser",
    "déclassée": "déclasser",
    "déclassées": "déclasser",
    "déclassés": "déclasser",
    "déclavetées": "déclaveter",
    "déclencha": "déclencher",
    "déclenchai": "déclencher",
    "déclenchaient": "déclencher",
    "déclenchais": "déclencher",
    "déclenchait": "déclencher",
    "déclenchant": "déclencher",
    "déclenchas": "déclencher",
    "déclenchasse": "déclencher",
    "déclenchassent": "déclencher",
    "déclenchasses": "déclencher",
    "déclenchassiez": "déclencher",
    "déclenchassions": "déclencher",
    "déclenche": "déclencher",
    "déclenchements": "déclenchement",
    "déclenchent": "déclencher",
    "déclenchera": "déclencher",
    "déclencherai": "déclencher",
    "déclencheraient": "déclencher",
    "déclencherais": "déclencher",
    "déclencherait": "déclencher",
    "déclencheras": "déclencher",
    "déclencherez": "déclencher",
    "déclencheriez": "déclencher",
    "déclencherions": "déclencher",
    "déclencherons": "déclencher",
    "déclencheront": "déclencher",
    "déclenches": "déclencher",
    "déclencheurs": "déclencheur",
    "déclenchez": "déclencher",
    "déclenchiez": "déclencher",
    "déclenchions": "déclencher",
    "déclenchons": "déclencher",
    "déclenchâmes": "déclencher",
    "déclenchât": "déclencher",
    "déclenchâtes": "déclencher",
    "déclenchèrent": "déclencher",
    "déclenché": "déclencher",
    "déclenchée": "déclencher",
    "déclenchées": "déclencher",
    "déclenchés": "déclencher",
    "déclics": "déclic",
    "déclina": "décliner",
    "déclinai": "décliner",
    "déclinaient": "décliner",
    "déclinais": "décliner",
    "déclinaisons": "déclinaison",
    "déclinait": "décliner",
    "déclinant": "décliner",
    "déclinante": "déclinant",
    "déclinantes": "déclinant",
    "déclinants": "déclinant",
    "déclinas": "décliner",
    "déclinasse": "décliner",
    "déclinassent": "décliner",
    "déclinasses": "décliner",
    "déclinassiez": "décliner",
    "déclinassions": "décliner",
    "décline": "décliner",
    "déclinent": "décliner",
    "déclinera": "décliner",
    "déclinerai": "décliner",
    "déclineraient": "décliner",
    "déclinerais": "décliner",
    "déclinerait": "décliner",
    "déclineras": "décliner",
    "déclinerez": "décliner",
    "déclineriez": "décliner",
    "déclinerions": "décliner",
    "déclinerons": "décliner",
    "déclineront": "décliner",
    "déclines": "décliner",
    "déclinez": "décliner",
    "décliniez": "décliner",
    "déclinions": "décliner",
    "déclinons": "décliner",
    "déclins": "déclin",
    "déclinâmes": "décliner",
    "déclinât": "décliner",
    "déclinâtes": "décliner",
    "déclinèrent": "décliner",
    "décliné": "décliner",
    "déclinée": "décliner",
    "déclinées": "décliner",
    "déclinés": "décliner",
    "déclique": "décliquer",
    "décliqueté": "décliqueter",
    "déclives": "déclive",
    "déclivités": "déclivité",
    "décloisonna": "décloisonner",
    "décloisonnai": "décloisonner",
    "décloisonnaient": "décloisonner",
    "décloisonnais": "décloisonner",
    "décloisonnait": "décloisonner",
    "décloisonnant": "décloisonner",
    "décloisonnas": "décloisonner",
    "décloisonnasse": "décloisonner",
    "décloisonnassent": "décloisonner",
    "décloisonnasses": "décloisonner",
    "décloisonnassiez": "décloisonner",
    "décloisonnassions": "décloisonner",
    "décloisonne": "décloisonner",
    "décloisonnements": "décloisonnement",
    "décloisonnent": "décloisonner",
    "décloisonnera": "décloisonner",
    "décloisonnerai": "décloisonner",
    "décloisonneraient": "décloisonner",
    "décloisonnerais": "décloisonner",
    "décloisonnerait": "décloisonner",
    "décloisonneras": "décloisonner",
    "décloisonnerez": "décloisonner",
    "décloisonneriez": "décloisonner",
    "décloisonnerions": "décloisonner",
    "décloisonnerons": "décloisonner",
    "décloisonneront": "décloisonner",
    "décloisonnes": "décloisonner",
    "décloisonnez": "décloisonner",
    "décloisonniez": "décloisonner",
    "décloisonnions": "décloisonner",
    "décloisonnons": "décloisonner",
    "décloisonnâmes": "décloisonner",
    "décloisonnât": "décloisonner",
    "décloisonnâtes": "décloisonner",
    "décloisonnèrent": "décloisonner",
    "décloisonné": "décloisonner",
    "décloisonnée": "décloisonner",
    "décloisonnées": "décloisonner",
    "décloisonnés": "décloisonner",
    "déclora": "déclore",
    "déclorai": "déclore",
    "décloraient": "déclore",
    "déclorais": "déclore",
    "déclorait": "déclore",
    "décloras": "déclore",
    "déclorez": "déclore",
    "décloriez": "déclore",
    "déclorions": "déclore",
    "déclorons": "déclore",
    "décloront": "déclore",
    "déclos": "déclore",
    "déclosant": "déclore",
    "déclose": "déclos",
    "déclosent": "déclore",
    "décloses": "déclos",
    "déclosiez": "déclore",
    "déclosions": "déclore",
    "déclot": "déclore",
    "décloua": "déclouer",
    "déclouai": "déclouer",
    "déclouaient": "déclouer",
    "déclouais": "déclouer",
    "déclouait": "déclouer",
    "déclouant": "déclouer",
    "déclouas": "déclouer",
    "déclouasse": "déclouer",
    "déclouassent": "déclouer",
    "déclouasses": "déclouer",
    "déclouassiez": "déclouer",
    "déclouassions": "déclouer",
    "décloue": "déclouer",
    "déclouent": "déclouer",
    "déclouera": "déclouer",
    "déclouerai": "déclouer",
    "décloueraient": "déclouer",
    "déclouerais": "déclouer",
    "déclouerait": "déclouer",
    "décloueras": "déclouer",
    "déclouerez": "déclouer",
    "décloueriez": "déclouer",
    "déclouerions": "déclouer",
    "déclouerons": "déclouer",
    "décloueront": "déclouer",
    "décloues": "déclouer",
    "déclouez": "déclouer",
    "déclouiez": "déclouer",
    "déclouions": "déclouer",
    "déclouons": "déclouer",
    "déclouâmes": "déclouer",
    "déclouât": "déclouer",
    "déclouâtes": "déclouer",
    "déclouèrent": "déclouer",
    "décloué": "déclouer",
    "déclouée": "déclouer",
    "déclouées": "déclouer",
    "décloués": "déclouer",
    "décocha": "décocher",
    "décochai": "décocher",
    "décochaient": "décocher",
    "décochais": "décocher",
    "décochait": "décocher",
    "décochant": "décocher",
    "décochas": "décocher",
    "décochasse": "décocher",
    "décochassent": "décocher",
    "décochasses": "décocher",
    "décochassiez": "décocher",
    "décochassions": "décocher",
    "décoche": "décocher",
    "décochent": "décocher",
    "décochera": "décocher",
    "décocherai": "décocher",
    "décocheraient": "décocher",
    "décocherais": "décocher",
    "décocherait": "décocher",
    "décocheras": "décocher",
    "décocherez": "décocher",
    "décocheriez": "décocher",
    "décocherions": "décocher",
    "décocherons": "décocher",
    "décocheront": "décocher",
    "décoches": "décocher",
    "décocheuses": "décocheur",
    "décochez": "décocher",
    "décochiez": "décocher",
    "décochions": "décocher",
    "décochons": "décocher",
    "décochâmes": "décocher",
    "décochât": "décocher",
    "décochâtes": "décocher",
    "décochèrent": "décocher",
    "décoché": "décocher",
    "décochée": "décocher",
    "décochées": "décocher",
    "décochés": "décocher",
    "décoconne": "décoconner",
    "décoconnerai": "décoconner",
    "décoctions": "décoction",
    "décoda": "décoder",
    "décodages": "décodage",
    "décodai": "décoder",
    "décodaient": "décoder",
    "décodais": "décoder",
    "décodait": "décoder",
    "décodant": "décoder",
    "décodas": "décoder",
    "décodasse": "décoder",
    "décodassent": "décoder",
    "décodasses": "décoder",
    "décodassiez": "décoder",
    "décodassions": "décoder",
    "décode": "décoder",
    "décodent": "décoder",
    "décodera": "décoder",
    "décoderai": "décoder",
    "décoderaient": "décoder",
    "décoderais": "décoder",
    "décoderait": "décoder",
    "décoderas": "décoder",
    "décoderez": "décoder",
    "décoderiez": "décoder",
    "décoderions": "décoder",
    "décoderons": "décoder",
    "décoderont": "décoder",
    "décodes": "décoder",
    "décodeurs": "décodeur",
    "décodeuse": "décodeur",
    "décodez": "décoder",
    "décodiez": "décoder",
    "décodions": "décoder",
    "décodons": "décoder",
    "décodâmes": "décoder",
    "décodât": "décoder",
    "décodâtes": "décoder",
    "décodèrent": "décoder",
    "décodé": "décoder",
    "décodée": "décoder",
    "décodées": "décoder",
    "décodés": "décoder",
    "décoffrés": "décoffrer",
    "décoiffa": "décoiffer",
    "décoiffai": "décoiffer",
    "décoiffaient": "décoiffer",
    "décoiffais": "décoiffer",
    "décoiffait": "décoiffer",
    "décoiffant": "décoiffer",
    "décoiffas": "décoiffer",
    "décoiffasse": "décoiffer",
    "décoiffassent": "décoiffer",
    "décoiffasses": "décoiffer",
    "décoiffassiez": "décoiffer",
    "décoiffassions": "décoiffer",
    "décoiffe": "décoiffer",
    "décoiffent": "décoiffer",
    "décoiffera": "décoiffer",
    "décoifferai": "décoiffer",
    "décoifferaient": "décoiffer",
    "décoifferais": "décoiffer",
    "décoifferait": "décoiffer",
    "décoifferas": "décoiffer",
    "décoifferez": "décoiffer",
    "décoifferiez": "décoiffer",
    "décoifferions": "décoiffer",
    "décoifferons": "décoiffer",
    "décoifferont": "décoiffer",
    "décoiffes": "décoiffer",
    "décoiffez": "décoiffer",
    "décoiffiez": "décoiffer",
    "décoiffions": "décoiffer",
    "décoiffons": "décoiffer",
    "décoiffâmes": "décoiffer",
    "décoiffât": "décoiffer",
    "décoiffâtes": "décoiffer",
    "décoiffèrent": "décoiffer",
    "décoiffé": "décoiffer",
    "décoiffée": "décoiffer",
    "décoiffées": "décoiffer",
    "décoiffés": "décoiffer",
    "décoince": "décoincer",
    "décoincent": "décoincer",
    "décoincera": "décoincer",
    "décoincerai": "décoincer",
    "décoinceraient": "décoincer",
    "décoincerais": "décoincer",
    "décoincerait": "décoincer",
    "décoinceras": "décoincer",
    "décoincerez": "décoincer",
    "décoinceriez": "décoincer",
    "décoincerions": "décoincer",
    "décoincerons": "décoincer",
    "décoinceront": "décoincer",
    "décoinces": "décoincer",
    "décoincez": "décoincer",
    "décoinciez": "décoincer",
    "décoincions": "décoincer",
    "décoincèrent": "décoincer",
    "décoincé": "décoincer",
    "décoincée": "décoincer",
    "décoincées": "décoincer",
    "décoincés": "décoincer",
    "décoinça": "décoincer",
    "décoinçai": "décoincer",
    "décoinçaient": "décoincer",
    "décoinçais": "décoincer",
    "décoinçait": "décoincer",
    "décoinçant": "décoincer",
    "décoinças": "décoincer",
    "décoinçasse": "décoincer",
    "décoinçassent": "décoincer",
    "décoinçasses": "décoincer",
    "décoinçassiez": "décoincer",
    "décoinçassions": "décoincer",
    "décoinçons": "décoincer",
    "décoinçâmes": "décoincer",
    "décoinçât": "décoincer",
    "décoinçâtes": "décoincer",
    "décolla": "décoller",
    "décollages": "décollage",
    "décollai": "décoller",
    "décollaient": "décoller",
    "décollais": "décoller",
    "décollait": "décoller",
    "décollant": "décoller",
    "décollas": "décoller",
    "décollasse": "décoller",
    "décollassent": "décoller",
    "décollasses": "décoller",
    "décollassiez": "décoller",
    "décollassions": "décoller",
    "décollations": "décollation",
    "décolle": "décoller",
    "décollements": "décollement",
    "décollent": "décoller",
    "décollera": "décoller",
    "décollerai": "décoller",
    "décolleraient": "décoller",
    "décollerais": "décoller",
    "décollerait": "décoller",
    "décolleras": "décoller",
    "décollerez": "décoller",
    "décolleriez": "décoller",
    "décollerions": "décoller",
    "décollerons": "décoller",
    "décolleront": "décoller",
    "décolles": "décoller",
    "décolleta": "décolleter",
    "décolletai": "décolleter",
    "décolletaient": "décolleter",
    "décolletais": "décolleter",
    "décolletait": "décolleter",
    "décolletant": "décolleter",
    "décolletas": "décolleter",
    "décolletasse": "décolleter",
    "décolletassent": "décolleter",
    "décolletasses": "décolleter",
    "décolletassiez": "décolleter",
    "décolletassions": "décolleter",
    "décolletez": "décolleter",
    "décolletiez": "décolleter",
    "décolletions": "décolleter",
    "décolletons": "décolleter",
    "décollette": "décolleter",
    "décollettent": "décolleter",
    "décollettera": "décolleter",
    "décolletterai": "décolleter",
    "décolletteraient": "décolleter",
    "décolletterais": "décolleter",
    "décolletterait": "décolleter",
    "décolletteras": "décolleter",
    "décolletterez": "décolleter",
    "décolletteriez": "décolleter",
    "décolletterions": "décolleter",
    "décolletterons": "décolleter",
    "décolletteront": "décolleter",
    "décollettes": "décolleter",
    "décolletâmes": "décolleter",
    "décolletât": "décolleter",
    "décolletâtes": "décolleter",
    "décolletèrent": "décolleter",
    "décolleté": "décolleter",
    "décolletée": "décolleter",
    "décolletées": "décolleter",
    "décolletés": "décolleter",
    "décollez": "décoller",
    "décolliez": "décoller",
    "décollions": "décoller",
    "décollons": "décoller",
    "décollâmes": "décoller",
    "décollât": "décoller",
    "décollâtes": "décoller",
    "décollèrent": "décoller",
    "décollé": "décoller",
    "décollée": "décoller",
    "décollées": "décoller",
    "décollés": "décoller",
    "décolonisa": "décoloniser",
    "décolonisai": "décoloniser",
    "décolonisaient": "décoloniser",
    "décolonisais": "décoloniser",
    "décolonisait": "décoloniser",
    "décolonisant": "décoloniser",
    "décolonisas": "décoloniser",
    "décolonisasse": "décoloniser",
    "décolonisassent": "décoloniser",
    "décolonisasses": "décoloniser",
    "décolonisassiez": "décoloniser",
    "décolonisassions": "décoloniser",
    "décolonisations": "décolonisation",
    "décolonise": "décoloniser",
    "décolonisent": "décoloniser",
    "décolonisera": "décoloniser",
    "décoloniserai": "décoloniser",
    "décoloniseraient": "décoloniser",
    "décoloniserais": "décoloniser",
    "décoloniserait": "décoloniser",
    "décoloniseras": "décoloniser",
    "décoloniserez": "décoloniser",
    "décoloniseriez": "décoloniser",
    "décoloniserions": "décoloniser",
    "décoloniserons": "décoloniser",
    "décoloniseront": "décoloniser",
    "décolonises": "décoloniser",
    "décolonisez": "décoloniser",
    "décolonisiez": "décoloniser",
    "décolonisions": "décoloniser",
    "décolonisons": "décoloniser",
    "décolonisâmes": "décoloniser",
    "décolonisât": "décoloniser",
    "décolonisâtes": "décoloniser",
    "décolonisèrent": "décoloniser",
    "décolonisé": "décoloniser",
    "décolonisée": "décoloniser",
    "décolonisées": "décoloniser",
    "décolonisés": "décoloniser",
    "décolora": "décolorer",
    "décolorai": "décolorer",
    "décoloraient": "décolorer",
    "décolorais": "décolorer",
    "décolorait": "décolorer",
    "décolorant": "décolorer",
    "décoloras": "décolorer",
    "décolorasse": "décolorer",
    "décolorassent": "décolorer",
    "décolorasses": "décolorer",
    "décolorassiez": "décolorer",
    "décolorassions": "décolorer",
    "décolorations": "décoloration",
    "décolore": "décolorer",
    "décolorent": "décolorer",
    "décolorera": "décolorer",
    "décolorerai": "décolorer",
    "décoloreraient": "décolorer",
    "décolorerais": "décolorer",
    "décolorerait": "décolorer",
    "décoloreras": "décolorer",
    "décolorerez": "décolorer",
    "décoloreriez": "décolorer",
    "décolorerions": "décolorer",
    "décolorerons": "décolorer",
    "décoloreront": "décolorer",
    "décolores": "décolorer",
    "décolorez": "décolorer",
    "décoloriez": "décolorer",
    "décolorions": "décolorer",
    "décolorons": "décolorer",
    "décolorâmes": "décolorer",
    "décolorât": "décolorer",
    "décolorâtes": "décolorer",
    "décolorèrent": "décolorer",
    "décoloré": "décolorer",
    "décolorée": "décolorer",
    "décolorées": "décolorer",
    "décolorés": "décolorer",
    "décolère": "décolérer",
    "décolèrent": "décolérer",
    "décolères": "décolérer",
    "décoléra": "décolérer",
    "décolérai": "décolérer",
    "décoléraient": "décolérer",
    "décolérais": "décolérer",
    "décolérait": "décolérer",
    "décolérant": "décolérer",
    "décoléras": "décolérer",
    "décolérasse": "décolérer",
    "décolérassent": "décolérer",
    "décolérasses": "décolérer",
    "décolérassiez": "décolérer",
    "décolérassions": "décolérer",
    "décolérera": "décolérer",
    "décolérerai": "décolérer",
    "décoléreraient": "décolérer",
    "décolérerais": "décolérer",
    "décolérerait": "décolérer",
    "décoléreras": "décolérer",
    "décolérerez": "décolérer",
    "décoléreriez": "décolérer",
    "décolérerions": "décolérer",
    "décolérerons": "décolérer",
    "décoléreront": "décolérer",
    "décolérez": "décolérer",
    "décolériez": "décolérer",
    "décolérions": "décolérer",
    "décolérons": "décolérer",
    "décolérâmes": "décolérer",
    "décolérât": "décolérer",
    "décolérâtes": "décolérer",
    "décolérèrent": "décolérer",
    "décoléré": "décolérer",
    "décombre": "décombrer",
    "décombres": "décombre",
    "décommanda": "décommander",
    "décommandai": "décommander",
    "décommandaient": "décommander",
    "décommandais": "décommander",
    "décommandait": "décommander",
    "décommandant": "décommander",
    "décommandas": "décommander",
    "décommandasse": "décommander",
    "décommandassent": "décommander",
    "décommandasses": "décommander",
    "décommandassiez": "décommander",
    "décommandassions": "décommander",
    "décommande": "décommander",
    "décommandent": "décommander",
    "décommandera": "décommander",
    "décommanderai": "décommander",
    "décommanderaient": "décommander",
    "décommanderais": "décommander",
    "décommanderait": "décommander",
    "décommanderas": "décommander",
    "décommanderez": "décommander",
    "décommanderiez": "décommander",
    "décommanderions": "décommander",
    "décommanderons": "décommander",
    "décommanderont": "décommander",
    "décommandes": "décommander",
    "décommandez": "décommander",
    "décommandiez": "décommander",
    "décommandions": "décommander",
    "décommandons": "décommander",
    "décommandâmes": "décommander",
    "décommandât": "décommander",
    "décommandâtes": "décommander",
    "décommandèrent": "décommander",
    "décommandé": "décommander",
    "décommandée": "décommander",
    "décommandées": "décommander",
    "décommandés": "décommander",
    "décommet": "décommettre",
    "décommets": "décommettre",
    "décommettaient": "décommettre",
    "décommettais": "décommettre",
    "décommettait": "décommettre",
    "décommettant": "décommettre",
    "décommette": "décommettre",
    "décommettent": "décommettre",
    "décommettes": "décommettre",
    "décommettez": "décommettre",
    "décommettiez": "décommettre",
    "décommettions": "décommettre",
    "décommettons": "décommettre",
    "décommettra": "décommettre",
    "décommettrai": "décommettre",
    "décommettraient": "décommettre",
    "décommettrais": "décommettre",
    "décommettrait": "décommettre",
    "décommettras": "décommettre",
    "décommettrez": "décommettre",
    "décommettriez": "décommettre",
    "décommettrions": "décommettre",
    "décommettrons": "décommettre",
    "décommettront": "décommettre",
    "décommirent": "décommettre",
    "décommis": "décommettre",
    "décommise": "décommettre",
    "décommises": "décommettre",
    "décommisse": "décommettre",
    "décommissent": "décommettre",
    "décommisses": "décommettre",
    "décommissiez": "décommettre",
    "décommissions": "décommettre",
    "décommit": "décommettre",
    "décommîmes": "décommettre",
    "décommît": "décommettre",
    "décommîtes": "décommettre",
    "décompensa": "décompenser",
    "décompensai": "décompenser",
    "décompensaient": "décompenser",
    "décompensais": "décompenser",
    "décompensait": "décompenser",
    "décompensant": "décompenser",
    "décompensas": "décompenser",
    "décompensasse": "décompenser",
    "décompensassent": "décompenser",
    "décompensasses": "décompenser",
    "décompensassiez": "décompenser",
    "décompensassions": "décompenser",
    "décompensations": "décompensation",
    "décompense": "décompenser",
    "décompensent": "décompenser",
    "décompensera": "décompenser",
    "décompenserai": "décompenser",
    "décompenseraient": "décompenser",
    "décompenserais": "décompenser",
    "décompenserait": "décompenser",
    "décompenseras": "décompenser",
    "décompenserez": "décompenser",
    "décompenseriez": "décompenser",
    "décompenserions": "décompenser",
    "décompenserons": "décompenser",
    "décompenseront": "décompenser",
    "décompenses": "décompenser",
    "décompensez": "décompenser",
    "décompensiez": "décompenser",
    "décompensions": "décompenser",
    "décompensons": "décompenser",
    "décompensâmes": "décompenser",
    "décompensât": "décompenser",
    "décompensâtes": "décompenser",
    "décompensèrent": "décompenser",
    "décompensé": "décompenser",
    "décompensée": "décompenser",
    "décompensées": "décompenser",
    "décompensés": "décompenser",
    "décompilations": "décompilation",
    "décomplexa": "décomplexer",
    "décomplexai": "décomplexer",
    "décomplexaient": "décomplexer",
    "décomplexais": "décomplexer",
    "décomplexait": "décomplexer",
    "décomplexant": "décomplexer",
    "décomplexas": "décomplexer",
    "décomplexasse": "décomplexer",
    "décomplexassent": "décomplexer",
    "décomplexasses": "décomplexer",
    "décomplexassiez": "décomplexer",
    "décomplexassions": "décomplexer",
    "décomplexe": "décomplexer",
    "décomplexent": "décomplexer",
    "décomplexera": "décomplexer",
    "décomplexerai": "décomplexer",
    "décomplexeraient": "décomplexer",
    "décomplexerais": "décomplexer",
    "décomplexerait": "décomplexer",
    "décomplexeras": "décomplexer",
    "décomplexerez": "décomplexer",
    "décomplexeriez": "décomplexer",
    "décomplexerions": "décomplexer",
    "décomplexerons": "décomplexer",
    "décomplexeront": "décomplexer",
    "décomplexes": "décomplexer",
    "décomplexez": "décomplexer",
    "décomplexiez": "décomplexer",
    "décomplexions": "décomplexer",
    "décomplexons": "décomplexer",
    "décomplexâmes": "décomplexer",
    "décomplexât": "décomplexer",
    "décomplexâtes": "décomplexer",
    "décomplexèrent": "décomplexer",
    "décomplexé": "décomplexer",
    "décomplexée": "décomplexer",
    "décomplexées": "décomplexer",
    "décomplexés": "décomplexer",
    "décomposa": "décomposer",
    "décomposai": "décomposer",
    "décomposaient": "décomposer",
    "décomposais": "décomposer",
    "décomposait": "décomposer",
    "décomposant": "décomposer",
    "décomposas": "décomposer",
    "décomposasse": "décomposer",
    "décomposassent": "décomposer",
    "décomposasses": "décomposer",
    "décomposassiez": "décomposer",
    "décomposassions": "décomposer",
    "décompose": "décomposer",
    "décomposent": "décomposer",
    "décomposera": "décomposer",
    "décomposerai": "décomposer",
    "décomposeraient": "décomposer",
    "décomposerais": "décomposer",
    "décomposerait": "décomposer",
    "décomposeras": "décomposer",
    "décomposerez": "décomposer",
    "décomposeriez": "décomposer",
    "décomposerions": "décomposer",
    "décomposerons": "décomposer",
    "décomposeront": "décomposer",
    "décomposes": "décomposer",
    "décomposez": "décomposer",
    "décomposiez": "décomposer",
    "décomposions": "décomposer",
    "décompositions": "décomposition",
    "décomposons": "décomposer",
    "décomposâmes": "décomposer",
    "décomposât": "décomposer",
    "décomposâtes": "décomposer",
    "décomposèrent": "décomposer",
    "décomposé": "décomposer",
    "décomposée": "décomposer",
    "décomposées": "décomposer",
    "décomposés": "décomposer",
    "décompressa": "décompresser",
    "décompresse": "décompresser",
    "décompressez": "décompresser",
    "décompressions": "décompression",
    "décompressé": "décompresser",
    "décomprima": "décomprimer",
    "décomprimai": "décomprimer",
    "décomprimaient": "décomprimer",
    "décomprimais": "décomprimer",
    "décomprimait": "décomprimer",
    "décomprimant": "décomprimer",
    "décomprimas": "décomprimer",
    "décomprimasse": "décomprimer",
    "décomprimassent": "décomprimer",
    "décomprimasses": "décomprimer",
    "décomprimassiez": "décomprimer",
    "décomprimassions": "décomprimer",
    "décomprime": "décomprimer",
    "décompriment": "décomprimer",
    "décomprimera": "décomprimer",
    "décomprimerai": "décomprimer",
    "décomprimeraient": "décomprimer",
    "décomprimerais": "décomprimer",
    "décomprimerait": "décomprimer",
    "décomprimeras": "décomprimer",
    "décomprimerez": "décomprimer",
    "décomprimeriez": "décomprimer",
    "décomprimerions": "décomprimer",
    "décomprimerons": "décomprimer",
    "décomprimeront": "décomprimer",
    "décomprimes": "décomprimer",
    "décomprimez": "décomprimer",
    "décomprimiez": "décomprimer",
    "décomprimions": "décomprimer",
    "décomprimons": "décomprimer",
    "décomprimâmes": "décomprimer",
    "décomprimât": "décomprimer",
    "décomprimâtes": "décomprimer",
    "décomprimèrent": "décomprimer",
    "décomprimé": "décomprimer",
    "décomprimée": "décomprimer",
    "décomprimées": "décomprimer",
    "décomprimés": "décomprimer",
    "décompta": "décompter",
    "décomptai": "décompter",
    "décomptaient": "décompter",
    "décomptais": "décompter",
    "décomptait": "décompter",
    "décomptant": "décompter",
    "décomptas": "décompter",
    "décomptasse": "décompter",
    "décomptassent": "décompter",
    "décomptasses": "décompter",
    "décomptassiez": "décompter",
    "décomptassions": "décompter",
    "décompte": "décompter",
    "décomptent": "décompter",
    "décomptera": "décompter",
    "décompterai": "décompter",
    "décompteraient": "décompter",
    "décompterais": "décompter",
    "décompterait": "décompter",
    "décompteras": "décompter",
    "décompterez": "décompter",
    "décompteriez": "décompter",
    "décompterions": "décompter",
    "décompterons": "décompter",
    "décompteront": "décompter",
    "décomptes": "décompter",
    "décomptez": "décompter",
    "décomptiez": "décompter",
    "décomptions": "décompter",
    "décomptons": "décompter",
    "décomptâmes": "décompter",
    "décomptât": "décompter",
    "décomptâtes": "décompter",
    "décomptèrent": "décompter",
    "décompté": "décompter",
    "décomptée": "décompter",
    "décomptées": "décompter",
    "décomptés": "décompter",
    "déconcentra": "déconcentrer",
    "déconcentrai": "déconcentrer",
    "déconcentraient": "déconcentrer",
    "déconcentrais": "déconcentrer",
    "déconcentrait": "déconcentrer",
    "déconcentrant": "déconcentrer",
    "déconcentras": "déconcentrer",
    "déconcentrasse": "déconcentrer",
    "déconcentrassent": "déconcentrer",
    "déconcentrasses": "déconcentrer",
    "déconcentrassiez": "déconcentrer",
    "déconcentrassions": "déconcentrer",
    "déconcentrations": "déconcentration",
    "déconcentre": "déconcentrer",
    "déconcentrent": "déconcentrer",
    "déconcentrera": "déconcentrer",
    "déconcentrerai": "déconcentrer",
    "déconcentreraient": "déconcentrer",
    "déconcentrerais": "déconcentrer",
    "déconcentrerait": "déconcentrer",
    "déconcentreras": "déconcentrer",
    "déconcentrerez": "déconcentrer",
    "déconcentreriez": "déconcentrer",
    "déconcentrerions": "déconcentrer",
    "déconcentrerons": "déconcentrer",
    "déconcentreront": "déconcentrer",
    "déconcentres": "déconcentrer",
    "déconcentrez": "déconcentrer",
    "déconcentriez": "déconcentrer",
    "déconcentrions": "déconcentrer",
    "déconcentrons": "déconcentrer",
    "déconcentrâmes": "déconcentrer",
    "déconcentrât": "déconcentrer",
    "déconcentrâtes": "déconcentrer",
    "déconcentrèrent": "déconcentrer",
    "déconcentré": "déconcentrer",
    "déconcentrée": "déconcentrer",
    "déconcentrées": "déconcentrer",
    "déconcentrés": "déconcentrer",
    "déconcerta": "déconcerter",
    "déconcertai": "déconcerter",
    "déconcertaient": "déconcerter",
    "déconcertais": "déconcerter",
    "déconcertait": "déconcerter",
    "déconcertant": "déconcerter",
    "déconcertante": "déconcertant",
    "déconcertantes": "déconcertant",
    "déconcertants": "déconcertant",
    "déconcertas": "déconcerter",
    "déconcertasse": "déconcerter",
    "déconcertassent": "déconcerter",
    "déconcertasses": "déconcerter",
    "déconcertassiez": "déconcerter",
    "déconcertassions": "déconcerter",
    "déconcerte": "déconcerter",
    "déconcertent": "déconcerter",
    "déconcertera": "déconcerter",
    "déconcerterai": "déconcerter",
    "déconcerteraient": "déconcerter",
    "déconcerterais": "déconcerter",
    "déconcerterait": "déconcerter",
    "déconcerteras": "déconcerter",
    "déconcerterez": "déconcerter",
    "déconcerteriez": "déconcerter",
    "déconcerterions": "déconcerter",
    "déconcerterons": "déconcerter",
    "déconcerteront": "déconcerter",
    "déconcertes": "déconcerter",
    "déconcertez": "déconcerter",
    "déconcertiez": "déconcerter",
    "déconcertions": "déconcerter",
    "déconcertons": "déconcerter",
    "déconcertâmes": "déconcerter",
    "déconcertât": "déconcerter",
    "déconcertâtes": "déconcerter",
    "déconcertèrent": "déconcerter",
    "déconcerté": "déconcerter",
    "déconcertée": "déconcerter",
    "déconcertées": "déconcerter",
    "déconcertés": "déconcerter",
    "déconfira": "déconfire",
    "déconfirai": "déconfire",
    "déconfiraient": "déconfire",
    "déconfirais": "déconfire",
    "déconfirait": "déconfire",
    "déconfiras": "déconfire",
    "déconfirent": "déconfire",
    "déconfirez": "déconfire",
    "déconfiriez": "déconfire",
    "déconfirions": "déconfire",
    "déconfirons": "déconfire",
    "déconfiront": "déconfire",
    "déconfis": "déconfire",
    "déconfisaient": "déconfire",
    "déconfisais": "déconfire",
    "déconfisait": "déconfire",
    "déconfisant": "déconfire",
    "déconfise": "déconfire",
    "déconfisent": "déconfire",
    "déconfises": "déconfire",
    "déconfisez": "déconfire",
    "déconfisiez": "déconfire",
    "déconfisions": "déconfire",
    "déconfisons": "déconfire",
    "déconfisse": "déconfire",
    "déconfissent": "déconfire",
    "déconfisses": "déconfire",
    "déconfissiez": "déconfire",
    "déconfissions": "déconfire",
    "déconfit": "déconfire",
    "déconfite": "déconfit",
    "déconfites": "déconfit",
    "déconfits": "déconfit",
    "déconfitures": "déconfiture",
    "déconfîmes": "déconfire",
    "déconfît": "déconfire",
    "déconfîtes": "déconfire",
    "décongela": "décongeler",
    "décongelai": "décongeler",
    "décongelaient": "décongeler",
    "décongelais": "décongeler",
    "décongelait": "décongeler",
    "décongelant": "décongeler",
    "décongelas": "décongeler",
    "décongelasse": "décongeler",
    "décongelassent": "décongeler",
    "décongelasses": "décongeler",
    "décongelassiez": "décongeler",
    "décongelassions": "décongeler",
    "décongelez": "décongeler",
    "décongeliez": "décongeler",
    "décongelions": "décongeler",
    "décongelons": "décongeler",
    "décongelâmes": "décongeler",
    "décongelât": "décongeler",
    "décongelâtes": "décongeler",
    "décongelèrent": "décongeler",
    "décongelé": "décongeler",
    "décongelée": "décongeler",
    "décongelées": "décongeler",
    "décongelés": "décongeler",
    "décongestionna": "décongestionner",
    "décongestionnai": "décongestionner",
    "décongestionnaient": "décongestionner",
    "décongestionnais": "décongestionner",
    "décongestionnait": "décongestionner",
    "décongestionnant": "décongestionner",
    "décongestionnas": "décongestionner",
    "décongestionnasse": "décongestionner",
    "décongestionnassent": "décongestionner",
    "décongestionnasses": "décongestionner",
    "décongestionnassiez": "décongestionner",
    "décongestionnassions": "décongestionner",
    "décongestionne": "décongestionner",
    "décongestionnements": "décongestionnement",
    "décongestionnent": "décongestionner",
    "décongestionnera": "décongestionner",
    "décongestionnerai": "décongestionner",
    "décongestionneraient": "décongestionner",
    "décongestionnerais": "décongestionner",
    "décongestionnerait": "décongestionner",
    "décongestionneras": "décongestionner",
    "décongestionnerez": "décongestionner",
    "décongestionneriez": "décongestionner",
    "décongestionnerions": "décongestionner",
    "décongestionnerons": "décongestionner",
    "décongestionneront": "décongestionner",
    "décongestionnes": "décongestionner",
    "décongestionnez": "décongestionner",
    "décongestionniez": "décongestionner",
    "décongestionnions": "décongestionner",
    "décongestionnons": "décongestionner",
    "décongestionnâmes": "décongestionner",
    "décongestionnât": "décongestionner",
    "décongestionnâtes": "décongestionner",
    "décongestionnèrent": "décongestionner",
    "décongestionné": "décongestionner",
    "décongestionnée": "décongestionner",
    "décongestionnées": "décongestionner",
    "décongestionnés": "décongestionner",
    "décongèle": "décongeler",
    "décongèlent": "décongeler",
    "décongèlera": "décongeler",
    "décongèlerai": "décongeler",
    "décongèleraient": "décongeler",
    "décongèlerais": "décongeler",
    "décongèlerait": "décongeler",
    "décongèleras": "décongeler",
    "décongèlerez": "décongeler",
    "décongèleriez": "décongeler",
    "décongèlerions": "décongeler",
    "décongèlerons": "décongeler",
    "décongèleront": "décongeler",
    "décongèles": "décongeler",
    "déconnages": "déconnage",
    "déconnaient": "déconner",
    "déconnais": "déconner",
    "déconnait": "déconner",
    "déconnant": "déconner",
    "déconne": "déconner",
    "déconnecta": "déconnecter",
    "déconnectai": "déconnecter",
    "déconnectaient": "déconnecter",
    "déconnectais": "déconnecter",
    "déconnectait": "déconnecter",
    "déconnectant": "déconnecter",
    "déconnectas": "déconnecter",
    "déconnectasse": "déconnecter",
    "déconnectassent": "déconnecter",
    "déconnectasses": "déconnecter",
    "déconnectassiez": "déconnecter",
    "déconnectassions": "déconnecter",
    "déconnecte": "déconnecter",
    "déconnectent": "déconnecter",
    "déconnectera": "déconnecter",
    "déconnecterai": "déconnecter",
    "déconnecteraient": "déconnecter",
    "déconnecterais": "déconnecter",
    "déconnecterait": "déconnecter",
    "déconnecteras": "déconnecter",
    "déconnecterez": "déconnecter",
    "déconnecteriez": "déconnecter",
    "déconnecterions": "déconnecter",
    "déconnecterons": "déconnecter",
    "déconnecteront": "déconnecter",
    "déconnectes": "déconnecter",
    "déconnectez": "déconnecter",
    "déconnectiez": "déconnecter",
    "déconnections": "déconnecter",
    "déconnectons": "déconnecter",
    "déconnectâmes": "déconnecter",
    "déconnectât": "déconnecter",
    "déconnectâtes": "déconnecter",
    "déconnectèrent": "déconnecter",
    "déconnecté": "déconnecter",
    "déconnectée": "déconnecter",
    "déconnectées": "déconnecter",
    "déconnectés": "déconnecter",
    "déconnent": "déconner",
    "déconnerai": "déconner",
    "déconnerais": "déconner",
    "déconnes": "déconner",
    "déconneurs": "déconneur",
    "déconneuse": "déconneur",
    "déconnez": "déconner",
    "déconné": "déconner",
    "déconophones": "déconophone",
    "déconseilla": "déconseiller",
    "déconseillai": "déconseiller",
    "déconseillaient": "déconseiller",
    "déconseillais": "déconseiller",
    "déconseillait": "déconseiller",
    "déconseillant": "déconseiller",
    "déconseillas": "déconseiller",
    "déconseillasse": "déconseiller",
    "déconseillassent": "déconseiller",
    "déconseillasses": "déconseiller",
    "déconseillassiez": "déconseiller",
    "déconseillassions": "déconseiller",
    "déconseille": "déconseiller",
    "déconseillent": "déconseiller",
    "déconseillera": "déconseiller",
    "déconseillerai": "déconseiller",
    "déconseilleraient": "déconseiller",
    "déconseillerais": "déconseiller",
    "déconseillerait": "déconseiller",
    "déconseilleras": "déconseiller",
    "déconseillerez": "déconseiller",
    "déconseilleriez": "déconseiller",
    "déconseillerions": "déconseiller",
    "déconseillerons": "déconseiller",
    "déconseilleront": "déconseiller",
    "déconseilles": "déconseiller",
    "déconseillez": "déconseiller",
    "déconseilliez": "déconseiller",
    "déconseillions": "déconseiller",
    "déconseillons": "déconseiller",
    "déconseillâmes": "déconseiller",
    "déconseillât": "déconseiller",
    "déconseillâtes": "déconseiller",
    "déconseillèrent": "déconseiller",
    "déconseillé": "déconseiller",
    "déconseillée": "déconseiller",
    "déconseillées": "déconseiller",
    "déconseillés": "déconseiller",
    "déconsidère": "déconsidérer",
    "déconsidèrent": "déconsidérer",
    "déconsidères": "déconsidérer",
    "déconsidéra": "déconsidérer",
    "déconsidérai": "déconsidérer",
    "déconsidéraient": "déconsidérer",
    "déconsidérais": "déconsidérer",
    "déconsidérait": "déconsidérer",
    "déconsidérant": "déconsidérer",
    "déconsidéras": "déconsidérer",
    "déconsidérasse": "déconsidérer",
    "déconsidérassent": "déconsidérer",
    "déconsidérasses": "déconsidérer",
    "déconsidérassiez": "déconsidérer",
    "déconsidérassions": "déconsidérer",
    "déconsidérera": "déconsidérer",
    "déconsidérerai": "déconsidérer",
    "déconsidéreraient": "déconsidérer",
    "déconsidérerais": "déconsidérer",
    "déconsidérerait": "déconsidérer",
    "déconsidéreras": "déconsidérer",
    "déconsidérerez": "déconsidérer",
    "déconsidéreriez": "déconsidérer",
    "déconsidérerions": "déconsidérer",
    "déconsidérerons": "déconsidérer",
    "déconsidéreront": "déconsidérer",
    "déconsidérez": "déconsidérer",
    "déconsidériez": "déconsidérer",
    "déconsidérions": "déconsidérer",
    "déconsidérons": "déconsidérer",
    "déconsidérâmes": "déconsidérer",
    "déconsidérât": "déconsidérer",
    "déconsidérâtes": "déconsidérer",
    "déconsidérèrent": "déconsidérer",
    "déconsidéré": "déconsidérer",
    "déconsidérée": "déconsidérer",
    "déconsidérées": "déconsidérer",
    "déconsidérés": "déconsidérer",
    "déconstipe": "déconstiper",
    "déconstructions": "déconstruction",
    "déconstruit": "déconstruire",
    "décontaminant": "décontaminer",
    "décontaminations": "décontamination",
    "décontaminé": "décontaminer",
    "décontenance": "décontenancer",
    "décontenancent": "décontenancer",
    "décontenancera": "décontenancer",
    "décontenancerai": "décontenancer",
    "décontenanceraient": "décontenancer",
    "décontenancerais": "décontenancer",
    "décontenancerait": "décontenancer",
    "décontenanceras": "décontenancer",
    "décontenancerez": "décontenancer",
    "décontenanceriez": "décontenancer",
    "décontenancerions": "décontenancer",
    "décontenancerons": "décontenancer",
    "décontenanceront": "décontenancer",
    "décontenances": "décontenancer",
    "décontenancez": "décontenancer",
    "décontenanciez": "décontenancer",
    "décontenancions": "décontenancer",
    "décontenancèrent": "décontenancer",
    "décontenancé": "décontenancer",
    "décontenancée": "décontenancer",
    "décontenancées": "décontenancer",
    "décontenancés": "décontenancer",
    "décontenança": "décontenancer",
    "décontenançai": "décontenancer",
    "décontenançaient": "décontenancer",
    "décontenançais": "décontenancer",
    "décontenançait": "décontenancer",
    "décontenançant": "décontenancer",
    "décontenanças": "décontenancer",
    "décontenançasse": "décontenancer",
    "décontenançassent": "décontenancer",
    "décontenançasses": "décontenancer",
    "décontenançassiez": "décontenancer",
    "décontenançassions": "décontenancer",
    "décontenançons": "décontenancer",
    "décontenançâmes": "décontenancer",
    "décontenançât": "décontenancer",
    "décontenançâtes": "décontenancer",
    "décontracta": "décontracter",
    "décontractai": "décontracter",
    "décontractaient": "décontracter",
    "décontractais": "décontracter",
    "décontractait": "décontracter",
    "décontractant": "décontracter",
    "décontractas": "décontracter",
    "décontractasse": "décontracter",
    "décontractassent": "décontracter",
    "décontractasses": "décontracter",
    "décontractassiez": "décontracter",
    "décontractassions": "décontracter",
    "décontracte": "décontracter",
    "décontractent": "décontracter",
    "décontractera": "décontracter",
    "décontracterai": "décontracter",
    "décontracteraient": "décontracter",
    "décontracterais": "décontracter",
    "décontracterait": "décontracter",
    "décontracteras": "décontracter",
    "décontracterez": "décontracter",
    "décontracteriez": "décontracter",
    "décontracterions": "décontracter",
    "décontracterons": "décontracter",
    "décontracteront": "décontracter",
    "décontractes": "décontracter",
    "décontractez": "décontracter",
    "décontractiez": "décontracter",
    "décontractions": "décontraction",
    "décontractons": "décontracter",
    "décontractâmes": "décontracter",
    "décontractât": "décontracter",
    "décontractâtes": "décontracter",
    "décontractèrent": "décontracter",
    "décontracté": "décontracter",
    "décontractée": "décontracter",
    "décontractées": "décontracter",
    "décontractés": "décontracter",
    "déconvenues": "déconvenue",
    "décora": "décorer",
    "décorai": "décorer",
    "décoraient": "décorer",
    "décorais": "décorer",
    "décorait": "décorer",
    "décorant": "décorer",
    "décoras": "décorer",
    "décorasse": "décorer",
    "décorassent": "décorer",
    "décorasses": "décorer",
    "décorassiez": "décorer",
    "décorassions": "décorer",
    "décorateurs": "décorateur",
    "décoratifs": "décoratif",
    "décorations": "décoration",
    "décorative": "décoratif",
    "décoratives": "décoratif",
    "décoratrice": "décorateur",
    "décoratrices": "décorateur",
    "décore": "décorer",
    "décorent": "décorer",
    "décorera": "décorer",
    "décorerai": "décorer",
    "décoreraient": "décorer",
    "décorerais": "décorer",
    "décorerait": "décorer",
    "décoreras": "décorer",
    "décorerez": "décorer",
    "décoreriez": "décorer",
    "décorerions": "décorer",
    "décorerons": "décorer",
    "décoreront": "décorer",
    "décores": "décorer",
    "décorez": "décorer",
    "décoriez": "décorer",
    "décorions": "décorer",
    "décorna": "décorner",
    "décornai": "décorner",
    "décornaient": "décorner",
    "décornais": "décorner",
    "décornait": "décorner",
    "décornant": "décorner",
    "décornas": "décorner",
    "décornasse": "décorner",
    "décornassent": "décorner",
    "décornasses": "décorner",
    "décornassiez": "décorner",
    "décornassions": "décorner",
    "décorne": "décorner",
    "décornent": "décorner",
    "décornera": "décorner",
    "décornerai": "décorner",
    "décorneraient": "décorner",
    "décornerais": "décorner",
    "décornerait": "décorner",
    "décorneras": "décorner",
    "décornerez": "décorner",
    "décorneriez": "décorner",
    "décornerions": "décorner",
    "décornerons": "décorner",
    "décorneront": "décorner",
    "décornes": "décorner",
    "décornez": "décorner",
    "décorniez": "décorner",
    "décornions": "décorner",
    "décornons": "décorner",
    "décornâmes": "décorner",
    "décornât": "décorner",
    "décornâtes": "décorner",
    "décornèrent": "décorner",
    "décorné": "décorner",
    "décornée": "décorner",
    "décornées": "décorner",
    "décornés": "décorner",
    "décorons": "décorer",
    "décors": "décor",
    "décorticages": "décorticage",
    "décortiqua": "décortiquer",
    "décortiquai": "décortiquer",
    "décortiquaient": "décortiquer",
    "décortiquais": "décortiquer",
    "décortiquait": "décortiquer",
    "décortiquant": "décortiquer",
    "décortiquas": "décortiquer",
    "décortiquasse": "décortiquer",
    "décortiquassent": "décortiquer",
    "décortiquasses": "décortiquer",
    "décortiquassiez": "décortiquer",
    "décortiquassions": "décortiquer",
    "décortique": "décortiquer",
    "décortiquent": "décortiquer",
    "décortiquera": "décortiquer",
    "décortiquerai": "décortiquer",
    "décortiqueraient": "décortiquer",
    "décortiquerais": "décortiquer",
    "décortiquerait": "décortiquer",
    "décortiqueras": "décortiquer",
    "décortiquerez": "décortiquer",
    "décortiqueriez": "décortiquer",
    "décortiquerions": "décortiquer",
    "décortiquerons": "décortiquer",
    "décortiqueront": "décortiquer",
    "décortiques": "décortiquer",
    "décortiquez": "décortiquer",
    "décortiquiez": "décortiquer",
    "décortiquions": "décortiquer",
    "décortiquons": "décortiquer",
    "décortiquâmes": "décortiquer",
    "décortiquât": "décortiquer",
    "décortiquâtes": "décortiquer",
    "décortiquèrent": "décortiquer",
    "décortiqué": "décortiquer",
    "décortiquée": "décortiquer",
    "décortiquées": "décortiquer",
    "décortiqués": "décortiquer",
    "décorums": "décorum",
    "décorâmes": "décorer",
    "décorât": "décorer",
    "décorâtes": "décorer",
    "décorèrent": "décorer",
    "décoré": "décorer",
    "décorée": "décorer",
    "décorées": "décorer",
    "décorés": "décorer",
    "décotes": "décote",
    "découcha": "découcher",
    "découchai": "découcher",
    "découchaient": "découcher",
    "découchais": "découcher",
    "découchait": "découcher",
    "découchant": "découcher",
    "découchas": "découcher",
    "découchasse": "découcher",
    "découchassent": "découcher",
    "découchasses": "découcher",
    "découchassiez": "découcher",
    "découchassions": "découcher",
    "découche": "découcher",
    "découchent": "découcher",
    "découchera": "découcher",
    "découcherai": "découcher",
    "découcheraient": "découcher",
    "découcherais": "découcher",
    "découcherait": "découcher",
    "découcheras": "découcher",
    "découcherez": "découcher",
    "découcheriez": "découcher",
    "découcherions": "découcher",
    "découcherons": "découcher",
    "découcheront": "découcher",
    "découches": "découcher",
    "découchez": "découcher",
    "découchiez": "découcher",
    "découchions": "découcher",
    "découchons": "découcher",
    "découchâmes": "découcher",
    "découchât": "découcher",
    "découchâtes": "découcher",
    "découchèrent": "découcher",
    "découché": "découcher",
    "découd": "découdre",
    "découdra": "découdre",
    "découdrai": "découdre",
    "découdraient": "découdre",
    "découdrais": "découdre",
    "découdrait": "découdre",
    "découdras": "découdre",
    "découdrez": "découdre",
    "découdriez": "découdre",
    "découdrions": "découdre",
    "découdrons": "découdre",
    "découdront": "découdre",
    "découds": "découdre",
    "découla": "découler",
    "découlai": "découler",
    "découlaient": "découler",
    "découlais": "découler",
    "découlait": "découler",
    "découlant": "découler",
    "découlas": "découler",
    "découlasse": "découler",
    "découlassent": "découler",
    "découlasses": "découler",
    "découlassiez": "découler",
    "découlassions": "découler",
    "découle": "découler",
    "découlent": "découler",
    "découlera": "découler",
    "découlerai": "découler",
    "découleraient": "découler",
    "découlerais": "découler",
    "découlerait": "découler",
    "découleras": "découler",
    "découlerez": "découler",
    "découleriez": "découler",
    "découlerions": "découler",
    "découlerons": "découler",
    "découleront": "découler",
    "découles": "découler",
    "découlez": "découler",
    "découliez": "découler",
    "découlions": "découler",
    "découlons": "découler",
    "découlâmes": "découler",
    "découlât": "découler",
    "découlâtes": "découler",
    "découlèrent": "découler",
    "découlé": "découler",
    "découpa": "découper",
    "découpages": "découpage",
    "découpai": "découper",
    "découpaient": "découper",
    "découpais": "découper",
    "découpait": "découper",
    "découpant": "découper",
    "découpas": "découper",
    "découpasse": "découper",
    "découpassent": "découper",
    "découpasses": "découper",
    "découpassiez": "découper",
    "découpassions": "découper",
    "découpe": "découper",
    "découpent": "découper",
    "découpera": "découper",
    "découperai": "découper",
    "découperaient": "découper",
    "découperais": "découper",
    "découperait": "découper",
    "découperas": "découper",
    "découperez": "découper",
    "découperiez": "découper",
    "découperions": "découper",
    "découperons": "découper",
    "découperont": "découper",
    "découpes": "découper",
    "découpeurs": "découpeur",
    "découpeuse": "découpeur",
    "découpez": "découper",
    "découpiez": "découper",
    "découpions": "découper",
    "découpla": "découpler",
    "découplai": "découpler",
    "découplaient": "découpler",
    "découplais": "découpler",
    "découplait": "découpler",
    "découplant": "découpler",
    "découplas": "découpler",
    "découplasse": "découpler",
    "découplassent": "découpler",
    "découplasses": "découpler",
    "découplassiez": "découpler",
    "découplassions": "découpler",
    "découple": "découpler",
    "découplent": "découpler",
    "découplera": "découpler",
    "découplerai": "découpler",
    "découpleraient": "découpler",
    "découplerais": "découpler",
    "découplerait": "découpler",
    "découpleras": "découpler",
    "découplerez": "découpler",
    "découpleriez": "découpler",
    "découplerions": "découpler",
    "découplerons": "découpler",
    "découpleront": "découpler",
    "découples": "découpler",
    "découplez": "découpler",
    "découpliez": "découpler",
    "découplions": "découpler",
    "découplons": "découpler",
    "découplâmes": "découpler",
    "découplât": "découpler",
    "découplâtes": "découpler",
    "découplèrent": "découpler",
    "découplé": "découpler",
    "découplée": "découpler",
    "découplées": "découpler",
    "découplés": "découpler",
    "découpons": "découper",
    "découpures": "découpure",
    "découpâmes": "découper",
    "découpât": "découper",
    "découpâtes": "découper",
    "découpèrent": "découper",
    "découpé": "découper",
    "découpée": "découper",
    "découpées": "découper",
    "découpés": "découper",
    "décourage": "décourager",
    "découragea": "décourager",
    "décourageai": "décourager",
    "décourageaient": "décourager",
    "décourageais": "décourager",
    "décourageait": "décourager",
    "décourageant": "décourager",
    "décourageante": "décourageant",
    "décourageantes": "décourageant",
    "décourageants": "décourageant",
    "décourageas": "décourager",
    "décourageasse": "décourager",
    "décourageassent": "décourager",
    "décourageasses": "décourager",
    "décourageassiez": "décourager",
    "décourageassions": "décourager",
    "découragements": "découragement",
    "découragent": "décourager",
    "décourageons": "décourager",
    "découragera": "décourager",
    "découragerai": "décourager",
    "décourageraient": "décourager",
    "découragerais": "décourager",
    "découragerait": "décourager",
    "décourageras": "décourager",
    "découragerez": "décourager",
    "décourageriez": "décourager",
    "découragerions": "décourager",
    "découragerons": "décourager",
    "décourageront": "décourager",
    "décourages": "décourager",
    "découragez": "décourager",
    "décourageâmes": "décourager",
    "décourageât": "décourager",
    "décourageâtes": "décourager",
    "découragiez": "décourager",
    "découragions": "décourager",
    "découragèrent": "décourager",
    "découragé": "décourager",
    "découragée": "décourager",
    "découragées": "décourager",
    "découragés": "décourager",
    "découronna": "découronner",
    "découronnai": "découronner",
    "découronnaient": "découronner",
    "découronnais": "découronner",
    "découronnait": "découronner",
    "découronnant": "découronner",
    "découronnas": "découronner",
    "découronnasse": "découronner",
    "découronnassent": "découronner",
    "découronnasses": "découronner",
    "découronnassiez": "découronner",
    "découronnassions": "découronner",
    "découronne": "découronner",
    "découronnent": "découronner",
    "découronnera": "découronner",
    "découronnerai": "découronner",
    "découronneraient": "découronner",
    "découronnerais": "découronner",
    "découronnerait": "découronner",
    "découronneras": "découronner",
    "découronnerez": "découronner",
    "découronneriez": "découronner",
    "découronnerions": "découronner",
    "découronnerons": "découronner",
    "découronneront": "découronner",
    "découronnes": "découronner",
    "découronnez": "découronner",
    "découronniez": "découronner",
    "découronnions": "découronner",
    "découronnons": "découronner",
    "découronnâmes": "découronner",
    "découronnât": "découronner",
    "découronnâtes": "découronner",
    "découronnèrent": "découronner",
    "découronné": "découronner",
    "découronnée": "découronner",
    "découronnées": "découronner",
    "découronnés": "découronner",
    "décousaient": "découdre",
    "décousais": "découdre",
    "décousait": "découdre",
    "décousant": "découdre",
    "découse": "découdre",
    "décousent": "découdre",
    "découses": "découdre",
    "décousez": "découdre",
    "décousiez": "découdre",
    "décousions": "découdre",
    "décousirent": "découdre",
    "décousis": "découdre",
    "décousisse": "découdre",
    "décousissent": "découdre",
    "décousisses": "découdre",
    "décousissiez": "découdre",
    "décousissions": "découdre",
    "décousit": "découdre",
    "décousons": "découdre",
    "décousu": "découdre",
    "décousue": "décousu",
    "décousues": "décousu",
    "décousus": "décousu",
    "décousîmes": "découdre",
    "décousît": "découdre",
    "décousîtes": "découdre",
    "découvert": "découvrir",
    "découverte": "découvrir",
    "découvertes": "découvrir",
    "découverts": "découvrir",
    "découvraient": "découvrir",
    "découvrais": "découvrir",
    "découvrait": "découvrir",
    "découvrant": "découvrir",
    "découvre": "découvrir",
    "découvrent": "découvrir",
    "découvres": "découvrir",
    "découvreurs": "découvreur",
    "découvreuse": "découvreur",
    "découvrez": "découvrir",
    "découvriez": "découvrir",
    "découvrions": "découvrir",
    "découvrira": "découvrir",
    "découvrirai": "découvrir",
    "découvriraient": "découvrir",
    "découvrirais": "découvrir",
    "découvrirait": "découvrir",
    "découvriras": "découvrir",
    "découvrirent": "découvrir",
    "découvrirez": "découvrir",
    "découvririez": "découvrir",
    "découvririons": "découvrir",
    "découvrirons": "découvrir",
    "découvriront": "découvrir",
    "découvris": "découvrir",
    "découvrisse": "découvrir",
    "découvrissent": "découvrir",
    "découvrisses": "découvrir",
    "découvrissiez": "découvrir",
    "découvrissions": "découvrir",
    "découvrit": "découvrir",
    "découvrons": "découvrir",
    "découvrîmes": "découvrir",
    "découvrît": "découvrir",
    "découvrîtes": "découvrir",
    "décrapouille": "décrapouiller",
    "décrassa": "décrasser",
    "décrassai": "décrasser",
    "décrassaient": "décrasser",
    "décrassais": "décrasser",
    "décrassait": "décrasser",
    "décrassant": "décrasser",
    "décrassas": "décrasser",
    "décrassasse": "décrasser",
    "décrassassent": "décrasser",
    "décrassasses": "décrasser",
    "décrassassiez": "décrasser",
    "décrassassions": "décrasser",
    "décrasse": "décrasser",
    "décrassent": "décrasser",
    "décrassera": "décrasser",
    "décrasserai": "décrasser",
    "décrasseraient": "décrasser",
    "décrasserais": "décrasser",
    "décrasserait": "décrasser",
    "décrasseras": "décrasser",
    "décrasserez": "décrasser",
    "décrasseriez": "décrasser",
    "décrasserions": "décrasser",
    "décrasserons": "décrasser",
    "décrasseront": "décrasser",
    "décrasses": "décrasser",
    "décrassez": "décrasser",
    "décrassiez": "décrasser",
    "décrassions": "décrasser",
    "décrassons": "décrasser",
    "décrassâmes": "décrasser",
    "décrassât": "décrasser",
    "décrassâtes": "décrasser",
    "décrassèrent": "décrasser",
    "décrassé": "décrasser",
    "décrassée": "décrasser",
    "décrassées": "décrasser",
    "décrassés": "décrasser",
    "décrets": "décret",
    "décrets-lois": "décret-loi",
    "décreusa": "décreuser",
    "décreusai": "décreuser",
    "décreusaient": "décreuser",
    "décreusais": "décreuser",
    "décreusait": "décreuser",
    "décreusant": "décreuser",
    "décreusas": "décreuser",
    "décreusasse": "décreuser",
    "décreusassent": "décreuser",
    "décreusasses": "décreuser",
    "décreusassiez": "décreuser",
    "décreusassions": "décreuser",
    "décreuse": "décreuser",
    "décreusent": "décreuser",
    "décreusera": "décreuser",
    "décreuserai": "décreuser",
    "décreuseraient": "décreuser",
    "décreuserais": "décreuser",
    "décreuserait": "décreuser",
    "décreuseras": "décreuser",
    "décreuserez": "décreuser",
    "décreuseriez": "décreuser",
    "décreuserions": "décreuser",
    "décreuserons": "décreuser",
    "décreuseront": "décreuser",
    "décreuses": "décreuser",
    "décreusez": "décreuser",
    "décreusiez": "décreuser",
    "décreusions": "décreuser",
    "décreusons": "décreuser",
    "décreusâmes": "décreuser",
    "décreusât": "décreuser",
    "décreusâtes": "décreuser",
    "décreusèrent": "décreuser",
    "décreusé": "décreuser",
    "décreusée": "décreuser",
    "décreusées": "décreuser",
    "décreusés": "décreuser",
    "décria": "décrier",
    "décriai": "décrier",
    "décriaient": "décrier",
    "décriais": "décrier",
    "décriait": "décrier",
    "décriant": "décrier",
    "décrias": "décrier",
    "décriasse": "décrier",
    "décriassent": "décrier",
    "décriasses": "décrier",
    "décriassiez": "décrier",
    "décriassions": "décrier",
    "décrie": "décrier",
    "décrient": "décrier",
    "décriera": "décrier",
    "décrierai": "décrier",
    "décrieraient": "décrier",
    "décrierais": "décrier",
    "décrierait": "décrier",
    "décrieras": "décrier",
    "décrierez": "décrier",
    "décrieriez": "décrier",
    "décrierions": "décrier",
    "décrierons": "décrier",
    "décrieront": "décrier",
    "décries": "décrier",
    "décriez": "décrier",
    "décriiez": "décrier",
    "décriions": "décrier",
    "décrions": "décrier",
    "décrira": "décrire",
    "décrirai": "décrire",
    "décriraient": "décrire",
    "décrirais": "décrire",
    "décrirait": "décrire",
    "décriras": "décrire",
    "décrirez": "décrire",
    "décririez": "décrire",
    "décririons": "décrire",
    "décrirons": "décrire",
    "décriront": "décrire",
    "décris": "décrire",
    "décrispations": "décrispation",
    "décrispe": "décrisper",
    "décrispât": "décrisper",
    "décrispé": "décrisper",
    "décrit": "décrire",
    "décrite": "décrit",
    "décrites": "décrit",
    "décrits": "décrit",
    "décrivaient": "décrire",
    "décrivais": "décrire",
    "décrivait": "décrire",
    "décrivant": "décrire",
    "décrive": "décrire",
    "décrivent": "décrire",
    "décrives": "décrire",
    "décrivez": "décrire",
    "décriviez": "décrire",
    "décrivions": "décrire",
    "décrivirent": "décrire",
    "décrivis": "décrire",
    "décrivisse": "décrire",
    "décrivissent": "décrire",
    "décrivisses": "décrire",
    "décrivissiez": "décrire",
    "décrivissions": "décrire",
    "décrivit": "décrire",
    "décrivons": "décrire",
    "décrivîmes": "décrire",
    "décrivît": "décrire",
    "décrivîtes": "décrire",
    "décriâmes": "décrier",
    "décriât": "décrier",
    "décriâtes": "décrier",
    "décrièrent": "décrier",
    "décrié": "décrier",
    "décriée": "décrier",
    "décriées": "décrier",
    "décriés": "décrier",
    "décrocha": "décrocher",
    "décrochages": "décrochage",
    "décrochai": "décrocher",
    "décrochaient": "décrocher",
    "décrochais": "décrocher",
    "décrochait": "décrocher",
    "décrochant": "décrocher",
    "décrochas": "décrocher",
    "décrochasse": "décrocher",
    "décrochassent": "décrocher",
    "décrochasses": "décrocher",
    "décrochassiez": "décrocher",
    "décrochassions": "décrocher",
    "décroche": "décrocher",
    "décrochements": "décrochement",
    "décrochent": "décrocher",
    "décrochera": "décrocher",
    "décrocherai": "décrocher",
    "décrocheraient": "décrocher",
    "décrocherais": "décrocher",
    "décrocherait": "décrocher",
    "décrocheras": "décrocher",
    "décrocherez": "décrocher",
    "décrocheriez": "décrocher",
    "décrocherions": "décrocher",
    "décrocherons": "décrocher",
    "décrocheront": "décrocher",
    "décroches": "décrocher",
    "décrochez": "décrocher",
    "décrochiez": "décrocher",
    "décrochions": "décrocher",
    "décrochons": "décrocher",
    "décrochâmes": "décrocher",
    "décrochât": "décrocher",
    "décrochâtes": "décrocher",
    "décrochèrent": "décrocher",
    "décroché": "décrocher",
    "décrochée": "décrocher",
    "décrochées": "décrocher",
    "décrochés": "décrocher",
    "décrois": "décroître",
    "décroisa": "décroiser",
    "décroisai": "décroiser",
    "décroisaient": "décroiser",
    "décroisais": "décroiser",
    "décroisait": "décroiser",
    "décroisant": "décroiser",
    "décroisas": "décroiser",
    "décroisasse": "décroiser",
    "décroisassent": "décroiser",
    "décroisasses": "décroiser",
    "décroisassiez": "décroiser",
    "décroisassions": "décroiser",
    "décroise": "décroiser",
    "décroisent": "décroiser",
    "décroisera": "décroiser",
    "décroiserai": "décroiser",
    "décroiseraient": "décroiser",
    "décroiserais": "décroiser",
    "décroiserait": "décroiser",
    "décroiseras": "décroiser",
    "décroiserez": "décroiser",
    "décroiseriez": "décroiser",
    "décroiserions": "décroiser",
    "décroiserons": "décroiser",
    "décroiseront": "décroiser",
    "décroises": "décroiser",
    "décroisez": "décroiser",
    "décroisiez": "décroiser",
    "décroisions": "décroiser",
    "décroisons": "décroiser",
    "décroissaient": "décroître",
    "décroissais": "décroître",
    "décroissait": "décroître",
    "décroissances": "décroissance",
    "décroissant": "décroître",
    "décroissante": "décroissant",
    "décroissantes": "décroissant",
    "décroissants": "décroissant",
    "décroisse": "décroître",
    "décroissent": "décroître",
    "décroisses": "décroître",
    "décroissez": "décroître",
    "décroissiez": "décroître",
    "décroissions": "décroître",
    "décroissons": "décroître",
    "décroisâmes": "décroiser",
    "décroisât": "décroiser",
    "décroisâtes": "décroiser",
    "décroisèrent": "décroiser",
    "décroisé": "décroiser",
    "décroisée": "décroiser",
    "décroisées": "décroiser",
    "décroisés": "décroiser",
    "décrotta": "décrotter",
    "décrottages": "décrottage",
    "décrottai": "décrotter",
    "décrottaient": "décrotter",
    "décrottais": "décrotter",
    "décrottait": "décrotter",
    "décrottant": "décrotter",
    "décrottas": "décrotter",
    "décrottasse": "décrotter",
    "décrottassent": "décrotter",
    "décrottasses": "décrotter",
    "décrottassiez": "décrotter",
    "décrottassions": "décrotter",
    "décrotte": "décrotter",
    "décrottent": "décrotter",
    "décrottera": "décrotter",
    "décrotterai": "décrotter",
    "décrotteraient": "décrotter",
    "décrotterais": "décrotter",
    "décrotterait": "décrotter",
    "décrotteras": "décrotter",
    "décrotterez": "décrotter",
    "décrotteriez": "décrotter",
    "décrotterions": "décrotter",
    "décrotterons": "décrotter",
    "décrotteront": "décrotter",
    "décrottes": "décrotter",
    "décrottez": "décrotter",
    "décrottiez": "décrotter",
    "décrottions": "décrotter",
    "décrottons": "décrotter",
    "décrottâmes": "décrotter",
    "décrottât": "décrotter",
    "décrottâtes": "décrotter",
    "décrottèrent": "décrotter",
    "décrotté": "décrotter",
    "décrottée": "décrotter",
    "décrottées": "décrotter",
    "décrottés": "décrotter",
    "décroît": "décroître",
    "décroîtra": "décroître",
    "décroîtrai": "décroître",
    "décroîtraient": "décroître",
    "décroîtrais": "décroître",
    "décroîtrait": "décroître",
    "décroîtras": "décroître",
    "décroîtrez": "décroître",
    "décroîtriez": "décroître",
    "décroîtrions": "décroître",
    "décroîtrons": "décroître",
    "décroîtront": "décroître",
    "décru": "décroître",
    "décrues": "décrue",
    "décrurent": "décroître",
    "décrus": "décroître",
    "décrusse": "décroître",
    "décrussent": "décroître",
    "décrusses": "décroître",
    "décrussiez": "décroître",
    "décrussions": "décroître",
    "décrut": "décroître",
    "décrypta": "décrypter",
    "décryptai": "décrypter",
    "décryptaient": "décrypter",
    "décryptais": "décrypter",
    "décryptait": "décrypter",
    "décryptant": "décrypter",
    "décryptas": "décrypter",
    "décryptasse": "décrypter",
    "décryptassent": "décrypter",
    "décryptasses": "décrypter",
    "décryptassiez": "décrypter",
    "décryptassions": "décrypter",
    "décrypte": "décrypter",
    "décryptent": "décrypter",
    "décryptera": "décrypter",
    "décrypterai": "décrypter",
    "décrypteraient": "décrypter",
    "décrypterais": "décrypter",
    "décrypterait": "décrypter",
    "décrypteras": "décrypter",
    "décrypterez": "décrypter",
    "décrypteriez": "décrypter",
    "décrypterions": "décrypter",
    "décrypterons": "décrypter",
    "décrypteront": "décrypter",
    "décryptes": "décrypter",
    "décrypteurs": "décrypteur",
    "décryptez": "décrypter",
    "décryptiez": "décrypter",
    "décryptions": "décrypter",
    "décryptons": "décrypter",
    "décryptâmes": "décrypter",
    "décryptât": "décrypter",
    "décryptâtes": "décrypter",
    "décryptèrent": "décrypter",
    "décrypté": "décrypter",
    "décryptée": "décrypter",
    "décryptées": "décrypter",
    "décryptés": "décrypter",
    "décrète": "décréter",
    "décrètent": "décréter",
    "décrètes": "décréter",
    "décrédibilisez": "décrédibiliser",
    "décrépi": "décrépir",
    "décrépie": "décrépir",
    "décrépies": "décrépir",
    "décrépira": "décrépir",
    "décrépirai": "décrépir",
    "décrépiraient": "décrépir",
    "décrépirais": "décrépir",
    "décrépirait": "décrépir",
    "décrépiras": "décrépir",
    "décrépirent": "décrépir",
    "décrépirez": "décrépir",
    "décrépiriez": "décrépir",
    "décrépirions": "décrépir",
    "décrépirons": "décrépir",
    "décrépiront": "décrépir",
    "décrépis": "décrépir",
    "décrépissaient": "décrépir",
    "décrépissais": "décrépir",
    "décrépissait": "décrépir",
    "décrépissant": "décrépir",
    "décrépisse": "décrépir",
    "décrépissent": "décrépir",
    "décrépisses": "décrépir",
    "décrépissez": "décrépir",
    "décrépissiez": "décrépir",
    "décrépissions": "décrépir",
    "décrépissons": "décrépir",
    "décrépit": "décrépir",
    "décrépite": "décrépit",
    "décrépites": "décrépit",
    "décrépits": "décrépit",
    "décrépîmes": "décrépir",
    "décrépît": "décrépir",
    "décrépîtes": "décrépir",
    "décréta": "décréter",
    "décrétai": "décréter",
    "décrétaient": "décréter",
    "décrétais": "décréter",
    "décrétait": "décréter",
    "décrétant": "décréter",
    "décrétas": "décréter",
    "décrétasse": "décréter",
    "décrétassent": "décréter",
    "décrétasses": "décréter",
    "décrétassiez": "décréter",
    "décrétassions": "décréter",
    "décrétera": "décréter",
    "décréterai": "décréter",
    "décréteraient": "décréter",
    "décréterais": "décréter",
    "décréterait": "décréter",
    "décréteras": "décréter",
    "décréterez": "décréter",
    "décréteriez": "décréter",
    "décréterions": "décréter",
    "décréterons": "décréter",
    "décréteront": "décréter",
    "décrétez": "décréter",
    "décrétiez": "décréter",
    "décrétions": "décréter",
    "décrétons": "décréter",
    "décrétâmes": "décréter",
    "décrétât": "décréter",
    "décrétâtes": "décréter",
    "décrétèrent": "décréter",
    "décrété": "décréter",
    "décrétée": "décréter",
    "décrétées": "décréter",
    "décrétés": "décréter",
    "décrûmes": "décroître",
    "décrût": "décroître",
    "décrûtes": "décroître",
    "décuira": "décuire",
    "décuirai": "décuire",
    "décuiraient": "décuire",
    "décuirais": "décuire",
    "décuirait": "décuire",
    "décuiras": "décuire",
    "décuirez": "décuire",
    "décuiriez": "décuire",
    "décuirions": "décuire",
    "décuirons": "décuire",
    "décuiront": "décuire",
    "décuis": "décuire",
    "décuisaient": "décuire",
    "décuisais": "décuire",
    "décuisait": "décuire",
    "décuisant": "décuire",
    "décuise": "décuire",
    "décuisent": "décuire",
    "décuises": "décuire",
    "décuisez": "décuire",
    "décuisiez": "décuire",
    "décuisions": "décuire",
    "décuisirent": "décuire",
    "décuisis": "décuire",
    "décuisisse": "décuire",
    "décuisissent": "décuire",
    "décuisisses": "décuire",
    "décuisissiez": "décuire",
    "décuisissions": "décuire",
    "décuisit": "décuire",
    "décuisons": "décuire",
    "décuisîmes": "décuire",
    "décuisît": "décuire",
    "décuisîtes": "décuire",
    "décuit": "décuire",
    "décuite": "décuire",
    "décuites": "décuire",
    "décuits": "décuire",
    "décuité": "décuiter",
    "déculotta": "déculotter",
    "déculottai": "déculotter",
    "déculottaient": "déculotter",
    "déculottais": "déculotter",
    "déculottait": "déculotter",
    "déculottant": "déculotter",
    "déculottas": "déculotter",
    "déculottasse": "déculotter",
    "déculottassent": "déculotter",
    "déculottasses": "déculotter",
    "déculottassiez": "déculotter",
    "déculottassions": "déculotter",
    "déculotte": "déculotter",
    "déculottent": "déculotter",
    "déculottera": "déculotter",
    "déculotterai": "déculotter",
    "déculotteraient": "déculotter",
    "déculotterais": "déculotter",
    "déculotterait": "déculotter",
    "déculotteras": "déculotter",
    "déculotterez": "déculotter",
    "déculotteriez": "déculotter",
    "déculotterions": "déculotter",
    "déculotterons": "déculotter",
    "déculotteront": "déculotter",
    "déculottes": "déculotter",
    "déculottez": "déculotter",
    "déculottiez": "déculotter",
    "déculottions": "déculotter",
    "déculottons": "déculotter",
    "déculottâmes": "déculotter",
    "déculottât": "déculotter",
    "déculottâtes": "déculotter",
    "déculottèrent": "déculotter",
    "déculotté": "déculotter",
    "déculottée": "déculotter",
    "déculottées": "déculotter",
    "déculottés": "déculotter",
    "déculpabilisait": "déculpabiliser",
    "déculpabilisé": "déculpabiliser",
    "décupla": "décupler",
    "décuplaient": "décupler",
    "décuplait": "décupler",
    "décuplant": "décupler",
    "décuple": "décupler",
    "décuplent": "décupler",
    "décuplera": "décupler",
    "décuplerait": "décupler",
    "décuples": "décuple",
    "décuplèrent": "décupler",
    "décuplé": "décupler",
    "décuplée": "décupler",
    "décuplées": "décupler",
    "décuplés": "décupler",
    "décurions": "décurion",
    "décuscuteuses": "décuscuteuse",
    "décuva": "décuver",
    "décuvai": "décuver",
    "décuvaient": "décuver",
    "décuvais": "décuver",
    "décuvait": "décuver",
    "décuvant": "décuver",
    "décuvas": "décuver",
    "décuvasse": "décuver",
    "décuvassent": "décuver",
    "décuvasses": "décuver",
    "décuvassiez": "décuver",
    "décuvassions": "décuver",
    "décuve": "décuver",
    "décuvent": "décuver",
    "décuvera": "décuver",
    "décuverai": "décuver",
    "décuveraient": "décuver",
    "décuverais": "décuver",
    "décuverait": "décuver",
    "décuveras": "décuver",
    "décuverez": "décuver",
    "décuveriez": "décuver",
    "décuverions": "décuver",
    "décuverons": "décuver",
    "décuveront": "décuver",
    "décuves": "décuver",
    "décuvez": "décuver",
    "décuviez": "décuver",
    "décuvions": "décuver",
    "décuvons": "décuver",
    "décuvâmes": "décuver",
    "décuvât": "décuver",
    "décuvâtes": "décuver",
    "décuvèrent": "décuver",
    "décuvé": "décuver",
    "décuvée": "décuver",
    "décuvées": "décuver",
    "décuvés": "décuver",
    "décède": "décéder",
    "décèdent": "décéder",
    "décèdes": "décéder",
    "décèle": "déceler",
    "décèlent": "déceler",
    "décèlera": "déceler",
    "décèlerai": "déceler",
    "décèleraient": "déceler",
    "décèlerais": "déceler",
    "décèlerait": "déceler",
    "décèleras": "déceler",
    "décèlerez": "déceler",
    "décèleriez": "déceler",
    "décèlerions": "déceler",
    "décèlerons": "déceler",
    "décèleront": "déceler",
    "décèles": "déceler",
    "décéda": "décéder",
    "décédai": "décéder",
    "décédaient": "décéder",
    "décédais": "décéder",
    "décédait": "décéder",
    "décédant": "décéder",
    "décédas": "décéder",
    "décédasse": "décéder",
    "décédassent": "décéder",
    "décédasses": "décéder",
    "décédassiez": "décéder",
    "décédassions": "décéder",
    "décédera": "décéder",
    "décéderai": "décéder",
    "décéderaient": "décéder",
    "décéderais": "décéder",
    "décéderait": "décéder",
    "décéderas": "décéder",
    "décéderez": "décéder",
    "décéderiez": "décéder",
    "décéderions": "décéder",
    "décéderons": "décéder",
    "décéderont": "décéder",
    "décédez": "décéder",
    "décédiez": "décéder",
    "décédions": "décéder",
    "décédons": "décéder",
    "décédâmes": "décéder",
    "décédât": "décéder",
    "décédâtes": "décéder",
    "décédèrent": "décéder",
    "décédé": "décéder",
    "décédée": "décéder",
    "décédées": "décéder",
    "décédés": "décéder",
    "décélère": "décélérer",
    "décélèrent": "décélérer",
    "décélères": "décélérer",
    "décéléra": "décélérer",
    "décélérai": "décélérer",
    "décéléraient": "décélérer",
    "décélérais": "décélérer",
    "décélérait": "décélérer",
    "décélérant": "décélérer",
    "décéléras": "décélérer",
    "décélérasse": "décélérer",
    "décélérassent": "décélérer",
    "décélérasses": "décélérer",
    "décélérassiez": "décélérer",
    "décélérassions": "décélérer",
    "décélérera": "décélérer",
    "décélérerai": "décélérer",
    "décéléreraient": "décélérer",
    "décélérerais": "décélérer",
    "décélérerait": "décélérer",
    "décéléreras": "décélérer",
    "décélérerez": "décélérer",
    "décéléreriez": "décélérer",
    "décélérerions": "décélérer",
    "décélérerons": "décélérer",
    "décéléreront": "décélérer",
    "décélérez": "décélérer",
    "décélériez": "décélérer",
    "décélérions": "décélérer",
    "décélérons": "décélérer",
    "décélérâmes": "décélérer",
    "décélérât": "décélérer",
    "décélérâtes": "décélérer",
    "décélérèrent": "décélérer",
    "décéléré": "décélérer",
    "décérébré": "décérébrer",
    "décérébrée": "décérébrer",
    "décérébrés": "décérébrer",
    "dédaigna": "dédaigner",
    "dédaignables": "dédaignable",
    "dédaignai": "dédaigner",
    "dédaignaient": "dédaigner",
    "dédaignais": "dédaigner",
    "dédaignait": "dédaigner",
    "dédaignant": "dédaigner",
    "dédaignas": "dédaigner",
    "dédaignasse": "dédaigner",
    "dédaignassent": "dédaigner",
    "dédaignasses": "dédaigner",
    "dédaignassiez": "dédaigner",
    "dédaignassions": "dédaigner",
    "dédaigne": "dédaigner",
    "dédaignent": "dédaigner",
    "dédaignera": "dédaigner",
    "dédaignerai": "dédaigner",
    "dédaigneraient": "dédaigner",
    "dédaignerais": "dédaigner",
    "dédaignerait": "dédaigner",
    "dédaigneras": "dédaigner",
    "dédaignerez": "dédaigner",
    "dédaigneriez": "dédaigner",
    "dédaignerions": "dédaigner",
    "dédaignerons": "dédaigner",
    "dédaigneront": "dédaigner",
    "dédaignes": "dédaigner",
    "dédaigneuse": "dédaigneux",
    "dédaigneuses": "dédaigneux",
    "dédaignez": "dédaigner",
    "dédaigniez": "dédaigner",
    "dédaignions": "dédaigner",
    "dédaignons": "dédaigner",
    "dédaignâmes": "dédaigner",
    "dédaignât": "dédaigner",
    "dédaignâtes": "dédaigner",
    "dédaignèrent": "dédaigner",
    "dédaigné": "dédaigner",
    "dédaignée": "dédaigner",
    "dédaignées": "dédaigner",
    "dédaignés": "dédaigner",
    "dédains": "dédain",
    "dédales": "dédale",
    "dédia": "dédier",
    "dédiai": "dédier",
    "dédiaient": "dédier",
    "dédiais": "dédier",
    "dédiait": "dédier",
    "dédiant": "dédier",
    "dédias": "dédier",
    "dédiasse": "dédier",
    "dédiassent": "dédier",
    "dédiasses": "dédier",
    "dédiassiez": "dédier",
    "dédiassions": "dédier",
    "dédicace": "dédicacer",
    "dédicacerai": "dédicacer",
    "dédicaces": "dédicacer",
    "dédicacez": "dédicacer",
    "dédicaciez": "dédicacer",
    "dédicacé": "dédicacer",
    "dédicacée": "dédicacer",
    "dédicacées": "dédicacer",
    "dédicacés": "dédicacer",
    "dédicatoires": "dédicatoire",
    "dédicaça": "dédicacer",
    "dédicaçait": "dédicacer",
    "dédie": "dédier",
    "dédient": "dédier",
    "dédiera": "dédier",
    "dédierai": "dédier",
    "dédieraient": "dédier",
    "dédierais": "dédier",
    "dédierait": "dédier",
    "dédieras": "dédier",
    "dédierez": "dédier",
    "dédieriez": "dédier",
    "dédierions": "dédier",
    "dédierons": "dédier",
    "dédieront": "dédier",
    "dédies": "dédier",
    "dédiez": "dédier",
    "dédiiez": "dédier",
    "dédiions": "dédier",
    "dédions": "dédier",
    "dédira": "dédire",
    "dédirai": "dédire",
    "dédiraient": "dédire",
    "dédirais": "dédire",
    "dédirait": "dédire",
    "dédiras": "dédire",
    "dédirent": "dédire",
    "dédirez": "dédire",
    "dédiriez": "dédire",
    "dédirions": "dédire",
    "dédirons": "dédire",
    "dédiront": "dédire",
    "dédis": "dédire",
    "dédisaient": "dédire",
    "dédisais": "dédire",
    "dédisait": "dédire",
    "dédisant": "dédire",
    "dédise": "dédire",
    "dédisent": "dédire",
    "dédises": "dédire",
    "dédisez": "dédire",
    "dédisiez": "dédire",
    "dédisions": "dédire",
    "dédisons": "dédire",
    "dédisse": "dédire",
    "dédissent": "dédire",
    "dédisses": "dédire",
    "dédissiez": "dédire",
    "dédissions": "dédire",
    "dédit": "dédire",
    "dédite": "dédire",
    "dédites": "dédire",
    "dédits": "dédit",
    "dédiâmes": "dédier",
    "dédiât": "dédier",
    "dédiâtes": "dédier",
    "dédièrent": "dédier",
    "dédié": "dédier",
    "dédiée": "dédier",
    "dédiées": "dédier",
    "dédiés": "dédier",
    "dédommage": "dédommager",
    "dédommagea": "dédommager",
    "dédommageai": "dédommager",
    "dédommageaient": "dédommager",
    "dédommageais": "dédommager",
    "dédommageait": "dédommager",
    "dédommageant": "dédommager",
    "dédommageas": "dédommager",
    "dédommageasse": "dédommager",
    "dédommageassent": "dédommager",
    "dédommageasses": "dédommager",
    "dédommageassiez": "dédommager",
    "dédommageassions": "dédommager",
    "dédommagements": "dédommagement",
    "dédommagent": "dédommager",
    "dédommageons": "dédommager",
    "dédommagera": "dédommager",
    "dédommagerai": "dédommager",
    "dédommageraient": "dédommager",
    "dédommagerais": "dédommager",
    "dédommagerait": "dédommager",
    "dédommageras": "dédommager",
    "dédommagerez": "dédommager",
    "dédommageriez": "dédommager",
    "dédommagerions": "dédommager",
    "dédommagerons": "dédommager",
    "dédommageront": "dédommager",
    "dédommages": "dédommager",
    "dédommagez": "dédommager",
    "dédommageâmes": "dédommager",
    "dédommageât": "dédommager",
    "dédommageâtes": "dédommager",
    "dédommagiez": "dédommager",
    "dédommagions": "dédommager",
    "dédommagèrent": "dédommager",
    "dédommagé": "dédommager",
    "dédommagée": "dédommager",
    "dédommagées": "dédommager",
    "dédommagés": "dédommager",
    "dédora": "dédorer",
    "dédorai": "dédorer",
    "dédoraient": "dédorer",
    "dédorais": "dédorer",
    "dédorait": "dédorer",
    "dédorant": "dédorer",
    "dédoras": "dédorer",
    "dédorasse": "dédorer",
    "dédorassent": "dédorer",
    "dédorasses": "dédorer",
    "dédorassiez": "dédorer",
    "dédorassions": "dédorer",
    "dédore": "dédorer",
    "dédorent": "dédorer",
    "dédorera": "dédorer",
    "dédorerai": "dédorer",
    "dédoreraient": "dédorer",
    "dédorerais": "dédorer",
    "dédorerait": "dédorer",
    "dédoreras": "dédorer",
    "dédorerez": "dédorer",
    "dédoreriez": "dédorer",
    "dédorerions": "dédorer",
    "dédorerons": "dédorer",
    "dédoreront": "dédorer",
    "dédores": "dédorer",
    "dédorez": "dédorer",
    "dédoriez": "dédorer",
    "dédorions": "dédorer",
    "dédorons": "dédorer",
    "dédorâmes": "dédorer",
    "dédorât": "dédorer",
    "dédorâtes": "dédorer",
    "dédorèrent": "dédorer",
    "dédoré": "dédorer",
    "dédorée": "dédorer",
    "dédorées": "dédorer",
    "dédorés": "dédorer",
    "dédouana": "dédouaner",
    "dédouanai": "dédouaner",
    "dédouanaient": "dédouaner",
    "dédouanais": "dédouaner",
    "dédouanait": "dédouaner",
    "dédouanant": "dédouaner",
    "dédouanas": "dédouaner",
    "dédouanasse": "dédouaner",
    "dédouanassent": "dédouaner",
    "dédouanasses": "dédouaner",
    "dédouanassiez": "dédouaner",
    "dédouanassions": "dédouaner",
    "dédouane": "dédouaner",
    "dédouanements": "dédouanement",
    "dédouanent": "dédouaner",
    "dédouanera": "dédouaner",
    "dédouanerai": "dédouaner",
    "dédouaneraient": "dédouaner",
    "dédouanerais": "dédouaner",
    "dédouanerait": "dédouaner",
    "dédouaneras": "dédouaner",
    "dédouanerez": "dédouaner",
    "dédouaneriez": "dédouaner",
    "dédouanerions": "dédouaner",
    "dédouanerons": "dédouaner",
    "dédouaneront": "dédouaner",
    "dédouanes": "dédouaner",
    "dédouanez": "dédouaner",
    "dédouaniez": "dédouaner",
    "dédouanions": "dédouaner",
    "dédouanons": "dédouaner",
    "dédouanâmes": "dédouaner",
    "dédouanât": "dédouaner",
    "dédouanâtes": "dédouaner",
    "dédouanèrent": "dédouaner",
    "dédouané": "dédouaner",
    "dédouanée": "dédouaner",
    "dédouanées": "dédouaner",
    "dédouanés": "dédouaner",
    "dédoubla": "dédoubler",
    "dédoublai": "dédoubler",
    "dédoublaient": "dédoubler",
    "dédoublais": "dédoubler",
    "dédoublait": "dédoubler",
    "dédoublant": "dédoubler",
    "dédoublas": "dédoubler",
    "dédoublasse": "dédoubler",
    "dédoublassent": "dédoubler",
    "dédoublasses": "dédoubler",
    "dédoublassiez": "dédoubler",
    "dédoublassions": "dédoubler",
    "dédouble": "dédoubler",
    "dédoublements": "dédoublement",
    "dédoublent": "dédoubler",
    "dédoublera": "dédoubler",
    "dédoublerai": "dédoubler",
    "dédoubleraient": "dédoubler",
    "dédoublerais": "dédoubler",
    "dédoublerait": "dédoubler",
    "dédoubleras": "dédoubler",
    "dédoublerez": "dédoubler",
    "dédoubleriez": "dédoubler",
    "dédoublerions": "dédoubler",
    "dédoublerons": "dédoubler",
    "dédoubleront": "dédoubler",
    "dédoubles": "dédoubler",
    "dédoublez": "dédoubler",
    "dédoubliez": "dédoubler",
    "dédoublions": "dédoubler",
    "dédoublons": "dédoubler",
    "dédoublâmes": "dédoubler",
    "dédoublât": "dédoubler",
    "dédoublâtes": "dédoubler",
    "dédoublèrent": "dédoubler",
    "dédoublé": "dédoubler",
    "dédoublée": "dédoubler",
    "dédoublées": "dédoubler",
    "dédoublés": "dédoubler",
    "dédramatisa": "dédramatiser",
    "dédramatisai": "dédramatiser",
    "dédramatisaient": "dédramatiser",
    "dédramatisais": "dédramatiser",
    "dédramatisait": "dédramatiser",
    "dédramatisant": "dédramatiser",
    "dédramatisas": "dédramatiser",
    "dédramatisasse": "dédramatiser",
    "dédramatisassent": "dédramatiser",
    "dédramatisasses": "dédramatiser",
    "dédramatisassiez": "dédramatiser",
    "dédramatisassions": "dédramatiser",
    "dédramatisations": "dédramatisation",
    "dédramatise": "dédramatiser",
    "dédramatisent": "dédramatiser",
    "dédramatisera": "dédramatiser",
    "dédramatiserai": "dédramatiser",
    "dédramatiseraient": "dédramatiser",
    "dédramatiserais": "dédramatiser",
    "dédramatiserait": "dédramatiser",
    "dédramatiseras": "dédramatiser",
    "dédramatiserez": "dédramatiser",
    "dédramatiseriez": "dédramatiser",
    "dédramatiserions": "dédramatiser",
    "dédramatiserons": "dédramatiser",
    "dédramatiseront": "dédramatiser",
    "dédramatises": "dédramatiser",
    "dédramatisez": "dédramatiser",
    "dédramatisiez": "dédramatiser",
    "dédramatisions": "dédramatiser",
    "dédramatisons": "dédramatiser",
    "dédramatisâmes": "dédramatiser",
    "dédramatisât": "dédramatiser",
    "dédramatisâtes": "dédramatiser",
    "dédramatisèrent": "dédramatiser",
    "dédramatisé": "dédramatiser",
    "dédramatisée": "dédramatiser",
    "dédramatisées": "dédramatiser",
    "dédramatisés": "dédramatiser",
    "déductibilités": "déductibilité",
    "déductibles": "déductible",
    "déductions": "déduction",
    "déductive": "déductif",
    "déduira": "déduire",
    "déduirai": "déduire",
    "déduiraient": "déduire",
    "déduirais": "déduire",
    "déduirait": "déduire",
    "déduiras": "déduire",
    "déduirez": "déduire",
    "déduiriez": "déduire",
    "déduirions": "déduire",
    "déduirons": "déduire",
    "déduiront": "déduire",
    "déduis": "déduire",
    "déduisaient": "déduire",
    "déduisais": "déduire",
    "déduisait": "déduire",
    "déduisant": "déduire",
    "déduise": "déduire",
    "déduisent": "déduire",
    "déduises": "déduire",
    "déduisez": "déduire",
    "déduisiez": "déduire",
    "déduisions": "déduire",
    "déduisirent": "déduire",
    "déduisis": "déduire",
    "déduisisse": "déduire",
    "déduisissent": "déduire",
    "déduisisses": "déduire",
    "déduisissiez": "déduire",
    "déduisissions": "déduire",
    "déduisit": "déduire",
    "déduisons": "déduire",
    "déduisîmes": "déduire",
    "déduisît": "déduire",
    "déduisîtes": "déduire",
    "déduit": "déduire",
    "déduite": "déduire",
    "déduites": "déduire",
    "déduits": "déduire",
    "dédîmes": "dédire",
    "dédît": "dédire",
    "dédîtes": "dédire",
    "déesse": "dieu",
    "déesses": "dieu",
    "défaillaient": "défaillir",
    "défaillais": "défaillir",
    "défaillait": "défaillir",
    "défaillances": "défaillance",
    "défaillant": "défaillir",
    "défaillante": "défaillant",
    "défaillantes": "défaillant",
    "défaillants": "défaillant",
    "défaille": "défaillir",
    "défaillent": "défaillir",
    "défailles": "défaillir",
    "défaillez": "défaillir",
    "défailli": "défaillir",
    "défailliez": "défaillir",
    "défaillions": "défaillir",
    "défaillira": "défaillir",
    "défaillirai": "défaillir",
    "défailliraient": "défaillir",
    "défaillirais": "défaillir",
    "défaillirait": "défaillir",
    "défailliras": "défaillir",
    "défaillirent": "défaillir",
    "défaillirez": "défaillir",
    "défailliriez": "défaillir",
    "défaillirions": "défaillir",
    "défaillirons": "défaillir",
    "défailliront": "défaillir",
    "défaillis": "défaillir",
    "défaillisse": "défaillir",
    "défaillissent": "défaillir",
    "défaillisses": "défaillir",
    "défaillissiez": "défaillir",
    "défaillissions": "défaillir",
    "défaillit": "défaillir",
    "défaillons": "défaillir",
    "défaillîmes": "défaillir",
    "défaillît": "défaillir",
    "défaillîtes": "défaillir",
    "défais": "défaire",
    "défaisaient": "défaire",
    "défaisais": "défaire",
    "défaisait": "défaire",
    "défaisant": "défaire",
    "défaisiez": "défaire",
    "défaisions": "défaire",
    "défaisons": "défaire",
    "défait": "défaire",
    "défaite": "défait",
    "défaites": "défaite",
    "défaitistes": "défaitiste",
    "défaits": "défait",
    "défalcations": "défalcation",
    "défalqua": "défalquer",
    "défalquai": "défalquer",
    "défalquaient": "défalquer",
    "défalquais": "défalquer",
    "défalquait": "défalquer",
    "défalquant": "défalquer",
    "défalquas": "défalquer",
    "défalquasse": "défalquer",
    "défalquassent": "défalquer",
    "défalquasses": "défalquer",
    "défalquassiez": "défalquer",
    "défalquassions": "défalquer",
    "défalque": "défalquer",
    "défalquent": "défalquer",
    "défalquera": "défalquer",
    "défalquerai": "défalquer",
    "défalqueraient": "défalquer",
    "défalquerais": "défalquer",
    "défalquerait": "défalquer",
    "défalqueras": "défalquer",
    "défalquerez": "défalquer",
    "défalqueriez": "défalquer",
    "défalquerions": "défalquer",
    "défalquerons": "défalquer",
    "défalqueront": "défalquer",
    "défalques": "défalquer",
    "défalquez": "défalquer",
    "défalquiez": "défalquer",
    "défalquions": "défalquer",
    "défalquons": "défalquer",
    "défalquâmes": "défalquer",
    "défalquât": "défalquer",
    "défalquâtes": "défalquer",
    "défalquèrent": "défalquer",
    "défalqué": "défalquer",
    "défalquée": "défalquer",
    "défalquées": "défalquer",
    "défalqués": "défalquer",
    "défarguaient": "défarguer",
    "défargue": "défarguer",
    "défargué": "défarguer",
    "défasse": "défaire",
    "défassent": "défaire",
    "défasses": "défaire",
    "défassiez": "défaire",
    "défassions": "défaire",
    "défatigante": "défatigant",
    "défatigantes": "défatigant",
    "défatigants": "défatigant",
    "défatigua": "défatiguer",
    "défatiguai": "défatiguer",
    "défatiguaient": "défatiguer",
    "défatiguais": "défatiguer",
    "défatiguait": "défatiguer",
    "défatiguant": "défatiguer",
    "défatiguas": "défatiguer",
    "défatiguasse": "défatiguer",
    "défatiguassent": "défatiguer",
    "défatiguasses": "défatiguer",
    "défatiguassiez": "défatiguer",
    "défatiguassions": "défatiguer",
    "défatigue": "défatiguer",
    "défatiguent": "défatiguer",
    "défatiguera": "défatiguer",
    "défatiguerai": "défatiguer",
    "défatigueraient": "défatiguer",
    "défatiguerais": "défatiguer",
    "défatiguerait": "défatiguer",
    "défatigueras": "défatiguer",
    "défatiguerez": "défatiguer",
    "défatigueriez": "défatiguer",
    "défatiguerions": "défatiguer",
    "défatiguerons": "défatiguer",
    "défatigueront": "défatiguer",
    "défatigues": "défatiguer",
    "défatiguez": "défatiguer",
    "défatiguiez": "défatiguer",
    "défatiguions": "défatiguer",
    "défatiguons": "défatiguer",
    "défatiguâmes": "défatiguer",
    "défatiguât": "défatiguer",
    "défatiguâtes": "défatiguer",
    "défatiguèrent": "défatiguer",
    "défatigué": "défatiguer",
    "défatiguée": "défatiguer",
    "défatiguées": "défatiguer",
    "défatigués": "défatiguer",
    "défaussa": "défausser",
    "défaussai": "défausser",
    "défaussaient": "défausser",
    "défaussais": "défausser",
    "défaussait": "défausser",
    "défaussant": "défausser",
    "défaussas": "défausser",
    "défaussasse": "défausser",
    "défaussassent": "défausser",
    "défaussasses": "défausser",
    "défaussassiez": "défausser",
    "défaussassions": "défausser",
    "défausse": "défausser",
    "défaussent": "défausser",
    "défaussera": "défausser",
    "défausserai": "défausser",
    "défausseraient": "défausser",
    "défausserais": "défausser",
    "défausserait": "défausser",
    "défausseras": "défausser",
    "défausserez": "défausser",
    "défausseriez": "défausser",
    "défausserions": "défausser",
    "défausserons": "défausser",
    "défausseront": "défausser",
    "défausses": "défausser",
    "défaussez": "défausser",
    "défaussiez": "défausser",
    "défaussions": "défausser",
    "défaussons": "défausser",
    "défaussâmes": "défausser",
    "défaussât": "défausser",
    "défaussâtes": "défausser",
    "défaussèrent": "défausser",
    "défaussé": "défausser",
    "défaussée": "défausser",
    "défaussées": "défausser",
    "défaussés": "défausser",
    "défauts": "défaut",
    "défaveurs": "défaveur",
    "défavorables": "défavorable",
    "défavorisa": "défavoriser",
    "défavorisai": "défavoriser",
    "défavorisaient": "défavoriser",
    "défavorisais": "défavoriser",
    "défavorisait": "défavoriser",
    "défavorisant": "défavoriser",
    "défavorisas": "défavoriser",
    "défavorisasse": "défavoriser",
    "défavorisassent": "défavoriser",
    "défavorisasses": "défavoriser",
    "défavorisassiez": "défavoriser",
    "défavorisassions": "défavoriser",
    "défavorise": "défavoriser",
    "défavorisent": "défavoriser",
    "défavorisera": "défavoriser",
    "défavoriserai": "défavoriser",
    "défavoriseraient": "défavoriser",
    "défavoriserais": "défavoriser",
    "défavoriserait": "défavoriser",
    "défavoriseras": "défavoriser",
    "défavoriserez": "défavoriser",
    "défavoriseriez": "défavoriser",
    "défavoriserions": "défavoriser",
    "défavoriserons": "défavoriser",
    "défavoriseront": "défavoriser",
    "défavorises": "défavoriser",
    "défavorisez": "défavoriser",
    "défavorisiez": "défavoriser",
    "défavorisions": "défavoriser",
    "défavorisons": "défavoriser",
    "défavorisâmes": "défavoriser",
    "défavorisât": "défavoriser",
    "défavorisâtes": "défavoriser",
    "défavorisèrent": "défavoriser",
    "défavorisé": "défavoriser",
    "défavorisée": "défavoriser",
    "défavorisées": "défavoriser",
    "défavorisés": "défavoriser",
    "défectifs": "défectif",
    "défectionnaires": "défectionnaire",
    "défections": "défection",
    "défective": "défectif",
    "défectives": "défectif",
    "défectueuse": "défectueux",
    "défectueuses": "défectueux",
    "défectuosités": "défectuosité",
    "défend": "défendre",
    "défendables": "défendable",
    "défendaient": "défendre",
    "défendais": "défendre",
    "défendait": "défendre",
    "défendant": "défendre",
    "défende": "défendre",
    "défendent": "défendre",
    "défenderesse": "défendeur",
    "défenderesses": "défendeur",
    "défendes": "défendre",
    "défendeurs": "défendeur",
    "défendez": "défendre",
    "défendiez": "défendre",
    "défendions": "défendre",
    "défendirent": "défendre",
    "défendis": "défendre",
    "défendisse": "défendre",
    "défendissent": "défendre",
    "défendisses": "défendre",
    "défendissiez": "défendre",
    "défendissions": "défendre",
    "défendit": "défendre",
    "défendons": "défendre",
    "défendra": "défendre",
    "défendrai": "défendre",
    "défendraient": "défendre",
    "défendrais": "défendre",
    "défendrait": "défendre",
    "défendras": "défendre",
    "défendrez": "défendre",
    "défendriez": "défendre",
    "défendrions": "défendre",
    "défendrons": "défendre",
    "défendront": "défendre",
    "défends": "défendre",
    "défendu": "défendre",
    "défendue": "défendu",
    "défendues": "défendu",
    "défendus": "défendu",
    "défendîmes": "défendre",
    "défendît": "défendre",
    "défendîtes": "défendre",
    "défenestra": "défenestrer",
    "défenestrai": "défenestrer",
    "défenestraient": "défenestrer",
    "défenestrais": "défenestrer",
    "défenestrait": "défenestrer",
    "défenestrant": "défenestrer",
    "défenestras": "défenestrer",
    "défenestrasse": "défenestrer",
    "défenestrassent": "défenestrer",
    "défenestrasses": "défenestrer",
    "défenestrassiez": "défenestrer",
    "défenestrassions": "défenestrer",
    "défenestre": "défenestrer",
    "défenestrent": "défenestrer",
    "défenestrera": "défenestrer",
    "défenestrerai": "défenestrer",
    "défenestreraient": "défenestrer",
    "défenestrerais": "défenestrer",
    "défenestrerait": "défenestrer",
    "défenestreras": "défenestrer",
    "défenestrerez": "défenestrer",
    "défenestreriez": "défenestrer",
    "défenestrerions": "défenestrer",
    "défenestrerons": "défenestrer",
    "défenestreront": "défenestrer",
    "défenestres": "défenestrer",
    "défenestrez": "défenestrer",
    "défenestriez": "défenestrer",
    "défenestrions": "défenestrer",
    "défenestrons": "défenestrer",
    "défenestrâmes": "défenestrer",
    "défenestrât": "défenestrer",
    "défenestrâtes": "défenestrer",
    "défenestrèrent": "défenestrer",
    "défenestré": "défenestrer",
    "défenestrée": "défenestrer",
    "défenestrées": "défenestrer",
    "défenestrés": "défenestrer",
    "défenses": "défense",
    "défenseurs": "défenseur",
    "défenseuse": "défenseur",
    "défenseuses": "défenseur",
    "défensifs": "défensif",
    "défensive": "défensif",
    "défensives": "défensive",
    "défera": "défaire",
    "déferai": "défaire",
    "déferaient": "défaire",
    "déferais": "défaire",
    "déferait": "défaire",
    "déferas": "défaire",
    "déferez": "défaire",
    "déferiez": "défaire",
    "déferions": "défaire",
    "déferla": "déferler",
    "déferlai": "déferler",
    "déferlaient": "déferler",
    "déferlais": "déferler",
    "déferlait": "déferler",
    "déferlant": "déferler",
    "déferlante": "déferlant",
    "déferlantes": "déferlante",
    "déferlas": "déferler",
    "déferlasse": "déferler",
    "déferlassent": "déferler",
    "déferlasses": "déferler",
    "déferlassiez": "déferler",
    "déferlassions": "déferler",
    "déferle": "déferler",
    "déferlements": "déferlement",
    "déferlent": "déferler",
    "déferlera": "déferler",
    "déferlerai": "déferler",
    "déferleraient": "déferler",
    "déferlerais": "déferler",
    "déferlerait": "déferler",
    "déferleras": "déferler",
    "déferlerez": "déferler",
    "déferleriez": "déferler",
    "déferlerions": "déferler",
    "déferlerons": "déferler",
    "déferleront": "déferler",
    "déferles": "déferler",
    "déferlez": "déferler",
    "déferliez": "déferler",
    "déferlions": "déferler",
    "déferlons": "déferler",
    "déferlâmes": "déferler",
    "déferlât": "déferler",
    "déferlâtes": "déferler",
    "déferlèrent": "déferler",
    "déferlé": "déferler",
    "déferlée": "déferler",
    "déferlées": "déferler",
    "déferlés": "déferler",
    "déferons": "défaire",
    "déferont": "défaire",
    "déferra": "déferrer",
    "déferrai": "déferrer",
    "déferraient": "déferrer",
    "déferrais": "déferrer",
    "déferrait": "déferrer",
    "déferrant": "déferrer",
    "déferras": "déferrer",
    "déferrasse": "déferrer",
    "déferrassent": "déferrer",
    "déferrasses": "déferrer",
    "déferrassiez": "déferrer",
    "déferrassions": "déferrer",
    "déferre": "déferrer",
    "déferrent": "déferrer",
    "déferrera": "déferrer",
    "déferrerai": "déferrer",
    "déferreraient": "déferrer",
    "déferrerais": "déferrer",
    "déferrerait": "déferrer",
    "déferreras": "déferrer",
    "déferrerez": "déferrer",
    "déferreriez": "déferrer",
    "déferrerions": "déferrer",
    "déferrerons": "déferrer",
    "déferreront": "déferrer",
    "déferres": "déferrer",
    "déferrez": "déferrer",
    "déferriez": "déferrer",
    "déferrions": "déferrer",
    "déferrons": "déferrer",
    "déferrâmes": "déferrer",
    "déferrât": "déferrer",
    "déferrâtes": "déferrer",
    "déferrèrent": "déferrer",
    "déferré": "déferrer",
    "déferrée": "déferrer",
    "déferrées": "déferrer",
    "déferrés": "déferrer",
    "défeuilla": "défeuiller",
    "défeuillai": "défeuiller",
    "défeuillaient": "défeuiller",
    "défeuillais": "défeuiller",
    "défeuillait": "défeuiller",
    "défeuillant": "défeuiller",
    "défeuillas": "défeuiller",
    "défeuillasse": "défeuiller",
    "défeuillassent": "défeuiller",
    "défeuillasses": "défeuiller",
    "défeuillassiez": "défeuiller",
    "défeuillassions": "défeuiller",
    "défeuille": "défeuiller",
    "défeuillent": "défeuiller",
    "défeuillera": "défeuiller",
    "défeuillerai": "défeuiller",
    "défeuilleraient": "défeuiller",
    "défeuillerais": "défeuiller",
    "défeuillerait": "défeuiller",
    "défeuilleras": "défeuiller",
    "défeuillerez": "défeuiller",
    "défeuilleriez": "défeuiller",
    "défeuillerions": "défeuiller",
    "défeuillerons": "défeuiller",
    "défeuilleront": "défeuiller",
    "défeuilles": "défeuiller",
    "défeuillez": "défeuiller",
    "défeuilliez": "défeuiller",
    "défeuillions": "défeuiller",
    "défeuillons": "défeuiller",
    "défeuillâmes": "défeuiller",
    "défeuillât": "défeuiller",
    "défeuillâtes": "défeuiller",
    "défeuillèrent": "défeuiller",
    "défeuillé": "défeuiller",
    "défeuillée": "défeuiller",
    "défeuillées": "défeuiller",
    "défeuillés": "défeuiller",
    "défia": "défier",
    "défiai": "défier",
    "défiaient": "défier",
    "défiais": "défier",
    "défiait": "défier",
    "défiances": "défiance",
    "défiant": "défier",
    "défiante": "défiant",
    "défiantes": "défiant",
    "défiants": "défiant",
    "défias": "défier",
    "défiasse": "défier",
    "défiassent": "défier",
    "défiasses": "défier",
    "défiassiez": "défier",
    "défiassions": "défier",
    "défibra": "défibrer",
    "défibrai": "défibrer",
    "défibraient": "défibrer",
    "défibrais": "défibrer",
    "défibrait": "défibrer",
    "défibrant": "défibrer",
    "défibras": "défibrer",
    "défibrasse": "défibrer",
    "défibrassent": "défibrer",
    "défibrasses": "défibrer",
    "défibrassiez": "défibrer",
    "défibrassions": "défibrer",
    "défibre": "défibrer",
    "défibrent": "défibrer",
    "défibrera": "défibrer",
    "défibrerai": "défibrer",
    "défibreraient": "défibrer",
    "défibrerais": "défibrer",
    "défibrerait": "défibrer",
    "défibreras": "défibrer",
    "défibrerez": "défibrer",
    "défibreriez": "défibrer",
    "défibrerions": "défibrer",
    "défibrerons": "défibrer",
    "défibreront": "défibrer",
    "défibres": "défibrer",
    "défibrez": "défibrer",
    "défibriez": "défibrer",
    "défibrillateurs": "défibrillateur",
    "défibrions": "défibrer",
    "défibrons": "défibrer",
    "défibrâmes": "défibrer",
    "défibrât": "défibrer",
    "défibrâtes": "défibrer",
    "défibrèrent": "défibrer",
    "défibré": "défibrer",
    "défibrée": "défibrer",
    "défibrées": "défibrer",
    "défibrés": "défibrer",
    "déficela": "déficeler",
    "déficelai": "déficeler",
    "déficelaient": "déficeler",
    "déficelais": "déficeler",
    "déficelait": "déficeler",
    "déficelant": "déficeler",
    "déficelas": "déficeler",
    "déficelasse": "déficeler",
    "déficelassent": "déficeler",
    "déficelasses": "déficeler",
    "déficelassiez": "déficeler",
    "déficelassions": "déficeler",
    "déficelez": "déficeler",
    "déficeliez": "déficeler",
    "déficelions": "déficeler",
    "déficelle": "déficeler",
    "déficellent": "déficeler",
    "déficellera": "déficeler",
    "déficellerai": "déficeler",
    "déficelleraient": "déficeler",
    "déficellerais": "déficeler",
    "déficellerait": "déficeler",
    "déficelleras": "déficeler",
    "déficellerez": "déficeler",
    "déficelleriez": "déficeler",
    "déficellerions": "déficeler",
    "déficellerons": "déficeler",
    "déficelleront": "déficeler",
    "déficelles": "déficeler",
    "déficelons": "déficeler",
    "déficelâmes": "déficeler",
    "déficelât": "déficeler",
    "déficelâtes": "déficeler",
    "déficelèrent": "déficeler",
    "déficelé": "déficeler",
    "déficelée": "déficeler",
    "déficelées": "déficeler",
    "déficelés": "déficeler",
    "déficiences": "déficience",
    "déficiente": "déficient",
    "déficientes": "déficient",
    "déficients": "déficient",
    "déficitaires": "déficitaire",
    "déficits": "déficit",
    "défie": "défier",
    "défient": "défier",
    "défiera": "défier",
    "défierai": "défier",
    "défieraient": "défier",
    "défierais": "défier",
    "défierait": "défier",
    "défieras": "défier",
    "défierez": "défier",
    "défieriez": "défier",
    "défierions": "défier",
    "défierons": "défier",
    "défieront": "défier",
    "défies": "défier",
    "défiez": "défier",
    "défigeait": "défiger",
    "défigura": "défigurer",
    "défigurai": "défigurer",
    "défiguraient": "défigurer",
    "défigurais": "défigurer",
    "défigurait": "défigurer",
    "défigurant": "défigurer",
    "défiguras": "défigurer",
    "défigurasse": "défigurer",
    "défigurassent": "défigurer",
    "défigurasses": "défigurer",
    "défigurassiez": "défigurer",
    "défigurassions": "défigurer",
    "défigurations": "défiguration",
    "défigure": "défigurer",
    "défigurent": "défigurer",
    "défigurera": "défigurer",
    "défigurerai": "défigurer",
    "défigureraient": "défigurer",
    "défigurerais": "défigurer",
    "défigurerait": "défigurer",
    "défigureras": "défigurer",
    "défigurerez": "défigurer",
    "défigureriez": "défigurer",
    "défigurerions": "défigurer",
    "défigurerons": "défigurer",
    "défigureront": "défigurer",
    "défigures": "défigurer",
    "défigurez": "défigurer",
    "défiguriez": "défigurer",
    "défigurions": "défigurer",
    "défigurons": "défigurer",
    "défigurâmes": "défigurer",
    "défigurât": "défigurer",
    "défigurâtes": "défigurer",
    "défigurèrent": "défigurer",
    "défiguré": "défigurer",
    "défigurée": "défigurer",
    "défigurées": "défigurer",
    "défigurés": "défigurer",
    "défiiez": "défier",
    "défiions": "défier",
    "défila": "défiler",
    "défilai": "défiler",
    "défilaient": "défiler",
    "défilais": "défiler",
    "défilait": "défiler",
    "défilant": "défiler",
    "défilantes": "défilant",
    "défilants": "défilant",
    "défilas": "défiler",
    "défilasse": "défiler",
    "défilassent": "défiler",
    "défilasses": "défiler",
    "défilassiez": "défiler",
    "défilassions": "défiler",
    "défile": "défiler",
    "défilements": "défilement",
    "défilent": "défiler",
    "défilera": "défiler",
    "défilerai": "défiler",
    "défileraient": "défiler",
    "défilerais": "défiler",
    "défilerait": "défiler",
    "défileras": "défiler",
    "défilerez": "défiler",
    "défileriez": "défiler",
    "défilerions": "défiler",
    "défilerons": "défiler",
    "défileront": "défiler",
    "défiles": "défiler",
    "défilez": "défiler",
    "défiliez": "défiler",
    "défilions": "défiler",
    "défilons": "défiler",
    "défilâmes": "défiler",
    "défilât": "défiler",
    "défilâtes": "défiler",
    "défilèrent": "défiler",
    "défilé": "défiler",
    "défilée": "défiler",
    "défilées": "défiler",
    "défilés": "défiler",
    "défini": "définir",
    "définie": "définir",
    "définies": "définir",
    "définira": "définir",
    "définirai": "définir",
    "définiraient": "définir",
    "définirais": "définir",
    "définirait": "définir",
    "définiras": "définir",
    "définirent": "définir",
    "définirez": "définir",
    "définiriez": "définir",
    "définirions": "définir",
    "définirons": "définir",
    "définiront": "définir",
    "définis": "définir",
    "définissables": "définissable",
    "définissaient": "définir",
    "définissais": "définir",
    "définissait": "définir",
    "définissant": "définir",
    "définisse": "définir",
    "définissent": "définir",
    "définisses": "définir",
    "définissez": "définir",
    "définissiez": "définir",
    "définissions": "définir",
    "définissons": "définir",
    "définit": "définir",
    "définitifs": "définitif",
    "définitions": "définition",
    "définitive": "définitif",
    "définitives": "définitif",
    "définîmes": "définir",
    "définît": "définir",
    "définîtes": "définir",
    "défions": "défier",
    "défirent": "défaire",
    "défis": "défi",
    "défiscalisations": "défiscalisation",
    "défiscalisé": "défiscaliser",
    "défisse": "défaire",
    "défissent": "défaire",
    "défisses": "défaire",
    "défissiez": "défaire",
    "défissions": "défaire",
    "défit": "défaire",
    "défiâmes": "défier",
    "défiât": "défier",
    "défiâtes": "défier",
    "défièrent": "défier",
    "défié": "défier",
    "défiée": "défier",
    "défiées": "défier",
    "défiés": "défier",
    "déflagrante": "déflagrant",
    "déflagrations": "déflagration",
    "déflationnistes": "déflationniste",
    "déflations": "déflation",
    "déflecteurs": "déflecteur",
    "défleuri": "défleurir",
    "défleurie": "défleurir",
    "défleuries": "défleurir",
    "défleurira": "défleurir",
    "défleurirai": "défleurir",
    "défleuriraient": "défleurir",
    "défleurirais": "défleurir",
    "défleurirait": "défleurir",
    "défleuriras": "défleurir",
    "défleurirent": "défleurir",
    "défleurirez": "défleurir",
    "défleuririez": "défleurir",
    "défleuririons": "défleurir",
    "défleurirons": "défleurir",
    "défleuriront": "défleurir",
    "défleuris": "défleurir",
    "défleurissaient": "défleurir",
    "défleurissais": "défleurir",
    "défleurissait": "défleurir",
    "défleurissant": "défleurir",
    "défleurisse": "défleurir",
    "défleurissent": "défleurir",
    "défleurisses": "défleurir",
    "défleurissez": "défleurir",
    "défleurissiez": "défleurir",
    "défleurissions": "défleurir",
    "défleurissons": "défleurir",
    "défleurit": "défleurir",
    "défleurîmes": "défleurir",
    "défleurît": "défleurir",
    "défleurîtes": "défleurir",
    "déflora": "déflorer",
    "déflorai": "déflorer",
    "défloraient": "déflorer",
    "déflorais": "déflorer",
    "défloraisons": "défloraison",
    "déflorait": "déflorer",
    "déflorant": "déflorer",
    "défloras": "déflorer",
    "déflorasse": "déflorer",
    "déflorassent": "déflorer",
    "déflorasses": "déflorer",
    "déflorassiez": "déflorer",
    "déflorassions": "déflorer",
    "déflore": "déflorer",
    "déflorent": "déflorer",
    "déflorera": "déflorer",
    "déflorerai": "déflorer",
    "défloreraient": "déflorer",
    "déflorerais": "déflorer",
    "déflorerait": "déflorer",
    "défloreras": "déflorer",
    "déflorerez": "déflorer",
    "défloreriez": "déflorer",
    "déflorerions": "déflorer",
    "déflorerons": "déflorer",
    "défloreront": "déflorer",
    "déflores": "déflorer",
    "déflorez": "déflorer",
    "défloriez": "déflorer",
    "déflorions": "déflorer",
    "déflorons": "déflorer",
    "déflorâmes": "déflorer",
    "déflorât": "déflorer",
    "déflorâtes": "déflorer",
    "déflorèrent": "déflorer",
    "défloré": "déflorer",
    "déflorée": "déflorer",
    "déflorées": "déflorer",
    "déflorés": "déflorer",
    "défolia": "défolier",
    "défoliai": "défolier",
    "défoliaient": "défolier",
    "défoliais": "défolier",
    "défoliait": "défolier",
    "défoliant": "défolier",
    "défolias": "défolier",
    "défoliasse": "défolier",
    "défoliassent": "défolier",
    "défoliasses": "défolier",
    "défoliassiez": "défolier",
    "défoliassions": "défolier",
    "défolie": "défolier",
    "défolient": "défolier",
    "défoliera": "défolier",
    "défolierai": "défolier",
    "défolieraient": "défolier",
    "défolierais": "défolier",
    "défolierait": "défolier",
    "défolieras": "défolier",
    "défolierez": "défolier",
    "défolieriez": "défolier",
    "défolierions": "défolier",
    "défolierons": "défolier",
    "défolieront": "défolier",
    "défolies": "défolier",
    "défoliez": "défolier",
    "défoliiez": "défolier",
    "défoliions": "défolier",
    "défolions": "défolier",
    "défoliâmes": "défolier",
    "défoliât": "défolier",
    "défoliâtes": "défolier",
    "défolièrent": "défolier",
    "défolié": "défolier",
    "défoliée": "défolier",
    "défoliées": "défolier",
    "défoliés": "défolier",
    "défonce": "défoncer",
    "défoncements": "défoncement",
    "défoncent": "défoncer",
    "défoncera": "défoncer",
    "défoncerai": "défoncer",
    "défonceraient": "défoncer",
    "défoncerais": "défoncer",
    "défoncerait": "défoncer",
    "défonceras": "défoncer",
    "défoncerez": "défoncer",
    "défonceriez": "défoncer",
    "défoncerions": "défoncer",
    "défoncerons": "défoncer",
    "défonceront": "défoncer",
    "défonces": "défoncer",
    "défoncez": "défoncer",
    "défonciez": "défoncer",
    "défoncions": "défoncer",
    "défoncèrent": "défoncer",
    "défoncé": "défoncer",
    "défoncée": "défoncer",
    "défoncées": "défoncer",
    "défoncés": "défoncer",
    "défont": "défaire",
    "défonça": "défoncer",
    "défonçai": "défoncer",
    "défonçaient": "défoncer",
    "défonçais": "défoncer",
    "défonçait": "défoncer",
    "défonçant": "défoncer",
    "défonças": "défoncer",
    "défonçasse": "défoncer",
    "défonçassent": "défoncer",
    "défonçasses": "défoncer",
    "défonçassiez": "défoncer",
    "défonçassions": "défoncer",
    "défonçons": "défoncer",
    "défonçâmes": "défoncer",
    "défonçât": "défoncer",
    "défonçâtes": "défoncer",
    "déforestations": "déforestation",
    "déforma": "déformer",
    "déformai": "déformer",
    "déformaient": "déformer",
    "déformais": "déformer",
    "déformait": "déformer",
    "déformant": "déformer",
    "déformante": "déformant",
    "déformantes": "déformant",
    "déformants": "déformant",
    "déformas": "déformer",
    "déformasse": "déformer",
    "déformassent": "déformer",
    "déformasses": "déformer",
    "déformassiez": "déformer",
    "déformassions": "déformer",
    "déformations": "déformation",
    "déforme": "déformer",
    "déforment": "déformer",
    "déformera": "déformer",
    "déformerai": "déformer",
    "déformeraient": "déformer",
    "déformerais": "déformer",
    "déformerait": "déformer",
    "déformeras": "déformer",
    "déformerez": "déformer",
    "déformeriez": "déformer",
    "déformerions": "déformer",
    "déformerons": "déformer",
    "déformeront": "déformer",
    "déformes": "déformer",
    "déformez": "déformer",
    "déformiez": "déformer",
    "déformions": "déformer",
    "déformons": "déformer",
    "déformâmes": "déformer",
    "déformât": "déformer",
    "déformâtes": "déformer",
    "déformèrent": "déformer",
    "déformé": "déformer",
    "déformée": "déformer",
    "déformées": "déformer",
    "déformés": "déformer",
    "défoula": "défouler",
    "défoulai": "défouler",
    "défoulaient": "défouler",
    "défoulais": "défouler",
    "défoulait": "défouler",
    "défoulant": "défouler",
    "défoulas": "défouler",
    "défoulasse": "défouler",
    "défoulassent": "défouler",
    "défoulasses": "défouler",
    "défoulassiez": "défouler",
    "défoulassions": "défouler",
    "défoule": "défouler",
    "défoulements": "défoulement",
    "défoulent": "défouler",
    "défoulera": "défouler",
    "défoulerai": "défouler",
    "défouleraient": "défouler",
    "défoulerais": "défouler",
    "défoulerait": "défouler",
    "défouleras": "défouler",
    "défoulerez": "défouler",
    "défouleriez": "défouler",
    "défoulerions": "défouler",
    "défoulerons": "défouler",
    "défouleront": "défouler",
    "défoules": "défouler",
    "défoulez": "défouler",
    "défouliez": "défouler",
    "défoulions": "défouler",
    "défoulons": "défouler",
    "défoulâmes": "défouler",
    "défoulât": "défouler",
    "défoulâtes": "défouler",
    "défoulèrent": "défouler",
    "défoulé": "défouler",
    "défoulée": "défouler",
    "défoulées": "défouler",
    "défoulés": "défouler",
    "défouraillaient": "défourailler",
    "défouraille": "défourailler",
    "défouraillent": "défourailler",
    "défouraillerait": "défourailler",
    "défouraillé": "défourailler",
    "défourna": "défourner",
    "défournait": "défourner",
    "défourra": "défourrer",
    "défourrai": "défourrer",
    "défourraient": "défourrer",
    "défourrais": "défourrer",
    "défourrait": "défourrer",
    "défourrant": "défourrer",
    "défourras": "défourrer",
    "défourrasse": "défourrer",
    "défourrassent": "défourrer",
    "défourrasses": "défourrer",
    "défourrassiez": "défourrer",
    "défourrassions": "défourrer",
    "défourre": "défourrer",
    "défourrent": "défourrer",
    "défourrera": "défourrer",
    "défourrerai": "défourrer",
    "défourreraient": "défourrer",
    "défourrerais": "défourrer",
    "défourrerait": "défourrer",
    "défourreras": "défourrer",
    "défourrerez": "défourrer",
    "défourreriez": "défourrer",
    "défourrerions": "défourrer",
    "défourrerons": "défourrer",
    "défourreront": "défourrer",
    "défourres": "défourrer",
    "défourrez": "défourrer",
    "défourriez": "défourrer",
    "défourrions": "défourrer",
    "défourrons": "défourrer",
    "défourrâmes": "défourrer",
    "défourrât": "défourrer",
    "défourrâtes": "défourrer",
    "défourrèrent": "défourrer",
    "défourré": "défourrer",
    "défourrée": "défourrer",
    "défourrées": "défourrer",
    "défourrés": "défourrer",
    "défraie": "défrayer",
    "défraiements": "défraiement",
    "défraient": "défrayer",
    "défraiera": "défrayer",
    "défraierai": "défrayer",
    "défraieraient": "défrayer",
    "défraierais": "défrayer",
    "défraierait": "défrayer",
    "défraieras": "défrayer",
    "défraierez": "défrayer",
    "défraieriez": "défrayer",
    "défraierions": "défrayer",
    "défraierons": "défrayer",
    "défraieront": "défrayer",
    "défraies": "défrayer",
    "défraya": "défrayer",
    "défrayai": "défrayer",
    "défrayaient": "défrayer",
    "défrayais": "défrayer",
    "défrayait": "défrayer",
    "défrayant": "défrayer",
    "défrayas": "défrayer",
    "défrayasse": "défrayer",
    "défrayassent": "défrayer",
    "défrayasses": "défrayer",
    "défrayassiez": "défrayer",
    "défrayassions": "défrayer",
    "défraye": "défrayer",
    "défrayent": "défrayer",
    "défrayera": "défrayer",
    "défrayerai": "défrayer",
    "défrayeraient": "défrayer",
    "défrayerais": "défrayer",
    "défrayerait": "défrayer",
    "défrayeras": "défrayer",
    "défrayerez": "défrayer",
    "défrayeriez": "défrayer",
    "défrayerions": "défrayer",
    "défrayerons": "défrayer",
    "défrayeront": "défrayer",
    "défrayes": "défrayer",
    "défrayez": "défrayer",
    "défrayiez": "défrayer",
    "défrayions": "défrayer",
    "défrayons": "défrayer",
    "défrayâmes": "défrayer",
    "défrayât": "défrayer",
    "défrayâtes": "défrayer",
    "défrayèrent": "défrayer",
    "défrayé": "défrayer",
    "défrayée": "défrayer",
    "défrayées": "défrayer",
    "défrayés": "défrayer",
    "défraîchi": "défraîchir",
    "défraîchie": "défraîchir",
    "défraîchies": "défraîchir",
    "défraîchira": "défraîchir",
    "défraîchirai": "défraîchir",
    "défraîchiraient": "défraîchir",
    "défraîchirais": "défraîchir",
    "défraîchirait": "défraîchir",
    "défraîchiras": "défraîchir",
    "défraîchirent": "défraîchir",
    "défraîchirez": "défraîchir",
    "défraîchiriez": "défraîchir",
    "défraîchirions": "défraîchir",
    "défraîchirons": "défraîchir",
    "défraîchiront": "défraîchir",
    "défraîchis": "défraîchir",
    "défraîchissaient": "défraîchir",
    "défraîchissais": "défraîchir",
    "défraîchissait": "défraîchir",
    "défraîchissant": "défraîchir",
    "défraîchisse": "défraîchir",
    "défraîchissent": "défraîchir",
    "défraîchisses": "défraîchir",
    "défraîchissez": "défraîchir",
    "défraîchissiez": "défraîchir",
    "défraîchissions": "défraîchir",
    "défraîchissons": "défraîchir",
    "défraîchit": "défraîchir",
    "défraîchîmes": "défraîchir",
    "défraîchît": "défraîchir",
    "défraîchîtes": "défraîchir",
    "défricha": "défricher",
    "défrichai": "défricher",
    "défrichaient": "défricher",
    "défrichais": "défricher",
    "défrichait": "défricher",
    "défrichant": "défricher",
    "défrichas": "défricher",
    "défrichasse": "défricher",
    "défrichassent": "défricher",
    "défrichasses": "défricher",
    "défrichassiez": "défricher",
    "défrichassions": "défricher",
    "défriche": "défricher",
    "défrichements": "défrichement",
    "défrichent": "défricher",
    "défrichera": "défricher",
    "défricherai": "défricher",
    "défricheraient": "défricher",
    "défricherais": "défricher",
    "défricherait": "défricher",
    "défricheras": "défricher",
    "défricherez": "défricher",
    "défricheriez": "défricher",
    "défricherions": "défricher",
    "défricherons": "défricher",
    "défricheront": "défricher",
    "défriches": "défricher",
    "défricheurs": "défricheur",
    "défrichez": "défricher",
    "défrichiez": "défricher",
    "défrichions": "défricher",
    "défrichons": "défricher",
    "défrichâmes": "défricher",
    "défrichât": "défricher",
    "défrichâtes": "défricher",
    "défrichèrent": "défricher",
    "défriché": "défricher",
    "défrichée": "défricher",
    "défrichées": "défricher",
    "défrichés": "défricher",
    "défringue": "défringuer",
    "défringues": "défringuer",
    "défripe": "défriper",
    "défripera": "défriper",
    "défripé": "défriper",
    "défripées": "défriper",
    "défrisa": "défriser",
    "défrisai": "défriser",
    "défrisaient": "défriser",
    "défrisais": "défriser",
    "défrisait": "défriser",
    "défrisant": "défriser",
    "défrisas": "défriser",
    "défrisasse": "défriser",
    "défrisassent": "défriser",
    "défrisasses": "défriser",
    "défrisassiez": "défriser",
    "défrisassions": "défriser",
    "défrise": "défriser",
    "défrisent": "défriser",
    "défrisera": "défriser",
    "défriserai": "défriser",
    "défriseraient": "défriser",
    "défriserais": "défriser",
    "défriserait": "défriser",
    "défriseras": "défriser",
    "défriserez": "défriser",
    "défriseriez": "défriser",
    "défriserions": "défriser",
    "défriserons": "défriser",
    "défriseront": "défriser",
    "défrises": "défriser",
    "défrisez": "défriser",
    "défrisiez": "défriser",
    "défrisions": "défriser",
    "défrisons": "défriser",
    "défrisâmes": "défriser",
    "défrisât": "défriser",
    "défrisâtes": "défriser",
    "défrisèrent": "défriser",
    "défrisé": "défriser",
    "défrisée": "défriser",
    "défrisées": "défriser",
    "défrisés": "défriser",
    "défroissa": "défroisser",
    "défroissai": "défroisser",
    "défroissaient": "défroisser",
    "défroissais": "défroisser",
    "défroissait": "défroisser",
    "défroissant": "défroisser",
    "défroissas": "défroisser",
    "défroissasse": "défroisser",
    "défroissassent": "défroisser",
    "défroissasses": "défroisser",
    "défroissassiez": "défroisser",
    "défroissassions": "défroisser",
    "défroisse": "défroisser",
    "défroissent": "défroisser",
    "défroissera": "défroisser",
    "défroisserai": "défroisser",
    "défroisseraient": "défroisser",
    "défroisserais": "défroisser",
    "défroisserait": "défroisser",
    "défroisseras": "défroisser",
    "défroisserez": "défroisser",
    "défroisseriez": "défroisser",
    "défroisserions": "défroisser",
    "défroisserons": "défroisser",
    "défroisseront": "défroisser",
    "défroisses": "défroisser",
    "défroissez": "défroisser",
    "défroissiez": "défroisser",
    "défroissions": "défroisser",
    "défroissons": "défroisser",
    "défroissâmes": "défroisser",
    "défroissât": "défroisser",
    "défroissâtes": "défroisser",
    "défroissèrent": "défroisser",
    "défroissé": "défroisser",
    "défroissée": "défroisser",
    "défroissées": "défroisser",
    "défroissés": "défroisser",
    "défronce": "défroncer",
    "défroncent": "défroncer",
    "défroncera": "défroncer",
    "défroncerai": "défroncer",
    "défronceraient": "défroncer",
    "défroncerais": "défroncer",
    "défroncerait": "défroncer",
    "défronceras": "défroncer",
    "défroncerez": "défroncer",
    "défronceriez": "défroncer",
    "défroncerions": "défroncer",
    "défroncerons": "défroncer",
    "défronceront": "défroncer",
    "défronces": "défroncer",
    "défroncez": "défroncer",
    "défronciez": "défroncer",
    "défroncions": "défroncer",
    "défroncèrent": "défroncer",
    "défroncé": "défroncer",
    "défroncée": "défroncer",
    "défroncées": "défroncer",
    "défroncés": "défroncer",
    "défronça": "défroncer",
    "défronçai": "défroncer",
    "défronçaient": "défroncer",
    "défronçais": "défroncer",
    "défronçait": "défroncer",
    "défronçant": "défroncer",
    "défronças": "défroncer",
    "défronçasse": "défroncer",
    "défronçassent": "défroncer",
    "défronçasses": "défroncer",
    "défronçassiez": "défroncer",
    "défronçassions": "défroncer",
    "défronçons": "défroncer",
    "défronçâmes": "défroncer",
    "défronçât": "défroncer",
    "défronçâtes": "défroncer",
    "défroqua": "défroquer",
    "défroquai": "défroquer",
    "défroquaient": "défroquer",
    "défroquais": "défroquer",
    "défroquait": "défroquer",
    "défroquant": "défroquer",
    "défroquas": "défroquer",
    "défroquasse": "défroquer",
    "défroquassent": "défroquer",
    "défroquasses": "défroquer",
    "défroquassiez": "défroquer",
    "défroquassions": "défroquer",
    "défroque": "défroquer",
    "défroquent": "défroquer",
    "défroquera": "défroquer",
    "défroquerai": "défroquer",
    "défroqueraient": "défroquer",
    "défroquerais": "défroquer",
    "défroquerait": "défroquer",
    "défroqueras": "défroquer",
    "défroquerez": "défroquer",
    "défroqueriez": "défroquer",
    "défroquerions": "défroquer",
    "défroquerons": "défroquer",
    "défroqueront": "défroquer",
    "défroques": "défroquer",
    "défroquez": "défroquer",
    "défroquiez": "défroquer",
    "défroquions": "défroquer",
    "défroquons": "défroquer",
    "défroquâmes": "défroquer",
    "défroquât": "défroquer",
    "défroquâtes": "défroquer",
    "défroquèrent": "défroquer",
    "défroqué": "défroquer",
    "défroquée": "défroquer",
    "défroquées": "défroquer",
    "défroqués": "défroquer",
    "défunte": "défunt",
    "défuntes": "défunt",
    "défunts": "défunt",
    "défunté": "défunter",
    "défâcha": "défâcher",
    "défâchai": "défâcher",
    "défâchaient": "défâcher",
    "défâchais": "défâcher",
    "défâchait": "défâcher",
    "défâchant": "défâcher",
    "défâchas": "défâcher",
    "défâchasse": "défâcher",
    "défâchassent": "défâcher",
    "défâchasses": "défâcher",
    "défâchassiez": "défâcher",
    "défâchassions": "défâcher",
    "défâche": "défâcher",
    "défâchent": "défâcher",
    "défâchera": "défâcher",
    "défâcherai": "défâcher",
    "défâcheraient": "défâcher",
    "défâcherais": "défâcher",
    "défâcherait": "défâcher",
    "défâcheras": "défâcher",
    "défâcherez": "défâcher",
    "défâcheriez": "défâcher",
    "défâcherions": "défâcher",
    "défâcherons": "défâcher",
    "défâcheront": "défâcher",
    "défâches": "défâcher",
    "défâchez": "défâcher",
    "défâchiez": "défâcher",
    "défâchions": "défâcher",
    "défâchons": "défâcher",
    "défâchâmes": "défâcher",
    "défâchât": "défâcher",
    "défâchâtes": "défâcher",
    "défâchèrent": "défâcher",
    "défâché": "défâcher",
    "défâchée": "défâcher",
    "défâchées": "défâcher",
    "défâchés": "défâcher",
    "défèque": "déféquer",
    "défèquent": "déféquer",
    "défèques": "déféquer",
    "défère": "déférer",
    "défèrent": "déférer",
    "défères": "déférer",
    "défécations": "défécation",
    "déféqua": "déféquer",
    "déféquai": "déféquer",
    "déféquaient": "déféquer",
    "déféquais": "déféquer",
    "déféquait": "déféquer",
    "déféquant": "déféquer",
    "déféquas": "déféquer",
    "déféquasse": "déféquer",
    "déféquassent": "déféquer",
    "déféquasses": "déféquer",
    "déféquassiez": "déféquer",
    "déféquassions": "déféquer",
    "déféquera": "déféquer",
    "déféquerai": "déféquer",
    "déféqueraient": "déféquer",
    "déféquerais": "déféquer",
    "déféquerait": "déféquer",
    "déféqueras": "déféquer",
    "déféquerez": "déféquer",
    "déféqueriez": "déféquer",
    "déféquerions": "déféquer",
    "déféquerons": "déféquer",
    "déféqueront": "déféquer",
    "déféquez": "déféquer",
    "déféquiez": "déféquer",
    "déféquions": "déféquer",
    "déféquons": "déféquer",
    "déféquâmes": "déféquer",
    "déféquât": "déféquer",
    "déféquâtes": "déféquer",
    "déféquèrent": "déféquer",
    "déféqué": "déféquer",
    "déféquée": "déféquer",
    "déféquées": "déféquer",
    "déféqués": "déféquer",
    "déféra": "déférer",
    "déférai": "déférer",
    "déféraient": "déférer",
    "déférais": "déférer",
    "déférait": "déférer",
    "déférant": "déférer",
    "déféras": "déférer",
    "déférasse": "déférer",
    "déférassent": "déférer",
    "déférasses": "déférer",
    "déférassiez": "déférer",
    "déférassions": "déférer",
    "déférences": "déférence",
    "déférente": "déférent",
    "déférentes": "déférent",
    "déférents": "déférent",
    "déférera": "déférer",
    "déférerai": "déférer",
    "déféreraient": "déférer",
    "déférerais": "déférer",
    "déférerait": "déférer",
    "déféreras": "déférer",
    "déférerez": "déférer",
    "déféreriez": "déférer",
    "déférerions": "déférer",
    "déférerons": "déférer",
    "déféreront": "déférer",
    "déférez": "déférer",
    "défériez": "déférer",
    "déférions": "déférer",
    "déférons": "déférer",
    "déférâmes": "déférer",
    "déférât": "déférer",
    "déférâtes": "déférer",
    "déférèrent": "déférer",
    "déféré": "déférer",
    "déférée": "déférer",
    "déférées": "déférer",
    "déférés": "déférer",
    "défîmes": "défaire",
    "défît": "défaire",
    "défîtes": "défaire",
    "dégage": "dégager",
    "dégagea": "dégager",
    "dégageai": "dégager",
    "dégageaient": "dégager",
    "dégageais": "dégager",
    "dégageait": "dégager",
    "dégageant": "dégager",
    "dégageas": "dégager",
    "dégageasse": "dégager",
    "dégageassent": "dégager",
    "dégageasses": "dégager",
    "dégageassiez": "dégager",
    "dégageassions": "dégager",
    "dégagements": "dégagement",
    "dégagent": "dégager",
    "dégageons": "dégager",
    "dégagera": "dégager",
    "dégagerai": "dégager",
    "dégageraient": "dégager",
    "dégagerais": "dégager",
    "dégagerait": "dégager",
    "dégageras": "dégager",
    "dégagerez": "dégager",
    "dégageriez": "dégager",
    "dégagerions": "dégager",
    "dégagerons": "dégager",
    "dégageront": "dégager",
    "dégages": "dégager",
    "dégagez": "dégager",
    "dégageâmes": "dégager",
    "dégageât": "dégager",
    "dégageâtes": "dégager",
    "dégagiez": "dégager",
    "dégagions": "dégager",
    "dégagèrent": "dégager",
    "dégagé": "dégager",
    "dégagée": "dégager",
    "dégagées": "dégager",
    "dégagés": "dégager",
    "dégaina": "dégainer",
    "dégainai": "dégainer",
    "dégainaient": "dégainer",
    "dégainais": "dégainer",
    "dégainait": "dégainer",
    "dégainant": "dégainer",
    "dégainas": "dégainer",
    "dégainasse": "dégainer",
    "dégainassent": "dégainer",
    "dégainasses": "dégainer",
    "dégainassiez": "dégainer",
    "dégainassions": "dégainer",
    "dégaine": "dégainer",
    "dégainent": "dégainer",
    "dégainera": "dégainer",
    "dégainerai": "dégainer",
    "dégaineraient": "dégainer",
    "dégainerais": "dégainer",
    "dégainerait": "dégainer",
    "dégaineras": "dégainer",
    "dégainerez": "dégainer",
    "dégaineriez": "dégainer",
    "dégainerions": "dégainer",
    "dégainerons": "dégainer",
    "dégaineront": "dégainer",
    "dégaines": "dégainer",
    "dégainez": "dégainer",
    "dégainiez": "dégainer",
    "dégainions": "dégainer",
    "dégainons": "dégainer",
    "dégainâmes": "dégainer",
    "dégainât": "dégainer",
    "dégainâtes": "dégainer",
    "dégainèrent": "dégainer",
    "dégainé": "dégainer",
    "dégainée": "dégainer",
    "dégainées": "dégainer",
    "dégainés": "dégainer",
    "déganta": "déganter",
    "dégantai": "déganter",
    "dégantaient": "déganter",
    "dégantais": "déganter",
    "dégantait": "déganter",
    "dégantant": "déganter",
    "dégantas": "déganter",
    "dégantasse": "déganter",
    "dégantassent": "déganter",
    "dégantasses": "déganter",
    "dégantassiez": "déganter",
    "dégantassions": "déganter",
    "dégante": "déganter",
    "dégantent": "déganter",
    "dégantera": "déganter",
    "déganterai": "déganter",
    "déganteraient": "déganter",
    "déganterais": "déganter",
    "déganterait": "déganter",
    "déganteras": "déganter",
    "déganterez": "déganter",
    "déganteriez": "déganter",
    "déganterions": "déganter",
    "déganterons": "déganter",
    "déganteront": "déganter",
    "dégantes": "déganter",
    "dégantez": "déganter",
    "dégantiez": "déganter",
    "dégantions": "déganter",
    "dégantons": "déganter",
    "dégantâmes": "déganter",
    "dégantât": "déganter",
    "dégantâtes": "déganter",
    "dégantèrent": "déganter",
    "déganté": "déganter",
    "dégantée": "déganter",
    "dégantées": "déganter",
    "dégantés": "déganter",
    "dégarni": "dégarnir",
    "dégarnie": "dégarnir",
    "dégarnies": "dégarnir",
    "dégarnira": "dégarnir",
    "dégarnirai": "dégarnir",
    "dégarniraient": "dégarnir",
    "dégarnirais": "dégarnir",
    "dégarnirait": "dégarnir",
    "dégarniras": "dégarnir",
    "dégarnirent": "dégarnir",
    "dégarnirez": "dégarnir",
    "dégarniriez": "dégarnir",
    "dégarnirions": "dégarnir",
    "dégarnirons": "dégarnir",
    "dégarniront": "dégarnir",
    "dégarnis": "dégarnir",
    "dégarnissaient": "dégarnir",
    "dégarnissais": "dégarnir",
    "dégarnissait": "dégarnir",
    "dégarnissant": "dégarnir",
    "dégarnisse": "dégarnir",
    "dégarnissent": "dégarnir",
    "dégarnisses": "dégarnir",
    "dégarnissez": "dégarnir",
    "dégarnissiez": "dégarnir",
    "dégarnissions": "dégarnir",
    "dégarnissons": "dégarnir",
    "dégarnit": "dégarnir",
    "dégarnîmes": "dégarnir",
    "dégarnît": "dégarnir",
    "dégarnîtes": "dégarnir",
    "dégauchi": "dégauchir",
    "dégauchie": "dégauchir",
    "dégauchies": "dégauchir",
    "dégauchira": "dégauchir",
    "dégauchirai": "dégauchir",
    "dégauchiraient": "dégauchir",
    "dégauchirais": "dégauchir",
    "dégauchirait": "dégauchir",
    "dégauchiras": "dégauchir",
    "dégauchirent": "dégauchir",
    "dégauchirez": "dégauchir",
    "dégauchiriez": "dégauchir",
    "dégauchirions": "dégauchir",
    "dégauchirons": "dégauchir",
    "dégauchiront": "dégauchir",
    "dégauchis": "dégauchir",
    "dégauchissaient": "dégauchir",
    "dégauchissais": "dégauchir",
    "dégauchissait": "dégauchir",
    "dégauchissant": "dégauchir",
    "dégauchisse": "dégauchir",
    "dégauchissent": "dégauchir",
    "dégauchisses": "dégauchir",
    "dégauchissez": "dégauchir",
    "dégauchissiez": "dégauchir",
    "dégauchissions": "dégauchir",
    "dégauchissons": "dégauchir",
    "dégauchit": "dégauchir",
    "dégauchîmes": "dégauchir",
    "dégauchît": "dégauchir",
    "dégauchîtes": "dégauchir",
    "dégaza": "dégazer",
    "dégazai": "dégazer",
    "dégazaient": "dégazer",
    "dégazais": "dégazer",
    "dégazait": "dégazer",
    "dégazant": "dégazer",
    "dégazas": "dégazer",
    "dégazasse": "dégazer",
    "dégazassent": "dégazer",
    "dégazasses": "dégazer",
    "dégazassiez": "dégazer",
    "dégazassions": "dégazer",
    "dégaze": "dégazer",
    "dégazent": "dégazer",
    "dégazera": "dégazer",
    "dégazerai": "dégazer",
    "dégazeraient": "dégazer",
    "dégazerais": "dégazer",
    "dégazerait": "dégazer",
    "dégazeras": "dégazer",
    "dégazerez": "dégazer",
    "dégazeriez": "dégazer",
    "dégazerions": "dégazer",
    "dégazerons": "dégazer",
    "dégazeront": "dégazer",
    "dégazes": "dégazer",
    "dégazez": "dégazer",
    "dégaziez": "dégazer",
    "dégazions": "dégazer",
    "dégazonna": "dégazonner",
    "dégazonnai": "dégazonner",
    "dégazonnaient": "dégazonner",
    "dégazonnais": "dégazonner",
    "dégazonnait": "dégazonner",
    "dégazonnant": "dégazonner",
    "dégazonnas": "dégazonner",
    "dégazonnasse": "dégazonner",
    "dégazonnassent": "dégazonner",
    "dégazonnasses": "dégazonner",
    "dégazonnassiez": "dégazonner",
    "dégazonnassions": "dégazonner",
    "dégazonne": "dégazonner",
    "dégazonnent": "dégazonner",
    "dégazonnera": "dégazonner",
    "dégazonnerai": "dégazonner",
    "dégazonneraient": "dégazonner",
    "dégazonnerais": "dégazonner",
    "dégazonnerait": "dégazonner",
    "dégazonneras": "dégazonner",
    "dégazonnerez": "dégazonner",
    "dégazonneriez": "dégazonner",
    "dégazonnerions": "dégazonner",
    "dégazonnerons": "dégazonner",
    "dégazonneront": "dégazonner",
    "dégazonnes": "dégazonner",
    "dégazonnez": "dégazonner",
    "dégazonniez": "dégazonner",
    "dégazonnions": "dégazonner",
    "dégazonnons": "dégazonner",
    "dégazonnâmes": "dégazonner",
    "dégazonnât": "dégazonner",
    "dégazonnâtes": "dégazonner",
    "dégazonnèrent": "dégazonner",
    "dégazonné": "dégazonner",
    "dégazonnée": "dégazonner",
    "dégazonnées": "dégazonner",
    "dégazonnés": "dégazonner",
    "dégazons": "dégazer",
    "dégazâmes": "dégazer",
    "dégazât": "dégazer",
    "dégazâtes": "dégazer",
    "dégazèrent": "dégazer",
    "dégazé": "dégazer",
    "dégazée": "dégazer",
    "dégazées": "dégazer",
    "dégazés": "dégazer",
    "dégela": "dégeler",
    "dégelai": "dégeler",
    "dégelaient": "dégeler",
    "dégelais": "dégeler",
    "dégelait": "dégeler",
    "dégelant": "dégeler",
    "dégelas": "dégeler",
    "dégelasse": "dégeler",
    "dégelassent": "dégeler",
    "dégelasses": "dégeler",
    "dégelassiez": "dégeler",
    "dégelassions": "dégeler",
    "dégelez": "dégeler",
    "dégeliez": "dégeler",
    "dégelions": "dégeler",
    "dégelons": "dégeler",
    "dégels": "dégel",
    "dégelâmes": "dégeler",
    "dégelât": "dégeler",
    "dégelâtes": "dégeler",
    "dégelèrent": "dégeler",
    "dégelé": "dégeler",
    "dégelée": "dégeler",
    "dégelées": "dégeler",
    "dégelés": "dégeler",
    "dégerma": "dégermer",
    "dégermai": "dégermer",
    "dégermaient": "dégermer",
    "dégermais": "dégermer",
    "dégermait": "dégermer",
    "dégermant": "dégermer",
    "dégermas": "dégermer",
    "dégermasse": "dégermer",
    "dégermassent": "dégermer",
    "dégermasses": "dégermer",
    "dégermassiez": "dégermer",
    "dégermassions": "dégermer",
    "dégerme": "dégermer",
    "dégerment": "dégermer",
    "dégermera": "dégermer",
    "dégermerai": "dégermer",
    "dégermeraient": "dégermer",
    "dégermerais": "dégermer",
    "dégermerait": "dégermer",
    "dégermeras": "dégermer",
    "dégermerez": "dégermer",
    "dégermeriez": "dégermer",
    "dégermerions": "dégermer",
    "dégermerons": "dégermer",
    "dégermeront": "dégermer",
    "dégermes": "dégermer",
    "dégermez": "dégermer",
    "dégermiez": "dégermer",
    "dégermions": "dégermer",
    "dégermons": "dégermer",
    "dégermâmes": "dégermer",
    "dégermât": "dégermer",
    "dégermâtes": "dégermer",
    "dégermèrent": "dégermer",
    "dégermé": "dégermer",
    "dégermée": "dégermer",
    "dégermées": "dégermer",
    "dégermés": "dégermer",
    "dégingandé": "dégingander",
    "dégingandée": "dégingander",
    "dégingandées": "dégingandé",
    "dégingandés": "dégingandé",
    "dégivra": "dégivrer",
    "dégivrai": "dégivrer",
    "dégivraient": "dégivrer",
    "dégivrais": "dégivrer",
    "dégivrait": "dégivrer",
    "dégivrant": "dégivrer",
    "dégivras": "dégivrer",
    "dégivrasse": "dégivrer",
    "dégivrassent": "dégivrer",
    "dégivrasses": "dégivrer",
    "dégivrassiez": "dégivrer",
    "dégivrassions": "dégivrer",
    "dégivre": "dégivrer",
    "dégivrent": "dégivrer",
    "dégivrera": "dégivrer",
    "dégivrerai": "dégivrer",
    "dégivreraient": "dégivrer",
    "dégivrerais": "dégivrer",
    "dégivrerait": "dégivrer",
    "dégivreras": "dégivrer",
    "dégivrerez": "dégivrer",
    "dégivreriez": "dégivrer",
    "dégivrerions": "dégivrer",
    "dégivrerons": "dégivrer",
    "dégivreront": "dégivrer",
    "dégivres": "dégivrer",
    "dégivrez": "dégivrer",
    "dégivriez": "dégivrer",
    "dégivrions": "dégivrer",
    "dégivrons": "dégivrer",
    "dégivrâmes": "dégivrer",
    "dégivrât": "dégivrer",
    "dégivrâtes": "dégivrer",
    "dégivrèrent": "dégivrer",
    "dégivré": "dégivrer",
    "dégivrée": "dégivrer",
    "dégivrées": "dégivrer",
    "dégivrés": "dégivrer",
    "déglace": "déglacer",
    "déglacent": "déglacer",
    "déglacera": "déglacer",
    "déglacerai": "déglacer",
    "déglaceraient": "déglacer",
    "déglacerais": "déglacer",
    "déglacerait": "déglacer",
    "déglaceras": "déglacer",
    "déglacerez": "déglacer",
    "déglaceriez": "déglacer",
    "déglacerions": "déglacer",
    "déglacerons": "déglacer",
    "déglaceront": "déglacer",
    "déglaces": "déglacer",
    "déglacez": "déglacer",
    "déglaciez": "déglacer",
    "déglacions": "déglacer",
    "déglacèrent": "déglacer",
    "déglacé": "déglacer",
    "déglacée": "déglacer",
    "déglacées": "déglacer",
    "déglacés": "déglacer",
    "déglaça": "déglacer",
    "déglaçai": "déglacer",
    "déglaçaient": "déglacer",
    "déglaçais": "déglacer",
    "déglaçait": "déglacer",
    "déglaçant": "déglacer",
    "déglaças": "déglacer",
    "déglaçasse": "déglacer",
    "déglaçassent": "déglacer",
    "déglaçasses": "déglacer",
    "déglaçassiez": "déglacer",
    "déglaçassions": "déglacer",
    "déglaçons": "déglacer",
    "déglaçâmes": "déglacer",
    "déglaçât": "déglacer",
    "déglaçâtes": "déglacer",
    "déglingua": "déglinguer",
    "déglinguai": "déglinguer",
    "déglinguaient": "déglinguer",
    "déglinguais": "déglinguer",
    "déglinguait": "déglinguer",
    "déglinguant": "déglinguer",
    "déglinguas": "déglinguer",
    "déglinguasse": "déglinguer",
    "déglinguassent": "déglinguer",
    "déglinguasses": "déglinguer",
    "déglinguassiez": "déglinguer",
    "déglinguassions": "déglinguer",
    "déglingue": "déglinguer",
    "déglinguent": "déglinguer",
    "déglinguera": "déglinguer",
    "déglinguerai": "déglinguer",
    "déglingueraient": "déglinguer",
    "déglinguerais": "déglinguer",
    "déglinguerait": "déglinguer",
    "déglingueras": "déglinguer",
    "déglinguerez": "déglinguer",
    "déglingueriez": "déglinguer",
    "déglinguerions": "déglinguer",
    "déglinguerons": "déglinguer",
    "déglingueront": "déglinguer",
    "déglingues": "déglinguer",
    "déglinguez": "déglinguer",
    "déglinguiez": "déglinguer",
    "déglinguions": "déglinguer",
    "déglinguons": "déglinguer",
    "déglinguâmes": "déglinguer",
    "déglinguât": "déglinguer",
    "déglinguâtes": "déglinguer",
    "déglinguèrent": "déglinguer",
    "déglingué": "déglinguer",
    "déglinguée": "déglinguer",
    "déglinguées": "déglinguer",
    "déglingués": "déglinguer",
    "dégluti": "déglutir",
    "déglutie": "déglutir",
    "dégluties": "déglutir",
    "déglutira": "déglutir",
    "déglutirai": "déglutir",
    "déglutiraient": "déglutir",
    "déglutirais": "déglutir",
    "déglutirait": "déglutir",
    "déglutiras": "déglutir",
    "déglutirent": "déglutir",
    "déglutirez": "déglutir",
    "déglutiriez": "déglutir",
    "déglutirions": "déglutir",
    "déglutirons": "déglutir",
    "déglutiront": "déglutir",
    "déglutis": "déglutir",
    "déglutissaient": "déglutir",
    "déglutissais": "déglutir",
    "déglutissait": "déglutir",
    "déglutissant": "déglutir",
    "déglutisse": "déglutir",
    "déglutissent": "déglutir",
    "déglutisses": "déglutir",
    "déglutissez": "déglutir",
    "déglutissiez": "déglutir",
    "déglutissions": "déglutir",
    "déglutissons": "déglutir",
    "déglutit": "déglutir",
    "déglutitions": "déglutition",
    "déglutîmes": "déglutir",
    "déglutît": "déglutir",
    "déglutîtes": "déglutir",
    "dégobilla": "dégobiller",
    "dégobillaient": "dégobiller",
    "dégobillait": "dégobiller",
    "dégobillant": "dégobiller",
    "dégobille": "dégobiller",
    "dégobillé": "dégobiller",
    "dégoisa": "dégoiser",
    "dégoisai": "dégoiser",
    "dégoisaient": "dégoiser",
    "dégoisais": "dégoiser",
    "dégoisait": "dégoiser",
    "dégoisant": "dégoiser",
    "dégoisas": "dégoiser",
    "dégoisasse": "dégoiser",
    "dégoisassent": "dégoiser",
    "dégoisasses": "dégoiser",
    "dégoisassiez": "dégoiser",
    "dégoisassions": "dégoiser",
    "dégoise": "dégoiser",
    "dégoisent": "dégoiser",
    "dégoisera": "dégoiser",
    "dégoiserai": "dégoiser",
    "dégoiseraient": "dégoiser",
    "dégoiserais": "dégoiser",
    "dégoiserait": "dégoiser",
    "dégoiseras": "dégoiser",
    "dégoiserez": "dégoiser",
    "dégoiseriez": "dégoiser",
    "dégoiserions": "dégoiser",
    "dégoiserons": "dégoiser",
    "dégoiseront": "dégoiser",
    "dégoises": "dégoiser",
    "dégoisez": "dégoiser",
    "dégoisiez": "dégoiser",
    "dégoisions": "dégoiser",
    "dégoisons": "dégoiser",
    "dégoisâmes": "dégoiser",
    "dégoisât": "dégoiser",
    "dégoisâtes": "dégoiser",
    "dégoisèrent": "dégoiser",
    "dégoisé": "dégoiser",
    "dégoisée": "dégoiser",
    "dégoisées": "dégoiser",
    "dégoisés": "dégoiser",
    "dégomma": "dégommer",
    "dégommai": "dégommer",
    "dégommaient": "dégommer",
    "dégommais": "dégommer",
    "dégommait": "dégommer",
    "dégommant": "dégommer",
    "dégommas": "dégommer",
    "dégommasse": "dégommer",
    "dégommassent": "dégommer",
    "dégommasses": "dégommer",
    "dégommassiez": "dégommer",
    "dégommassions": "dégommer",
    "dégomme": "dégommer",
    "dégomment": "dégommer",
    "dégommera": "dégommer",
    "dégommerai": "dégommer",
    "dégommeraient": "dégommer",
    "dégommerais": "dégommer",
    "dégommerait": "dégommer",
    "dégommeras": "dégommer",
    "dégommerez": "dégommer",
    "dégommeriez": "dégommer",
    "dégommerions": "dégommer",
    "dégommerons": "dégommer",
    "dégommeront": "dégommer",
    "dégommes": "dégommer",
    "dégommez": "dégommer",
    "dégommiez": "dégommer",
    "dégommions": "dégommer",
    "dégommons": "dégommer",
    "dégommâmes": "dégommer",
    "dégommât": "dégommer",
    "dégommâtes": "dégommer",
    "dégommèrent": "dégommer",
    "dégommé": "dégommer",
    "dégommée": "dégommer",
    "dégommées": "dégommer",
    "dégommés": "dégommer",
    "dégonfla": "dégonfler",
    "dégonflages": "dégonflage",
    "dégonflai": "dégonfler",
    "dégonflaient": "dégonfler",
    "dégonflais": "dégonfler",
    "dégonflait": "dégonfler",
    "dégonflant": "dégonfler",
    "dégonflas": "dégonfler",
    "dégonflasse": "dégonfler",
    "dégonflassent": "dégonfler",
    "dégonflasses": "dégonfler",
    "dégonflassiez": "dégonfler",
    "dégonflassions": "dégonfler",
    "dégonfle": "dégonfler",
    "dégonflent": "dégonfler",
    "dégonflera": "dégonfler",
    "dégonflerai": "dégonfler",
    "dégonfleraient": "dégonfler",
    "dégonflerais": "dégonfler",
    "dégonflerait": "dégonfler",
    "dégonfleras": "dégonfler",
    "dégonflerez": "dégonfler",
    "dégonfleriez": "dégonfler",
    "dégonflerions": "dégonfler",
    "dégonflerons": "dégonfler",
    "dégonfleront": "dégonfler",
    "dégonfles": "dégonfler",
    "dégonflez": "dégonfler",
    "dégonfliez": "dégonfler",
    "dégonflions": "dégonfler",
    "dégonflons": "dégonfler",
    "dégonflâmes": "dégonfler",
    "dégonflât": "dégonfler",
    "dégonflâtes": "dégonfler",
    "dégonflèrent": "dégonfler",
    "dégonflé": "dégonfler",
    "dégonflée": "dégonfler",
    "dégonflées": "dégonfler",
    "dégonflés": "dégonfler",
    "dégorge": "dégorger",
    "dégorgea": "dégorger",
    "dégorgeai": "dégorger",
    "dégorgeaient": "dégorger",
    "dégorgeais": "dégorger",
    "dégorgeait": "dégorger",
    "dégorgeant": "dégorger",
    "dégorgeas": "dégorger",
    "dégorgeasse": "dégorger",
    "dégorgeassent": "dégorger",
    "dégorgeasses": "dégorger",
    "dégorgeassiez": "dégorger",
    "dégorgeassions": "dégorger",
    "dégorgent": "dégorger",
    "dégorgeons": "dégorger",
    "dégorgera": "dégorger",
    "dégorgerai": "dégorger",
    "dégorgeraient": "dégorger",
    "dégorgerais": "dégorger",
    "dégorgerait": "dégorger",
    "dégorgeras": "dégorger",
    "dégorgerez": "dégorger",
    "dégorgeriez": "dégorger",
    "dégorgerions": "dégorger",
    "dégorgerons": "dégorger",
    "dégorgeront": "dégorger",
    "dégorges": "dégorger",
    "dégorgez": "dégorger",
    "dégorgeâmes": "dégorger",
    "dégorgeât": "dégorger",
    "dégorgeâtes": "dégorger",
    "dégorgiez": "dégorger",
    "dégorgions": "dégorger",
    "dégorgèrent": "dégorger",
    "dégorgé": "dégorger",
    "dégorgée": "dégorger",
    "dégorgées": "dégorger",
    "dégorgés": "dégorger",
    "dégota": "dégoter",
    "dégotai": "dégoter",
    "dégotaient": "dégoter",
    "dégotais": "dégoter",
    "dégotait": "dégoter",
    "dégotant": "dégoter",
    "dégotas": "dégoter",
    "dégotasse": "dégoter",
    "dégotassent": "dégoter",
    "dégotasses": "dégoter",
    "dégotassiez": "dégoter",
    "dégotassions": "dégoter",
    "dégote": "dégoter",
    "dégotent": "dégoter",
    "dégotera": "dégoter",
    "dégoterai": "dégoter",
    "dégoteraient": "dégoter",
    "dégoterais": "dégoter",
    "dégoterait": "dégoter",
    "dégoteras": "dégoter",
    "dégoterez": "dégoter",
    "dégoteriez": "dégoter",
    "dégoterions": "dégoter",
    "dégoterons": "dégoter",
    "dégoteront": "dégoter",
    "dégotes": "dégoter",
    "dégotez": "dégoter",
    "dégotiez": "dégoter",
    "dégotions": "dégoter",
    "dégotons": "dégoter",
    "dégotta": "dégotter",
    "dégottai": "dégotter",
    "dégottaient": "dégotter",
    "dégottais": "dégotter",
    "dégottait": "dégotter",
    "dégottant": "dégotter",
    "dégottas": "dégotter",
    "dégottasse": "dégotter",
    "dégottassent": "dégotter",
    "dégottasses": "dégotter",
    "dégottassiez": "dégotter",
    "dégottassions": "dégotter",
    "dégotte": "dégotter",
    "dégottent": "dégotter",
    "dégottera": "dégotter",
    "dégotterai": "dégotter",
    "dégotteraient": "dégotter",
    "dégotterais": "dégotter",
    "dégotterait": "dégotter",
    "dégotteras": "dégotter",
    "dégotterez": "dégotter",
    "dégotteriez": "dégotter",
    "dégotterions": "dégotter",
    "dégotterons": "dégotter",
    "dégotteront": "dégotter",
    "dégottes": "dégotter",
    "dégottez": "dégotter",
    "dégottiez": "dégotter",
    "dégottions": "dégotter",
    "dégottons": "dégotter",
    "dégottâmes": "dégotter",
    "dégottât": "dégotter",
    "dégottâtes": "dégotter",
    "dégottèrent": "dégotter",
    "dégotté": "dégotter",
    "dégottée": "dégotter",
    "dégottées": "dégotter",
    "dégottés": "dégotter",
    "dégotâmes": "dégoter",
    "dégotât": "dégoter",
    "dégotâtes": "dégoter",
    "dégotèrent": "dégoter",
    "dégoté": "dégoter",
    "dégotée": "dégoter",
    "dégotées": "dégoter",
    "dégotés": "dégoter",
    "dégoulina": "dégouliner",
    "dégoulinades": "dégoulinade",
    "dégoulinai": "dégouliner",
    "dégoulinaient": "dégouliner",
    "dégoulinais": "dégouliner",
    "dégoulinait": "dégouliner",
    "dégoulinant": "dégouliner",
    "dégoulinante": "dégoulinant",
    "dégoulinantes": "dégoulinant",
    "dégoulinants": "dégoulinant",
    "dégoulinas": "dégouliner",
    "dégoulinasse": "dégouliner",
    "dégoulinassent": "dégouliner",
    "dégoulinasses": "dégouliner",
    "dégoulinassiez": "dégouliner",
    "dégoulinassions": "dégouliner",
    "dégouline": "dégouliner",
    "dégoulinements": "dégoulinement",
    "dégoulinent": "dégouliner",
    "dégoulinera": "dégouliner",
    "dégoulinerai": "dégouliner",
    "dégoulineraient": "dégouliner",
    "dégoulinerais": "dégouliner",
    "dégoulinerait": "dégouliner",
    "dégoulineras": "dégouliner",
    "dégoulinerez": "dégouliner",
    "dégoulineriez": "dégouliner",
    "dégoulinerions": "dégouliner",
    "dégoulinerons": "dégouliner",
    "dégoulineront": "dégouliner",
    "dégoulines": "dégouliner",
    "dégoulinez": "dégouliner",
    "dégouliniez": "dégouliner",
    "dégoulinions": "dégouliner",
    "dégoulinons": "dégouliner",
    "dégoulinures": "dégoulinure",
    "dégoulinâmes": "dégouliner",
    "dégoulinât": "dégouliner",
    "dégoulinâtes": "dégouliner",
    "dégoulinèrent": "dégouliner",
    "dégouliné": "dégouliner",
    "dégoupilla": "dégoupiller",
    "dégoupillai": "dégoupiller",
    "dégoupillaient": "dégoupiller",
    "dégoupillais": "dégoupiller",
    "dégoupillait": "dégoupiller",
    "dégoupillant": "dégoupiller",
    "dégoupillas": "dégoupiller",
    "dégoupillasse": "dégoupiller",
    "dégoupillassent": "dégoupiller",
    "dégoupillasses": "dégoupiller",
    "dégoupillassiez": "dégoupiller",
    "dégoupillassions": "dégoupiller",
    "dégoupille": "dégoupiller",
    "dégoupillent": "dégoupiller",
    "dégoupillera": "dégoupiller",
    "dégoupillerai": "dégoupiller",
    "dégoupilleraient": "dégoupiller",
    "dégoupillerais": "dégoupiller",
    "dégoupillerait": "dégoupiller",
    "dégoupilleras": "dégoupiller",
    "dégoupillerez": "dégoupiller",
    "dégoupilleriez": "dégoupiller",
    "dégoupillerions": "dégoupiller",
    "dégoupillerons": "dégoupiller",
    "dégoupilleront": "dégoupiller",
    "dégoupilles": "dégoupiller",
    "dégoupillez": "dégoupiller",
    "dégoupilliez": "dégoupiller",
    "dégoupillions": "dégoupiller",
    "dégoupillons": "dégoupiller",
    "dégoupillâmes": "dégoupiller",
    "dégoupillât": "dégoupiller",
    "dégoupillâtes": "dégoupiller",
    "dégoupillèrent": "dégoupiller",
    "dégoupillé": "dégoupiller",
    "dégoupillée": "dégoupiller",
    "dégoupillées": "dégoupiller",
    "dégoupillés": "dégoupiller",
    "dégourdi": "dégourdir",
    "dégourdie": "dégourdir",
    "dégourdies": "dégourdir",
    "dégourdira": "dégourdir",
    "dégourdirai": "dégourdir",
    "dégourdiraient": "dégourdir",
    "dégourdirais": "dégourdir",
    "dégourdirait": "dégourdir",
    "dégourdiras": "dégourdir",
    "dégourdirent": "dégourdir",
    "dégourdirez": "dégourdir",
    "dégourdiriez": "dégourdir",
    "dégourdirions": "dégourdir",
    "dégourdirons": "dégourdir",
    "dégourdiront": "dégourdir",
    "dégourdis": "dégourdir",
    "dégourdissaient": "dégourdir",
    "dégourdissais": "dégourdir",
    "dégourdissait": "dégourdir",
    "dégourdissant": "dégourdir",
    "dégourdisse": "dégourdir",
    "dégourdissent": "dégourdir",
    "dégourdisses": "dégourdir",
    "dégourdissez": "dégourdir",
    "dégourdissiez": "dégourdir",
    "dégourdissions": "dégourdir",
    "dégourdissons": "dégourdir",
    "dégourdit": "dégourdir",
    "dégourdîmes": "dégourdir",
    "dégourdît": "dégourdir",
    "dégourdîtes": "dégourdir",
    "dégoutta": "dégoutter",
    "dégouttai": "dégoutter",
    "dégouttaient": "dégoutter",
    "dégouttais": "dégoutter",
    "dégouttait": "dégoutter",
    "dégouttant": "dégoutter",
    "dégouttante": "dégouttant",
    "dégouttantes": "dégouttant",
    "dégouttants": "dégouttant",
    "dégouttas": "dégoutter",
    "dégouttasse": "dégoutter",
    "dégouttassent": "dégoutter",
    "dégouttasses": "dégoutter",
    "dégouttassiez": "dégoutter",
    "dégouttassions": "dégoutter",
    "dégoutte": "dégoutter",
    "dégouttent": "dégoutter",
    "dégouttera": "dégoutter",
    "dégoutterai": "dégoutter",
    "dégoutteraient": "dégoutter",
    "dégoutterais": "dégoutter",
    "dégoutterait": "dégoutter",
    "dégoutteras": "dégoutter",
    "dégoutterez": "dégoutter",
    "dégoutteriez": "dégoutter",
    "dégoutterions": "dégoutter",
    "dégoutterons": "dégoutter",
    "dégoutteront": "dégoutter",
    "dégouttes": "dégoutter",
    "dégouttez": "dégoutter",
    "dégouttiez": "dégoutter",
    "dégouttions": "dégoutter",
    "dégouttons": "dégoutter",
    "dégouttâmes": "dégoutter",
    "dégouttât": "dégoutter",
    "dégouttâtes": "dégoutter",
    "dégouttèrent": "dégoutter",
    "dégoutté": "dégoutter",
    "dégoûta": "dégoûter",
    "dégoûtai": "dégoûter",
    "dégoûtaient": "dégoûter",
    "dégoûtais": "dégoûter",
    "dégoûtait": "dégoûter",
    "dégoûtant": "dégoûter",
    "dégoûtante": "dégoûtant",
    "dégoûtantes": "dégoûtant",
    "dégoûtants": "dégoûtant",
    "dégoûtas": "dégoûter",
    "dégoûtasse": "dégoûter",
    "dégoûtassent": "dégoûter",
    "dégoûtasses": "dégoûter",
    "dégoûtassiez": "dégoûter",
    "dégoûtassions": "dégoûter",
    "dégoûtations": "dégoûtation",
    "dégoûte": "dégoûter",
    "dégoûtent": "dégoûter",
    "dégoûtera": "dégoûter",
    "dégoûterai": "dégoûter",
    "dégoûteraient": "dégoûter",
    "dégoûterais": "dégoûter",
    "dégoûterait": "dégoûter",
    "dégoûteras": "dégoûter",
    "dégoûterez": "dégoûter",
    "dégoûteriez": "dégoûter",
    "dégoûterions": "dégoûter",
    "dégoûterons": "dégoûter",
    "dégoûteront": "dégoûter",
    "dégoûtes": "dégoûter",
    "dégoûtez": "dégoûter",
    "dégoûtiez": "dégoûter",
    "dégoûtions": "dégoûter",
    "dégoûtons": "dégoûter",
    "dégoûts": "dégoût",
    "dégoûtâmes": "dégoûter",
    "dégoûtât": "dégoûter",
    "dégoûtâtes": "dégoûter",
    "dégoûtèrent": "dégoûter",
    "dégoûté": "dégoûter",
    "dégoûtée": "dégoûter",
    "dégoûtées": "dégoûter",
    "dégoûtés": "dégoûter",
    "dégrada": "dégrader",
    "dégradables": "dégradable",
    "dégradai": "dégrader",
    "dégradaient": "dégrader",
    "dégradais": "dégrader",
    "dégradait": "dégrader",
    "dégradant": "dégrader",
    "dégradante": "dégradant",
    "dégradantes": "dégradant",
    "dégradants": "dégradant",
    "dégradas": "dégrader",
    "dégradasse": "dégrader",
    "dégradassent": "dégrader",
    "dégradasses": "dégrader",
    "dégradassiez": "dégrader",
    "dégradassions": "dégrader",
    "dégradations": "dégradation",
    "dégrade": "dégrader",
    "dégradent": "dégrader",
    "dégradera": "dégrader",
    "dégraderai": "dégrader",
    "dégraderaient": "dégrader",
    "dégraderais": "dégrader",
    "dégraderait": "dégrader",
    "dégraderas": "dégrader",
    "dégraderez": "dégrader",
    "dégraderiez": "dégrader",
    "dégraderions": "dégrader",
    "dégraderons": "dégrader",
    "dégraderont": "dégrader",
    "dégrades": "dégrader",
    "dégradez": "dégrader",
    "dégradiez": "dégrader",
    "dégradions": "dégrader",
    "dégradons": "dégrader",
    "dégradâmes": "dégrader",
    "dégradât": "dégrader",
    "dégradâtes": "dégrader",
    "dégradèrent": "dégrader",
    "dégradé": "dégrader",
    "dégradée": "dégrader",
    "dégradées": "dégrader",
    "dégradés": "dégrader",
    "dégrafa": "dégrafer",
    "dégrafai": "dégrafer",
    "dégrafaient": "dégrafer",
    "dégrafais": "dégrafer",
    "dégrafait": "dégrafer",
    "dégrafant": "dégrafer",
    "dégrafas": "dégrafer",
    "dégrafasse": "dégrafer",
    "dégrafassent": "dégrafer",
    "dégrafasses": "dégrafer",
    "dégrafassiez": "dégrafer",
    "dégrafassions": "dégrafer",
    "dégrafe": "dégrafer",
    "dégrafent": "dégrafer",
    "dégrafera": "dégrafer",
    "dégraferai": "dégrafer",
    "dégraferaient": "dégrafer",
    "dégraferais": "dégrafer",
    "dégraferait": "dégrafer",
    "dégraferas": "dégrafer",
    "dégraferez": "dégrafer",
    "dégraferiez": "dégrafer",
    "dégraferions": "dégrafer",
    "dégraferons": "dégrafer",
    "dégraferont": "dégrafer",
    "dégrafes": "dégrafer",
    "dégrafez": "dégrafer",
    "dégrafiez": "dégrafer",
    "dégrafions": "dégrafer",
    "dégrafons": "dégrafer",
    "dégrafâmes": "dégrafer",
    "dégrafât": "dégrafer",
    "dégrafâtes": "dégrafer",
    "dégrafèrent": "dégrafer",
    "dégrafé": "dégrafer",
    "dégrafée": "dégrafer",
    "dégrafées": "dégrafer",
    "dégrafés": "dégrafer",
    "dégraissa": "dégraisser",
    "dégraissages": "dégraissage",
    "dégraissai": "dégraisser",
    "dégraissaient": "dégraisser",
    "dégraissais": "dégraisser",
    "dégraissait": "dégraisser",
    "dégraissant": "dégraisser",
    "dégraissante": "dégraissant",
    "dégraissas": "dégraisser",
    "dégraissasse": "dégraisser",
    "dégraissassent": "dégraisser",
    "dégraissasses": "dégraisser",
    "dégraissassiez": "dégraisser",
    "dégraissassions": "dégraisser",
    "dégraisse": "dégraisser",
    "dégraissent": "dégraisser",
    "dégraissera": "dégraisser",
    "dégraisserai": "dégraisser",
    "dégraisseraient": "dégraisser",
    "dégraisserais": "dégraisser",
    "dégraisserait": "dégraisser",
    "dégraisseras": "dégraisser",
    "dégraisserez": "dégraisser",
    "dégraisseriez": "dégraisser",
    "dégraisserions": "dégraisser",
    "dégraisserons": "dégraisser",
    "dégraisseront": "dégraisser",
    "dégraisses": "dégraisser",
    "dégraissez": "dégraisser",
    "dégraissiez": "dégraisser",
    "dégraissions": "dégraisser",
    "dégraissons": "dégraisser",
    "dégraissâmes": "dégraisser",
    "dégraissât": "dégraisser",
    "dégraissâtes": "dégraisser",
    "dégraissèrent": "dégraisser",
    "dégraissé": "dégraisser",
    "dégraissée": "dégraisser",
    "dégraissées": "dégraisser",
    "dégraissés": "dégraisser",
    "dégressifs": "dégressif",
    "dégressive": "dégressif",
    "dégressives": "dégressif",
    "dégreva": "dégrever",
    "dégrevai": "dégrever",
    "dégrevaient": "dégrever",
    "dégrevais": "dégrever",
    "dégrevait": "dégrever",
    "dégrevant": "dégrever",
    "dégrevas": "dégrever",
    "dégrevasse": "dégrever",
    "dégrevassent": "dégrever",
    "dégrevasses": "dégrever",
    "dégrevassiez": "dégrever",
    "dégrevassions": "dégrever",
    "dégrevez": "dégrever",
    "dégreviez": "dégrever",
    "dégrevions": "dégrever",
    "dégrevons": "dégrever",
    "dégrevâmes": "dégrever",
    "dégrevât": "dégrever",
    "dégrevâtes": "dégrever",
    "dégrevèrent": "dégrever",
    "dégrevé": "dégrever",
    "dégrevée": "dégrever",
    "dégrevées": "dégrever",
    "dégrevés": "dégrever",
    "dégriffe": "dégriffer",
    "dégriffé": "dégriffer",
    "dégriffés": "dégriffé",
    "dégringola": "dégringoler",
    "dégringolades": "dégringolade",
    "dégringolai": "dégringoler",
    "dégringolaient": "dégringoler",
    "dégringolais": "dégringoler",
    "dégringolait": "dégringoler",
    "dégringolant": "dégringoler",
    "dégringolas": "dégringoler",
    "dégringolasse": "dégringoler",
    "dégringolassent": "dégringoler",
    "dégringolasses": "dégringoler",
    "dégringolassiez": "dégringoler",
    "dégringolassions": "dégringoler",
    "dégringole": "dégringoler",
    "dégringolent": "dégringoler",
    "dégringolera": "dégringoler",
    "dégringolerai": "dégringoler",
    "dégringoleraient": "dégringoler",
    "dégringolerais": "dégringoler",
    "dégringolerait": "dégringoler",
    "dégringoleras": "dégringoler",
    "dégringolerez": "dégringoler",
    "dégringoleriez": "dégringoler",
    "dégringolerions": "dégringoler",
    "dégringolerons": "dégringoler",
    "dégringoleront": "dégringoler",
    "dégringoles": "dégringoler",
    "dégringolez": "dégringoler",
    "dégringoliez": "dégringoler",
    "dégringolions": "dégringoler",
    "dégringolons": "dégringoler",
    "dégringolâmes": "dégringoler",
    "dégringolât": "dégringoler",
    "dégringolâtes": "dégringoler",
    "dégringolèrent": "dégringoler",
    "dégringolé": "dégringoler",
    "dégringolée": "dégringoler",
    "dégringolées": "dégringoler",
    "dégringolés": "dégringoler",
    "dégrisa": "dégriser",
    "dégrisai": "dégriser",
    "dégrisaient": "dégriser",
    "dégrisais": "dégriser",
    "dégrisait": "dégriser",
    "dégrisant": "dégriser",
    "dégrisas": "dégriser",
    "dégrisasse": "dégriser",
    "dégrisassent": "dégriser",
    "dégrisasses": "dégriser",
    "dégrisassiez": "dégriser",
    "dégrisassions": "dégriser",
    "dégrise": "dégriser",
    "dégrisent": "dégriser",
    "dégrisera": "dégriser",
    "dégriserai": "dégriser",
    "dégriseraient": "dégriser",
    "dégriserais": "dégriser",
    "dégriserait": "dégriser",
    "dégriseras": "dégriser",
    "dégriserez": "dégriser",
    "dégriseriez": "dégriser",
    "dégriserions": "dégriser",
    "dégriserons": "dégriser",
    "dégriseront": "dégriser",
    "dégrises": "dégriser",
    "dégrisez": "dégriser",
    "dégrisiez": "dégriser",
    "dégrisions": "dégriser",
    "dégrisons": "dégriser",
    "dégrisâmes": "dégriser",
    "dégrisât": "dégriser",
    "dégrisâtes": "dégriser",
    "dégrisèrent": "dégriser",
    "dégrisé": "dégriser",
    "dégrisée": "dégriser",
    "dégrisées": "dégriser",
    "dégrisés": "dégriser",
    "dégrossi": "dégrossir",
    "dégrossie": "dégrossir",
    "dégrossies": "dégrossir",
    "dégrossira": "dégrossir",
    "dégrossirai": "dégrossir",
    "dégrossiraient": "dégrossir",
    "dégrossirais": "dégrossir",
    "dégrossirait": "dégrossir",
    "dégrossiras": "dégrossir",
    "dégrossirent": "dégrossir",
    "dégrossirez": "dégrossir",
    "dégrossiriez": "dégrossir",
    "dégrossirions": "dégrossir",
    "dégrossirons": "dégrossir",
    "dégrossiront": "dégrossir",
    "dégrossis": "dégrossir",
    "dégrossissaient": "dégrossir",
    "dégrossissais": "dégrossir",
    "dégrossissait": "dégrossir",
    "dégrossissant": "dégrossir",
    "dégrossisse": "dégrossir",
    "dégrossissent": "dégrossir",
    "dégrossisses": "dégrossir",
    "dégrossissez": "dégrossir",
    "dégrossissiez": "dégrossir",
    "dégrossissions": "dégrossir",
    "dégrossissons": "dégrossir",
    "dégrossit": "dégrossir",
    "dégrossîmes": "dégrossir",
    "dégrossît": "dégrossir",
    "dégrossîtes": "dégrossir",
    "dégrouille": "dégrouiller",
    "dégroupa": "dégrouper",
    "dégroupai": "dégrouper",
    "dégroupaient": "dégrouper",
    "dégroupais": "dégrouper",
    "dégroupait": "dégrouper",
    "dégroupant": "dégrouper",
    "dégroupas": "dégrouper",
    "dégroupasse": "dégrouper",
    "dégroupassent": "dégrouper",
    "dégroupasses": "dégrouper",
    "dégroupassiez": "dégrouper",
    "dégroupassions": "dégrouper",
    "dégroupe": "dégrouper",
    "dégroupent": "dégrouper",
    "dégroupera": "dégrouper",
    "dégrouperai": "dégrouper",
    "dégrouperaient": "dégrouper",
    "dégrouperais": "dégrouper",
    "dégrouperait": "dégrouper",
    "dégrouperas": "dégrouper",
    "dégrouperez": "dégrouper",
    "dégrouperiez": "dégrouper",
    "dégrouperions": "dégrouper",
    "dégrouperons": "dégrouper",
    "dégrouperont": "dégrouper",
    "dégroupes": "dégrouper",
    "dégroupez": "dégrouper",
    "dégroupiez": "dégrouper",
    "dégroupions": "dégrouper",
    "dégroupons": "dégrouper",
    "dégroupâmes": "dégrouper",
    "dégroupât": "dégrouper",
    "dégroupâtes": "dégrouper",
    "dégroupèrent": "dégrouper",
    "dégroupé": "dégrouper",
    "dégroupée": "dégrouper",
    "dégroupées": "dégrouper",
    "dégroupés": "dégrouper",
    "dégrène": "dégrèner",
    "dégrève": "dégrever",
    "dégrèvements": "dégrèvement",
    "dégrèvent": "dégrever",
    "dégrèvera": "dégrever",
    "dégrèverai": "dégrever",
    "dégrèveraient": "dégrever",
    "dégrèverais": "dégrever",
    "dégrèverait": "dégrever",
    "dégrèveras": "dégrever",
    "dégrèverez": "dégrever",
    "dégrèveriez": "dégrever",
    "dégrèverions": "dégrever",
    "dégrèverons": "dégrever",
    "dégrèveront": "dégrever",
    "dégrèves": "dégrever",
    "dégrée": "dégréer",
    "déguenillée": "déguenillé",
    "déguenillées": "déguenillé",
    "déguenillés": "déguenillé",
    "déguerpi": "déguerpir",
    "déguerpira": "déguerpir",
    "déguerpirai": "déguerpir",
    "déguerpiraient": "déguerpir",
    "déguerpirais": "déguerpir",
    "déguerpirait": "déguerpir",
    "déguerpiras": "déguerpir",
    "déguerpirent": "déguerpir",
    "déguerpirez": "déguerpir",
    "déguerpiriez": "déguerpir",
    "déguerpirions": "déguerpir",
    "déguerpirons": "déguerpir",
    "déguerpiront": "déguerpir",
    "déguerpis": "déguerpir",
    "déguerpissaient": "déguerpir",
    "déguerpissais": "déguerpir",
    "déguerpissait": "déguerpir",
    "déguerpissant": "déguerpir",
    "déguerpisse": "déguerpir",
    "déguerpissent": "déguerpir",
    "déguerpisses": "déguerpir",
    "déguerpissez": "déguerpir",
    "déguerpissiez": "déguerpir",
    "déguerpissions": "déguerpir",
    "déguerpissons": "déguerpir",
    "déguerpit": "déguerpir",
    "déguerpîmes": "déguerpir",
    "déguerpît": "déguerpir",
    "déguerpîtes": "déguerpir",
    "dégueula": "dégueuler",
    "dégueulai": "dégueuler",
    "dégueulaient": "dégueuler",
    "dégueulais": "dégueuler",
    "dégueulait": "dégueuler",
    "dégueulant": "dégueuler",
    "dégueulas": "dégueuler",
    "dégueulasse": "dégueuler",
    "dégueulassent": "dégueuler",
    "dégueulasseries": "dégueulasserie",
    "dégueulasses": "dégueuler",
    "dégueulassiez": "dégueuler",
    "dégueulassions": "dégueuler",
    "dégueulassé": "dégueulasser",
    "dégueulassés": "dégueulasser",
    "dégueule": "dégueuler",
    "dégueulent": "dégueuler",
    "dégueulera": "dégueuler",
    "dégueulerai": "dégueuler",
    "dégueuleraient": "dégueuler",
    "dégueulerais": "dégueuler",
    "dégueulerait": "dégueuler",
    "dégueuleras": "dégueuler",
    "dégueulerez": "dégueuler",
    "dégueuleriez": "dégueuler",
    "dégueulerions": "dégueuler",
    "dégueulerons": "dégueuler",
    "dégueuleront": "dégueuler",
    "dégueules": "dégueuler",
    "dégueulez": "dégueuler",
    "dégueuliez": "dégueuler",
    "dégueulions": "dégueuler",
    "dégueulons": "dégueuler",
    "dégueulâmes": "dégueuler",
    "dégueulât": "dégueuler",
    "dégueulâtes": "dégueuler",
    "dégueulèrent": "dégueuler",
    "dégueulé": "dégueuler",
    "dégueulée": "dégueuler",
    "dégueulées": "dégueuler",
    "dégueulés": "dégueuler",
    "dégueus": "dégueu",
    "déguisa": "déguiser",
    "déguisai": "déguiser",
    "déguisaient": "déguiser",
    "déguisais": "déguiser",
    "déguisait": "déguiser",
    "déguisant": "déguiser",
    "déguisas": "déguiser",
    "déguisasse": "déguiser",
    "déguisassent": "déguiser",
    "déguisasses": "déguiser",
    "déguisassiez": "déguiser",
    "déguisassions": "déguiser",
    "déguise": "déguiser",
    "déguisements": "déguisement",
    "déguisent": "déguiser",
    "déguisera": "déguiser",
    "déguiserai": "déguiser",
    "déguiseraient": "déguiser",
    "déguiserais": "déguiser",
    "déguiserait": "déguiser",
    "déguiseras": "déguiser",
    "déguiserez": "déguiser",
    "déguiseriez": "déguiser",
    "déguiserions": "déguiser",
    "déguiserons": "déguiser",
    "déguiseront": "déguiser",
    "déguises": "déguiser",
    "déguisez": "déguiser",
    "déguisiez": "déguiser",
    "déguisions": "déguiser",
    "déguisons": "déguiser",
    "déguisâmes": "déguiser",
    "déguisât": "déguiser",
    "déguisâtes": "déguiser",
    "déguisèrent": "déguiser",
    "déguisé": "déguiser",
    "déguisée": "déguiser",
    "déguisées": "déguiser",
    "déguisés": "déguiser",
    "dégurgitant": "dégurgiter",
    "dégusta": "déguster",
    "dégustai": "déguster",
    "dégustaient": "déguster",
    "dégustais": "déguster",
    "dégustait": "déguster",
    "dégustant": "déguster",
    "dégustas": "déguster",
    "dégustasse": "déguster",
    "dégustassent": "déguster",
    "dégustasses": "déguster",
    "dégustassiez": "déguster",
    "dégustassions": "déguster",
    "dégustateurs": "dégustateur",
    "dégustations": "dégustation",
    "dégustatrice": "dégustateur",
    "dégustatrices": "dégustateur",
    "déguste": "déguster",
    "dégustent": "déguster",
    "dégustera": "déguster",
    "dégusterai": "déguster",
    "dégusteraient": "déguster",
    "dégusterais": "déguster",
    "dégusterait": "déguster",
    "dégusteras": "déguster",
    "dégusterez": "déguster",
    "dégusteriez": "déguster",
    "dégusterions": "déguster",
    "dégusterons": "déguster",
    "dégusteront": "déguster",
    "dégustes": "déguster",
    "dégustez": "déguster",
    "dégustiez": "déguster",
    "dégustions": "déguster",
    "dégustons": "déguster",
    "dégustâmes": "déguster",
    "dégustât": "déguster",
    "dégustâtes": "déguster",
    "dégustèrent": "déguster",
    "dégusté": "déguster",
    "dégustée": "déguster",
    "dégustées": "déguster",
    "dégustés": "déguster",
    "dégâts": "dégât",
    "dégèle": "dégeler",
    "dégèlent": "dégeler",
    "dégèlera": "dégeler",
    "dégèlerai": "dégeler",
    "dégèleraient": "dégeler",
    "dégèlerais": "dégeler",
    "dégèlerait": "dégeler",
    "dégèleras": "dégeler",
    "dégèlerez": "dégeler",
    "dégèleriez": "dégeler",
    "dégèlerions": "dégeler",
    "dégèlerons": "dégeler",
    "dégèleront": "dégeler",
    "dégèles": "dégeler",
    "dégénère": "dégénérer",
    "dégénèrent": "dégénérer",
    "dégénères": "dégénérer",
    "dégénéra": "dégénérer",
    "dégénérai": "dégénérer",
    "dégénéraient": "dégénérer",
    "dégénérais": "dégénérer",
    "dégénérait": "dégénérer",
    "dégénérant": "dégénérer",
    "dégénéras": "dégénérer",
    "dégénérasse": "dégénérer",
    "dégénérassent": "dégénérer",
    "dégénérasses": "dégénérer",
    "dégénérassiez": "dégénérer",
    "dégénérassions": "dégénérer",
    "dégénératifs": "dégénératif",
    "dégénérative": "dégénératif",
    "dégénératives": "dégénératif",
    "dégénérera": "dégénérer",
    "dégénérerai": "dégénérer",
    "dégénéreraient": "dégénérer",
    "dégénérerais": "dégénérer",
    "dégénérerait": "dégénérer",
    "dégénéreras": "dégénérer",
    "dégénérerez": "dégénérer",
    "dégénéreriez": "dégénérer",
    "dégénérerions": "dégénérer",
    "dégénérerons": "dégénérer",
    "dégénéreront": "dégénérer",
    "dégénérescences": "dégénérescence",
    "dégénérez": "dégénérer",
    "dégénériez": "dégénérer",
    "dégénérions": "dégénérer",
    "dégénérons": "dégénérer",
    "dégénérâmes": "dégénérer",
    "dégénérât": "dégénérer",
    "dégénérâtes": "dégénérer",
    "dégénérèrent": "dégénérer",
    "dégénéré": "dégénérer",
    "dégénérée": "dégénérer",
    "dégénérées": "dégénérer",
    "dégénérés": "dégénérer",
    "déhale": "déhaler",
    "déhalées": "déhaler",
    "déhancha": "déhancher",
    "déhanchai": "déhancher",
    "déhanchaient": "déhancher",
    "déhanchais": "déhancher",
    "déhanchait": "déhancher",
    "déhanchant": "déhancher",
    "déhanchas": "déhancher",
    "déhanchasse": "déhancher",
    "déhanchassent": "déhancher",
    "déhanchasses": "déhancher",
    "déhanchassiez": "déhancher",
    "déhanchassions": "déhancher",
    "déhanche": "déhancher",
    "déhanchements": "déhanchement",
    "déhanchent": "déhancher",
    "déhanchera": "déhancher",
    "déhancherai": "déhancher",
    "déhancheraient": "déhancher",
    "déhancherais": "déhancher",
    "déhancherait": "déhancher",
    "déhancheras": "déhancher",
    "déhancherez": "déhancher",
    "déhancheriez": "déhancher",
    "déhancherions": "déhancher",
    "déhancherons": "déhancher",
    "déhancheront": "déhancher",
    "déhanches": "déhancher",
    "déhanchez": "déhancher",
    "déhanchiez": "déhancher",
    "déhanchions": "déhancher",
    "déhanchons": "déhancher",
    "déhanchâmes": "déhancher",
    "déhanchât": "déhancher",
    "déhanchâtes": "déhancher",
    "déhanchèrent": "déhancher",
    "déhanché": "déhancher",
    "déhanchée": "déhancher",
    "déhanchées": "déhancher",
    "déhanchés": "déhancher",
    "déharnacha": "déharnacher",
    "déharnachées": "déharnacher",
    "déhotte": "déhotter",
    "déhotté": "déhotter",
    "déhottée": "déhotter",
    "déicides": "déicide",
    "déifia": "déifier",
    "déifiai": "déifier",
    "déifiaient": "déifier",
    "déifiais": "déifier",
    "déifiait": "déifier",
    "déifiant": "déifier",
    "déifias": "déifier",
    "déifiasse": "déifier",
    "déifiassent": "déifier",
    "déifiasses": "déifier",
    "déifiassiez": "déifier",
    "déifiassions": "déifier",
    "déifie": "déifier",
    "déifient": "déifier",
    "déifiera": "déifier",
    "déifierai": "déifier",
    "déifieraient": "déifier",
    "déifierais": "déifier",
    "déifierait": "déifier",
    "déifieras": "déifier",
    "déifierez": "déifier",
    "déifieriez": "déifier",
    "déifierions": "déifier",
    "déifierons": "déifier",
    "déifieront": "déifier",
    "déifies": "déifier",
    "déifiez": "déifier",
    "déifiiez": "déifier",
    "déifiions": "déifier",
    "déifions": "déifier",
    "déifiâmes": "déifier",
    "déifiât": "déifier",
    "déifiâtes": "déifier",
    "déifièrent": "déifier",
    "déifié": "déifier",
    "déifiée": "déifier",
    "déifiées": "déifier",
    "déifiés": "déifier",
    "déismes": "déisme",
    "déités": "déité",
    "déjanta": "déjanter",
    "déjantai": "déjanter",
    "déjantaient": "déjanter",
    "déjantais": "déjanter",
    "déjantait": "déjanter",
    "déjantant": "déjanter",
    "déjantas": "déjanter",
    "déjantasse": "déjanter",
    "déjantassent": "déjanter",
    "déjantasses": "déjanter",
    "déjantassiez": "déjanter",
    "déjantassions": "déjanter",
    "déjante": "déjanter",
    "déjantent": "déjanter",
    "déjantera": "déjanter",
    "déjanterai": "déjanter",
    "déjanteraient": "déjanter",
    "déjanterais": "déjanter",
    "déjanterait": "déjanter",
    "déjanteras": "déjanter",
    "déjanterez": "déjanter",
    "déjanteriez": "déjanter",
    "déjanterions": "déjanter",
    "déjanterons": "déjanter",
    "déjanteront": "déjanter",
    "déjantes": "déjanter",
    "déjantez": "déjanter",
    "déjantiez": "déjanter",
    "déjantions": "déjanter",
    "déjantons": "déjanter",
    "déjantâmes": "déjanter",
    "déjantât": "déjanter",
    "déjantâtes": "déjanter",
    "déjantèrent": "déjanter",
    "déjanté": "déjanter",
    "déjantée": "déjanter",
    "déjantées": "déjanter",
    "déjantés": "déjanter",
    "déjaugeant": "déjauger",
    "déjauni": "déjaunir",
    "déjaunie": "déjaunir",
    "déjaunies": "déjaunir",
    "déjaunira": "déjaunir",
    "déjaunirai": "déjaunir",
    "déjauniraient": "déjaunir",
    "déjaunirais": "déjaunir",
    "déjaunirait": "déjaunir",
    "déjauniras": "déjaunir",
    "déjaunirent": "déjaunir",
    "déjaunirez": "déjaunir",
    "déjauniriez": "déjaunir",
    "déjaunirions": "déjaunir",
    "déjaunirons": "déjaunir",
    "déjauniront": "déjaunir",
    "déjaunis": "déjaunir",
    "déjaunissaient": "déjaunir",
    "déjaunissais": "déjaunir",
    "déjaunissait": "déjaunir",
    "déjaunissant": "déjaunir",
    "déjaunisse": "déjaunir",
    "déjaunissent": "déjaunir",
    "déjaunisses": "déjaunir",
    "déjaunissez": "déjaunir",
    "déjaunissiez": "déjaunir",
    "déjaunissions": "déjaunir",
    "déjaunissons": "déjaunir",
    "déjaunit": "déjaunir",
    "déjaunîmes": "déjaunir",
    "déjaunît": "déjaunir",
    "déjaunîtes": "déjaunir",
    "déjections": "déjection",
    "déjeta": "déjeter",
    "déjetai": "déjeter",
    "déjetaient": "déjeter",
    "déjetais": "déjeter",
    "déjetait": "déjeter",
    "déjetant": "déjeter",
    "déjetas": "déjeter",
    "déjetasse": "déjeter",
    "déjetassent": "déjeter",
    "déjetasses": "déjeter",
    "déjetassiez": "déjeter",
    "déjetassions": "déjeter",
    "déjetez": "déjeter",
    "déjetiez": "déjeter",
    "déjetions": "déjeter",
    "déjetons": "déjeter",
    "déjette": "déjeter",
    "déjettent": "déjeter",
    "déjettera": "déjeter",
    "déjetterai": "déjeter",
    "déjetteraient": "déjeter",
    "déjetterais": "déjeter",
    "déjetterait": "déjeter",
    "déjetteras": "déjeter",
    "déjetterez": "déjeter",
    "déjetteriez": "déjeter",
    "déjetterions": "déjeter",
    "déjetterons": "déjeter",
    "déjetteront": "déjeter",
    "déjettes": "déjeter",
    "déjetâmes": "déjeter",
    "déjetât": "déjeter",
    "déjetâtes": "déjeter",
    "déjetèrent": "déjeter",
    "déjeté": "déjeter",
    "déjetée": "déjeter",
    "déjetées": "déjeter",
    "déjetés": "déjeter",
    "déjeuna": "déjeuner",
    "déjeunai": "déjeuner",
    "déjeunaient": "déjeuner",
    "déjeunais": "déjeuner",
    "déjeunait": "déjeuner",
    "déjeunant": "déjeuner",
    "déjeunas": "déjeuner",
    "déjeunasse": "déjeuner",
    "déjeunassent": "déjeuner",
    "déjeunasses": "déjeuner",
    "déjeunassiez": "déjeuner",
    "déjeunassions": "déjeuner",
    "déjeune": "déjeuner",
    "déjeunent": "déjeuner",
    "déjeunera": "déjeuner",
    "déjeunerai": "déjeuner",
    "déjeuneraient": "déjeuner",
    "déjeunerais": "déjeuner",
    "déjeunerait": "déjeuner",
    "déjeuneras": "déjeuner",
    "déjeunerez": "déjeuner",
    "déjeuneriez": "déjeuner",
    "déjeunerions": "déjeuner",
    "déjeunerons": "déjeuner",
    "déjeuneront": "déjeuner",
    "déjeuners": "déjeuner",
    "déjeunes": "déjeuner",
    "déjeunez": "déjeuner",
    "déjeuniez": "déjeuner",
    "déjeunions": "déjeuner",
    "déjeunons": "déjeuner",
    "déjeunâmes": "déjeuner",
    "déjeunât": "déjeuner",
    "déjeunâtes": "déjeuner",
    "déjeunèrent": "déjeuner",
    "déjeuné": "déjeuner",
    "déjoua": "déjouer",
    "déjouai": "déjouer",
    "déjouaient": "déjouer",
    "déjouais": "déjouer",
    "déjouait": "déjouer",
    "déjouant": "déjouer",
    "déjouas": "déjouer",
    "déjouasse": "déjouer",
    "déjouassent": "déjouer",
    "déjouasses": "déjouer",
    "déjouassiez": "déjouer",
    "déjouassions": "déjouer",
    "déjoue": "déjouer",
    "déjouent": "déjouer",
    "déjouera": "déjouer",
    "déjouerai": "déjouer",
    "déjoueraient": "déjouer",
    "déjouerais": "déjouer",
    "déjouerait": "déjouer",
    "déjoueras": "déjouer",
    "déjouerez": "déjouer",
    "déjoueriez": "déjouer",
    "déjouerions": "déjouer",
    "déjouerons": "déjouer",
    "déjoueront": "déjouer",
    "déjoues": "déjouer",
    "déjouez": "déjouer",
    "déjouiez": "déjouer",
    "déjouions": "déjouer",
    "déjouons": "déjouer",
    "déjouâmes": "déjouer",
    "déjouât": "déjouer",
    "déjouâtes": "déjouer",
    "déjouèrent": "déjouer",
    "déjoué": "déjouer",
    "déjouée": "déjouer",
    "déjouées": "déjouer",
    "déjoués": "déjouer",
    "déjuchaient": "déjucher",
    "déjuge": "déjuger",
    "déjugea": "déjuger",
    "déjugeai": "déjuger",
    "déjugeaient": "déjuger",
    "déjugeais": "déjuger",
    "déjugeait": "déjuger",
    "déjugeant": "déjuger",
    "déjugeas": "déjuger",
    "déjugeasse": "déjuger",
    "déjugeassent": "déjuger",
    "déjugeasses": "déjuger",
    "déjugeassiez": "déjuger",
    "déjugeassions": "déjuger",
    "déjugent": "déjuger",
    "déjugeons": "déjuger",
    "déjugera": "déjuger",
    "déjugerai": "déjuger",
    "déjugeraient": "déjuger",
    "déjugerais": "déjuger",
    "déjugerait": "déjuger",
    "déjugeras": "déjuger",
    "déjugerez": "déjuger",
    "déjugeriez": "déjuger",
    "déjugerions": "déjuger",
    "déjugerons": "déjuger",
    "déjugeront": "déjuger",
    "déjuges": "déjuger",
    "déjugez": "déjuger",
    "déjugeâmes": "déjuger",
    "déjugeât": "déjuger",
    "déjugeâtes": "déjuger",
    "déjugiez": "déjuger",
    "déjugions": "déjuger",
    "déjugèrent": "déjuger",
    "déjugé": "déjuger",
    "déjugée": "déjuger",
    "déjugées": "déjuger",
    "déjugés": "déjuger",
    "délabra": "délabrer",
    "délabrai": "délabrer",
    "délabraient": "délabrer",
    "délabrais": "délabrer",
    "délabrait": "délabrer",
    "délabrant": "délabrer",
    "délabras": "délabrer",
    "délabrasse": "délabrer",
    "délabrassent": "délabrer",
    "délabrasses": "délabrer",
    "délabrassiez": "délabrer",
    "délabrassions": "délabrer",
    "délabre": "délabrer",
    "délabrements": "délabrement",
    "délabrent": "délabrer",
    "délabrera": "délabrer",
    "délabrerai": "délabrer",
    "délabreraient": "délabrer",
    "délabrerais": "délabrer",
    "délabrerait": "délabrer",
    "délabreras": "délabrer",
    "délabrerez": "délabrer",
    "délabreriez": "délabrer",
    "délabrerions": "délabrer",
    "délabrerons": "délabrer",
    "délabreront": "délabrer",
    "délabres": "délabrer",
    "délabrez": "délabrer",
    "délabriez": "délabrer",
    "délabrions": "délabrer",
    "délabrons": "délabrer",
    "délabrâmes": "délabrer",
    "délabrât": "délabrer",
    "délabrâtes": "délabrer",
    "délabrèrent": "délabrer",
    "délabré": "délabrer",
    "délabrée": "délabrer",
    "délabrées": "délabrer",
    "délabrés": "délabrer",
    "délabyrinthez": "délabyrinther",
    "délace": "délacer",
    "délacent": "délacer",
    "délacera": "délacer",
    "délacerai": "délacer",
    "délaceraient": "délacer",
    "délacerais": "délacer",
    "délacerait": "délacer",
    "délaceras": "délacer",
    "délacerez": "délacer",
    "délaceriez": "délacer",
    "délacerions": "délacer",
    "délacerons": "délacer",
    "délaceront": "délacer",
    "délaces": "délacer",
    "délacez": "délacer",
    "délaciez": "délacer",
    "délacions": "délacer",
    "délacèrent": "délacer",
    "délacé": "délacer",
    "délacée": "délacer",
    "délacées": "délacer",
    "délacés": "délacer",
    "délaie": "délayer",
    "délaient": "délayer",
    "délaiera": "délayer",
    "délaierai": "délayer",
    "délaieraient": "délayer",
    "délaierais": "délayer",
    "délaierait": "délayer",
    "délaieras": "délayer",
    "délaierez": "délayer",
    "délaieriez": "délayer",
    "délaierions": "délayer",
    "délaierons": "délayer",
    "délaieront": "délayer",
    "délaies": "délayer",
    "délais": "délai",
    "délais-congés": "délai-congé",
    "délaissa": "délaisser",
    "délaissai": "délaisser",
    "délaissaient": "délaisser",
    "délaissais": "délaisser",
    "délaissait": "délaisser",
    "délaissant": "délaisser",
    "délaissas": "délaisser",
    "délaissasse": "délaisser",
    "délaissassent": "délaisser",
    "délaissasses": "délaisser",
    "délaissassiez": "délaisser",
    "délaissassions": "délaisser",
    "délaisse": "délaisser",
    "délaissements": "délaissement",
    "délaissent": "délaisser",
    "délaissera": "délaisser",
    "délaisserai": "délaisser",
    "délaisseraient": "délaisser",
    "délaisserais": "délaisser",
    "délaisserait": "délaisser",
    "délaisseras": "délaisser",
    "délaisserez": "délaisser",
    "délaisseriez": "délaisser",
    "délaisserions": "délaisser",
    "délaisserons": "délaisser",
    "délaisseront": "délaisser",
    "délaisses": "délaisser",
    "délaissez": "délaisser",
    "délaissiez": "délaisser",
    "délaissions": "délaisser",
    "délaissons": "délaisser",
    "délaissâmes": "délaisser",
    "délaissât": "délaisser",
    "délaissâtes": "délaisser",
    "délaissèrent": "délaisser",
    "délaissé": "délaisser",
    "délaissée": "délaisser",
    "délaissées": "délaisser",
    "délaissés": "délaisser",
    "délaita": "délaiter",
    "délaite": "délaiter",
    "délardant": "délarder",
    "délassa": "délasser",
    "délassai": "délasser",
    "délassaient": "délasser",
    "délassais": "délasser",
    "délassait": "délasser",
    "délassant": "délasser",
    "délassante": "délassant",
    "délassantes": "délassant",
    "délassants": "délassant",
    "délassas": "délasser",
    "délassasse": "délasser",
    "délassassent": "délasser",
    "délassasses": "délasser",
    "délassassiez": "délasser",
    "délassassions": "délasser",
    "délasse": "délasser",
    "délassements": "délassement",
    "délassent": "délasser",
    "délassera": "délasser",
    "délasserai": "délasser",
    "délasseraient": "délasser",
    "délasserais": "délasser",
    "délasserait": "délasser",
    "délasseras": "délasser",
    "délasserez": "délasser",
    "délasseriez": "délasser",
    "délasserions": "délasser",
    "délasserons": "délasser",
    "délasseront": "délasser",
    "délasses": "délasser",
    "délassez": "délasser",
    "délassiez": "délasser",
    "délassions": "délasser",
    "délassons": "délasser",
    "délassâmes": "délasser",
    "délassât": "délasser",
    "délassâtes": "délasser",
    "délassèrent": "délasser",
    "délassé": "délasser",
    "délassée": "délasser",
    "délassées": "délasser",
    "délassés": "délasser",
    "délateurs": "délateur",
    "délations": "délation",
    "délatrice": "délateur",
    "délatrices": "délateur",
    "délava": "délaver",
    "délavai": "délaver",
    "délavaient": "délaver",
    "délavais": "délaver",
    "délavait": "délaver",
    "délavant": "délaver",
    "délavas": "délaver",
    "délavasse": "délaver",
    "délavassent": "délaver",
    "délavasses": "délaver",
    "délavassiez": "délaver",
    "délavassions": "délaver",
    "délave": "délaver",
    "délavent": "délaver",
    "délavera": "délaver",
    "délaverai": "délaver",
    "délaveraient": "délaver",
    "délaverais": "délaver",
    "délaverait": "délaver",
    "délaveras": "délaver",
    "délaverez": "délaver",
    "délaveriez": "délaver",
    "délaverions": "délaver",
    "délaverons": "délaver",
    "délaveront": "délaver",
    "délaves": "délaver",
    "délavez": "délaver",
    "délaviez": "délaver",
    "délavions": "délaver",
    "délavons": "délaver",
    "délavâmes": "délaver",
    "délavât": "délaver",
    "délavâtes": "délaver",
    "délavèrent": "délaver",
    "délavé": "délaver",
    "délavée": "délaver",
    "délavées": "délaver",
    "délavés": "délaver",
    "délaya": "délayer",
    "délayai": "délayer",
    "délayaient": "délayer",
    "délayais": "délayer",
    "délayait": "délayer",
    "délayant": "délayer",
    "délayas": "délayer",
    "délayasse": "délayer",
    "délayassent": "délayer",
    "délayasses": "délayer",
    "délayassiez": "délayer",
    "délayassions": "délayer",
    "délaye": "délayer",
    "délayent": "délayer",
    "délayera": "délayer",
    "délayerai": "délayer",
    "délayeraient": "délayer",
    "délayerais": "délayer",
    "délayerait": "délayer",
    "délayeras": "délayer",
    "délayerez": "délayer",
    "délayeriez": "délayer",
    "délayerions": "délayer",
    "délayerons": "délayer",
    "délayeront": "délayer",
    "délayes": "délayer",
    "délayez": "délayer",
    "délayiez": "délayer",
    "délayions": "délayer",
    "délayons": "délayer",
    "délayâmes": "délayer",
    "délayât": "délayer",
    "délayâtes": "délayer",
    "délayèrent": "délayer",
    "délayé": "délayer",
    "délayée": "délayer",
    "délayées": "délayer",
    "délayés": "délayer",
    "délaça": "délacer",
    "délaçai": "délacer",
    "délaçaient": "délacer",
    "délaçais": "délacer",
    "délaçait": "délacer",
    "délaçant": "délacer",
    "délaças": "délacer",
    "délaçasse": "délacer",
    "délaçassent": "délacer",
    "délaçasses": "délacer",
    "délaçassiez": "délacer",
    "délaçassions": "délacer",
    "délaçons": "délacer",
    "délaçâmes": "délacer",
    "délaçât": "délacer",
    "délaçâtes": "délacer",
    "délecta": "délecter",
    "délectables": "délectable",
    "délectai": "délecter",
    "délectaient": "délecter",
    "délectais": "délecter",
    "délectait": "délecter",
    "délectant": "délecter",
    "délectas": "délecter",
    "délectasse": "délecter",
    "délectassent": "délecter",
    "délectasses": "délecter",
    "délectassiez": "délecter",
    "délectassions": "délecter",
    "délectations": "délectation",
    "délecte": "délecter",
    "délectent": "délecter",
    "délectera": "délecter",
    "délecterai": "délecter",
    "délecteraient": "délecter",
    "délecterais": "délecter",
    "délecterait": "délecter",
    "délecteras": "délecter",
    "délecterez": "délecter",
    "délecteriez": "délecter",
    "délecterions": "délecter",
    "délecterons": "délecter",
    "délecteront": "délecter",
    "délectes": "délecter",
    "délectez": "délecter",
    "délectiez": "délecter",
    "délections": "délecter",
    "délectons": "délecter",
    "délectâmes": "délecter",
    "délectât": "délecter",
    "délectâtes": "délecter",
    "délectèrent": "délecter",
    "délecté": "délecter",
    "délectée": "délecter",
    "délectées": "délecter",
    "délectés": "délecter",
    "délesta": "délester",
    "délestai": "délester",
    "délestaient": "délester",
    "délestais": "délester",
    "délestait": "délester",
    "délestant": "délester",
    "délestas": "délester",
    "délestasse": "délester",
    "délestassent": "délester",
    "délestasses": "délester",
    "délestassiez": "délester",
    "délestassions": "délester",
    "déleste": "délester",
    "délestent": "délester",
    "délestera": "délester",
    "délesterai": "délester",
    "délesteraient": "délester",
    "délesterais": "délester",
    "délesterait": "délester",
    "délesteras": "délester",
    "délesterez": "délester",
    "délesteriez": "délester",
    "délesterions": "délester",
    "délesterons": "délester",
    "délesteront": "délester",
    "délestes": "délester",
    "délestez": "délester",
    "délestiez": "délester",
    "délestions": "délester",
    "délestons": "délester",
    "délestâmes": "délester",
    "délestât": "délester",
    "délestâtes": "délester",
    "délestèrent": "délester",
    "délesté": "délester",
    "délestée": "délester",
    "délestées": "délester",
    "délestés": "délester",
    "délia": "délier",
    "déliai": "délier",
    "déliaient": "délier",
    "déliais": "délier",
    "déliait": "délier",
    "déliant": "délier",
    "délias": "délier",
    "déliasse": "délier",
    "déliassent": "délier",
    "déliasses": "délier",
    "déliassiez": "délier",
    "déliassions": "délier",
    "délibère": "délibérer",
    "délibèrent": "délibérer",
    "délibères": "délibérer",
    "délibéra": "délibérer",
    "délibérai": "délibérer",
    "délibéraient": "délibérer",
    "délibérais": "délibérer",
    "délibérait": "délibérer",
    "délibérant": "délibérer",
    "délibéras": "délibérer",
    "délibérasse": "délibérer",
    "délibérassent": "délibérer",
    "délibérasses": "délibérer",
    "délibérassiez": "délibérer",
    "délibérassions": "délibérer",
    "délibératifs": "délibératif",
    "délibérations": "délibération",
    "délibérative": "délibératif",
    "délibératives": "délibératif",
    "délibérera": "délibérer",
    "délibérerai": "délibérer",
    "délibéreraient": "délibérer",
    "délibérerais": "délibérer",
    "délibérerait": "délibérer",
    "délibéreras": "délibérer",
    "délibérerez": "délibérer",
    "délibéreriez": "délibérer",
    "délibérerions": "délibérer",
    "délibérerons": "délibérer",
    "délibéreront": "délibérer",
    "délibérez": "délibérer",
    "délibériez": "délibérer",
    "délibérions": "délibérer",
    "délibérons": "délibérer",
    "délibérâmes": "délibérer",
    "délibérât": "délibérer",
    "délibérâtes": "délibérer",
    "délibérèrent": "délibérer",
    "délibéré": "délibérer",
    "délibérée": "délibérer",
    "délibérées": "délibérer",
    "délibérés": "délibérer",
    "délicate": "délicat",
    "délicates": "délicat",
    "délicatesses": "délicatesse",
    "délicats": "délicat",
    "délices": "délice",
    "délicieuse": "délicieux",
    "délicieuses": "délicieux",
    "délictuelle": "délictuel",
    "délictuelles": "délictuel",
    "délictuels": "délictuel",
    "délictueuse": "délictueux",
    "délictueuses": "délictueux",
    "délie": "délier",
    "délient": "délier",
    "déliera": "délier",
    "délierai": "délier",
    "délieraient": "délier",
    "délierais": "délier",
    "délierait": "délier",
    "délieras": "délier",
    "délierez": "délier",
    "délieriez": "délier",
    "délierions": "délier",
    "délierons": "délier",
    "délieront": "délier",
    "délies": "délier",
    "déliez": "délier",
    "déliiez": "délier",
    "déliions": "délier",
    "délimita": "délimiter",
    "délimitai": "délimiter",
    "délimitaient": "délimiter",
    "délimitais": "délimiter",
    "délimitait": "délimiter",
    "délimitant": "délimiter",
    "délimitas": "délimiter",
    "délimitasse": "délimiter",
    "délimitassent": "délimiter",
    "délimitasses": "délimiter",
    "délimitassiez": "délimiter",
    "délimitassions": "délimiter",
    "délimitations": "délimitation",
    "délimite": "délimiter",
    "délimitent": "délimiter",
    "délimitera": "délimiter",
    "délimiterai": "délimiter",
    "délimiteraient": "délimiter",
    "délimiterais": "délimiter",
    "délimiterait": "délimiter",
    "délimiteras": "délimiter",
    "délimiterez": "délimiter",
    "délimiteriez": "délimiter",
    "délimiterions": "délimiter",
    "délimiterons": "délimiter",
    "délimiteront": "délimiter",
    "délimites": "délimiter",
    "délimitez": "délimiter",
    "délimitiez": "délimiter",
    "délimitions": "délimiter",
    "délimitons": "délimiter",
    "délimitâmes": "délimiter",
    "délimitât": "délimiter",
    "délimitâtes": "délimiter",
    "délimitèrent": "délimiter",
    "délimité": "délimiter",
    "délimitée": "délimiter",
    "délimitées": "délimiter",
    "délimités": "délimiter",
    "délinquances": "délinquance",
    "délinquante": "délinquant",
    "délinquantes": "délinquant",
    "délinquants": "délinquant",
    "délinéaments": "délinéament",
    "délions": "délier",
    "déliquescences": "déliquescence",
    "déliquescente": "déliquescent",
    "déliquescentes": "déliquescent",
    "déliquescents": "déliquescent",
    "délira": "délirer",
    "délirai": "délirer",
    "déliraient": "délirer",
    "délirais": "délirer",
    "délirait": "délirer",
    "délirant": "délirer",
    "délirante": "délirant",
    "délirantes": "délirant",
    "délirants": "délirant",
    "déliras": "délirer",
    "délirasse": "délirer",
    "délirassent": "délirer",
    "délirasses": "délirer",
    "délirassiez": "délirer",
    "délirassions": "délirer",
    "délire": "délirer",
    "délirent": "délirer",
    "délirera": "délirer",
    "délirerai": "délirer",
    "délireraient": "délirer",
    "délirerais": "délirer",
    "délirerait": "délirer",
    "délireras": "délirer",
    "délirerez": "délirer",
    "délireriez": "délirer",
    "délirerions": "délirer",
    "délirerons": "délirer",
    "délireront": "délirer",
    "délires": "délirer",
    "délirez": "délirer",
    "déliriez": "délirer",
    "délirions": "délirer",
    "délirons": "délirer",
    "délirâmes": "délirer",
    "délirât": "délirer",
    "délirâtes": "délirer",
    "délirèrent": "délirer",
    "déliré": "délirer",
    "délitaient": "déliter",
    "délite": "déliter",
    "délitent": "déliter",
    "déliteront": "déliter",
    "délits": "délit",
    "délité": "déliter",
    "délitée": "déliter",
    "délitées": "déliter",
    "délivra": "délivrer",
    "délivrai": "délivrer",
    "délivraient": "délivrer",
    "délivrais": "délivrer",
    "délivrait": "délivrer",
    "délivrances": "délivrance",
    "délivrant": "délivrer",
    "délivras": "délivrer",
    "délivrasse": "délivrer",
    "délivrassent": "délivrer",
    "délivrasses": "délivrer",
    "délivrassiez": "délivrer",
    "délivrassions": "délivrer",
    "délivre": "délivrer",
    "délivrent": "délivrer",
    "délivrera": "délivrer",
    "délivrerai": "délivrer",
    "délivreraient": "délivrer",
    "délivrerais": "délivrer",
    "délivrerait": "délivrer",
    "délivreras": "délivrer",
    "délivrerez": "délivrer",
    "délivreriez": "délivrer",
    "délivrerions": "délivrer",
    "délivrerons": "délivrer",
    "délivreront": "délivrer",
    "délivres": "délivrer",
    "délivreurs": "délivreur",
    "délivrez": "délivrer",
    "délivriez": "délivrer",
    "délivrions": "délivrer",
    "délivrons": "délivrer",
    "délivrâmes": "délivrer",
    "délivrât": "délivrer",
    "délivrâtes": "délivrer",
    "délivrèrent": "délivrer",
    "délivré": "délivrer",
    "délivrée": "délivrer",
    "délivrées": "délivrer",
    "délivrés": "délivrer",
    "déliâmes": "délier",
    "déliât": "délier",
    "déliâtes": "délier",
    "délièrent": "délier",
    "délié": "délier",
    "déliée": "délier",
    "déliées": "délier",
    "déliés": "délier",
    "délocalisa": "délocaliser",
    "délocalisai": "délocaliser",
    "délocalisaient": "délocaliser",
    "délocalisais": "délocaliser",
    "délocalisait": "délocaliser",
    "délocalisant": "délocaliser",
    "délocalisas": "délocaliser",
    "délocalisasse": "délocaliser",
    "délocalisassent": "délocaliser",
    "délocalisasses": "délocaliser",
    "délocalisassiez": "délocaliser",
    "délocalisassions": "délocaliser",
    "délocalisations": "délocalisation",
    "délocalise": "délocaliser",
    "délocalisent": "délocaliser",
    "délocalisera": "délocaliser",
    "délocaliserai": "délocaliser",
    "délocaliseraient": "délocaliser",
    "délocaliserais": "délocaliser",
    "délocaliserait": "délocaliser",
    "délocaliseras": "délocaliser",
    "délocaliserez": "délocaliser",
    "délocaliseriez": "délocaliser",
    "délocaliserions": "délocaliser",
    "délocaliserons": "délocaliser",
    "délocaliseront": "délocaliser",
    "délocalises": "délocaliser",
    "délocalisez": "délocaliser",
    "délocalisiez": "délocaliser",
    "délocalisions": "délocaliser",
    "délocalisons": "délocaliser",
    "délocalisâmes": "délocaliser",
    "délocalisât": "délocaliser",
    "délocalisâtes": "délocaliser",
    "délocalisèrent": "délocaliser",
    "délocalisé": "délocaliser",
    "délocalisée": "délocaliser",
    "délocalisées": "délocaliser",
    "délocalisés": "délocaliser",
    "déloge": "déloger",
    "délogea": "déloger",
    "délogeai": "déloger",
    "délogeaient": "déloger",
    "délogeais": "déloger",
    "délogeait": "déloger",
    "délogeant": "déloger",
    "délogeas": "déloger",
    "délogeasse": "déloger",
    "délogeassent": "déloger",
    "délogeasses": "déloger",
    "délogeassiez": "déloger",
    "délogeassions": "déloger",
    "délogent": "déloger",
    "délogeons": "déloger",
    "délogera": "déloger",
    "délogerai": "déloger",
    "délogeraient": "déloger",
    "délogerais": "déloger",
    "délogerait": "déloger",
    "délogeras": "déloger",
    "délogerez": "déloger",
    "délogeriez": "déloger",
    "délogerions": "déloger",
    "délogerons": "déloger",
    "délogeront": "déloger",
    "déloges": "déloger",
    "délogez": "déloger",
    "délogeâmes": "déloger",
    "délogeât": "déloger",
    "délogeâtes": "déloger",
    "délogiez": "déloger",
    "délogions": "déloger",
    "délogèrent": "déloger",
    "délogé": "déloger",
    "délogée": "déloger",
    "délogées": "déloger",
    "délogés": "déloger",
    "déloquaient": "déloquer",
    "déloque": "déloquer",
    "déloques": "déloquer",
    "déloqué": "déloquer",
    "déloquées": "déloquer",
    "déloqués": "déloquer",
    "délourdant": "délourder",
    "déloyale": "déloyal",
    "déloyales": "déloyal",
    "déloyautés": "déloyauté",
    "déloyaux": "déloyal",
    "déluges": "déluge",
    "déluré": "délurer",
    "délurée": "délurer",
    "délurées": "délurer",
    "délurés": "déluré",
    "délustra": "délustrer",
    "délustrai": "délustrer",
    "délustraient": "délustrer",
    "délustrais": "délustrer",
    "délustrait": "délustrer",
    "délustrant": "délustrer",
    "délustras": "délustrer",
    "délustrasse": "délustrer",
    "délustrassent": "délustrer",
    "délustrasses": "délustrer",
    "délustrassiez": "délustrer",
    "délustrassions": "délustrer",
    "délustre": "délustrer",
    "délustrent": "délustrer",
    "délustrera": "délustrer",
    "délustrerai": "délustrer",
    "délustreraient": "délustrer",
    "délustrerais": "délustrer",
    "délustrerait": "délustrer",
    "délustreras": "délustrer",
    "délustrerez": "délustrer",
    "délustreriez": "délustrer",
    "délustrerions": "délustrer",
    "délustrerons": "délustrer",
    "délustreront": "délustrer",
    "délustres": "délustrer",
    "délustrez": "délustrer",
    "délustriez": "délustrer",
    "délustrions": "délustrer",
    "délustrons": "délustrer",
    "délustrâmes": "délustrer",
    "délustrât": "délustrer",
    "délustrâtes": "délustrer",
    "délustrèrent": "délustrer",
    "délustré": "délustrer",
    "délustrée": "délustrer",
    "délustrées": "délustrer",
    "délustrés": "délustrer",
    "délègue": "déléguer",
    "délèguent": "déléguer",
    "délègues": "déléguer",
    "délégations": "délégation",
    "délégua": "déléguer",
    "déléguai": "déléguer",
    "déléguaient": "déléguer",
    "déléguais": "déléguer",
    "déléguait": "déléguer",
    "déléguant": "déléguer",
    "déléguas": "déléguer",
    "déléguasse": "déléguer",
    "déléguassent": "déléguer",
    "déléguasses": "déléguer",
    "déléguassiez": "déléguer",
    "déléguassions": "déléguer",
    "déléguera": "déléguer",
    "déléguerai": "déléguer",
    "délégueraient": "déléguer",
    "déléguerais": "déléguer",
    "déléguerait": "déléguer",
    "délégueras": "déléguer",
    "déléguerez": "déléguer",
    "délégueriez": "déléguer",
    "déléguerions": "déléguer",
    "déléguerons": "déléguer",
    "délégueront": "déléguer",
    "déléguez": "déléguer",
    "déléguiez": "déléguer",
    "déléguions": "déléguer",
    "déléguons": "déléguer",
    "déléguâmes": "déléguer",
    "déléguât": "déléguer",
    "déléguâtes": "déléguer",
    "déléguèrent": "déléguer",
    "délégué": "déléguer",
    "déléguée": "déléguer",
    "déléguées": "déléguer",
    "délégués": "déléguer",
    "délétères": "délétère",
    "démagnétisé": "démagnétiser",
    "démagnétisée": "démagnétiser",
    "démagogies": "démagogie",
    "démagogiques": "démagogique",
    "démagogues": "démagogue",
    "démaigri": "démaigrir",
    "démaigrie": "démaigrir",
    "démaigries": "démaigrir",
    "démaigrira": "démaigrir",
    "démaigrirai": "démaigrir",
    "démaigriraient": "démaigrir",
    "démaigrirais": "démaigrir",
    "démaigrirait": "démaigrir",
    "démaigriras": "démaigrir",
    "démaigrirent": "démaigrir",
    "démaigrirez": "démaigrir",
    "démaigririez": "démaigrir",
    "démaigririons": "démaigrir",
    "démaigrirons": "démaigrir",
    "démaigriront": "démaigrir",
    "démaigris": "démaigrir",
    "démaigrissaient": "démaigrir",
    "démaigrissais": "démaigrir",
    "démaigrissait": "démaigrir",
    "démaigrissant": "démaigrir",
    "démaigrisse": "démaigrir",
    "démaigrissent": "démaigrir",
    "démaigrisses": "démaigrir",
    "démaigrissez": "démaigrir",
    "démaigrissiez": "démaigrir",
    "démaigrissions": "démaigrir",
    "démaigrissons": "démaigrir",
    "démaigrit": "démaigrir",
    "démaigrîmes": "démaigrir",
    "démaigrît": "démaigrir",
    "démaigrîtes": "démaigrir",
    "démailla": "démailler",
    "démaillai": "démailler",
    "démaillaient": "démailler",
    "démaillais": "démailler",
    "démaillait": "démailler",
    "démaillant": "démailler",
    "démaillas": "démailler",
    "démaillasse": "démailler",
    "démaillassent": "démailler",
    "démaillasses": "démailler",
    "démaillassiez": "démailler",
    "démaillassions": "démailler",
    "démaille": "démailler",
    "démaillent": "démailler",
    "démaillera": "démailler",
    "démaillerai": "démailler",
    "démailleraient": "démailler",
    "démaillerais": "démailler",
    "démaillerait": "démailler",
    "démailleras": "démailler",
    "démaillerez": "démailler",
    "démailleriez": "démailler",
    "démaillerions": "démailler",
    "démaillerons": "démailler",
    "démailleront": "démailler",
    "démailles": "démailler",
    "démaillez": "démailler",
    "démailliez": "démailler",
    "démaillions": "démailler",
    "démaillons": "démailler",
    "démaillota": "démailloter",
    "démaillotai": "démailloter",
    "démaillotaient": "démailloter",
    "démaillotais": "démailloter",
    "démaillotait": "démailloter",
    "démaillotant": "démailloter",
    "démaillotas": "démailloter",
    "démaillotasse": "démailloter",
    "démaillotassent": "démailloter",
    "démaillotasses": "démailloter",
    "démaillotassiez": "démailloter",
    "démaillotassions": "démailloter",
    "démaillote": "démailloter",
    "démaillotent": "démailloter",
    "démaillotera": "démailloter",
    "démailloterai": "démailloter",
    "démailloteraient": "démailloter",
    "démailloterais": "démailloter",
    "démailloterait": "démailloter",
    "démailloteras": "démailloter",
    "démailloterez": "démailloter",
    "démailloteriez": "démailloter",
    "démailloterions": "démailloter",
    "démailloterons": "démailloter",
    "démailloteront": "démailloter",
    "démaillotes": "démailloter",
    "démaillotez": "démailloter",
    "démaillotiez": "démailloter",
    "démaillotions": "démailloter",
    "démaillotons": "démailloter",
    "démaillotâmes": "démailloter",
    "démaillotât": "démailloter",
    "démaillotâtes": "démailloter",
    "démaillotèrent": "démailloter",
    "démailloté": "démailloter",
    "démaillotée": "démailloter",
    "démaillotées": "démailloter",
    "démaillotés": "démailloter",
    "démaillâmes": "démailler",
    "démaillât": "démailler",
    "démaillâtes": "démailler",
    "démaillèrent": "démailler",
    "démaillé": "démailler",
    "démaillée": "démailler",
    "démaillées": "démailler",
    "démaillés": "démailler",
    "démancha": "démancher",
    "démanchai": "démancher",
    "démanchaient": "démancher",
    "démanchais": "démancher",
    "démanchait": "démancher",
    "démanchant": "démancher",
    "démanchas": "démancher",
    "démanchasse": "démancher",
    "démanchassent": "démancher",
    "démanchasses": "démancher",
    "démanchassiez": "démancher",
    "démanchassions": "démancher",
    "démanche": "démancher",
    "démanchent": "démancher",
    "démanchera": "démancher",
    "démancherai": "démancher",
    "démancheraient": "démancher",
    "démancherais": "démancher",
    "démancherait": "démancher",
    "démancheras": "démancher",
    "démancherez": "démancher",
    "démancheriez": "démancher",
    "démancherions": "démancher",
    "démancherons": "démancher",
    "démancheront": "démancher",
    "démanches": "démancher",
    "démanchez": "démancher",
    "démanchiez": "démancher",
    "démanchions": "démancher",
    "démanchons": "démancher",
    "démanchâmes": "démancher",
    "démanchât": "démancher",
    "démanchâtes": "démancher",
    "démanchèrent": "démancher",
    "démanché": "démancher",
    "démanchée": "démancher",
    "démanchées": "démancher",
    "démanchés": "démancher",
    "démange": "démanger",
    "démangea": "démanger",
    "démangeai": "démanger",
    "démangeaient": "démanger",
    "démangeais": "démanger",
    "démangeaisons": "démangeaison",
    "démangeait": "démanger",
    "démangeant": "démanger",
    "démangeas": "démanger",
    "démangeasse": "démanger",
    "démangeassent": "démanger",
    "démangeasses": "démanger",
    "démangeassiez": "démanger",
    "démangeassions": "démanger",
    "démangent": "démanger",
    "démangeons": "démanger",
    "démangera": "démanger",
    "démangerai": "démanger",
    "démangeraient": "démanger",
    "démangerais": "démanger",
    "démangerait": "démanger",
    "démangeras": "démanger",
    "démangerez": "démanger",
    "démangeriez": "démanger",
    "démangerions": "démanger",
    "démangerons": "démanger",
    "démangeront": "démanger",
    "démanges": "démanger",
    "démangez": "démanger",
    "démangeâmes": "démanger",
    "démangeât": "démanger",
    "démangeâtes": "démanger",
    "démangiez": "démanger",
    "démangions": "démanger",
    "démangèrent": "démanger",
    "démangé": "démanger",
    "démangés": "démanger",
    "démantela": "démanteler",
    "démantelai": "démanteler",
    "démantelaient": "démanteler",
    "démantelais": "démanteler",
    "démantelait": "démanteler",
    "démantelant": "démanteler",
    "démantelas": "démanteler",
    "démantelasse": "démanteler",
    "démantelassent": "démanteler",
    "démantelasses": "démanteler",
    "démantelassiez": "démanteler",
    "démantelassions": "démanteler",
    "démantelez": "démanteler",
    "démanteliez": "démanteler",
    "démantelions": "démanteler",
    "démantelons": "démanteler",
    "démantelâmes": "démanteler",
    "démantelât": "démanteler",
    "démantelâtes": "démanteler",
    "démantelèrent": "démanteler",
    "démantelé": "démanteler",
    "démantelée": "démanteler",
    "démantelées": "démanteler",
    "démantelés": "démanteler",
    "démantibula": "démantibuler",
    "démantibulai": "démantibuler",
    "démantibulaient": "démantibuler",
    "démantibulais": "démantibuler",
    "démantibulait": "démantibuler",
    "démantibulant": "démantibuler",
    "démantibulas": "démantibuler",
    "démantibulasse": "démantibuler",
    "démantibulassent": "démantibuler",
    "démantibulasses": "démantibuler",
    "démantibulassiez": "démantibuler",
    "démantibulassions": "démantibuler",
    "démantibule": "démantibuler",
    "démantibulent": "démantibuler",
    "démantibulera": "démantibuler",
    "démantibulerai": "démantibuler",
    "démantibuleraient": "démantibuler",
    "démantibulerais": "démantibuler",
    "démantibulerait": "démantibuler",
    "démantibuleras": "démantibuler",
    "démantibulerez": "démantibuler",
    "démantibuleriez": "démantibuler",
    "démantibulerions": "démantibuler",
    "démantibulerons": "démantibuler",
    "démantibuleront": "démantibuler",
    "démantibules": "démantibuler",
    "démantibulez": "démantibuler",
    "démantibuliez": "démantibuler",
    "démantibulions": "démantibuler",
    "démantibulons": "démantibuler",
    "démantibulâmes": "démantibuler",
    "démantibulât": "démantibuler",
    "démantibulâtes": "démantibuler",
    "démantibulèrent": "démantibuler",
    "démantibulé": "démantibuler",
    "démantibulée": "démantibuler",
    "démantibulées": "démantibuler",
    "démantibulés": "démantibuler",
    "démantèle": "démanteler",
    "démantèlements": "démantèlement",
    "démantèlent": "démanteler",
    "démantèlera": "démanteler",
    "démantèlerai": "démanteler",
    "démantèleraient": "démanteler",
    "démantèlerais": "démanteler",
    "démantèlerait": "démanteler",
    "démantèleras": "démanteler",
    "démantèlerez": "démanteler",
    "démantèleriez": "démanteler",
    "démantèlerions": "démanteler",
    "démantèlerons": "démanteler",
    "démantèleront": "démanteler",
    "démantèles": "démanteler",
    "démaquilla": "démaquiller",
    "démaquillai": "démaquiller",
    "démaquillaient": "démaquiller",
    "démaquillais": "démaquiller",
    "démaquillait": "démaquiller",
    "démaquillant": "démaquiller",
    "démaquillante": "démaquillant",
    "démaquillas": "démaquiller",
    "démaquillasse": "démaquiller",
    "démaquillassent": "démaquiller",
    "démaquillasses": "démaquiller",
    "démaquillassiez": "démaquiller",
    "démaquillassions": "démaquiller",
    "démaquille": "démaquiller",
    "démaquillent": "démaquiller",
    "démaquillera": "démaquiller",
    "démaquillerai": "démaquiller",
    "démaquilleraient": "démaquiller",
    "démaquillerais": "démaquiller",
    "démaquillerait": "démaquiller",
    "démaquilleras": "démaquiller",
    "démaquillerez": "démaquiller",
    "démaquilleriez": "démaquiller",
    "démaquillerions": "démaquiller",
    "démaquillerons": "démaquiller",
    "démaquilleront": "démaquiller",
    "démaquilles": "démaquiller",
    "démaquillez": "démaquiller",
    "démaquilliez": "démaquiller",
    "démaquillions": "démaquiller",
    "démaquillons": "démaquiller",
    "démaquillâmes": "démaquiller",
    "démaquillât": "démaquiller",
    "démaquillâtes": "démaquiller",
    "démaquillèrent": "démaquiller",
    "démaquillé": "démaquiller",
    "démaquillée": "démaquiller",
    "démaquillées": "démaquiller",
    "démaquillés": "démaquiller",
    "démarcations": "démarcation",
    "démarcha": "démarcher",
    "démarchages": "démarchage",
    "démarchait": "démarcher",
    "démarche": "démarcher",
    "démarches": "démarche",
    "démarcheurs": "démarcheur",
    "démarcheuse": "démarcheur",
    "démaria": "démarier",
    "démariai": "démarier",
    "démariaient": "démarier",
    "démariais": "démarier",
    "démariait": "démarier",
    "démariant": "démarier",
    "démarias": "démarier",
    "démariasse": "démarier",
    "démariassent": "démarier",
    "démariasses": "démarier",
    "démariassiez": "démarier",
    "démariassions": "démarier",
    "démarie": "démarier",
    "démarient": "démarier",
    "démariera": "démarier",
    "démarierai": "démarier",
    "démarieraient": "démarier",
    "démarierais": "démarier",
    "démarierait": "démarier",
    "démarieras": "démarier",
    "démarierez": "démarier",
    "démarieriez": "démarier",
    "démarierions": "démarier",
    "démarierons": "démarier",
    "démarieront": "démarier",
    "démaries": "démarier",
    "démariez": "démarier",
    "démariiez": "démarier",
    "démariions": "démarier",
    "démarions": "démarier",
    "démariâmes": "démarier",
    "démariât": "démarier",
    "démariâtes": "démarier",
    "démarièrent": "démarier",
    "démarié": "démarier",
    "démariée": "démarier",
    "démariées": "démarier",
    "démariés": "démarier",
    "démarqua": "démarquer",
    "démarquai": "démarquer",
    "démarquaient": "démarquer",
    "démarquais": "démarquer",
    "démarquait": "démarquer",
    "démarquant": "démarquer",
    "démarquas": "démarquer",
    "démarquasse": "démarquer",
    "démarquassent": "démarquer",
    "démarquasses": "démarquer",
    "démarquassiez": "démarquer",
    "démarquassions": "démarquer",
    "démarque": "démarquer",
    "démarquent": "démarquer",
    "démarquera": "démarquer",
    "démarquerai": "démarquer",
    "démarqueraient": "démarquer",
    "démarquerais": "démarquer",
    "démarquerait": "démarquer",
    "démarqueras": "démarquer",
    "démarquerez": "démarquer",
    "démarqueriez": "démarquer",
    "démarquerions": "démarquer",
    "démarquerons": "démarquer",
    "démarqueront": "démarquer",
    "démarques": "démarquer",
    "démarquez": "démarquer",
    "démarquiez": "démarquer",
    "démarquions": "démarquer",
    "démarquons": "démarquer",
    "démarquâmes": "démarquer",
    "démarquât": "démarquer",
    "démarquâtes": "démarquer",
    "démarquèrent": "démarquer",
    "démarqué": "démarquer",
    "démarquée": "démarquer",
    "démarquées": "démarquer",
    "démarqués": "démarquer",
    "démarra": "démarrer",
    "démarrages": "démarrage",
    "démarrai": "démarrer",
    "démarraient": "démarrer",
    "démarrais": "démarrer",
    "démarrait": "démarrer",
    "démarrant": "démarrer",
    "démarras": "démarrer",
    "démarrasse": "démarrer",
    "démarrassent": "démarrer",
    "démarrasses": "démarrer",
    "démarrassiez": "démarrer",
    "démarrassions": "démarrer",
    "démarre": "démarrer",
    "démarrent": "démarrer",
    "démarrera": "démarrer",
    "démarrerai": "démarrer",
    "démarreraient": "démarrer",
    "démarrerais": "démarrer",
    "démarrerait": "démarrer",
    "démarreras": "démarrer",
    "démarrerez": "démarrer",
    "démarreriez": "démarrer",
    "démarrerions": "démarrer",
    "démarrerons": "démarrer",
    "démarreront": "démarrer",
    "démarres": "démarrer",
    "démarreurs": "démarreur",
    "démarrez": "démarrer",
    "démarriez": "démarrer",
    "démarrions": "démarrer",
    "démarrons": "démarrer",
    "démarrâmes": "démarrer",
    "démarrât": "démarrer",
    "démarrâtes": "démarrer",
    "démarrèrent": "démarrer",
    "démarré": "démarrer",
    "démarrée": "démarrer",
    "démarrées": "démarrer",
    "démarrés": "démarrer",
    "démasqua": "démasquer",
    "démasquai": "démasquer",
    "démasquaient": "démasquer",
    "démasquais": "démasquer",
    "démasquait": "démasquer",
    "démasquant": "démasquer",
    "démasquas": "démasquer",
    "démasquasse": "démasquer",
    "démasquassent": "démasquer",
    "démasquasses": "démasquer",
    "démasquassiez": "démasquer",
    "démasquassions": "démasquer",
    "démasque": "démasquer",
    "démasquent": "démasquer",
    "démasquera": "démasquer",
    "démasquerai": "démasquer",
    "démasqueraient": "démasquer",
    "démasquerais": "démasquer",
    "démasquerait": "démasquer",
    "démasqueras": "démasquer",
    "démasquerez": "démasquer",
    "démasqueriez": "démasquer",
    "démasquerions": "démasquer",
    "démasquerons": "démasquer",
    "démasqueront": "démasquer",
    "démasques": "démasquer",
    "démasquez": "démasquer",
    "démasquiez": "démasquer",
    "démasquions": "démasquer",
    "démasquons": "démasquer",
    "démasquâmes": "démasquer",
    "démasquât": "démasquer",
    "démasquâtes": "démasquer",
    "démasquèrent": "démasquer",
    "démasqué": "démasquer",
    "démasquée": "démasquer",
    "démasquées": "démasquer",
    "démasqués": "démasquer",
    "dématérialise": "dématérialiser",
    "dématérialisent": "dématérialiser",
    "dématérialisé": "dématérialiser",
    "démembra": "démembrer",
    "démembrai": "démembrer",
    "démembraient": "démembrer",
    "démembrais": "démembrer",
    "démembrait": "démembrer",
    "démembrant": "démembrer",
    "démembras": "démembrer",
    "démembrasse": "démembrer",
    "démembrassent": "démembrer",
    "démembrasses": "démembrer",
    "démembrassiez": "démembrer",
    "démembrassions": "démembrer",
    "démembre": "démembrer",
    "démembrements": "démembrement",
    "démembrent": "démembrer",
    "démembrera": "démembrer",
    "démembrerai": "démembrer",
    "démembreraient": "démembrer",
    "démembrerais": "démembrer",
    "démembrerait": "démembrer",
    "démembreras": "démembrer",
    "démembrerez": "démembrer",
    "démembreriez": "démembrer",
    "démembrerions": "démembrer",
    "démembrerons": "démembrer",
    "démembreront": "démembrer",
    "démembres": "démembrer",
    "démembrez": "démembrer",
    "démembriez": "démembrer",
    "démembrions": "démembrer",
    "démembrons": "démembrer",
    "démembrâmes": "démembrer",
    "démembrât": "démembrer",
    "démembrâtes": "démembrer",
    "démembrèrent": "démembrer",
    "démembré": "démembrer",
    "démembrée": "démembrer",
    "démembrées": "démembrer",
    "démembrés": "démembrer",
    "démena": "démener",
    "démenai": "démener",
    "démenaient": "démener",
    "démenais": "démener",
    "démenait": "démener",
    "démenant": "démener",
    "démenas": "démener",
    "démenasse": "démener",
    "démenassent": "démener",
    "démenasses": "démener",
    "démenassiez": "démener",
    "démenassions": "démener",
    "démences": "démence",
    "démenez": "démener",
    "démeniez": "démener",
    "démenions": "démener",
    "démenons": "démener",
    "démenotte": "démenotter",
    "démens": "démentir",
    "dément": "démentir",
    "démentaient": "démentir",
    "démentais": "démentir",
    "démentait": "démentir",
    "démentant": "démentir",
    "démente": "démentir",
    "démentent": "démentir",
    "démentes": "démentir",
    "démentez": "démentir",
    "démenti": "démentir",
    "démentie": "démentir",
    "démentielle": "démentiel",
    "démentielles": "démentiel",
    "démentiels": "démentiel",
    "démenties": "démentir",
    "démentiez": "démentir",
    "démentions": "démentir",
    "démentira": "démentir",
    "démentirai": "démentir",
    "démentiraient": "démentir",
    "démentirais": "démentir",
    "démentirait": "démentir",
    "démentiras": "démentir",
    "démentirent": "démentir",
    "démentirez": "démentir",
    "démentiriez": "démentir",
    "démentirions": "démentir",
    "démentirons": "démentir",
    "démentiront": "démentir",
    "démentis": "démentir",
    "démentisse": "démentir",
    "démentissent": "démentir",
    "démentisses": "démentir",
    "démentissiez": "démentir",
    "démentissions": "démentir",
    "démentit": "démentir",
    "démentons": "démentir",
    "déments": "dément",
    "démentîmes": "démentir",
    "démentît": "démentir",
    "démentîtes": "démentir",
    "démenâmes": "démener",
    "démenât": "démener",
    "démenâtes": "démener",
    "démenèrent": "démener",
    "démené": "démener",
    "démenée": "démener",
    "démenées": "démener",
    "démenés": "démener",
    "démerdaient": "démerder",
    "démerdais": "démerder",
    "démerdait": "démerder",
    "démerdards": "démerdard",
    "démerde": "démerder",
    "démerdent": "démerder",
    "démerdera": "démerder",
    "démerderai": "démerder",
    "démerderas": "démerder",
    "démerdes": "démerder",
    "démerdez": "démerder",
    "démerdé": "démerder",
    "démerdée": "démerder",
    "démerdés": "démerder",
    "démersale": "démersal",
    "démersales": "démersal",
    "démersaux": "démersal",
    "démesurent": "démesurer",
    "démesures": "démesure",
    "démesuré": "démesurer",
    "démesurée": "démesurer",
    "démesurées": "démesurer",
    "démesurés": "démesurer",
    "démet": "démettre",
    "démets": "démettre",
    "démettaient": "démettre",
    "démettais": "démettre",
    "démettait": "démettre",
    "démettant": "démettre",
    "démette": "démettre",
    "démettent": "démettre",
    "démettes": "démettre",
    "démettez": "démettre",
    "démettiez": "démettre",
    "démettions": "démettre",
    "démettons": "démettre",
    "démettra": "démettre",
    "démettrai": "démettre",
    "démettraient": "démettre",
    "démettrais": "démettre",
    "démettrait": "démettre",
    "démettras": "démettre",
    "démettrez": "démettre",
    "démettriez": "démettre",
    "démettrions": "démettre",
    "démettrons": "démettre",
    "démettront": "démettre",
    "démeubla": "démeubler",
    "démeublai": "démeubler",
    "démeublaient": "démeubler",
    "démeublais": "démeubler",
    "démeublait": "démeubler",
    "démeublant": "démeubler",
    "démeublas": "démeubler",
    "démeublasse": "démeubler",
    "démeublassent": "démeubler",
    "démeublasses": "démeubler",
    "démeublassiez": "démeubler",
    "démeublassions": "démeubler",
    "démeuble": "démeubler",
    "démeublent": "démeubler",
    "démeublera": "démeubler",
    "démeublerai": "démeubler",
    "démeubleraient": "démeubler",
    "démeublerais": "démeubler",
    "démeublerait": "démeubler",
    "démeubleras": "démeubler",
    "démeublerez": "démeubler",
    "démeubleriez": "démeubler",
    "démeublerions": "démeubler",
    "démeublerons": "démeubler",
    "démeubleront": "démeubler",
    "démeubles": "démeubler",
    "démeublez": "démeubler",
    "démeubliez": "démeubler",
    "démeublions": "démeubler",
    "démeublons": "démeubler",
    "démeublâmes": "démeubler",
    "démeublât": "démeubler",
    "démeublâtes": "démeubler",
    "démeublèrent": "démeubler",
    "démeublé": "démeubler",
    "démeublée": "démeubler",
    "démeublées": "démeubler",
    "démeublés": "démeubler",
    "démilitarisa": "démilitariser",
    "démilitarisai": "démilitariser",
    "démilitarisaient": "démilitariser",
    "démilitarisais": "démilitariser",
    "démilitarisait": "démilitariser",
    "démilitarisant": "démilitariser",
    "démilitarisas": "démilitariser",
    "démilitarisasse": "démilitariser",
    "démilitarisassent": "démilitariser",
    "démilitarisasses": "démilitariser",
    "démilitarisassiez": "démilitariser",
    "démilitarisassions": "démilitariser",
    "démilitarisations": "démilitarisation",
    "démilitarise": "démilitariser",
    "démilitarisent": "démilitariser",
    "démilitarisera": "démilitariser",
    "démilitariserai": "démilitariser",
    "démilitariseraient": "démilitariser",
    "démilitariserais": "démilitariser",
    "démilitariserait": "démilitariser",
    "démilitariseras": "démilitariser",
    "démilitariserez": "démilitariser",
    "démilitariseriez": "démilitariser",
    "démilitariserions": "démilitariser",
    "démilitariserons": "démilitariser",
    "démilitariseront": "démilitariser",
    "démilitarises": "démilitariser",
    "démilitarisez": "démilitariser",
    "démilitarisiez": "démilitariser",
    "démilitarisions": "démilitariser",
    "démilitarisons": "démilitariser",
    "démilitarisâmes": "démilitariser",
    "démilitarisât": "démilitariser",
    "démilitarisâtes": "démilitariser",
    "démilitarisèrent": "démilitariser",
    "démilitarisé": "démilitariser",
    "démilitarisée": "démilitariser",
    "démilitarisées": "démilitariser",
    "démilitarisés": "démilitariser",
    "démina": "déminer",
    "déminages": "déminage",
    "déminai": "déminer",
    "déminaient": "déminer",
    "déminais": "déminer",
    "déminait": "déminer",
    "déminant": "déminer",
    "déminas": "déminer",
    "déminasse": "déminer",
    "déminassent": "déminer",
    "déminasses": "déminer",
    "déminassiez": "déminer",
    "déminassions": "déminer",
    "démine": "déminer",
    "déminent": "déminer",
    "déminera": "déminer",
    "déminerai": "déminer",
    "démineraient": "déminer",
    "déminerais": "déminer",
    "déminerait": "déminer",
    "démineras": "déminer",
    "déminerez": "déminer",
    "démineriez": "déminer",
    "déminerions": "déminer",
    "déminerons": "déminer",
    "démineront": "déminer",
    "démines": "déminer",
    "démineurs": "démineur",
    "déminez": "déminer",
    "déminiez": "déminer",
    "déminions": "déminer",
    "déminons": "déminer",
    "déminâmes": "déminer",
    "déminât": "déminer",
    "déminâtes": "déminer",
    "déminèrent": "déminer",
    "déminé": "déminer",
    "déminée": "déminer",
    "déminées": "déminer",
    "déminéralisa": "déminéraliser",
    "déminéralisai": "déminéraliser",
    "déminéralisaient": "déminéraliser",
    "déminéralisais": "déminéraliser",
    "déminéralisait": "déminéraliser",
    "déminéralisant": "déminéraliser",
    "déminéralisas": "déminéraliser",
    "déminéralisasse": "déminéraliser",
    "déminéralisassent": "déminéraliser",
    "déminéralisasses": "déminéraliser",
    "déminéralisassiez": "déminéraliser",
    "déminéralisassions": "déminéraliser",
    "déminéralise": "déminéraliser",
    "déminéralisent": "déminéraliser",
    "déminéralisera": "déminéraliser",
    "déminéraliserai": "déminéraliser",
    "déminéraliseraient": "déminéraliser",
    "déminéraliserais": "déminéraliser",
    "déminéraliserait": "déminéraliser",
    "déminéraliseras": "déminéraliser",
    "déminéraliserez": "déminéraliser",
    "déminéraliseriez": "déminéraliser",
    "déminéraliserions": "déminéraliser",
    "déminéraliserons": "déminéraliser",
    "déminéraliseront": "déminéraliser",
    "déminéralises": "déminéraliser",
    "déminéralisez": "déminéraliser",
    "déminéralisiez": "déminéraliser",
    "déminéralisions": "déminéraliser",
    "déminéralisons": "déminéraliser",
    "déminéralisâmes": "déminéraliser",
    "déminéralisât": "déminéraliser",
    "déminéralisâtes": "déminéraliser",
    "déminéralisèrent": "déminéraliser",
    "déminéralisé": "déminéraliser",
    "déminéralisée": "déminéraliser",
    "déminéralisées": "déminéraliser",
    "déminéralisés": "déminéraliser",
    "déminés": "déminer",
    "démirent": "démettre",
    "démis": "démettre",
    "démise": "démis",
    "démises": "démis",
    "démisse": "démettre",
    "démissent": "démettre",
    "démisses": "démettre",
    "démissiez": "démettre",
    "démissionna": "démissionner",
    "démissionnai": "démissionner",
    "démissionnaient": "démissionner",
    "démissionnaires": "démissionnaire",
    "démissionnais": "démissionner",
    "démissionnait": "démissionner",
    "démissionnant": "démissionner",
    "démissionnas": "démissionner",
    "démissionnasse": "démissionner",
    "démissionnassent": "démissionner",
    "démissionnasses": "démissionner",
    "démissionnassiez": "démissionner",
    "démissionnassions": "démissionner",
    "démissionne": "démissionner",
    "démissionnent": "démissionner",
    "démissionnera": "démissionner",
    "démissionnerai": "démissionner",
    "démissionneraient": "démissionner",
    "démissionnerais": "démissionner",
    "démissionnerait": "démissionner",
    "démissionneras": "démissionner",
    "démissionnerez": "démissionner",
    "démissionneriez": "démissionner",
    "démissionnerions": "démissionner",
    "démissionnerons": "démissionner",
    "démissionneront": "démissionner",
    "démissionnes": "démissionner",
    "démissionnez": "démissionner",
    "démissionniez": "démissionner",
    "démissionnions": "démissionner",
    "démissionnons": "démissionner",
    "démissionnâmes": "démissionner",
    "démissionnât": "démissionner",
    "démissionnâtes": "démissionner",
    "démissionnèrent": "démissionner",
    "démissionné": "démissionner",
    "démissionnée": "démissionner",
    "démissionnées": "démissionner",
    "démissionnés": "démissionner",
    "démissions": "démission",
    "démit": "démettre",
    "démiurges": "démiurge",
    "démobilisa": "démobiliser",
    "démobilisai": "démobiliser",
    "démobilisaient": "démobiliser",
    "démobilisais": "démobiliser",
    "démobilisait": "démobiliser",
    "démobilisant": "démobiliser",
    "démobilisas": "démobiliser",
    "démobilisasse": "démobiliser",
    "démobilisassent": "démobiliser",
    "démobilisasses": "démobiliser",
    "démobilisassiez": "démobiliser",
    "démobilisassions": "démobiliser",
    "démobilisations": "démobilisation",
    "démobilise": "démobiliser",
    "démobilisent": "démobiliser",
    "démobilisera": "démobiliser",
    "démobiliserai": "démobiliser",
    "démobiliseraient": "démobiliser",
    "démobiliserais": "démobiliser",
    "démobiliserait": "démobiliser",
    "démobiliseras": "démobiliser",
    "démobiliserez": "démobiliser",
    "démobiliseriez": "démobiliser",
    "démobiliserions": "démobiliser",
    "démobiliserons": "démobiliser",
    "démobiliseront": "démobiliser",
    "démobilises": "démobiliser",
    "démobilisez": "démobiliser",
    "démobilisiez": "démobiliser",
    "démobilisions": "démobiliser",
    "démobilisons": "démobiliser",
    "démobilisâmes": "démobiliser",
    "démobilisât": "démobiliser",
    "démobilisâtes": "démobiliser",
    "démobilisèrent": "démobiliser",
    "démobilisé": "démobiliser",
    "démobilisée": "démobiliser",
    "démobilisées": "démobiliser",
    "démobilisés": "démobiliser",
    "démocrate-chrétienne": "démocrate-chrétien",
    "démocrates": "démocrate",
    "démocrates-chrétiennes": "démocrate-chrétien",
    "démocrates-chrétiens": "démocrate-chrétien",
    "démocraties": "démocratie",
    "démocratiques": "démocratique",
    "démocratisa": "démocratiser",
    "démocratisai": "démocratiser",
    "démocratisaient": "démocratiser",
    "démocratisais": "démocratiser",
    "démocratisait": "démocratiser",
    "démocratisant": "démocratiser",
    "démocratisas": "démocratiser",
    "démocratisasse": "démocratiser",
    "démocratisassent": "démocratiser",
    "démocratisasses": "démocratiser",
    "démocratisassiez": "démocratiser",
    "démocratisassions": "démocratiser",
    "démocratisations": "démocratisation",
    "démocratise": "démocratiser",
    "démocratisent": "démocratiser",
    "démocratisera": "démocratiser",
    "démocratiserai": "démocratiser",
    "démocratiseraient": "démocratiser",
    "démocratiserais": "démocratiser",
    "démocratiserait": "démocratiser",
    "démocratiseras": "démocratiser",
    "démocratiserez": "démocratiser",
    "démocratiseriez": "démocratiser",
    "démocratiserions": "démocratiser",
    "démocratiserons": "démocratiser",
    "démocratiseront": "démocratiser",
    "démocratises": "démocratiser",
    "démocratisez": "démocratiser",
    "démocratisiez": "démocratiser",
    "démocratisions": "démocratiser",
    "démocratisons": "démocratiser",
    "démocratisâmes": "démocratiser",
    "démocratisât": "démocratiser",
    "démocratisâtes": "démocratiser",
    "démocratisèrent": "démocratiser",
    "démocratisé": "démocratiser",
    "démocratisée": "démocratiser",
    "démocratisées": "démocratiser",
    "démocratisés": "démocratiser",
    "démoda": "démoder",
    "démodai": "démoder",
    "démodaient": "démoder",
    "démodais": "démoder",
    "démodait": "démoder",
    "démodant": "démoder",
    "démodas": "démoder",
    "démodasse": "démoder",
    "démodassent": "démoder",
    "démodasses": "démoder",
    "démodassiez": "démoder",
    "démodassions": "démoder",
    "démode": "démoder",
    "démodent": "démoder",
    "démodera": "démoder",
    "démoderai": "démoder",
    "démoderaient": "démoder",
    "démoderais": "démoder",
    "démoderait": "démoder",
    "démoderas": "démoder",
    "démoderez": "démoder",
    "démoderiez": "démoder",
    "démoderions": "démoder",
    "démoderons": "démoder",
    "démoderont": "démoder",
    "démodes": "démoder",
    "démodez": "démoder",
    "démodiez": "démoder",
    "démodions": "démoder",
    "démodons": "démoder",
    "démodulateurs": "démodulateur",
    "démodâmes": "démoder",
    "démodât": "démoder",
    "démodâtes": "démoder",
    "démodèrent": "démoder",
    "démodé": "démoder",
    "démodée": "démoder",
    "démodées": "démoder",
    "démodés": "démoder",
    "démographies": "démographie",
    "démographiques": "démographique",
    "démoli": "démolir",
    "démolie": "démolir",
    "démolies": "démolir",
    "démolira": "démolir",
    "démolirai": "démolir",
    "démoliraient": "démolir",
    "démolirais": "démolir",
    "démolirait": "démolir",
    "démoliras": "démolir",
    "démolirent": "démolir",
    "démolirez": "démolir",
    "démoliriez": "démolir",
    "démolirions": "démolir",
    "démolirons": "démolir",
    "démoliront": "démolir",
    "démolis": "démolir",
    "démolissaient": "démolir",
    "démolissais": "démolir",
    "démolissait": "démolir",
    "démolissant": "démolir",
    "démolisse": "démolir",
    "démolissent": "démolir",
    "démolisses": "démolir",
    "démolisseurs": "démolisseur",
    "démolisseuse": "démolisseur",
    "démolissez": "démolir",
    "démolissiez": "démolir",
    "démolissions": "démolir",
    "démolissons": "démolir",
    "démolit": "démolir",
    "démolitions": "démolition",
    "démolîmes": "démolir",
    "démolît": "démolir",
    "démolîtes": "démolir",
    "démone": "démon",
    "démones": "démon",
    "démoniaques": "démoniaque",
    "démonopolisations": "démonopolisation",
    "démons": "démon",
    "démonstrateurs": "démonstrateur",
    "démonstratifs": "démonstratif",
    "démonstrations": "démonstration",
    "démonstrative": "démonstratif",
    "démonstratives": "démonstratif",
    "démonstratrice": "démonstrateur",
    "démonta": "démonter",
    "démontables": "démontable",
    "démontages": "démontage",
    "démontai": "démonter",
    "démontaient": "démonter",
    "démontais": "démonter",
    "démontait": "démonter",
    "démontant": "démonter",
    "démontas": "démonter",
    "démontasse": "démonter",
    "démontassent": "démonter",
    "démontasses": "démonter",
    "démontassiez": "démonter",
    "démontassions": "démonter",
    "démonte": "démonter",
    "démonte-pneus": "démonte-pneu",
    "démontent": "démonter",
    "démontera": "démonter",
    "démonterai": "démonter",
    "démonteraient": "démonter",
    "démonterais": "démonter",
    "démonterait": "démonter",
    "démonteras": "démonter",
    "démonterez": "démonter",
    "démonteriez": "démonter",
    "démonterions": "démonter",
    "démonterons": "démonter",
    "démonteront": "démonter",
    "démontes": "démonter",
    "démontez": "démonter",
    "démontiez": "démonter",
    "démontions": "démonter",
    "démontons": "démonter",
    "démontra": "démontrer",
    "démontrai": "démontrer",
    "démontraient": "démontrer",
    "démontrais": "démontrer",
    "démontrait": "démontrer",
    "démontrant": "démontrer",
    "démontras": "démontrer",
    "démontrasse": "démontrer",
    "démontrassent": "démontrer",
    "démontrasses": "démontrer",
    "démontrassiez": "démontrer",
    "démontrassions": "démontrer",
    "démontre": "démontrer",
    "démontrent": "démontrer",
    "démontrera": "démontrer",
    "démontrerai": "démontrer",
    "démontreraient": "démontrer",
    "démontrerais": "démontrer",
    "démontrerait": "démontrer",
    "démontreras": "démontrer",
    "démontrerez": "démontrer",
    "démontreriez": "démontrer",
    "démontrerions": "démontrer",
    "démontrerons": "démontrer",
    "démontreront": "démontrer",
    "démontres": "démontrer",
    "démontrez": "démontrer",
    "démontriez": "démontrer",
    "démontrions": "démontrer",
    "démontrons": "démontrer",
    "démontrâmes": "démontrer",
    "démontrât": "démontrer",
    "démontrâtes": "démontrer",
    "démontrèrent": "démontrer",
    "démontré": "démontrer",
    "démontrée": "démontrer",
    "démontrées": "démontrer",
    "démontrés": "démontrer",
    "démontâmes": "démonter",
    "démontât": "démonter",
    "démontâtes": "démonter",
    "démontèrent": "démonter",
    "démonté": "démonter",
    "démontée": "démonter",
    "démontées": "démonter",
    "démontés": "démonter",
    "démonétisa": "démonétiser",
    "démonétisai": "démonétiser",
    "démonétisaient": "démonétiser",
    "démonétisais": "démonétiser",
    "démonétisait": "démonétiser",
    "démonétisant": "démonétiser",
    "démonétisas": "démonétiser",
    "démonétisasse": "démonétiser",
    "démonétisassent": "démonétiser",
    "démonétisasses": "démonétiser",
    "démonétisassiez": "démonétiser",
    "démonétisassions": "démonétiser",
    "démonétise": "démonétiser",
    "démonétisent": "démonétiser",
    "démonétisera": "démonétiser",
    "démonétiserai": "démonétiser",
    "démonétiseraient": "démonétiser",
    "démonétiserais": "démonétiser",
    "démonétiserait": "démonétiser",
    "démonétiseras": "démonétiser",
    "démonétiserez": "démonétiser",
    "démonétiseriez": "démonétiser",
    "démonétiserions": "démonétiser",
    "démonétiserons": "démonétiser",
    "démonétiseront": "démonétiser",
    "démonétises": "démonétiser",
    "démonétisez": "démonétiser",
    "démonétisiez": "démonétiser",
    "démonétisions": "démonétiser",
    "démonétisons": "démonétiser",
    "démonétisâmes": "démonétiser",
    "démonétisât": "démonétiser",
    "démonétisâtes": "démonétiser",
    "démonétisèrent": "démonétiser",
    "démonétisé": "démonétiser",
    "démonétisée": "démonétiser",
    "démonétisées": "démonétiser",
    "démonétisés": "démonétiser",
    "démoralisa": "démoraliser",
    "démoralisai": "démoraliser",
    "démoralisaient": "démoraliser",
    "démoralisais": "démoraliser",
    "démoralisait": "démoraliser",
    "démoralisant": "démoraliser",
    "démoralisante": "démoralisant",
    "démoralisants": "démoralisant",
    "démoralisas": "démoraliser",
    "démoralisasse": "démoraliser",
    "démoralisassent": "démoraliser",
    "démoralisasses": "démoraliser",
    "démoralisassiez": "démoraliser",
    "démoralisassions": "démoraliser",
    "démoralisateurs": "démoralisateur",
    "démoralise": "démoraliser",
    "démoralisent": "démoraliser",
    "démoralisera": "démoraliser",
    "démoraliserai": "démoraliser",
    "démoraliseraient": "démoraliser",
    "démoraliserais": "démoraliser",
    "démoraliserait": "démoraliser",
    "démoraliseras": "démoraliser",
    "démoraliserez": "démoraliser",
    "démoraliseriez": "démoraliser",
    "démoraliserions": "démoraliser",
    "démoraliserons": "démoraliser",
    "démoraliseront": "démoraliser",
    "démoralises": "démoraliser",
    "démoralisez": "démoraliser",
    "démoralisiez": "démoraliser",
    "démoralisions": "démoraliser",
    "démoralisons": "démoraliser",
    "démoralisâmes": "démoraliser",
    "démoralisât": "démoraliser",
    "démoralisâtes": "démoraliser",
    "démoralisèrent": "démoraliser",
    "démoralisé": "démoraliser",
    "démoralisée": "démoraliser",
    "démoralisées": "démoraliser",
    "démoralisés": "démoraliser",
    "démord": "démordre",
    "démordaient": "démordre",
    "démordais": "démordre",
    "démordait": "démordre",
    "démordant": "démordre",
    "démorde": "démordre",
    "démordent": "démordre",
    "démordes": "démordre",
    "démordez": "démordre",
    "démordiez": "démordre",
    "démordions": "démordre",
    "démordirent": "démordre",
    "démordis": "démordre",
    "démordisse": "démordre",
    "démordissent": "démordre",
    "démordisses": "démordre",
    "démordissiez": "démordre",
    "démordissions": "démordre",
    "démordit": "démordre",
    "démordons": "démordre",
    "démordra": "démordre",
    "démordrai": "démordre",
    "démordraient": "démordre",
    "démordrais": "démordre",
    "démordrait": "démordre",
    "démordras": "démordre",
    "démordrez": "démordre",
    "démordriez": "démordre",
    "démordrions": "démordre",
    "démordrons": "démordre",
    "démordront": "démordre",
    "démords": "démordre",
    "démordu": "démordre",
    "démordîmes": "démordre",
    "démordît": "démordre",
    "démordîtes": "démordre",
    "démotivations": "démotivation",
    "démotive": "démotiver",
    "démotivée": "démotiver",
    "démoucheté": "démoucheter",
    "démoula": "démouler",
    "démoulai": "démouler",
    "démoulaient": "démouler",
    "démoulais": "démouler",
    "démoulait": "démouler",
    "démoulant": "démouler",
    "démoulas": "démouler",
    "démoulasse": "démouler",
    "démoulassent": "démouler",
    "démoulasses": "démouler",
    "démoulassiez": "démouler",
    "démoulassions": "démouler",
    "démoule": "démouler",
    "démoulent": "démouler",
    "démoulera": "démouler",
    "démoulerai": "démouler",
    "démouleraient": "démouler",
    "démoulerais": "démouler",
    "démoulerait": "démouler",
    "démouleras": "démouler",
    "démoulerez": "démouler",
    "démouleriez": "démouler",
    "démoulerions": "démouler",
    "démoulerons": "démouler",
    "démouleront": "démouler",
    "démoules": "démouler",
    "démoulez": "démouler",
    "démouliez": "démouler",
    "démoulions": "démouler",
    "démoulons": "démouler",
    "démoulâmes": "démouler",
    "démoulât": "démouler",
    "démoulâtes": "démouler",
    "démoulèrent": "démouler",
    "démoulé": "démouler",
    "démoulée": "démouler",
    "démoulées": "démouler",
    "démoulés": "démouler",
    "démoustications": "démoustication",
    "démoustiqua": "démoustiquer",
    "démoustiquai": "démoustiquer",
    "démoustiquaient": "démoustiquer",
    "démoustiquais": "démoustiquer",
    "démoustiquait": "démoustiquer",
    "démoustiquant": "démoustiquer",
    "démoustiquas": "démoustiquer",
    "démoustiquasse": "démoustiquer",
    "démoustiquassent": "démoustiquer",
    "démoustiquasses": "démoustiquer",
    "démoustiquassiez": "démoustiquer",
    "démoustiquassions": "démoustiquer",
    "démoustique": "démoustiquer",
    "démoustiquent": "démoustiquer",
    "démoustiquera": "démoustiquer",
    "démoustiquerai": "démoustiquer",
    "démoustiqueraient": "démoustiquer",
    "démoustiquerais": "démoustiquer",
    "démoustiquerait": "démoustiquer",
    "démoustiqueras": "démoustiquer",
    "démoustiquerez": "démoustiquer",
    "démoustiqueriez": "démoustiquer",
    "démoustiquerions": "démoustiquer",
    "démoustiquerons": "démoustiquer",
    "démoustiqueront": "démoustiquer",
    "démoustiques": "démoustiquer",
    "démoustiquez": "démoustiquer",
    "démoustiquiez": "démoustiquer",
    "démoustiquions": "démoustiquer",
    "démoustiquons": "démoustiquer",
    "démoustiquâmes": "démoustiquer",
    "démoustiquât": "démoustiquer",
    "démoustiquâtes": "démoustiquer",
    "démoustiquèrent": "démoustiquer",
    "démoustiqué": "démoustiquer",
    "démoustiquée": "démoustiquer",
    "démoustiquées": "démoustiquer",
    "démoustiqués": "démoustiquer",
    "démultiplia": "démultiplier",
    "démultipliai": "démultiplier",
    "démultipliaient": "démultiplier",
    "démultipliais": "démultiplier",
    "démultipliait": "démultiplier",
    "démultipliant": "démultiplier",
    "démultiplias": "démultiplier",
    "démultipliasse": "démultiplier",
    "démultipliassent": "démultiplier",
    "démultipliasses": "démultiplier",
    "démultipliassiez": "démultiplier",
    "démultipliassions": "démultiplier",
    "démultiplications": "démultiplication",
    "démultiplie": "démultiplier",
    "démultiplient": "démultiplier",
    "démultipliera": "démultiplier",
    "démultiplierai": "démultiplier",
    "démultiplieraient": "démultiplier",
    "démultiplierais": "démultiplier",
    "démultiplierait": "démultiplier",
    "démultiplieras": "démultiplier",
    "démultiplierez": "démultiplier",
    "démultiplieriez": "démultiplier",
    "démultiplierions": "démultiplier",
    "démultiplierons": "démultiplier",
    "démultiplieront": "démultiplier",
    "démultiplies": "démultiplier",
    "démultipliez": "démultiplier",
    "démultipliiez": "démultiplier",
    "démultipliions": "démultiplier",
    "démultiplions": "démultiplier",
    "démultipliâmes": "démultiplier",
    "démultipliât": "démultiplier",
    "démultipliâtes": "démultiplier",
    "démultiplièrent": "démultiplier",
    "démultiplié": "démultiplier",
    "démultipliée": "démultiplier",
    "démultipliées": "démultiplier",
    "démultipliés": "démultiplier",
    "démuni": "démunir",
    "démunie": "démunir",
    "démunies": "démunir",
    "démunira": "démunir",
    "démunirai": "démunir",
    "démuniraient": "démunir",
    "démunirais": "démunir",
    "démunirait": "démunir",
    "démuniras": "démunir",
    "démunirent": "démunir",
    "démunirez": "démunir",
    "démuniriez": "démunir",
    "démunirions": "démunir",
    "démunirons": "démunir",
    "démuniront": "démunir",
    "démunis": "démunir",
    "démunissaient": "démunir",
    "démunissais": "démunir",
    "démunissait": "démunir",
    "démunissant": "démunir",
    "démunisse": "démunir",
    "démunissent": "démunir",
    "démunisses": "démunir",
    "démunissez": "démunir",
    "démunissiez": "démunir",
    "démunissions": "démunir",
    "démunissons": "démunir",
    "démunit": "démunir",
    "démunîmes": "démunir",
    "démunît": "démunir",
    "démunîtes": "démunir",
    "démurge": "démurger",
    "démusela": "démuseler",
    "démuselai": "démuseler",
    "démuselaient": "démuseler",
    "démuselais": "démuseler",
    "démuselait": "démuseler",
    "démuselant": "démuseler",
    "démuselas": "démuseler",
    "démuselasse": "démuseler",
    "démuselassent": "démuseler",
    "démuselasses": "démuseler",
    "démuselassiez": "démuseler",
    "démuselassions": "démuseler",
    "démuselez": "démuseler",
    "démuseliez": "démuseler",
    "démuselions": "démuseler",
    "démuselle": "démuseler",
    "démusellent": "démuseler",
    "démusellera": "démuseler",
    "démusellerai": "démuseler",
    "démuselleraient": "démuseler",
    "démusellerais": "démuseler",
    "démusellerait": "démuseler",
    "démuselleras": "démuseler",
    "démusellerez": "démuseler",
    "démuselleriez": "démuseler",
    "démusellerions": "démuseler",
    "démusellerons": "démuseler",
    "démuselleront": "démuseler",
    "démuselles": "démuseler",
    "démuselons": "démuseler",
    "démuselâmes": "démuseler",
    "démuselât": "démuseler",
    "démuselâtes": "démuseler",
    "démuselèrent": "démuseler",
    "démuselé": "démuseler",
    "démuselée": "démuseler",
    "démuselées": "démuseler",
    "démuselés": "démuseler",
    "démystifia": "démystifier",
    "démystifiai": "démystifier",
    "démystifiaient": "démystifier",
    "démystifiais": "démystifier",
    "démystifiait": "démystifier",
    "démystifiant": "démystifier",
    "démystifias": "démystifier",
    "démystifiasse": "démystifier",
    "démystifiassent": "démystifier",
    "démystifiasses": "démystifier",
    "démystifiassiez": "démystifier",
    "démystifiassions": "démystifier",
    "démystifications": "démystification",
    "démystificatrice": "démystificateur",
    "démystifie": "démystifier",
    "démystifient": "démystifier",
    "démystifiera": "démystifier",
    "démystifierai": "démystifier",
    "démystifieraient": "démystifier",
    "démystifierais": "démystifier",
    "démystifierait": "démystifier",
    "démystifieras": "démystifier",
    "démystifierez": "démystifier",
    "démystifieriez": "démystifier",
    "démystifierions": "démystifier",
    "démystifierons": "démystifier",
    "démystifieront": "démystifier",
    "démystifies": "démystifier",
    "démystifiez": "démystifier",
    "démystifiiez": "démystifier",
    "démystifiions": "démystifier",
    "démystifions": "démystifier",
    "démystifiâmes": "démystifier",
    "démystifiât": "démystifier",
    "démystifiâtes": "démystifier",
    "démystifièrent": "démystifier",
    "démystifié": "démystifier",
    "démystifiée": "démystifier",
    "démystifiées": "démystifier",
    "démystifiés": "démystifier",
    "démythifie": "démythifier",
    "démythifié": "démythifier",
    "démâta": "démâter",
    "démâtages": "démâtage",
    "démâtai": "démâter",
    "démâtaient": "démâter",
    "démâtais": "démâter",
    "démâtait": "démâter",
    "démâtant": "démâter",
    "démâtas": "démâter",
    "démâtasse": "démâter",
    "démâtassent": "démâter",
    "démâtasses": "démâter",
    "démâtassiez": "démâter",
    "démâtassions": "démâter",
    "démâte": "démâter",
    "démâtent": "démâter",
    "démâtera": "démâter",
    "démâterai": "démâter",
    "démâteraient": "démâter",
    "démâterais": "démâter",
    "démâterait": "démâter",
    "démâteras": "démâter",
    "démâterez": "démâter",
    "démâteriez": "démâter",
    "démâterions": "démâter",
    "démâterons": "démâter",
    "démâteront": "démâter",
    "démâtes": "démâter",
    "démâtez": "démâter",
    "démâtiez": "démâter",
    "démâtions": "démâter",
    "démâtons": "démâter",
    "démâtâmes": "démâter",
    "démâtât": "démâter",
    "démâtâtes": "démâter",
    "démâtèrent": "démâter",
    "démâté": "démâter",
    "démâtée": "démâter",
    "démâtées": "démâter",
    "démâtés": "démâter",
    "démène": "démener",
    "démènent": "démener",
    "démènera": "démener",
    "démènerai": "démener",
    "démèneraient": "démener",
    "démènerais": "démener",
    "démènerait": "démener",
    "démèneras": "démener",
    "démènerez": "démener",
    "démèneriez": "démener",
    "démènerions": "démener",
    "démènerons": "démener",
    "démèneront": "démener",
    "démènes": "démener",
    "déménage": "déménager",
    "déménagea": "déménager",
    "déménageai": "déménager",
    "déménageaient": "déménager",
    "déménageais": "déménager",
    "déménageait": "déménager",
    "déménageant": "déménager",
    "déménageas": "déménager",
    "déménageasse": "déménager",
    "déménageassent": "déménager",
    "déménageasses": "déménager",
    "déménageassiez": "déménager",
    "déménageassions": "déménager",
    "déménagements": "déménagement",
    "déménagent": "déménager",
    "déménageons": "déménager",
    "déménagera": "déménager",
    "déménagerai": "déménager",
    "déménageraient": "déménager",
    "déménagerais": "déménager",
    "déménagerait": "déménager",
    "déménageras": "déménager",
    "déménagerez": "déménager",
    "déménageriez": "déménager",
    "déménagerions": "déménager",
    "déménagerons": "déménager",
    "déménageront": "déménager",
    "déménages": "déménager",
    "déménageurs": "déménageur",
    "déménageuse": "déménageur",
    "déménagez": "déménager",
    "déménageâmes": "déménager",
    "déménageât": "déménager",
    "déménageâtes": "déménager",
    "déménagiez": "déménager",
    "déménagions": "déménager",
    "déménagèrent": "déménager",
    "déménagé": "déménager",
    "déménagée": "déménager",
    "déménagées": "déménager",
    "déménagés": "déménager",
    "démérita": "démériter",
    "déméritai": "démériter",
    "déméritaient": "démériter",
    "déméritais": "démériter",
    "déméritait": "démériter",
    "déméritant": "démériter",
    "déméritas": "démériter",
    "déméritasse": "démériter",
    "déméritassent": "démériter",
    "déméritasses": "démériter",
    "déméritassiez": "démériter",
    "déméritassions": "démériter",
    "démérite": "démériter",
    "déméritent": "démériter",
    "déméritera": "démériter",
    "démériterai": "démériter",
    "démériteraient": "démériter",
    "démériterais": "démériter",
    "démériterait": "démériter",
    "démériteras": "démériter",
    "démériterez": "démériter",
    "démériteriez": "démériter",
    "démériterions": "démériter",
    "démériterons": "démériter",
    "démériteront": "démériter",
    "démérites": "démériter",
    "déméritez": "démériter",
    "déméritiez": "démériter",
    "déméritions": "démériter",
    "déméritons": "démériter",
    "déméritâmes": "démériter",
    "déméritât": "démériter",
    "déméritâtes": "démériter",
    "déméritèrent": "démériter",
    "démérité": "démériter",
    "démêla": "démêler",
    "démêlai": "démêler",
    "démêlaient": "démêler",
    "démêlais": "démêler",
    "démêlait": "démêler",
    "démêlant": "démêler",
    "démêlas": "démêler",
    "démêlasse": "démêler",
    "démêlassent": "démêler",
    "démêlasses": "démêler",
    "démêlassiez": "démêler",
    "démêlassions": "démêler",
    "démêle": "démêler",
    "démêlent": "démêler",
    "démêlera": "démêler",
    "démêlerai": "démêler",
    "démêleraient": "démêler",
    "démêlerais": "démêler",
    "démêlerait": "démêler",
    "démêleras": "démêler",
    "démêlerez": "démêler",
    "démêleriez": "démêler",
    "démêlerions": "démêler",
    "démêlerons": "démêler",
    "démêleront": "démêler",
    "démêles": "démêler",
    "démêlez": "démêler",
    "démêliez": "démêler",
    "démêlions": "démêler",
    "démêlons": "démêler",
    "démêlâmes": "démêler",
    "démêlât": "démêler",
    "démêlâtes": "démêler",
    "démêlèrent": "démêler",
    "démêlé": "démêler",
    "démêlée": "démêler",
    "démêlées": "démêler",
    "démêlés": "démêler",
    "démîmes": "démettre",
    "démît": "démettre",
    "démîtes": "démettre",
    "dénanti": "dénantir",
    "dénantie": "dénantir",
    "dénanties": "dénantir",
    "dénantira": "dénantir",
    "dénantirai": "dénantir",
    "dénantiraient": "dénantir",
    "dénantirais": "dénantir",
    "dénantirait": "dénantir",
    "dénantiras": "dénantir",
    "dénantirent": "dénantir",
    "dénantirez": "dénantir",
    "dénantiriez": "dénantir",
    "dénantirions": "dénantir",
    "dénantirons": "dénantir",
    "dénantiront": "dénantir",
    "dénantis": "dénantir",
    "dénantissaient": "dénantir",
    "dénantissais": "dénantir",
    "dénantissait": "dénantir",
    "dénantissant": "dénantir",
    "dénantisse": "dénantir",
    "dénantissent": "dénantir",
    "dénantisses": "dénantir",
    "dénantissez": "dénantir",
    "dénantissiez": "dénantir",
    "dénantissions": "dénantir",
    "dénantissons": "dénantir",
    "dénantit": "dénantir",
    "dénantîmes": "dénantir",
    "dénantît": "dénantir",
    "dénantîtes": "dénantir",
    "dénatalités": "dénatalité",
    "dénationalisa": "dénationaliser",
    "dénationalisai": "dénationaliser",
    "dénationalisaient": "dénationaliser",
    "dénationalisais": "dénationaliser",
    "dénationalisait": "dénationaliser",
    "dénationalisant": "dénationaliser",
    "dénationalisas": "dénationaliser",
    "dénationalisasse": "dénationaliser",
    "dénationalisassent": "dénationaliser",
    "dénationalisasses": "dénationaliser",
    "dénationalisassiez": "dénationaliser",
    "dénationalisassions": "dénationaliser",
    "dénationalisations": "dénationalisation",
    "dénationalise": "dénationaliser",
    "dénationalisent": "dénationaliser",
    "dénationalisera": "dénationaliser",
    "dénationaliserai": "dénationaliser",
    "dénationaliseraient": "dénationaliser",
    "dénationaliserais": "dénationaliser",
    "dénationaliserait": "dénationaliser",
    "dénationaliseras": "dénationaliser",
    "dénationaliserez": "dénationaliser",
    "dénationaliseriez": "dénationaliser",
    "dénationaliserions": "dénationaliser",
    "dénationaliserons": "dénationaliser",
    "dénationaliseront": "dénationaliser",
    "dénationalises": "dénationaliser",
    "dénationalisez": "dénationaliser",
    "dénationalisiez": "dénationaliser",
    "dénationalisions": "dénationaliser",
    "dénationalisons": "dénationaliser",
    "dénationalisâmes": "dénationaliser",
    "dénationalisât": "dénationaliser",
    "dénationalisâtes": "dénationaliser",
    "dénationalisèrent": "dénationaliser",
    "dénationalisé": "dénationaliser",
    "dénationalisée": "dénationaliser",
    "dénationalisées": "dénationaliser",
    "dénationalisés": "dénationaliser",
    "dénatura": "dénaturer",
    "dénaturai": "dénaturer",
    "dénaturaient": "dénaturer",
    "dénaturais": "dénaturer",
    "dénaturait": "dénaturer",
    "dénaturalisa": "dénaturaliser",
    "dénaturalisai": "dénaturaliser",
    "dénaturalisaient": "dénaturaliser",
    "dénaturalisais": "dénaturaliser",
    "dénaturalisait": "dénaturaliser",
    "dénaturalisant": "dénaturaliser",
    "dénaturalisas": "dénaturaliser",
    "dénaturalisasse": "dénaturaliser",
    "dénaturalisassent": "dénaturaliser",
    "dénaturalisasses": "dénaturaliser",
    "dénaturalisassiez": "dénaturaliser",
    "dénaturalisassions": "dénaturaliser",
    "dénaturalise": "dénaturaliser",
    "dénaturalisent": "dénaturaliser",
    "dénaturalisera": "dénaturaliser",
    "dénaturaliserai": "dénaturaliser",
    "dénaturaliseraient": "dénaturaliser",
    "dénaturaliserais": "dénaturaliser",
    "dénaturaliserait": "dénaturaliser",
    "dénaturaliseras": "dénaturaliser",
    "dénaturaliserez": "dénaturaliser",
    "dénaturaliseriez": "dénaturaliser",
    "dénaturaliserions": "dénaturaliser",
    "dénaturaliserons": "dénaturaliser",
    "dénaturaliseront": "dénaturaliser",
    "dénaturalises": "dénaturaliser",
    "dénaturalisez": "dénaturaliser",
    "dénaturalisiez": "dénaturaliser",
    "dénaturalisions": "dénaturaliser",
    "dénaturalisons": "dénaturaliser",
    "dénaturalisâmes": "dénaturaliser",
    "dénaturalisât": "dénaturaliser",
    "dénaturalisâtes": "dénaturaliser",
    "dénaturalisèrent": "dénaturaliser",
    "dénaturalisé": "dénaturaliser",
    "dénaturalisée": "dénaturaliser",
    "dénaturalisées": "dénaturaliser",
    "dénaturalisés": "dénaturaliser",
    "dénaturant": "dénaturer",
    "dénaturas": "dénaturer",
    "dénaturasse": "dénaturer",
    "dénaturassent": "dénaturer",
    "dénaturasses": "dénaturer",
    "dénaturassiez": "dénaturer",
    "dénaturassions": "dénaturer",
    "dénaturations": "dénaturation",
    "dénature": "dénaturer",
    "dénaturent": "dénaturer",
    "dénaturera": "dénaturer",
    "dénaturerai": "dénaturer",
    "dénatureraient": "dénaturer",
    "dénaturerais": "dénaturer",
    "dénaturerait": "dénaturer",
    "dénatureras": "dénaturer",
    "dénaturerez": "dénaturer",
    "dénatureriez": "dénaturer",
    "dénaturerions": "dénaturer",
    "dénaturerons": "dénaturer",
    "dénatureront": "dénaturer",
    "dénatures": "dénaturer",
    "dénaturez": "dénaturer",
    "dénaturiez": "dénaturer",
    "dénaturions": "dénaturer",
    "dénaturons": "dénaturer",
    "dénaturâmes": "dénaturer",
    "dénaturât": "dénaturer",
    "dénaturâtes": "dénaturer",
    "dénaturèrent": "dénaturer",
    "dénaturé": "dénaturer",
    "dénaturée": "dénaturer",
    "dénaturées": "dénaturer",
    "dénaturés": "dénaturer",
    "déneige": "déneiger",
    "déneigea": "déneiger",
    "déneigeai": "déneiger",
    "déneigeaient": "déneiger",
    "déneigeais": "déneiger",
    "déneigeait": "déneiger",
    "déneigeant": "déneiger",
    "déneigeas": "déneiger",
    "déneigeasse": "déneiger",
    "déneigeassent": "déneiger",
    "déneigeasses": "déneiger",
    "déneigeassiez": "déneiger",
    "déneigeassions": "déneiger",
    "déneigent": "déneiger",
    "déneigeons": "déneiger",
    "déneigera": "déneiger",
    "déneigerai": "déneiger",
    "déneigeraient": "déneiger",
    "déneigerais": "déneiger",
    "déneigerait": "déneiger",
    "déneigeras": "déneiger",
    "déneigerez": "déneiger",
    "déneigeriez": "déneiger",
    "déneigerions": "déneiger",
    "déneigerons": "déneiger",
    "déneigeront": "déneiger",
    "déneiges": "déneiger",
    "déneigez": "déneiger",
    "déneigeâmes": "déneiger",
    "déneigeât": "déneiger",
    "déneigeâtes": "déneiger",
    "déneigiez": "déneiger",
    "déneigions": "déneiger",
    "déneigèrent": "déneiger",
    "déneigé": "déneiger",
    "déneigée": "déneiger",
    "déneigées": "déneiger",
    "déneigés": "déneiger",
    "dénervé": "dénerver",
    "dénia": "dénier",
    "déniai": "dénier",
    "déniaient": "dénier",
    "déniais": "dénier",
    "déniaisa": "déniaiser",
    "déniaisai": "déniaiser",
    "déniaisaient": "déniaiser",
    "déniaisais": "déniaiser",
    "déniaisait": "déniaiser",
    "déniaisant": "déniaiser",
    "déniaisas": "déniaiser",
    "déniaisasse": "déniaiser",
    "déniaisassent": "déniaiser",
    "déniaisasses": "déniaiser",
    "déniaisassiez": "déniaiser",
    "déniaisassions": "déniaiser",
    "déniaise": "déniaiser",
    "déniaisent": "déniaiser",
    "déniaisera": "déniaiser",
    "déniaiserai": "déniaiser",
    "déniaiseraient": "déniaiser",
    "déniaiserais": "déniaiser",
    "déniaiserait": "déniaiser",
    "déniaiseras": "déniaiser",
    "déniaiserez": "déniaiser",
    "déniaiseriez": "déniaiser",
    "déniaiserions": "déniaiser",
    "déniaiserons": "déniaiser",
    "déniaiseront": "déniaiser",
    "déniaises": "déniaiser",
    "déniaisez": "déniaiser",
    "déniaisiez": "déniaiser",
    "déniaisions": "déniaiser",
    "déniaisons": "déniaiser",
    "déniaisâmes": "déniaiser",
    "déniaisât": "déniaiser",
    "déniaisâtes": "déniaiser",
    "déniaisèrent": "déniaiser",
    "déniaisé": "déniaiser",
    "déniaisée": "déniaiser",
    "déniaisées": "déniaiser",
    "déniaisés": "déniaiser",
    "déniait": "dénier",
    "déniant": "dénier",
    "dénias": "dénier",
    "déniasse": "dénier",
    "déniassent": "dénier",
    "déniasses": "dénier",
    "déniassiez": "dénier",
    "déniassions": "dénier",
    "dénicha": "dénicher",
    "dénichai": "dénicher",
    "dénichaient": "dénicher",
    "dénichais": "dénicher",
    "dénichait": "dénicher",
    "dénichant": "dénicher",
    "dénichas": "dénicher",
    "dénichasse": "dénicher",
    "dénichassent": "dénicher",
    "dénichasses": "dénicher",
    "dénichassiez": "dénicher",
    "dénichassions": "dénicher",
    "déniche": "dénicher",
    "dénichent": "dénicher",
    "dénichera": "dénicher",
    "dénicherai": "dénicher",
    "dénicheraient": "dénicher",
    "dénicherais": "dénicher",
    "dénicherait": "dénicher",
    "dénicheras": "dénicher",
    "dénicherez": "dénicher",
    "dénicheriez": "dénicher",
    "dénicherions": "dénicher",
    "dénicherons": "dénicher",
    "dénicheront": "dénicher",
    "déniches": "dénicher",
    "dénicheurs": "dénicheur",
    "dénicheuse": "dénicheur",
    "dénichez": "dénicher",
    "dénichiez": "dénicher",
    "dénichions": "dénicher",
    "dénichons": "dénicher",
    "dénichâmes": "dénicher",
    "dénichât": "dénicher",
    "dénichâtes": "dénicher",
    "dénichèrent": "dénicher",
    "déniché": "dénicher",
    "dénichée": "dénicher",
    "dénichées": "dénicher",
    "dénichés": "dénicher",
    "dénie": "dénier",
    "dénient": "dénier",
    "déniera": "dénier",
    "dénierai": "dénier",
    "dénieraient": "dénier",
    "dénierais": "dénier",
    "dénierait": "dénier",
    "dénieras": "dénier",
    "dénierez": "dénier",
    "dénieriez": "dénier",
    "dénierions": "dénier",
    "dénierons": "dénier",
    "dénieront": "dénier",
    "dénies": "dénier",
    "déniez": "dénier",
    "dénigra": "dénigrer",
    "dénigrai": "dénigrer",
    "dénigraient": "dénigrer",
    "dénigrais": "dénigrer",
    "dénigrait": "dénigrer",
    "dénigrant": "dénigrer",
    "dénigrante": "dénigrant",
    "dénigras": "dénigrer",
    "dénigrasse": "dénigrer",
    "dénigrassent": "dénigrer",
    "dénigrasses": "dénigrer",
    "dénigrassiez": "dénigrer",
    "dénigrassions": "dénigrer",
    "dénigre": "dénigrer",
    "dénigrements": "dénigrement",
    "dénigrent": "dénigrer",
    "dénigrera": "dénigrer",
    "dénigrerai": "dénigrer",
    "dénigreraient": "dénigrer",
    "dénigrerais": "dénigrer",
    "dénigrerait": "dénigrer",
    "dénigreras": "dénigrer",
    "dénigrerez": "dénigrer",
    "dénigreriez": "dénigrer",
    "dénigrerions": "dénigrer",
    "dénigrerons": "dénigrer",
    "dénigreront": "dénigrer",
    "dénigres": "dénigrer",
    "dénigreuses": "dénigreur",
    "dénigrez": "dénigrer",
    "dénigriez": "dénigrer",
    "dénigrions": "dénigrer",
    "dénigrons": "dénigrer",
    "dénigrâmes": "dénigrer",
    "dénigrât": "dénigrer",
    "dénigrâtes": "dénigrer",
    "dénigrèrent": "dénigrer",
    "dénigré": "dénigrer",
    "dénigrée": "dénigrer",
    "dénigrées": "dénigrer",
    "dénigrés": "dénigrer",
    "déniiez": "dénier",
    "déniions": "dénier",
    "dénions": "dénier",
    "dénis": "déni",
    "dénivela": "déniveler",
    "dénivelai": "déniveler",
    "dénivelaient": "déniveler",
    "dénivelais": "déniveler",
    "dénivelait": "déniveler",
    "dénivelant": "déniveler",
    "dénivelas": "déniveler",
    "dénivelasse": "déniveler",
    "dénivelassent": "déniveler",
    "dénivelasses": "déniveler",
    "dénivelassiez": "déniveler",
    "dénivelassions": "déniveler",
    "dénivelez": "déniveler",
    "déniveliez": "déniveler",
    "dénivelions": "déniveler",
    "dénivellations": "dénivellation",
    "dénivelle": "déniveler",
    "dénivellements": "dénivellement",
    "dénivellent": "déniveler",
    "dénivellera": "déniveler",
    "dénivellerai": "déniveler",
    "dénivelleraient": "déniveler",
    "dénivellerais": "déniveler",
    "dénivellerait": "déniveler",
    "dénivelleras": "déniveler",
    "dénivellerez": "déniveler",
    "dénivelleriez": "déniveler",
    "dénivellerions": "déniveler",
    "dénivellerons": "déniveler",
    "dénivelleront": "déniveler",
    "dénivelles": "déniveler",
    "dénivelons": "déniveler",
    "dénivelâmes": "déniveler",
    "dénivelât": "déniveler",
    "dénivelâtes": "déniveler",
    "dénivelèrent": "déniveler",
    "dénivelé": "déniveler",
    "dénivelée": "déniveler",
    "dénivelées": "déniveler",
    "dénivelés": "déniveler",
    "déniâmes": "dénier",
    "déniât": "dénier",
    "déniâtes": "dénier",
    "dénièrent": "dénier",
    "dénié": "dénier",
    "déniée": "dénier",
    "déniées": "dénier",
    "déniés": "dénier",
    "dénoie": "dénoyer",
    "dénoient": "dénoyer",
    "dénoiera": "dénoyer",
    "dénoierai": "dénoyer",
    "dénoieraient": "dénoyer",
    "dénoierais": "dénoyer",
    "dénoierait": "dénoyer",
    "dénoieras": "dénoyer",
    "dénoierez": "dénoyer",
    "dénoieriez": "dénoyer",
    "dénoierions": "dénoyer",
    "dénoierons": "dénoyer",
    "dénoieront": "dénoyer",
    "dénoies": "dénoyer",
    "dénombra": "dénombrer",
    "dénombrables": "dénombrable",
    "dénombrai": "dénombrer",
    "dénombraient": "dénombrer",
    "dénombrais": "dénombrer",
    "dénombrait": "dénombrer",
    "dénombrant": "dénombrer",
    "dénombras": "dénombrer",
    "dénombrasse": "dénombrer",
    "dénombrassent": "dénombrer",
    "dénombrasses": "dénombrer",
    "dénombrassiez": "dénombrer",
    "dénombrassions": "dénombrer",
    "dénombre": "dénombrer",
    "dénombrements": "dénombrement",
    "dénombrent": "dénombrer",
    "dénombrera": "dénombrer",
    "dénombrerai": "dénombrer",
    "dénombreraient": "dénombrer",
    "dénombrerais": "dénombrer",
    "dénombrerait": "dénombrer",
    "dénombreras": "dénombrer",
    "dénombrerez": "dénombrer",
    "dénombreriez": "dénombrer",
    "dénombrerions": "dénombrer",
    "dénombrerons": "dénombrer",
    "dénombreront": "dénombrer",
    "dénombres": "dénombrer",
    "dénombrez": "dénombrer",
    "dénombriez": "dénombrer",
    "dénombrions": "dénombrer",
    "dénombrons": "dénombrer",
    "dénombrâmes": "dénombrer",
    "dénombrât": "dénombrer",
    "dénombrâtes": "dénombrer",
    "dénombrèrent": "dénombrer",
    "dénombré": "dénombrer",
    "dénombrée": "dénombrer",
    "dénombrées": "dénombrer",
    "dénombrés": "dénombrer",
    "dénominateurs": "dénominateur",
    "dénominations": "dénomination",
    "dénomma": "dénommer",
    "dénommai": "dénommer",
    "dénommaient": "dénommer",
    "dénommais": "dénommer",
    "dénommait": "dénommer",
    "dénommant": "dénommer",
    "dénommas": "dénommer",
    "dénommasse": "dénommer",
    "dénommassent": "dénommer",
    "dénommasses": "dénommer",
    "dénommassiez": "dénommer",
    "dénommassions": "dénommer",
    "dénomme": "dénommer",
    "dénomment": "dénommer",
    "dénommera": "dénommer",
    "dénommerai": "dénommer",
    "dénommeraient": "dénommer",
    "dénommerais": "dénommer",
    "dénommerait": "dénommer",
    "dénommeras": "dénommer",
    "dénommerez": "dénommer",
    "dénommeriez": "dénommer",
    "dénommerions": "dénommer",
    "dénommerons": "dénommer",
    "dénommeront": "dénommer",
    "dénommes": "dénommer",
    "dénommez": "dénommer",
    "dénommiez": "dénommer",
    "dénommions": "dénommer",
    "dénommons": "dénommer",
    "dénommâmes": "dénommer",
    "dénommât": "dénommer",
    "dénommâtes": "dénommer",
    "dénommèrent": "dénommer",
    "dénommé": "dénommer",
    "dénommée": "dénommer",
    "dénommées": "dénommer",
    "dénommés": "dénommer",
    "dénonce": "dénoncer",
    "dénoncent": "dénoncer",
    "dénoncera": "dénoncer",
    "dénoncerai": "dénoncer",
    "dénonceraient": "dénoncer",
    "dénoncerais": "dénoncer",
    "dénoncerait": "dénoncer",
    "dénonceras": "dénoncer",
    "dénoncerez": "dénoncer",
    "dénonceriez": "dénoncer",
    "dénoncerions": "dénoncer",
    "dénoncerons": "dénoncer",
    "dénonceront": "dénoncer",
    "dénonces": "dénoncer",
    "dénoncez": "dénoncer",
    "dénonciateurs": "dénonciateur",
    "dénonciations": "dénonciation",
    "dénonciatrice": "dénonciateur",
    "dénonciatrices": "dénonciateur",
    "dénonciez": "dénoncer",
    "dénoncions": "dénoncer",
    "dénoncèrent": "dénoncer",
    "dénoncé": "dénoncer",
    "dénoncée": "dénoncer",
    "dénoncées": "dénoncer",
    "dénoncés": "dénoncer",
    "dénonnçais": "dénoncer",
    "dénonça": "dénoncer",
    "dénonçai": "dénoncer",
    "dénonçaient": "dénoncer",
    "dénonçais": "dénoncer",
    "dénonçait": "dénoncer",
    "dénonçant": "dénoncer",
    "dénonças": "dénoncer",
    "dénonçasse": "dénoncer",
    "dénonçassent": "dénoncer",
    "dénonçasses": "dénoncer",
    "dénonçassiez": "dénoncer",
    "dénonçassions": "dénoncer",
    "dénonçons": "dénoncer",
    "dénonçâmes": "dénoncer",
    "dénonçât": "dénoncer",
    "dénonçâtes": "dénoncer",
    "dénota": "dénoter",
    "dénotai": "dénoter",
    "dénotaient": "dénoter",
    "dénotais": "dénoter",
    "dénotait": "dénoter",
    "dénotant": "dénoter",
    "dénotas": "dénoter",
    "dénotasse": "dénoter",
    "dénotassent": "dénoter",
    "dénotasses": "dénoter",
    "dénotassiez": "dénoter",
    "dénotassions": "dénoter",
    "dénote": "dénoter",
    "dénotent": "dénoter",
    "dénotera": "dénoter",
    "dénoterai": "dénoter",
    "dénoteraient": "dénoter",
    "dénoterais": "dénoter",
    "dénoterait": "dénoter",
    "dénoteras": "dénoter",
    "dénoterez": "dénoter",
    "dénoteriez": "dénoter",
    "dénoterions": "dénoter",
    "dénoterons": "dénoter",
    "dénoteront": "dénoter",
    "dénotes": "dénoter",
    "dénotez": "dénoter",
    "dénotiez": "dénoter",
    "dénotions": "dénoter",
    "dénotons": "dénoter",
    "dénotâmes": "dénoter",
    "dénotât": "dénoter",
    "dénotâtes": "dénoter",
    "dénotèrent": "dénoter",
    "dénoté": "dénoter",
    "dénotée": "dénoter",
    "dénotées": "dénoter",
    "dénotés": "dénoter",
    "dénoua": "dénouer",
    "dénouai": "dénouer",
    "dénouaient": "dénouer",
    "dénouais": "dénouer",
    "dénouait": "dénouer",
    "dénouant": "dénouer",
    "dénouas": "dénouer",
    "dénouasse": "dénouer",
    "dénouassent": "dénouer",
    "dénouasses": "dénouer",
    "dénouassiez": "dénouer",
    "dénouassions": "dénouer",
    "dénoue": "dénouer",
    "dénouements": "dénouement",
    "dénouent": "dénouer",
    "dénouera": "dénouer",
    "dénouerai": "dénouer",
    "dénoueraient": "dénouer",
    "dénouerais": "dénouer",
    "dénouerait": "dénouer",
    "dénoueras": "dénouer",
    "dénouerez": "dénouer",
    "dénoueriez": "dénouer",
    "dénouerions": "dénouer",
    "dénouerons": "dénouer",
    "dénoueront": "dénouer",
    "dénoues": "dénouer",
    "dénouez": "dénouer",
    "dénouiez": "dénouer",
    "dénouions": "dénouer",
    "dénouons": "dénouer",
    "dénouâmes": "dénouer",
    "dénouât": "dénouer",
    "dénouâtes": "dénouer",
    "dénouèrent": "dénouer",
    "dénoué": "dénouer",
    "dénouée": "dénouer",
    "dénouées": "dénouer",
    "dénoués": "dénouer",
    "dénoya": "dénoyer",
    "dénoyai": "dénoyer",
    "dénoyaient": "dénoyer",
    "dénoyais": "dénoyer",
    "dénoyait": "dénoyer",
    "dénoyant": "dénoyer",
    "dénoyas": "dénoyer",
    "dénoyasse": "dénoyer",
    "dénoyassent": "dénoyer",
    "dénoyasses": "dénoyer",
    "dénoyassiez": "dénoyer",
    "dénoyassions": "dénoyer",
    "dénoyauta": "dénoyauter",
    "dénoyautai": "dénoyauter",
    "dénoyautaient": "dénoyauter",
    "dénoyautais": "dénoyauter",
    "dénoyautait": "dénoyauter",
    "dénoyautant": "dénoyauter",
    "dénoyautas": "dénoyauter",
    "dénoyautasse": "dénoyauter",
    "dénoyautassent": "dénoyauter",
    "dénoyautasses": "dénoyauter",
    "dénoyautassiez": "dénoyauter",
    "dénoyautassions": "dénoyauter",
    "dénoyaute": "dénoyauter",
    "dénoyautent": "dénoyauter",
    "dénoyautera": "dénoyauter",
    "dénoyauterai": "dénoyauter",
    "dénoyauteraient": "dénoyauter",
    "dénoyauterais": "dénoyauter",
    "dénoyauterait": "dénoyauter",
    "dénoyauteras": "dénoyauter",
    "dénoyauterez": "dénoyauter",
    "dénoyauteriez": "dénoyauter",
    "dénoyauterions": "dénoyauter",
    "dénoyauterons": "dénoyauter",
    "dénoyauteront": "dénoyauter",
    "dénoyautes": "dénoyauter",
    "dénoyautez": "dénoyauter",
    "dénoyautiez": "dénoyauter",
    "dénoyautions": "dénoyauter",
    "dénoyautons": "dénoyauter",
    "dénoyautâmes": "dénoyauter",
    "dénoyautât": "dénoyauter",
    "dénoyautâtes": "dénoyauter",
    "dénoyautèrent": "dénoyauter",
    "dénoyauté": "dénoyauter",
    "dénoyautée": "dénoyauter",
    "dénoyautées": "dénoyauter",
    "dénoyautés": "dénoyauter",
    "dénoyez": "dénoyer",
    "dénoyiez": "dénoyer",
    "dénoyions": "dénoyer",
    "dénoyons": "dénoyer",
    "dénoyâmes": "dénoyer",
    "dénoyât": "dénoyer",
    "dénoyâtes": "dénoyer",
    "dénoyèrent": "dénoyer",
    "dénoyé": "dénoyer",
    "dénoyée": "dénoyer",
    "dénoyées": "dénoyer",
    "dénoyés": "dénoyer",
    "dénua": "dénuer",
    "dénuai": "dénuer",
    "dénuaient": "dénuer",
    "dénuais": "dénuer",
    "dénuait": "dénuer",
    "dénuant": "dénuer",
    "dénuas": "dénuer",
    "dénuasse": "dénuer",
    "dénuassent": "dénuer",
    "dénuasses": "dénuer",
    "dénuassiez": "dénuer",
    "dénuassions": "dénuer",
    "dénucléarisations": "dénucléarisation",
    "dénuda": "dénuder",
    "dénudai": "dénuder",
    "dénudaient": "dénuder",
    "dénudais": "dénuder",
    "dénudait": "dénuder",
    "dénudant": "dénuder",
    "dénudas": "dénuder",
    "dénudasse": "dénuder",
    "dénudassent": "dénuder",
    "dénudasses": "dénuder",
    "dénudassiez": "dénuder",
    "dénudassions": "dénuder",
    "dénudations": "dénudation",
    "dénude": "dénuder",
    "dénudent": "dénuder",
    "dénudera": "dénuder",
    "dénuderai": "dénuder",
    "dénuderaient": "dénuder",
    "dénuderais": "dénuder",
    "dénuderait": "dénuder",
    "dénuderas": "dénuder",
    "dénuderez": "dénuder",
    "dénuderiez": "dénuder",
    "dénuderions": "dénuder",
    "dénuderons": "dénuder",
    "dénuderont": "dénuder",
    "dénudes": "dénuder",
    "dénudez": "dénuder",
    "dénudiez": "dénuder",
    "dénudions": "dénuder",
    "dénudons": "dénuder",
    "dénudâmes": "dénuder",
    "dénudât": "dénuder",
    "dénudâtes": "dénuder",
    "dénudèrent": "dénuder",
    "dénudé": "dénuder",
    "dénudée": "dénuder",
    "dénudées": "dénuder",
    "dénudés": "dénuder",
    "dénue": "dénuer",
    "dénuements": "dénuement",
    "dénuent": "dénuer",
    "dénuera": "dénuer",
    "dénuerai": "dénuer",
    "dénueraient": "dénuer",
    "dénuerais": "dénuer",
    "dénuerait": "dénuer",
    "dénueras": "dénuer",
    "dénuerez": "dénuer",
    "dénueriez": "dénuer",
    "dénuerions": "dénuer",
    "dénuerons": "dénuer",
    "dénueront": "dénuer",
    "dénues": "dénuer",
    "dénuez": "dénuer",
    "dénuiez": "dénuer",
    "dénuions": "dénuer",
    "dénuons": "dénuer",
    "dénutritions": "dénutrition",
    "dénuâmes": "dénuer",
    "dénuât": "dénuer",
    "dénuâtes": "dénuer",
    "dénuèrent": "dénuer",
    "dénué": "dénuer",
    "dénuée": "dénuer",
    "dénuées": "dénuer",
    "dénués": "dénuer",
    "dénégateurs": "dénégateur",
    "dénégations": "dénégation",
    "déodorants": "déodorant",
    "déontologies": "déontologie",
    "déontologiques": "déontologique",
    "dépailla": "dépailler",
    "dépaillai": "dépailler",
    "dépaillaient": "dépailler",
    "dépaillais": "dépailler",
    "dépaillait": "dépailler",
    "dépaillant": "dépailler",
    "dépaillas": "dépailler",
    "dépaillasse": "dépailler",
    "dépaillassent": "dépailler",
    "dépaillasses": "dépailler",
    "dépaillassiez": "dépailler",
    "dépaillassions": "dépailler",
    "dépaille": "dépailler",
    "dépaillent": "dépailler",
    "dépaillera": "dépailler",
    "dépaillerai": "dépailler",
    "dépailleraient": "dépailler",
    "dépaillerais": "dépailler",
    "dépaillerait": "dépailler",
    "dépailleras": "dépailler",
    "dépaillerez": "dépailler",
    "dépailleriez": "dépailler",
    "dépaillerions": "dépailler",
    "dépaillerons": "dépailler",
    "dépailleront": "dépailler",
    "dépailles": "dépailler",
    "dépaillez": "dépailler",
    "dépailliez": "dépailler",
    "dépaillions": "dépailler",
    "dépaillons": "dépailler",
    "dépaillâmes": "dépailler",
    "dépaillât": "dépailler",
    "dépaillâtes": "dépailler",
    "dépaillèrent": "dépailler",
    "dépaillé": "dépailler",
    "dépaillée": "dépailler",
    "dépaillées": "dépailler",
    "dépaillés": "dépailler",
    "dépanna": "dépanner",
    "dépannages": "dépannage",
    "dépannai": "dépanner",
    "dépannaient": "dépanner",
    "dépannais": "dépanner",
    "dépannait": "dépanner",
    "dépannant": "dépanner",
    "dépannas": "dépanner",
    "dépannasse": "dépanner",
    "dépannassent": "dépanner",
    "dépannasses": "dépanner",
    "dépannassiez": "dépanner",
    "dépannassions": "dépanner",
    "dépanne": "dépanner",
    "dépannent": "dépanner",
    "dépannera": "dépanner",
    "dépannerai": "dépanner",
    "dépanneraient": "dépanner",
    "dépannerais": "dépanner",
    "dépannerait": "dépanner",
    "dépanneras": "dépanner",
    "dépannerez": "dépanner",
    "dépanneriez": "dépanner",
    "dépannerions": "dépanner",
    "dépannerons": "dépanner",
    "dépanneront": "dépanner",
    "dépannes": "dépanner",
    "dépanneurs": "dépanneur",
    "dépanneuse": "dépanneur",
    "dépanneuses": "dépanneur",
    "dépannez": "dépanner",
    "dépanniez": "dépanner",
    "dépannions": "dépanner",
    "dépannons": "dépanner",
    "dépannâmes": "dépanner",
    "dépannât": "dépanner",
    "dépannâtes": "dépanner",
    "dépannèrent": "dépanner",
    "dépanné": "dépanner",
    "dépannée": "dépanner",
    "dépannées": "dépanner",
    "dépannés": "dépanner",
    "dépaqueta": "dépaqueter",
    "dépaquetai": "dépaqueter",
    "dépaquetaient": "dépaqueter",
    "dépaquetais": "dépaqueter",
    "dépaquetait": "dépaqueter",
    "dépaquetant": "dépaqueter",
    "dépaquetas": "dépaqueter",
    "dépaquetasse": "dépaqueter",
    "dépaquetassent": "dépaqueter",
    "dépaquetasses": "dépaqueter",
    "dépaquetassiez": "dépaqueter",
    "dépaquetassions": "dépaqueter",
    "dépaquetez": "dépaqueter",
    "dépaquetiez": "dépaqueter",
    "dépaquetions": "dépaqueter",
    "dépaquetons": "dépaqueter",
    "dépaquette": "dépaqueter",
    "dépaquettent": "dépaqueter",
    "dépaquettera": "dépaqueter",
    "dépaquetterai": "dépaqueter",
    "dépaquetteraient": "dépaqueter",
    "dépaquetterais": "dépaqueter",
    "dépaquetterait": "dépaqueter",
    "dépaquetteras": "dépaqueter",
    "dépaquetterez": "dépaqueter",
    "dépaquetteriez": "dépaqueter",
    "dépaquetterions": "dépaqueter",
    "dépaquetterons": "dépaqueter",
    "dépaquetteront": "dépaqueter",
    "dépaquettes": "dépaqueter",
    "dépaquetâmes": "dépaqueter",
    "dépaquetât": "dépaqueter",
    "dépaquetâtes": "dépaqueter",
    "dépaquetèrent": "dépaqueter",
    "dépaqueté": "dépaqueter",
    "dépaquetée": "dépaqueter",
    "dépaquetées": "dépaqueter",
    "dépaquetés": "dépaqueter",
    "dépara": "déparer",
    "déparai": "déparer",
    "déparaient": "déparer",
    "déparais": "déparer",
    "déparait": "déparer",
    "déparant": "déparer",
    "déparas": "déparer",
    "déparasse": "déparer",
    "déparassent": "déparer",
    "déparasses": "déparer",
    "déparassiez": "déparer",
    "déparassions": "déparer",
    "dépare": "déparer",
    "dépareilla": "dépareiller",
    "dépareillai": "dépareiller",
    "dépareillaient": "dépareiller",
    "dépareillais": "dépareiller",
    "dépareillait": "dépareiller",
    "dépareillant": "dépareiller",
    "dépareillas": "dépareiller",
    "dépareillasse": "dépareiller",
    "dépareillassent": "dépareiller",
    "dépareillasses": "dépareiller",
    "dépareillassiez": "dépareiller",
    "dépareillassions": "dépareiller",
    "dépareille": "dépareiller",
    "dépareillent": "dépareiller",
    "dépareillera": "dépareiller",
    "dépareillerai": "dépareiller",
    "dépareilleraient": "dépareiller",
    "dépareillerais": "dépareiller",
    "dépareillerait": "dépareiller",
    "dépareilleras": "dépareiller",
    "dépareillerez": "dépareiller",
    "dépareilleriez": "dépareiller",
    "dépareillerions": "dépareiller",
    "dépareillerons": "dépareiller",
    "dépareilleront": "dépareiller",
    "dépareilles": "dépareiller",
    "dépareillez": "dépareiller",
    "dépareilliez": "dépareiller",
    "dépareillions": "dépareiller",
    "dépareillons": "dépareiller",
    "dépareillâmes": "dépareiller",
    "dépareillât": "dépareiller",
    "dépareillâtes": "dépareiller",
    "dépareillèrent": "dépareiller",
    "dépareillé": "dépareiller",
    "dépareillée": "dépareiller",
    "dépareillées": "dépareiller",
    "dépareillés": "dépareiller",
    "déparent": "déparer",
    "déparera": "déparer",
    "déparerai": "déparer",
    "dépareraient": "déparer",
    "déparerais": "déparer",
    "déparerait": "déparer",
    "dépareras": "déparer",
    "déparerez": "déparer",
    "dépareriez": "déparer",
    "déparerions": "déparer",
    "déparerons": "déparer",
    "dépareront": "déparer",
    "dépares": "déparer",
    "déparez": "déparer",
    "déparia": "déparier",
    "dépariai": "déparier",
    "dépariaient": "déparier",
    "dépariais": "déparier",
    "dépariait": "déparier",
    "dépariant": "déparier",
    "déparias": "déparier",
    "dépariasse": "déparier",
    "dépariassent": "déparier",
    "dépariasses": "déparier",
    "dépariassiez": "déparier",
    "dépariassions": "déparier",
    "déparie": "déparier",
    "déparient": "déparier",
    "dépariera": "déparier",
    "déparierai": "déparier",
    "déparieraient": "déparier",
    "déparierais": "déparier",
    "déparierait": "déparier",
    "déparieras": "déparier",
    "déparierez": "déparier",
    "déparieriez": "déparier",
    "déparierions": "déparier",
    "déparierons": "déparier",
    "déparieront": "déparier",
    "déparies": "déparier",
    "dépariez": "déparier",
    "dépariiez": "déparier",
    "dépariions": "déparier",
    "déparions": "déparier",
    "dépariâmes": "déparier",
    "dépariât": "déparier",
    "dépariâtes": "déparier",
    "déparièrent": "déparier",
    "déparié": "déparier",
    "dépariée": "déparier",
    "dépariées": "déparier",
    "dépariés": "déparier",
    "déparlait": "déparler",
    "déparons": "déparer",
    "dépars": "départir",
    "départ": "départir",
    "départage": "départager",
    "départagea": "départager",
    "départageai": "départager",
    "départageaient": "départager",
    "départageais": "départager",
    "départageait": "départager",
    "départageant": "départager",
    "départageas": "départager",
    "départageasse": "départager",
    "départageassent": "départager",
    "départageasses": "départager",
    "départageassiez": "départager",
    "départageassions": "départager",
    "départagent": "départager",
    "départageons": "départager",
    "départagera": "départager",
    "départagerai": "départager",
    "départageraient": "départager",
    "départagerais": "départager",
    "départagerait": "départager",
    "départageras": "départager",
    "départagerez": "départager",
    "départageriez": "départager",
    "départagerions": "départager",
    "départagerons": "départager",
    "départageront": "départager",
    "départages": "départager",
    "départagez": "départager",
    "départageâmes": "départager",
    "départageât": "départager",
    "départageâtes": "départager",
    "départagiez": "départager",
    "départagions": "départager",
    "départagèrent": "départager",
    "départagé": "départager",
    "départagée": "départager",
    "départagées": "départager",
    "départagés": "départager",
    "départaient": "départir",
    "départais": "départir",
    "départait": "départir",
    "départant": "départir",
    "départe": "départir",
    "départementale": "départemental",
    "départementales": "départementale",
    "départementaux": "départemental",
    "départements": "département",
    "départent": "départir",
    "départes": "départir",
    "départez": "départir",
    "départi": "départir",
    "départie": "départir",
    "départies": "départir",
    "départiez": "départir",
    "départions": "départir",
    "départira": "départir",
    "départirai": "départir",
    "départiraient": "départir",
    "départirais": "départir",
    "départirait": "départir",
    "départiras": "départir",
    "départirent": "départir",
    "départirez": "départir",
    "départiriez": "départir",
    "départirions": "départir",
    "départirons": "départir",
    "départiront": "départir",
    "départis": "départir",
    "départisse": "départir",
    "départissent": "départir",
    "départisses": "départir",
    "départissiez": "départir",
    "départissions": "départir",
    "départit": "départir",
    "départons": "départir",
    "départs": "départ",
    "départîmes": "départir",
    "départît": "départir",
    "départîtes": "départir",
    "déparâmes": "déparer",
    "déparât": "déparer",
    "déparâtes": "déparer",
    "déparèrent": "déparer",
    "déparé": "déparer",
    "déparée": "déparer",
    "déparées": "déparer",
    "déparés": "déparer",
    "dépassa": "dépasser",
    "dépassai": "dépasser",
    "dépassaient": "dépasser",
    "dépassais": "dépasser",
    "dépassait": "dépasser",
    "dépassant": "dépasser",
    "dépassas": "dépasser",
    "dépassasse": "dépasser",
    "dépassassent": "dépasser",
    "dépassasses": "dépasser",
    "dépassassiez": "dépasser",
    "dépassassions": "dépasser",
    "dépasse": "dépasser",
    "dépassements": "dépassement",
    "dépassent": "dépasser",
    "dépassera": "dépasser",
    "dépasserai": "dépasser",
    "dépasseraient": "dépasser",
    "dépasserais": "dépasser",
    "dépasserait": "dépasser",
    "dépasseras": "dépasser",
    "dépasserez": "dépasser",
    "dépasseriez": "dépasser",
    "dépasserions": "dépasser",
    "dépasserons": "dépasser",
    "dépasseront": "dépasser",
    "dépasses": "dépasser",
    "dépassez": "dépasser",
    "dépassiez": "dépasser",
    "dépassionna": "dépassionner",
    "dépassionnai": "dépassionner",
    "dépassionnaient": "dépassionner",
    "dépassionnais": "dépassionner",
    "dépassionnait": "dépassionner",
    "dépassionnant": "dépassionner",
    "dépassionnas": "dépassionner",
    "dépassionnasse": "dépassionner",
    "dépassionnassent": "dépassionner",
    "dépassionnasses": "dépassionner",
    "dépassionnassiez": "dépassionner",
    "dépassionnassions": "dépassionner",
    "dépassionne": "dépassionner",
    "dépassionnent": "dépassionner",
    "dépassionnera": "dépassionner",
    "dépassionnerai": "dépassionner",
    "dépassionneraient": "dépassionner",
    "dépassionnerais": "dépassionner",
    "dépassionnerait": "dépassionner",
    "dépassionneras": "dépassionner",
    "dépassionnerez": "dépassionner",
    "dépassionneriez": "dépassionner",
    "dépassionnerions": "dépassionner",
    "dépassionnerons": "dépassionner",
    "dépassionneront": "dépassionner",
    "dépassionnes": "dépassionner",
    "dépassionnez": "dépassionner",
    "dépassionniez": "dépassionner",
    "dépassionnions": "dépassionner",
    "dépassionnons": "dépassionner",
    "dépassionnâmes": "dépassionner",
    "dépassionnât": "dépassionner",
    "dépassionnâtes": "dépassionner",
    "dépassionnèrent": "dépassionner",
    "dépassionné": "dépassionner",
    "dépassionnée": "dépassionner",
    "dépassionnées": "dépassionner",
    "dépassionnés": "dépassionner",
    "dépassions": "dépasser",
    "dépassons": "dépasser",
    "dépassâmes": "dépasser",
    "dépassât": "dépasser",
    "dépassâtes": "dépasser",
    "dépassèrent": "dépasser",
    "dépassé": "dépasser",
    "dépassée": "dépasser",
    "dépassées": "dépasser",
    "dépassés": "dépasser",
    "dépatouillait": "dépatouiller",
    "dépatouille": "dépatouiller",
    "dépava": "dépaver",
    "dépavai": "dépaver",
    "dépavaient": "dépaver",
    "dépavais": "dépaver",
    "dépavait": "dépaver",
    "dépavant": "dépaver",
    "dépavas": "dépaver",
    "dépavasse": "dépaver",
    "dépavassent": "dépaver",
    "dépavasses": "dépaver",
    "dépavassiez": "dépaver",
    "dépavassions": "dépaver",
    "dépave": "dépaver",
    "dépavent": "dépaver",
    "dépavera": "dépaver",
    "dépaverai": "dépaver",
    "dépaveraient": "dépaver",
    "dépaverais": "dépaver",
    "dépaverait": "dépaver",
    "dépaveras": "dépaver",
    "dépaverez": "dépaver",
    "dépaveriez": "dépaver",
    "dépaverions": "dépaver",
    "dépaverons": "dépaver",
    "dépaveront": "dépaver",
    "dépaves": "dépaver",
    "dépavez": "dépaver",
    "dépaviez": "dépaver",
    "dépavillonnements": "dépavillonnement",
    "dépavions": "dépaver",
    "dépavons": "dépaver",
    "dépavâmes": "dépaver",
    "dépavât": "dépaver",
    "dépavâtes": "dépaver",
    "dépavèrent": "dépaver",
    "dépavé": "dépaver",
    "dépavée": "dépaver",
    "dépavées": "dépaver",
    "dépavés": "dépaver",
    "dépaysa": "dépayser",
    "dépaysai": "dépayser",
    "dépaysaient": "dépayser",
    "dépaysais": "dépayser",
    "dépaysait": "dépayser",
    "dépaysant": "dépayser",
    "dépaysante": "dépaysant",
    "dépaysantes": "dépaysant",
    "dépaysas": "dépayser",
    "dépaysasse": "dépayser",
    "dépaysassent": "dépayser",
    "dépaysasses": "dépayser",
    "dépaysassiez": "dépayser",
    "dépaysassions": "dépayser",
    "dépayse": "dépayser",
    "dépaysements": "dépaysement",
    "dépaysent": "dépayser",
    "dépaysera": "dépayser",
    "dépayserai": "dépayser",
    "dépayseraient": "dépayser",
    "dépayserais": "dépayser",
    "dépayserait": "dépayser",
    "dépayseras": "dépayser",
    "dépayserez": "dépayser",
    "dépayseriez": "dépayser",
    "dépayserions": "dépayser",
    "dépayserons": "dépayser",
    "dépayseront": "dépayser",
    "dépayses": "dépayser",
    "dépaysez": "dépayser",
    "dépaysiez": "dépayser",
    "dépaysions": "dépayser",
    "dépaysons": "dépayser",
    "dépaysâmes": "dépayser",
    "dépaysât": "dépayser",
    "dépaysâtes": "dépayser",
    "dépaysèrent": "dépayser",
    "dépaysé": "dépayser",
    "dépaysée": "dépayser",
    "dépaysées": "dépayser",
    "dépaysés": "dépayser",
    "dépeceurs": "dépeceur",
    "dépecez": "dépecer",
    "dépeciez": "dépecer",
    "dépecions": "dépecer",
    "dépecèrent": "dépecer",
    "dépecé": "dépecer",
    "dépecée": "dépecer",
    "dépecées": "dépecer",
    "dépecés": "dépecer",
    "dépeigna": "dépeigner",
    "dépeignai": "dépeigner",
    "dépeignaient": "dépeindre",
    "dépeignais": "dépeindre",
    "dépeignait": "dépeindre",
    "dépeignant": "dépeindre",
    "dépeignas": "dépeigner",
    "dépeignasse": "dépeigner",
    "dépeignassent": "dépeigner",
    "dépeignasses": "dépeigner",
    "dépeignassiez": "dépeigner",
    "dépeignassions": "dépeigner",
    "dépeigne": "dépeindre",
    "dépeignent": "dépeindre",
    "dépeignera": "dépeigner",
    "dépeignerai": "dépeigner",
    "dépeigneraient": "dépeigner",
    "dépeignerais": "dépeigner",
    "dépeignerait": "dépeigner",
    "dépeigneras": "dépeigner",
    "dépeignerez": "dépeigner",
    "dépeigneriez": "dépeigner",
    "dépeignerions": "dépeigner",
    "dépeignerons": "dépeigner",
    "dépeigneront": "dépeigner",
    "dépeignes": "dépeindre",
    "dépeignez": "dépeindre",
    "dépeigniez": "dépeindre",
    "dépeignions": "dépeindre",
    "dépeignirent": "dépeindre",
    "dépeignis": "dépeindre",
    "dépeignisse": "dépeindre",
    "dépeignissent": "dépeindre",
    "dépeignisses": "dépeindre",
    "dépeignissiez": "dépeindre",
    "dépeignissions": "dépeindre",
    "dépeignit": "dépeindre",
    "dépeignons": "dépeindre",
    "dépeignâmes": "dépeigner",
    "dépeignât": "dépeigner",
    "dépeignâtes": "dépeigner",
    "dépeignèrent": "dépeigner",
    "dépeigné": "dépeigner",
    "dépeignée": "dépeigner",
    "dépeignées": "dépeigner",
    "dépeignés": "dépeigner",
    "dépeignîmes": "dépeindre",
    "dépeignît": "dépeindre",
    "dépeignîtes": "dépeindre",
    "dépeindra": "dépeindre",
    "dépeindrai": "dépeindre",
    "dépeindraient": "dépeindre",
    "dépeindrais": "dépeindre",
    "dépeindrait": "dépeindre",
    "dépeindras": "dépeindre",
    "dépeindrez": "dépeindre",
    "dépeindriez": "dépeindre",
    "dépeindrions": "dépeindre",
    "dépeindrons": "dépeindre",
    "dépeindront": "dépeindre",
    "dépeins": "dépeindre",
    "dépeint": "dépeindre",
    "dépeinte": "dépeint",
    "dépeintes": "dépeint",
    "dépeints": "dépeint",
    "dépenaillements": "dépenaillement",
    "dépenaillée": "dépenaillé",
    "dépenaillées": "dépenaillé",
    "dépenaillés": "dépenaillé",
    "dépend": "dépendre",
    "dépendaient": "dépendre",
    "dépendais": "dépendre",
    "dépendait": "dépendre",
    "dépendances": "dépendance",
    "dépendant": "dépendre",
    "dépendante": "dépendant",
    "dépendantes": "dépendant",
    "dépendants": "dépendant",
    "dépende": "dépendre",
    "dépendent": "dépendre",
    "dépendes": "dépendre",
    "dépendeurs": "dépendeur",
    "dépendez": "dépendre",
    "dépendiez": "dépendre",
    "dépendions": "dépendre",
    "dépendirent": "dépendre",
    "dépendis": "dépendre",
    "dépendisse": "dépendre",
    "dépendissent": "dépendre",
    "dépendisses": "dépendre",
    "dépendissiez": "dépendre",
    "dépendissions": "dépendre",
    "dépendit": "dépendre",
    "dépendons": "dépendre",
    "dépendra": "dépendre",
    "dépendrai": "dépendre",
    "dépendraient": "dépendre",
    "dépendrais": "dépendre",
    "dépendrait": "dépendre",
    "dépendras": "dépendre",
    "dépendrez": "dépendre",
    "dépendriez": "dépendre",
    "dépendrions": "dépendre",
    "dépendrons": "dépendre",
    "dépendront": "dépendre",
    "dépends": "dépendre",
    "dépendu": "dépendre",
    "dépendue": "dépendre",
    "dépendues": "dépendre",
    "dépendus": "dépendre",
    "dépendîmes": "dépendre",
    "dépendît": "dépendre",
    "dépendîtes": "dépendre",
    "dépensa": "dépenser",
    "dépensai": "dépenser",
    "dépensaient": "dépenser",
    "dépensais": "dépenser",
    "dépensait": "dépenser",
    "dépensant": "dépenser",
    "dépensas": "dépenser",
    "dépensasse": "dépenser",
    "dépensassent": "dépenser",
    "dépensasses": "dépenser",
    "dépensassiez": "dépenser",
    "dépensassions": "dépenser",
    "dépense": "dépenser",
    "dépensent": "dépenser",
    "dépensera": "dépenser",
    "dépenserai": "dépenser",
    "dépenseraient": "dépenser",
    "dépenserais": "dépenser",
    "dépenserait": "dépenser",
    "dépenseras": "dépenser",
    "dépenserez": "dépenser",
    "dépenseriez": "dépenser",
    "dépenserions": "dépenser",
    "dépenserons": "dépenser",
    "dépenseront": "dépenser",
    "dépenses": "dépenser",
    "dépensez": "dépenser",
    "dépensiers": "dépensier",
    "dépensiez": "dépenser",
    "dépensions": "dépenser",
    "dépensière": "dépensier",
    "dépensons": "dépenser",
    "dépensâmes": "dépenser",
    "dépensât": "dépenser",
    "dépensâtes": "dépenser",
    "dépensèrent": "dépenser",
    "dépensé": "dépenser",
    "dépensée": "dépenser",
    "dépensées": "dépenser",
    "dépensés": "dépenser",
    "déperditions": "déperdition",
    "dépersonnalisé": "dépersonnaliser",
    "dépersonnalisée": "dépersonnalisé",
    "dépeupla": "dépeupler",
    "dépeuplai": "dépeupler",
    "dépeuplaient": "dépeupler",
    "dépeuplais": "dépeupler",
    "dépeuplait": "dépeupler",
    "dépeuplant": "dépeupler",
    "dépeuplas": "dépeupler",
    "dépeuplasse": "dépeupler",
    "dépeuplassent": "dépeupler",
    "dépeuplasses": "dépeupler",
    "dépeuplassiez": "dépeupler",
    "dépeuplassions": "dépeupler",
    "dépeuple": "dépeupler",
    "dépeuplent": "dépeupler",
    "dépeuplera": "dépeupler",
    "dépeuplerai": "dépeupler",
    "dépeupleraient": "dépeupler",
    "dépeuplerais": "dépeupler",
    "dépeuplerait": "dépeupler",
    "dépeupleras": "dépeupler",
    "dépeuplerez": "dépeupler",
    "dépeupleriez": "dépeupler",
    "dépeuplerions": "dépeupler",
    "dépeuplerons": "dépeupler",
    "dépeupleront": "dépeupler",
    "dépeuples": "dépeupler",
    "dépeuplez": "dépeupler",
    "dépeupliez": "dépeupler",
    "dépeuplions": "dépeupler",
    "dépeuplons": "dépeupler",
    "dépeuplâmes": "dépeupler",
    "dépeuplât": "dépeupler",
    "dépeuplâtes": "dépeupler",
    "dépeuplèrent": "dépeupler",
    "dépeuplé": "dépeupler",
    "dépeuplée": "dépeupler",
    "dépeuplées": "dépeupler",
    "dépeuplés": "dépeupler",
    "dépeça": "dépecer",
    "dépeçages": "dépeçage",
    "dépeçai": "dépecer",
    "dépeçaient": "dépecer",
    "dépeçais": "dépecer",
    "dépeçait": "dépecer",
    "dépeçant": "dépecer",
    "dépeças": "dépecer",
    "dépeçasse": "dépecer",
    "dépeçassent": "dépecer",
    "dépeçasses": "dépecer",
    "dépeçassiez": "dépecer",
    "dépeçassions": "dépecer",
    "dépeçons": "dépecer",
    "dépeçâmes": "dépecer",
    "dépeçât": "dépecer",
    "dépeçâtes": "dépecer",
    "déphasa": "déphaser",
    "déphasages": "déphasage",
    "déphasai": "déphaser",
    "déphasaient": "déphaser",
    "déphasais": "déphaser",
    "déphasait": "déphaser",
    "déphasant": "déphaser",
    "déphasas": "déphaser",
    "déphasasse": "déphaser",
    "déphasassent": "déphaser",
    "déphasasses": "déphaser",
    "déphasassiez": "déphaser",
    "déphasassions": "déphaser",
    "déphase": "déphaser",
    "déphasent": "déphaser",
    "déphasera": "déphaser",
    "déphaserai": "déphaser",
    "déphaseraient": "déphaser",
    "déphaserais": "déphaser",
    "déphaserait": "déphaser",
    "déphaseras": "déphaser",
    "déphaserez": "déphaser",
    "déphaseriez": "déphaser",
    "déphaserions": "déphaser",
    "déphaserons": "déphaser",
    "déphaseront": "déphaser",
    "déphases": "déphaser",
    "déphaseurs": "déphaseur",
    "déphasez": "déphaser",
    "déphasiez": "déphaser",
    "déphasions": "déphaser",
    "déphasons": "déphaser",
    "déphasâmes": "déphaser",
    "déphasât": "déphaser",
    "déphasâtes": "déphaser",
    "déphasèrent": "déphaser",
    "déphasé": "déphaser",
    "déphasée": "déphaser",
    "déphasées": "déphaser",
    "déphasés": "déphaser",
    "dépiauta": "dépiauter",
    "dépiautai": "dépiauter",
    "dépiautaient": "dépiauter",
    "dépiautais": "dépiauter",
    "dépiautait": "dépiauter",
    "dépiautant": "dépiauter",
    "dépiautas": "dépiauter",
    "dépiautasse": "dépiauter",
    "dépiautassent": "dépiauter",
    "dépiautasses": "dépiauter",
    "dépiautassiez": "dépiauter",
    "dépiautassions": "dépiauter",
    "dépiaute": "dépiauter",
    "dépiautent": "dépiauter",
    "dépiautera": "dépiauter",
    "dépiauterai": "dépiauter",
    "dépiauteraient": "dépiauter",
    "dépiauterais": "dépiauter",
    "dépiauterait": "dépiauter",
    "dépiauteras": "dépiauter",
    "dépiauterez": "dépiauter",
    "dépiauteriez": "dépiauter",
    "dépiauterions": "dépiauter",
    "dépiauterons": "dépiauter",
    "dépiauteront": "dépiauter",
    "dépiautes": "dépiauter",
    "dépiautez": "dépiauter",
    "dépiautiez": "dépiauter",
    "dépiautions": "dépiauter",
    "dépiautons": "dépiauter",
    "dépiautâmes": "dépiauter",
    "dépiautât": "dépiauter",
    "dépiautâtes": "dépiauter",
    "dépiautèrent": "dépiauter",
    "dépiauté": "dépiauter",
    "dépiautée": "dépiauter",
    "dépiautées": "dépiauter",
    "dépiautés": "dépiauter",
    "dépieute": "dépieuter",
    "dépigmenté": "dépigmenter",
    "dépigmentés": "dépigmenter",
    "dépila": "dépiler",
    "dépilai": "dépiler",
    "dépilaient": "dépiler",
    "dépilais": "dépiler",
    "dépilait": "dépiler",
    "dépilant": "dépiler",
    "dépilas": "dépiler",
    "dépilasse": "dépiler",
    "dépilassent": "dépiler",
    "dépilasses": "dépiler",
    "dépilassiez": "dépiler",
    "dépilassions": "dépiler",
    "dépile": "dépiler",
    "dépilent": "dépiler",
    "dépilera": "dépiler",
    "dépilerai": "dépiler",
    "dépileraient": "dépiler",
    "dépilerais": "dépiler",
    "dépilerait": "dépiler",
    "dépileras": "dépiler",
    "dépilerez": "dépiler",
    "dépileriez": "dépiler",
    "dépilerions": "dépiler",
    "dépilerons": "dépiler",
    "dépileront": "dépiler",
    "dépiles": "dépiler",
    "dépilez": "dépiler",
    "dépiliez": "dépiler",
    "dépilions": "dépiler",
    "dépilons": "dépiler",
    "dépilâmes": "dépiler",
    "dépilât": "dépiler",
    "dépilâtes": "dépiler",
    "dépilèrent": "dépiler",
    "dépilé": "dépiler",
    "dépilée": "dépiler",
    "dépilées": "dépiler",
    "dépilés": "dépiler",
    "dépiqua": "dépiquer",
    "dépiquages": "dépiquage",
    "dépiquai": "dépiquer",
    "dépiquaient": "dépiquer",
    "dépiquais": "dépiquer",
    "dépiquait": "dépiquer",
    "dépiquant": "dépiquer",
    "dépiquas": "dépiquer",
    "dépiquasse": "dépiquer",
    "dépiquassent": "dépiquer",
    "dépiquasses": "dépiquer",
    "dépiquassiez": "dépiquer",
    "dépiquassions": "dépiquer",
    "dépique": "dépiquer",
    "dépiquent": "dépiquer",
    "dépiquera": "dépiquer",
    "dépiquerai": "dépiquer",
    "dépiqueraient": "dépiquer",
    "dépiquerais": "dépiquer",
    "dépiquerait": "dépiquer",
    "dépiqueras": "dépiquer",
    "dépiquerez": "dépiquer",
    "dépiqueriez": "dépiquer",
    "dépiquerions": "dépiquer",
    "dépiquerons": "dépiquer",
    "dépiqueront": "dépiquer",
    "dépiques": "dépiquer",
    "dépiquez": "dépiquer",
    "dépiquiez": "dépiquer",
    "dépiquions": "dépiquer",
    "dépiquons": "dépiquer",
    "dépiquâmes": "dépiquer",
    "dépiquât": "dépiquer",
    "dépiquâtes": "dépiquer",
    "dépiquèrent": "dépiquer",
    "dépiqué": "dépiquer",
    "dépiquée": "dépiquer",
    "dépiquées": "dépiquer",
    "dépiqués": "dépiquer",
    "dépista": "dépister",
    "dépistages": "dépistage",
    "dépistai": "dépister",
    "dépistaient": "dépister",
    "dépistais": "dépister",
    "dépistait": "dépister",
    "dépistant": "dépister",
    "dépistas": "dépister",
    "dépistasse": "dépister",
    "dépistassent": "dépister",
    "dépistasses": "dépister",
    "dépistassiez": "dépister",
    "dépistassions": "dépister",
    "dépiste": "dépister",
    "dépistent": "dépister",
    "dépistera": "dépister",
    "dépisterai": "dépister",
    "dépisteraient": "dépister",
    "dépisterais": "dépister",
    "dépisterait": "dépister",
    "dépisteras": "dépister",
    "dépisterez": "dépister",
    "dépisteriez": "dépister",
    "dépisterions": "dépister",
    "dépisterons": "dépister",
    "dépisteront": "dépister",
    "dépistes": "dépister",
    "dépistez": "dépister",
    "dépistiez": "dépister",
    "dépistions": "dépister",
    "dépistons": "dépister",
    "dépistâmes": "dépister",
    "dépistât": "dépister",
    "dépistâtes": "dépister",
    "dépistèrent": "dépister",
    "dépisté": "dépister",
    "dépistée": "dépister",
    "dépistées": "dépister",
    "dépistés": "dépister",
    "dépita": "dépiter",
    "dépitait": "dépiter",
    "dépits": "dépit",
    "dépité": "dépiter",
    "dépitée": "dépiter",
    "dépitées": "dépité",
    "dépités": "dépiter",
    "déplace": "déplacer",
    "déplacements": "déplacement",
    "déplacent": "déplacer",
    "déplacera": "déplacer",
    "déplacerai": "déplacer",
    "déplaceraient": "déplacer",
    "déplacerais": "déplacer",
    "déplacerait": "déplacer",
    "déplaceras": "déplacer",
    "déplacerez": "déplacer",
    "déplaceriez": "déplacer",
    "déplacerions": "déplacer",
    "déplacerons": "déplacer",
    "déplaceront": "déplacer",
    "déplaces": "déplacer",
    "déplacez": "déplacer",
    "déplaciez": "déplacer",
    "déplacions": "déplacer",
    "déplacèrent": "déplacer",
    "déplacé": "déplacer",
    "déplacée": "déplacer",
    "déplacées": "déplacer",
    "déplacés": "déplacer",
    "déplafonnements": "déplafonnement",
    "déplaira": "déplaire",
    "déplairai": "déplaire",
    "déplairaient": "déplaire",
    "déplairais": "déplaire",
    "déplairait": "déplaire",
    "déplairas": "déplaire",
    "déplairez": "déplaire",
    "déplairiez": "déplaire",
    "déplairions": "déplaire",
    "déplairons": "déplaire",
    "déplairont": "déplaire",
    "déplais": "déplaire",
    "déplaisaient": "déplaire",
    "déplaisais": "déplaire",
    "déplaisait": "déplaire",
    "déplaisant": "déplaire",
    "déplaisante": "déplaisant",
    "déplaisantes": "déplaisant",
    "déplaisants": "déplaisant",
    "déplaise": "déplaire",
    "déplaisent": "déplaire",
    "déplaises": "déplaire",
    "déplaisez": "déplaire",
    "déplaisiez": "déplaire",
    "déplaisions": "déplaire",
    "déplaisirs": "déplaisir",
    "déplaisons": "déplaire",
    "déplanque": "déplanquer",
    "déplanta": "déplanter",
    "déplantai": "déplanter",
    "déplantaient": "déplanter",
    "déplantais": "déplanter",
    "déplantait": "déplanter",
    "déplantant": "déplanter",
    "déplantas": "déplanter",
    "déplantasse": "déplanter",
    "déplantassent": "déplanter",
    "déplantasses": "déplanter",
    "déplantassiez": "déplanter",
    "déplantassions": "déplanter",
    "déplante": "déplanter",
    "déplantent": "déplanter",
    "déplantera": "déplanter",
    "déplanterai": "déplanter",
    "déplanteraient": "déplanter",
    "déplanterais": "déplanter",
    "déplanterait": "déplanter",
    "déplanteras": "déplanter",
    "déplanterez": "déplanter",
    "déplanteriez": "déplanter",
    "déplanterions": "déplanter",
    "déplanterons": "déplanter",
    "déplanteront": "déplanter",
    "déplantes": "déplanter",
    "déplantez": "déplanter",
    "déplantiez": "déplanter",
    "déplantions": "déplanter",
    "déplantons": "déplanter",
    "déplantâmes": "déplanter",
    "déplantât": "déplanter",
    "déplantâtes": "déplanter",
    "déplantèrent": "déplanter",
    "déplanté": "déplanter",
    "déplantée": "déplanter",
    "déplantées": "déplanter",
    "déplantés": "déplanter",
    "déplaça": "déplacer",
    "déplaçai": "déplacer",
    "déplaçaient": "déplacer",
    "déplaçais": "déplacer",
    "déplaçait": "déplacer",
    "déplaçant": "déplacer",
    "déplaças": "déplacer",
    "déplaçasse": "déplacer",
    "déplaçassent": "déplacer",
    "déplaçasses": "déplacer",
    "déplaçassiez": "déplacer",
    "déplaçassions": "déplacer",
    "déplaçons": "déplacer",
    "déplaçâmes": "déplacer",
    "déplaçât": "déplacer",
    "déplaçâtes": "déplacer",
    "déplaît": "déplaire",
    "déplia": "déplier",
    "dépliai": "déplier",
    "dépliaient": "déplier",
    "dépliais": "déplier",
    "dépliait": "déplier",
    "dépliant": "déplier",
    "dépliante": "dépliant",
    "dépliants": "dépliant",
    "déplias": "déplier",
    "dépliasse": "déplier",
    "dépliassent": "déplier",
    "dépliasses": "déplier",
    "dépliassiez": "déplier",
    "dépliassions": "déplier",
    "déplie": "déplier",
    "déplient": "déplier",
    "dépliera": "déplier",
    "déplierai": "déplier",
    "déplieraient": "déplier",
    "déplierais": "déplier",
    "déplierait": "déplier",
    "déplieras": "déplier",
    "déplierez": "déplier",
    "déplieriez": "déplier",
    "déplierions": "déplier",
    "déplierons": "déplier",
    "déplieront": "déplier",
    "déplies": "déplier",
    "dépliez": "déplier",
    "dépliiez": "déplier",
    "dépliions": "déplier",
    "déplions": "déplier",
    "déplissa": "déplisser",
    "déplissai": "déplisser",
    "déplissaient": "déplisser",
    "déplissais": "déplisser",
    "déplissait": "déplisser",
    "déplissant": "déplisser",
    "déplissas": "déplisser",
    "déplissasse": "déplisser",
    "déplissassent": "déplisser",
    "déplissasses": "déplisser",
    "déplissassiez": "déplisser",
    "déplissassions": "déplisser",
    "déplisse": "déplisser",
    "déplissent": "déplisser",
    "déplissera": "déplisser",
    "déplisserai": "déplisser",
    "déplisseraient": "déplisser",
    "déplisserais": "déplisser",
    "déplisserait": "déplisser",
    "déplisseras": "déplisser",
    "déplisserez": "déplisser",
    "déplisseriez": "déplisser",
    "déplisserions": "déplisser",
    "déplisserons": "déplisser",
    "déplisseront": "déplisser",
    "déplisses": "déplisser",
    "déplissez": "déplisser",
    "déplissiez": "déplisser",
    "déplissions": "déplisser",
    "déplissons": "déplisser",
    "déplissâmes": "déplisser",
    "déplissât": "déplisser",
    "déplissâtes": "déplisser",
    "déplissèrent": "déplisser",
    "déplissé": "déplisser",
    "déplissée": "déplisser",
    "déplissées": "déplisser",
    "déplissés": "déplisser",
    "dépliâmes": "déplier",
    "dépliât": "déplier",
    "dépliâtes": "déplier",
    "déplièrent": "déplier",
    "déplié": "déplier",
    "dépliée": "déplier",
    "dépliées": "déplier",
    "dépliés": "déplier",
    "déploie": "déployer",
    "déploiements": "déploiement",
    "déploient": "déployer",
    "déploiera": "déployer",
    "déploierai": "déployer",
    "déploieraient": "déployer",
    "déploierais": "déployer",
    "déploierait": "déployer",
    "déploieras": "déployer",
    "déploierez": "déployer",
    "déploieriez": "déployer",
    "déploierions": "déployer",
    "déploierons": "déployer",
    "déploieront": "déployer",
    "déploies": "déployer",
    "déplomba": "déplomber",
    "déplombai": "déplomber",
    "déplombaient": "déplomber",
    "déplombais": "déplomber",
    "déplombait": "déplomber",
    "déplombant": "déplomber",
    "déplombas": "déplomber",
    "déplombasse": "déplomber",
    "déplombassent": "déplomber",
    "déplombasses": "déplomber",
    "déplombassiez": "déplomber",
    "déplombassions": "déplomber",
    "déplombe": "déplomber",
    "déplombent": "déplomber",
    "déplombera": "déplomber",
    "déplomberai": "déplomber",
    "déplomberaient": "déplomber",
    "déplomberais": "déplomber",
    "déplomberait": "déplomber",
    "déplomberas": "déplomber",
    "déplomberez": "déplomber",
    "déplomberiez": "déplomber",
    "déplomberions": "déplomber",
    "déplomberons": "déplomber",
    "déplomberont": "déplomber",
    "déplombes": "déplomber",
    "déplombez": "déplomber",
    "déplombiez": "déplomber",
    "déplombions": "déplomber",
    "déplombons": "déplomber",
    "déplombâmes": "déplomber",
    "déplombât": "déplomber",
    "déplombâtes": "déplomber",
    "déplombèrent": "déplomber",
    "déplombé": "déplomber",
    "déplombée": "déplomber",
    "déplombées": "déplomber",
    "déplombés": "déplomber",
    "déplora": "déplorer",
    "déplorables": "déplorable",
    "déplorai": "déplorer",
    "déploraient": "déplorer",
    "déplorais": "déplorer",
    "déplorait": "déplorer",
    "déplorant": "déplorer",
    "déploras": "déplorer",
    "déplorasse": "déplorer",
    "déplorassent": "déplorer",
    "déplorasses": "déplorer",
    "déplorassiez": "déplorer",
    "déplorassions": "déplorer",
    "déplore": "déplorer",
    "déplorent": "déplorer",
    "déplorera": "déplorer",
    "déplorerai": "déplorer",
    "déploreraient": "déplorer",
    "déplorerais": "déplorer",
    "déplorerait": "déplorer",
    "déploreras": "déplorer",
    "déplorerez": "déplorer",
    "déploreriez": "déplorer",
    "déplorerions": "déplorer",
    "déplorerons": "déplorer",
    "déploreront": "déplorer",
    "déplores": "déplorer",
    "déplorez": "déplorer",
    "déploriez": "déplorer",
    "déplorions": "déplorer",
    "déplorons": "déplorer",
    "déplorâmes": "déplorer",
    "déplorât": "déplorer",
    "déplorâtes": "déplorer",
    "déplorèrent": "déplorer",
    "déploré": "déplorer",
    "déplorée": "déplorer",
    "déplorées": "déplorer",
    "déplorés": "déplorer",
    "déploya": "déployer",
    "déployai": "déployer",
    "déployaient": "déployer",
    "déployais": "déployer",
    "déployait": "déployer",
    "déployant": "déployer",
    "déployas": "déployer",
    "déployasse": "déployer",
    "déployassent": "déployer",
    "déployasses": "déployer",
    "déployassiez": "déployer",
    "déployassions": "déployer",
    "déployez": "déployer",
    "déployiez": "déployer",
    "déployions": "déployer",
    "déployons": "déployer",
    "déployâmes": "déployer",
    "déployât": "déployer",
    "déployâtes": "déployer",
    "déployèrent": "déployer",
    "déployé": "déployer",
    "déployée": "déployer",
    "déployées": "déployer",
    "déployés": "déployer",
    "déplu": "déplaire",
    "dépluma": "déplumer",
    "déplumai": "déplumer",
    "déplumaient": "déplumer",
    "déplumais": "déplumer",
    "déplumait": "déplumer",
    "déplumant": "déplumer",
    "déplumas": "déplumer",
    "déplumasse": "déplumer",
    "déplumassent": "déplumer",
    "déplumasses": "déplumer",
    "déplumassiez": "déplumer",
    "déplumassions": "déplumer",
    "déplume": "déplumer",
    "déplument": "déplumer",
    "déplumera": "déplumer",
    "déplumerai": "déplumer",
    "déplumeraient": "déplumer",
    "déplumerais": "déplumer",
    "déplumerait": "déplumer",
    "déplumeras": "déplumer",
    "déplumerez": "déplumer",
    "déplumeriez": "déplumer",
    "déplumerions": "déplumer",
    "déplumerons": "déplumer",
    "déplumeront": "déplumer",
    "déplumes": "déplumer",
    "déplumez": "déplumer",
    "déplumiez": "déplumer",
    "déplumions": "déplumer",
    "déplumons": "déplumer",
    "déplumâmes": "déplumer",
    "déplumât": "déplumer",
    "déplumâtes": "déplumer",
    "déplumèrent": "déplumer",
    "déplumé": "déplumer",
    "déplumée": "déplumer",
    "déplumées": "déplumer",
    "déplumés": "déplumer",
    "déplurent": "déplaire",
    "déplus": "déplaire",
    "déplusse": "déplaire",
    "déplussent": "déplaire",
    "déplusses": "déplaire",
    "déplussiez": "déplaire",
    "déplussions": "déplaire",
    "déplut": "déplaire",
    "déplâtra": "déplâtrer",
    "déplâtrai": "déplâtrer",
    "déplâtraient": "déplâtrer",
    "déplâtrais": "déplâtrer",
    "déplâtrait": "déplâtrer",
    "déplâtrant": "déplâtrer",
    "déplâtras": "déplâtrer",
    "déplâtrasse": "déplâtrer",
    "déplâtrassent": "déplâtrer",
    "déplâtrasses": "déplâtrer",
    "déplâtrassiez": "déplâtrer",
    "déplâtrassions": "déplâtrer",
    "déplâtre": "déplâtrer",
    "déplâtrent": "déplâtrer",
    "déplâtrera": "déplâtrer",
    "déplâtrerai": "déplâtrer",
    "déplâtreraient": "déplâtrer",
    "déplâtrerais": "déplâtrer",
    "déplâtrerait": "déplâtrer",
    "déplâtreras": "déplâtrer",
    "déplâtrerez": "déplâtrer",
    "déplâtreriez": "déplâtrer",
    "déplâtrerions": "déplâtrer",
    "déplâtrerons": "déplâtrer",
    "déplâtreront": "déplâtrer",
    "déplâtres": "déplâtrer",
    "déplâtrez": "déplâtrer",
    "déplâtriez": "déplâtrer",
    "déplâtrions": "déplâtrer",
    "déplâtrons": "déplâtrer",
    "déplâtrâmes": "déplâtrer",
    "déplâtrât": "déplâtrer",
    "déplâtrâtes": "déplâtrer",
    "déplâtrèrent": "déplâtrer",
    "déplâtré": "déplâtrer",
    "déplâtrée": "déplâtrer",
    "déplâtrées": "déplâtrer",
    "déplâtrés": "déplâtrer",
    "déplûmes": "déplaire",
    "déplût": "déplaire",
    "déplûtes": "déplaire",
    "dépoile": "dépoiler",
    "dépoilé": "dépoiler",
    "dépoilée": "dépoiler",
    "dépoilées": "dépoiler",
    "dépointées": "dépointer",
    "dépoitraillé": "dépoitrailler",
    "dépoitraillée": "dépoitraillé",
    "dépoitraillées": "dépoitraillé",
    "dépoitraillés": "dépoitraillé",
    "dépoli": "dépolir",
    "dépolie": "dépolir",
    "dépolies": "dépolir",
    "dépolira": "dépolir",
    "dépolirai": "dépolir",
    "dépoliraient": "dépolir",
    "dépolirais": "dépolir",
    "dépolirait": "dépolir",
    "dépoliras": "dépolir",
    "dépolirent": "dépolir",
    "dépolirez": "dépolir",
    "dépoliriez": "dépolir",
    "dépolirions": "dépolir",
    "dépolirons": "dépolir",
    "dépoliront": "dépolir",
    "dépolis": "dépolir",
    "dépolissaient": "dépolir",
    "dépolissais": "dépolir",
    "dépolissait": "dépolir",
    "dépolissant": "dépolir",
    "dépolisse": "dépolir",
    "dépolissent": "dépolir",
    "dépolisses": "dépolir",
    "dépolissez": "dépolir",
    "dépolissiez": "dépolir",
    "dépolissions": "dépolir",
    "dépolissons": "dépolir",
    "dépolit": "dépolir",
    "dépolitisa": "dépolitiser",
    "dépolitisai": "dépolitiser",
    "dépolitisaient": "dépolitiser",
    "dépolitisais": "dépolitiser",
    "dépolitisait": "dépolitiser",
    "dépolitisant": "dépolitiser",
    "dépolitisas": "dépolitiser",
    "dépolitisasse": "dépolitiser",
    "dépolitisassent": "dépolitiser",
    "dépolitisasses": "dépolitiser",
    "dépolitisassiez": "dépolitiser",
    "dépolitisassions": "dépolitiser",
    "dépolitisations": "dépolitisation",
    "dépolitise": "dépolitiser",
    "dépolitisent": "dépolitiser",
    "dépolitisera": "dépolitiser",
    "dépolitiserai": "dépolitiser",
    "dépolitiseraient": "dépolitiser",
    "dépolitiserais": "dépolitiser",
    "dépolitiserait": "dépolitiser",
    "dépolitiseras": "dépolitiser",
    "dépolitiserez": "dépolitiser",
    "dépolitiseriez": "dépolitiser",
    "dépolitiserions": "dépolitiser",
    "dépolitiserons": "dépolitiser",
    "dépolitiseront": "dépolitiser",
    "dépolitises": "dépolitiser",
    "dépolitisez": "dépolitiser",
    "dépolitisiez": "dépolitiser",
    "dépolitisions": "dépolitiser",
    "dépolitisons": "dépolitiser",
    "dépolitisâmes": "dépolitiser",
    "dépolitisât": "dépolitiser",
    "dépolitisâtes": "dépolitiser",
    "dépolitisèrent": "dépolitiser",
    "dépolitisé": "dépolitiser",
    "dépolitisée": "dépolitiser",
    "dépolitisées": "dépolitiser",
    "dépolitisés": "dépolitiser",
    "dépollua": "dépolluer",
    "dépolluai": "dépolluer",
    "dépolluaient": "dépolluer",
    "dépolluais": "dépolluer",
    "dépolluait": "dépolluer",
    "dépolluant": "dépolluer",
    "dépolluas": "dépolluer",
    "dépolluasse": "dépolluer",
    "dépolluassent": "dépolluer",
    "dépolluasses": "dépolluer",
    "dépolluassiez": "dépolluer",
    "dépolluassions": "dépolluer",
    "dépollue": "dépolluer",
    "dépolluent": "dépolluer",
    "dépolluera": "dépolluer",
    "dépolluerai": "dépolluer",
    "dépollueraient": "dépolluer",
    "dépolluerais": "dépolluer",
    "dépolluerait": "dépolluer",
    "dépollueras": "dépolluer",
    "dépolluerez": "dépolluer",
    "dépollueriez": "dépolluer",
    "dépolluerions": "dépolluer",
    "dépolluerons": "dépolluer",
    "dépollueront": "dépolluer",
    "dépollues": "dépolluer",
    "dépolluez": "dépolluer",
    "dépolluiez": "dépolluer",
    "dépolluions": "dépolluer",
    "dépolluons": "dépolluer",
    "dépollutions": "dépollution",
    "dépolluâmes": "dépolluer",
    "dépolluât": "dépolluer",
    "dépolluâtes": "dépolluer",
    "dépolluèrent": "dépolluer",
    "dépollué": "dépolluer",
    "dépolluée": "dépolluer",
    "dépolluées": "dépolluer",
    "dépollués": "dépolluer",
    "dépolîmes": "dépolir",
    "dépolît": "dépolir",
    "dépolîtes": "dépolir",
    "déponente": "déponent",
    "déponentes": "déponent",
    "déponents": "déponent",
    "dépopulations": "dépopulation",
    "déporta": "déporter",
    "déportai": "déporter",
    "déportaient": "déporter",
    "déportais": "déporter",
    "déportait": "déporter",
    "déportant": "déporter",
    "déportas": "déporter",
    "déportasse": "déporter",
    "déportassent": "déporter",
    "déportasses": "déporter",
    "déportassiez": "déporter",
    "déportassions": "déporter",
    "déportations": "déportation",
    "déporte": "déporter",
    "déportements": "déportement",
    "déportent": "déporter",
    "déportera": "déporter",
    "déporterai": "déporter",
    "déporteraient": "déporter",
    "déporterais": "déporter",
    "déporterait": "déporter",
    "déporteras": "déporter",
    "déporterez": "déporter",
    "déporteriez": "déporter",
    "déporterions": "déporter",
    "déporterons": "déporter",
    "déporteront": "déporter",
    "déportes": "déporter",
    "déportez": "déporter",
    "déportiez": "déporter",
    "déportions": "déporter",
    "déportons": "déporter",
    "déportâmes": "déporter",
    "déportât": "déporter",
    "déportâtes": "déporter",
    "déportèrent": "déporter",
    "déporté": "déporter",
    "déportée": "déporter",
    "déportées": "déporter",
    "déportés": "déporter",
    "déposa": "déposer",
    "déposai": "déposer",
    "déposaient": "déposer",
    "déposais": "déposer",
    "déposait": "déposer",
    "déposant": "déposer",
    "déposante": "déposant",
    "déposantes": "déposant",
    "déposants": "déposant",
    "déposas": "déposer",
    "déposasse": "déposer",
    "déposassent": "déposer",
    "déposasses": "déposer",
    "déposassiez": "déposer",
    "déposassions": "déposer",
    "dépose": "déposer",
    "déposent": "déposer",
    "déposera": "déposer",
    "déposerai": "déposer",
    "déposeraient": "déposer",
    "déposerais": "déposer",
    "déposerait": "déposer",
    "déposeras": "déposer",
    "déposerez": "déposer",
    "déposeriez": "déposer",
    "déposerions": "déposer",
    "déposerons": "déposer",
    "déposeront": "déposer",
    "déposes": "déposer",
    "déposez": "déposer",
    "déposiez": "déposer",
    "déposions": "déposer",
    "dépositaires": "dépositaire",
    "dépositions": "déposition",
    "déposons": "déposer",
    "dépossède": "déposséder",
    "dépossèdent": "déposséder",
    "dépossèdes": "déposséder",
    "déposséda": "déposséder",
    "dépossédai": "déposséder",
    "dépossédaient": "déposséder",
    "dépossédais": "déposséder",
    "dépossédait": "déposséder",
    "dépossédant": "déposséder",
    "dépossédas": "déposséder",
    "dépossédasse": "déposséder",
    "dépossédassent": "déposséder",
    "dépossédasses": "déposséder",
    "dépossédassiez": "déposséder",
    "dépossédassions": "déposséder",
    "dépossédera": "déposséder",
    "déposséderai": "déposséder",
    "déposséderaient": "déposséder",
    "déposséderais": "déposséder",
    "déposséderait": "déposséder",
    "déposséderas": "déposséder",
    "déposséderez": "déposséder",
    "déposséderiez": "déposséder",
    "déposséderions": "déposséder",
    "déposséderons": "déposséder",
    "déposséderont": "déposséder",
    "dépossédez": "déposséder",
    "dépossédiez": "déposséder",
    "dépossédions": "déposséder",
    "dépossédons": "déposséder",
    "dépossédâmes": "déposséder",
    "dépossédât": "déposséder",
    "dépossédâtes": "déposséder",
    "dépossédèrent": "déposséder",
    "dépossédé": "déposséder",
    "dépossédée": "déposséder",
    "dépossédées": "déposséder",
    "dépossédés": "déposséder",
    "déposâmes": "déposer",
    "déposât": "déposer",
    "déposâtes": "déposer",
    "déposèrent": "déposer",
    "déposé": "déposer",
    "déposée": "déposer",
    "déposées": "déposer",
    "déposés": "déposer",
    "dépota": "dépoter",
    "dépotai": "dépoter",
    "dépotaient": "dépoter",
    "dépotais": "dépoter",
    "dépotait": "dépoter",
    "dépotant": "dépoter",
    "dépotas": "dépoter",
    "dépotasse": "dépoter",
    "dépotassent": "dépoter",
    "dépotasses": "dépoter",
    "dépotassiez": "dépoter",
    "dépotassions": "dépoter",
    "dépote": "dépoter",
    "dépotent": "dépoter",
    "dépotera": "dépoter",
    "dépoterai": "dépoter",
    "dépoteraient": "dépoter",
    "dépoterais": "dépoter",
    "dépoterait": "dépoter",
    "dépoteras": "dépoter",
    "dépoterez": "dépoter",
    "dépoteriez": "dépoter",
    "dépoterions": "dépoter",
    "dépoterons": "dépoter",
    "dépoteront": "dépoter",
    "dépotes": "dépoter",
    "dépotez": "dépoter",
    "dépotiez": "dépoter",
    "dépotions": "dépoter",
    "dépotoirs": "dépotoir",
    "dépotons": "dépoter",
    "dépotâmes": "dépoter",
    "dépotât": "dépoter",
    "dépotâtes": "dépoter",
    "dépotèrent": "dépoter",
    "dépoté": "dépoter",
    "dépotée": "dépoter",
    "dépotées": "dépoter",
    "dépotés": "dépoter",
    "dépoudra": "dépoudrer",
    "dépoudrai": "dépoudrer",
    "dépoudraient": "dépoudrer",
    "dépoudrais": "dépoudrer",
    "dépoudrait": "dépoudrer",
    "dépoudrant": "dépoudrer",
    "dépoudras": "dépoudrer",
    "dépoudrasse": "dépoudrer",
    "dépoudrassent": "dépoudrer",
    "dépoudrasses": "dépoudrer",
    "dépoudrassiez": "dépoudrer",
    "dépoudrassions": "dépoudrer",
    "dépoudre": "dépoudrer",
    "dépoudrent": "dépoudrer",
    "dépoudrera": "dépoudrer",
    "dépoudrerai": "dépoudrer",
    "dépoudreraient": "dépoudrer",
    "dépoudrerais": "dépoudrer",
    "dépoudrerait": "dépoudrer",
    "dépoudreras": "dépoudrer",
    "dépoudrerez": "dépoudrer",
    "dépoudreriez": "dépoudrer",
    "dépoudrerions": "dépoudrer",
    "dépoudrerons": "dépoudrer",
    "dépoudreront": "dépoudrer",
    "dépoudres": "dépoudrer",
    "dépoudrez": "dépoudrer",
    "dépoudriez": "dépoudrer",
    "dépoudrions": "dépoudrer",
    "dépoudrons": "dépoudrer",
    "dépoudrâmes": "dépoudrer",
    "dépoudrât": "dépoudrer",
    "dépoudrâtes": "dépoudrer",
    "dépoudrèrent": "dépoudrer",
    "dépoudré": "dépoudrer",
    "dépoudrée": "dépoudrer",
    "dépoudrées": "dépoudrer",
    "dépoudrés": "dépoudrer",
    "dépouilla": "dépouiller",
    "dépouillai": "dépouiller",
    "dépouillaient": "dépouiller",
    "dépouillais": "dépouiller",
    "dépouillait": "dépouiller",
    "dépouillant": "dépouiller",
    "dépouillas": "dépouiller",
    "dépouillasse": "dépouiller",
    "dépouillassent": "dépouiller",
    "dépouillasses": "dépouiller",
    "dépouillassiez": "dépouiller",
    "dépouillassions": "dépouiller",
    "dépouille": "dépouiller",
    "dépouillements": "dépouillement",
    "dépouillent": "dépouiller",
    "dépouillera": "dépouiller",
    "dépouillerai": "dépouiller",
    "dépouilleraient": "dépouiller",
    "dépouillerais": "dépouiller",
    "dépouillerait": "dépouiller",
    "dépouilleras": "dépouiller",
    "dépouillerez": "dépouiller",
    "dépouilleriez": "dépouiller",
    "dépouillerions": "dépouiller",
    "dépouillerons": "dépouiller",
    "dépouilleront": "dépouiller",
    "dépouilles": "dépouiller",
    "dépouillez": "dépouiller",
    "dépouilliez": "dépouiller",
    "dépouillions": "dépouiller",
    "dépouillons": "dépouiller",
    "dépouillâmes": "dépouiller",
    "dépouillât": "dépouiller",
    "dépouillâtes": "dépouiller",
    "dépouillèrent": "dépouiller",
    "dépouillé": "dépouiller",
    "dépouillée": "dépouiller",
    "dépouillées": "dépouiller",
    "dépouillés": "dépouiller",
    "dépourvoie": "dépourvoir",
    "dépourvoient": "dépourvoir",
    "dépourvoies": "dépourvoir",
    "dépourvoira": "dépourvoir",
    "dépourvoirai": "dépourvoir",
    "dépourvoiraient": "dépourvoir",
    "dépourvoirais": "dépourvoir",
    "dépourvoirait": "dépourvoir",
    "dépourvoiras": "dépourvoir",
    "dépourvoirez": "dépourvoir",
    "dépourvoiriez": "dépourvoir",
    "dépourvoirions": "dépourvoir",
    "dépourvoirons": "dépourvoir",
    "dépourvoiront": "dépourvoir",
    "dépourvois": "dépourvoir",
    "dépourvoit": "dépourvoir",
    "dépourvoyaient": "dépourvoir",
    "dépourvoyais": "dépourvoir",
    "dépourvoyait": "dépourvoir",
    "dépourvoyant": "dépourvoir",
    "dépourvoyez": "dépourvoir",
    "dépourvoyiez": "dépourvoir",
    "dépourvoyions": "dépourvoir",
    "dépourvoyons": "dépourvoir",
    "dépourvu": "dépourvoir",
    "dépourvue": "dépourvu",
    "dépourvues": "dépourvu",
    "dépourvurent": "dépourvoir",
    "dépourvus": "dépourvu",
    "dépourvusse": "dépourvoir",
    "dépourvussent": "dépourvoir",
    "dépourvusses": "dépourvoir",
    "dépourvussiez": "dépourvoir",
    "dépourvussions": "dépourvoir",
    "dépourvut": "dépourvoir",
    "dépourvûmes": "dépourvoir",
    "dépourvût": "dépourvoir",
    "dépourvûtes": "dépourvoir",
    "dépoussière": "dépoussiérer",
    "dépoussièrent": "dépoussiérer",
    "dépoussières": "dépoussiérer",
    "dépoussiéra": "dépoussiérer",
    "dépoussiérai": "dépoussiérer",
    "dépoussiéraient": "dépoussiérer",
    "dépoussiérais": "dépoussiérer",
    "dépoussiérait": "dépoussiérer",
    "dépoussiérant": "dépoussiérer",
    "dépoussiéras": "dépoussiérer",
    "dépoussiérasse": "dépoussiérer",
    "dépoussiérassent": "dépoussiérer",
    "dépoussiérasses": "dépoussiérer",
    "dépoussiérassiez": "dépoussiérer",
    "dépoussiérassions": "dépoussiérer",
    "dépoussiérera": "dépoussiérer",
    "dépoussiérerai": "dépoussiérer",
    "dépoussiéreraient": "dépoussiérer",
    "dépoussiérerais": "dépoussiérer",
    "dépoussiérerait": "dépoussiérer",
    "dépoussiéreras": "dépoussiérer",
    "dépoussiérerez": "dépoussiérer",
    "dépoussiéreriez": "dépoussiérer",
    "dépoussiérerions": "dépoussiérer",
    "dépoussiérerons": "dépoussiérer",
    "dépoussiéreront": "dépoussiérer",
    "dépoussiérez": "dépoussiérer",
    "dépoussiériez": "dépoussiérer",
    "dépoussiérions": "dépoussiérer",
    "dépoussiérons": "dépoussiérer",
    "dépoussiérâmes": "dépoussiérer",
    "dépoussiérât": "dépoussiérer",
    "dépoussiérâtes": "dépoussiérer",
    "dépoussiérèrent": "dépoussiérer",
    "dépoussiéré": "dépoussiérer",
    "dépoussiérée": "dépoussiérer",
    "dépoussiérées": "dépoussiérer",
    "dépoussiérés": "dépoussiérer",
    "dépoétisa": "dépoétiser",
    "dépoétisai": "dépoétiser",
    "dépoétisaient": "dépoétiser",
    "dépoétisais": "dépoétiser",
    "dépoétisait": "dépoétiser",
    "dépoétisant": "dépoétiser",
    "dépoétisas": "dépoétiser",
    "dépoétisasse": "dépoétiser",
    "dépoétisassent": "dépoétiser",
    "dépoétisasses": "dépoétiser",
    "dépoétisassiez": "dépoétiser",
    "dépoétisassions": "dépoétiser",
    "dépoétise": "dépoétiser",
    "dépoétisent": "dépoétiser",
    "dépoétisera": "dépoétiser",
    "dépoétiserai": "dépoétiser",
    "dépoétiseraient": "dépoétiser",
    "dépoétiserais": "dépoétiser",
    "dépoétiserait": "dépoétiser",
    "dépoétiseras": "dépoétiser",
    "dépoétiserez": "dépoétiser",
    "dépoétiseriez": "dépoétiser",
    "dépoétiserions": "dépoétiser",
    "dépoétiserons": "dépoétiser",
    "dépoétiseront": "dépoétiser",
    "dépoétises": "dépoétiser",
    "dépoétisez": "dépoétiser",
    "dépoétisiez": "dépoétiser",
    "dépoétisions": "dépoétiser",
    "dépoétisons": "dépoétiser",
    "dépoétisâmes": "dépoétiser",
    "dépoétisât": "dépoétiser",
    "dépoétisâtes": "dépoétiser",
    "dépoétisèrent": "dépoétiser",
    "dépoétisé": "dépoétiser",
    "dépoétisée": "dépoétiser",
    "dépoétisées": "dépoétiser",
    "dépoétisés": "dépoétiser",
    "déprava": "dépraver",
    "dépravai": "dépraver",
    "dépravaient": "dépraver",
    "dépravais": "dépraver",
    "dépravait": "dépraver",
    "dépravant": "dépraver",
    "dépravas": "dépraver",
    "dépravasse": "dépraver",
    "dépravassent": "dépraver",
    "dépravasses": "dépraver",
    "dépravassiez": "dépraver",
    "dépravassions": "dépraver",
    "dépravations": "dépravation",
    "déprave": "dépraver",
    "dépravent": "dépraver",
    "dépravera": "dépraver",
    "dépraverai": "dépraver",
    "dépraveraient": "dépraver",
    "dépraverais": "dépraver",
    "dépraverait": "dépraver",
    "dépraveras": "dépraver",
    "dépraverez": "dépraver",
    "dépraveriez": "dépraver",
    "dépraverions": "dépraver",
    "dépraverons": "dépraver",
    "dépraveront": "dépraver",
    "dépraves": "dépraver",
    "dépravez": "dépraver",
    "dépraviez": "dépraver",
    "dépravions": "dépraver",
    "dépravons": "dépraver",
    "dépravâmes": "dépraver",
    "dépravât": "dépraver",
    "dépravâtes": "dépraver",
    "dépravèrent": "dépraver",
    "dépravé": "dépraver",
    "dépravée": "dépraver",
    "dépravées": "dépraver",
    "dépravés": "dépraver",
    "déprenaient": "déprendre",
    "déprenais": "déprendre",
    "déprenait": "déprendre",
    "déprenant": "déprendre",
    "déprend": "déprendre",
    "déprendra": "déprendre",
    "déprendrai": "déprendre",
    "déprendraient": "déprendre",
    "déprendrais": "déprendre",
    "déprendrait": "déprendre",
    "déprendras": "déprendre",
    "déprendrez": "déprendre",
    "déprendriez": "déprendre",
    "déprendrions": "déprendre",
    "déprendrons": "déprendre",
    "déprendront": "déprendre",
    "déprends": "déprendre",
    "déprenez": "déprendre",
    "dépreniez": "déprendre",
    "déprenions": "déprendre",
    "déprenne": "déprendre",
    "déprennent": "déprendre",
    "déprennes": "déprendre",
    "déprenons": "déprendre",
    "dépressifs": "dépressif",
    "dépressions": "dépression",
    "dépressive": "dépressif",
    "dépressives": "dépressif",
    "dépressurisait": "dépressuriser",
    "dépressurise": "dépressuriser",
    "dépressurisé": "dépressuriser",
    "dépressurisés": "dépressuriser",
    "déprima": "déprimer",
    "déprimai": "déprimer",
    "déprimaient": "déprimer",
    "déprimais": "déprimer",
    "déprimait": "déprimer",
    "déprimant": "déprimer",
    "déprimante": "déprimant",
    "déprimantes": "déprimant",
    "déprimants": "déprimant",
    "déprimas": "déprimer",
    "déprimasse": "déprimer",
    "déprimassent": "déprimer",
    "déprimasses": "déprimer",
    "déprimassiez": "déprimer",
    "déprimassions": "déprimer",
    "déprime": "déprimer",
    "dépriment": "déprimer",
    "déprimera": "déprimer",
    "déprimerai": "déprimer",
    "déprimeraient": "déprimer",
    "déprimerais": "déprimer",
    "déprimerait": "déprimer",
    "déprimeras": "déprimer",
    "déprimerez": "déprimer",
    "déprimeriez": "déprimer",
    "déprimerions": "déprimer",
    "déprimerons": "déprimer",
    "déprimeront": "déprimer",
    "déprimes": "déprimer",
    "déprimez": "déprimer",
    "déprimiez": "déprimer",
    "déprimions": "déprimer",
    "déprimons": "déprimer",
    "déprimâmes": "déprimer",
    "déprimât": "déprimer",
    "déprimâtes": "déprimer",
    "déprimèrent": "déprimer",
    "déprimé": "déprimer",
    "déprimée": "déprimer",
    "déprimées": "déprimer",
    "déprimés": "déprimer",
    "déprirent": "déprendre",
    "dépris": "déprendre",
    "déprise": "déprendre",
    "déprises": "déprendre",
    "déprisse": "déprendre",
    "déprissent": "déprendre",
    "déprisses": "déprendre",
    "déprissiez": "déprendre",
    "déprissions": "déprendre",
    "déprit": "déprendre",
    "déprogrammations": "déprogrammation",
    "déprogrammez": "déprogrammer",
    "déprogrammé": "déprogrammer",
    "déprogrammée": "déprogrammer",
    "déprécations": "déprécation",
    "déprécia": "déprécier",
    "dépréciai": "déprécier",
    "dépréciaient": "déprécier",
    "dépréciais": "déprécier",
    "dépréciait": "déprécier",
    "dépréciant": "déprécier",
    "déprécias": "déprécier",
    "dépréciasse": "déprécier",
    "dépréciassent": "déprécier",
    "dépréciasses": "déprécier",
    "dépréciassiez": "déprécier",
    "dépréciassions": "déprécier",
    "dépréciatifs": "dépréciatif",
    "dépréciations": "dépréciation",
    "dépréciative": "dépréciatif",
    "dépréciatives": "dépréciatif",
    "déprécie": "déprécier",
    "déprécient": "déprécier",
    "dépréciera": "déprécier",
    "déprécierai": "déprécier",
    "déprécieraient": "déprécier",
    "déprécierais": "déprécier",
    "déprécierait": "déprécier",
    "déprécieras": "déprécier",
    "déprécierez": "déprécier",
    "déprécieriez": "déprécier",
    "déprécierions": "déprécier",
    "déprécierons": "déprécier",
    "déprécieront": "déprécier",
    "déprécies": "déprécier",
    "dépréciez": "déprécier",
    "dépréciiez": "déprécier",
    "dépréciions": "déprécier",
    "déprécions": "déprécier",
    "dépréciâmes": "déprécier",
    "dépréciât": "déprécier",
    "dépréciâtes": "déprécier",
    "déprécièrent": "déprécier",
    "déprécié": "déprécier",
    "dépréciée": "déprécier",
    "dépréciées": "déprécier",
    "dépréciés": "déprécier",
    "déprédateurs": "déprédateur",
    "déprédations": "déprédation",
    "déprîmes": "déprendre",
    "déprît": "déprendre",
    "déprîtes": "déprendre",
    "dépucela": "dépuceler",
    "dépucelages": "dépucelage",
    "dépuceleurs": "dépuceleur",
    "dépucelle": "dépuceler",
    "dépucellera": "dépuceler",
    "dépucelons": "dépuceler",
    "dépucelé": "dépuceler",
    "dépucelée": "dépuceler",
    "dépulpé": "dépulper",
    "dépura": "dépurer",
    "dépurai": "dépurer",
    "dépuraient": "dépurer",
    "dépurais": "dépurer",
    "dépurait": "dépurer",
    "dépurant": "dépurer",
    "dépuras": "dépurer",
    "dépurasse": "dépurer",
    "dépurassent": "dépurer",
    "dépurasses": "dépurer",
    "dépurassiez": "dépurer",
    "dépurassions": "dépurer",
    "dépuratifs": "dépuratif",
    "dépure": "dépurer",
    "dépurent": "dépurer",
    "dépurera": "dépurer",
    "dépurerai": "dépurer",
    "dépureraient": "dépurer",
    "dépurerais": "dépurer",
    "dépurerait": "dépurer",
    "dépureras": "dépurer",
    "dépurerez": "dépurer",
    "dépureriez": "dépurer",
    "dépurerions": "dépurer",
    "dépurerons": "dépurer",
    "dépureront": "dépurer",
    "dépures": "dépurer",
    "dépurez": "dépurer",
    "dépuriez": "dépurer",
    "dépurions": "dépurer",
    "dépurons": "dépurer",
    "dépurâmes": "dépurer",
    "dépurât": "dépurer",
    "dépurâtes": "dépurer",
    "dépurèrent": "dépurer",
    "dépuré": "dépurer",
    "dépurée": "dépurer",
    "dépurées": "dépurer",
    "dépurés": "dépurer",
    "députa": "députer",
    "députai": "députer",
    "députaient": "députer",
    "députais": "députer",
    "députait": "députer",
    "députant": "députer",
    "députas": "députer",
    "députasse": "députer",
    "députassent": "députer",
    "députasses": "députer",
    "députassiez": "députer",
    "députassions": "députer",
    "députations": "députation",
    "députe": "députer",
    "députent": "députer",
    "députera": "députer",
    "députerai": "députer",
    "députeraient": "députer",
    "députerais": "députer",
    "députerait": "députer",
    "députeras": "députer",
    "députerez": "députer",
    "députeriez": "députer",
    "députerions": "députer",
    "députerons": "députer",
    "députeront": "députer",
    "députes": "députer",
    "députez": "députer",
    "députiez": "députer",
    "députions": "députer",
    "députons": "députer",
    "députâmes": "députer",
    "députât": "députer",
    "députâtes": "députer",
    "députèrent": "députer",
    "député": "députer",
    "députée": "députer",
    "députées": "députer",
    "députés": "députer",
    "députés-maires": "député-maire",
    "dépèce": "dépecer",
    "dépècements": "dépècement",
    "dépècent": "dépecer",
    "dépècera": "dépecer",
    "dépècerai": "dépecer",
    "dépèceraient": "dépecer",
    "dépècerais": "dépecer",
    "dépècerait": "dépecer",
    "dépèceras": "dépecer",
    "dépècerez": "dépecer",
    "dépèceriez": "dépecer",
    "dépècerions": "dépecer",
    "dépècerons": "dépecer",
    "dépèceront": "dépecer",
    "dépèces": "dépecer",
    "dépénalisations": "dépénalisation",
    "dépéri": "dépérir",
    "dépérira": "dépérir",
    "dépérirai": "dépérir",
    "dépériraient": "dépérir",
    "dépérirais": "dépérir",
    "dépérirait": "dépérir",
    "dépériras": "dépérir",
    "dépérirent": "dépérir",
    "dépérirez": "dépérir",
    "dépéririez": "dépérir",
    "dépéririons": "dépérir",
    "dépérirons": "dépérir",
    "dépériront": "dépérir",
    "dépéris": "dépérir",
    "dépérissaient": "dépérir",
    "dépérissais": "dépérir",
    "dépérissait": "dépérir",
    "dépérissant": "dépérir",
    "dépérisse": "dépérir",
    "dépérissements": "dépérissement",
    "dépérissent": "dépérir",
    "dépérisses": "dépérir",
    "dépérissez": "dépérir",
    "dépérissiez": "dépérir",
    "dépérissions": "dépérir",
    "dépérissons": "dépérir",
    "dépérit": "dépérir",
    "dépérîmes": "dépérir",
    "dépérît": "dépérir",
    "dépérîtes": "dépérir",
    "dépêcha": "dépêcher",
    "dépêchai": "dépêcher",
    "dépêchaient": "dépêcher",
    "dépêchais": "dépêcher",
    "dépêchait": "dépêcher",
    "dépêchant": "dépêcher",
    "dépêchas": "dépêcher",
    "dépêchasse": "dépêcher",
    "dépêchassent": "dépêcher",
    "dépêchasses": "dépêcher",
    "dépêchassiez": "dépêcher",
    "dépêchassions": "dépêcher",
    "dépêche": "dépêcher",
    "dépêchent": "dépêcher",
    "dépêchera": "dépêcher",
    "dépêcherai": "dépêcher",
    "dépêcheraient": "dépêcher",
    "dépêcherais": "dépêcher",
    "dépêcherait": "dépêcher",
    "dépêcheras": "dépêcher",
    "dépêcherez": "dépêcher",
    "dépêcheriez": "dépêcher",
    "dépêcherions": "dépêcher",
    "dépêcherons": "dépêcher",
    "dépêcheront": "dépêcher",
    "dépêches": "dépêcher",
    "dépêchez": "dépêcher",
    "dépêchiez": "dépêcher",
    "dépêchions": "dépêcher",
    "dépêchons": "dépêcher",
    "dépêchâmes": "dépêcher",
    "dépêchât": "dépêcher",
    "dépêchâtes": "dépêcher",
    "dépêchèrent": "dépêcher",
    "dépêché": "dépêcher",
    "dépêchée": "dépêcher",
    "dépêchées": "dépêcher",
    "dépêchés": "dépêcher",
    "dépêtra": "dépêtrer",
    "dépêtrai": "dépêtrer",
    "dépêtraient": "dépêtrer",
    "dépêtrais": "dépêtrer",
    "dépêtrait": "dépêtrer",
    "dépêtrant": "dépêtrer",
    "dépêtras": "dépêtrer",
    "dépêtrasse": "dépêtrer",
    "dépêtrassent": "dépêtrer",
    "dépêtrasses": "dépêtrer",
    "dépêtrassiez": "dépêtrer",
    "dépêtrassions": "dépêtrer",
    "dépêtre": "dépêtrer",
    "dépêtrent": "dépêtrer",
    "dépêtrera": "dépêtrer",
    "dépêtrerai": "dépêtrer",
    "dépêtreraient": "dépêtrer",
    "dépêtrerais": "dépêtrer",
    "dépêtrerait": "dépêtrer",
    "dépêtreras": "dépêtrer",
    "dépêtrerez": "dépêtrer",
    "dépêtreriez": "dépêtrer",
    "dépêtrerions": "dépêtrer",
    "dépêtrerons": "dépêtrer",
    "dépêtreront": "dépêtrer",
    "dépêtres": "dépêtrer",
    "dépêtrez": "dépêtrer",
    "dépêtriez": "dépêtrer",
    "dépêtrions": "dépêtrer",
    "dépêtrons": "dépêtrer",
    "dépêtrâmes": "dépêtrer",
    "dépêtrât": "dépêtrer",
    "dépêtrâtes": "dépêtrer",
    "dépêtrèrent": "dépêtrer",
    "dépêtré": "dépêtrer",
    "dépêtrée": "dépêtrer",
    "dépêtrées": "dépêtrer",
    "dépêtrés": "dépêtrer",
    "dépôts": "dépôt",
    "déqualifications": "déqualification",
    "déquillé": "déquiller",
    "déquillés": "déquiller",
    "déracina": "déraciner",
    "déracinai": "déraciner",
    "déracinaient": "déraciner",
    "déracinais": "déraciner",
    "déracinait": "déraciner",
    "déracinant": "déraciner",
    "déracinas": "déraciner",
    "déracinasse": "déraciner",
    "déracinassent": "déraciner",
    "déracinasses": "déraciner",
    "déracinassiez": "déraciner",
    "déracinassions": "déraciner",
    "déracine": "déraciner",
    "déracinements": "déracinement",
    "déracinent": "déraciner",
    "déracinera": "déraciner",
    "déracinerai": "déraciner",
    "déracineraient": "déraciner",
    "déracinerais": "déraciner",
    "déracinerait": "déraciner",
    "déracineras": "déraciner",
    "déracinerez": "déraciner",
    "déracineriez": "déraciner",
    "déracinerions": "déraciner",
    "déracinerons": "déraciner",
    "déracineront": "déraciner",
    "déracines": "déraciner",
    "déracinez": "déraciner",
    "déraciniez": "déraciner",
    "déracinions": "déraciner",
    "déracinons": "déraciner",
    "déracinâmes": "déraciner",
    "déracinât": "déraciner",
    "déracinâtes": "déraciner",
    "déracinèrent": "déraciner",
    "déraciné": "déraciner",
    "déracinée": "déraciner",
    "déracinées": "déraciner",
    "déracinés": "déraciner",
    "dérada": "dérader",
    "déradai": "dérader",
    "déradaient": "dérader",
    "déradais": "dérader",
    "déradait": "dérader",
    "déradant": "dérader",
    "déradas": "dérader",
    "déradasse": "dérader",
    "déradassent": "dérader",
    "déradasses": "dérader",
    "déradassiez": "dérader",
    "déradassions": "dérader",
    "dérade": "dérader",
    "déradent": "dérader",
    "déradera": "dérader",
    "déraderai": "dérader",
    "déraderaient": "dérader",
    "déraderais": "dérader",
    "déraderait": "dérader",
    "déraderas": "dérader",
    "déraderez": "dérader",
    "déraderiez": "dérader",
    "déraderions": "dérader",
    "déraderons": "dérader",
    "déraderont": "dérader",
    "dérades": "dérader",
    "déradez": "dérader",
    "déradiez": "dérader",
    "déradions": "dérader",
    "déradons": "dérader",
    "déradâmes": "dérader",
    "déradât": "dérader",
    "déradâtes": "dérader",
    "déradèrent": "dérader",
    "déradé": "dérader",
    "dérage": "dérager",
    "déragea": "dérager",
    "dérageai": "dérager",
    "dérageaient": "dérager",
    "dérageais": "dérager",
    "dérageait": "dérager",
    "dérageant": "dérager",
    "dérageas": "dérager",
    "dérageasse": "dérager",
    "dérageassent": "dérager",
    "dérageasses": "dérager",
    "dérageassiez": "dérager",
    "dérageassions": "dérager",
    "déragent": "dérager",
    "dérageons": "dérager",
    "déragera": "dérager",
    "déragerai": "dérager",
    "dérageraient": "dérager",
    "déragerais": "dérager",
    "déragerait": "dérager",
    "dérageras": "dérager",
    "déragerez": "dérager",
    "dérageriez": "dérager",
    "déragerions": "dérager",
    "déragerons": "dérager",
    "dérageront": "dérager",
    "dérages": "dérager",
    "déragez": "dérager",
    "dérageâmes": "dérager",
    "dérageât": "dérager",
    "dérageâtes": "dérager",
    "déragiez": "dérager",
    "déragions": "dérager",
    "déragèrent": "dérager",
    "déragé": "dérager",
    "dérailla": "dérailler",
    "déraillai": "dérailler",
    "déraillaient": "dérailler",
    "déraillais": "dérailler",
    "déraillait": "dérailler",
    "déraillant": "dérailler",
    "déraillas": "dérailler",
    "déraillasse": "dérailler",
    "déraillassent": "dérailler",
    "déraillasses": "dérailler",
    "déraillassiez": "dérailler",
    "déraillassions": "dérailler",
    "déraille": "dérailler",
    "déraillements": "déraillement",
    "déraillent": "dérailler",
    "déraillera": "dérailler",
    "déraillerai": "dérailler",
    "dérailleraient": "dérailler",
    "déraillerais": "dérailler",
    "déraillerait": "dérailler",
    "dérailleras": "dérailler",
    "déraillerez": "dérailler",
    "dérailleriez": "dérailler",
    "déraillerions": "dérailler",
    "déraillerons": "dérailler",
    "dérailleront": "dérailler",
    "dérailles": "dérailler",
    "déraillez": "dérailler",
    "dérailliez": "dérailler",
    "déraillions": "dérailler",
    "déraillons": "dérailler",
    "déraillâmes": "dérailler",
    "déraillât": "dérailler",
    "déraillâtes": "dérailler",
    "déraillèrent": "dérailler",
    "déraillé": "dérailler",
    "déraisonna": "déraisonner",
    "déraisonnables": "déraisonnable",
    "déraisonnai": "déraisonner",
    "déraisonnaient": "déraisonner",
    "déraisonnais": "déraisonner",
    "déraisonnait": "déraisonner",
    "déraisonnant": "déraisonner",
    "déraisonnas": "déraisonner",
    "déraisonnasse": "déraisonner",
    "déraisonnassent": "déraisonner",
    "déraisonnasses": "déraisonner",
    "déraisonnassiez": "déraisonner",
    "déraisonnassions": "déraisonner",
    "déraisonne": "déraisonner",
    "déraisonnent": "déraisonner",
    "déraisonnera": "déraisonner",
    "déraisonnerai": "déraisonner",
    "déraisonneraient": "déraisonner",
    "déraisonnerais": "déraisonner",
    "déraisonnerait": "déraisonner",
    "déraisonneras": "déraisonner",
    "déraisonnerez": "déraisonner",
    "déraisonneriez": "déraisonner",
    "déraisonnerions": "déraisonner",
    "déraisonnerons": "déraisonner",
    "déraisonneront": "déraisonner",
    "déraisonnes": "déraisonner",
    "déraisonnez": "déraisonner",
    "déraisonniez": "déraisonner",
    "déraisonnions": "déraisonner",
    "déraisonnons": "déraisonner",
    "déraisonnâmes": "déraisonner",
    "déraisonnât": "déraisonner",
    "déraisonnâtes": "déraisonner",
    "déraisonnèrent": "déraisonner",
    "déraisonné": "déraisonner",
    "déraisons": "déraison",
    "dérange": "déranger",
    "dérangea": "déranger",
    "dérangeai": "déranger",
    "dérangeaient": "déranger",
    "dérangeais": "déranger",
    "dérangeait": "déranger",
    "dérangeant": "déranger",
    "dérangeante": "dérangeant",
    "dérangeantes": "dérangeant",
    "dérangeants": "dérangeant",
    "dérangeas": "déranger",
    "dérangeasse": "déranger",
    "dérangeassent": "déranger",
    "dérangeasses": "déranger",
    "dérangeassiez": "déranger",
    "dérangeassions": "déranger",
    "dérangements": "dérangement",
    "dérangent": "déranger",
    "dérangeons": "déranger",
    "dérangera": "déranger",
    "dérangerai": "déranger",
    "dérangeraient": "déranger",
    "dérangerais": "déranger",
    "dérangerait": "déranger",
    "dérangeras": "déranger",
    "dérangerez": "déranger",
    "dérangeriez": "déranger",
    "dérangerions": "déranger",
    "dérangerons": "déranger",
    "dérangeront": "déranger",
    "déranges": "déranger",
    "dérangez": "déranger",
    "dérangeâmes": "déranger",
    "dérangeât": "déranger",
    "dérangeâtes": "déranger",
    "dérangiez": "déranger",
    "dérangions": "déranger",
    "dérangèrent": "déranger",
    "dérangé": "déranger",
    "dérangée": "déranger",
    "dérangées": "déranger",
    "dérangés": "déranger",
    "dérapa": "déraper",
    "dérapages": "dérapage",
    "dérapai": "déraper",
    "dérapaient": "déraper",
    "dérapais": "déraper",
    "dérapait": "déraper",
    "dérapant": "déraper",
    "dérapas": "déraper",
    "dérapasse": "déraper",
    "dérapassent": "déraper",
    "dérapasses": "déraper",
    "dérapassiez": "déraper",
    "dérapassions": "déraper",
    "dérape": "déraper",
    "dérapent": "déraper",
    "dérapera": "déraper",
    "déraperai": "déraper",
    "déraperaient": "déraper",
    "déraperais": "déraper",
    "déraperait": "déraper",
    "déraperas": "déraper",
    "déraperez": "déraper",
    "déraperiez": "déraper",
    "déraperions": "déraper",
    "déraperons": "déraper",
    "déraperont": "déraper",
    "dérapes": "déraper",
    "dérapez": "déraper",
    "dérapiez": "déraper",
    "dérapions": "déraper",
    "dérapons": "déraper",
    "dérapâmes": "déraper",
    "dérapât": "déraper",
    "dérapâtes": "déraper",
    "dérapèrent": "déraper",
    "dérapé": "déraper",
    "dérasa": "déraser",
    "dérasai": "déraser",
    "dérasaient": "déraser",
    "dérasais": "déraser",
    "dérasait": "déraser",
    "dérasant": "déraser",
    "dérasas": "déraser",
    "dérasasse": "déraser",
    "dérasassent": "déraser",
    "dérasasses": "déraser",
    "dérasassiez": "déraser",
    "dérasassions": "déraser",
    "dérase": "déraser",
    "dérasent": "déraser",
    "dérasera": "déraser",
    "déraserai": "déraser",
    "déraseraient": "déraser",
    "déraserais": "déraser",
    "déraserait": "déraser",
    "déraseras": "déraser",
    "déraserez": "déraser",
    "déraseriez": "déraser",
    "déraserions": "déraser",
    "déraserons": "déraser",
    "déraseront": "déraser",
    "dérases": "déraser",
    "dérasez": "déraser",
    "dérasiez": "déraser",
    "dérasions": "déraser",
    "dérasons": "déraser",
    "dérasâmes": "déraser",
    "dérasât": "déraser",
    "dérasâtes": "déraser",
    "dérasèrent": "déraser",
    "dérasé": "déraser",
    "dérasée": "déraser",
    "dérasées": "déraser",
    "dérasés": "déraser",
    "dératisa": "dératiser",
    "dératisai": "dératiser",
    "dératisaient": "dératiser",
    "dératisais": "dératiser",
    "dératisait": "dératiser",
    "dératisant": "dératiser",
    "dératisas": "dératiser",
    "dératisasse": "dératiser",
    "dératisassent": "dératiser",
    "dératisasses": "dératiser",
    "dératisassiez": "dératiser",
    "dératisassions": "dératiser",
    "dératisations": "dératisation",
    "dératise": "dératiser",
    "dératisent": "dératiser",
    "dératisera": "dératiser",
    "dératiserai": "dératiser",
    "dératiseraient": "dératiser",
    "dératiserais": "dératiser",
    "dératiserait": "dératiser",
    "dératiseras": "dératiser",
    "dératiserez": "dératiser",
    "dératiseriez": "dératiser",
    "dératiserions": "dératiser",
    "dératiserons": "dératiser",
    "dératiseront": "dératiser",
    "dératises": "dératiser",
    "dératisez": "dératiser",
    "dératisiez": "dératiser",
    "dératisions": "dératiser",
    "dératisons": "dératiser",
    "dératisâmes": "dératiser",
    "dératisât": "dératiser",
    "dératisâtes": "dératiser",
    "dératisèrent": "dératiser",
    "dératisé": "dératiser",
    "dératisée": "dératiser",
    "dératisées": "dératiser",
    "dératisés": "dératiser",
    "dératée": "dératé",
    "dératées": "dératé",
    "dératés": "dératé",
    "dérelia": "dérelier",
    "déreliai": "dérelier",
    "déreliaient": "dérelier",
    "déreliais": "dérelier",
    "déreliait": "dérelier",
    "déreliant": "dérelier",
    "dérelias": "dérelier",
    "déreliasse": "dérelier",
    "déreliassent": "dérelier",
    "déreliasses": "dérelier",
    "déreliassiez": "dérelier",
    "déreliassions": "dérelier",
    "dérelie": "dérelier",
    "dérelient": "dérelier",
    "déreliera": "dérelier",
    "dérelierai": "dérelier",
    "dérelieraient": "dérelier",
    "dérelierais": "dérelier",
    "dérelierait": "dérelier",
    "dérelieras": "dérelier",
    "dérelierez": "dérelier",
    "dérelieriez": "dérelier",
    "dérelierions": "dérelier",
    "dérelierons": "dérelier",
    "dérelieront": "dérelier",
    "dérelies": "dérelier",
    "déreliez": "dérelier",
    "déreliiez": "dérelier",
    "déreliions": "dérelier",
    "dérelions": "dérelier",
    "déreliâmes": "dérelier",
    "déreliât": "dérelier",
    "déreliâtes": "dérelier",
    "dérelièrent": "dérelier",
    "dérelié": "dérelier",
    "déreliée": "dérelier",
    "déreliées": "dérelier",
    "déreliés": "dérelier",
    "dérida": "dérider",
    "déridai": "dérider",
    "déridaient": "dérider",
    "déridais": "dérider",
    "déridait": "dérider",
    "déridant": "dérider",
    "déridas": "dérider",
    "déridasse": "dérider",
    "déridassent": "dérider",
    "déridasses": "dérider",
    "déridassiez": "dérider",
    "déridassions": "dérider",
    "déride": "dérider",
    "dérident": "dérider",
    "déridera": "dérider",
    "dériderai": "dérider",
    "dérideraient": "dérider",
    "dériderais": "dérider",
    "dériderait": "dérider",
    "dérideras": "dérider",
    "dériderez": "dérider",
    "dérideriez": "dérider",
    "dériderions": "dérider",
    "dériderons": "dérider",
    "dérideront": "dérider",
    "dérides": "dérider",
    "déridez": "dérider",
    "déridiez": "dérider",
    "déridions": "dérider",
    "déridons": "dérider",
    "déridâmes": "dérider",
    "déridât": "dérider",
    "déridâtes": "dérider",
    "déridèrent": "dérider",
    "déridé": "dérider",
    "déridée": "dérider",
    "déridées": "dérider",
    "déridés": "dérider",
    "dérisions": "dérision",
    "dérisoires": "dérisoire",
    "dériva": "dériver",
    "dérivai": "dériver",
    "dérivaient": "dériver",
    "dérivais": "dériver",
    "dérivait": "dériver",
    "dérivant": "dériver",
    "dérivante": "dérivant",
    "dérivantes": "dérivant",
    "dérivants": "dérivant",
    "dérivas": "dériver",
    "dérivasse": "dériver",
    "dérivassent": "dériver",
    "dérivasses": "dériver",
    "dérivassiez": "dériver",
    "dérivassions": "dériver",
    "dérivatifs": "dérivatif",
    "dérivations": "dérivation",
    "dérive": "dériver",
    "dérivent": "dériver",
    "dérivera": "dériver",
    "dériverai": "dériver",
    "dériveraient": "dériver",
    "dériverais": "dériver",
    "dériverait": "dériver",
    "dériveras": "dériver",
    "dériverez": "dériver",
    "dériveriez": "dériver",
    "dériverions": "dériver",
    "dériverons": "dériver",
    "dériveront": "dériver",
    "dérives": "dériver",
    "dériveurs": "dériveur",
    "dérivez": "dériver",
    "dériviez": "dériver",
    "dérivions": "dériver",
    "dérivons": "dériver",
    "dérivâmes": "dériver",
    "dérivât": "dériver",
    "dérivâtes": "dériver",
    "dérivèrent": "dériver",
    "dérivé": "dériver",
    "dérivée": "dériver",
    "dérivées": "dériver",
    "dérivés": "dériver",
    "déroba": "dérober",
    "dérobades": "dérobade",
    "dérobai": "dérober",
    "dérobaient": "dérober",
    "dérobais": "dérober",
    "dérobait": "dérober",
    "dérobant": "dérober",
    "dérobas": "dérober",
    "dérobasse": "dérober",
    "dérobassent": "dérober",
    "dérobasses": "dérober",
    "dérobassiez": "dérober",
    "dérobassions": "dérober",
    "dérobe": "dérober",
    "dérobent": "dérober",
    "dérobera": "dérober",
    "déroberai": "dérober",
    "déroberaient": "dérober",
    "déroberais": "dérober",
    "déroberait": "dérober",
    "déroberas": "dérober",
    "déroberez": "dérober",
    "déroberiez": "dérober",
    "déroberions": "dérober",
    "déroberons": "dérober",
    "déroberont": "dérober",
    "dérobes": "dérober",
    "dérobeuse": "dérobeur",
    "dérobez": "dérober",
    "dérobiez": "dérober",
    "dérobions": "dérober",
    "dérobons": "dérober",
    "dérobâmes": "dérober",
    "dérobât": "dérober",
    "dérobâtes": "dérober",
    "dérobèrent": "dérober",
    "dérobé": "dérober",
    "dérobée": "dérober",
    "dérobées": "dérober",
    "dérobés": "dérober",
    "dérocha": "dérocher",
    "dérochai": "dérocher",
    "dérochaient": "dérocher",
    "dérochais": "dérocher",
    "dérochait": "dérocher",
    "dérochant": "dérocher",
    "dérochas": "dérocher",
    "dérochasse": "dérocher",
    "dérochassent": "dérocher",
    "dérochasses": "dérocher",
    "dérochassiez": "dérocher",
    "dérochassions": "dérocher",
    "déroche": "dérocher",
    "dérochent": "dérocher",
    "dérochera": "dérocher",
    "dérocherai": "dérocher",
    "dérocheraient": "dérocher",
    "dérocherais": "dérocher",
    "dérocherait": "dérocher",
    "dérocheras": "dérocher",
    "dérocherez": "dérocher",
    "dérocheriez": "dérocher",
    "dérocherions": "dérocher",
    "dérocherons": "dérocher",
    "dérocheront": "dérocher",
    "déroches": "dérocher",
    "dérochez": "dérocher",
    "dérochiez": "dérocher",
    "dérochions": "dérocher",
    "dérochons": "dérocher",
    "dérochâmes": "dérocher",
    "dérochât": "dérocher",
    "dérochâtes": "dérocher",
    "dérochèrent": "dérocher",
    "déroché": "dérocher",
    "dérochée": "dérocher",
    "dérochées": "dérocher",
    "dérochés": "dérocher",
    "dérogations": "dérogation",
    "dérogatoires": "dérogatoire",
    "déroge": "déroger",
    "dérogea": "déroger",
    "dérogeai": "déroger",
    "dérogeaient": "déroger",
    "dérogeais": "déroger",
    "dérogeait": "déroger",
    "dérogeant": "déroger",
    "dérogeas": "déroger",
    "dérogeasse": "déroger",
    "dérogeassent": "déroger",
    "dérogeasses": "déroger",
    "dérogeassiez": "déroger",
    "dérogeassions": "déroger",
    "dérogent": "déroger",
    "dérogeons": "déroger",
    "dérogera": "déroger",
    "dérogerai": "déroger",
    "dérogeraient": "déroger",
    "dérogerais": "déroger",
    "dérogerait": "déroger",
    "dérogeras": "déroger",
    "dérogerez": "déroger",
    "dérogeriez": "déroger",
    "dérogerions": "déroger",
    "dérogerons": "déroger",
    "dérogeront": "déroger",
    "déroges": "déroger",
    "dérogez": "déroger",
    "dérogeâmes": "déroger",
    "dérogeât": "déroger",
    "dérogeâtes": "déroger",
    "dérogiez": "déroger",
    "dérogions": "déroger",
    "dérogèrent": "déroger",
    "dérogé": "déroger",
    "dérouilla": "dérouiller",
    "dérouillai": "dérouiller",
    "dérouillaient": "dérouiller",
    "dérouillais": "dérouiller",
    "dérouillait": "dérouiller",
    "dérouillant": "dérouiller",
    "dérouillas": "dérouiller",
    "dérouillasse": "dérouiller",
    "dérouillassent": "dérouiller",
    "dérouillasses": "dérouiller",
    "dérouillassiez": "dérouiller",
    "dérouillassions": "dérouiller",
    "dérouille": "dérouiller",
    "dérouillent": "dérouiller",
    "dérouillera": "dérouiller",
    "dérouillerai": "dérouiller",
    "dérouilleraient": "dérouiller",
    "dérouillerais": "dérouiller",
    "dérouillerait": "dérouiller",
    "dérouilleras": "dérouiller",
    "dérouillerez": "dérouiller",
    "dérouilleriez": "dérouiller",
    "dérouillerions": "dérouiller",
    "dérouillerons": "dérouiller",
    "dérouilleront": "dérouiller",
    "dérouilles": "dérouiller",
    "dérouillez": "dérouiller",
    "dérouilliez": "dérouiller",
    "dérouillions": "dérouiller",
    "dérouillons": "dérouiller",
    "dérouillâmes": "dérouiller",
    "dérouillât": "dérouiller",
    "dérouillâtes": "dérouiller",
    "dérouillèrent": "dérouiller",
    "dérouillé": "dérouiller",
    "dérouillée": "dérouiller",
    "dérouillées": "dérouiller",
    "dérouillés": "dérouiller",
    "déroula": "dérouler",
    "déroulai": "dérouler",
    "déroulaient": "dérouler",
    "déroulais": "dérouler",
    "déroulait": "dérouler",
    "déroulant": "dérouler",
    "déroulas": "dérouler",
    "déroulasse": "dérouler",
    "déroulassent": "dérouler",
    "déroulasses": "dérouler",
    "déroulassiez": "dérouler",
    "déroulassions": "dérouler",
    "déroule": "dérouler",
    "déroulements": "déroulement",
    "déroulent": "dérouler",
    "déroulera": "dérouler",
    "déroulerai": "dérouler",
    "dérouleraient": "dérouler",
    "déroulerais": "dérouler",
    "déroulerait": "dérouler",
    "dérouleras": "dérouler",
    "déroulerez": "dérouler",
    "dérouleriez": "dérouler",
    "déroulerions": "dérouler",
    "déroulerons": "dérouler",
    "dérouleront": "dérouler",
    "déroules": "dérouler",
    "dérouleurs": "dérouleur",
    "dérouleuse": "dérouleur",
    "déroulez": "dérouler",
    "dérouliez": "dérouler",
    "déroulions": "dérouler",
    "déroulons": "dérouler",
    "déroulâmes": "dérouler",
    "déroulât": "dérouler",
    "déroulâtes": "dérouler",
    "déroulèrent": "dérouler",
    "déroulé": "dérouler",
    "déroulée": "dérouler",
    "déroulées": "dérouler",
    "déroulés": "dérouler",
    "dérouta": "dérouter",
    "déroutai": "dérouter",
    "déroutaient": "dérouter",
    "déroutais": "dérouter",
    "déroutait": "dérouter",
    "déroutant": "dérouter",
    "déroutante": "déroutant",
    "déroutantes": "déroutant",
    "déroutants": "déroutant",
    "déroutas": "dérouter",
    "déroutasse": "dérouter",
    "déroutassent": "dérouter",
    "déroutasses": "dérouter",
    "déroutassiez": "dérouter",
    "déroutassions": "dérouter",
    "déroute": "dérouter",
    "déroutent": "dérouter",
    "déroutera": "dérouter",
    "dérouterai": "dérouter",
    "dérouteraient": "dérouter",
    "dérouterais": "dérouter",
    "dérouterait": "dérouter",
    "dérouteras": "dérouter",
    "dérouterez": "dérouter",
    "dérouteriez": "dérouter",
    "dérouterions": "dérouter",
    "dérouterons": "dérouter",
    "dérouteront": "dérouter",
    "déroutes": "dérouter",
    "déroutez": "dérouter",
    "déroutiez": "dérouter",
    "déroutions": "dérouter",
    "déroutons": "dérouter",
    "déroutâmes": "dérouter",
    "déroutât": "dérouter",
    "déroutâtes": "dérouter",
    "déroutèrent": "dérouter",
    "dérouté": "dérouter",
    "déroutée": "dérouter",
    "déroutées": "dérouter",
    "déroutés": "dérouter",
    "dérègle": "dérégler",
    "dérèglementations": "dérèglementation",
    "dérèglements": "dérèglement",
    "dérèglent": "dérégler",
    "dérègles": "dérégler",
    "déréalisaient": "déréaliser",
    "dérégla": "dérégler",
    "déréglai": "dérégler",
    "déréglaient": "dérégler",
    "déréglais": "dérégler",
    "déréglait": "dérégler",
    "déréglant": "dérégler",
    "déréglas": "dérégler",
    "déréglasse": "dérégler",
    "déréglassent": "dérégler",
    "déréglasses": "dérégler",
    "déréglassiez": "dérégler",
    "déréglassions": "dérégler",
    "déréglementations": "déréglementation",
    "déréglera": "dérégler",
    "déréglerai": "dérégler",
    "dérégleraient": "dérégler",
    "déréglerais": "dérégler",
    "déréglerait": "dérégler",
    "dérégleras": "dérégler",
    "déréglerez": "dérégler",
    "dérégleriez": "dérégler",
    "déréglerions": "dérégler",
    "déréglerons": "dérégler",
    "dérégleront": "dérégler",
    "déréglez": "dérégler",
    "dérégliez": "dérégler",
    "déréglions": "dérégler",
    "déréglons": "dérégler",
    "déréglâmes": "dérégler",
    "déréglât": "dérégler",
    "déréglâtes": "dérégler",
    "déréglèrent": "dérégler",
    "déréglé": "dérégler",
    "déréglée": "dérégler",
    "déréglées": "dérégler",
    "déréglés": "dérégler",
    "dérégulations": "dérégulation",
    "dérélictions": "déréliction",
    "dés": "dé",
    "désabonna": "désabonner",
    "désabonnai": "désabonner",
    "désabonnaient": "désabonner",
    "désabonnais": "désabonner",
    "désabonnait": "désabonner",
    "désabonnant": "désabonner",
    "désabonnas": "désabonner",
    "désabonnasse": "désabonner",
    "désabonnassent": "désabonner",
    "désabonnasses": "désabonner",
    "désabonnassiez": "désabonner",
    "désabonnassions": "désabonner",
    "désabonne": "désabonner",
    "désabonnements": "désabonnement",
    "désabonnent": "désabonner",
    "désabonnera": "désabonner",
    "désabonnerai": "désabonner",
    "désabonneraient": "désabonner",
    "désabonnerais": "désabonner",
    "désabonnerait": "désabonner",
    "désabonneras": "désabonner",
    "désabonnerez": "désabonner",
    "désabonneriez": "désabonner",
    "désabonnerions": "désabonner",
    "désabonnerons": "désabonner",
    "désabonneront": "désabonner",
    "désabonnes": "désabonner",
    "désabonnez": "désabonner",
    "désabonniez": "désabonner",
    "désabonnions": "désabonner",
    "désabonnons": "désabonner",
    "désabonnâmes": "désabonner",
    "désabonnât": "désabonner",
    "désabonnâtes": "désabonner",
    "désabonnèrent": "désabonner",
    "désabonné": "désabonner",
    "désabonnée": "désabonner",
    "désabonnées": "désabonner",
    "désabonnés": "désabonner",
    "désabusa": "désabuser",
    "désabusai": "désabuser",
    "désabusaient": "désabuser",
    "désabusais": "désabuser",
    "désabusait": "désabuser",
    "désabusant": "désabuser",
    "désabusas": "désabuser",
    "désabusasse": "désabuser",
    "désabusassent": "désabuser",
    "désabusasses": "désabuser",
    "désabusassiez": "désabuser",
    "désabusassions": "désabuser",
    "désabuse": "désabuser",
    "désabusent": "désabuser",
    "désabusera": "désabuser",
    "désabuserai": "désabuser",
    "désabuseraient": "désabuser",
    "désabuserais": "désabuser",
    "désabuserait": "désabuser",
    "désabuseras": "désabuser",
    "désabuserez": "désabuser",
    "désabuseriez": "désabuser",
    "désabuserions": "désabuser",
    "désabuserons": "désabuser",
    "désabuseront": "désabuser",
    "désabuses": "désabuser",
    "désabusez": "désabuser",
    "désabusiez": "désabuser",
    "désabusions": "désabuser",
    "désabusons": "désabuser",
    "désabusâmes": "désabuser",
    "désabusât": "désabuser",
    "désabusâtes": "désabuser",
    "désabusèrent": "désabuser",
    "désabusé": "désabuser",
    "désabusée": "désabuser",
    "désabusées": "désabuser",
    "désabusés": "désabuser",
    "désaccorda": "désaccorder",
    "désaccordai": "désaccorder",
    "désaccordaient": "désaccorder",
    "désaccordais": "désaccorder",
    "désaccordait": "désaccorder",
    "désaccordant": "désaccorder",
    "désaccordas": "désaccorder",
    "désaccordasse": "désaccorder",
    "désaccordassent": "désaccorder",
    "désaccordasses": "désaccorder",
    "désaccordassiez": "désaccorder",
    "désaccordassions": "désaccorder",
    "désaccorde": "désaccorder",
    "désaccordent": "désaccorder",
    "désaccordera": "désaccorder",
    "désaccorderai": "désaccorder",
    "désaccorderaient": "désaccorder",
    "désaccorderais": "désaccorder",
    "désaccorderait": "désaccorder",
    "désaccorderas": "désaccorder",
    "désaccorderez": "désaccorder",
    "désaccorderiez": "désaccorder",
    "désaccorderions": "désaccorder",
    "désaccorderons": "désaccorder",
    "désaccorderont": "désaccorder",
    "désaccordes": "désaccorder",
    "désaccordez": "désaccorder",
    "désaccordiez": "désaccorder",
    "désaccordions": "désaccorder",
    "désaccordons": "désaccorder",
    "désaccords": "désaccord",
    "désaccordâmes": "désaccorder",
    "désaccordât": "désaccorder",
    "désaccordâtes": "désaccorder",
    "désaccordèrent": "désaccorder",
    "désaccordé": "désaccorder",
    "désaccordée": "désaccorder",
    "désaccordées": "désaccorder",
    "désaccordés": "désaccorder",
    "désaccoutuma": "désaccoutumer",
    "désaccoutumai": "désaccoutumer",
    "désaccoutumaient": "désaccoutumer",
    "désaccoutumais": "désaccoutumer",
    "désaccoutumait": "désaccoutumer",
    "désaccoutumant": "désaccoutumer",
    "désaccoutumas": "désaccoutumer",
    "désaccoutumasse": "désaccoutumer",
    "désaccoutumassent": "désaccoutumer",
    "désaccoutumasses": "désaccoutumer",
    "désaccoutumassiez": "désaccoutumer",
    "désaccoutumassions": "désaccoutumer",
    "désaccoutume": "désaccoutumer",
    "désaccoutument": "désaccoutumer",
    "désaccoutumera": "désaccoutumer",
    "désaccoutumerai": "désaccoutumer",
    "désaccoutumeraient": "désaccoutumer",
    "désaccoutumerais": "désaccoutumer",
    "désaccoutumerait": "désaccoutumer",
    "désaccoutumeras": "désaccoutumer",
    "désaccoutumerez": "désaccoutumer",
    "désaccoutumeriez": "désaccoutumer",
    "désaccoutumerions": "désaccoutumer",
    "désaccoutumerons": "désaccoutumer",
    "désaccoutumeront": "désaccoutumer",
    "désaccoutumes": "désaccoutumer",
    "désaccoutumez": "désaccoutumer",
    "désaccoutumiez": "désaccoutumer",
    "désaccoutumions": "désaccoutumer",
    "désaccoutumons": "désaccoutumer",
    "désaccoutumâmes": "désaccoutumer",
    "désaccoutumât": "désaccoutumer",
    "désaccoutumâtes": "désaccoutumer",
    "désaccoutumèrent": "désaccoutumer",
    "désaccoutumé": "désaccoutumer",
    "désaccoutumée": "désaccoutumer",
    "désaccoutumées": "désaccoutumer",
    "désaccoutumés": "désaccoutumer",
    "désacralisé": "désacraliser",
    "désacralisée": "désacraliser",
    "désactiva": "désactiver",
    "désactivai": "désactiver",
    "désactivaient": "désactiver",
    "désactivais": "désactiver",
    "désactivait": "désactiver",
    "désactivant": "désactiver",
    "désactivas": "désactiver",
    "désactivasse": "désactiver",
    "désactivassent": "désactiver",
    "désactivasses": "désactiver",
    "désactivassiez": "désactiver",
    "désactivassions": "désactiver",
    "désactivations": "désactivation",
    "désactive": "désactiver",
    "désactivent": "désactiver",
    "désactivera": "désactiver",
    "désactiverai": "désactiver",
    "désactiveraient": "désactiver",
    "désactiverais": "désactiver",
    "désactiverait": "désactiver",
    "désactiveras": "désactiver",
    "désactiverez": "désactiver",
    "désactiveriez": "désactiver",
    "désactiverions": "désactiver",
    "désactiverons": "désactiver",
    "désactiveront": "désactiver",
    "désactives": "désactiver",
    "désactivez": "désactiver",
    "désactiviez": "désactiver",
    "désactivions": "désactiver",
    "désactivons": "désactiver",
    "désactivâmes": "désactiver",
    "désactivât": "désactiver",
    "désactivâtes": "désactiver",
    "désactivèrent": "désactiver",
    "désactivé": "désactiver",
    "désactivée": "désactiver",
    "désactivées": "désactiver",
    "désactivés": "désactiver",
    "désadapta": "désadapter",
    "désadaptai": "désadapter",
    "désadaptaient": "désadapter",
    "désadaptais": "désadapter",
    "désadaptait": "désadapter",
    "désadaptant": "désadapter",
    "désadaptas": "désadapter",
    "désadaptasse": "désadapter",
    "désadaptassent": "désadapter",
    "désadaptasses": "désadapter",
    "désadaptassiez": "désadapter",
    "désadaptassions": "désadapter",
    "désadapte": "désadapter",
    "désadaptent": "désadapter",
    "désadaptera": "désadapter",
    "désadapterai": "désadapter",
    "désadapteraient": "désadapter",
    "désadapterais": "désadapter",
    "désadapterait": "désadapter",
    "désadapteras": "désadapter",
    "désadapterez": "désadapter",
    "désadapteriez": "désadapter",
    "désadapterions": "désadapter",
    "désadapterons": "désadapter",
    "désadapteront": "désadapter",
    "désadaptes": "désadapter",
    "désadaptez": "désadapter",
    "désadaptiez": "désadapter",
    "désadaptions": "désadapter",
    "désadaptons": "désadapter",
    "désadaptâmes": "désadapter",
    "désadaptât": "désadapter",
    "désadaptâtes": "désadapter",
    "désadaptèrent": "désadapter",
    "désadapté": "désadapter",
    "désadaptée": "désadapter",
    "désadaptées": "désadapter",
    "désadaptés": "désadapter",
    "désaffecta": "désaffecter",
    "désaffectai": "désaffecter",
    "désaffectaient": "désaffecter",
    "désaffectais": "désaffecter",
    "désaffectait": "désaffecter",
    "désaffectant": "désaffecter",
    "désaffectas": "désaffecter",
    "désaffectasse": "désaffecter",
    "désaffectassent": "désaffecter",
    "désaffectasses": "désaffecter",
    "désaffectassiez": "désaffecter",
    "désaffectassions": "désaffecter",
    "désaffectations": "désaffectation",
    "désaffecte": "désaffecter",
    "désaffectent": "désaffecter",
    "désaffectera": "désaffecter",
    "désaffecterai": "désaffecter",
    "désaffecteraient": "désaffecter",
    "désaffecterais": "désaffecter",
    "désaffecterait": "désaffecter",
    "désaffecteras": "désaffecter",
    "désaffecterez": "désaffecter",
    "désaffecteriez": "désaffecter",
    "désaffecterions": "désaffecter",
    "désaffecterons": "désaffecter",
    "désaffecteront": "désaffecter",
    "désaffectes": "désaffecter",
    "désaffectez": "désaffecter",
    "désaffectiez": "désaffecter",
    "désaffections": "désaffection",
    "désaffectons": "désaffecter",
    "désaffectâmes": "désaffecter",
    "désaffectât": "désaffecter",
    "désaffectâtes": "désaffecter",
    "désaffectèrent": "désaffecter",
    "désaffecté": "désaffecter",
    "désaffectée": "désaffecter",
    "désaffectées": "désaffecter",
    "désaffectés": "désaffecter",
    "désagrège": "désagréger",
    "désagrègent": "désagréger",
    "désagrèges": "désagréger",
    "désagréables": "désagréable",
    "désagrégations": "désagrégation",
    "désagrégea": "désagréger",
    "désagrégeai": "désagréger",
    "désagrégeaient": "désagréger",
    "désagrégeais": "désagréger",
    "désagrégeait": "désagréger",
    "désagrégeant": "désagréger",
    "désagrégeas": "désagréger",
    "désagrégeasse": "désagréger",
    "désagrégeassent": "désagréger",
    "désagrégeasses": "désagréger",
    "désagrégeassiez": "désagréger",
    "désagrégeassions": "désagréger",
    "désagrégeons": "désagréger",
    "désagrégera": "désagréger",
    "désagrégerai": "désagréger",
    "désagrégeraient": "désagréger",
    "désagrégerais": "désagréger",
    "désagrégerait": "désagréger",
    "désagrégeras": "désagréger",
    "désagrégerez": "désagréger",
    "désagrégeriez": "désagréger",
    "désagrégerions": "désagréger",
    "désagrégerons": "désagréger",
    "désagrégeront": "désagréger",
    "désagrégez": "désagréger",
    "désagrégeâmes": "désagréger",
    "désagrégeât": "désagréger",
    "désagrégeâtes": "désagréger",
    "désagrégiez": "désagréger",
    "désagrégions": "désagréger",
    "désagrégèrent": "désagréger",
    "désagrégé": "désagréger",
    "désagrégée": "désagréger",
    "désagrégées": "désagréger",
    "désagrégés": "désagréger",
    "désagréments": "désagrément",
    "désaimanta": "désaimanter",
    "désaimantai": "désaimanter",
    "désaimantaient": "désaimanter",
    "désaimantais": "désaimanter",
    "désaimantait": "désaimanter",
    "désaimantant": "désaimanter",
    "désaimantas": "désaimanter",
    "désaimantasse": "désaimanter",
    "désaimantassent": "désaimanter",
    "désaimantasses": "désaimanter",
    "désaimantassiez": "désaimanter",
    "désaimantassions": "désaimanter",
    "désaimante": "désaimanter",
    "désaimantent": "désaimanter",
    "désaimantera": "désaimanter",
    "désaimanterai": "désaimanter",
    "désaimanteraient": "désaimanter",
    "désaimanterais": "désaimanter",
    "désaimanterait": "désaimanter",
    "désaimanteras": "désaimanter",
    "désaimanterez": "désaimanter",
    "désaimanteriez": "désaimanter",
    "désaimanterions": "désaimanter",
    "désaimanterons": "désaimanter",
    "désaimanteront": "désaimanter",
    "désaimantes": "désaimanter",
    "désaimantez": "désaimanter",
    "désaimantiez": "désaimanter",
    "désaimantions": "désaimanter",
    "désaimantons": "désaimanter",
    "désaimantâmes": "désaimanter",
    "désaimantât": "désaimanter",
    "désaimantâtes": "désaimanter",
    "désaimantèrent": "désaimanter",
    "désaimanté": "désaimanter",
    "désaimantée": "désaimanter",
    "désaimantées": "désaimanter",
    "désaimantés": "désaimanter",
    "désaimée": "désaimer",
    "désajustés": "désajuster",
    "désaltère": "désaltérer",
    "désaltèrent": "désaltérer",
    "désaltères": "désaltérer",
    "désaltéra": "désaltérer",
    "désaltérai": "désaltérer",
    "désaltéraient": "désaltérer",
    "désaltérais": "désaltérer",
    "désaltérait": "désaltérer",
    "désaltérant": "désaltérer",
    "désaltérante": "désaltérant",
    "désaltéras": "désaltérer",
    "désaltérasse": "désaltérer",
    "désaltérassent": "désaltérer",
    "désaltérasses": "désaltérer",
    "désaltérassiez": "désaltérer",
    "désaltérassions": "désaltérer",
    "désaltérera": "désaltérer",
    "désaltérerai": "désaltérer",
    "désaltéreraient": "désaltérer",
    "désaltérerais": "désaltérer",
    "désaltérerait": "désaltérer",
    "désaltéreras": "désaltérer",
    "désaltérerez": "désaltérer",
    "désaltéreriez": "désaltérer",
    "désaltérerions": "désaltérer",
    "désaltérerons": "désaltérer",
    "désaltéreront": "désaltérer",
    "désaltérez": "désaltérer",
    "désaltériez": "désaltérer",
    "désaltérions": "désaltérer",
    "désaltérons": "désaltérer",
    "désaltérâmes": "désaltérer",
    "désaltérât": "désaltérer",
    "désaltérâtes": "désaltérer",
    "désaltérèrent": "désaltérer",
    "désaltéré": "désaltérer",
    "désaltérée": "désaltérer",
    "désaltérées": "désaltérer",
    "désaltérés": "désaltérer",
    "désamorce": "désamorcer",
    "désamorcent": "désamorcer",
    "désamorcera": "désamorcer",
    "désamorcerai": "désamorcer",
    "désamorceraient": "désamorcer",
    "désamorcerais": "désamorcer",
    "désamorcerait": "désamorcer",
    "désamorceras": "désamorcer",
    "désamorcerez": "désamorcer",
    "désamorceriez": "désamorcer",
    "désamorcerions": "désamorcer",
    "désamorcerons": "désamorcer",
    "désamorceront": "désamorcer",
    "désamorces": "désamorcer",
    "désamorcez": "désamorcer",
    "désamorciez": "désamorcer",
    "désamorcions": "désamorcer",
    "désamorcèrent": "désamorcer",
    "désamorcé": "désamorcer",
    "désamorcée": "désamorcer",
    "désamorcées": "désamorcer",
    "désamorcés": "désamorcer",
    "désamorça": "désamorcer",
    "désamorçai": "désamorcer",
    "désamorçaient": "désamorcer",
    "désamorçais": "désamorcer",
    "désamorçait": "désamorcer",
    "désamorçant": "désamorcer",
    "désamorças": "désamorcer",
    "désamorçasse": "désamorcer",
    "désamorçassent": "désamorcer",
    "désamorçasses": "désamorcer",
    "désamorçassiez": "désamorcer",
    "désamorçassions": "désamorcer",
    "désamorçons": "désamorcer",
    "désamorçâmes": "désamorcer",
    "désamorçât": "désamorcer",
    "désamorçâtes": "désamorcer",
    "désape": "désaper",
    "désapent": "désaper",
    "désapez": "désaper",
    "désapparia": "désapparier",
    "désappariai": "désapparier",
    "désappariaient": "désapparier",
    "désappariais": "désapparier",
    "désappariait": "désapparier",
    "désappariant": "désapparier",
    "désapparias": "désapparier",
    "désappariasse": "désapparier",
    "désappariassent": "désapparier",
    "désappariasses": "désapparier",
    "désappariassiez": "désapparier",
    "désappariassions": "désapparier",
    "désapparie": "désapparier",
    "désapparient": "désapparier",
    "désappariera": "désapparier",
    "désapparierai": "désapparier",
    "désapparieraient": "désapparier",
    "désapparierais": "désapparier",
    "désapparierait": "désapparier",
    "désapparieras": "désapparier",
    "désapparierez": "désapparier",
    "désapparieriez": "désapparier",
    "désapparierions": "désapparier",
    "désapparierons": "désapparier",
    "désapparieront": "désapparier",
    "désapparies": "désapparier",
    "désappariez": "désapparier",
    "désappariiez": "désapparier",
    "désappariions": "désapparier",
    "désapparions": "désapparier",
    "désappariâmes": "désapparier",
    "désappariât": "désapparier",
    "désappariâtes": "désapparier",
    "désapparièrent": "désapparier",
    "désapparié": "désapparier",
    "désappariée": "désapparier",
    "désappariées": "désapparier",
    "désappariés": "désapparier",
    "désappointa": "désappointer",
    "désappointai": "désappointer",
    "désappointaient": "désappointer",
    "désappointais": "désappointer",
    "désappointait": "désappointer",
    "désappointant": "désappointer",
    "désappointas": "désappointer",
    "désappointasse": "désappointer",
    "désappointassent": "désappointer",
    "désappointasses": "désappointer",
    "désappointassiez": "désappointer",
    "désappointassions": "désappointer",
    "désappointe": "désappointer",
    "désappointements": "désappointement",
    "désappointent": "désappointer",
    "désappointera": "désappointer",
    "désappointerai": "désappointer",
    "désappointeraient": "désappointer",
    "désappointerais": "désappointer",
    "désappointerait": "désappointer",
    "désappointeras": "désappointer",
    "désappointerez": "désappointer",
    "désappointeriez": "désappointer",
    "désappointerions": "désappointer",
    "désappointerons": "désappointer",
    "désappointeront": "désappointer",
    "désappointes": "désappointer",
    "désappointez": "désappointer",
    "désappointiez": "désappointer",
    "désappointions": "désappointer",
    "désappointons": "désappointer",
    "désappointâmes": "désappointer",
    "désappointât": "désappointer",
    "désappointâtes": "désappointer",
    "désappointèrent": "désappointer",
    "désappointé": "désappointer",
    "désappointée": "désappointer",
    "désappointées": "désappointer",
    "désappointés": "désappointer",
    "désapprenaient": "désapprendre",
    "désapprenais": "désapprendre",
    "désapprenait": "désapprendre",
    "désapprenant": "désapprendre",
    "désapprend": "désapprendre",
    "désapprendra": "désapprendre",
    "désapprendrai": "désapprendre",
    "désapprendraient": "désapprendre",
    "désapprendrais": "désapprendre",
    "désapprendrait": "désapprendre",
    "désapprendras": "désapprendre",
    "désapprendrez": "désapprendre",
    "désapprendriez": "désapprendre",
    "désapprendrions": "désapprendre",
    "désapprendrons": "désapprendre",
    "désapprendront": "désapprendre",
    "désapprends": "désapprendre",
    "désapprenez": "désapprendre",
    "désappreniez": "désapprendre",
    "désapprenions": "désapprendre",
    "désapprenne": "désapprendre",
    "désapprennent": "désapprendre",
    "désapprennes": "désapprendre",
    "désapprenons": "désapprendre",
    "désapprirent": "désapprendre",
    "désappris": "désapprendre",
    "désapprise": "désapprendre",
    "désapprises": "désapprendre",
    "désapprisse": "désapprendre",
    "désapprissent": "désapprendre",
    "désapprisses": "désapprendre",
    "désapprissiez": "désapprendre",
    "désapprissions": "désapprendre",
    "désapprit": "désapprendre",
    "désapprobateurs": "désapprobateur",
    "désapprobations": "désapprobation",
    "désapprobatrice": "désapprobateur",
    "désapprobatrices": "désapprobateur",
    "désapprouva": "désapprouver",
    "désapprouvai": "désapprouver",
    "désapprouvaient": "désapprouver",
    "désapprouvais": "désapprouver",
    "désapprouvait": "désapprouver",
    "désapprouvant": "désapprouver",
    "désapprouvas": "désapprouver",
    "désapprouvasse": "désapprouver",
    "désapprouvassent": "désapprouver",
    "désapprouvasses": "désapprouver",
    "désapprouvassiez": "désapprouver",
    "désapprouvassions": "désapprouver",
    "désapprouve": "désapprouver",
    "désapprouvent": "désapprouver",
    "désapprouvera": "désapprouver",
    "désapprouverai": "désapprouver",
    "désapprouveraient": "désapprouver",
    "désapprouverais": "désapprouver",
    "désapprouverait": "désapprouver",
    "désapprouveras": "désapprouver",
    "désapprouverez": "désapprouver",
    "désapprouveriez": "désapprouver",
    "désapprouverions": "désapprouver",
    "désapprouverons": "désapprouver",
    "désapprouveront": "désapprouver",
    "désapprouves": "désapprouver",
    "désapprouvez": "désapprouver",
    "désapprouviez": "désapprouver",
    "désapprouvions": "désapprouver",
    "désapprouvons": "désapprouver",
    "désapprouvâmes": "désapprouver",
    "désapprouvât": "désapprouver",
    "désapprouvâtes": "désapprouver",
    "désapprouvèrent": "désapprouver",
    "désapprouvé": "désapprouver",
    "désapprouvée": "désapprouver",
    "désapprouvées": "désapprouver",
    "désapprouvés": "désapprouver",
    "désapprovisionna": "désapprovisionner",
    "désapprovisionnai": "désapprovisionner",
    "désapprovisionnaient": "désapprovisionner",
    "désapprovisionnais": "désapprovisionner",
    "désapprovisionnait": "désapprovisionner",
    "désapprovisionnant": "désapprovisionner",
    "désapprovisionnas": "désapprovisionner",
    "désapprovisionnasse": "désapprovisionner",
    "désapprovisionnassent": "désapprovisionner",
    "désapprovisionnasses": "désapprovisionner",
    "désapprovisionnassiez": "désapprovisionner",
    "désapprovisionnassions": "désapprovisionner",
    "désapprovisionne": "désapprovisionner",
    "désapprovisionnent": "désapprovisionner",
    "désapprovisionnera": "désapprovisionner",
    "désapprovisionnerai": "désapprovisionner",
    "désapprovisionneraient": "désapprovisionner",
    "désapprovisionnerais": "désapprovisionner",
    "désapprovisionnerait": "désapprovisionner",
    "désapprovisionneras": "désapprovisionner",
    "désapprovisionnerez": "désapprovisionner",
    "désapprovisionneriez": "désapprovisionner",
    "désapprovisionnerions": "désapprovisionner",
    "désapprovisionnerons": "désapprovisionner",
    "désapprovisionneront": "désapprovisionner",
    "désapprovisionnes": "désapprovisionner",
    "désapprovisionnez": "désapprovisionner",
    "désapprovisionniez": "désapprovisionner",
    "désapprovisionnions": "désapprovisionner",
    "désapprovisionnons": "désapprovisionner",
    "désapprovisionnâmes": "désapprovisionner",
    "désapprovisionnât": "désapprovisionner",
    "désapprovisionnâtes": "désapprovisionner",
    "désapprovisionnèrent": "désapprovisionner",
    "désapprovisionné": "désapprovisionner",
    "désapprovisionnée": "désapprovisionner",
    "désapprovisionnées": "désapprovisionner",
    "désapprovisionnés": "désapprovisionner",
    "désapprîmes": "désapprendre",
    "désapprît": "désapprendre",
    "désapprîtes": "désapprendre",
    "désargenta": "désargenter",
    "désargentai": "désargenter",
    "désargentaient": "désargenter",
    "désargentais": "désargenter",
    "désargentait": "désargenter",
    "désargentant": "désargenter",
    "désargentas": "désargenter",
    "désargentasse": "désargenter",
    "désargentassent": "désargenter",
    "désargentasses": "désargenter",
    "désargentassiez": "désargenter",
    "désargentassions": "désargenter",
    "désargente": "désargenter",
    "désargentent": "désargenter",
    "désargentera": "désargenter",
    "désargenterai": "désargenter",
    "désargenteraient": "désargenter",
    "désargenterais": "désargenter",
    "désargenterait": "désargenter",
    "désargenteras": "désargenter",
    "désargenterez": "désargenter",
    "désargenteriez": "désargenter",
    "désargenterions": "désargenter",
    "désargenterons": "désargenter",
    "désargenteront": "désargenter",
    "désargentes": "désargenter",
    "désargentez": "désargenter",
    "désargentiez": "désargenter",
    "désargentions": "désargenter",
    "désargentons": "désargenter",
    "désargentâmes": "désargenter",
    "désargentât": "désargenter",
    "désargentâtes": "désargenter",
    "désargentèrent": "désargenter",
    "désargenté": "désargenter",
    "désargentée": "désargenter",
    "désargentées": "désargenter",
    "désargentés": "désargenter",
    "désarma": "désarmer",
    "désarmai": "désarmer",
    "désarmaient": "désarmer",
    "désarmais": "désarmer",
    "désarmait": "désarmer",
    "désarmant": "désarmer",
    "désarmante": "désarmant",
    "désarmantes": "désarmant",
    "désarmants": "désarmant",
    "désarmas": "désarmer",
    "désarmasse": "désarmer",
    "désarmassent": "désarmer",
    "désarmasses": "désarmer",
    "désarmassiez": "désarmer",
    "désarmassions": "désarmer",
    "désarme": "désarmer",
    "désarmements": "désarmement",
    "désarment": "désarmer",
    "désarmera": "désarmer",
    "désarmerai": "désarmer",
    "désarmeraient": "désarmer",
    "désarmerais": "désarmer",
    "désarmerait": "désarmer",
    "désarmeras": "désarmer",
    "désarmerez": "désarmer",
    "désarmeriez": "désarmer",
    "désarmerions": "désarmer",
    "désarmerons": "désarmer",
    "désarmeront": "désarmer",
    "désarmes": "désarmer",
    "désarmez": "désarmer",
    "désarmiez": "désarmer",
    "désarmions": "désarmer",
    "désarmons": "désarmer",
    "désarmâmes": "désarmer",
    "désarmât": "désarmer",
    "désarmâtes": "désarmer",
    "désarmèrent": "désarmer",
    "désarmé": "désarmer",
    "désarmée": "désarmer",
    "désarmées": "désarmer",
    "désarmés": "désarmer",
    "désarrimez": "désarrimer",
    "désarrimé": "désarrimer",
    "désarrois": "désarroi",
    "désarticula": "désarticuler",
    "désarticulai": "désarticuler",
    "désarticulaient": "désarticuler",
    "désarticulais": "désarticuler",
    "désarticulait": "désarticuler",
    "désarticulant": "désarticuler",
    "désarticulas": "désarticuler",
    "désarticulasse": "désarticuler",
    "désarticulassent": "désarticuler",
    "désarticulasses": "désarticuler",
    "désarticulassiez": "désarticuler",
    "désarticulassions": "désarticuler",
    "désarticule": "désarticuler",
    "désarticulent": "désarticuler",
    "désarticulera": "désarticuler",
    "désarticulerai": "désarticuler",
    "désarticuleraient": "désarticuler",
    "désarticulerais": "désarticuler",
    "désarticulerait": "désarticuler",
    "désarticuleras": "désarticuler",
    "désarticulerez": "désarticuler",
    "désarticuleriez": "désarticuler",
    "désarticulerions": "désarticuler",
    "désarticulerons": "désarticuler",
    "désarticuleront": "désarticuler",
    "désarticules": "désarticuler",
    "désarticulez": "désarticuler",
    "désarticuliez": "désarticuler",
    "désarticulions": "désarticuler",
    "désarticulons": "désarticuler",
    "désarticulâmes": "désarticuler",
    "désarticulât": "désarticuler",
    "désarticulâtes": "désarticuler",
    "désarticulèrent": "désarticuler",
    "désarticulé": "désarticuler",
    "désarticulée": "désarticuler",
    "désarticulées": "désarticuler",
    "désarticulés": "désarticuler",
    "désarçonna": "désarçonner",
    "désarçonnai": "désarçonner",
    "désarçonnaient": "désarçonner",
    "désarçonnais": "désarçonner",
    "désarçonnait": "désarçonner",
    "désarçonnant": "désarçonner",
    "désarçonnas": "désarçonner",
    "désarçonnasse": "désarçonner",
    "désarçonnassent": "désarçonner",
    "désarçonnasses": "désarçonner",
    "désarçonnassiez": "désarçonner",
    "désarçonnassions": "désarçonner",
    "désarçonne": "désarçonner",
    "désarçonnent": "désarçonner",
    "désarçonnera": "désarçonner",
    "désarçonnerai": "désarçonner",
    "désarçonneraient": "désarçonner",
    "désarçonnerais": "désarçonner",
    "désarçonnerait": "désarçonner",
    "désarçonneras": "désarçonner",
    "désarçonnerez": "désarçonner",
    "désarçonneriez": "désarçonner",
    "désarçonnerions": "désarçonner",
    "désarçonnerons": "désarçonner",
    "désarçonneront": "désarçonner",
    "désarçonnes": "désarçonner",
    "désarçonnez": "désarçonner",
    "désarçonniez": "désarçonner",
    "désarçonnions": "désarçonner",
    "désarçonnons": "désarçonner",
    "désarçonnâmes": "désarçonner",
    "désarçonnât": "désarçonner",
    "désarçonnâtes": "désarçonner",
    "désarçonnèrent": "désarçonner",
    "désarçonné": "désarçonner",
    "désarçonnée": "désarçonner",
    "désarçonnées": "désarçonner",
    "désarçonnés": "désarçonner",
    "désassembla": "désassembler",
    "désassemblai": "désassembler",
    "désassemblaient": "désassembler",
    "désassemblais": "désassembler",
    "désassemblait": "désassembler",
    "désassemblant": "désassembler",
    "désassemblas": "désassembler",
    "désassemblasse": "désassembler",
    "désassemblassent": "désassembler",
    "désassemblasses": "désassembler",
    "désassemblassiez": "désassembler",
    "désassemblassions": "désassembler",
    "désassemble": "désassembler",
    "désassemblent": "désassembler",
    "désassemblera": "désassembler",
    "désassemblerai": "désassembler",
    "désassembleraient": "désassembler",
    "désassemblerais": "désassembler",
    "désassemblerait": "désassembler",
    "désassembleras": "désassembler",
    "désassemblerez": "désassembler",
    "désassembleriez": "désassembler",
    "désassemblerions": "désassembler",
    "désassemblerons": "désassembler",
    "désassembleront": "désassembler",
    "désassembles": "désassembler",
    "désassemblez": "désassembler",
    "désassembliez": "désassembler",
    "désassemblions": "désassembler",
    "désassemblons": "désassembler",
    "désassemblâmes": "désassembler",
    "désassemblât": "désassembler",
    "désassemblâtes": "désassembler",
    "désassemblèrent": "désassembler",
    "désassemblé": "désassembler",
    "désassemblée": "désassembler",
    "désassemblées": "désassembler",
    "désassemblés": "désassembler",
    "désassimila": "désassimiler",
    "désassimilai": "désassimiler",
    "désassimilaient": "désassimiler",
    "désassimilais": "désassimiler",
    "désassimilait": "désassimiler",
    "désassimilant": "désassimiler",
    "désassimilas": "désassimiler",
    "désassimilasse": "désassimiler",
    "désassimilassent": "désassimiler",
    "désassimilasses": "désassimiler",
    "désassimilassiez": "désassimiler",
    "désassimilassions": "désassimiler",
    "désassimile": "désassimiler",
    "désassimilent": "désassimiler",
    "désassimilera": "désassimiler",
    "désassimilerai": "désassimiler",
    "désassimileraient": "désassimiler",
    "désassimilerais": "désassimiler",
    "désassimilerait": "désassimiler",
    "désassimileras": "désassimiler",
    "désassimilerez": "désassimiler",
    "désassimileriez": "désassimiler",
    "désassimilerions": "désassimiler",
    "désassimilerons": "désassimiler",
    "désassimileront": "désassimiler",
    "désassimiles": "désassimiler",
    "désassimilez": "désassimiler",
    "désassimiliez": "désassimiler",
    "désassimilions": "désassimiler",
    "désassimilons": "désassimiler",
    "désassimilâmes": "désassimiler",
    "désassimilât": "désassimiler",
    "désassimilâtes": "désassimiler",
    "désassimilèrent": "désassimiler",
    "désassimilé": "désassimiler",
    "désassimilée": "désassimiler",
    "désassimilées": "désassimiler",
    "désassimilés": "désassimiler",
    "désassorti": "désassortir",
    "désassortie": "désassortir",
    "désassorties": "désassortir",
    "désassortira": "désassortir",
    "désassortirai": "désassortir",
    "désassortiraient": "désassortir",
    "désassortirais": "désassortir",
    "désassortirait": "désassortir",
    "désassortiras": "désassortir",
    "désassortirent": "désassortir",
    "désassortirez": "désassortir",
    "désassortiriez": "désassortir",
    "désassortirions": "désassortir",
    "désassortirons": "désassortir",
    "désassortiront": "désassortir",
    "désassortis": "désassortir",
    "désassortissaient": "désassortir",
    "désassortissais": "désassortir",
    "désassortissait": "désassortir",
    "désassortissant": "désassortir",
    "désassortisse": "désassortir",
    "désassortissent": "désassortir",
    "désassortisses": "désassortir",
    "désassortissez": "désassortir",
    "désassortissiez": "désassortir",
    "désassortissions": "désassortir",
    "désassortissons": "désassortir",
    "désassortit": "désassortir",
    "désassortîmes": "désassortir",
    "désassortît": "désassortir",
    "désassortîtes": "désassortir",
    "désastres": "désastre",
    "désastreuse": "désastreux",
    "désastreuses": "désastreux",
    "désavantage": "désavantager",
    "désavantagea": "désavantager",
    "désavantageai": "désavantager",
    "désavantageaient": "désavantager",
    "désavantageais": "désavantager",
    "désavantageait": "désavantager",
    "désavantageant": "désavantager",
    "désavantageas": "désavantager",
    "désavantageasse": "désavantager",
    "désavantageassent": "désavantager",
    "désavantageasses": "désavantager",
    "désavantageassiez": "désavantager",
    "désavantageassions": "désavantager",
    "désavantagent": "désavantager",
    "désavantageons": "désavantager",
    "désavantagera": "désavantager",
    "désavantagerai": "désavantager",
    "désavantageraient": "désavantager",
    "désavantagerais": "désavantager",
    "désavantagerait": "désavantager",
    "désavantageras": "désavantager",
    "désavantagerez": "désavantager",
    "désavantageriez": "désavantager",
    "désavantagerions": "désavantager",
    "désavantagerons": "désavantager",
    "désavantageront": "désavantager",
    "désavantages": "désavantager",
    "désavantageuse": "désavantageux",
    "désavantageuses": "désavantageux",
    "désavantagez": "désavantager",
    "désavantageâmes": "désavantager",
    "désavantageât": "désavantager",
    "désavantageâtes": "désavantager",
    "désavantagiez": "désavantager",
    "désavantagions": "désavantager",
    "désavantagèrent": "désavantager",
    "désavantagé": "désavantager",
    "désavantagée": "désavantager",
    "désavantagées": "désavantager",
    "désavantagés": "désavantager",
    "désaveux": "désaveu",
    "désavoua": "désavouer",
    "désavouai": "désavouer",
    "désavouaient": "désavouer",
    "désavouais": "désavouer",
    "désavouait": "désavouer",
    "désavouant": "désavouer",
    "désavouas": "désavouer",
    "désavouasse": "désavouer",
    "désavouassent": "désavouer",
    "désavouasses": "désavouer",
    "désavouassiez": "désavouer",
    "désavouassions": "désavouer",
    "désavoue": "désavouer",
    "désavouent": "désavouer",
    "désavouera": "désavouer",
    "désavouerai": "désavouer",
    "désavoueraient": "désavouer",
    "désavouerais": "désavouer",
    "désavouerait": "désavouer",
    "désavoueras": "désavouer",
    "désavouerez": "désavouer",
    "désavoueriez": "désavouer",
    "désavouerions": "désavouer",
    "désavouerons": "désavouer",
    "désavoueront": "désavouer",
    "désavoues": "désavouer",
    "désavouez": "désavouer",
    "désavouiez": "désavouer",
    "désavouions": "désavouer",
    "désavouons": "désavouer",
    "désavouâmes": "désavouer",
    "désavouât": "désavouer",
    "désavouâtes": "désavouer",
    "désavouèrent": "désavouer",
    "désavoué": "désavouer",
    "désavouée": "désavouer",
    "désavouées": "désavouer",
    "désavoués": "désavouer",
    "désaxa": "désaxer",
    "désaxai": "désaxer",
    "désaxaient": "désaxer",
    "désaxais": "désaxer",
    "désaxait": "désaxer",
    "désaxant": "désaxer",
    "désaxas": "désaxer",
    "désaxasse": "désaxer",
    "désaxassent": "désaxer",
    "désaxasses": "désaxer",
    "désaxassiez": "désaxer",
    "désaxassions": "désaxer",
    "désaxe": "désaxer",
    "désaxent": "désaxer",
    "désaxera": "désaxer",
    "désaxerai": "désaxer",
    "désaxeraient": "désaxer",
    "désaxerais": "désaxer",
    "désaxerait": "désaxer",
    "désaxeras": "désaxer",
    "désaxerez": "désaxer",
    "désaxeriez": "désaxer",
    "désaxerions": "désaxer",
    "désaxerons": "désaxer",
    "désaxeront": "désaxer",
    "désaxes": "désaxer",
    "désaxez": "désaxer",
    "désaxiez": "désaxer",
    "désaxions": "désaxer",
    "désaxons": "désaxer",
    "désaxâmes": "désaxer",
    "désaxât": "désaxer",
    "désaxâtes": "désaxer",
    "désaxèrent": "désaxer",
    "désaxé": "désaxer",
    "désaxée": "désaxer",
    "désaxées": "désaxer",
    "désaxés": "désaxer",
    "déscolarisé": "déscolariser",
    "désembourbée": "désembourber",
    "désembourgeoisa": "désembourgeoiser",
    "désembourgeoisai": "désembourgeoiser",
    "désembourgeoisaient": "désembourgeoiser",
    "désembourgeoisais": "désembourgeoiser",
    "désembourgeoisait": "désembourgeoiser",
    "désembourgeoisant": "désembourgeoiser",
    "désembourgeoisas": "désembourgeoiser",
    "désembourgeoisasse": "désembourgeoiser",
    "désembourgeoisassent": "désembourgeoiser",
    "désembourgeoisasses": "désembourgeoiser",
    "désembourgeoisassiez": "désembourgeoiser",
    "désembourgeoisassions": "désembourgeoiser",
    "désembourgeoise": "désembourgeoiser",
    "désembourgeoisent": "désembourgeoiser",
    "désembourgeoisera": "désembourgeoiser",
    "désembourgeoiserai": "désembourgeoiser",
    "désembourgeoiseraient": "désembourgeoiser",
    "désembourgeoiserais": "désembourgeoiser",
    "désembourgeoiserait": "désembourgeoiser",
    "désembourgeoiseras": "désembourgeoiser",
    "désembourgeoiserez": "désembourgeoiser",
    "désembourgeoiseriez": "désembourgeoiser",
    "désembourgeoiserions": "désembourgeoiser",
    "désembourgeoiserons": "désembourgeoiser",
    "désembourgeoiseront": "désembourgeoiser",
    "désembourgeoises": "désembourgeoiser",
    "désembourgeoisez": "désembourgeoiser",
    "désembourgeoisiez": "désembourgeoiser",
    "désembourgeoisions": "désembourgeoiser",
    "désembourgeoisons": "désembourgeoiser",
    "désembourgeoisâmes": "désembourgeoiser",
    "désembourgeoisât": "désembourgeoiser",
    "désembourgeoisâtes": "désembourgeoiser",
    "désembourgeoisèrent": "désembourgeoiser",
    "désembourgeoisé": "désembourgeoiser",
    "désembourgeoisée": "désembourgeoiser",
    "désembourgeoisées": "désembourgeoiser",
    "désembourgeoisés": "désembourgeoiser",
    "désempara": "désemparer",
    "désemparai": "désemparer",
    "désemparaient": "désemparer",
    "désemparais": "désemparer",
    "désemparait": "désemparer",
    "désemparant": "désemparer",
    "désemparas": "désemparer",
    "désemparasse": "désemparer",
    "désemparassent": "désemparer",
    "désemparasses": "désemparer",
    "désemparassiez": "désemparer",
    "désemparassions": "désemparer",
    "désempare": "désemparer",
    "désemparent": "désemparer",
    "désemparera": "désemparer",
    "désemparerai": "désemparer",
    "désempareraient": "désemparer",
    "désemparerais": "désemparer",
    "désemparerait": "désemparer",
    "désempareras": "désemparer",
    "désemparerez": "désemparer",
    "désempareriez": "désemparer",
    "désemparerions": "désemparer",
    "désemparerons": "désemparer",
    "désempareront": "désemparer",
    "désempares": "désemparer",
    "désemparez": "désemparer",
    "désempariez": "désemparer",
    "désemparions": "désemparer",
    "désemparons": "désemparer",
    "désemparâmes": "désemparer",
    "désemparât": "désemparer",
    "désemparâtes": "désemparer",
    "désemparèrent": "désemparer",
    "désemparé": "désemparer",
    "désemparée": "désemparer",
    "désemparées": "désemparer",
    "désemparés": "désemparer",
    "désempenné": "désempenner",
    "désempierraient": "désempierrer",
    "désempli": "désemplir",
    "désemplie": "désemplir",
    "désemplies": "désemplir",
    "désemplira": "désemplir",
    "désemplirai": "désemplir",
    "désempliraient": "désemplir",
    "désemplirais": "désemplir",
    "désemplirait": "désemplir",
    "désempliras": "désemplir",
    "désemplirent": "désemplir",
    "désemplirez": "désemplir",
    "désempliriez": "désemplir",
    "désemplirions": "désemplir",
    "désemplirons": "désemplir",
    "désempliront": "désemplir",
    "désemplis": "désemplir",
    "désemplissaient": "désemplir",
    "désemplissais": "désemplir",
    "désemplissait": "désemplir",
    "désemplissant": "désemplir",
    "désemplisse": "désemplir",
    "désemplissent": "désemplir",
    "désemplisses": "désemplir",
    "désemplissez": "désemplir",
    "désemplissiez": "désemplir",
    "désemplissions": "désemplir",
    "désemplissons": "désemplir",
    "désemplit": "désemplir",
    "désemplîmes": "désemplir",
    "désemplît": "désemplir",
    "désemplîtes": "désemplir",
    "désencadra": "désencadrer",
    "désencadrai": "désencadrer",
    "désencadraient": "désencadrer",
    "désencadrais": "désencadrer",
    "désencadrait": "désencadrer",
    "désencadrant": "désencadrer",
    "désencadras": "désencadrer",
    "désencadrasse": "désencadrer",
    "désencadrassent": "désencadrer",
    "désencadrasses": "désencadrer",
    "désencadrassiez": "désencadrer",
    "désencadrassions": "désencadrer",
    "désencadre": "désencadrer",
    "désencadrent": "désencadrer",
    "désencadrera": "désencadrer",
    "désencadrerai": "désencadrer",
    "désencadreraient": "désencadrer",
    "désencadrerais": "désencadrer",
    "désencadrerait": "désencadrer",
    "désencadreras": "désencadrer",
    "désencadrerez": "désencadrer",
    "désencadreriez": "désencadrer",
    "désencadrerions": "désencadrer",
    "désencadrerons": "désencadrer",
    "désencadreront": "désencadrer",
    "désencadres": "désencadrer",
    "désencadrez": "désencadrer",
    "désencadriez": "désencadrer",
    "désencadrions": "désencadrer",
    "désencadrons": "désencadrer",
    "désencadrâmes": "désencadrer",
    "désencadrât": "désencadrer",
    "désencadrâtes": "désencadrer",
    "désencadrèrent": "désencadrer",
    "désencadré": "désencadrer",
    "désencadrée": "désencadrer",
    "désencadrées": "désencadrer",
    "désencadrés": "désencadrer",
    "désenchanta": "désenchanter",
    "désenchantai": "désenchanter",
    "désenchantaient": "désenchanter",
    "désenchantais": "désenchanter",
    "désenchantait": "désenchanter",
    "désenchantant": "désenchanter",
    "désenchantas": "désenchanter",
    "désenchantasse": "désenchanter",
    "désenchantassent": "désenchanter",
    "désenchantasses": "désenchanter",
    "désenchantassiez": "désenchanter",
    "désenchantassions": "désenchanter",
    "désenchante": "désenchanter",
    "désenchantements": "désenchantement",
    "désenchantent": "désenchanter",
    "désenchantera": "désenchanter",
    "désenchanterai": "désenchanter",
    "désenchanteraient": "désenchanter",
    "désenchanterais": "désenchanter",
    "désenchanterait": "désenchanter",
    "désenchanteras": "désenchanter",
    "désenchanterez": "désenchanter",
    "désenchanteriez": "désenchanter",
    "désenchanterions": "désenchanter",
    "désenchanterons": "désenchanter",
    "désenchanteront": "désenchanter",
    "désenchantes": "désenchanter",
    "désenchantez": "désenchanter",
    "désenchantiez": "désenchanter",
    "désenchantions": "désenchanter",
    "désenchantons": "désenchanter",
    "désenchantâmes": "désenchanter",
    "désenchantât": "désenchanter",
    "désenchantâtes": "désenchanter",
    "désenchantèrent": "désenchanter",
    "désenchanté": "désenchanter",
    "désenchantée": "désenchanter",
    "désenchantées": "désenchanter",
    "désenchantés": "désenchanter",
    "désenchaîna": "désenchaîner",
    "désenchaînai": "désenchaîner",
    "désenchaînaient": "désenchaîner",
    "désenchaînais": "désenchaîner",
    "désenchaînait": "désenchaîner",
    "désenchaînant": "désenchaîner",
    "désenchaînas": "désenchaîner",
    "désenchaînasse": "désenchaîner",
    "désenchaînassent": "désenchaîner",
    "désenchaînasses": "désenchaîner",
    "désenchaînassiez": "désenchaîner",
    "désenchaînassions": "désenchaîner",
    "désenchaîne": "désenchaîner",
    "désenchaînent": "désenchaîner",
    "désenchaînera": "désenchaîner",
    "désenchaînerai": "désenchaîner",
    "désenchaîneraient": "désenchaîner",
    "désenchaînerais": "désenchaîner",
    "désenchaînerait": "désenchaîner",
    "désenchaîneras": "désenchaîner",
    "désenchaînerez": "désenchaîner",
    "désenchaîneriez": "désenchaîner",
    "désenchaînerions": "désenchaîner",
    "désenchaînerons": "désenchaîner",
    "désenchaîneront": "désenchaîner",
    "désenchaînes": "désenchaîner",
    "désenchaînez": "désenchaîner",
    "désenchaîniez": "désenchaîner",
    "désenchaînions": "désenchaîner",
    "désenchaînons": "désenchaîner",
    "désenchaînâmes": "désenchaîner",
    "désenchaînât": "désenchaîner",
    "désenchaînâtes": "désenchaîner",
    "désenchaînèrent": "désenchaîner",
    "désenchaîné": "désenchaîner",
    "désenchaînée": "désenchaîner",
    "désenchaînées": "désenchaîner",
    "désenchaînés": "désenchaîner",
    "désenchevêtra": "désenchevêtrer",
    "désenclava": "désenclaver",
    "désenclavai": "désenclaver",
    "désenclavaient": "désenclaver",
    "désenclavais": "désenclaver",
    "désenclavait": "désenclaver",
    "désenclavant": "désenclaver",
    "désenclavas": "désenclaver",
    "désenclavasse": "désenclaver",
    "désenclavassent": "désenclaver",
    "désenclavasses": "désenclaver",
    "désenclavassiez": "désenclaver",
    "désenclavassions": "désenclaver",
    "désenclave": "désenclaver",
    "désenclavements": "désenclavement",
    "désenclavent": "désenclaver",
    "désenclavera": "désenclaver",
    "désenclaverai": "désenclaver",
    "désenclaveraient": "désenclaver",
    "désenclaverais": "désenclaver",
    "désenclaverait": "désenclaver",
    "désenclaveras": "désenclaver",
    "désenclaverez": "désenclaver",
    "désenclaveriez": "désenclaver",
    "désenclaverions": "désenclaver",
    "désenclaverons": "désenclaver",
    "désenclaveront": "désenclaver",
    "désenclaves": "désenclaver",
    "désenclavez": "désenclaver",
    "désenclaviez": "désenclaver",
    "désenclavions": "désenclaver",
    "désenclavons": "désenclaver",
    "désenclavâmes": "désenclaver",
    "désenclavât": "désenclaver",
    "désenclavâtes": "désenclaver",
    "désenclavèrent": "désenclaver",
    "désenclavé": "désenclaver",
    "désenclavée": "désenclaver",
    "désenclavées": "désenclaver",
    "désenclavés": "désenclaver",
    "désencombra": "désencombrer",
    "désencombrai": "désencombrer",
    "désencombraient": "désencombrer",
    "désencombrais": "désencombrer",
    "désencombrait": "désencombrer",
    "désencombrant": "désencombrer",
    "désencombras": "désencombrer",
    "désencombrasse": "désencombrer",
    "désencombrassent": "désencombrer",
    "désencombrasses": "désencombrer",
    "désencombrassiez": "désencombrer",
    "désencombrassions": "désencombrer",
    "désencombre": "désencombrer",
    "désencombrent": "désencombrer",
    "désencombrera": "désencombrer",
    "désencombrerai": "désencombrer",
    "désencombreraient": "désencombrer",
    "désencombrerais": "désencombrer",
    "désencombrerait": "désencombrer",
    "désencombreras": "désencombrer",
    "désencombrerez": "désencombrer",
    "désencombreriez": "désencombrer",
    "désencombrerions": "désencombrer",
    "désencombrerons": "désencombrer",
    "désencombreront": "désencombrer",
    "désencombres": "désencombrer",
    "désencombrez": "désencombrer",
    "désencombriez": "désencombrer",
    "désencombrions": "désencombrer",
    "désencombrons": "désencombrer",
    "désencombrâmes": "désencombrer",
    "désencombrât": "désencombrer",
    "désencombrâtes": "désencombrer",
    "désencombrèrent": "désencombrer",
    "désencombré": "désencombrer",
    "désencombrée": "désencombrer",
    "désencombrées": "désencombrer",
    "désencombrés": "désencombrer",
    "désenfla": "désenfler",
    "désenflai": "désenfler",
    "désenflaient": "désenfler",
    "désenflais": "désenfler",
    "désenflait": "désenfler",
    "désenflant": "désenfler",
    "désenflas": "désenfler",
    "désenflasse": "désenfler",
    "désenflassent": "désenfler",
    "désenflasses": "désenfler",
    "désenflassiez": "désenfler",
    "désenflassions": "désenfler",
    "désenfle": "désenfler",
    "désenflent": "désenfler",
    "désenflera": "désenfler",
    "désenflerai": "désenfler",
    "désenfleraient": "désenfler",
    "désenflerais": "désenfler",
    "désenflerait": "désenfler",
    "désenfleras": "désenfler",
    "désenflerez": "désenfler",
    "désenfleriez": "désenfler",
    "désenflerions": "désenfler",
    "désenflerons": "désenfler",
    "désenfleront": "désenfler",
    "désenfles": "désenfler",
    "désenflez": "désenfler",
    "désenfliez": "désenfler",
    "désenflions": "désenfler",
    "désenflons": "désenfler",
    "désenflâmes": "désenfler",
    "désenflât": "désenfler",
    "désenflâtes": "désenfler",
    "désenflèrent": "désenfler",
    "désenflé": "désenfler",
    "désenflée": "désenfler",
    "désenflées": "désenfler",
    "désenflés": "désenfler",
    "désenfuma": "désenfumer",
    "désenfumai": "désenfumer",
    "désenfumaient": "désenfumer",
    "désenfumais": "désenfumer",
    "désenfumait": "désenfumer",
    "désenfumant": "désenfumer",
    "désenfumas": "désenfumer",
    "désenfumasse": "désenfumer",
    "désenfumassent": "désenfumer",
    "désenfumasses": "désenfumer",
    "désenfumassiez": "désenfumer",
    "désenfumassions": "désenfumer",
    "désenfume": "désenfumer",
    "désenfument": "désenfumer",
    "désenfumera": "désenfumer",
    "désenfumerai": "désenfumer",
    "désenfumeraient": "désenfumer",
    "désenfumerais": "désenfumer",
    "désenfumerait": "désenfumer",
    "désenfumeras": "désenfumer",
    "désenfumerez": "désenfumer",
    "désenfumeriez": "désenfumer",
    "désenfumerions": "désenfumer",
    "désenfumerons": "désenfumer",
    "désenfumeront": "désenfumer",
    "désenfumes": "désenfumer",
    "désenfumez": "désenfumer",
    "désenfumiez": "désenfumer",
    "désenfumions": "désenfumer",
    "désenfumons": "désenfumer",
    "désenfumâmes": "désenfumer",
    "désenfumât": "désenfumer",
    "désenfumâtes": "désenfumer",
    "désenfumèrent": "désenfumer",
    "désenfumé": "désenfumer",
    "désenfumée": "désenfumer",
    "désenfumées": "désenfumer",
    "désenfumés": "désenfumer",
    "désengage": "désengager",
    "désengagea": "désengager",
    "désengageai": "désengager",
    "désengageaient": "désengager",
    "désengageais": "désengager",
    "désengageait": "désengager",
    "désengageant": "désengager",
    "désengageas": "désengager",
    "désengageasse": "désengager",
    "désengageassent": "désengager",
    "désengageasses": "désengager",
    "désengageassiez": "désengager",
    "désengageassions": "désengager",
    "désengagements": "désengagement",
    "désengagent": "désengager",
    "désengageons": "désengager",
    "désengagera": "désengager",
    "désengagerai": "désengager",
    "désengageraient": "désengager",
    "désengagerais": "désengager",
    "désengagerait": "désengager",
    "désengageras": "désengager",
    "désengagerez": "désengager",
    "désengageriez": "désengager",
    "désengagerions": "désengager",
    "désengagerons": "désengager",
    "désengageront": "désengager",
    "désengages": "désengager",
    "désengagez": "désengager",
    "désengageâmes": "désengager",
    "désengageât": "désengager",
    "désengageâtes": "désengager",
    "désengagiez": "désengager",
    "désengagions": "désengager",
    "désengagèrent": "désengager",
    "désengagé": "désengager",
    "désengagée": "désengager",
    "désengagées": "désengager",
    "désengagés": "désengager",
    "désengorge": "désengorger",
    "désengorgea": "désengorger",
    "désengorgeai": "désengorger",
    "désengorgeaient": "désengorger",
    "désengorgeais": "désengorger",
    "désengorgeait": "désengorger",
    "désengorgeant": "désengorger",
    "désengorgeas": "désengorger",
    "désengorgeasse": "désengorger",
    "désengorgeassent": "désengorger",
    "désengorgeasses": "désengorger",
    "désengorgeassiez": "désengorger",
    "désengorgeassions": "désengorger",
    "désengorgements": "désengorgement",
    "désengorgent": "désengorger",
    "désengorgeons": "désengorger",
    "désengorgera": "désengorger",
    "désengorgerai": "désengorger",
    "désengorgeraient": "désengorger",
    "désengorgerais": "désengorger",
    "désengorgerait": "désengorger",
    "désengorgeras": "désengorger",
    "désengorgerez": "désengorger",
    "désengorgeriez": "désengorger",
    "désengorgerions": "désengorger",
    "désengorgerons": "désengorger",
    "désengorgeront": "désengorger",
    "désengorges": "désengorger",
    "désengorgez": "désengorger",
    "désengorgeâmes": "désengorger",
    "désengorgeât": "désengorger",
    "désengorgeâtes": "désengorger",
    "désengorgiez": "désengorger",
    "désengorgions": "désengorger",
    "désengorgèrent": "désengorger",
    "désengorgé": "désengorger",
    "désengorgée": "désengorger",
    "désengorgées": "désengorger",
    "désengorgés": "désengorger",
    "désengourdi": "désengourdir",
    "désengourdie": "désengourdir",
    "désengourdies": "désengourdir",
    "désengourdira": "désengourdir",
    "désengourdirai": "désengourdir",
    "désengourdiraient": "désengourdir",
    "désengourdirais": "désengourdir",
    "désengourdirait": "désengourdir",
    "désengourdiras": "désengourdir",
    "désengourdirent": "désengourdir",
    "désengourdirez": "désengourdir",
    "désengourdiriez": "désengourdir",
    "désengourdirions": "désengourdir",
    "désengourdirons": "désengourdir",
    "désengourdiront": "désengourdir",
    "désengourdis": "désengourdir",
    "désengourdissaient": "désengourdir",
    "désengourdissais": "désengourdir",
    "désengourdissait": "désengourdir",
    "désengourdissant": "désengourdir",
    "désengourdisse": "désengourdir",
    "désengourdissent": "désengourdir",
    "désengourdisses": "désengourdir",
    "désengourdissez": "désengourdir",
    "désengourdissiez": "désengourdir",
    "désengourdissions": "désengourdir",
    "désengourdissons": "désengourdir",
    "désengourdit": "désengourdir",
    "désengourdîmes": "désengourdir",
    "désengourdît": "désengourdir",
    "désengourdîtes": "désengourdir",
    "désenivra": "désenivrer",
    "désenivrai": "désenivrer",
    "désenivraient": "désenivrer",
    "désenivrais": "désenivrer",
    "désenivrait": "désenivrer",
    "désenivrant": "désenivrer",
    "désenivras": "désenivrer",
    "désenivrasse": "désenivrer",
    "désenivrassent": "désenivrer",
    "désenivrasses": "désenivrer",
    "désenivrassiez": "désenivrer",
    "désenivrassions": "désenivrer",
    "désenivre": "désenivrer",
    "désenivrent": "désenivrer",
    "désenivrera": "désenivrer",
    "désenivrerai": "désenivrer",
    "désenivreraient": "désenivrer",
    "désenivrerais": "désenivrer",
    "désenivrerait": "désenivrer",
    "désenivreras": "désenivrer",
    "désenivrerez": "désenivrer",
    "désenivreriez": "désenivrer",
    "désenivrerions": "désenivrer",
    "désenivrerons": "désenivrer",
    "désenivreront": "désenivrer",
    "désenivres": "désenivrer",
    "désenivrez": "désenivrer",
    "désenivriez": "désenivrer",
    "désenivrions": "désenivrer",
    "désenivrons": "désenivrer",
    "désenivrâmes": "désenivrer",
    "désenivrât": "désenivrer",
    "désenivrâtes": "désenivrer",
    "désenivrèrent": "désenivrer",
    "désenivré": "désenivrer",
    "désenivrée": "désenivrer",
    "désenivrées": "désenivrer",
    "désenivrés": "désenivrer",
    "désenlaidi": "désenlaidir",
    "désenlaidie": "désenlaidir",
    "désenlaidies": "désenlaidir",
    "désenlaidira": "désenlaidir",
    "désenlaidirai": "désenlaidir",
    "désenlaidiraient": "désenlaidir",
    "désenlaidirais": "désenlaidir",
    "désenlaidirait": "désenlaidir",
    "désenlaidiras": "désenlaidir",
    "désenlaidirent": "désenlaidir",
    "désenlaidirez": "désenlaidir",
    "désenlaidiriez": "désenlaidir",
    "désenlaidirions": "désenlaidir",
    "désenlaidirons": "désenlaidir",
    "désenlaidiront": "désenlaidir",
    "désenlaidis": "désenlaidir",
    "désenlaidissaient": "désenlaidir",
    "désenlaidissais": "désenlaidir",
    "désenlaidissait": "désenlaidir",
    "désenlaidissant": "désenlaidir",
    "désenlaidisse": "désenlaidir",
    "désenlaidissent": "désenlaidir",
    "désenlaidisses": "désenlaidir",
    "désenlaidissez": "désenlaidir",
    "désenlaidissiez": "désenlaidir",
    "désenlaidissions": "désenlaidir",
    "désenlaidissons": "désenlaidir",
    "désenlaidit": "désenlaidir",
    "désenlaidîmes": "désenlaidir",
    "désenlaidît": "désenlaidir",
    "désenlaidîtes": "désenlaidir",
    "désennuie": "désennuyer",
    "désennuient": "désennuyer",
    "désennuiera": "désennuyer",
    "désennuierai": "désennuyer",
    "désennuieraient": "désennuyer",
    "désennuierais": "désennuyer",
    "désennuierait": "désennuyer",
    "désennuieras": "désennuyer",
    "désennuierez": "désennuyer",
    "désennuieriez": "désennuyer",
    "désennuierions": "désennuyer",
    "désennuierons": "désennuyer",
    "désennuieront": "désennuyer",
    "désennuies": "désennuyer",
    "désennuya": "désennuyer",
    "désennuyai": "désennuyer",
    "désennuyaient": "désennuyer",
    "désennuyais": "désennuyer",
    "désennuyait": "désennuyer",
    "désennuyant": "désennuyer",
    "désennuyas": "désennuyer",
    "désennuyasse": "désennuyer",
    "désennuyassent": "désennuyer",
    "désennuyasses": "désennuyer",
    "désennuyassiez": "désennuyer",
    "désennuyassions": "désennuyer",
    "désennuyez": "désennuyer",
    "désennuyiez": "désennuyer",
    "désennuyions": "désennuyer",
    "désennuyons": "désennuyer",
    "désennuyâmes": "désennuyer",
    "désennuyât": "désennuyer",
    "désennuyâtes": "désennuyer",
    "désennuyèrent": "désennuyer",
    "désennuyé": "désennuyer",
    "désennuyée": "désennuyer",
    "désennuyées": "désennuyer",
    "désennuyés": "désennuyer",
    "désenrhuma": "désenrhumer",
    "désenrhumai": "désenrhumer",
    "désenrhumaient": "désenrhumer",
    "désenrhumais": "désenrhumer",
    "désenrhumait": "désenrhumer",
    "désenrhumant": "désenrhumer",
    "désenrhumas": "désenrhumer",
    "désenrhumasse": "désenrhumer",
    "désenrhumassent": "désenrhumer",
    "désenrhumasses": "désenrhumer",
    "désenrhumassiez": "désenrhumer",
    "désenrhumassions": "désenrhumer",
    "désenrhume": "désenrhumer",
    "désenrhument": "désenrhumer",
    "désenrhumera": "désenrhumer",
    "désenrhumerai": "désenrhumer",
    "désenrhumeraient": "désenrhumer",
    "désenrhumerais": "désenrhumer",
    "désenrhumerait": "désenrhumer",
    "désenrhumeras": "désenrhumer",
    "désenrhumerez": "désenrhumer",
    "désenrhumeriez": "désenrhumer",
    "désenrhumerions": "désenrhumer",
    "désenrhumerons": "désenrhumer",
    "désenrhumeront": "désenrhumer",
    "désenrhumes": "désenrhumer",
    "désenrhumez": "désenrhumer",
    "désenrhumiez": "désenrhumer",
    "désenrhumions": "désenrhumer",
    "désenrhumons": "désenrhumer",
    "désenrhumâmes": "désenrhumer",
    "désenrhumât": "désenrhumer",
    "désenrhumâtes": "désenrhumer",
    "désenrhumèrent": "désenrhumer",
    "désenrhumé": "désenrhumer",
    "désenrhumée": "désenrhumer",
    "désenrhumées": "désenrhumer",
    "désenrhumés": "désenrhumer",
    "désensabla": "désensabler",
    "désensablai": "désensabler",
    "désensablaient": "désensabler",
    "désensablais": "désensabler",
    "désensablait": "désensabler",
    "désensablant": "désensabler",
    "désensablas": "désensabler",
    "désensablasse": "désensabler",
    "désensablassent": "désensabler",
    "désensablasses": "désensabler",
    "désensablassiez": "désensabler",
    "désensablassions": "désensabler",
    "désensable": "désensabler",
    "désensablent": "désensabler",
    "désensablera": "désensabler",
    "désensablerai": "désensabler",
    "désensableraient": "désensabler",
    "désensablerais": "désensabler",
    "désensablerait": "désensabler",
    "désensableras": "désensabler",
    "désensablerez": "désensabler",
    "désensableriez": "désensabler",
    "désensablerions": "désensabler",
    "désensablerons": "désensabler",
    "désensableront": "désensabler",
    "désensables": "désensabler",
    "désensablez": "désensabler",
    "désensabliez": "désensabler",
    "désensablions": "désensabler",
    "désensablons": "désensabler",
    "désensablâmes": "désensabler",
    "désensablât": "désensabler",
    "désensablâtes": "désensabler",
    "désensablèrent": "désensabler",
    "désensablé": "désensabler",
    "désensablée": "désensabler",
    "désensablées": "désensabler",
    "désensablés": "désensabler",
    "désensibilisa": "désensibiliser",
    "désensibilisai": "désensibiliser",
    "désensibilisaient": "désensibiliser",
    "désensibilisais": "désensibiliser",
    "désensibilisait": "désensibiliser",
    "désensibilisant": "désensibiliser",
    "désensibilisas": "désensibiliser",
    "désensibilisasse": "désensibiliser",
    "désensibilisassent": "désensibiliser",
    "désensibilisasses": "désensibiliser",
    "désensibilisassiez": "désensibiliser",
    "désensibilisassions": "désensibiliser",
    "désensibilise": "désensibiliser",
    "désensibilisent": "désensibiliser",
    "désensibilisera": "désensibiliser",
    "désensibiliserai": "désensibiliser",
    "désensibiliseraient": "désensibiliser",
    "désensibiliserais": "désensibiliser",
    "désensibiliserait": "désensibiliser",
    "désensibiliseras": "désensibiliser",
    "désensibiliserez": "désensibiliser",
    "désensibiliseriez": "désensibiliser",
    "désensibiliserions": "désensibiliser",
    "désensibiliserons": "désensibiliser",
    "désensibiliseront": "désensibiliser",
    "désensibilises": "désensibiliser",
    "désensibilisez": "désensibiliser",
    "désensibilisiez": "désensibiliser",
    "désensibilisions": "désensibiliser",
    "désensibilisons": "désensibiliser",
    "désensibilisâmes": "désensibiliser",
    "désensibilisât": "désensibiliser",
    "désensibilisâtes": "désensibiliser",
    "désensibilisèrent": "désensibiliser",
    "désensibilisé": "désensibiliser",
    "désensibilisée": "désensibiliser",
    "désensibilisées": "désensibiliser",
    "désensibilisés": "désensibiliser",
    "désensorcelé": "désensorceler",
    "désentassa": "désentasser",
    "désentassai": "désentasser",
    "désentassaient": "désentasser",
    "désentassais": "désentasser",
    "désentassait": "désentasser",
    "désentassant": "désentasser",
    "désentassas": "désentasser",
    "désentassasse": "désentasser",
    "désentassassent": "désentasser",
    "désentassasses": "désentasser",
    "désentassassiez": "désentasser",
    "désentassassions": "désentasser",
    "désentasse": "désentasser",
    "désentassent": "désentasser",
    "désentassera": "désentasser",
    "désentasserai": "désentasser",
    "désentasseraient": "désentasser",
    "désentasserais": "désentasser",
    "désentasserait": "désentasser",
    "désentasseras": "désentasser",
    "désentasserez": "désentasser",
    "désentasseriez": "désentasser",
    "désentasserions": "désentasser",
    "désentasserons": "désentasser",
    "désentasseront": "désentasser",
    "désentasses": "désentasser",
    "désentassez": "désentasser",
    "désentassiez": "désentasser",
    "désentassions": "désentasser",
    "désentassons": "désentasser",
    "désentassâmes": "désentasser",
    "désentassât": "désentasser",
    "désentassâtes": "désentasser",
    "désentassèrent": "désentasser",
    "désentassé": "désentasser",
    "désentassée": "désentasser",
    "désentassées": "désentasser",
    "désentassés": "désentasser",
    "désentoila": "désentoiler",
    "désentoilai": "désentoiler",
    "désentoilaient": "désentoiler",
    "désentoilais": "désentoiler",
    "désentoilait": "désentoiler",
    "désentoilant": "désentoiler",
    "désentoilas": "désentoiler",
    "désentoilasse": "désentoiler",
    "désentoilassent": "désentoiler",
    "désentoilasses": "désentoiler",
    "désentoilassiez": "désentoiler",
    "désentoilassions": "désentoiler",
    "désentoile": "désentoiler",
    "désentoilent": "désentoiler",
    "désentoilera": "désentoiler",
    "désentoilerai": "désentoiler",
    "désentoileraient": "désentoiler",
    "désentoilerais": "désentoiler",
    "désentoilerait": "désentoiler",
    "désentoileras": "désentoiler",
    "désentoilerez": "désentoiler",
    "désentoileriez": "désentoiler",
    "désentoilerions": "désentoiler",
    "désentoilerons": "désentoiler",
    "désentoileront": "désentoiler",
    "désentoiles": "désentoiler",
    "désentoilez": "désentoiler",
    "désentoiliez": "désentoiler",
    "désentoilions": "désentoiler",
    "désentoilons": "désentoiler",
    "désentoilâmes": "désentoiler",
    "désentoilât": "désentoiler",
    "désentoilâtes": "désentoiler",
    "désentoilèrent": "désentoiler",
    "désentoilé": "désentoiler",
    "désentoilée": "désentoiler",
    "désentoilées": "désentoiler",
    "désentoilés": "désentoiler",
    "désentortilla": "désentortiller",
    "désentortillai": "désentortiller",
    "désentortillaient": "désentortiller",
    "désentortillais": "désentortiller",
    "désentortillait": "désentortiller",
    "désentortillant": "désentortiller",
    "désentortillas": "désentortiller",
    "désentortillasse": "désentortiller",
    "désentortillassent": "désentortiller",
    "désentortillasses": "désentortiller",
    "désentortillassiez": "désentortiller",
    "désentortillassions": "désentortiller",
    "désentortille": "désentortiller",
    "désentortillent": "désentortiller",
    "désentortillera": "désentortiller",
    "désentortillerai": "désentortiller",
    "désentortilleraient": "désentortiller",
    "désentortillerais": "désentortiller",
    "désentortillerait": "désentortiller",
    "désentortilleras": "désentortiller",
    "désentortillerez": "désentortiller",
    "désentortilleriez": "désentortiller",
    "désentortillerions": "désentortiller",
    "désentortillerons": "désentortiller",
    "désentortilleront": "désentortiller",
    "désentortilles": "désentortiller",
    "désentortillez": "désentortiller",
    "désentortilliez": "désentortiller",
    "désentortillions": "désentortiller",
    "désentortillons": "désentortiller",
    "désentortillâmes": "désentortiller",
    "désentortillât": "désentortiller",
    "désentortillâtes": "désentortiller",
    "désentortillèrent": "désentortiller",
    "désentortillé": "désentortiller",
    "désentortillée": "désentortiller",
    "désentortillées": "désentortiller",
    "désentortillés": "désentortiller",
    "désentrava": "désentraver",
    "désentravai": "désentraver",
    "désentravaient": "désentraver",
    "désentravais": "désentraver",
    "désentravait": "désentraver",
    "désentravant": "désentraver",
    "désentravas": "désentraver",
    "désentravasse": "désentraver",
    "désentravassent": "désentraver",
    "désentravasses": "désentraver",
    "désentravassiez": "désentraver",
    "désentravassions": "désentraver",
    "désentrave": "désentraver",
    "désentravent": "désentraver",
    "désentravera": "désentraver",
    "désentraverai": "désentraver",
    "désentraveraient": "désentraver",
    "désentraverais": "désentraver",
    "désentraverait": "désentraver",
    "désentraveras": "désentraver",
    "désentraverez": "désentraver",
    "désentraveriez": "désentraver",
    "désentraverions": "désentraver",
    "désentraverons": "désentraver",
    "désentraveront": "désentraver",
    "désentraves": "désentraver",
    "désentravez": "désentraver",
    "désentraviez": "désentraver",
    "désentravions": "désentraver",
    "désentravons": "désentraver",
    "désentravâmes": "désentraver",
    "désentravât": "désentraver",
    "désentravâtes": "désentraver",
    "désentravèrent": "désentraver",
    "désentravé": "désentraver",
    "désentravée": "désentraver",
    "désentravées": "désentraver",
    "désentravés": "désentraver",
    "désenvasa": "désenvaser",
    "désenvasai": "désenvaser",
    "désenvasaient": "désenvaser",
    "désenvasais": "désenvaser",
    "désenvasait": "désenvaser",
    "désenvasant": "désenvaser",
    "désenvasas": "désenvaser",
    "désenvasasse": "désenvaser",
    "désenvasassent": "désenvaser",
    "désenvasasses": "désenvaser",
    "désenvasassiez": "désenvaser",
    "désenvasassions": "désenvaser",
    "désenvase": "désenvaser",
    "désenvasent": "désenvaser",
    "désenvasera": "désenvaser",
    "désenvaserai": "désenvaser",
    "désenvaseraient": "désenvaser",
    "désenvaserais": "désenvaser",
    "désenvaserait": "désenvaser",
    "désenvaseras": "désenvaser",
    "désenvaserez": "désenvaser",
    "désenvaseriez": "désenvaser",
    "désenvaserions": "désenvaser",
    "désenvaserons": "désenvaser",
    "désenvaseront": "désenvaser",
    "désenvases": "désenvaser",
    "désenvasez": "désenvaser",
    "désenvasiez": "désenvaser",
    "désenvasions": "désenvaser",
    "désenvasons": "désenvaser",
    "désenvasâmes": "désenvaser",
    "désenvasât": "désenvaser",
    "désenvasâtes": "désenvaser",
    "désenvasèrent": "désenvaser",
    "désenvasé": "désenvaser",
    "désenvasée": "désenvaser",
    "désenvasées": "désenvaser",
    "désenvasés": "désenvaser",
    "désenveloppa": "désenvelopper",
    "désenveloppai": "désenvelopper",
    "désenveloppaient": "désenvelopper",
    "désenveloppais": "désenvelopper",
    "désenveloppait": "désenvelopper",
    "désenveloppant": "désenvelopper",
    "désenveloppas": "désenvelopper",
    "désenveloppasse": "désenvelopper",
    "désenveloppassent": "désenvelopper",
    "désenveloppasses": "désenvelopper",
    "désenveloppassiez": "désenvelopper",
    "désenveloppassions": "désenvelopper",
    "désenveloppe": "désenvelopper",
    "désenveloppent": "désenvelopper",
    "désenveloppera": "désenvelopper",
    "désenvelopperai": "désenvelopper",
    "désenvelopperaient": "désenvelopper",
    "désenvelopperais": "désenvelopper",
    "désenvelopperait": "désenvelopper",
    "désenvelopperas": "désenvelopper",
    "désenvelopperez": "désenvelopper",
    "désenvelopperiez": "désenvelopper",
    "désenvelopperions": "désenvelopper",
    "désenvelopperons": "désenvelopper",
    "désenvelopperont": "désenvelopper",
    "désenveloppes": "désenvelopper",
    "désenveloppez": "désenvelopper",
    "désenveloppiez": "désenvelopper",
    "désenveloppions": "désenvelopper",
    "désenveloppons": "désenvelopper",
    "désenveloppâmes": "désenvelopper",
    "désenveloppât": "désenvelopper",
    "désenveloppâtes": "désenvelopper",
    "désenveloppèrent": "désenvelopper",
    "désenveloppé": "désenvelopper",
    "désenveloppée": "désenvelopper",
    "désenveloppées": "désenvelopper",
    "désenveloppés": "désenvelopper",
    "désenvenima": "désenvenimer",
    "désenvenimai": "désenvenimer",
    "désenvenimaient": "désenvenimer",
    "désenvenimais": "désenvenimer",
    "désenvenimait": "désenvenimer",
    "désenvenimant": "désenvenimer",
    "désenvenimas": "désenvenimer",
    "désenvenimasse": "désenvenimer",
    "désenvenimassent": "désenvenimer",
    "désenvenimasses": "désenvenimer",
    "désenvenimassiez": "désenvenimer",
    "désenvenimassions": "désenvenimer",
    "désenvenime": "désenvenimer",
    "désenveniment": "désenvenimer",
    "désenvenimera": "désenvenimer",
    "désenvenimerai": "désenvenimer",
    "désenvenimeraient": "désenvenimer",
    "désenvenimerais": "désenvenimer",
    "désenvenimerait": "désenvenimer",
    "désenvenimeras": "désenvenimer",
    "désenvenimerez": "désenvenimer",
    "désenvenimeriez": "désenvenimer",
    "désenvenimerions": "désenvenimer",
    "désenvenimerons": "désenvenimer",
    "désenvenimeront": "désenvenimer",
    "désenvenimes": "désenvenimer",
    "désenvenimez": "désenvenimer",
    "désenvenimiez": "désenvenimer",
    "désenvenimions": "désenvenimer",
    "désenvenimons": "désenvenimer",
    "désenvenimâmes": "désenvenimer",
    "désenvenimât": "désenvenimer",
    "désenvenimâtes": "désenvenimer",
    "désenvenimèrent": "désenvenimer",
    "désenvenimé": "désenvenimer",
    "désenvenimée": "désenvenimer",
    "désenvenimées": "désenvenimer",
    "désenvenimés": "désenvenimer",
    "désenvoûteurs": "désenvoûteur",
    "désenvoûté": "désenvoûter",
    "déserta": "déserter",
    "désertai": "déserter",
    "désertaient": "déserter",
    "désertais": "déserter",
    "désertait": "déserter",
    "désertant": "déserter",
    "désertas": "déserter",
    "désertasse": "déserter",
    "désertassent": "déserter",
    "désertasses": "déserter",
    "désertassiez": "déserter",
    "désertassions": "déserter",
    "déserte": "déserter",
    "désertent": "déserter",
    "désertera": "déserter",
    "déserterai": "déserter",
    "déserteraient": "déserter",
    "déserterais": "déserter",
    "déserterait": "déserter",
    "déserteras": "déserter",
    "déserterez": "déserter",
    "déserteriez": "déserter",
    "déserterions": "déserter",
    "déserterons": "déserter",
    "déserteront": "déserter",
    "désertes": "déserter",
    "déserteurs": "déserteur",
    "déserteuse": "déserteux",
    "déserteuses": "déserteux",
    "désertez": "déserter",
    "désertiez": "déserter",
    "désertifications": "désertification",
    "désertifie": "désertifier",
    "désertions": "désertion",
    "désertiques": "désertique",
    "désertons": "déserter",
    "déserts": "désert",
    "désertâmes": "déserter",
    "désertât": "déserter",
    "désertâtes": "déserter",
    "désertèrent": "déserter",
    "déserté": "déserter",
    "désertée": "déserter",
    "désertées": "déserter",
    "désertés": "déserter",
    "désescalades": "désescalade",
    "désespoirs": "désespoir",
    "désespère": "désespérer",
    "désespèrent": "désespérer",
    "désespères": "désespérer",
    "désespéra": "désespérer",
    "désespérai": "désespérer",
    "désespéraient": "désespérer",
    "désespérais": "désespérer",
    "désespérait": "désespérer",
    "désespérances": "désespérance",
    "désespérant": "désespérer",
    "désespérante": "désespérant",
    "désespérantes": "désespérant",
    "désespérants": "désespérant",
    "désespéras": "désespérer",
    "désespérasse": "désespérer",
    "désespérassent": "désespérer",
    "désespérasses": "désespérer",
    "désespérassiez": "désespérer",
    "désespérassions": "désespérer",
    "désespérera": "désespérer",
    "désespérerai": "désespérer",
    "désespéreraient": "désespérer",
    "désespérerais": "désespérer",
    "désespérerait": "désespérer",
    "désespéreras": "désespérer",
    "désespérerez": "désespérer",
    "désespéreriez": "désespérer",
    "désespérerions": "désespérer",
    "désespérerons": "désespérer",
    "désespéreront": "désespérer",
    "désespérez": "désespérer",
    "désespériez": "désespérer",
    "désespérions": "désespérer",
    "désespérons": "désespérer",
    "désespérâmes": "désespérer",
    "désespérât": "désespérer",
    "désespérâtes": "désespérer",
    "désespérèrent": "désespérer",
    "désespéré": "désespérer",
    "désespérée": "désespérer",
    "désespérées": "désespérer",
    "désespérés": "désespérer",
    "déshabilla": "déshabiller",
    "déshabillages": "déshabillage",
    "déshabillai": "déshabiller",
    "déshabillaient": "déshabiller",
    "déshabillais": "déshabiller",
    "déshabillait": "déshabiller",
    "déshabillant": "déshabiller",
    "déshabillas": "déshabiller",
    "déshabillasse": "déshabiller",
    "déshabillassent": "déshabiller",
    "déshabillasses": "déshabiller",
    "déshabillassiez": "déshabiller",
    "déshabillassions": "déshabiller",
    "déshabille": "déshabiller",
    "déshabillent": "déshabiller",
    "déshabillera": "déshabiller",
    "déshabillerai": "déshabiller",
    "déshabilleraient": "déshabiller",
    "déshabillerais": "déshabiller",
    "déshabillerait": "déshabiller",
    "déshabilleras": "déshabiller",
    "déshabillerez": "déshabiller",
    "déshabilleriez": "déshabiller",
    "déshabillerions": "déshabiller",
    "déshabillerons": "déshabiller",
    "déshabilleront": "déshabiller",
    "déshabilles": "déshabiller",
    "déshabillez": "déshabiller",
    "déshabilliez": "déshabiller",
    "déshabillions": "déshabiller",
    "déshabillons": "déshabiller",
    "déshabillâmes": "déshabiller",
    "déshabillât": "déshabiller",
    "déshabillâtes": "déshabiller",
    "déshabillèrent": "déshabiller",
    "déshabillé": "déshabiller",
    "déshabillée": "déshabiller",
    "déshabillées": "déshabiller",
    "déshabillés": "déshabiller",
    "déshabitua": "déshabituer",
    "déshabituai": "déshabituer",
    "déshabituaient": "déshabituer",
    "déshabituais": "déshabituer",
    "déshabituait": "déshabituer",
    "déshabituant": "déshabituer",
    "déshabituas": "déshabituer",
    "déshabituasse": "déshabituer",
    "déshabituassent": "déshabituer",
    "déshabituasses": "déshabituer",
    "déshabituassiez": "déshabituer",
    "déshabituassions": "déshabituer",
    "déshabitue": "déshabituer",
    "déshabituent": "déshabituer",
    "déshabituera": "déshabituer",
    "déshabituerai": "déshabituer",
    "déshabitueraient": "déshabituer",
    "déshabituerais": "déshabituer",
    "déshabituerait": "déshabituer",
    "déshabitueras": "déshabituer",
    "déshabituerez": "déshabituer",
    "déshabitueriez": "déshabituer",
    "déshabituerions": "déshabituer",
    "déshabituerons": "déshabituer",
    "déshabitueront": "déshabituer",
    "déshabitues": "déshabituer",
    "déshabituez": "déshabituer",
    "déshabituiez": "déshabituer",
    "déshabituions": "déshabituer",
    "déshabituons": "déshabituer",
    "déshabituâmes": "déshabituer",
    "déshabituât": "déshabituer",
    "déshabituâtes": "déshabituer",
    "déshabituèrent": "déshabituer",
    "déshabitué": "déshabituer",
    "déshabituée": "déshabituer",
    "déshabituées": "déshabituer",
    "déshabitués": "déshabituer",
    "déshabité": "déshabiter",
    "déshabitée": "déshabité",
    "déshabités": "déshabiter",
    "désherba": "désherber",
    "désherbai": "désherber",
    "désherbaient": "désherber",
    "désherbais": "désherber",
    "désherbait": "désherber",
    "désherbant": "désherber",
    "désherbants": "désherbant",
    "désherbas": "désherber",
    "désherbasse": "désherber",
    "désherbassent": "désherber",
    "désherbasses": "désherber",
    "désherbassiez": "désherber",
    "désherbassions": "désherber",
    "désherbe": "désherber",
    "désherbent": "désherber",
    "désherbera": "désherber",
    "désherberai": "désherber",
    "désherberaient": "désherber",
    "désherberais": "désherber",
    "désherberait": "désherber",
    "désherberas": "désherber",
    "désherberez": "désherber",
    "désherberiez": "désherber",
    "désherberions": "désherber",
    "désherberons": "désherber",
    "désherberont": "désherber",
    "désherbes": "désherber",
    "désherbez": "désherber",
    "désherbiez": "désherber",
    "désherbions": "désherber",
    "désherbons": "désherber",
    "désherbâmes": "désherber",
    "désherbât": "désherber",
    "désherbâtes": "désherber",
    "désherbèrent": "désherber",
    "désherbé": "désherber",
    "désherbée": "désherber",
    "désherbées": "désherber",
    "désherbés": "désherber",
    "désheuraient": "désheurer",
    "déshonneurs": "déshonneur",
    "déshonnêtes": "déshonnête",
    "déshonora": "déshonorer",
    "déshonorai": "déshonorer",
    "déshonoraient": "déshonorer",
    "déshonorais": "déshonorer",
    "déshonorait": "déshonorer",
    "déshonorant": "déshonorer",
    "déshonorante": "déshonorant",
    "déshonorantes": "déshonorant",
    "déshonorants": "déshonorant",
    "déshonoras": "déshonorer",
    "déshonorasse": "déshonorer",
    "déshonorassent": "déshonorer",
    "déshonorasses": "déshonorer",
    "déshonorassiez": "déshonorer",
    "déshonorassions": "déshonorer",
    "déshonore": "déshonorer",
    "déshonorent": "déshonorer",
    "déshonorera": "déshonorer",
    "déshonorerai": "déshonorer",
    "déshonoreraient": "déshonorer",
    "déshonorerais": "déshonorer",
    "déshonorerait": "déshonorer",
    "déshonoreras": "déshonorer",
    "déshonorerez": "déshonorer",
    "déshonoreriez": "déshonorer",
    "déshonorerions": "déshonorer",
    "déshonorerons": "déshonorer",
    "déshonoreront": "déshonorer",
    "déshonores": "déshonorer",
    "déshonorez": "déshonorer",
    "déshonoriez": "déshonorer",
    "déshonorions": "déshonorer",
    "déshonorons": "déshonorer",
    "déshonorâmes": "déshonorer",
    "déshonorât": "déshonorer",
    "déshonorâtes": "déshonorer",
    "déshonorèrent": "déshonorer",
    "déshonoré": "déshonorer",
    "déshonorée": "déshonorer",
    "déshonorées": "déshonorer",
    "déshonorés": "déshonorer",
    "déshumanisa": "déshumaniser",
    "déshumanisai": "déshumaniser",
    "déshumanisaient": "déshumaniser",
    "déshumanisais": "déshumaniser",
    "déshumanisait": "déshumaniser",
    "déshumanisant": "déshumaniser",
    "déshumanisante": "déshumanisant",
    "déshumanisas": "déshumaniser",
    "déshumanisasse": "déshumaniser",
    "déshumanisassent": "déshumaniser",
    "déshumanisasses": "déshumaniser",
    "déshumanisassiez": "déshumaniser",
    "déshumanisassions": "déshumaniser",
    "déshumanise": "déshumaniser",
    "déshumanisent": "déshumaniser",
    "déshumanisera": "déshumaniser",
    "déshumaniserai": "déshumaniser",
    "déshumaniseraient": "déshumaniser",
    "déshumaniserais": "déshumaniser",
    "déshumaniserait": "déshumaniser",
    "déshumaniseras": "déshumaniser",
    "déshumaniserez": "déshumaniser",
    "déshumaniseriez": "déshumaniser",
    "déshumaniserions": "déshumaniser",
    "déshumaniserons": "déshumaniser",
    "déshumaniseront": "déshumaniser",
    "déshumanises": "déshumaniser",
    "déshumanisez": "déshumaniser",
    "déshumanisiez": "déshumaniser",
    "déshumanisions": "déshumaniser",
    "déshumanisons": "déshumaniser",
    "déshumanisâmes": "déshumaniser",
    "déshumanisât": "déshumaniser",
    "déshumanisâtes": "déshumaniser",
    "déshumanisèrent": "déshumaniser",
    "déshumanisé": "déshumaniser",
    "déshumanisée": "déshumaniser",
    "déshumanisées": "déshumaniser",
    "déshumanisés": "déshumaniser",
    "déshydrata": "déshydrater",
    "déshydratai": "déshydrater",
    "déshydrataient": "déshydrater",
    "déshydratais": "déshydrater",
    "déshydratait": "déshydrater",
    "déshydratant": "déshydrater",
    "déshydratas": "déshydrater",
    "déshydratasse": "déshydrater",
    "déshydratassent": "déshydrater",
    "déshydratasses": "déshydrater",
    "déshydratassiez": "déshydrater",
    "déshydratassions": "déshydrater",
    "déshydratations": "déshydratation",
    "déshydrate": "déshydrater",
    "déshydratent": "déshydrater",
    "déshydratera": "déshydrater",
    "déshydraterai": "déshydrater",
    "déshydrateraient": "déshydrater",
    "déshydraterais": "déshydrater",
    "déshydraterait": "déshydrater",
    "déshydrateras": "déshydrater",
    "déshydraterez": "déshydrater",
    "déshydrateriez": "déshydrater",
    "déshydraterions": "déshydrater",
    "déshydraterons": "déshydrater",
    "déshydrateront": "déshydrater",
    "déshydrates": "déshydrater",
    "déshydratez": "déshydrater",
    "déshydratiez": "déshydrater",
    "déshydrations": "déshydrater",
    "déshydratons": "déshydrater",
    "déshydratâmes": "déshydrater",
    "déshydratât": "déshydrater",
    "déshydratâtes": "déshydrater",
    "déshydratèrent": "déshydrater",
    "déshydraté": "déshydrater",
    "déshydratée": "déshydrater",
    "déshydratées": "déshydrater",
    "déshydratés": "déshydrater",
    "déshydrogène": "déshydrogéner",
    "déshydrogènent": "déshydrogéner",
    "déshydrogènes": "déshydrogéner",
    "déshydrogéna": "déshydrogéner",
    "déshydrogénai": "déshydrogéner",
    "déshydrogénaient": "déshydrogéner",
    "déshydrogénais": "déshydrogéner",
    "déshydrogénait": "déshydrogéner",
    "déshydrogénant": "déshydrogéner",
    "déshydrogénas": "déshydrogéner",
    "déshydrogénasse": "déshydrogéner",
    "déshydrogénassent": "déshydrogéner",
    "déshydrogénasses": "déshydrogéner",
    "déshydrogénassiez": "déshydrogéner",
    "déshydrogénassions": "déshydrogéner",
    "déshydrogénera": "déshydrogéner",
    "déshydrogénerai": "déshydrogéner",
    "déshydrogéneraient": "déshydrogéner",
    "déshydrogénerais": "déshydrogéner",
    "déshydrogénerait": "déshydrogéner",
    "déshydrogéneras": "déshydrogéner",
    "déshydrogénerez": "déshydrogéner",
    "déshydrogéneriez": "déshydrogéner",
    "déshydrogénerions": "déshydrogéner",
    "déshydrogénerons": "déshydrogéner",
    "déshydrogéneront": "déshydrogéner",
    "déshydrogénez": "déshydrogéner",
    "déshydrogéniez": "déshydrogéner",
    "déshydrogénions": "déshydrogéner",
    "déshydrogénons": "déshydrogéner",
    "déshydrogénâmes": "déshydrogéner",
    "déshydrogénât": "déshydrogéner",
    "déshydrogénâtes": "déshydrogéner",
    "déshydrogénèrent": "déshydrogéner",
    "déshydrogéné": "déshydrogéner",
    "déshydrogénée": "déshydrogéner",
    "déshydrogénées": "déshydrogéner",
    "déshydrogénés": "déshydrogéner",
    "déshérences": "déshérence",
    "déshérita": "déshériter",
    "déshéritai": "déshériter",
    "déshéritaient": "déshériter",
    "déshéritais": "déshériter",
    "déshéritait": "déshériter",
    "déshéritant": "déshériter",
    "déshéritas": "déshériter",
    "déshéritasse": "déshériter",
    "déshéritassent": "déshériter",
    "déshéritasses": "déshériter",
    "déshéritassiez": "déshériter",
    "déshéritassions": "déshériter",
    "déshérite": "déshériter",
    "déshéritent": "déshériter",
    "déshéritera": "déshériter",
    "déshériterai": "déshériter",
    "déshériteraient": "déshériter",
    "déshériterais": "déshériter",
    "déshériterait": "déshériter",
    "déshériteras": "déshériter",
    "déshériterez": "déshériter",
    "déshériteriez": "déshériter",
    "déshériterions": "déshériter",
    "déshériterons": "déshériter",
    "déshériteront": "déshériter",
    "déshérites": "déshériter",
    "déshéritez": "déshériter",
    "déshéritiez": "déshériter",
    "déshéritions": "déshériter",
    "déshéritons": "déshériter",
    "déshéritâmes": "déshériter",
    "déshéritât": "déshériter",
    "déshéritâtes": "déshériter",
    "déshéritèrent": "déshériter",
    "déshérité": "déshériter",
    "déshéritée": "déshériter",
    "déshéritées": "déshériter",
    "déshérités": "déshériter",
    "désidéologisa": "désidéologiser",
    "désidéologisai": "désidéologiser",
    "désidéologisaient": "désidéologiser",
    "désidéologisais": "désidéologiser",
    "désidéologisait": "désidéologiser",
    "désidéologisant": "désidéologiser",
    "désidéologisas": "désidéologiser",
    "désidéologisasse": "désidéologiser",
    "désidéologisassent": "désidéologiser",
    "désidéologisasses": "désidéologiser",
    "désidéologisassiez": "désidéologiser",
    "désidéologisassions": "désidéologiser",
    "désidéologisations": "désidéologisation",
    "désidéologise": "désidéologiser",
    "désidéologisent": "désidéologiser",
    "désidéologisera": "désidéologiser",
    "désidéologiserai": "désidéologiser",
    "désidéologiseraient": "désidéologiser",
    "désidéologiserais": "désidéologiser",
    "désidéologiserait": "désidéologiser",
    "désidéologiseras": "désidéologiser",
    "désidéologiserez": "désidéologiser",
    "désidéologiseriez": "désidéologiser",
    "désidéologiserions": "désidéologiser",
    "désidéologiserons": "désidéologiser",
    "désidéologiseront": "désidéologiser",
    "désidéologises": "désidéologiser",
    "désidéologisez": "désidéologiser",
    "désidéologisiez": "désidéologiser",
    "désidéologisions": "désidéologiser",
    "désidéologisons": "désidéologiser",
    "désidéologisâmes": "désidéologiser",
    "désidéologisât": "désidéologiser",
    "désidéologisâtes": "désidéologiser",
    "désidéologisèrent": "désidéologiser",
    "désidéologisé": "désidéologiser",
    "désidéologisée": "désidéologiser",
    "désidéologisées": "désidéologiser",
    "désidéologisés": "désidéologiser",
    "désigna": "désigner",
    "désignai": "désigner",
    "désignaient": "désigner",
    "désignais": "désigner",
    "désignait": "désigner",
    "désignant": "désigner",
    "désignas": "désigner",
    "désignasse": "désigner",
    "désignassent": "désigner",
    "désignasses": "désigner",
    "désignassiez": "désigner",
    "désignassions": "désigner",
    "désignations": "désignation",
    "désigne": "désigner",
    "désignent": "désigner",
    "désignera": "désigner",
    "désignerai": "désigner",
    "désigneraient": "désigner",
    "désignerais": "désigner",
    "désignerait": "désigner",
    "désigneras": "désigner",
    "désignerez": "désigner",
    "désigneriez": "désigner",
    "désignerions": "désigner",
    "désignerons": "désigner",
    "désigneront": "désigner",
    "désignes": "désigner",
    "désignez": "désigner",
    "désigniez": "désigner",
    "désignions": "désigner",
    "désignons": "désigner",
    "désignâmes": "désigner",
    "désignât": "désigner",
    "désignâtes": "désigner",
    "désignèrent": "désigner",
    "désigné": "désigner",
    "désignée": "désigner",
    "désignées": "désigner",
    "désignés": "désigner",
    "désillusionna": "désillusionner",
    "désillusionnai": "désillusionner",
    "désillusionnaient": "désillusionner",
    "désillusionnais": "désillusionner",
    "désillusionnait": "désillusionner",
    "désillusionnant": "désillusionner",
    "désillusionnas": "désillusionner",
    "désillusionnasse": "désillusionner",
    "désillusionnassent": "désillusionner",
    "désillusionnasses": "désillusionner",
    "désillusionnassiez": "désillusionner",
    "désillusionnassions": "désillusionner",
    "désillusionne": "désillusionner",
    "désillusionnent": "désillusionner",
    "désillusionnera": "désillusionner",
    "désillusionnerai": "désillusionner",
    "désillusionneraient": "désillusionner",
    "désillusionnerais": "désillusionner",
    "désillusionnerait": "désillusionner",
    "désillusionneras": "désillusionner",
    "désillusionnerez": "désillusionner",
    "désillusionneriez": "désillusionner",
    "désillusionnerions": "désillusionner",
    "désillusionnerons": "désillusionner",
    "désillusionneront": "désillusionner",
    "désillusionnes": "désillusionner",
    "désillusionnez": "désillusionner",
    "désillusionniez": "désillusionner",
    "désillusionnions": "désillusionner",
    "désillusionnons": "désillusionner",
    "désillusionnâmes": "désillusionner",
    "désillusionnât": "désillusionner",
    "désillusionnâtes": "désillusionner",
    "désillusionnèrent": "désillusionner",
    "désillusionné": "désillusionner",
    "désillusionnée": "désillusionner",
    "désillusionnées": "désillusionner",
    "désillusionnés": "désillusionner",
    "désillusions": "désillusion",
    "désincarcéré": "désincarcérer",
    "désincarnant": "désincarner",
    "désincarne": "désincarner",
    "désincarné": "désincarner",
    "désincarnée": "désincarné",
    "désincarnées": "désincarné",
    "désincarnés": "désincarner",
    "désincrusta": "désincruster",
    "désincrustai": "désincruster",
    "désincrustaient": "désincruster",
    "désincrustais": "désincruster",
    "désincrustait": "désincruster",
    "désincrustant": "désincruster",
    "désincrustante": "désincrustant",
    "désincrustas": "désincruster",
    "désincrustasse": "désincruster",
    "désincrustassent": "désincruster",
    "désincrustasses": "désincruster",
    "désincrustassiez": "désincruster",
    "désincrustassions": "désincruster",
    "désincruste": "désincruster",
    "désincrustent": "désincruster",
    "désincrustera": "désincruster",
    "désincrusterai": "désincruster",
    "désincrusteraient": "désincruster",
    "désincrusterais": "désincruster",
    "désincrusterait": "désincruster",
    "désincrusteras": "désincruster",
    "désincrusterez": "désincruster",
    "désincrusteriez": "désincruster",
    "désincrusterions": "désincruster",
    "désincrusterons": "désincruster",
    "désincrusteront": "désincruster",
    "désincrustes": "désincruster",
    "désincrustez": "désincruster",
    "désincrustiez": "désincruster",
    "désincrustions": "désincruster",
    "désincrustons": "désincruster",
    "désincrustâmes": "désincruster",
    "désincrustât": "désincruster",
    "désincrustâtes": "désincruster",
    "désincrustèrent": "désincruster",
    "désincrusté": "désincruster",
    "désincrustée": "désincruster",
    "désincrustées": "désincruster",
    "désincrustés": "désincruster",
    "désindexa": "désindexer",
    "désindexai": "désindexer",
    "désindexaient": "désindexer",
    "désindexais": "désindexer",
    "désindexait": "désindexer",
    "désindexant": "désindexer",
    "désindexas": "désindexer",
    "désindexasse": "désindexer",
    "désindexassent": "désindexer",
    "désindexasses": "désindexer",
    "désindexassiez": "désindexer",
    "désindexassions": "désindexer",
    "désindexe": "désindexer",
    "désindexent": "désindexer",
    "désindexera": "désindexer",
    "désindexerai": "désindexer",
    "désindexeraient": "désindexer",
    "désindexerais": "désindexer",
    "désindexerait": "désindexer",
    "désindexeras": "désindexer",
    "désindexerez": "désindexer",
    "désindexeriez": "désindexer",
    "désindexerions": "désindexer",
    "désindexerons": "désindexer",
    "désindexeront": "désindexer",
    "désindexes": "désindexer",
    "désindexez": "désindexer",
    "désindexiez": "désindexer",
    "désindexions": "désindexer",
    "désindexons": "désindexer",
    "désindexâmes": "désindexer",
    "désindexât": "désindexer",
    "désindexâtes": "désindexer",
    "désindexèrent": "désindexer",
    "désindexé": "désindexer",
    "désindexée": "désindexer",
    "désindexées": "désindexer",
    "désindexés": "désindexer",
    "désindustrialisations": "désindustrialisation",
    "désinences": "désinence",
    "désinfecta": "désinfecter",
    "désinfectai": "désinfecter",
    "désinfectaient": "désinfecter",
    "désinfectais": "désinfecter",
    "désinfectait": "désinfecter",
    "désinfectant": "désinfecter",
    "désinfectante": "désinfectant",
    "désinfectantes": "désinfectant",
    "désinfectants": "désinfectant",
    "désinfectas": "désinfecter",
    "désinfectasse": "désinfecter",
    "désinfectassent": "désinfecter",
    "désinfectasses": "désinfecter",
    "désinfectassiez": "désinfecter",
    "désinfectassions": "désinfecter",
    "désinfecte": "désinfecter",
    "désinfectent": "désinfecter",
    "désinfectera": "désinfecter",
    "désinfecterai": "désinfecter",
    "désinfecteraient": "désinfecter",
    "désinfecterais": "désinfecter",
    "désinfecterait": "désinfecter",
    "désinfecteras": "désinfecter",
    "désinfecterez": "désinfecter",
    "désinfecteriez": "désinfecter",
    "désinfecterions": "désinfecter",
    "désinfecterons": "désinfecter",
    "désinfecteront": "désinfecter",
    "désinfectes": "désinfecter",
    "désinfectez": "désinfecter",
    "désinfectiez": "désinfecter",
    "désinfections": "désinfection",
    "désinfectons": "désinfecter",
    "désinfectâmes": "désinfecter",
    "désinfectât": "désinfecter",
    "désinfectâtes": "désinfecter",
    "désinfectèrent": "désinfecter",
    "désinfecté": "désinfecter",
    "désinfectée": "désinfecter",
    "désinfectées": "désinfecter",
    "désinfectés": "désinfecter",
    "désinflations": "désinflation",
    "désinformations": "désinformation",
    "désinformée": "désinformer",
    "désinhibe": "désinhiber",
    "désinstallé": "désinstaller",
    "désintoxications": "désintoxication",
    "désintoxiqua": "désintoxiquer",
    "désintoxiquai": "désintoxiquer",
    "désintoxiquaient": "désintoxiquer",
    "désintoxiquais": "désintoxiquer",
    "désintoxiquait": "désintoxiquer",
    "désintoxiquant": "désintoxiquer",
    "désintoxiquas": "désintoxiquer",
    "désintoxiquasse": "désintoxiquer",
    "désintoxiquassent": "désintoxiquer",
    "désintoxiquasses": "désintoxiquer",
    "désintoxiquassiez": "désintoxiquer",
    "désintoxiquassions": "désintoxiquer",
    "désintoxique": "désintoxiquer",
    "désintoxiquent": "désintoxiquer",
    "désintoxiquera": "désintoxiquer",
    "désintoxiquerai": "désintoxiquer",
    "désintoxiqueraient": "désintoxiquer",
    "désintoxiquerais": "désintoxiquer",
    "désintoxiquerait": "désintoxiquer",
    "désintoxiqueras": "désintoxiquer",
    "désintoxiquerez": "désintoxiquer",
    "désintoxiqueriez": "désintoxiquer",
    "désintoxiquerions": "désintoxiquer",
    "désintoxiquerons": "désintoxiquer",
    "désintoxiqueront": "désintoxiquer",
    "désintoxiques": "désintoxiquer",
    "désintoxiquez": "désintoxiquer",
    "désintoxiquiez": "désintoxiquer",
    "désintoxiquions": "désintoxiquer",
    "désintoxiquons": "désintoxiquer",
    "désintoxiquâmes": "désintoxiquer",
    "désintoxiquât": "désintoxiquer",
    "désintoxiquâtes": "désintoxiquer",
    "désintoxiquèrent": "désintoxiquer",
    "désintoxiqué": "désintoxiquer",
    "désintoxiquée": "désintoxiquer",
    "désintoxiquées": "désintoxiquer",
    "désintoxiqués": "désintoxiquer",
    "désintègre": "désintégrer",
    "désintègrent": "désintégrer",
    "désintègres": "désintégrer",
    "désintégra": "désintégrer",
    "désintégrai": "désintégrer",
    "désintégraient": "désintégrer",
    "désintégrais": "désintégrer",
    "désintégrait": "désintégrer",
    "désintégrant": "désintégrer",
    "désintégras": "désintégrer",
    "désintégrasse": "désintégrer",
    "désintégrassent": "désintégrer",
    "désintégrasses": "désintégrer",
    "désintégrassiez": "désintégrer",
    "désintégrassions": "désintégrer",
    "désintégrations": "désintégration",
    "désintégrera": "désintégrer",
    "désintégrerai": "désintégrer",
    "désintégreraient": "désintégrer",
    "désintégrerais": "désintégrer",
    "désintégrerait": "désintégrer",
    "désintégreras": "désintégrer",
    "désintégrerez": "désintégrer",
    "désintégreriez": "désintégrer",
    "désintégrerions": "désintégrer",
    "désintégrerons": "désintégrer",
    "désintégreront": "désintégrer",
    "désintégrez": "désintégrer",
    "désintégriez": "désintégrer",
    "désintégrions": "désintégrer",
    "désintégrons": "désintégrer",
    "désintégrâmes": "désintégrer",
    "désintégrât": "désintégrer",
    "désintégrâtes": "désintégrer",
    "désintégrèrent": "désintégrer",
    "désintégré": "désintégrer",
    "désintégrée": "désintégrer",
    "désintégrées": "désintégrer",
    "désintégrés": "désintégrer",
    "désintéressa": "désintéresser",
    "désintéressai": "désintéresser",
    "désintéressaient": "désintéresser",
    "désintéressais": "désintéresser",
    "désintéressait": "désintéresser",
    "désintéressant": "désintéresser",
    "désintéressas": "désintéresser",
    "désintéressasse": "désintéresser",
    "désintéressassent": "désintéresser",
    "désintéressasses": "désintéresser",
    "désintéressassiez": "désintéresser",
    "désintéressassions": "désintéresser",
    "désintéresse": "désintéresser",
    "désintéressements": "désintéressement",
    "désintéressent": "désintéresser",
    "désintéressera": "désintéresser",
    "désintéresserai": "désintéresser",
    "désintéresseraient": "désintéresser",
    "désintéresserais": "désintéresser",
    "désintéresserait": "désintéresser",
    "désintéresseras": "désintéresser",
    "désintéresserez": "désintéresser",
    "désintéresseriez": "désintéresser",
    "désintéresserions": "désintéresser",
    "désintéresserons": "désintéresser",
    "désintéresseront": "désintéresser",
    "désintéresses": "désintéresser",
    "désintéressez": "désintéresser",
    "désintéressiez": "désintéresser",
    "désintéressions": "désintéresser",
    "désintéressons": "désintéresser",
    "désintéressâmes": "désintéresser",
    "désintéressât": "désintéresser",
    "désintéressâtes": "désintéresser",
    "désintéressèrent": "désintéresser",
    "désintéressé": "désintéresser",
    "désintéressée": "désintéresser",
    "désintéressées": "désintéresser",
    "désintéressés": "désintéresser",
    "désintérêts": "désintérêt",
    "désinvesti": "désinvestir",
    "désinvestie": "désinvestir",
    "désinvesties": "désinvestir",
    "désinvestira": "désinvestir",
    "désinvestirai": "désinvestir",
    "désinvestiraient": "désinvestir",
    "désinvestirais": "désinvestir",
    "désinvestirait": "désinvestir",
    "désinvestiras": "désinvestir",
    "désinvestirent": "désinvestir",
    "désinvestirez": "désinvestir",
    "désinvestiriez": "désinvestir",
    "désinvestirions": "désinvestir",
    "désinvestirons": "désinvestir",
    "désinvestiront": "désinvestir",
    "désinvestis": "désinvestir",
    "désinvestissaient": "désinvestir",
    "désinvestissais": "désinvestir",
    "désinvestissait": "désinvestir",
    "désinvestissant": "désinvestir",
    "désinvestisse": "désinvestir",
    "désinvestissent": "désinvestir",
    "désinvestisses": "désinvestir",
    "désinvestissez": "désinvestir",
    "désinvestissiez": "désinvestir",
    "désinvestissions": "désinvestir",
    "désinvestissons": "désinvestir",
    "désinvestit": "désinvestir",
    "désinvestîmes": "désinvestir",
    "désinvestît": "désinvestir",
    "désinvestîtes": "désinvestir",
    "désinvita": "désinviter",
    "désinvitai": "désinviter",
    "désinvitaient": "désinviter",
    "désinvitais": "désinviter",
    "désinvitait": "désinviter",
    "désinvitant": "désinviter",
    "désinvitas": "désinviter",
    "désinvitasse": "désinviter",
    "désinvitassent": "désinviter",
    "désinvitasses": "désinviter",
    "désinvitassiez": "désinviter",
    "désinvitassions": "désinviter",
    "désinvite": "désinviter",
    "désinvitent": "désinviter",
    "désinvitera": "désinviter",
    "désinviterai": "désinviter",
    "désinviteraient": "désinviter",
    "désinviterais": "désinviter",
    "désinviterait": "désinviter",
    "désinviteras": "désinviter",
    "désinviterez": "désinviter",
    "désinviteriez": "désinviter",
    "désinviterions": "désinviter",
    "désinviterons": "désinviter",
    "désinviteront": "désinviter",
    "désinvites": "désinviter",
    "désinvitez": "désinviter",
    "désinvitiez": "désinviter",
    "désinvitions": "désinviter",
    "désinvitons": "désinviter",
    "désinvitâmes": "désinviter",
    "désinvitât": "désinviter",
    "désinvitâtes": "désinviter",
    "désinvitèrent": "désinviter",
    "désinvité": "désinviter",
    "désinvitée": "désinviter",
    "désinvitées": "désinviter",
    "désinvités": "désinviter",
    "désinvoltes": "désinvolte",
    "désinvoltures": "désinvolture",
    "désira": "désirer",
    "désirables": "désirable",
    "désirai": "désirer",
    "désiraient": "désirer",
    "désirais": "désirer",
    "désirait": "désirer",
    "désirant": "désirer",
    "désirante": "désirant",
    "désiras": "désirer",
    "désirasse": "désirer",
    "désirassent": "désirer",
    "désirasses": "désirer",
    "désirassiez": "désirer",
    "désirassions": "désirer",
    "désire": "désirer",
    "désirent": "désirer",
    "désirera": "désirer",
    "désirerai": "désirer",
    "désireraient": "désirer",
    "désirerais": "désirer",
    "désirerait": "désirer",
    "désireras": "désirer",
    "désirerez": "désirer",
    "désireriez": "désirer",
    "désirerions": "désirer",
    "désirerons": "désirer",
    "désireront": "désirer",
    "désires": "désirer",
    "désireuse": "désireux",
    "désireuses": "désireux",
    "désirez": "désirer",
    "désiriez": "désirer",
    "désirions": "désirer",
    "désirons": "désirer",
    "désirs": "désir",
    "désirâmes": "désirer",
    "désirât": "désirer",
    "désirâtes": "désirer",
    "désirèrent": "désirer",
    "désiré": "désirer",
    "désirée": "désirer",
    "désirées": "désirer",
    "désirés": "désirer",
    "désista": "désister",
    "désistai": "désister",
    "désistaient": "désister",
    "désistais": "désister",
    "désistait": "désister",
    "désistant": "désister",
    "désistas": "désister",
    "désistasse": "désister",
    "désistassent": "désister",
    "désistasses": "désister",
    "désistassiez": "désister",
    "désistassions": "désister",
    "désiste": "désister",
    "désistements": "désistement",
    "désistent": "désister",
    "désistera": "désister",
    "désisterai": "désister",
    "désisteraient": "désister",
    "désisterais": "désister",
    "désisterait": "désister",
    "désisteras": "désister",
    "désisterez": "désister",
    "désisteriez": "désister",
    "désisterions": "désister",
    "désisterons": "désister",
    "désisteront": "désister",
    "désistes": "désister",
    "désistez": "désister",
    "désistiez": "désister",
    "désistions": "désister",
    "désistons": "désister",
    "désistâmes": "désister",
    "désistât": "désister",
    "désistâtes": "désister",
    "désistèrent": "désister",
    "désisté": "désister",
    "désistée": "désister",
    "désistées": "désister",
    "désistés": "désister",
    "déslipe": "désliper",
    "désoblige": "désobliger",
    "désobligea": "désobliger",
    "désobligeai": "désobliger",
    "désobligeaient": "désobliger",
    "désobligeais": "désobliger",
    "désobligeait": "désobliger",
    "désobligeant": "désobliger",
    "désobligeante": "désobligeant",
    "désobligeantes": "désobligeant",
    "désobligeants": "désobligeant",
    "désobligeas": "désobliger",
    "désobligeasse": "désobliger",
    "désobligeassent": "désobliger",
    "désobligeasses": "désobliger",
    "désobligeassiez": "désobliger",
    "désobligeassions": "désobliger",
    "désobligent": "désobliger",
    "désobligeons": "désobliger",
    "désobligera": "désobliger",
    "désobligerai": "désobliger",
    "désobligeraient": "désobliger",
    "désobligerais": "désobliger",
    "désobligerait": "désobliger",
    "désobligeras": "désobliger",
    "désobligerez": "désobliger",
    "désobligeriez": "désobliger",
    "désobligerions": "désobliger",
    "désobligerons": "désobliger",
    "désobligeront": "désobliger",
    "désobliges": "désobliger",
    "désobligez": "désobliger",
    "désobligeâmes": "désobliger",
    "désobligeât": "désobliger",
    "désobligeâtes": "désobliger",
    "désobligiez": "désobliger",
    "désobligions": "désobliger",
    "désobligèrent": "désobliger",
    "désobligé": "désobliger",
    "désobligée": "désobliger",
    "désobligées": "désobliger",
    "désobligés": "désobliger",
    "désobstrua": "désobstruer",
    "désobstruai": "désobstruer",
    "désobstruaient": "désobstruer",
    "désobstruais": "désobstruer",
    "désobstruait": "désobstruer",
    "désobstruant": "désobstruer",
    "désobstruas": "désobstruer",
    "désobstruasse": "désobstruer",
    "désobstruassent": "désobstruer",
    "désobstruasses": "désobstruer",
    "désobstruassiez": "désobstruer",
    "désobstruassions": "désobstruer",
    "désobstrue": "désobstruer",
    "désobstruent": "désobstruer",
    "désobstruera": "désobstruer",
    "désobstruerai": "désobstruer",
    "désobstrueraient": "désobstruer",
    "désobstruerais": "désobstruer",
    "désobstruerait": "désobstruer",
    "désobstrueras": "désobstruer",
    "désobstruerez": "désobstruer",
    "désobstrueriez": "désobstruer",
    "désobstruerions": "désobstruer",
    "désobstruerons": "désobstruer",
    "désobstrueront": "désobstruer",
    "désobstrues": "désobstruer",
    "désobstruez": "désobstruer",
    "désobstruiez": "désobstruer",
    "désobstruions": "désobstruer",
    "désobstruons": "désobstruer",
    "désobstruâmes": "désobstruer",
    "désobstruât": "désobstruer",
    "désobstruâtes": "désobstruer",
    "désobstruèrent": "désobstruer",
    "désobstrué": "désobstruer",
    "désobstruée": "désobstruer",
    "désobstruées": "désobstruer",
    "désobstrués": "désobstruer",
    "désobéi": "désobéir",
    "désobéira": "désobéir",
    "désobéirai": "désobéir",
    "désobéiraient": "désobéir",
    "désobéirais": "désobéir",
    "désobéirait": "désobéir",
    "désobéiras": "désobéir",
    "désobéirent": "désobéir",
    "désobéirez": "désobéir",
    "désobéiriez": "désobéir",
    "désobéirions": "désobéir",
    "désobéirons": "désobéir",
    "désobéiront": "désobéir",
    "désobéis": "désobéir",
    "désobéissaient": "désobéir",
    "désobéissais": "désobéir",
    "désobéissait": "désobéir",
    "désobéissances": "désobéissance",
    "désobéissant": "désobéir",
    "désobéissante": "désobéissant",
    "désobéissantes": "désobéissant",
    "désobéissants": "désobéissant",
    "désobéisse": "désobéir",
    "désobéissent": "désobéir",
    "désobéisses": "désobéir",
    "désobéissez": "désobéir",
    "désobéissiez": "désobéir",
    "désobéissions": "désobéir",
    "désobéissons": "désobéir",
    "désobéit": "désobéir",
    "désobéîmes": "désobéir",
    "désobéît": "désobéir",
    "désobéîtes": "désobéir",
    "désoccupa": "désoccuper",
    "désoccupai": "désoccuper",
    "désoccupaient": "désoccuper",
    "désoccupais": "désoccuper",
    "désoccupait": "désoccuper",
    "désoccupant": "désoccuper",
    "désoccupas": "désoccuper",
    "désoccupasse": "désoccuper",
    "désoccupassent": "désoccuper",
    "désoccupasses": "désoccuper",
    "désoccupassiez": "désoccuper",
    "désoccupassions": "désoccuper",
    "désoccupe": "désoccuper",
    "désoccupent": "désoccuper",
    "désoccupera": "désoccuper",
    "désoccuperai": "désoccuper",
    "désoccuperaient": "désoccuper",
    "désoccuperais": "désoccuper",
    "désoccuperait": "désoccuper",
    "désoccuperas": "désoccuper",
    "désoccuperez": "désoccuper",
    "désoccuperiez": "désoccuper",
    "désoccuperions": "désoccuper",
    "désoccuperons": "désoccuper",
    "désoccuperont": "désoccuper",
    "désoccupes": "désoccuper",
    "désoccupez": "désoccuper",
    "désoccupiez": "désoccuper",
    "désoccupions": "désoccuper",
    "désoccupons": "désoccuper",
    "désoccupâmes": "désoccuper",
    "désoccupât": "désoccuper",
    "désoccupâtes": "désoccuper",
    "désoccupèrent": "désoccuper",
    "désoccupé": "désoccuper",
    "désoccupée": "désoccuper",
    "désoccupées": "désoccuper",
    "désoccupés": "désoccuper",
    "désodorisa": "désodoriser",
    "désodorisai": "désodoriser",
    "désodorisaient": "désodoriser",
    "désodorisais": "désodoriser",
    "désodorisait": "désodoriser",
    "désodorisant": "désodoriser",
    "désodorisante": "désodorisant",
    "désodorisants": "désodorisant",
    "désodorisas": "désodoriser",
    "désodorisasse": "désodoriser",
    "désodorisassent": "désodoriser",
    "désodorisasses": "désodoriser",
    "désodorisassiez": "désodoriser",
    "désodorisassions": "désodoriser",
    "désodorise": "désodoriser",
    "désodorisent": "désodoriser",
    "désodorisera": "désodoriser",
    "désodoriserai": "désodoriser",
    "désodoriseraient": "désodoriser",
    "désodoriserais": "désodoriser",
    "désodoriserait": "désodoriser",
    "désodoriseras": "désodoriser",
    "désodoriserez": "désodoriser",
    "désodoriseriez": "désodoriser",
    "désodoriserions": "désodoriser",
    "désodoriserons": "désodoriser",
    "désodoriseront": "désodoriser",
    "désodorises": "désodoriser",
    "désodorisez": "désodoriser",
    "désodorisiez": "désodoriser",
    "désodorisions": "désodoriser",
    "désodorisons": "désodoriser",
    "désodorisâmes": "désodoriser",
    "désodorisât": "désodoriser",
    "désodorisâtes": "désodoriser",
    "désodorisèrent": "désodoriser",
    "désodorisé": "désodoriser",
    "désodorisée": "désodoriser",
    "désodorisées": "désodoriser",
    "désodorisés": "désodoriser",
    "désoeuvrements": "désoeuvrement",
    "désoeuvré": "désoeuvrer",
    "désoeuvrée": "désoeuvrer",
    "désoeuvrées": "désoeuvrer",
    "désoeuvrés": "désoeuvrer",
    "désola": "désoler",
    "désolai": "désoler",
    "désolaient": "désoler",
    "désolais": "désoler",
    "désolait": "désoler",
    "désolant": "désoler",
    "désolante": "désolant",
    "désolantes": "désolant",
    "désolants": "désolant",
    "désolas": "désoler",
    "désolasse": "désoler",
    "désolassent": "désoler",
    "désolasses": "désoler",
    "désolassiez": "désoler",
    "désolassions": "désoler",
    "désolations": "désolation",
    "désole": "désoler",
    "désolent": "désoler",
    "désolera": "désoler",
    "désolerai": "désoler",
    "désoleraient": "désoler",
    "désolerais": "désoler",
    "désolerait": "désoler",
    "désoleras": "désoler",
    "désolerez": "désoler",
    "désoleriez": "désoler",
    "désolerions": "désoler",
    "désolerons": "désoler",
    "désoleront": "désoler",
    "désoles": "désoler",
    "désolez": "désoler",
    "désolidarisa": "désolidariser",
    "désolidarisai": "désolidariser",
    "désolidarisaient": "désolidariser",
    "désolidarisais": "désolidariser",
    "désolidarisait": "désolidariser",
    "désolidarisant": "désolidariser",
    "désolidarisas": "désolidariser",
    "désolidarisasse": "désolidariser",
    "désolidarisassent": "désolidariser",
    "désolidarisasses": "désolidariser",
    "désolidarisassiez": "désolidariser",
    "désolidarisassions": "désolidariser",
    "désolidarise": "désolidariser",
    "désolidarisent": "désolidariser",
    "désolidarisera": "désolidariser",
    "désolidariserai": "désolidariser",
    "désolidariseraient": "désolidariser",
    "désolidariserais": "désolidariser",
    "désolidariserait": "désolidariser",
    "désolidariseras": "désolidariser",
    "désolidariserez": "désolidariser",
    "désolidariseriez": "désolidariser",
    "désolidariserions": "désolidariser",
    "désolidariserons": "désolidariser",
    "désolidariseront": "désolidariser",
    "désolidarises": "désolidariser",
    "désolidarisez": "désolidariser",
    "désolidarisiez": "désolidariser",
    "désolidarisions": "désolidariser",
    "désolidarisons": "désolidariser",
    "désolidarisâmes": "désolidariser",
    "désolidarisât": "désolidariser",
    "désolidarisâtes": "désolidariser",
    "désolidarisèrent": "désolidariser",
    "désolidarisé": "désolidariser",
    "désolidarisée": "désolidariser",
    "désolidarisées": "désolidariser",
    "désolidarisés": "désolidariser",
    "désoliez": "désoler",
    "désolions": "désoler",
    "désolons": "désoler",
    "désolâmes": "désoler",
    "désolât": "désoler",
    "désolâtes": "désoler",
    "désolèrent": "désoler",
    "désolé": "désoler",
    "désolée": "désoler",
    "désolées": "désoler",
    "désolés": "désoler",
    "désopilant": "désopiler",
    "désopilante": "désopilant",
    "désopilantes": "désopilant",
    "désopilants": "désopilant",
    "désorbitent": "désorbiter",
    "désordonna": "désordonner",
    "désordonnai": "désordonner",
    "désordonnaient": "désordonner",
    "désordonnais": "désordonner",
    "désordonnait": "désordonner",
    "désordonnant": "désordonner",
    "désordonnas": "désordonner",
    "désordonnasse": "désordonner",
    "désordonnassent": "désordonner",
    "désordonnasses": "désordonner",
    "désordonnassiez": "désordonner",
    "désordonnassions": "désordonner",
    "désordonne": "désordonner",
    "désordonnent": "désordonner",
    "désordonnera": "désordonner",
    "désordonnerai": "désordonner",
    "désordonneraient": "désordonner",
    "désordonnerais": "désordonner",
    "désordonnerait": "désordonner",
    "désordonneras": "désordonner",
    "désordonnerez": "désordonner",
    "désordonneriez": "désordonner",
    "désordonnerions": "désordonner",
    "désordonnerons": "désordonner",
    "désordonneront": "désordonner",
    "désordonnes": "désordonner",
    "désordonnez": "désordonner",
    "désordonniez": "désordonner",
    "désordonnions": "désordonner",
    "désordonnons": "désordonner",
    "désordonnâmes": "désordonner",
    "désordonnât": "désordonner",
    "désordonnâtes": "désordonner",
    "désordonnèrent": "désordonner",
    "désordonné": "désordonner",
    "désordonnée": "désordonner",
    "désordonnées": "désordonner",
    "désordonnés": "désordonner",
    "désordres": "désordre",
    "désorganisa": "désorganiser",
    "désorganisai": "désorganiser",
    "désorganisaient": "désorganiser",
    "désorganisais": "désorganiser",
    "désorganisait": "désorganiser",
    "désorganisant": "désorganiser",
    "désorganisas": "désorganiser",
    "désorganisasse": "désorganiser",
    "désorganisassent": "désorganiser",
    "désorganisasses": "désorganiser",
    "désorganisassiez": "désorganiser",
    "désorganisassions": "désorganiser",
    "désorganisations": "désorganisation",
    "désorganise": "désorganiser",
    "désorganisent": "désorganiser",
    "désorganisera": "désorganiser",
    "désorganiserai": "désorganiser",
    "désorganiseraient": "désorganiser",
    "désorganiserais": "désorganiser",
    "désorganiserait": "désorganiser",
    "désorganiseras": "désorganiser",
    "désorganiserez": "désorganiser",
    "désorganiseriez": "désorganiser",
    "désorganiserions": "désorganiser",
    "désorganiserons": "désorganiser",
    "désorganiseront": "désorganiser",
    "désorganises": "désorganiser",
    "désorganisez": "désorganiser",
    "désorganisiez": "désorganiser",
    "désorganisions": "désorganiser",
    "désorganisons": "désorganiser",
    "désorganisâmes": "désorganiser",
    "désorganisât": "désorganiser",
    "désorganisâtes": "désorganiser",
    "désorganisèrent": "désorganiser",
    "désorganisé": "désorganiser",
    "désorganisée": "désorganiser",
    "désorganisées": "désorganiser",
    "désorganisés": "désorganiser",
    "désorienta": "désorienter",
    "désorientai": "désorienter",
    "désorientaient": "désorienter",
    "désorientais": "désorienter",
    "désorientait": "désorienter",
    "désorientant": "désorienter",
    "désorientas": "désorienter",
    "désorientasse": "désorienter",
    "désorientassent": "désorienter",
    "désorientasses": "désorienter",
    "désorientassiez": "désorienter",
    "désorientassions": "désorienter",
    "désoriente": "désorienter",
    "désorientent": "désorienter",
    "désorientera": "désorienter",
    "désorienterai": "désorienter",
    "désorienteraient": "désorienter",
    "désorienterais": "désorienter",
    "désorienterait": "désorienter",
    "désorienteras": "désorienter",
    "désorienterez": "désorienter",
    "désorienteriez": "désorienter",
    "désorienterions": "désorienter",
    "désorienterons": "désorienter",
    "désorienteront": "désorienter",
    "désorientes": "désorienter",
    "désorientez": "désorienter",
    "désorientiez": "désorienter",
    "désorientions": "désorienter",
    "désorientons": "désorienter",
    "désorientâmes": "désorienter",
    "désorientât": "désorienter",
    "désorientâtes": "désorienter",
    "désorientèrent": "désorienter",
    "désorienté": "désorienter",
    "désorientée": "désorienter",
    "désorientées": "désorienter",
    "désorientés": "désorienter",
    "désossa": "désosser",
    "désossai": "désosser",
    "désossaient": "désosser",
    "désossais": "désosser",
    "désossait": "désosser",
    "désossant": "désosser",
    "désossas": "désosser",
    "désossasse": "désosser",
    "désossassent": "désosser",
    "désossasses": "désosser",
    "désossassiez": "désosser",
    "désossassions": "désosser",
    "désosse": "désosser",
    "désossent": "désosser",
    "désossera": "désosser",
    "désosserai": "désosser",
    "désosseraient": "désosser",
    "désosserais": "désosser",
    "désosserait": "désosser",
    "désosseras": "désosser",
    "désosserez": "désosser",
    "désosseriez": "désosser",
    "désosserions": "désosser",
    "désosserons": "désosser",
    "désosseront": "désosser",
    "désosses": "désosser",
    "désossez": "désosser",
    "désossiez": "désosser",
    "désossions": "désosser",
    "désossons": "désosser",
    "désossâmes": "désosser",
    "désossât": "désosser",
    "désossâtes": "désosser",
    "désossèrent": "désosser",
    "désossé": "désosser",
    "désossée": "désosser",
    "désossées": "désosser",
    "désossés": "désosser",
    "déstabilisa": "déstabiliser",
    "déstabilisai": "déstabiliser",
    "déstabilisaient": "déstabiliser",
    "déstabilisais": "déstabiliser",
    "déstabilisait": "déstabiliser",
    "déstabilisant": "déstabiliser",
    "déstabilisante": "déstabilisant",
    "déstabilisantes": "déstabilisant",
    "déstabilisants": "déstabilisant",
    "déstabilisas": "déstabiliser",
    "déstabilisasse": "déstabiliser",
    "déstabilisassent": "déstabiliser",
    "déstabilisasses": "déstabiliser",
    "déstabilisassiez": "déstabiliser",
    "déstabilisassions": "déstabiliser",
    "déstabilisateurs": "déstabilisateur",
    "déstabilisations": "déstabilisation",
    "déstabilisatrice": "déstabilisateur",
    "déstabilisatrices": "déstabilisateur",
    "déstabilise": "déstabiliser",
    "déstabilisent": "déstabiliser",
    "déstabilisera": "déstabiliser",
    "déstabiliserai": "déstabiliser",
    "déstabiliseraient": "déstabiliser",
    "déstabiliserais": "déstabiliser",
    "déstabiliserait": "déstabiliser",
    "déstabiliseras": "déstabiliser",
    "déstabiliserez": "déstabiliser",
    "déstabiliseriez": "déstabiliser",
    "déstabiliserions": "déstabiliser",
    "déstabiliserons": "déstabiliser",
    "déstabiliseront": "déstabiliser",
    "déstabilises": "déstabiliser",
    "déstabilisez": "déstabiliser",
    "déstabilisiez": "déstabiliser",
    "déstabilisions": "déstabiliser",
    "déstabilisons": "déstabiliser",
    "déstabilisâmes": "déstabiliser",
    "déstabilisât": "déstabiliser",
    "déstabilisâtes": "déstabiliser",
    "déstabilisèrent": "déstabiliser",
    "déstabilisé": "déstabiliser",
    "déstabilisée": "déstabiliser",
    "déstabilisées": "déstabiliser",
    "déstabilisés": "déstabiliser",
    "déstalinisations": "déstalinisation",
    "déstocké": "déstocker",
    "déstructura": "déstructurer",
    "déstructurai": "déstructurer",
    "déstructuraient": "déstructurer",
    "déstructurais": "déstructurer",
    "déstructurait": "déstructurer",
    "déstructurant": "déstructurer",
    "déstructuras": "déstructurer",
    "déstructurasse": "déstructurer",
    "déstructurassent": "déstructurer",
    "déstructurasses": "déstructurer",
    "déstructurassiez": "déstructurer",
    "déstructurassions": "déstructurer",
    "déstructurations": "déstructuration",
    "déstructure": "déstructurer",
    "déstructurent": "déstructurer",
    "déstructurera": "déstructurer",
    "déstructurerai": "déstructurer",
    "déstructureraient": "déstructurer",
    "déstructurerais": "déstructurer",
    "déstructurerait": "déstructurer",
    "déstructureras": "déstructurer",
    "déstructurerez": "déstructurer",
    "déstructureriez": "déstructurer",
    "déstructurerions": "déstructurer",
    "déstructurerons": "déstructurer",
    "déstructureront": "déstructurer",
    "déstructures": "déstructurer",
    "déstructurez": "déstructurer",
    "déstructuriez": "déstructurer",
    "déstructurions": "déstructurer",
    "déstructurons": "déstructurer",
    "déstructurâmes": "déstructurer",
    "déstructurât": "déstructurer",
    "déstructurâtes": "déstructurer",
    "déstructurèrent": "déstructurer",
    "déstructuré": "déstructurer",
    "déstructurée": "déstructurer",
    "déstructurées": "déstructurer",
    "déstructurés": "déstructurer",
    "désuets": "désuet",
    "désulfurisations": "désulfurisation",
    "désuni": "désunir",
    "désunie": "désunir",
    "désunies": "désunir",
    "désunions": "désunion",
    "désunira": "désunir",
    "désunirai": "désunir",
    "désuniraient": "désunir",
    "désunirais": "désunir",
    "désunirait": "désunir",
    "désuniras": "désunir",
    "désunirent": "désunir",
    "désunirez": "désunir",
    "désuniriez": "désunir",
    "désunirions": "désunir",
    "désunirons": "désunir",
    "désuniront": "désunir",
    "désunis": "désunir",
    "désunissaient": "désunir",
    "désunissais": "désunir",
    "désunissait": "désunir",
    "désunissant": "désunir",
    "désunisse": "désunir",
    "désunissent": "désunir",
    "désunisses": "désunir",
    "désunissez": "désunir",
    "désunissiez": "désunir",
    "désunissions": "désunir",
    "désunissons": "désunir",
    "désunit": "désunir",
    "désunîmes": "désunir",
    "désunît": "désunir",
    "désunîtes": "désunir",
    "désuète": "désuet",
    "désuètes": "désuet",
    "désuétudes": "désuétude",
    "désynchronisé": "désynchroniser",
    "déséchoua": "déséchouer",
    "déséchouai": "déséchouer",
    "déséchouaient": "déséchouer",
    "déséchouais": "déséchouer",
    "déséchouait": "déséchouer",
    "déséchouant": "déséchouer",
    "déséchouas": "déséchouer",
    "déséchouasse": "déséchouer",
    "déséchouassent": "déséchouer",
    "déséchouasses": "déséchouer",
    "déséchouassiez": "déséchouer",
    "déséchouassions": "déséchouer",
    "déséchoue": "déséchouer",
    "déséchouent": "déséchouer",
    "déséchouera": "déséchouer",
    "déséchouerai": "déséchouer",
    "déséchoueraient": "déséchouer",
    "déséchouerais": "déséchouer",
    "déséchouerait": "déséchouer",
    "déséchoueras": "déséchouer",
    "déséchouerez": "déséchouer",
    "déséchoueriez": "déséchouer",
    "déséchouerions": "déséchouer",
    "déséchouerons": "déséchouer",
    "déséchoueront": "déséchouer",
    "déséchoues": "déséchouer",
    "déséchouez": "déséchouer",
    "déséchouiez": "déséchouer",
    "déséchouions": "déséchouer",
    "déséchouons": "déséchouer",
    "déséchouâmes": "déséchouer",
    "déséchouât": "déséchouer",
    "déséchouâtes": "déséchouer",
    "déséchouèrent": "déséchouer",
    "déséchoué": "déséchouer",
    "déséchouée": "déséchouer",
    "déséchouées": "déséchouer",
    "déséchoués": "déséchouer",
    "désénerva": "désénerver",
    "désénervai": "désénerver",
    "désénervaient": "désénerver",
    "désénervais": "désénerver",
    "désénervait": "désénerver",
    "désénervant": "désénerver",
    "désénervas": "désénerver",
    "désénervasse": "désénerver",
    "désénervassent": "désénerver",
    "désénervasses": "désénerver",
    "désénervassiez": "désénerver",
    "désénervassions": "désénerver",
    "désénerve": "désénerver",
    "désénervent": "désénerver",
    "désénervera": "désénerver",
    "désénerverai": "désénerver",
    "désénerveraient": "désénerver",
    "désénerverais": "désénerver",
    "désénerverait": "désénerver",
    "désénerveras": "désénerver",
    "désénerverez": "désénerver",
    "désénerveriez": "désénerver",
    "désénerverions": "désénerver",
    "désénerverons": "désénerver",
    "désénerveront": "désénerver",
    "désénerves": "désénerver",
    "désénervez": "désénerver",
    "désénerviez": "désénerver",
    "désénervions": "désénerver",
    "désénervons": "désénerver",
    "désénervâmes": "désénerver",
    "désénervât": "désénerver",
    "désénervâtes": "désénerver",
    "désénervèrent": "désénerver",
    "désénervé": "désénerver",
    "désénervée": "désénerver",
    "désénervées": "désénerver",
    "désénervés": "désénerver",
    "désépaissis": "désépaissir",
    "déséquilibra": "déséquilibrer",
    "déséquilibrai": "déséquilibrer",
    "déséquilibraient": "déséquilibrer",
    "déséquilibrais": "déséquilibrer",
    "déséquilibrait": "déséquilibrer",
    "déséquilibrant": "déséquilibrer",
    "déséquilibrante": "déséquilibrant",
    "déséquilibrantes": "déséquilibrant",
    "déséquilibrants": "déséquilibrant",
    "déséquilibras": "déséquilibrer",
    "déséquilibrasse": "déséquilibrer",
    "déséquilibrassent": "déséquilibrer",
    "déséquilibrasses": "déséquilibrer",
    "déséquilibrassiez": "déséquilibrer",
    "déséquilibrassions": "déséquilibrer",
    "déséquilibre": "déséquilibrer",
    "déséquilibrent": "déséquilibrer",
    "déséquilibrera": "déséquilibrer",
    "déséquilibrerai": "déséquilibrer",
    "déséquilibreraient": "déséquilibrer",
    "déséquilibrerais": "déséquilibrer",
    "déséquilibrerait": "déséquilibrer",
    "déséquilibreras": "déséquilibrer",
    "déséquilibrerez": "déséquilibrer",
    "déséquilibreriez": "déséquilibrer",
    "déséquilibrerions": "déséquilibrer",
    "déséquilibrerons": "déséquilibrer",
    "déséquilibreront": "déséquilibrer",
    "déséquilibres": "déséquilibrer",
    "déséquilibrez": "déséquilibrer",
    "déséquilibriez": "déséquilibrer",
    "déséquilibrions": "déséquilibrer",
    "déséquilibrons": "déséquilibrer",
    "déséquilibrâmes": "déséquilibrer",
    "déséquilibrât": "déséquilibrer",
    "déséquilibrâtes": "déséquilibrer",
    "déséquilibrèrent": "déséquilibrer",
    "déséquilibré": "déséquilibrer",
    "déséquilibrée": "déséquilibrer",
    "déséquilibrées": "déséquilibrer",
    "déséquilibrés": "déséquilibrer",
    "déséquipa": "déséquiper",
    "déséquipai": "déséquiper",
    "déséquipaient": "déséquiper",
    "déséquipais": "déséquiper",
    "déséquipait": "déséquiper",
    "déséquipant": "déséquiper",
    "déséquipas": "déséquiper",
    "déséquipasse": "déséquiper",
    "déséquipassent": "déséquiper",
    "déséquipasses": "déséquiper",
    "déséquipassiez": "déséquiper",
    "déséquipassions": "déséquiper",
    "déséquipe": "déséquiper",
    "déséquipent": "déséquiper",
    "déséquipera": "déséquiper",
    "déséquiperai": "déséquiper",
    "déséquiperaient": "déséquiper",
    "déséquiperais": "déséquiper",
    "déséquiperait": "déséquiper",
    "déséquiperas": "déséquiper",
    "déséquiperez": "déséquiper",
    "déséquiperiez": "déséquiper",
    "déséquiperions": "déséquiper",
    "déséquiperons": "déséquiper",
    "déséquiperont": "déséquiper",
    "déséquipes": "déséquiper",
    "déséquipez": "déséquiper",
    "déséquipiez": "déséquiper",
    "déséquipions": "déséquiper",
    "déséquipons": "déséquiper",
    "déséquipâmes": "déséquiper",
    "déséquipât": "déséquiper",
    "déséquipâtes": "déséquiper",
    "déséquipèrent": "déséquiper",
    "déséquipé": "déséquiper",
    "déséquipée": "déséquiper",
    "déséquipées": "déséquiper",
    "déséquipés": "déséquiper",
    "désétabli": "désétablir",
    "désétablie": "désétablir",
    "désétablies": "désétablir",
    "désétablira": "désétablir",
    "désétablirai": "désétablir",
    "désétabliraient": "désétablir",
    "désétablirais": "désétablir",
    "désétablirait": "désétablir",
    "désétabliras": "désétablir",
    "désétablirent": "désétablir",
    "désétablirez": "désétablir",
    "désétabliriez": "désétablir",
    "désétablirions": "désétablir",
    "désétablirons": "désétablir",
    "désétabliront": "désétablir",
    "désétablis": "désétablir",
    "désétablissaient": "désétablir",
    "désétablissais": "désétablir",
    "désétablissait": "désétablir",
    "désétablissant": "désétablir",
    "désétablisse": "désétablir",
    "désétablissent": "désétablir",
    "désétablisses": "désétablir",
    "désétablissez": "désétablir",
    "désétablissiez": "désétablir",
    "désétablissions": "désétablir",
    "désétablissons": "désétablir",
    "désétablit": "désétablir",
    "désétablîmes": "désétablir",
    "désétablît": "désétablir",
    "désétablîtes": "désétablir",
    "détacha": "détacher",
    "détachai": "détacher",
    "détachaient": "détacher",
    "détachais": "détacher",
    "détachait": "détacher",
    "détachant": "détacher",
    "détachants": "détachant",
    "détachas": "détacher",
    "détachasse": "détacher",
    "détachassent": "détacher",
    "détachasses": "détacher",
    "détachassiez": "détacher",
    "détachassions": "détacher",
    "détache": "détacher",
    "détachements": "détachement",
    "détachent": "détacher",
    "détachera": "détacher",
    "détacherai": "détacher",
    "détacheraient": "détacher",
    "détacherais": "détacher",
    "détacherait": "détacher",
    "détacheras": "détacher",
    "détacherez": "détacher",
    "détacheriez": "détacher",
    "détacherions": "détacher",
    "détacherons": "détacher",
    "détacheront": "détacher",
    "détaches": "détacher",
    "détachez": "détacher",
    "détachiez": "détacher",
    "détachions": "détacher",
    "détachons": "détacher",
    "détachâmes": "détacher",
    "détachât": "détacher",
    "détachâtes": "détacher",
    "détachèrent": "détacher",
    "détaché": "détacher",
    "détachée": "détacher",
    "détachées": "détacher",
    "détachés": "détacher",
    "détailla": "détailler",
    "détaillai": "détailler",
    "détaillaient": "détailler",
    "détaillais": "détailler",
    "détaillait": "détailler",
    "détaillant": "détailler",
    "détaillante": "détaillant",
    "détaillants": "détaillant",
    "détaillas": "détailler",
    "détaillasse": "détailler",
    "détaillassent": "détailler",
    "détaillasses": "détailler",
    "détaillassiez": "détailler",
    "détaillassions": "détailler",
    "détaille": "détailler",
    "détaillent": "détailler",
    "détaillera": "détailler",
    "détaillerai": "détailler",
    "détailleraient": "détailler",
    "détaillerais": "détailler",
    "détaillerait": "détailler",
    "détailleras": "détailler",
    "détaillerez": "détailler",
    "détailleriez": "détailler",
    "détaillerions": "détailler",
    "détaillerons": "détailler",
    "détailleront": "détailler",
    "détailles": "détailler",
    "détaillez": "détailler",
    "détailliez": "détailler",
    "détaillions": "détailler",
    "détaillons": "détailler",
    "détaillâmes": "détailler",
    "détaillât": "détailler",
    "détaillâtes": "détailler",
    "détaillèrent": "détailler",
    "détaillé": "détailler",
    "détaillée": "détailler",
    "détaillées": "détailler",
    "détaillés": "détailler",
    "détails": "détail",
    "détala": "détaler",
    "détalai": "détaler",
    "détalaient": "détaler",
    "détalais": "détaler",
    "détalait": "détaler",
    "détalant": "détaler",
    "détalas": "détaler",
    "détalasse": "détaler",
    "détalassent": "détaler",
    "détalasses": "détaler",
    "détalassiez": "détaler",
    "détalassions": "détaler",
    "détale": "détaler",
    "détalent": "détaler",
    "détalera": "détaler",
    "détalerai": "détaler",
    "détaleraient": "détaler",
    "détalerais": "détaler",
    "détalerait": "détaler",
    "détaleras": "détaler",
    "détalerez": "détaler",
    "détaleriez": "détaler",
    "détalerions": "détaler",
    "détalerons": "détaler",
    "détaleront": "détaler",
    "détales": "détaler",
    "détalez": "détaler",
    "détaliez": "détaler",
    "détalions": "détaler",
    "détalla": "détaller",
    "détallai": "détaller",
    "détallaient": "détaller",
    "détallais": "détaller",
    "détallait": "détaller",
    "détallant": "détaller",
    "détallas": "détaller",
    "détallasse": "détaller",
    "détallassent": "détaller",
    "détallasses": "détaller",
    "détallassiez": "détaller",
    "détallassions": "détaller",
    "détalle": "détaller",
    "détallent": "détaller",
    "détallera": "détaller",
    "détallerai": "détaller",
    "détalleraient": "détaller",
    "détallerais": "détaller",
    "détallerait": "détaller",
    "détalleras": "détaller",
    "détallerez": "détaller",
    "détalleriez": "détaller",
    "détallerions": "détaller",
    "détallerons": "détaller",
    "détalleront": "détaller",
    "détalles": "détaller",
    "détallez": "détaller",
    "détalliez": "détaller",
    "détallions": "détaller",
    "détallons": "détaller",
    "détallâmes": "détaller",
    "détallât": "détaller",
    "détallâtes": "détaller",
    "détallèrent": "détaller",
    "détallé": "détaller",
    "détallée": "détaller",
    "détallées": "détaller",
    "détallés": "détaller",
    "détalons": "détaler",
    "détalâmes": "détaler",
    "détalât": "détaler",
    "détalâtes": "détaler",
    "détalèrent": "détaler",
    "détalé": "détaler",
    "détapa": "détaper",
    "détapai": "détaper",
    "détapaient": "détaper",
    "détapais": "détaper",
    "détapait": "détaper",
    "détapant": "détaper",
    "détapas": "détaper",
    "détapasse": "détaper",
    "détapassent": "détaper",
    "détapasses": "détaper",
    "détapassiez": "détaper",
    "détapassions": "détaper",
    "détape": "détaper",
    "détapent": "détaper",
    "détapera": "détaper",
    "détaperai": "détaper",
    "détaperaient": "détaper",
    "détaperais": "détaper",
    "détaperait": "détaper",
    "détaperas": "détaper",
    "détaperez": "détaper",
    "détaperiez": "détaper",
    "détaperions": "détaper",
    "détaperons": "détaper",
    "détaperont": "détaper",
    "détapes": "détaper",
    "détapez": "détaper",
    "détapiez": "détaper",
    "détapions": "détaper",
    "détapons": "détaper",
    "détapâmes": "détaper",
    "détapât": "détaper",
    "détapâtes": "détaper",
    "détapèrent": "détaper",
    "détapé": "détaper",
    "détapée": "détaper",
    "détapées": "détaper",
    "détapés": "détaper",
    "détartra": "détartrer",
    "détartrai": "détartrer",
    "détartraient": "détartrer",
    "détartrais": "détartrer",
    "détartrait": "détartrer",
    "détartrant": "détartrer",
    "détartrants": "détartrant",
    "détartras": "détartrer",
    "détartrasse": "détartrer",
    "détartrassent": "détartrer",
    "détartrasses": "détartrer",
    "détartrassiez": "détartrer",
    "détartrassions": "détartrer",
    "détartre": "détartrer",
    "détartrent": "détartrer",
    "détartrera": "détartrer",
    "détartrerai": "détartrer",
    "détartreraient": "détartrer",
    "détartrerais": "détartrer",
    "détartrerait": "détartrer",
    "détartreras": "détartrer",
    "détartrerez": "détartrer",
    "détartreriez": "détartrer",
    "détartrerions": "détartrer",
    "détartrerons": "détartrer",
    "détartreront": "détartrer",
    "détartres": "détartrer",
    "détartrez": "détartrer",
    "détartriez": "détartrer",
    "détartrions": "détartrer",
    "détartrons": "détartrer",
    "détartrâmes": "détartrer",
    "détartrât": "détartrer",
    "détartrâtes": "détartrer",
    "détartrèrent": "détartrer",
    "détartré": "détartrer",
    "détartrée": "détartrer",
    "détartrées": "détartrer",
    "détartrés": "détartrer",
    "détaxa": "détaxer",
    "détaxai": "détaxer",
    "détaxaient": "détaxer",
    "détaxais": "détaxer",
    "détaxait": "détaxer",
    "détaxant": "détaxer",
    "détaxas": "détaxer",
    "détaxasse": "détaxer",
    "détaxassent": "détaxer",
    "détaxasses": "détaxer",
    "détaxassiez": "détaxer",
    "détaxassions": "détaxer",
    "détaxations": "détaxation",
    "détaxe": "détaxer",
    "détaxent": "détaxer",
    "détaxera": "détaxer",
    "détaxerai": "détaxer",
    "détaxeraient": "détaxer",
    "détaxerais": "détaxer",
    "détaxerait": "détaxer",
    "détaxeras": "détaxer",
    "détaxerez": "détaxer",
    "détaxeriez": "détaxer",
    "détaxerions": "détaxer",
    "détaxerons": "détaxer",
    "détaxeront": "détaxer",
    "détaxes": "détaxer",
    "détaxez": "détaxer",
    "détaxiez": "détaxer",
    "détaxions": "détaxer",
    "détaxons": "détaxer",
    "détaxâmes": "détaxer",
    "détaxât": "détaxer",
    "détaxâtes": "détaxer",
    "détaxèrent": "détaxer",
    "détaxé": "détaxer",
    "détaxée": "détaxer",
    "détaxées": "détaxer",
    "détaxés": "détaxer",
    "détecta": "détecter",
    "détectables": "détectable",
    "détectai": "détecter",
    "détectaient": "détecter",
    "détectais": "détecter",
    "détectait": "détecter",
    "détectant": "détecter",
    "détectas": "détecter",
    "détectasse": "détecter",
    "détectassent": "détecter",
    "détectasses": "détecter",
    "détectassiez": "détecter",
    "détectassions": "détecter",
    "détecte": "détecter",
    "détectent": "détecter",
    "détectera": "détecter",
    "détecterai": "détecter",
    "détecteraient": "détecter",
    "détecterais": "détecter",
    "détecterait": "détecter",
    "détecteras": "détecter",
    "détecterez": "détecter",
    "détecteriez": "détecter",
    "détecterions": "détecter",
    "détecterons": "détecter",
    "détecteront": "détecter",
    "détectes": "détecter",
    "détecteurs": "détecteur",
    "détectez": "détecter",
    "détectiez": "détecter",
    "détections": "détection",
    "détectives": "détective",
    "détectives-conseils": "détective-conseil",
    "détectons": "détecter",
    "détectâmes": "détecter",
    "détectât": "détecter",
    "détectâtes": "détecter",
    "détectèrent": "détecter",
    "détecté": "détecter",
    "détectée": "détecter",
    "détectées": "détecter",
    "détectés": "détecter",
    "déteignaient": "déteindre",
    "déteignais": "déteindre",
    "déteignait": "déteindre",
    "déteignant": "déteindre",
    "déteigne": "déteindre",
    "déteignent": "déteindre",
    "déteignes": "déteindre",
    "déteignez": "déteindre",
    "déteigniez": "déteindre",
    "déteignions": "déteindre",
    "déteignirent": "déteindre",
    "déteignis": "déteindre",
    "déteignisse": "déteindre",
    "déteignissent": "déteindre",
    "déteignisses": "déteindre",
    "déteignissiez": "déteindre",
    "déteignissions": "déteindre",
    "déteignit": "déteindre",
    "déteignons": "déteindre",
    "déteignîmes": "déteindre",
    "déteignît": "déteindre",
    "déteignîtes": "déteindre",
    "déteindra": "déteindre",
    "déteindrai": "déteindre",
    "déteindraient": "déteindre",
    "déteindrais": "déteindre",
    "déteindrait": "déteindre",
    "déteindras": "déteindre",
    "déteindrez": "déteindre",
    "déteindriez": "déteindre",
    "déteindrions": "déteindre",
    "déteindrons": "déteindre",
    "déteindront": "déteindre",
    "déteins": "déteindre",
    "déteint": "déteindre",
    "déteinte": "déteindre",
    "déteintes": "déteindre",
    "déteints": "déteindre",
    "détela": "dételer",
    "dételai": "dételer",
    "dételaient": "dételer",
    "dételais": "dételer",
    "dételait": "dételer",
    "dételant": "dételer",
    "dételas": "dételer",
    "dételasse": "dételer",
    "dételassent": "dételer",
    "dételasses": "dételer",
    "dételassiez": "dételer",
    "dételassions": "dételer",
    "dételez": "dételer",
    "dételiez": "dételer",
    "dételions": "dételer",
    "dételle": "dételer",
    "détellent": "dételer",
    "détellera": "dételer",
    "détellerai": "dételer",
    "dételleraient": "dételer",
    "détellerais": "dételer",
    "détellerait": "dételer",
    "dételleras": "dételer",
    "détellerez": "dételer",
    "dételleriez": "dételer",
    "détellerions": "dételer",
    "détellerons": "dételer",
    "dételleront": "dételer",
    "dételles": "dételer",
    "dételons": "dételer",
    "dételâmes": "dételer",
    "dételât": "dételer",
    "dételâtes": "dételer",
    "dételèrent": "dételer",
    "dételé": "dételer",
    "dételée": "dételer",
    "dételées": "dételer",
    "dételés": "dételer",
    "détenaient": "détenir",
    "détenais": "détenir",
    "détenait": "détenir",
    "détenant": "détenir",
    "détend": "détendre",
    "détendaient": "détendre",
    "détendais": "détendre",
    "détendait": "détendre",
    "détendant": "détendre",
    "détende": "détendre",
    "détendent": "détendre",
    "détendes": "détendre",
    "détendez": "détendre",
    "détendiez": "détendre",
    "détendions": "détendre",
    "détendirent": "détendre",
    "détendis": "détendre",
    "détendisse": "détendre",
    "détendissent": "détendre",
    "détendisses": "détendre",
    "détendissiez": "détendre",
    "détendissions": "détendre",
    "détendit": "détendre",
    "détendons": "détendre",
    "détendra": "détendre",
    "détendrai": "détendre",
    "détendraient": "détendre",
    "détendrais": "détendre",
    "détendrait": "détendre",
    "détendras": "détendre",
    "détendrez": "détendre",
    "détendriez": "détendre",
    "détendrions": "détendre",
    "détendrons": "détendre",
    "détendront": "détendre",
    "détends": "détendre",
    "détendu": "détendre",
    "détendue": "détendu",
    "détendues": "détendu",
    "détendus": "détendu",
    "détendîmes": "détendre",
    "détendît": "détendre",
    "détendîtes": "détendre",
    "détenez": "détenir",
    "déteniez": "détenir",
    "détenions": "détenir",
    "détenons": "détenir",
    "détentes": "détente",
    "détenteurs": "détenteur",
    "détentions": "détention",
    "détentrice": "détenteur",
    "détentrices": "détenteur",
    "détenu": "détenir",
    "détenue": "détenu",
    "détenues": "détenu",
    "détenus": "détenu",
    "déterge": "déterger",
    "détergea": "déterger",
    "détergeai": "déterger",
    "détergeaient": "déterger",
    "détergeais": "déterger",
    "détergeait": "déterger",
    "détergeant": "déterger",
    "détergeas": "déterger",
    "détergeasse": "déterger",
    "détergeassent": "déterger",
    "détergeasses": "déterger",
    "détergeassiez": "déterger",
    "détergeassions": "déterger",
    "détergent": "déterger",
    "détergents": "détergent",
    "détergeons": "déterger",
    "détergera": "déterger",
    "détergerai": "déterger",
    "détergeraient": "déterger",
    "détergerais": "déterger",
    "détergerait": "déterger",
    "détergeras": "déterger",
    "détergerez": "déterger",
    "détergeriez": "déterger",
    "détergerions": "déterger",
    "détergerons": "déterger",
    "détergeront": "déterger",
    "déterges": "déterger",
    "détergez": "déterger",
    "détergeâmes": "déterger",
    "détergeât": "déterger",
    "détergeâtes": "déterger",
    "détergiez": "déterger",
    "détergions": "déterger",
    "détergèrent": "déterger",
    "détergé": "déterger",
    "détergée": "déterger",
    "détergées": "déterger",
    "détergés": "déterger",
    "détermina": "déterminer",
    "déterminai": "déterminer",
    "déterminaient": "déterminer",
    "déterminais": "déterminer",
    "déterminait": "déterminer",
    "déterminant": "déterminer",
    "déterminante": "déterminant",
    "déterminantes": "déterminant",
    "déterminants": "déterminant",
    "déterminas": "déterminer",
    "déterminasse": "déterminer",
    "déterminassent": "déterminer",
    "déterminasses": "déterminer",
    "déterminassiez": "déterminer",
    "déterminassions": "déterminer",
    "déterminations": "détermination",
    "détermine": "déterminer",
    "déterminent": "déterminer",
    "déterminera": "déterminer",
    "déterminerai": "déterminer",
    "détermineraient": "déterminer",
    "déterminerais": "déterminer",
    "déterminerait": "déterminer",
    "détermineras": "déterminer",
    "déterminerez": "déterminer",
    "détermineriez": "déterminer",
    "déterminerions": "déterminer",
    "déterminerons": "déterminer",
    "détermineront": "déterminer",
    "détermines": "déterminer",
    "déterminez": "déterminer",
    "déterminiez": "déterminer",
    "déterminions": "déterminer",
    "déterminismes": "déterminisme",
    "déterministes": "déterministe",
    "déterminons": "déterminer",
    "déterminâmes": "déterminer",
    "déterminât": "déterminer",
    "déterminâtes": "déterminer",
    "déterminèrent": "déterminer",
    "déterminé": "déterminer",
    "déterminée": "déterminer",
    "déterminées": "déterminer",
    "déterminés": "déterminer",
    "déterra": "déterrer",
    "déterrai": "déterrer",
    "déterraient": "déterrer",
    "déterrais": "déterrer",
    "déterrait": "déterrer",
    "déterrant": "déterrer",
    "déterras": "déterrer",
    "déterrasse": "déterrer",
    "déterrassent": "déterrer",
    "déterrasses": "déterrer",
    "déterrassiez": "déterrer",
    "déterrassions": "déterrer",
    "déterre": "déterrer",
    "déterrent": "déterrer",
    "déterrera": "déterrer",
    "déterrerai": "déterrer",
    "déterreraient": "déterrer",
    "déterrerais": "déterrer",
    "déterrerait": "déterrer",
    "déterreras": "déterrer",
    "déterrerez": "déterrer",
    "déterreriez": "déterrer",
    "déterrerions": "déterrer",
    "déterrerons": "déterrer",
    "déterreront": "déterrer",
    "déterres": "déterrer",
    "déterreurs": "déterreur",
    "déterreuse": "déterreur",
    "déterrez": "déterrer",
    "déterriez": "déterrer",
    "déterrions": "déterrer",
    "déterrons": "déterrer",
    "déterrâmes": "déterrer",
    "déterrât": "déterrer",
    "déterrâtes": "déterrer",
    "déterrèrent": "déterrer",
    "déterré": "déterrer",
    "déterrée": "déterrer",
    "déterrées": "déterrer",
    "déterrés": "déterrer",
    "détersifs": "détersif",
    "détersive": "détersif",
    "détesta": "détester",
    "détestables": "détestable",
    "détestai": "détester",
    "détestaient": "détester",
    "détestais": "détester",
    "détestait": "détester",
    "détestant": "détester",
    "détestas": "détester",
    "détestasse": "détester",
    "détestassent": "détester",
    "détestasses": "détester",
    "détestassiez": "détester",
    "détestassions": "détester",
    "détestations": "détestation",
    "déteste": "détester",
    "détestent": "détester",
    "détestera": "détester",
    "détesterai": "détester",
    "détesteraient": "détester",
    "détesterais": "détester",
    "détesterait": "détester",
    "détesteras": "détester",
    "détesterez": "détester",
    "détesteriez": "détester",
    "détesterions": "détester",
    "détesterons": "détester",
    "détesteront": "détester",
    "détestes": "détester",
    "détestez": "détester",
    "détestiez": "détester",
    "détestions": "détester",
    "détestons": "détester",
    "détestâmes": "détester",
    "détestât": "détester",
    "détestâtes": "détester",
    "détestèrent": "détester",
    "détesté": "détester",
    "détestée": "détester",
    "détestées": "détester",
    "détestés": "détester",
    "détiendra": "détenir",
    "détiendrai": "détenir",
    "détiendraient": "détenir",
    "détiendrais": "détenir",
    "détiendrait": "détenir",
    "détiendras": "détenir",
    "détiendrez": "détenir",
    "détiendriez": "détenir",
    "détiendrions": "détenir",
    "détiendrons": "détenir",
    "détiendront": "détenir",
    "détienne": "détenir",
    "détiennent": "détenir",
    "détiennes": "détenir",
    "détiens": "détenir",
    "détient": "détenir",
    "détimbrée": "détimbré",
    "détinrent": "détenir",
    "détins": "détenir",
    "détinsse": "détenir",
    "détinssent": "détenir",
    "détinsses": "détenir",
    "détinssiez": "détenir",
    "détinssions": "détenir",
    "détint": "détenir",
    "détira": "détirer",
    "détirai": "détirer",
    "détiraient": "détirer",
    "détirais": "détirer",
    "détirait": "détirer",
    "détirant": "détirer",
    "détiras": "détirer",
    "détirasse": "détirer",
    "détirassent": "détirer",
    "détirasses": "détirer",
    "détirassiez": "détirer",
    "détirassions": "détirer",
    "détire": "détirer",
    "détirent": "détirer",
    "détirera": "détirer",
    "détirerai": "détirer",
    "détireraient": "détirer",
    "détirerais": "détirer",
    "détirerait": "détirer",
    "détireras": "détirer",
    "détirerez": "détirer",
    "détireriez": "détirer",
    "détirerions": "détirer",
    "détirerons": "détirer",
    "détireront": "détirer",
    "détires": "détirer",
    "détirez": "détirer",
    "détiriez": "détirer",
    "détirions": "détirer",
    "détirons": "détirer",
    "détirâmes": "détirer",
    "détirât": "détirer",
    "détirâtes": "détirer",
    "détirèrent": "détirer",
    "détiré": "détirer",
    "détirée": "détirer",
    "détirées": "détirer",
    "détirés": "détirer",
    "détissa": "détisser",
    "détissai": "détisser",
    "détissaient": "détisser",
    "détissais": "détisser",
    "détissait": "détisser",
    "détissant": "détisser",
    "détissas": "détisser",
    "détissasse": "détisser",
    "détissassent": "détisser",
    "détissasses": "détisser",
    "détissassiez": "détisser",
    "détissassions": "détisser",
    "détisse": "détisser",
    "détissent": "détisser",
    "détissera": "détisser",
    "détisserai": "détisser",
    "détisseraient": "détisser",
    "détisserais": "détisser",
    "détisserait": "détisser",
    "détisseras": "détisser",
    "détisserez": "détisser",
    "détisseriez": "détisser",
    "détisserions": "détisser",
    "détisserons": "détisser",
    "détisseront": "détisser",
    "détisses": "détisser",
    "détissez": "détisser",
    "détissiez": "détisser",
    "détissions": "détisser",
    "détissons": "détisser",
    "détissâmes": "détisser",
    "détissât": "détisser",
    "détissâtes": "détisser",
    "détissèrent": "détisser",
    "détissé": "détisser",
    "détissée": "détisser",
    "détissées": "détisser",
    "détissés": "détisser",
    "détona": "détoner",
    "détonai": "détoner",
    "détonaient": "détoner",
    "détonais": "détoner",
    "détonait": "détoner",
    "détonant": "détoner",
    "détonante": "détonant",
    "détonants": "détonant",
    "détonas": "détoner",
    "détonasse": "détoner",
    "détonassent": "détoner",
    "détonasses": "détoner",
    "détonassiez": "détoner",
    "détonassions": "détoner",
    "détonateurs": "détonateur",
    "détonations": "détonation",
    "détone": "détoner",
    "détonent": "détoner",
    "détonera": "détoner",
    "détonerai": "détoner",
    "détoneraient": "détoner",
    "détonerais": "détoner",
    "détonerait": "détoner",
    "détoneras": "détoner",
    "détonerez": "détoner",
    "détoneriez": "détoner",
    "détonerions": "détoner",
    "détonerons": "détoner",
    "détoneront": "détoner",
    "détones": "détoner",
    "détonez": "détoner",
    "détoniez": "détoner",
    "détonions": "détoner",
    "détonna": "détonner",
    "détonnai": "détonner",
    "détonnaient": "détonner",
    "détonnais": "détonner",
    "détonnait": "détonner",
    "détonnant": "détonner",
    "détonnas": "détonner",
    "détonnasse": "détonner",
    "détonnassent": "détonner",
    "détonnasses": "détonner",
    "détonnassiez": "détonner",
    "détonnassions": "détonner",
    "détonne": "détonner",
    "détonnent": "détonner",
    "détonnera": "détonner",
    "détonnerai": "détonner",
    "détonneraient": "détonner",
    "détonnerais": "détonner",
    "détonnerait": "détonner",
    "détonneras": "détonner",
    "détonnerez": "détonner",
    "détonneriez": "détonner",
    "détonnerions": "détonner",
    "détonnerons": "détonner",
    "détonneront": "détonner",
    "détonnes": "détonner",
    "détonnez": "détonner",
    "détonniez": "détonner",
    "détonnions": "détonner",
    "détonnons": "détonner",
    "détonnâmes": "détonner",
    "détonnât": "détonner",
    "détonnâtes": "détonner",
    "détonnèrent": "détonner",
    "détonné": "détonner",
    "détonons": "détoner",
    "détonâmes": "détoner",
    "détonât": "détoner",
    "détonâtes": "détoner",
    "détonèrent": "détoner",
    "détoné": "détoner",
    "détonée": "détoner",
    "détord": "détordre",
    "détordaient": "détordre",
    "détordais": "détordre",
    "détordait": "détordre",
    "détordant": "détordre",
    "détorde": "détordre",
    "détordent": "détordre",
    "détordes": "détordre",
    "détordez": "détordre",
    "détordiez": "détordre",
    "détordions": "détordre",
    "détordirent": "détordre",
    "détordis": "détordre",
    "détordisse": "détordre",
    "détordissent": "détordre",
    "détordisses": "détordre",
    "détordissiez": "détordre",
    "détordissions": "détordre",
    "détordit": "détordre",
    "détordons": "détordre",
    "détordra": "détordre",
    "détordrai": "détordre",
    "détordraient": "détordre",
    "détordrais": "détordre",
    "détordrait": "détordre",
    "détordras": "détordre",
    "détordrez": "détordre",
    "détordriez": "détordre",
    "détordrions": "détordre",
    "détordrons": "détordre",
    "détordront": "détordre",
    "détords": "détordre",
    "détordu": "détordre",
    "détordue": "détordre",
    "détordues": "détordre",
    "détordus": "détordre",
    "détordîmes": "détordre",
    "détordît": "détordre",
    "détordîtes": "détordre",
    "détorsions": "détorsion",
    "détortillai": "détortiller",
    "détortille": "détortiller",
    "détoura": "détourer",
    "détourai": "détourer",
    "détouraient": "détourer",
    "détourais": "détourer",
    "détourait": "détourer",
    "détourant": "détourer",
    "détouras": "détourer",
    "détourasse": "détourer",
    "détourassent": "détourer",
    "détourasses": "détourer",
    "détourassiez": "détourer",
    "détourassions": "détourer",
    "détoure": "détourer",
    "détourent": "détourer",
    "détourera": "détourer",
    "détourerai": "détourer",
    "détoureraient": "détourer",
    "détourerais": "détourer",
    "détourerait": "détourer",
    "détoureras": "détourer",
    "détourerez": "détourer",
    "détoureriez": "détourer",
    "détourerions": "détourer",
    "détourerons": "détourer",
    "détoureront": "détourer",
    "détoures": "détourer",
    "détourez": "détourer",
    "détouriez": "détourer",
    "détourions": "détourer",
    "détourna": "détourner",
    "détournai": "détourner",
    "détournaient": "détourner",
    "détournais": "détourner",
    "détournait": "détourner",
    "détournant": "détourner",
    "détournas": "détourner",
    "détournasse": "détourner",
    "détournassent": "détourner",
    "détournasses": "détourner",
    "détournassiez": "détourner",
    "détournassions": "détourner",
    "détourne": "détourner",
    "détournements": "détournement",
    "détournent": "détourner",
    "détournera": "détourner",
    "détournerai": "détourner",
    "détourneraient": "détourner",
    "détournerais": "détourner",
    "détournerait": "détourner",
    "détourneras": "détourner",
    "détournerez": "détourner",
    "détourneriez": "détourner",
    "détournerions": "détourner",
    "détournerons": "détourner",
    "détourneront": "détourner",
    "détournes": "détourner",
    "détournez": "détourner",
    "détourniez": "détourner",
    "détournions": "détourner",
    "détournons": "détourner",
    "détournâmes": "détourner",
    "détournât": "détourner",
    "détournâtes": "détourner",
    "détournèrent": "détourner",
    "détourné": "détourner",
    "détournée": "détourner",
    "détournées": "détourner",
    "détournés": "détourner",
    "détourons": "détourer",
    "détours": "détour",
    "détourâmes": "détourer",
    "détourât": "détourer",
    "détourâtes": "détourer",
    "détourèrent": "détourer",
    "détouré": "détourer",
    "détourée": "détourer",
    "détourées": "détourer",
    "détourés": "détourer",
    "détoxications": "détoxication",
    "détoxiqua": "détoxiquer",
    "détoxiquai": "détoxiquer",
    "détoxiquaient": "détoxiquer",
    "détoxiquais": "détoxiquer",
    "détoxiquait": "détoxiquer",
    "détoxiquant": "détoxiquer",
    "détoxiquas": "détoxiquer",
    "détoxiquasse": "détoxiquer",
    "détoxiquassent": "détoxiquer",
    "détoxiquasses": "détoxiquer",
    "détoxiquassiez": "détoxiquer",
    "détoxiquassions": "détoxiquer",
    "détoxique": "détoxiquer",
    "détoxiquent": "détoxiquer",
    "détoxiquera": "détoxiquer",
    "détoxiquerai": "détoxiquer",
    "détoxiqueraient": "détoxiquer",
    "détoxiquerais": "détoxiquer",
    "détoxiquerait": "détoxiquer",
    "détoxiqueras": "détoxiquer",
    "détoxiquerez": "détoxiquer",
    "détoxiqueriez": "détoxiquer",
    "détoxiquerions": "détoxiquer",
    "détoxiquerons": "détoxiquer",
    "détoxiqueront": "détoxiquer",
    "détoxiques": "détoxiquer",
    "détoxiquez": "détoxiquer",
    "détoxiquiez": "détoxiquer",
    "détoxiquions": "détoxiquer",
    "détoxiquons": "détoxiquer",
    "détoxiquâmes": "détoxiquer",
    "détoxiquât": "détoxiquer",
    "détoxiquâtes": "détoxiquer",
    "détoxiquèrent": "détoxiquer",
    "détoxiqué": "détoxiquer",
    "détoxiquée": "détoxiquer",
    "détoxiquées": "détoxiquer",
    "détoxiqués": "détoxiquer",
    "détracteurs": "détracteur",
    "détractrice": "détracteur",
    "détractrices": "détracteur",
    "détrancha": "détrancher",
    "détranchai": "détrancher",
    "détranchaient": "détrancher",
    "détranchais": "détrancher",
    "détranchait": "détrancher",
    "détranchant": "détrancher",
    "détranchas": "détrancher",
    "détranchasse": "détrancher",
    "détranchassent": "détrancher",
    "détranchasses": "détrancher",
    "détranchassiez": "détrancher",
    "détranchassions": "détrancher",
    "détranche": "détrancher",
    "détranchent": "détrancher",
    "détranchera": "détrancher",
    "détrancherai": "détrancher",
    "détrancheraient": "détrancher",
    "détrancherais": "détrancher",
    "détrancherait": "détrancher",
    "détrancheras": "détrancher",
    "détrancherez": "détrancher",
    "détrancheriez": "détrancher",
    "détrancherions": "détrancher",
    "détrancherons": "détrancher",
    "détrancheront": "détrancher",
    "détranches": "détrancher",
    "détranchez": "détrancher",
    "détranchiez": "détrancher",
    "détranchions": "détrancher",
    "détranchons": "détrancher",
    "détranchâmes": "détrancher",
    "détranchât": "détrancher",
    "détranchâtes": "détrancher",
    "détranchèrent": "détrancher",
    "détranché": "détrancher",
    "détranchée": "détrancher",
    "détranchées": "détrancher",
    "détranchés": "détrancher",
    "détraqua": "détraquer",
    "détraquai": "détraquer",
    "détraquaient": "détraquer",
    "détraquais": "détraquer",
    "détraquait": "détraquer",
    "détraquant": "détraquer",
    "détraquas": "détraquer",
    "détraquasse": "détraquer",
    "détraquassent": "détraquer",
    "détraquasses": "détraquer",
    "détraquassiez": "détraquer",
    "détraquassions": "détraquer",
    "détraque": "détraquer",
    "détraquent": "détraquer",
    "détraquera": "détraquer",
    "détraquerai": "détraquer",
    "détraqueraient": "détraquer",
    "détraquerais": "détraquer",
    "détraquerait": "détraquer",
    "détraqueras": "détraquer",
    "détraquerez": "détraquer",
    "détraqueriez": "détraquer",
    "détraquerions": "détraquer",
    "détraquerons": "détraquer",
    "détraqueront": "détraquer",
    "détraques": "détraquer",
    "détraquez": "détraquer",
    "détraquiez": "détraquer",
    "détraquions": "détraquer",
    "détraquons": "détraquer",
    "détraquâmes": "détraquer",
    "détraquât": "détraquer",
    "détraquâtes": "détraquer",
    "détraquèrent": "détraquer",
    "détraqué": "détraquer",
    "détraquée": "détraquer",
    "détraquées": "détraquer",
    "détraqués": "détraquer",
    "détrempa": "détremper",
    "détrempai": "détremper",
    "détrempaient": "détremper",
    "détrempais": "détremper",
    "détrempait": "détremper",
    "détrempant": "détremper",
    "détrempas": "détremper",
    "détrempasse": "détremper",
    "détrempassent": "détremper",
    "détrempasses": "détremper",
    "détrempassiez": "détremper",
    "détrempassions": "détremper",
    "détrempe": "détremper",
    "détrempent": "détremper",
    "détrempera": "détremper",
    "détremperai": "détremper",
    "détremperaient": "détremper",
    "détremperais": "détremper",
    "détremperait": "détremper",
    "détremperas": "détremper",
    "détremperez": "détremper",
    "détremperiez": "détremper",
    "détremperions": "détremper",
    "détremperons": "détremper",
    "détremperont": "détremper",
    "détrempes": "détremper",
    "détrempez": "détremper",
    "détrempiez": "détremper",
    "détrempions": "détremper",
    "détrempons": "détremper",
    "détrempâmes": "détremper",
    "détrempât": "détremper",
    "détrempâtes": "détremper",
    "détrempèrent": "détremper",
    "détrempé": "détremper",
    "détrempée": "détremper",
    "détrempées": "détremper",
    "détrempés": "détremper",
    "détresses": "détresse",
    "détribalisée": "détribaliser",
    "détricota": "détricoter",
    "détricotai": "détricoter",
    "détricotaient": "détricoter",
    "détricotais": "détricoter",
    "détricotait": "détricoter",
    "détricotant": "détricoter",
    "détricotas": "détricoter",
    "détricotasse": "détricoter",
    "détricotassent": "détricoter",
    "détricotasses": "détricoter",
    "détricotassiez": "détricoter",
    "détricotassions": "détricoter",
    "détricote": "détricoter",
    "détricotent": "détricoter",
    "détricotera": "détricoter",
    "détricoterai": "détricoter",
    "détricoteraient": "détricoter",
    "détricoterais": "détricoter",
    "détricoterait": "détricoter",
    "détricoteras": "détricoter",
    "détricoterez": "détricoter",
    "détricoteriez": "détricoter",
    "détricoterions": "détricoter",
    "détricoterons": "détricoter",
    "détricoteront": "détricoter",
    "détricotes": "détricoter",
    "détricotez": "détricoter",
    "détricotiez": "détricoter",
    "détricotions": "détricoter",
    "détricotons": "détricoter",
    "détricotâmes": "détricoter",
    "détricotât": "détricoter",
    "détricotâtes": "détricoter",
    "détricotèrent": "détricoter",
    "détricoté": "détricoter",
    "détricotée": "détricoter",
    "détricotées": "détricoter",
    "détricotés": "détricoter",
    "détriments": "détriment",
    "détritiques": "détritique",
    "détroits": "détroit",
    "détrompa": "détromper",
    "détrompai": "détromper",
    "détrompaient": "détromper",
    "détrompais": "détromper",
    "détrompait": "détromper",
    "détrompant": "détromper",
    "détrompas": "détromper",
    "détrompasse": "détromper",
    "détrompassent": "détromper",
    "détrompasses": "détromper",
    "détrompassiez": "détromper",
    "détrompassions": "détromper",
    "détrompe": "détromper",
    "détrompent": "détromper",
    "détrompera": "détromper",
    "détromperai": "détromper",
    "détromperaient": "détromper",
    "détromperais": "détromper",
    "détromperait": "détromper",
    "détromperas": "détromper",
    "détromperez": "détromper",
    "détromperiez": "détromper",
    "détromperions": "détromper",
    "détromperons": "détromper",
    "détromperont": "détromper",
    "détrompes": "détromper",
    "détrompez": "détromper",
    "détrompiez": "détromper",
    "détrompions": "détromper",
    "détrompons": "détromper",
    "détrompâmes": "détromper",
    "détrompât": "détromper",
    "détrompâtes": "détromper",
    "détrompèrent": "détromper",
    "détrompé": "détromper",
    "détrompée": "détromper",
    "détrompées": "détromper",
    "détrompés": "détromper",
    "détroncha": "détroncher",
    "détronchant": "détroncher",
    "détronche": "détroncher",
    "détronchent": "détroncher",
    "détroncherais": "détroncher",
    "détronchèrent": "détroncher",
    "détronché": "détroncher",
    "détroussa": "détrousser",
    "détroussai": "détrousser",
    "détroussaient": "détrousser",
    "détroussais": "détrousser",
    "détroussait": "détrousser",
    "détroussant": "détrousser",
    "détroussas": "détrousser",
    "détroussasse": "détrousser",
    "détroussassent": "détrousser",
    "détroussasses": "détrousser",
    "détroussassiez": "détrousser",
    "détroussassions": "détrousser",
    "détrousse": "détrousser",
    "détroussent": "détrousser",
    "détroussera": "détrousser",
    "détrousserai": "détrousser",
    "détrousseraient": "détrousser",
    "détrousserais": "détrousser",
    "détrousserait": "détrousser",
    "détrousseras": "détrousser",
    "détrousserez": "détrousser",
    "détrousseriez": "détrousser",
    "détrousserions": "détrousser",
    "détrousserons": "détrousser",
    "détrousseront": "détrousser",
    "détrousses": "détrousser",
    "détrousseurs": "détrousseur",
    "détroussez": "détrousser",
    "détroussiez": "détrousser",
    "détroussions": "détrousser",
    "détroussons": "détrousser",
    "détroussâmes": "détrousser",
    "détroussât": "détrousser",
    "détroussâtes": "détrousser",
    "détroussèrent": "détrousser",
    "détroussé": "détrousser",
    "détroussée": "détrousser",
    "détroussées": "détrousser",
    "détroussés": "détrousser",
    "détruira": "détruire",
    "détruirai": "détruire",
    "détruiraient": "détruire",
    "détruirais": "détruire",
    "détruirait": "détruire",
    "détruiras": "détruire",
    "détruirez": "détruire",
    "détruiriez": "détruire",
    "détruirions": "détruire",
    "détruirons": "détruire",
    "détruiront": "détruire",
    "détruis": "détruire",
    "détruisaient": "détruire",
    "détruisais": "détruire",
    "détruisait": "détruire",
    "détruisant": "détruire",
    "détruise": "détruire",
    "détruisent": "détruire",
    "détruises": "détruire",
    "détruisez": "détruire",
    "détruisiez": "détruire",
    "détruisions": "détruire",
    "détruisirent": "détruire",
    "détruisis": "détruire",
    "détruisisse": "détruire",
    "détruisissent": "détruire",
    "détruisisses": "détruire",
    "détruisissiez": "détruire",
    "détruisissions": "détruire",
    "détruisit": "détruire",
    "détruisons": "détruire",
    "détruisîmes": "détruire",
    "détruisît": "détruire",
    "détruisîtes": "détruire",
    "détruit": "détruire",
    "détruite": "détruire",
    "détruites": "détruire",
    "détruits": "détruire",
    "détrôna": "détrôner",
    "détrônai": "détrôner",
    "détrônaient": "détrôner",
    "détrônais": "détrôner",
    "détrônait": "détrôner",
    "détrônant": "détrôner",
    "détrônas": "détrôner",
    "détrônasse": "détrôner",
    "détrônassent": "détrôner",
    "détrônasses": "détrôner",
    "détrônassiez": "détrôner",
    "détrônassions": "détrôner",
    "détrône": "détrôner",
    "détrônent": "détrôner",
    "détrônera": "détrôner",
    "détrônerai": "détrôner",
    "détrôneraient": "détrôner",
    "détrônerais": "détrôner",
    "détrônerait": "détrôner",
    "détrôneras": "détrôner",
    "détrônerez": "détrôner",
    "détrôneriez": "détrôner",
    "détrônerions": "détrôner",
    "détrônerons": "détrôner",
    "détrôneront": "détrôner",
    "détrônes": "détrôner",
    "détrônez": "détrôner",
    "détrôniez": "détrôner",
    "détrônions": "détrôner",
    "détrônons": "détrôner",
    "détrônâmes": "détrôner",
    "détrônât": "détrôner",
    "détrônâtes": "détrôner",
    "détrônèrent": "détrôner",
    "détrôné": "détrôner",
    "détrônée": "détrôner",
    "détrônées": "détrôner",
    "détrônés": "détrôner",
    "détériora": "détériorer",
    "détériorai": "détériorer",
    "détérioraient": "détériorer",
    "détériorais": "détériorer",
    "détériorait": "détériorer",
    "détériorant": "détériorer",
    "détérioras": "détériorer",
    "détériorasse": "détériorer",
    "détériorassent": "détériorer",
    "détériorasses": "détériorer",
    "détériorassiez": "détériorer",
    "détériorassions": "détériorer",
    "détériorations": "détérioration",
    "détériore": "détériorer",
    "détériorent": "détériorer",
    "détériorera": "détériorer",
    "détériorerai": "détériorer",
    "détérioreraient": "détériorer",
    "détériorerais": "détériorer",
    "détériorerait": "détériorer",
    "détérioreras": "détériorer",
    "détériorerez": "détériorer",
    "détérioreriez": "détériorer",
    "détériorerions": "détériorer",
    "détériorerons": "détériorer",
    "détérioreront": "détériorer",
    "détériores": "détériorer",
    "détériorez": "détériorer",
    "détérioriez": "détériorer",
    "détériorions": "détériorer",
    "détériorons": "détériorer",
    "détériorâmes": "détériorer",
    "détériorât": "détériorer",
    "détériorâtes": "détériorer",
    "détériorèrent": "détériorer",
    "détérioré": "détériorer",
    "détériorée": "détériorer",
    "détériorées": "détériorer",
    "détériorés": "détériorer",
    "détînmes": "détenir",
    "détînt": "détenir",
    "détîntes": "détenir",
    "dévala": "dévaler",
    "dévalai": "dévaler",
    "dévalaient": "dévaler",
    "dévalais": "dévaler",
    "dévalait": "dévaler",
    "dévalant": "dévaler",
    "dévalas": "dévaler",
    "dévalasse": "dévaler",
    "dévalassent": "dévaler",
    "dévalasses": "dévaler",
    "dévalassiez": "dévaler",
    "dévalassions": "dévaler",
    "dévale": "dévaler",
    "dévalements": "dévalement",
    "dévalent": "dévaler",
    "dévalera": "dévaler",
    "dévalerai": "dévaler",
    "dévaleraient": "dévaler",
    "dévalerais": "dévaler",
    "dévalerait": "dévaler",
    "dévaleras": "dévaler",
    "dévalerez": "dévaler",
    "dévaleriez": "dévaler",
    "dévalerions": "dévaler",
    "dévalerons": "dévaler",
    "dévaleront": "dévaler",
    "dévales": "dévaler",
    "dévalez": "dévaler",
    "dévaliez": "dévaler",
    "dévalions": "dévaler",
    "dévalisa": "dévaliser",
    "dévalisai": "dévaliser",
    "dévalisaient": "dévaliser",
    "dévalisais": "dévaliser",
    "dévalisait": "dévaliser",
    "dévalisant": "dévaliser",
    "dévalisas": "dévaliser",
    "dévalisasse": "dévaliser",
    "dévalisassent": "dévaliser",
    "dévalisasses": "dévaliser",
    "dévalisassiez": "dévaliser",
    "dévalisassions": "dévaliser",
    "dévalise": "dévaliser",
    "dévalisent": "dévaliser",
    "dévalisera": "dévaliser",
    "dévaliserai": "dévaliser",
    "dévaliseraient": "dévaliser",
    "dévaliserais": "dévaliser",
    "dévaliserait": "dévaliser",
    "dévaliseras": "dévaliser",
    "dévaliserez": "dévaliser",
    "dévaliseriez": "dévaliser",
    "dévaliserions": "dévaliser",
    "dévaliserons": "dévaliser",
    "dévaliseront": "dévaliser",
    "dévalises": "dévaliser",
    "dévalisez": "dévaliser",
    "dévalisiez": "dévaliser",
    "dévalisions": "dévaliser",
    "dévalisons": "dévaliser",
    "dévalisâmes": "dévaliser",
    "dévalisât": "dévaliser",
    "dévalisâtes": "dévaliser",
    "dévalisèrent": "dévaliser",
    "dévalisé": "dévaliser",
    "dévalisée": "dévaliser",
    "dévalisées": "dévaliser",
    "dévalisés": "dévaliser",
    "dévalons": "dévaler",
    "dévalorisa": "dévaloriser",
    "dévalorisai": "dévaloriser",
    "dévalorisaient": "dévaloriser",
    "dévalorisais": "dévaloriser",
    "dévalorisait": "dévaloriser",
    "dévalorisant": "dévaloriser",
    "dévalorisas": "dévaloriser",
    "dévalorisasse": "dévaloriser",
    "dévalorisassent": "dévaloriser",
    "dévalorisasses": "dévaloriser",
    "dévalorisassiez": "dévaloriser",
    "dévalorisassions": "dévaloriser",
    "dévalorisations": "dévalorisation",
    "dévalorise": "dévaloriser",
    "dévalorisent": "dévaloriser",
    "dévalorisera": "dévaloriser",
    "dévaloriserai": "dévaloriser",
    "dévaloriseraient": "dévaloriser",
    "dévaloriserais": "dévaloriser",
    "dévaloriserait": "dévaloriser",
    "dévaloriseras": "dévaloriser",
    "dévaloriserez": "dévaloriser",
    "dévaloriseriez": "dévaloriser",
    "dévaloriserions": "dévaloriser",
    "dévaloriserons": "dévaloriser",
    "dévaloriseront": "dévaloriser",
    "dévalorises": "dévaloriser",
    "dévalorisez": "dévaloriser",
    "dévalorisiez": "dévaloriser",
    "dévalorisions": "dévaloriser",
    "dévalorisons": "dévaloriser",
    "dévalorisâmes": "dévaloriser",
    "dévalorisât": "dévaloriser",
    "dévalorisâtes": "dévaloriser",
    "dévalorisèrent": "dévaloriser",
    "dévalorisé": "dévaloriser",
    "dévalorisée": "dévaloriser",
    "dévalorisées": "dévaloriser",
    "dévalorisés": "dévaloriser",
    "dévalua": "dévaluer",
    "dévaluai": "dévaluer",
    "dévaluaient": "dévaluer",
    "dévaluais": "dévaluer",
    "dévaluait": "dévaluer",
    "dévaluant": "dévaluer",
    "dévaluas": "dévaluer",
    "dévaluasse": "dévaluer",
    "dévaluassent": "dévaluer",
    "dévaluasses": "dévaluer",
    "dévaluassiez": "dévaluer",
    "dévaluassions": "dévaluer",
    "dévaluations": "dévaluation",
    "dévalue": "dévaluer",
    "dévaluent": "dévaluer",
    "dévaluera": "dévaluer",
    "dévaluerai": "dévaluer",
    "dévalueraient": "dévaluer",
    "dévaluerais": "dévaluer",
    "dévaluerait": "dévaluer",
    "dévalueras": "dévaluer",
    "dévaluerez": "dévaluer",
    "dévalueriez": "dévaluer",
    "dévaluerions": "dévaluer",
    "dévaluerons": "dévaluer",
    "dévalueront": "dévaluer",
    "dévalues": "dévaluer",
    "dévaluez": "dévaluer",
    "dévaluiez": "dévaluer",
    "dévaluions": "dévaluer",
    "dévaluons": "dévaluer",
    "dévaluâmes": "dévaluer",
    "dévaluât": "dévaluer",
    "dévaluâtes": "dévaluer",
    "dévaluèrent": "dévaluer",
    "dévalué": "dévaluer",
    "dévaluée": "dévaluer",
    "dévaluées": "dévaluer",
    "dévalués": "dévaluer",
    "dévalâmes": "dévaler",
    "dévalât": "dévaler",
    "dévalâtes": "dévaler",
    "dévalèrent": "dévaler",
    "dévalé": "dévaler",
    "dévalée": "dévaler",
    "dévalées": "dévaler",
    "dévalés": "dévaler",
    "dévasta": "dévaster",
    "dévastai": "dévaster",
    "dévastaient": "dévaster",
    "dévastais": "dévaster",
    "dévastait": "dévaster",
    "dévastant": "dévaster",
    "dévastas": "dévaster",
    "dévastasse": "dévaster",
    "dévastassent": "dévaster",
    "dévastasses": "dévaster",
    "dévastassiez": "dévaster",
    "dévastassions": "dévaster",
    "dévastateurs": "dévastateur",
    "dévastations": "dévastation",
    "dévastatrice": "dévastateur",
    "dévastatrices": "dévastateur",
    "dévaste": "dévaster",
    "dévastent": "dévaster",
    "dévastera": "dévaster",
    "dévasterai": "dévaster",
    "dévasteraient": "dévaster",
    "dévasterais": "dévaster",
    "dévasterait": "dévaster",
    "dévasteras": "dévaster",
    "dévasterez": "dévaster",
    "dévasteriez": "dévaster",
    "dévasterions": "dévaster",
    "dévasterons": "dévaster",
    "dévasteront": "dévaster",
    "dévastes": "dévaster",
    "dévastez": "dévaster",
    "dévastiez": "dévaster",
    "dévastions": "dévaster",
    "dévastons": "dévaster",
    "dévastâmes": "dévaster",
    "dévastât": "dévaster",
    "dévastâtes": "dévaster",
    "dévastèrent": "dévaster",
    "dévasté": "dévaster",
    "dévastée": "dévaster",
    "dévastées": "dévaster",
    "dévastés": "dévaster",
    "déveinards": "déveinard",
    "déveines": "déveine",
    "développa": "développer",
    "développai": "développer",
    "développaient": "développer",
    "développais": "développer",
    "développait": "développer",
    "développant": "développer",
    "développas": "développer",
    "développasse": "développer",
    "développassent": "développer",
    "développasses": "développer",
    "développassiez": "développer",
    "développassions": "développer",
    "développe": "développer",
    "développements": "développement",
    "développent": "développer",
    "développera": "développer",
    "développerai": "développer",
    "développeraient": "développer",
    "développerais": "développer",
    "développerait": "développer",
    "développeras": "développer",
    "développerez": "développer",
    "développeriez": "développer",
    "développerions": "développer",
    "développerons": "développer",
    "développeront": "développer",
    "développes": "développer",
    "développez": "développer",
    "développiez": "développer",
    "développions": "développer",
    "développons": "développer",
    "développâmes": "développer",
    "développât": "développer",
    "développâtes": "développer",
    "développèrent": "développer",
    "développé": "développer",
    "développée": "développer",
    "développées": "développer",
    "développés": "développer",
    "déverbale": "déverbal",
    "déverbales": "déverbal",
    "déverbaux": "déverbal",
    "déverdi": "déverdir",
    "déverdie": "déverdir",
    "déverdies": "déverdir",
    "déverdira": "déverdir",
    "déverdirai": "déverdir",
    "déverdiraient": "déverdir",
    "déverdirais": "déverdir",
    "déverdirait": "déverdir",
    "déverdiras": "déverdir",
    "déverdirent": "déverdir",
    "déverdirez": "déverdir",
    "déverdiriez": "déverdir",
    "déverdirions": "déverdir",
    "déverdirons": "déverdir",
    "déverdiront": "déverdir",
    "déverdis": "déverdir",
    "déverdissaient": "déverdir",
    "déverdissais": "déverdir",
    "déverdissait": "déverdir",
    "déverdissant": "déverdir",
    "déverdisse": "déverdir",
    "déverdissent": "déverdir",
    "déverdisses": "déverdir",
    "déverdissez": "déverdir",
    "déverdissiez": "déverdir",
    "déverdissions": "déverdir",
    "déverdissons": "déverdir",
    "déverdit": "déverdir",
    "déverdîmes": "déverdir",
    "déverdît": "déverdir",
    "déverdîtes": "déverdir",
    "dévergonda": "dévergonder",
    "dévergondages": "dévergondage",
    "dévergondai": "dévergonder",
    "dévergondaient": "dévergonder",
    "dévergondais": "dévergonder",
    "dévergondait": "dévergonder",
    "dévergondant": "dévergonder",
    "dévergondas": "dévergonder",
    "dévergondasse": "dévergonder",
    "dévergondassent": "dévergonder",
    "dévergondasses": "dévergonder",
    "dévergondassiez": "dévergonder",
    "dévergondassions": "dévergonder",
    "dévergonde": "dévergonder",
    "dévergondent": "dévergonder",
    "dévergondera": "dévergonder",
    "dévergonderai": "dévergonder",
    "dévergonderaient": "dévergonder",
    "dévergonderais": "dévergonder",
    "dévergonderait": "dévergonder",
    "dévergonderas": "dévergonder",
    "dévergonderez": "dévergonder",
    "dévergonderiez": "dévergonder",
    "dévergonderions": "dévergonder",
    "dévergonderons": "dévergonder",
    "dévergonderont": "dévergonder",
    "dévergondes": "dévergonder",
    "dévergondez": "dévergonder",
    "dévergondiez": "dévergonder",
    "dévergondions": "dévergonder",
    "dévergondons": "dévergonder",
    "dévergondâmes": "dévergonder",
    "dévergondât": "dévergonder",
    "dévergondâtes": "dévergonder",
    "dévergondèrent": "dévergonder",
    "dévergondé": "dévergonder",
    "dévergondée": "dévergonder",
    "dévergondées": "dévergonder",
    "dévergondés": "dévergonder",
    "déverni": "dévernir",
    "dévernie": "dévernir",
    "dévernies": "dévernir",
    "dévernira": "dévernir",
    "dévernirai": "dévernir",
    "déverniraient": "dévernir",
    "dévernirais": "dévernir",
    "dévernirait": "dévernir",
    "déverniras": "dévernir",
    "dévernirent": "dévernir",
    "dévernirez": "dévernir",
    "déverniriez": "dévernir",
    "dévernirions": "dévernir",
    "dévernirons": "dévernir",
    "déverniront": "dévernir",
    "dévernis": "dévernir",
    "dévernissaient": "dévernir",
    "dévernissais": "dévernir",
    "dévernissait": "dévernir",
    "dévernissant": "dévernir",
    "dévernisse": "dévernir",
    "dévernissent": "dévernir",
    "dévernisses": "dévernir",
    "dévernissez": "dévernir",
    "dévernissiez": "dévernir",
    "dévernissions": "dévernir",
    "dévernissons": "dévernir",
    "dévernit": "dévernir",
    "dévernîmes": "dévernir",
    "dévernît": "dévernir",
    "dévernîtes": "dévernir",
    "déverrouilla": "déverrouiller",
    "déverrouillai": "déverrouiller",
    "déverrouillaient": "déverrouiller",
    "déverrouillais": "déverrouiller",
    "déverrouillait": "déverrouiller",
    "déverrouillant": "déverrouiller",
    "déverrouillas": "déverrouiller",
    "déverrouillasse": "déverrouiller",
    "déverrouillassent": "déverrouiller",
    "déverrouillasses": "déverrouiller",
    "déverrouillassiez": "déverrouiller",
    "déverrouillassions": "déverrouiller",
    "déverrouille": "déverrouiller",
    "déverrouillent": "déverrouiller",
    "déverrouillera": "déverrouiller",
    "déverrouillerai": "déverrouiller",
    "déverrouilleraient": "déverrouiller",
    "déverrouillerais": "déverrouiller",
    "déverrouillerait": "déverrouiller",
    "déverrouilleras": "déverrouiller",
    "déverrouillerez": "déverrouiller",
    "déverrouilleriez": "déverrouiller",
    "déverrouillerions": "déverrouiller",
    "déverrouillerons": "déverrouiller",
    "déverrouilleront": "déverrouiller",
    "déverrouilles": "déverrouiller",
    "déverrouillez": "déverrouiller",
    "déverrouilliez": "déverrouiller",
    "déverrouillions": "déverrouiller",
    "déverrouillons": "déverrouiller",
    "déverrouillâmes": "déverrouiller",
    "déverrouillât": "déverrouiller",
    "déverrouillâtes": "déverrouiller",
    "déverrouillèrent": "déverrouiller",
    "déverrouillé": "déverrouiller",
    "déverrouillée": "déverrouiller",
    "déverrouillées": "déverrouiller",
    "déverrouillés": "déverrouiller",
    "déversa": "déverser",
    "déversai": "déverser",
    "déversaient": "déverser",
    "déversais": "déverser",
    "déversait": "déverser",
    "déversant": "déverser",
    "déversas": "déverser",
    "déversasse": "déverser",
    "déversassent": "déverser",
    "déversasses": "déverser",
    "déversassiez": "déverser",
    "déversassions": "déverser",
    "déverse": "déverser",
    "déversements": "déversement",
    "déversent": "déverser",
    "déversera": "déverser",
    "déverserai": "déverser",
    "déverseraient": "déverser",
    "déverserais": "déverser",
    "déverserait": "déverser",
    "déverseras": "déverser",
    "déverserez": "déverser",
    "déverseriez": "déverser",
    "déverserions": "déverser",
    "déverserons": "déverser",
    "déverseront": "déverser",
    "déverses": "déverser",
    "déversez": "déverser",
    "déversiez": "déverser",
    "déversions": "déverser",
    "déversons": "déverser",
    "déversâmes": "déverser",
    "déversât": "déverser",
    "déversâtes": "déverser",
    "déversèrent": "déverser",
    "déversé": "déverser",
    "déversée": "déverser",
    "déversées": "déverser",
    "déversés": "déverser",
    "dévia": "dévier",
    "déviai": "dévier",
    "déviaient": "dévier",
    "déviais": "dévier",
    "déviait": "dévier",
    "déviances": "déviance",
    "déviant": "dévier",
    "déviante": "déviant",
    "déviants": "déviant",
    "dévias": "dévier",
    "déviasse": "dévier",
    "déviassent": "dévier",
    "déviasses": "dévier",
    "déviassiez": "dévier",
    "déviassions": "dévier",
    "déviationnismes": "déviationnisme",
    "déviations": "déviation",
    "dévida": "dévider",
    "dévidai": "dévider",
    "dévidaient": "dévider",
    "dévidais": "dévider",
    "dévidait": "dévider",
    "dévidant": "dévider",
    "dévidas": "dévider",
    "dévidasse": "dévider",
    "dévidassent": "dévider",
    "dévidasses": "dévider",
    "dévidassiez": "dévider",
    "dévidassions": "dévider",
    "dévide": "dévider",
    "dévident": "dévider",
    "dévidera": "dévider",
    "déviderai": "dévider",
    "dévideraient": "dévider",
    "déviderais": "dévider",
    "déviderait": "dévider",
    "dévideras": "dévider",
    "déviderez": "dévider",
    "dévideriez": "dévider",
    "déviderions": "dévider",
    "déviderons": "dévider",
    "dévideront": "dévider",
    "dévides": "dévider",
    "dévidez": "dévider",
    "dévidiez": "dévider",
    "dévidions": "dévider",
    "dévidoirs": "dévidoir",
    "dévidons": "dévider",
    "dévidâmes": "dévider",
    "dévidât": "dévider",
    "dévidâtes": "dévider",
    "dévidèrent": "dévider",
    "dévidé": "dévider",
    "dévidée": "dévider",
    "dévidées": "dévider",
    "dévidés": "dévider",
    "dévie": "dévier",
    "dévient": "dévier",
    "déviera": "dévier",
    "dévierai": "dévier",
    "dévieraient": "dévier",
    "dévierais": "dévier",
    "dévierait": "dévier",
    "dévieras": "dévier",
    "dévierez": "dévier",
    "dévieriez": "dévier",
    "dévierions": "dévier",
    "dévierons": "dévier",
    "dévieront": "dévier",
    "dévies": "dévier",
    "déviez": "dévier",
    "déviiez": "dévier",
    "déviions": "dévier",
    "dévions": "dévier",
    "dévirginisée": "dévirginiser",
    "dévirilisant": "déviriliser",
    "dévirilisé": "déviriliser",
    "dévisage": "dévisager",
    "dévisagea": "dévisager",
    "dévisageai": "dévisager",
    "dévisageaient": "dévisager",
    "dévisageais": "dévisager",
    "dévisageait": "dévisager",
    "dévisageant": "dévisager",
    "dévisageas": "dévisager",
    "dévisageasse": "dévisager",
    "dévisageassent": "dévisager",
    "dévisageasses": "dévisager",
    "dévisageassiez": "dévisager",
    "dévisageassions": "dévisager",
    "dévisagent": "dévisager",
    "dévisageons": "dévisager",
    "dévisagera": "dévisager",
    "dévisagerai": "dévisager",
    "dévisageraient": "dévisager",
    "dévisagerais": "dévisager",
    "dévisagerait": "dévisager",
    "dévisageras": "dévisager",
    "dévisagerez": "dévisager",
    "dévisageriez": "dévisager",
    "dévisagerions": "dévisager",
    "dévisagerons": "dévisager",
    "dévisageront": "dévisager",
    "dévisages": "dévisager",
    "dévisagez": "dévisager",
    "dévisageâmes": "dévisager",
    "dévisageât": "dévisager",
    "dévisageâtes": "dévisager",
    "dévisagiez": "dévisager",
    "dévisagions": "dévisager",
    "dévisagèrent": "dévisager",
    "dévisagé": "dévisager",
    "dévisagée": "dévisager",
    "dévisagées": "dévisager",
    "dévisagés": "dévisager",
    "dévissa": "dévisser",
    "dévissages": "dévissage",
    "dévissai": "dévisser",
    "dévissaient": "dévisser",
    "dévissais": "dévisser",
    "dévissait": "dévisser",
    "dévissant": "dévisser",
    "dévissas": "dévisser",
    "dévissasse": "dévisser",
    "dévissassent": "dévisser",
    "dévissasses": "dévisser",
    "dévissassiez": "dévisser",
    "dévissassions": "dévisser",
    "dévisse": "dévisser",
    "dévissent": "dévisser",
    "dévissera": "dévisser",
    "dévisserai": "dévisser",
    "dévisseraient": "dévisser",
    "dévisserais": "dévisser",
    "dévisserait": "dévisser",
    "dévisseras": "dévisser",
    "dévisserez": "dévisser",
    "dévisseriez": "dévisser",
    "dévisserions": "dévisser",
    "dévisserons": "dévisser",
    "dévisseront": "dévisser",
    "dévisses": "dévisser",
    "dévissez": "dévisser",
    "dévissiez": "dévisser",
    "dévissions": "dévisser",
    "dévissons": "dévisser",
    "dévissâmes": "dévisser",
    "dévissât": "dévisser",
    "dévissâtes": "dévisser",
    "dévissèrent": "dévisser",
    "dévissé": "dévisser",
    "dévissée": "dévisser",
    "dévissées": "dévisser",
    "dévissés": "dévisser",
    "dévitalisa": "dévitaliser",
    "dévitalisai": "dévitaliser",
    "dévitalisaient": "dévitaliser",
    "dévitalisais": "dévitaliser",
    "dévitalisait": "dévitaliser",
    "dévitalisant": "dévitaliser",
    "dévitalisas": "dévitaliser",
    "dévitalisasse": "dévitaliser",
    "dévitalisassent": "dévitaliser",
    "dévitalisasses": "dévitaliser",
    "dévitalisassiez": "dévitaliser",
    "dévitalisassions": "dévitaliser",
    "dévitalise": "dévitaliser",
    "dévitalisent": "dévitaliser",
    "dévitalisera": "dévitaliser",
    "dévitaliserai": "dévitaliser",
    "dévitaliseraient": "dévitaliser",
    "dévitaliserais": "dévitaliser",
    "dévitaliserait": "dévitaliser",
    "dévitaliseras": "dévitaliser",
    "dévitaliserez": "dévitaliser",
    "dévitaliseriez": "dévitaliser",
    "dévitaliserions": "dévitaliser",
    "dévitaliserons": "dévitaliser",
    "dévitaliseront": "dévitaliser",
    "dévitalises": "dévitaliser",
    "dévitalisez": "dévitaliser",
    "dévitalisiez": "dévitaliser",
    "dévitalisions": "dévitaliser",
    "dévitalisons": "dévitaliser",
    "dévitalisâmes": "dévitaliser",
    "dévitalisât": "dévitaliser",
    "dévitalisâtes": "dévitaliser",
    "dévitalisèrent": "dévitaliser",
    "dévitalisé": "dévitaliser",
    "dévitalisée": "dévitaliser",
    "dévitalisées": "dévitaliser",
    "dévitalisés": "dévitaliser",
    "déviâmes": "dévier",
    "déviât": "dévier",
    "déviâtes": "dévier",
    "dévièrent": "dévier",
    "dévié": "dévier",
    "déviée": "dévier",
    "déviées": "dévier",
    "déviés": "dévier",
    "dévoie": "dévoyer",
    "dévoient": "dévoyer",
    "dévoiera": "dévoyer",
    "dévoierai": "dévoyer",
    "dévoieraient": "dévoyer",
    "dévoierais": "dévoyer",
    "dévoierait": "dévoyer",
    "dévoieras": "dévoyer",
    "dévoierez": "dévoyer",
    "dévoieriez": "dévoyer",
    "dévoierions": "dévoyer",
    "dévoierons": "dévoyer",
    "dévoieront": "dévoyer",
    "dévoies": "dévoyer",
    "dévoila": "dévoiler",
    "dévoilai": "dévoiler",
    "dévoilaient": "dévoiler",
    "dévoilais": "dévoiler",
    "dévoilait": "dévoiler",
    "dévoilant": "dévoiler",
    "dévoilas": "dévoiler",
    "dévoilasse": "dévoiler",
    "dévoilassent": "dévoiler",
    "dévoilasses": "dévoiler",
    "dévoilassiez": "dévoiler",
    "dévoilassions": "dévoiler",
    "dévoile": "dévoiler",
    "dévoilements": "dévoilement",
    "dévoilent": "dévoiler",
    "dévoilera": "dévoiler",
    "dévoilerai": "dévoiler",
    "dévoileraient": "dévoiler",
    "dévoilerais": "dévoiler",
    "dévoilerait": "dévoiler",
    "dévoileras": "dévoiler",
    "dévoilerez": "dévoiler",
    "dévoileriez": "dévoiler",
    "dévoilerions": "dévoiler",
    "dévoilerons": "dévoiler",
    "dévoileront": "dévoiler",
    "dévoiles": "dévoiler",
    "dévoilez": "dévoiler",
    "dévoiliez": "dévoiler",
    "dévoilions": "dévoiler",
    "dévoilons": "dévoiler",
    "dévoilâmes": "dévoiler",
    "dévoilât": "dévoiler",
    "dévoilâtes": "dévoiler",
    "dévoilèrent": "dévoiler",
    "dévoilé": "dévoiler",
    "dévoilée": "dévoiler",
    "dévoilées": "dévoiler",
    "dévoilés": "dévoiler",
    "dévoloppements": "dévoloppement",
    "dévolue": "dévolu",
    "dévolues": "dévolu",
    "dévolus": "dévolu",
    "dévonienne": "dévonien",
    "dévora": "dévorer",
    "dévorai": "dévorer",
    "dévoraient": "dévorer",
    "dévorais": "dévorer",
    "dévorait": "dévorer",
    "dévorant": "dévorer",
    "dévorante": "dévorant",
    "dévorantes": "dévorant",
    "dévorants": "dévorant",
    "dévoras": "dévorer",
    "dévorasse": "dévorer",
    "dévorassent": "dévorer",
    "dévorasses": "dévorer",
    "dévorassiez": "dévorer",
    "dévorassions": "dévorer",
    "dévorateurs": "dévorateur",
    "dévoratrice": "dévorateur",
    "dévore": "dévorer",
    "dévorent": "dévorer",
    "dévorera": "dévorer",
    "dévorerai": "dévorer",
    "dévoreraient": "dévorer",
    "dévorerais": "dévorer",
    "dévorerait": "dévorer",
    "dévoreras": "dévorer",
    "dévorerez": "dévorer",
    "dévoreriez": "dévorer",
    "dévorerions": "dévorer",
    "dévorerons": "dévorer",
    "dévoreront": "dévorer",
    "dévores": "dévorer",
    "dévoreurs": "dévoreur",
    "dévoreuse": "dévoreur",
    "dévoreuses": "dévoreur",
    "dévorez": "dévorer",
    "dévoriez": "dévorer",
    "dévorions": "dévorer",
    "dévorons": "dévorer",
    "dévorâmes": "dévorer",
    "dévorât": "dévorer",
    "dévorâtes": "dévorer",
    "dévorèrent": "dévorer",
    "dévoré": "dévorer",
    "dévorée": "dévorer",
    "dévorées": "dévorer",
    "dévorés": "dévorer",
    "dévote": "dévot",
    "dévotes": "dévot",
    "dévotionnelle": "dévotionnel",
    "dévotions": "dévotion",
    "dévots": "dévot",
    "dévoua": "dévouer",
    "dévouai": "dévouer",
    "dévouaient": "dévouer",
    "dévouais": "dévouer",
    "dévouait": "dévouer",
    "dévouant": "dévouer",
    "dévouas": "dévouer",
    "dévouasse": "dévouer",
    "dévouassent": "dévouer",
    "dévouasses": "dévouer",
    "dévouassiez": "dévouer",
    "dévouassions": "dévouer",
    "dévoue": "dévouer",
    "dévouements": "dévouement",
    "dévouent": "dévouer",
    "dévouera": "dévouer",
    "dévouerai": "dévouer",
    "dévoueraient": "dévouer",
    "dévouerais": "dévouer",
    "dévouerait": "dévouer",
    "dévoueras": "dévouer",
    "dévouerez": "dévouer",
    "dévoueriez": "dévouer",
    "dévouerions": "dévouer",
    "dévouerons": "dévouer",
    "dévoueront": "dévouer",
    "dévoues": "dévouer",
    "dévouez": "dévouer",
    "dévouiez": "dévouer",
    "dévouions": "dévouer",
    "dévouons": "dévouer",
    "dévouâmes": "dévouer",
    "dévouât": "dévouer",
    "dévouâtes": "dévouer",
    "dévouèrent": "dévouer",
    "dévoué": "dévouer",
    "dévouée": "dévouer",
    "dévouées": "dévouer",
    "dévoués": "dévouer",
    "dévoya": "dévoyer",
    "dévoyai": "dévoyer",
    "dévoyaient": "dévoyer",
    "dévoyais": "dévoyer",
    "dévoyait": "dévoyer",
    "dévoyant": "dévoyer",
    "dévoyas": "dévoyer",
    "dévoyasse": "dévoyer",
    "dévoyassent": "dévoyer",
    "dévoyasses": "dévoyer",
    "dévoyassiez": "dévoyer",
    "dévoyassions": "dévoyer",
    "dévoyez": "dévoyer",
    "dévoyiez": "dévoyer",
    "dévoyions": "dévoyer",
    "dévoyons": "dévoyer",
    "dévoyâmes": "dévoyer",
    "dévoyât": "dévoyer",
    "dévoyâtes": "dévoyer",
    "dévoyèrent": "dévoyer",
    "dévoyé": "dévoyer",
    "dévoyée": "dévoyer",
    "dévoyées": "dévoyer",
    "dévoyés": "dévoyer",
    "dévêt": "dévêtir",
    "dévêtaient": "dévêtir",
    "dévêtais": "dévêtir",
    "dévêtait": "dévêtir",
    "dévêtant": "dévêtir",
    "dévête": "dévêtir",
    "dévêtent": "dévêtir",
    "dévêtes": "dévêtir",
    "dévêtez": "dévêtir",
    "dévêtiez": "dévêtir",
    "dévêtions": "dévêtir",
    "dévêtira": "dévêtir",
    "dévêtirai": "dévêtir",
    "dévêtiraient": "dévêtir",
    "dévêtirais": "dévêtir",
    "dévêtirait": "dévêtir",
    "dévêtiras": "dévêtir",
    "dévêtirent": "dévêtir",
    "dévêtirez": "dévêtir",
    "dévêtiriez": "dévêtir",
    "dévêtirions": "dévêtir",
    "dévêtirons": "dévêtir",
    "dévêtiront": "dévêtir",
    "dévêtis": "dévêtir",
    "dévêtisse": "dévêtir",
    "dévêtissent": "dévêtir",
    "dévêtisses": "dévêtir",
    "dévêtissiez": "dévêtir",
    "dévêtissions": "dévêtir",
    "dévêtit": "dévêtir",
    "dévêtons": "dévêtir",
    "dévêts": "dévêtir",
    "dévêtu": "dévêtir",
    "dévêtue": "dévêtir",
    "dévêtues": "dévêtir",
    "dévêtus": "dévêtir",
    "dévêtîmes": "dévêtir",
    "dévêtît": "dévêtir",
    "dévêtîtes": "dévêtir",
    "dézingue": "dézinguer",
    "dézingués": "dézinguer",
    "déçois": "décevoir",
    "déçoit": "décevoir",
    "déçoive": "décevoir",
    "déçoivent": "décevoir",
    "déçoives": "décevoir",
    "déçu": "décevoir",
    "déçue": "déçu",
    "déçues": "déçu",
    "déçurent": "décevoir",
    "déçus": "déçu",
    "déçusse": "décevoir",
    "déçussent": "décevoir",
    "déçusses": "décevoir",
    "déçussiez": "décevoir",
    "déçussions": "décevoir",
    "déçut": "décevoir",
    "déçûmes": "décevoir",
    "déçût": "décevoir",
    "déçûtes": "décevoir",
    "dîmes": "dire",
    "dîna": "dîner",
    "dînai": "dîner",
    "dînaient": "dîner",
    "dînais": "dîner",
    "dînait": "dîner",
    "dînant": "dîner",
    "dînas": "dîner",
    "dînasse": "dîner",
    "dînassent": "dîner",
    "dînasses": "dîner",
    "dînassiez": "dîner",
    "dînassions": "dîner",
    "dînatoires": "dînatoire",
    "dîne": "dîner",
    "dînent": "dîner",
    "dînera": "dîner",
    "dînerai": "dîner",
    "dîneraient": "dîner",
    "dînerais": "dîner",
    "dînerait": "dîner",
    "dîneras": "dîner",
    "dînerez": "dîner",
    "dîneriez": "dîner",
    "dînerions": "dîner",
    "dînerons": "dîner",
    "dîneront": "dîner",
    "dîners": "dîner",
    "dînes": "dîner",
    "dînettes": "dînette",
    "dîneurs": "dîneur",
    "dîneuse": "dîneur",
    "dînez": "dîner",
    "dîniez": "dîner",
    "dînions": "dîner",
    "dînons": "dîner",
    "dînâmes": "dîner",
    "dînât": "dîner",
    "dînâtes": "dîner",
    "dînèrent": "dîner",
    "dîné": "dîner",
    "dît": "dire",
    "dîtes": "dire",
    "dômes": "dôme",
    "dôngs": "dông",
    "dû": "devoir",
    "dûmes": "devoir",
    "dût": "devoir",
    "dûtes": "devoir",
    "e": "7e",
    "e-mails": "e-mail",
    "eaux": "eau",
    "eaux-de-vie": "eau-de-vie",
    "eaux-fortes": "eau-forte",
    "ecchymoses": "ecchymose",
    "ecchymosé": "ecchymoser",
    "ecchymosée": "ecchymosé",
    "ecclésiale": "ecclésial",
    "ecclésiastiques": "ecclésiastique",
    "echancrures": "echancrure",
    "ectoplasmes": "ectoplasme",
    "ectoplasmiques": "ectoplasmique",
    "ectropions": "ectropion",
    "eczémas": "eczéma",
    "eczémateuse": "eczémateux",
    "eczémateuses": "eczémateux",
    "edwardienne": "edwardien",
    "efface": "effacer",
    "effacements": "effacement",
    "effacent": "effacer",
    "effacera": "effacer",
    "effacerai": "effacer",
    "effaceraient": "effacer",
    "effacerais": "effacer",
    "effacerait": "effacer",
    "effaceras": "effacer",
    "effacerez": "effacer",
    "effaceriez": "effacer",
    "effacerions": "effacer",
    "effacerons": "effacer",
    "effaceront": "effacer",
    "effaces": "effacer",
    "effacez": "effacer",
    "effaciez": "effacer",
    "effacions": "effacer",
    "effacèrent": "effacer",
    "effacé": "effacer",
    "effacée": "effacer",
    "effacées": "effacer",
    "effacés": "effacer",
    "effara": "effarer",
    "effarai": "effarer",
    "effaraient": "effarer",
    "effarais": "effarer",
    "effarait": "effarer",
    "effarant": "effarer",
    "effarante": "effarant",
    "effarantes": "effarant",
    "effarants": "effarant",
    "effaras": "effarer",
    "effarasse": "effarer",
    "effarassent": "effarer",
    "effarasses": "effarer",
    "effarassiez": "effarer",
    "effarassions": "effarer",
    "effare": "effarer",
    "effarements": "effarement",
    "effarent": "effarer",
    "effarera": "effarer",
    "effarerai": "effarer",
    "effareraient": "effarer",
    "effarerais": "effarer",
    "effarerait": "effarer",
    "effareras": "effarer",
    "effarerez": "effarer",
    "effareriez": "effarer",
    "effarerions": "effarer",
    "effarerons": "effarer",
    "effareront": "effarer",
    "effares": "effarer",
    "effarez": "effarer",
    "effariez": "effarer",
    "effarions": "effarer",
    "effarons": "effarer",
    "effaroucha": "effaroucher",
    "effarouchai": "effaroucher",
    "effarouchaient": "effaroucher",
    "effarouchais": "effaroucher",
    "effarouchait": "effaroucher",
    "effarouchant": "effaroucher",
    "effarouchas": "effaroucher",
    "effarouchasse": "effaroucher",
    "effarouchassent": "effaroucher",
    "effarouchasses": "effaroucher",
    "effarouchassiez": "effaroucher",
    "effarouchassions": "effaroucher",
    "effarouche": "effaroucher",
    "effarouchements": "effarouchement",
    "effarouchent": "effaroucher",
    "effarouchera": "effaroucher",
    "effaroucherai": "effaroucher",
    "effaroucheraient": "effaroucher",
    "effaroucherais": "effaroucher",
    "effaroucherait": "effaroucher",
    "effaroucheras": "effaroucher",
    "effaroucherez": "effaroucher",
    "effaroucheriez": "effaroucher",
    "effaroucherions": "effaroucher",
    "effaroucherons": "effaroucher",
    "effaroucheront": "effaroucher",
    "effarouches": "effaroucher",
    "effarouchez": "effaroucher",
    "effarouchiez": "effaroucher",
    "effarouchions": "effaroucher",
    "effarouchons": "effaroucher",
    "effarouchâmes": "effaroucher",
    "effarouchât": "effaroucher",
    "effarouchâtes": "effaroucher",
    "effarouchèrent": "effaroucher",
    "effarouché": "effaroucher",
    "effarouchée": "effaroucher",
    "effarouchées": "effaroucher",
    "effarouchés": "effaroucher",
    "effarvattes": "effarvatte",
    "effarâmes": "effarer",
    "effarât": "effarer",
    "effarâtes": "effarer",
    "effarèrent": "effarer",
    "effaré": "effarer",
    "effarée": "effarer",
    "effarées": "effarer",
    "effarés": "effarer",
    "effaça": "effacer",
    "effaçables": "effaçable",
    "effaçai": "effacer",
    "effaçaient": "effacer",
    "effaçais": "effacer",
    "effaçait": "effacer",
    "effaçant": "effacer",
    "effaças": "effacer",
    "effaçasse": "effacer",
    "effaçassent": "effacer",
    "effaçasses": "effacer",
    "effaçassiez": "effacer",
    "effaçassions": "effacer",
    "effaçons": "effacer",
    "effaçâmes": "effacer",
    "effaçât": "effacer",
    "effaçâtes": "effacer",
    "effectifs": "effectif",
    "effective": "effectif",
    "effectives": "effectif",
    "effectivités": "effectivité",
    "effectua": "effectuer",
    "effectuai": "effectuer",
    "effectuaient": "effectuer",
    "effectuais": "effectuer",
    "effectuait": "effectuer",
    "effectuant": "effectuer",
    "effectuas": "effectuer",
    "effectuasse": "effectuer",
    "effectuassent": "effectuer",
    "effectuasses": "effectuer",
    "effectuassiez": "effectuer",
    "effectuassions": "effectuer",
    "effectue": "effectuer",
    "effectuent": "effectuer",
    "effectuera": "effectuer",
    "effectuerai": "effectuer",
    "effectueraient": "effectuer",
    "effectuerais": "effectuer",
    "effectuerait": "effectuer",
    "effectueras": "effectuer",
    "effectuerez": "effectuer",
    "effectueriez": "effectuer",
    "effectuerions": "effectuer",
    "effectuerons": "effectuer",
    "effectueront": "effectuer",
    "effectues": "effectuer",
    "effectuez": "effectuer",
    "effectuiez": "effectuer",
    "effectuions": "effectuer",
    "effectuons": "effectuer",
    "effectuâmes": "effectuer",
    "effectuât": "effectuer",
    "effectuâtes": "effectuer",
    "effectuèrent": "effectuer",
    "effectué": "effectuer",
    "effectuée": "effectuer",
    "effectuées": "effectuer",
    "effectués": "effectuer",
    "effervescences": "effervescence",
    "effervescente": "effervescent",
    "effervescentes": "effervescent",
    "effervescents": "effervescent",
    "effets": "effet",
    "effeuilla": "effeuiller",
    "effeuillai": "effeuiller",
    "effeuillaient": "effeuiller",
    "effeuillais": "effeuiller",
    "effeuillait": "effeuiller",
    "effeuillant": "effeuiller",
    "effeuillas": "effeuiller",
    "effeuillasse": "effeuiller",
    "effeuillassent": "effeuiller",
    "effeuillasses": "effeuiller",
    "effeuillassiez": "effeuiller",
    "effeuillassions": "effeuiller",
    "effeuille": "effeuiller",
    "effeuillent": "effeuiller",
    "effeuillera": "effeuiller",
    "effeuillerai": "effeuiller",
    "effeuilleraient": "effeuiller",
    "effeuillerais": "effeuiller",
    "effeuillerait": "effeuiller",
    "effeuilleras": "effeuiller",
    "effeuillerez": "effeuiller",
    "effeuilleriez": "effeuiller",
    "effeuillerions": "effeuiller",
    "effeuillerons": "effeuiller",
    "effeuilleront": "effeuiller",
    "effeuilles": "effeuiller",
    "effeuilleuse": "effeuilleur",
    "effeuilleuses": "effeuilleur",
    "effeuillez": "effeuiller",
    "effeuilliez": "effeuiller",
    "effeuillions": "effeuiller",
    "effeuillons": "effeuiller",
    "effeuillâmes": "effeuiller",
    "effeuillât": "effeuiller",
    "effeuillâtes": "effeuiller",
    "effeuillèrent": "effeuiller",
    "effeuillé": "effeuiller",
    "effeuillée": "effeuiller",
    "effeuillées": "effeuiller",
    "effeuillés": "effeuiller",
    "efficaces": "efficace",
    "efficacités": "efficacité",
    "efficiences": "efficience",
    "efficiente": "efficient",
    "efficientes": "efficient",
    "efficients": "efficient",
    "effigies": "effigie",
    "effila": "effiler",
    "effilai": "effiler",
    "effilaient": "effiler",
    "effilais": "effiler",
    "effilait": "effiler",
    "effilant": "effiler",
    "effilas": "effiler",
    "effilasse": "effiler",
    "effilassent": "effiler",
    "effilasses": "effiler",
    "effilassiez": "effiler",
    "effilassions": "effiler",
    "effile": "effiler",
    "effilent": "effiler",
    "effilera": "effiler",
    "effilerai": "effiler",
    "effileraient": "effiler",
    "effilerais": "effiler",
    "effilerait": "effiler",
    "effileras": "effiler",
    "effilerez": "effiler",
    "effileriez": "effiler",
    "effilerions": "effiler",
    "effilerons": "effiler",
    "effileront": "effiler",
    "effiles": "effiler",
    "effilez": "effiler",
    "effiliez": "effiler",
    "effilions": "effiler",
    "effilocha": "effilocher",
    "effilochai": "effilocher",
    "effilochaient": "effilocher",
    "effilochais": "effilocher",
    "effilochait": "effilocher",
    "effilochant": "effilocher",
    "effilochas": "effilocher",
    "effilochasse": "effilocher",
    "effilochassent": "effilocher",
    "effilochasses": "effilocher",
    "effilochassiez": "effilocher",
    "effilochassions": "effilocher",
    "effiloche": "effilocher",
    "effilochent": "effilocher",
    "effilochera": "effilocher",
    "effilocherai": "effilocher",
    "effilocheraient": "effilocher",
    "effilocherais": "effilocher",
    "effilocherait": "effilocher",
    "effilocheras": "effilocher",
    "effilocherez": "effilocher",
    "effilocheriez": "effilocher",
    "effilocherions": "effilocher",
    "effilocherons": "effilocher",
    "effilocheront": "effilocher",
    "effiloches": "effilocher",
    "effilochez": "effilocher",
    "effilochiez": "effilocher",
    "effilochions": "effilocher",
    "effilochons": "effilocher",
    "effilochures": "effilochure",
    "effilochâmes": "effilocher",
    "effilochât": "effilocher",
    "effilochâtes": "effilocher",
    "effilochèrent": "effilocher",
    "effiloché": "effilocher",
    "effilochée": "effilocher",
    "effilochées": "effilocher",
    "effilochés": "effilocher",
    "effilons": "effiler",
    "effilures": "effilure",
    "effilâmes": "effiler",
    "effilât": "effiler",
    "effilâtes": "effiler",
    "effilèrent": "effiler",
    "effilé": "effiler",
    "effilée": "effiler",
    "effilées": "effiler",
    "effilés": "effiler",
    "efflanqué": "efflanquer",
    "efflanquée": "efflanquer",
    "efflanquées": "efflanquer",
    "efflanqués": "efflanquer",
    "effleura": "effleurer",
    "effleurai": "effleurer",
    "effleuraient": "effleurer",
    "effleurais": "effleurer",
    "effleurait": "effleurer",
    "effleurant": "effleurer",
    "effleuras": "effleurer",
    "effleurasse": "effleurer",
    "effleurassent": "effleurer",
    "effleurasses": "effleurer",
    "effleurassiez": "effleurer",
    "effleurassions": "effleurer",
    "effleure": "effleurer",
    "effleurements": "effleurement",
    "effleurent": "effleurer",
    "effleurera": "effleurer",
    "effleurerai": "effleurer",
    "effleureraient": "effleurer",
    "effleurerais": "effleurer",
    "effleurerait": "effleurer",
    "effleureras": "effleurer",
    "effleurerez": "effleurer",
    "effleureriez": "effleurer",
    "effleurerions": "effleurer",
    "effleurerons": "effleurer",
    "effleureront": "effleurer",
    "effleures": "effleurer",
    "effleurez": "effleurer",
    "effleuri": "effleurir",
    "effleurie": "effleurir",
    "effleuries": "effleurir",
    "effleuriez": "effleurer",
    "effleurions": "effleurer",
    "effleurira": "effleurir",
    "effleurirai": "effleurir",
    "effleuriraient": "effleurir",
    "effleurirais": "effleurir",
    "effleurirait": "effleurir",
    "effleuriras": "effleurir",
    "effleurirent": "effleurir",
    "effleurirez": "effleurir",
    "effleuririez": "effleurir",
    "effleuririons": "effleurir",
    "effleurirons": "effleurir",
    "effleuriront": "effleurir",
    "effleuris": "effleurir",
    "effleurissaient": "effleurir",
    "effleurissais": "effleurir",
    "effleurissait": "effleurir",
    "effleurissant": "effleurir",
    "effleurisse": "effleurir",
    "effleurissent": "effleurir",
    "effleurisses": "effleurir",
    "effleurissez": "effleurir",
    "effleurissiez": "effleurir",
    "effleurissions": "effleurir",
    "effleurissons": "effleurir",
    "effleurit": "effleurir",
    "effleurons": "effleurer",
    "effleurâmes": "effleurer",
    "effleurât": "effleurer",
    "effleurâtes": "effleurer",
    "effleurèrent": "effleurer",
    "effleuré": "effleurer",
    "effleurée": "effleurer",
    "effleurées": "effleurer",
    "effleurés": "effleurer",
    "effleurîmes": "effleurir",
    "effleurît": "effleurir",
    "effleurîtes": "effleurir",
    "efflorescences": "efflorescence",
    "efflorescente": "efflorescent",
    "efflorescentes": "efflorescent",
    "efflorescents": "efflorescent",
    "effluents": "effluent",
    "effluves": "effluve",
    "effondra": "effondrer",
    "effondrai": "effondrer",
    "effondraient": "effondrer",
    "effondrais": "effondrer",
    "effondrait": "effondrer",
    "effondrant": "effondrer",
    "effondras": "effondrer",
    "effondrasse": "effondrer",
    "effondrassent": "effondrer",
    "effondrasses": "effondrer",
    "effondrassiez": "effondrer",
    "effondrassions": "effondrer",
    "effondre": "effondrer",
    "effondrements": "effondrement",
    "effondrent": "effondrer",
    "effondrera": "effondrer",
    "effondrerai": "effondrer",
    "effondreraient": "effondrer",
    "effondrerais": "effondrer",
    "effondrerait": "effondrer",
    "effondreras": "effondrer",
    "effondrerez": "effondrer",
    "effondreriez": "effondrer",
    "effondrerions": "effondrer",
    "effondrerons": "effondrer",
    "effondreront": "effondrer",
    "effondres": "effondrer",
    "effondrez": "effondrer",
    "effondriez": "effondrer",
    "effondrions": "effondrer",
    "effondrons": "effondrer",
    "effondrâmes": "effondrer",
    "effondrât": "effondrer",
    "effondrâtes": "effondrer",
    "effondrèrent": "effondrer",
    "effondré": "effondrer",
    "effondrée": "effondrer",
    "effondrées": "effondrer",
    "effondrés": "effondrer",
    "efforce": "efforcer",
    "efforcent": "efforcer",
    "efforcera": "efforcer",
    "efforcerai": "efforcer",
    "efforceraient": "efforcer",
    "efforcerais": "efforcer",
    "efforcerait": "efforcer",
    "efforceras": "efforcer",
    "efforcerez": "efforcer",
    "efforceriez": "efforcer",
    "efforcerions": "efforcer",
    "efforcerons": "efforcer",
    "efforceront": "efforcer",
    "efforces": "efforcer",
    "efforcez": "efforcer",
    "efforciez": "efforcer",
    "efforcions": "efforcer",
    "efforcèrent": "efforcer",
    "efforcé": "efforcer",
    "efforcée": "efforcer",
    "efforcées": "efforcer",
    "efforcés": "efforcer",
    "efforts": "effort",
    "efforça": "efforcer",
    "efforçai": "efforcer",
    "efforçaient": "efforcer",
    "efforçais": "efforcer",
    "efforçait": "efforcer",
    "efforçant": "efforcer",
    "efforças": "efforcer",
    "efforçasse": "efforcer",
    "efforçassent": "efforcer",
    "efforçasses": "efforcer",
    "efforçassiez": "efforcer",
    "efforçassions": "efforcer",
    "efforçons": "efforcer",
    "efforçâmes": "efforcer",
    "efforçât": "efforcer",
    "efforçâtes": "efforcer",
    "effractions": "effraction",
    "effraie": "effrayer",
    "effraient": "effrayer",
    "effraiera": "effrayer",
    "effraierai": "effrayer",
    "effraieraient": "effrayer",
    "effraierais": "effrayer",
    "effraierait": "effrayer",
    "effraieras": "effrayer",
    "effraierez": "effrayer",
    "effraieriez": "effrayer",
    "effraierions": "effrayer",
    "effraierons": "effrayer",
    "effraieront": "effrayer",
    "effraies": "effrayer",
    "effrange": "effranger",
    "effrangea": "effranger",
    "effrangeai": "effranger",
    "effrangeaient": "effranger",
    "effrangeais": "effranger",
    "effrangeait": "effranger",
    "effrangeant": "effranger",
    "effrangeas": "effranger",
    "effrangeasse": "effranger",
    "effrangeassent": "effranger",
    "effrangeasses": "effranger",
    "effrangeassiez": "effranger",
    "effrangeassions": "effranger",
    "effrangent": "effranger",
    "effrangeons": "effranger",
    "effrangera": "effranger",
    "effrangerai": "effranger",
    "effrangeraient": "effranger",
    "effrangerais": "effranger",
    "effrangerait": "effranger",
    "effrangeras": "effranger",
    "effrangerez": "effranger",
    "effrangeriez": "effranger",
    "effrangerions": "effranger",
    "effrangerons": "effranger",
    "effrangeront": "effranger",
    "effranges": "effranger",
    "effrangez": "effranger",
    "effrangeâmes": "effranger",
    "effrangeât": "effranger",
    "effrangeâtes": "effranger",
    "effrangiez": "effranger",
    "effrangions": "effranger",
    "effrangèrent": "effranger",
    "effrangé": "effranger",
    "effrangée": "effranger",
    "effrangées": "effranger",
    "effrangés": "effranger",
    "effraya": "effrayer",
    "effrayai": "effrayer",
    "effrayaient": "effrayer",
    "effrayais": "effrayer",
    "effrayait": "effrayer",
    "effrayant": "effrayer",
    "effrayante": "effrayant",
    "effrayantes": "effrayant",
    "effrayants": "effrayant",
    "effrayas": "effrayer",
    "effrayasse": "effrayer",
    "effrayassent": "effrayer",
    "effrayasses": "effrayer",
    "effrayassiez": "effrayer",
    "effrayassions": "effrayer",
    "effraye": "effrayer",
    "effrayent": "effrayer",
    "effrayera": "effrayer",
    "effrayerai": "effrayer",
    "effrayeraient": "effrayer",
    "effrayerais": "effrayer",
    "effrayerait": "effrayer",
    "effrayeras": "effrayer",
    "effrayerez": "effrayer",
    "effrayeriez": "effrayer",
    "effrayerions": "effrayer",
    "effrayerons": "effrayer",
    "effrayeront": "effrayer",
    "effrayes": "effrayer",
    "effrayez": "effrayer",
    "effrayiez": "effrayer",
    "effrayions": "effrayer",
    "effrayons": "effrayer",
    "effrayâmes": "effrayer",
    "effrayât": "effrayer",
    "effrayâtes": "effrayer",
    "effrayèrent": "effrayer",
    "effrayé": "effrayer",
    "effrayée": "effrayer",
    "effrayées": "effrayer",
    "effrayés": "effrayer",
    "effrita": "effriter",
    "effritai": "effriter",
    "effritaient": "effriter",
    "effritais": "effriter",
    "effritait": "effriter",
    "effritant": "effriter",
    "effritas": "effriter",
    "effritasse": "effriter",
    "effritassent": "effriter",
    "effritasses": "effriter",
    "effritassiez": "effriter",
    "effritassions": "effriter",
    "effrite": "effriter",
    "effritements": "effritement",
    "effritent": "effriter",
    "effritera": "effriter",
    "effriterai": "effriter",
    "effriteraient": "effriter",
    "effriterais": "effriter",
    "effriterait": "effriter",
    "effriteras": "effriter",
    "effriterez": "effriter",
    "effriteriez": "effriter",
    "effriterions": "effriter",
    "effriterons": "effriter",
    "effriteront": "effriter",
    "effrites": "effriter",
    "effritez": "effriter",
    "effritiez": "effriter",
    "effritions": "effriter",
    "effritons": "effriter",
    "effritâmes": "effriter",
    "effritât": "effriter",
    "effritâtes": "effriter",
    "effritèrent": "effriter",
    "effrité": "effriter",
    "effritée": "effriter",
    "effritées": "effriter",
    "effrités": "effriter",
    "effrois": "effroi",
    "effronteries": "effronterie",
    "effrontée": "effronté",
    "effrontées": "effronté",
    "effrontés": "effronté",
    "effroyables": "effroyable",
    "effrénée": "effréné",
    "effrénées": "effréné",
    "effrénés": "effréné",
    "effulgente": "effulgent",
    "effusionnistes": "effusionniste",
    "effusions": "effusion",
    "effémina": "efféminer",
    "efféminai": "efféminer",
    "efféminaient": "efféminer",
    "efféminais": "efféminer",
    "efféminait": "efféminer",
    "efféminant": "efféminer",
    "efféminas": "efféminer",
    "efféminasse": "efféminer",
    "efféminassent": "efféminer",
    "efféminasses": "efféminer",
    "efféminassiez": "efféminer",
    "efféminassions": "efféminer",
    "effémine": "efféminer",
    "efféminent": "efféminer",
    "efféminera": "efféminer",
    "efféminerai": "efféminer",
    "effémineraient": "efféminer",
    "efféminerais": "efféminer",
    "efféminerait": "efféminer",
    "effémineras": "efféminer",
    "efféminerez": "efféminer",
    "effémineriez": "efféminer",
    "efféminerions": "efféminer",
    "efféminerons": "efféminer",
    "effémineront": "efféminer",
    "effémines": "efféminer",
    "efféminez": "efféminer",
    "efféminiez": "efféminer",
    "efféminions": "efféminer",
    "efféminons": "efféminer",
    "efféminâmes": "efféminer",
    "efféminât": "efféminer",
    "efféminâtes": "efféminer",
    "efféminèrent": "efféminer",
    "efféminé": "efféminer",
    "efféminée": "efféminer",
    "efféminées": "efféminer",
    "efféminés": "efféminer",
    "efférente": "efférent",
    "efférentes": "efférent",
    "efférents": "efférent",
    "eiders": "eider",
    "einsteinienne": "einsteinien",
    "ektachromes": "ektachrome",
    "eldorados": "eldorado",
    "elfes": "elfe",
    "elle": "lui",
    "elles": "lui",
    "ellipses": "ellipse",
    "ellipsoïdale": "ellipsoïdal",
    "ellipsoïdales": "ellipsoïdal",
    "ellipsoïdaux": "ellipsoïdal",
    "elliptiques": "elliptique",
    "ellébores": "ellébore",
    "elzévirs": "elzévir",
    "emails": "email",
    "emballa": "emballer",
    "emballages": "emballage",
    "emballai": "emballer",
    "emballaient": "emballer",
    "emballais": "emballer",
    "emballait": "emballer",
    "emballant": "emballer",
    "emballas": "emballer",
    "emballasse": "emballer",
    "emballassent": "emballer",
    "emballasses": "emballer",
    "emballassiez": "emballer",
    "emballassions": "emballer",
    "emballe": "emballer",
    "emballements": "emballement",
    "emballent": "emballer",
    "emballera": "emballer",
    "emballerai": "emballer",
    "emballeraient": "emballer",
    "emballerais": "emballer",
    "emballerait": "emballer",
    "emballeras": "emballer",
    "emballerez": "emballer",
    "emballeriez": "emballer",
    "emballerions": "emballer",
    "emballerons": "emballer",
    "emballeront": "emballer",
    "emballes": "emballer",
    "emballeurs": "emballeur",
    "emballeuse": "emballeur",
    "emballeuses": "emballeur",
    "emballez": "emballer",
    "emballiez": "emballer",
    "emballions": "emballer",
    "emballons": "emballer",
    "emballâmes": "emballer",
    "emballât": "emballer",
    "emballâtes": "emballer",
    "emballèrent": "emballer",
    "emballé": "emballer",
    "emballée": "emballer",
    "emballées": "emballer",
    "emballés": "emballer",
    "embaluchonnés": "embaluchonner",
    "embarbouilla": "embarbouiller",
    "embarbouillé": "embarbouiller",
    "embarcadères": "embarcadère",
    "embarcations": "embarcation",
    "embardées": "embardée",
    "embargos": "embargo",
    "embarqua": "embarquer",
    "embarquai": "embarquer",
    "embarquaient": "embarquer",
    "embarquais": "embarquer",
    "embarquait": "embarquer",
    "embarquant": "embarquer",
    "embarquas": "embarquer",
    "embarquasse": "embarquer",
    "embarquassent": "embarquer",
    "embarquasses": "embarquer",
    "embarquassiez": "embarquer",
    "embarquassions": "embarquer",
    "embarque": "embarquer",
    "embarquements": "embarquement",
    "embarquent": "embarquer",
    "embarquera": "embarquer",
    "embarquerai": "embarquer",
    "embarqueraient": "embarquer",
    "embarquerais": "embarquer",
    "embarquerait": "embarquer",
    "embarqueras": "embarquer",
    "embarquerez": "embarquer",
    "embarqueriez": "embarquer",
    "embarquerions": "embarquer",
    "embarquerons": "embarquer",
    "embarqueront": "embarquer",
    "embarques": "embarquer",
    "embarquez": "embarquer",
    "embarquiez": "embarquer",
    "embarquions": "embarquer",
    "embarquons": "embarquer",
    "embarquâmes": "embarquer",
    "embarquât": "embarquer",
    "embarquâtes": "embarquer",
    "embarquèrent": "embarquer",
    "embarqué": "embarquer",
    "embarquée": "embarquer",
    "embarquées": "embarquer",
    "embarqués": "embarquer",
    "embarra": "embarrer",
    "embarrai": "embarrer",
    "embarraient": "embarrer",
    "embarrais": "embarrer",
    "embarrait": "embarrer",
    "embarrant": "embarrer",
    "embarras": "embarrer",
    "embarrassa": "embarrasser",
    "embarrassai": "embarrasser",
    "embarrassaient": "embarrasser",
    "embarrassais": "embarrasser",
    "embarrassait": "embarrasser",
    "embarrassant": "embarrasser",
    "embarrassante": "embarrassant",
    "embarrassantes": "embarrassant",
    "embarrassants": "embarrassant",
    "embarrassas": "embarrasser",
    "embarrassasse": "embarrasser",
    "embarrassassent": "embarrasser",
    "embarrassasses": "embarrasser",
    "embarrassassiez": "embarrasser",
    "embarrassassions": "embarrasser",
    "embarrasse": "embarrer",
    "embarrassent": "embarrer",
    "embarrassera": "embarrasser",
    "embarrasserai": "embarrasser",
    "embarrasseraient": "embarrasser",
    "embarrasserais": "embarrasser",
    "embarrasserait": "embarrasser",
    "embarrasseras": "embarrasser",
    "embarrasserez": "embarrasser",
    "embarrasseriez": "embarrasser",
    "embarrasserions": "embarrasser",
    "embarrasserons": "embarrasser",
    "embarrasseront": "embarrasser",
    "embarrasses": "embarrer",
    "embarrassez": "embarrasser",
    "embarrassiez": "embarrer",
    "embarrassions": "embarrer",
    "embarrassons": "embarrasser",
    "embarrassâmes": "embarrasser",
    "embarrassât": "embarrasser",
    "embarrassâtes": "embarrasser",
    "embarrassèrent": "embarrasser",
    "embarrassé": "embarrasser",
    "embarrassée": "embarrasser",
    "embarrassées": "embarrasser",
    "embarrassés": "embarrasser",
    "embarre": "embarrer",
    "embarrent": "embarrer",
    "embarrera": "embarrer",
    "embarrerai": "embarrer",
    "embarreraient": "embarrer",
    "embarrerais": "embarrer",
    "embarrerait": "embarrer",
    "embarreras": "embarrer",
    "embarrerez": "embarrer",
    "embarreriez": "embarrer",
    "embarrerions": "embarrer",
    "embarrerons": "embarrer",
    "embarreront": "embarrer",
    "embarres": "embarrer",
    "embarrez": "embarrer",
    "embarriez": "embarrer",
    "embarrions": "embarrer",
    "embarrons": "embarrer",
    "embarrâmes": "embarrer",
    "embarrât": "embarrer",
    "embarrâtes": "embarrer",
    "embarrèrent": "embarrer",
    "embarré": "embarrer",
    "embarrée": "embarrer",
    "embarrées": "embarrer",
    "embarrés": "embarrer",
    "embases": "embase",
    "embastilla": "embastiller",
    "embastillai": "embastiller",
    "embastillaient": "embastiller",
    "embastillais": "embastiller",
    "embastillait": "embastiller",
    "embastillant": "embastiller",
    "embastillas": "embastiller",
    "embastillasse": "embastiller",
    "embastillassent": "embastiller",
    "embastillasses": "embastiller",
    "embastillassiez": "embastiller",
    "embastillassions": "embastiller",
    "embastille": "embastiller",
    "embastillent": "embastiller",
    "embastillera": "embastiller",
    "embastillerai": "embastiller",
    "embastilleraient": "embastiller",
    "embastillerais": "embastiller",
    "embastillerait": "embastiller",
    "embastilleras": "embastiller",
    "embastillerez": "embastiller",
    "embastilleriez": "embastiller",
    "embastillerions": "embastiller",
    "embastillerons": "embastiller",
    "embastilleront": "embastiller",
    "embastilles": "embastiller",
    "embastillez": "embastiller",
    "embastilliez": "embastiller",
    "embastillions": "embastiller",
    "embastillons": "embastiller",
    "embastillâmes": "embastiller",
    "embastillât": "embastiller",
    "embastillâtes": "embastiller",
    "embastillèrent": "embastiller",
    "embastillé": "embastiller",
    "embastillée": "embastiller",
    "embastillées": "embastiller",
    "embastillés": "embastiller",
    "embat": "embattre",
    "embats": "embattre",
    "embattaient": "embattre",
    "embattais": "embattre",
    "embattait": "embattre",
    "embattant": "embattre",
    "embatte": "embattre",
    "embattent": "embattre",
    "embattes": "embattre",
    "embattez": "embattre",
    "embattiez": "embattre",
    "embattions": "embattre",
    "embattirent": "embattre",
    "embattis": "embattre",
    "embattisse": "embattre",
    "embattissent": "embattre",
    "embattisses": "embattre",
    "embattissiez": "embattre",
    "embattissions": "embattre",
    "embattit": "embattre",
    "embattons": "embattre",
    "embattra": "embattre",
    "embattrai": "embattre",
    "embattraient": "embattre",
    "embattrais": "embattre",
    "embattrait": "embattre",
    "embattras": "embattre",
    "embattrez": "embattre",
    "embattriez": "embattre",
    "embattrions": "embattre",
    "embattrons": "embattre",
    "embattront": "embattre",
    "embattu": "embattre",
    "embattue": "embattre",
    "embattues": "embattre",
    "embattus": "embattre",
    "embattîmes": "embattre",
    "embattît": "embattre",
    "embattîtes": "embattre",
    "embaucha": "embaucher",
    "embauchai": "embaucher",
    "embauchaient": "embaucher",
    "embauchais": "embaucher",
    "embauchait": "embaucher",
    "embauchant": "embaucher",
    "embauchas": "embaucher",
    "embauchasse": "embaucher",
    "embauchassent": "embaucher",
    "embauchasses": "embaucher",
    "embauchassiez": "embaucher",
    "embauchassions": "embaucher",
    "embauche": "embaucher",
    "embauchent": "embaucher",
    "embauchera": "embaucher",
    "embaucherai": "embaucher",
    "embaucheraient": "embaucher",
    "embaucherais": "embaucher",
    "embaucherait": "embaucher",
    "embaucheras": "embaucher",
    "embaucherez": "embaucher",
    "embaucheriez": "embaucher",
    "embaucherions": "embaucher",
    "embaucherons": "embaucher",
    "embaucheront": "embaucher",
    "embauches": "embaucher",
    "embauchez": "embaucher",
    "embauchiez": "embaucher",
    "embauchions": "embaucher",
    "embauchoirs": "embauchoir",
    "embauchons": "embaucher",
    "embauchâmes": "embaucher",
    "embauchât": "embaucher",
    "embauchâtes": "embaucher",
    "embauchèrent": "embaucher",
    "embauché": "embaucher",
    "embauchée": "embaucher",
    "embauchées": "embaucher",
    "embauchés": "embaucher",
    "embauma": "embaumer",
    "embaumai": "embaumer",
    "embaumaient": "embaumer",
    "embaumais": "embaumer",
    "embaumait": "embaumer",
    "embaumant": "embaumer",
    "embaumants": "embaumant",
    "embaumas": "embaumer",
    "embaumasse": "embaumer",
    "embaumassent": "embaumer",
    "embaumasses": "embaumer",
    "embaumassiez": "embaumer",
    "embaumassions": "embaumer",
    "embaume": "embaumer",
    "embaumements": "embaumement",
    "embaument": "embaumer",
    "embaumera": "embaumer",
    "embaumerai": "embaumer",
    "embaumeraient": "embaumer",
    "embaumerais": "embaumer",
    "embaumerait": "embaumer",
    "embaumeras": "embaumer",
    "embaumerez": "embaumer",
    "embaumeriez": "embaumer",
    "embaumerions": "embaumer",
    "embaumerons": "embaumer",
    "embaumeront": "embaumer",
    "embaumes": "embaumer",
    "embaumeurs": "embaumeur",
    "embaumeuse": "embaumeur",
    "embaumez": "embaumer",
    "embaumiez": "embaumer",
    "embaumions": "embaumer",
    "embaumons": "embaumer",
    "embaumâmes": "embaumer",
    "embaumât": "embaumer",
    "embaumâtes": "embaumer",
    "embaumèrent": "embaumer",
    "embaumé": "embaumer",
    "embaumée": "embaumer",
    "embaumées": "embaumer",
    "embaumés": "embaumer",
    "embelli": "embellir",
    "embellie": "embellir",
    "embellies": "embellir",
    "embellira": "embellir",
    "embellirai": "embellir",
    "embelliraient": "embellir",
    "embellirais": "embellir",
    "embellirait": "embellir",
    "embelliras": "embellir",
    "embellirent": "embellir",
    "embellirez": "embellir",
    "embelliriez": "embellir",
    "embellirions": "embellir",
    "embellirons": "embellir",
    "embelliront": "embellir",
    "embellis": "embellir",
    "embellissaient": "embellir",
    "embellissais": "embellir",
    "embellissait": "embellir",
    "embellissant": "embellir",
    "embellisse": "embellir",
    "embellissements": "embellissement",
    "embellissent": "embellir",
    "embellisses": "embellir",
    "embellissez": "embellir",
    "embellissiez": "embellir",
    "embellissions": "embellir",
    "embellissons": "embellir",
    "embellit": "embellir",
    "embellîmes": "embellir",
    "embellît": "embellir",
    "embellîtes": "embellir",
    "emberlificota": "emberlificoter",
    "emberlificotai": "emberlificoter",
    "emberlificotaient": "emberlificoter",
    "emberlificotais": "emberlificoter",
    "emberlificotait": "emberlificoter",
    "emberlificotant": "emberlificoter",
    "emberlificotas": "emberlificoter",
    "emberlificotasse": "emberlificoter",
    "emberlificotassent": "emberlificoter",
    "emberlificotasses": "emberlificoter",
    "emberlificotassiez": "emberlificoter",
    "emberlificotassions": "emberlificoter",
    "emberlificote": "emberlificoter",
    "emberlificotent": "emberlificoter",
    "emberlificotera": "emberlificoter",
    "emberlificoterai": "emberlificoter",
    "emberlificoteraient": "emberlificoter",
    "emberlificoterais": "emberlificoter",
    "emberlificoterait": "emberlificoter",
    "emberlificoteras": "emberlificoter",
    "emberlificoterez": "emberlificoter",
    "emberlificoteriez": "emberlificoter",
    "emberlificoterions": "emberlificoter",
    "emberlificoterons": "emberlificoter",
    "emberlificoteront": "emberlificoter",
    "emberlificotes": "emberlificoter",
    "emberlificotez": "emberlificoter",
    "emberlificotiez": "emberlificoter",
    "emberlificotions": "emberlificoter",
    "emberlificotons": "emberlificoter",
    "emberlificotâmes": "emberlificoter",
    "emberlificotât": "emberlificoter",
    "emberlificotâtes": "emberlificoter",
    "emberlificotèrent": "emberlificoter",
    "emberlificoté": "emberlificoter",
    "emberlificotée": "emberlificoter",
    "emberlificotées": "emberlificoter",
    "emberlificotés": "emberlificoter",
    "embijoutée": "embijouté",
    "emblava": "emblaver",
    "emblavages": "emblavage",
    "emblavai": "emblaver",
    "emblavaient": "emblaver",
    "emblavais": "emblaver",
    "emblavait": "emblaver",
    "emblavant": "emblaver",
    "emblavas": "emblaver",
    "emblavasse": "emblaver",
    "emblavassent": "emblaver",
    "emblavasses": "emblaver",
    "emblavassiez": "emblaver",
    "emblavassions": "emblaver",
    "emblave": "emblaver",
    "emblavements": "emblavement",
    "emblavent": "emblaver",
    "emblavera": "emblaver",
    "emblaverai": "emblaver",
    "emblaveraient": "emblaver",
    "emblaverais": "emblaver",
    "emblaverait": "emblaver",
    "emblaveras": "emblaver",
    "emblaverez": "emblaver",
    "emblaveriez": "emblaver",
    "emblaverions": "emblaver",
    "emblaverons": "emblaver",
    "emblaveront": "emblaver",
    "emblaves": "emblaver",
    "emblavez": "emblaver",
    "emblaviez": "emblaver",
    "emblavions": "emblaver",
    "emblavons": "emblaver",
    "emblavures": "emblavure",
    "emblavâmes": "emblaver",
    "emblavât": "emblaver",
    "emblavâtes": "emblaver",
    "emblavèrent": "emblaver",
    "emblavé": "emblaver",
    "emblavée": "emblaver",
    "emblavées": "emblaver",
    "emblavés": "emblaver",
    "emblèmes": "emblème",
    "emblématiques": "emblématique",
    "embobelina": "embobeliner",
    "embobelinai": "embobeliner",
    "embobelinaient": "embobeliner",
    "embobelinais": "embobeliner",
    "embobelinait": "embobeliner",
    "embobelinant": "embobeliner",
    "embobelinas": "embobeliner",
    "embobelinasse": "embobeliner",
    "embobelinassent": "embobeliner",
    "embobelinasses": "embobeliner",
    "embobelinassiez": "embobeliner",
    "embobelinassions": "embobeliner",
    "embobeline": "embobeliner",
    "embobelinent": "embobeliner",
    "embobelinera": "embobeliner",
    "embobelinerai": "embobeliner",
    "embobelineraient": "embobeliner",
    "embobelinerais": "embobeliner",
    "embobelinerait": "embobeliner",
    "embobelineras": "embobeliner",
    "embobelinerez": "embobeliner",
    "embobelineriez": "embobeliner",
    "embobelinerions": "embobeliner",
    "embobelinerons": "embobeliner",
    "embobelineront": "embobeliner",
    "embobelines": "embobeliner",
    "embobelinez": "embobeliner",
    "embobeliniez": "embobeliner",
    "embobelinions": "embobeliner",
    "embobelinons": "embobeliner",
    "embobelinâmes": "embobeliner",
    "embobelinât": "embobeliner",
    "embobelinâtes": "embobeliner",
    "embobelinèrent": "embobeliner",
    "embobeliné": "embobeliner",
    "embobelinée": "embobeliner",
    "embobelinées": "embobeliner",
    "embobelinés": "embobeliner",
    "embobina": "embobiner",
    "embobinai": "embobiner",
    "embobinaient": "embobiner",
    "embobinais": "embobiner",
    "embobinait": "embobiner",
    "embobinant": "embobiner",
    "embobinas": "embobiner",
    "embobinasse": "embobiner",
    "embobinassent": "embobiner",
    "embobinasses": "embobiner",
    "embobinassiez": "embobiner",
    "embobinassions": "embobiner",
    "embobine": "embobiner",
    "embobinent": "embobiner",
    "embobinera": "embobiner",
    "embobinerai": "embobiner",
    "embobineraient": "embobiner",
    "embobinerais": "embobiner",
    "embobinerait": "embobiner",
    "embobineras": "embobiner",
    "embobinerez": "embobiner",
    "embobineriez": "embobiner",
    "embobinerions": "embobiner",
    "embobinerons": "embobiner",
    "embobineront": "embobiner",
    "embobines": "embobiner",
    "embobinez": "embobiner",
    "embobiniez": "embobiner",
    "embobinions": "embobiner",
    "embobinons": "embobiner",
    "embobinâmes": "embobiner",
    "embobinât": "embobiner",
    "embobinâtes": "embobiner",
    "embobinèrent": "embobiner",
    "embobiné": "embobiner",
    "embobinée": "embobiner",
    "embobinées": "embobiner",
    "embobinés": "embobiner",
    "emboira": "emboire",
    "emboirai": "emboire",
    "emboiraient": "emboire",
    "emboirais": "emboire",
    "emboirait": "emboire",
    "emboiras": "emboire",
    "emboirez": "emboire",
    "emboiriez": "emboire",
    "emboirions": "emboire",
    "emboirons": "emboire",
    "emboiront": "emboire",
    "embois": "emboire",
    "emboit": "emboire",
    "emboive": "emboire",
    "emboivent": "emboire",
    "emboives": "emboire",
    "embolies": "embolie",
    "embonpoints": "embonpoint",
    "embossa": "embosser",
    "embossai": "embosser",
    "embossaient": "embosser",
    "embossais": "embosser",
    "embossait": "embosser",
    "embossant": "embosser",
    "embossas": "embosser",
    "embossasse": "embosser",
    "embossassent": "embosser",
    "embossasses": "embosser",
    "embossassiez": "embosser",
    "embossassions": "embosser",
    "embosse": "embosser",
    "embossent": "embosser",
    "embossera": "embosser",
    "embosserai": "embosser",
    "embosseraient": "embosser",
    "embosserais": "embosser",
    "embosserait": "embosser",
    "embosseras": "embosser",
    "embosserez": "embosser",
    "embosseriez": "embosser",
    "embosserions": "embosser",
    "embosserons": "embosser",
    "embosseront": "embosser",
    "embosses": "embosser",
    "embossez": "embosser",
    "embossiez": "embosser",
    "embossions": "embosser",
    "embossons": "embosser",
    "embossâmes": "embosser",
    "embossât": "embosser",
    "embossâtes": "embosser",
    "embossèrent": "embosser",
    "embossé": "embosser",
    "embossée": "embosser",
    "embossées": "embosser",
    "embossés": "embosser",
    "emboucanent": "emboucaner",
    "emboucha": "emboucher",
    "embouchai": "emboucher",
    "embouchaient": "emboucher",
    "embouchais": "emboucher",
    "embouchait": "emboucher",
    "embouchant": "emboucher",
    "embouchas": "emboucher",
    "embouchasse": "emboucher",
    "embouchassent": "emboucher",
    "embouchasses": "emboucher",
    "embouchassiez": "emboucher",
    "embouchassions": "emboucher",
    "embouche": "emboucher",
    "embouchent": "emboucher",
    "embouchera": "emboucher",
    "emboucherai": "emboucher",
    "emboucheraient": "emboucher",
    "emboucherais": "emboucher",
    "emboucherait": "emboucher",
    "emboucheras": "emboucher",
    "emboucherez": "emboucher",
    "emboucheriez": "emboucher",
    "emboucherions": "emboucher",
    "emboucherons": "emboucher",
    "emboucheront": "emboucher",
    "embouches": "emboucher",
    "embouchez": "emboucher",
    "embouchiez": "emboucher",
    "embouchions": "emboucher",
    "embouchoirs": "embouchoir",
    "embouchons": "emboucher",
    "embouchures": "embouchure",
    "embouchâmes": "emboucher",
    "embouchât": "emboucher",
    "embouchâtes": "emboucher",
    "embouchèrent": "emboucher",
    "embouché": "emboucher",
    "embouchée": "emboucher",
    "embouchées": "emboucher",
    "embouchés": "emboucher",
    "embouqué": "embouquer",
    "embourba": "embourber",
    "embourbai": "embourber",
    "embourbaient": "embourber",
    "embourbais": "embourber",
    "embourbait": "embourber",
    "embourbant": "embourber",
    "embourbas": "embourber",
    "embourbasse": "embourber",
    "embourbassent": "embourber",
    "embourbasses": "embourber",
    "embourbassiez": "embourber",
    "embourbassions": "embourber",
    "embourbe": "embourber",
    "embourbent": "embourber",
    "embourbera": "embourber",
    "embourberai": "embourber",
    "embourberaient": "embourber",
    "embourberais": "embourber",
    "embourberait": "embourber",
    "embourberas": "embourber",
    "embourberez": "embourber",
    "embourberiez": "embourber",
    "embourberions": "embourber",
    "embourberons": "embourber",
    "embourberont": "embourber",
    "embourbes": "embourber",
    "embourbez": "embourber",
    "embourbiez": "embourber",
    "embourbions": "embourber",
    "embourbons": "embourber",
    "embourbâmes": "embourber",
    "embourbât": "embourber",
    "embourbâtes": "embourber",
    "embourbèrent": "embourber",
    "embourbé": "embourber",
    "embourbée": "embourber",
    "embourbées": "embourber",
    "embourbés": "embourber",
    "embourgeoisa": "embourgeoiser",
    "embourgeoisai": "embourgeoiser",
    "embourgeoisaient": "embourgeoiser",
    "embourgeoisais": "embourgeoiser",
    "embourgeoisait": "embourgeoiser",
    "embourgeoisant": "embourgeoiser",
    "embourgeoisas": "embourgeoiser",
    "embourgeoisasse": "embourgeoiser",
    "embourgeoisassent": "embourgeoiser",
    "embourgeoisasses": "embourgeoiser",
    "embourgeoisassiez": "embourgeoiser",
    "embourgeoisassions": "embourgeoiser",
    "embourgeoise": "embourgeoiser",
    "embourgeoisements": "embourgeoisement",
    "embourgeoisent": "embourgeoiser",
    "embourgeoisera": "embourgeoiser",
    "embourgeoiserai": "embourgeoiser",
    "embourgeoiseraient": "embourgeoiser",
    "embourgeoiserais": "embourgeoiser",
    "embourgeoiserait": "embourgeoiser",
    "embourgeoiseras": "embourgeoiser",
    "embourgeoiserez": "embourgeoiser",
    "embourgeoiseriez": "embourgeoiser",
    "embourgeoiserions": "embourgeoiser",
    "embourgeoiserons": "embourgeoiser",
    "embourgeoiseront": "embourgeoiser",
    "embourgeoises": "embourgeoiser",
    "embourgeoisez": "embourgeoiser",
    "embourgeoisiez": "embourgeoiser",
    "embourgeoisions": "embourgeoiser",
    "embourgeoisons": "embourgeoiser",
    "embourgeoisâmes": "embourgeoiser",
    "embourgeoisât": "embourgeoiser",
    "embourgeoisâtes": "embourgeoiser",
    "embourgeoisèrent": "embourgeoiser",
    "embourgeoisé": "embourgeoiser",
    "embourgeoisée": "embourgeoiser",
    "embourgeoisées": "embourgeoiser",
    "embourgeoisés": "embourgeoiser",
    "embouteilla": "embouteiller",
    "embouteillages": "embouteillage",
    "embouteillai": "embouteiller",
    "embouteillaient": "embouteiller",
    "embouteillais": "embouteiller",
    "embouteillait": "embouteiller",
    "embouteillant": "embouteiller",
    "embouteillas": "embouteiller",
    "embouteillasse": "embouteiller",
    "embouteillassent": "embouteiller",
    "embouteillasses": "embouteiller",
    "embouteillassiez": "embouteiller",
    "embouteillassions": "embouteiller",
    "embouteille": "embouteiller",
    "embouteillent": "embouteiller",
    "embouteillera": "embouteiller",
    "embouteillerai": "embouteiller",
    "embouteilleraient": "embouteiller",
    "embouteillerais": "embouteiller",
    "embouteillerait": "embouteiller",
    "embouteilleras": "embouteiller",
    "embouteillerez": "embouteiller",
    "embouteilleriez": "embouteiller",
    "embouteillerions": "embouteiller",
    "embouteillerons": "embouteiller",
    "embouteilleront": "embouteiller",
    "embouteilles": "embouteiller",
    "embouteilleurs": "embouteilleur",
    "embouteillez": "embouteiller",
    "embouteilliez": "embouteiller",
    "embouteillions": "embouteiller",
    "embouteillons": "embouteiller",
    "embouteillâmes": "embouteiller",
    "embouteillât": "embouteiller",
    "embouteillâtes": "embouteiller",
    "embouteillèrent": "embouteiller",
    "embouteillé": "embouteiller",
    "embouteillée": "embouteiller",
    "embouteillées": "embouteiller",
    "embouteillés": "embouteiller",
    "embouti": "emboutir",
    "emboutie": "emboutir",
    "embouties": "emboutir",
    "emboutira": "emboutir",
    "emboutirai": "emboutir",
    "emboutiraient": "emboutir",
    "emboutirais": "emboutir",
    "emboutirait": "emboutir",
    "emboutiras": "emboutir",
    "emboutirent": "emboutir",
    "emboutirez": "emboutir",
    "emboutiriez": "emboutir",
    "emboutirions": "emboutir",
    "emboutirons": "emboutir",
    "emboutiront": "emboutir",
    "emboutis": "emboutir",
    "emboutissaient": "emboutir",
    "emboutissais": "emboutir",
    "emboutissait": "emboutir",
    "emboutissant": "emboutir",
    "emboutisse": "emboutir",
    "emboutissent": "emboutir",
    "emboutisses": "emboutir",
    "emboutisseuse": "emboutisseur",
    "emboutissez": "emboutir",
    "emboutissiez": "emboutir",
    "emboutissions": "emboutir",
    "emboutissons": "emboutir",
    "emboutit": "emboutir",
    "embouts": "embout",
    "emboutîmes": "emboutir",
    "emboutît": "emboutir",
    "emboutîtes": "emboutir",
    "emboîta": "emboîter",
    "emboîtables": "emboîtable",
    "emboîtages": "emboîtage",
    "emboîtai": "emboîter",
    "emboîtaient": "emboîter",
    "emboîtais": "emboîter",
    "emboîtait": "emboîter",
    "emboîtant": "emboîter",
    "emboîtas": "emboîter",
    "emboîtasse": "emboîter",
    "emboîtassent": "emboîter",
    "emboîtasses": "emboîter",
    "emboîtassiez": "emboîter",
    "emboîtassions": "emboîter",
    "emboîte": "emboîter",
    "emboîtent": "emboîter",
    "emboîtera": "emboîter",
    "emboîterai": "emboîter",
    "emboîteraient": "emboîter",
    "emboîterais": "emboîter",
    "emboîterait": "emboîter",
    "emboîteras": "emboîter",
    "emboîterez": "emboîter",
    "emboîteriez": "emboîter",
    "emboîterions": "emboîter",
    "emboîterons": "emboîter",
    "emboîteront": "emboîter",
    "emboîtes": "emboîter",
    "emboîtez": "emboîter",
    "emboîtiez": "emboîter",
    "emboîtions": "emboîter",
    "emboîtons": "emboîter",
    "emboîtures": "emboîture",
    "emboîtâmes": "emboîter",
    "emboîtât": "emboîter",
    "emboîtâtes": "emboîter",
    "emboîtèrent": "emboîter",
    "emboîté": "emboîter",
    "emboîtée": "emboîter",
    "emboîtées": "emboîter",
    "emboîtés": "emboîter",
    "embraie": "embrayer",
    "embraient": "embrayer",
    "embraiera": "embrayer",
    "embraierai": "embrayer",
    "embraieraient": "embrayer",
    "embraierais": "embrayer",
    "embraierait": "embrayer",
    "embraieras": "embrayer",
    "embraierez": "embrayer",
    "embraieriez": "embrayer",
    "embraierions": "embrayer",
    "embraierons": "embrayer",
    "embraieront": "embrayer",
    "embraies": "embrayer",
    "embrancha": "embrancher",
    "embranchai": "embrancher",
    "embranchaient": "embrancher",
    "embranchais": "embrancher",
    "embranchait": "embrancher",
    "embranchant": "embrancher",
    "embranchas": "embrancher",
    "embranchasse": "embrancher",
    "embranchassent": "embrancher",
    "embranchasses": "embrancher",
    "embranchassiez": "embrancher",
    "embranchassions": "embrancher",
    "embranche": "embrancher",
    "embranchements": "embranchement",
    "embranchent": "embrancher",
    "embranchera": "embrancher",
    "embrancherai": "embrancher",
    "embrancheraient": "embrancher",
    "embrancherais": "embrancher",
    "embrancherait": "embrancher",
    "embrancheras": "embrancher",
    "embrancherez": "embrancher",
    "embrancheriez": "embrancher",
    "embrancherions": "embrancher",
    "embrancherons": "embrancher",
    "embrancheront": "embrancher",
    "embranches": "embrancher",
    "embranchez": "embrancher",
    "embranchiez": "embrancher",
    "embranchions": "embrancher",
    "embranchons": "embrancher",
    "embranchâmes": "embrancher",
    "embranchât": "embrancher",
    "embranchâtes": "embrancher",
    "embranchèrent": "embrancher",
    "embranché": "embrancher",
    "embranchée": "embrancher",
    "embranchées": "embrancher",
    "embranchés": "embrancher",
    "embraqua": "embraquer",
    "embraquai": "embraquer",
    "embraquaient": "embraquer",
    "embraquais": "embraquer",
    "embraquait": "embraquer",
    "embraquant": "embraquer",
    "embraquas": "embraquer",
    "embraquasse": "embraquer",
    "embraquassent": "embraquer",
    "embraquasses": "embraquer",
    "embraquassiez": "embraquer",
    "embraquassions": "embraquer",
    "embraque": "embraquer",
    "embraquent": "embraquer",
    "embraquera": "embraquer",
    "embraquerai": "embraquer",
    "embraqueraient": "embraquer",
    "embraquerais": "embraquer",
    "embraquerait": "embraquer",
    "embraqueras": "embraquer",
    "embraquerez": "embraquer",
    "embraqueriez": "embraquer",
    "embraquerions": "embraquer",
    "embraquerons": "embraquer",
    "embraqueront": "embraquer",
    "embraques": "embraquer",
    "embraquez": "embraquer",
    "embraquiez": "embraquer",
    "embraquions": "embraquer",
    "embraquons": "embraquer",
    "embraquâmes": "embraquer",
    "embraquât": "embraquer",
    "embraquâtes": "embraquer",
    "embraquèrent": "embraquer",
    "embraqué": "embraquer",
    "embraquée": "embraquer",
    "embraquées": "embraquer",
    "embraqués": "embraquer",
    "embrasa": "embraser",
    "embrasai": "embraser",
    "embrasaient": "embraser",
    "embrasais": "embraser",
    "embrasait": "embraser",
    "embrasant": "embraser",
    "embrasas": "embraser",
    "embrasasse": "embraser",
    "embrasassent": "embraser",
    "embrasasses": "embraser",
    "embrasassiez": "embraser",
    "embrasassions": "embraser",
    "embrase": "embraser",
    "embrasements": "embrasement",
    "embrasent": "embraser",
    "embrasera": "embraser",
    "embraserai": "embraser",
    "embraseraient": "embraser",
    "embraserais": "embraser",
    "embraserait": "embraser",
    "embraseras": "embraser",
    "embraserez": "embraser",
    "embraseriez": "embraser",
    "embraserions": "embraser",
    "embraserons": "embraser",
    "embraseront": "embraser",
    "embrases": "embraser",
    "embrasez": "embraser",
    "embrasiez": "embraser",
    "embrasions": "embraser",
    "embrasons": "embraser",
    "embrassa": "embrasser",
    "embrassades": "embrassade",
    "embrassai": "embrasser",
    "embrassaient": "embrasser",
    "embrassais": "embrasser",
    "embrassait": "embrasser",
    "embrassant": "embrasser",
    "embrassas": "embrasser",
    "embrassasse": "embrasser",
    "embrassassent": "embrasser",
    "embrassasses": "embrasser",
    "embrassassiez": "embrasser",
    "embrassassions": "embrasser",
    "embrasse": "embrasser",
    "embrassements": "embrassement",
    "embrassent": "embrasser",
    "embrassera": "embrasser",
    "embrasserai": "embrasser",
    "embrasseraient": "embrasser",
    "embrasserais": "embrasser",
    "embrasserait": "embrasser",
    "embrasseras": "embrasser",
    "embrasserez": "embrasser",
    "embrasseriez": "embrasser",
    "embrasserions": "embrasser",
    "embrasserons": "embrasser",
    "embrasseront": "embrasser",
    "embrasses": "embrasser",
    "embrasseurs": "embrasseur",
    "embrasseuse": "embrasseur",
    "embrasseuses": "embrasseur",
    "embrassez": "embrasser",
    "embrassiez": "embrasser",
    "embrassions": "embrasser",
    "embrassons": "embrasser",
    "embrassâmes": "embrasser",
    "embrassât": "embrasser",
    "embrassâtes": "embrasser",
    "embrassèrent": "embrasser",
    "embrassé": "embrasser",
    "embrassée": "embrasser",
    "embrassées": "embrasser",
    "embrassés": "embrasser",
    "embrasures": "embrasure",
    "embrasâmes": "embraser",
    "embrasât": "embraser",
    "embrasâtes": "embraser",
    "embrasèrent": "embraser",
    "embrasé": "embraser",
    "embrasée": "embraser",
    "embrasées": "embraser",
    "embrasés": "embraser",
    "embraya": "embrayer",
    "embrayages": "embrayage",
    "embrayai": "embrayer",
    "embrayaient": "embrayer",
    "embrayais": "embrayer",
    "embrayait": "embrayer",
    "embrayant": "embrayer",
    "embrayas": "embrayer",
    "embrayasse": "embrayer",
    "embrayassent": "embrayer",
    "embrayasses": "embrayer",
    "embrayassiez": "embrayer",
    "embrayassions": "embrayer",
    "embraye": "embrayer",
    "embrayent": "embrayer",
    "embrayera": "embrayer",
    "embrayerai": "embrayer",
    "embrayeraient": "embrayer",
    "embrayerais": "embrayer",
    "embrayerait": "embrayer",
    "embrayeras": "embrayer",
    "embrayerez": "embrayer",
    "embrayeriez": "embrayer",
    "embrayerions": "embrayer",
    "embrayerons": "embrayer",
    "embrayeront": "embrayer",
    "embrayes": "embrayer",
    "embrayez": "embrayer",
    "embrayiez": "embrayer",
    "embrayions": "embrayer",
    "embrayons": "embrayer",
    "embrayâmes": "embrayer",
    "embrayât": "embrayer",
    "embrayâtes": "embrayer",
    "embrayèrent": "embrayer",
    "embrayé": "embrayer",
    "embrayée": "embrayer",
    "embrayées": "embrayer",
    "embrayés": "embrayer",
    "embrigada": "embrigader",
    "embrigadai": "embrigader",
    "embrigadaient": "embrigader",
    "embrigadais": "embrigader",
    "embrigadait": "embrigader",
    "embrigadant": "embrigader",
    "embrigadas": "embrigader",
    "embrigadasse": "embrigader",
    "embrigadassent": "embrigader",
    "embrigadasses": "embrigader",
    "embrigadassiez": "embrigader",
    "embrigadassions": "embrigader",
    "embrigade": "embrigader",
    "embrigadent": "embrigader",
    "embrigadera": "embrigader",
    "embrigaderai": "embrigader",
    "embrigaderaient": "embrigader",
    "embrigaderais": "embrigader",
    "embrigaderait": "embrigader",
    "embrigaderas": "embrigader",
    "embrigaderez": "embrigader",
    "embrigaderiez": "embrigader",
    "embrigaderions": "embrigader",
    "embrigaderons": "embrigader",
    "embrigaderont": "embrigader",
    "embrigades": "embrigader",
    "embrigadez": "embrigader",
    "embrigadiez": "embrigader",
    "embrigadions": "embrigader",
    "embrigadons": "embrigader",
    "embrigadâmes": "embrigader",
    "embrigadât": "embrigader",
    "embrigadâtes": "embrigader",
    "embrigadèrent": "embrigader",
    "embrigadé": "embrigader",
    "embrigadée": "embrigader",
    "embrigadées": "embrigader",
    "embrigadés": "embrigader",
    "embringua": "embringuer",
    "embringuai": "embringuer",
    "embringuaient": "embringuer",
    "embringuais": "embringuer",
    "embringuait": "embringuer",
    "embringuant": "embringuer",
    "embringuas": "embringuer",
    "embringuasse": "embringuer",
    "embringuassent": "embringuer",
    "embringuasses": "embringuer",
    "embringuassiez": "embringuer",
    "embringuassions": "embringuer",
    "embringue": "embringuer",
    "embringuent": "embringuer",
    "embringuera": "embringuer",
    "embringuerai": "embringuer",
    "embringueraient": "embringuer",
    "embringuerais": "embringuer",
    "embringuerait": "embringuer",
    "embringueras": "embringuer",
    "embringuerez": "embringuer",
    "embringueriez": "embringuer",
    "embringuerions": "embringuer",
    "embringuerons": "embringuer",
    "embringueront": "embringuer",
    "embringues": "embringuer",
    "embringuez": "embringuer",
    "embringuiez": "embringuer",
    "embringuions": "embringuer",
    "embringuons": "embringuer",
    "embringuâmes": "embringuer",
    "embringuât": "embringuer",
    "embringuâtes": "embringuer",
    "embringuèrent": "embringuer",
    "embringué": "embringuer",
    "embringuée": "embringuer",
    "embringuées": "embringuer",
    "embringués": "embringuer",
    "embrocations": "embrocation",
    "embrocha": "embrocher",
    "embrochai": "embrocher",
    "embrochaient": "embrocher",
    "embrochais": "embrocher",
    "embrochait": "embrocher",
    "embrochant": "embrocher",
    "embrochas": "embrocher",
    "embrochasse": "embrocher",
    "embrochassent": "embrocher",
    "embrochasses": "embrocher",
    "embrochassiez": "embrocher",
    "embrochassions": "embrocher",
    "embroche": "embrocher",
    "embrochent": "embrocher",
    "embrochera": "embrocher",
    "embrocherai": "embrocher",
    "embrocheraient": "embrocher",
    "embrocherais": "embrocher",
    "embrocherait": "embrocher",
    "embrocheras": "embrocher",
    "embrocherez": "embrocher",
    "embrocheriez": "embrocher",
    "embrocherions": "embrocher",
    "embrocherons": "embrocher",
    "embrocheront": "embrocher",
    "embroches": "embrocher",
    "embrochez": "embrocher",
    "embrochiez": "embrocher",
    "embrochions": "embrocher",
    "embrochons": "embrocher",
    "embrochâmes": "embrocher",
    "embrochât": "embrocher",
    "embrochâtes": "embrocher",
    "embrochèrent": "embrocher",
    "embroché": "embrocher",
    "embrochée": "embrocher",
    "embrochées": "embrocher",
    "embrochés": "embrocher",
    "embrouilla": "embrouiller",
    "embrouillai": "embrouiller",
    "embrouillaient": "embrouiller",
    "embrouillais": "embrouiller",
    "embrouillait": "embrouiller",
    "embrouillaminis": "embrouillamini",
    "embrouillant": "embrouiller",
    "embrouillas": "embrouiller",
    "embrouillasse": "embrouiller",
    "embrouillassent": "embrouiller",
    "embrouillasses": "embrouiller",
    "embrouillassiez": "embrouiller",
    "embrouillassions": "embrouiller",
    "embrouille": "embrouiller",
    "embrouillements": "embrouillement",
    "embrouillent": "embrouiller",
    "embrouillera": "embrouiller",
    "embrouillerai": "embrouiller",
    "embrouilleraient": "embrouiller",
    "embrouillerais": "embrouiller",
    "embrouillerait": "embrouiller",
    "embrouilleras": "embrouiller",
    "embrouillerez": "embrouiller",
    "embrouilleriez": "embrouiller",
    "embrouillerions": "embrouiller",
    "embrouillerons": "embrouiller",
    "embrouilleront": "embrouiller",
    "embrouilles": "embrouiller",
    "embrouilleurs": "embrouilleur",
    "embrouilleuses": "embrouilleur",
    "embrouillez": "embrouiller",
    "embrouilliez": "embrouiller",
    "embrouillions": "embrouiller",
    "embrouillons": "embrouiller",
    "embrouillâmes": "embrouiller",
    "embrouillât": "embrouiller",
    "embrouillâtes": "embrouiller",
    "embrouillèrent": "embrouiller",
    "embrouillé": "embrouiller",
    "embrouillée": "embrouiller",
    "embrouillées": "embrouiller",
    "embrouillés": "embrouiller",
    "embroussaille": "embroussailler",
    "embroussaillée": "embroussailler",
    "embroussaillées": "embroussailler",
    "embroussaillés": "embroussailler",
    "embruma": "embrumer",
    "embrumai": "embrumer",
    "embrumaient": "embrumer",
    "embrumais": "embrumer",
    "embrumait": "embrumer",
    "embrumant": "embrumer",
    "embrumas": "embrumer",
    "embrumasse": "embrumer",
    "embrumassent": "embrumer",
    "embrumasses": "embrumer",
    "embrumassiez": "embrumer",
    "embrumassions": "embrumer",
    "embrume": "embrumer",
    "embrument": "embrumer",
    "embrumera": "embrumer",
    "embrumerai": "embrumer",
    "embrumeraient": "embrumer",
    "embrumerais": "embrumer",
    "embrumerait": "embrumer",
    "embrumeras": "embrumer",
    "embrumerez": "embrumer",
    "embrumeriez": "embrumer",
    "embrumerions": "embrumer",
    "embrumerons": "embrumer",
    "embrumeront": "embrumer",
    "embrumes": "embrumer",
    "embrumez": "embrumer",
    "embrumiez": "embrumer",
    "embrumions": "embrumer",
    "embrumons": "embrumer",
    "embrumâmes": "embrumer",
    "embrumât": "embrumer",
    "embrumâtes": "embrumer",
    "embrumèrent": "embrumer",
    "embrumé": "embrumer",
    "embrumée": "embrumer",
    "embrumées": "embrumer",
    "embrumés": "embrumer",
    "embruni": "embrunir",
    "embrunie": "embrunir",
    "embrunies": "embrunir",
    "embrunira": "embrunir",
    "embrunirai": "embrunir",
    "embruniraient": "embrunir",
    "embrunirais": "embrunir",
    "embrunirait": "embrunir",
    "embruniras": "embrunir",
    "embrunirent": "embrunir",
    "embrunirez": "embrunir",
    "embruniriez": "embrunir",
    "embrunirions": "embrunir",
    "embrunirons": "embrunir",
    "embruniront": "embrunir",
    "embrunis": "embrunir",
    "embrunissaient": "embrunir",
    "embrunissais": "embrunir",
    "embrunissait": "embrunir",
    "embrunissant": "embrunir",
    "embrunisse": "embrunir",
    "embrunissent": "embrunir",
    "embrunisses": "embrunir",
    "embrunissez": "embrunir",
    "embrunissiez": "embrunir",
    "embrunissions": "embrunir",
    "embrunissons": "embrunir",
    "embrunit": "embrunir",
    "embruns": "embrun",
    "embrunîmes": "embrunir",
    "embrunît": "embrunir",
    "embrunîtes": "embrunir",
    "embryonnaires": "embryonnaire",
    "embryons": "embryon",
    "embu": "emboire",
    "embua": "embuer",
    "embuai": "embuer",
    "embuaient": "embuer",
    "embuais": "embuer",
    "embuait": "embuer",
    "embuant": "embuer",
    "embuas": "embuer",
    "embuasse": "embuer",
    "embuassent": "embuer",
    "embuasses": "embuer",
    "embuassiez": "embuer",
    "embuassions": "embuer",
    "embue": "embuer",
    "embuent": "embuer",
    "embuera": "embuer",
    "embuerai": "embuer",
    "embueraient": "embuer",
    "embuerais": "embuer",
    "embuerait": "embuer",
    "embueras": "embuer",
    "embuerez": "embuer",
    "embueriez": "embuer",
    "embuerions": "embuer",
    "embuerons": "embuer",
    "embueront": "embuer",
    "embues": "embuer",
    "embuez": "embuer",
    "embuiez": "embuer",
    "embuions": "embuer",
    "embuons": "embuer",
    "emburent": "emboire",
    "embus": "embu",
    "embuscades": "embuscade",
    "embusqua": "embusquer",
    "embusquai": "embusquer",
    "embusquaient": "embusquer",
    "embusquais": "embusquer",
    "embusquait": "embusquer",
    "embusquant": "embusquer",
    "embusquas": "embusquer",
    "embusquasse": "embusquer",
    "embusquassent": "embusquer",
    "embusquasses": "embusquer",
    "embusquassiez": "embusquer",
    "embusquassions": "embusquer",
    "embusque": "embusquer",
    "embusquent": "embusquer",
    "embusquera": "embusquer",
    "embusquerai": "embusquer",
    "embusqueraient": "embusquer",
    "embusquerais": "embusquer",
    "embusquerait": "embusquer",
    "embusqueras": "embusquer",
    "embusquerez": "embusquer",
    "embusqueriez": "embusquer",
    "embusquerions": "embusquer",
    "embusquerons": "embusquer",
    "embusqueront": "embusquer",
    "embusques": "embusquer",
    "embusquez": "embusquer",
    "embusquiez": "embusquer",
    "embusquions": "embusquer",
    "embusquons": "embusquer",
    "embusquâmes": "embusquer",
    "embusquât": "embusquer",
    "embusquâtes": "embusquer",
    "embusquèrent": "embusquer",
    "embusqué": "embusquer",
    "embusquée": "embusquer",
    "embusquées": "embusquer",
    "embusqués": "embusquer",
    "embusse": "emboire",
    "embussent": "emboire",
    "embusses": "emboire",
    "embussiez": "emboire",
    "embussions": "emboire",
    "embut": "emboire",
    "embuvaient": "emboire",
    "embuvais": "emboire",
    "embuvait": "emboire",
    "embuvant": "emboire",
    "embuvez": "emboire",
    "embuviez": "emboire",
    "embuvions": "emboire",
    "embuvons": "emboire",
    "embuâmes": "embuer",
    "embuât": "embuer",
    "embuâtes": "embuer",
    "embuèrent": "embuer",
    "embué": "embuer",
    "embuée": "embuer",
    "embuées": "embuer",
    "embués": "embuer",
    "embâcles": "embâcle",
    "embéguinées": "embéguiner",
    "embêta": "embêter",
    "embêtai": "embêter",
    "embêtaient": "embêter",
    "embêtais": "embêter",
    "embêtait": "embêter",
    "embêtant": "embêter",
    "embêtante": "embêtant",
    "embêtantes": "embêtant",
    "embêtants": "embêtant",
    "embêtas": "embêter",
    "embêtasse": "embêter",
    "embêtassent": "embêter",
    "embêtasses": "embêter",
    "embêtassiez": "embêter",
    "embêtassions": "embêter",
    "embête": "embêter",
    "embêtements": "embêtement",
    "embêtent": "embêter",
    "embêtera": "embêter",
    "embêterai": "embêter",
    "embêteraient": "embêter",
    "embêterais": "embêter",
    "embêterait": "embêter",
    "embêteras": "embêter",
    "embêterez": "embêter",
    "embêteriez": "embêter",
    "embêterions": "embêter",
    "embêterons": "embêter",
    "embêteront": "embêter",
    "embêtes": "embêter",
    "embêtez": "embêter",
    "embêtiez": "embêter",
    "embêtions": "embêter",
    "embêtons": "embêter",
    "embêtâmes": "embêter",
    "embêtât": "embêter",
    "embêtâtes": "embêter",
    "embêtèrent": "embêter",
    "embêté": "embêter",
    "embêtée": "embêter",
    "embêtées": "embêter",
    "embêtés": "embêter",
    "embûches": "embûche",
    "embûmes": "emboire",
    "embût": "emboire",
    "embûtes": "emboire",
    "emmagasina": "emmagasiner",
    "emmagasinai": "emmagasiner",
    "emmagasinaient": "emmagasiner",
    "emmagasinais": "emmagasiner",
    "emmagasinait": "emmagasiner",
    "emmagasinant": "emmagasiner",
    "emmagasinas": "emmagasiner",
    "emmagasinasse": "emmagasiner",
    "emmagasinassent": "emmagasiner",
    "emmagasinasses": "emmagasiner",
    "emmagasinassiez": "emmagasiner",
    "emmagasinassions": "emmagasiner",
    "emmagasine": "emmagasiner",
    "emmagasinent": "emmagasiner",
    "emmagasinera": "emmagasiner",
    "emmagasinerai": "emmagasiner",
    "emmagasineraient": "emmagasiner",
    "emmagasinerais": "emmagasiner",
    "emmagasinerait": "emmagasiner",
    "emmagasineras": "emmagasiner",
    "emmagasinerez": "emmagasiner",
    "emmagasineriez": "emmagasiner",
    "emmagasinerions": "emmagasiner",
    "emmagasinerons": "emmagasiner",
    "emmagasineront": "emmagasiner",
    "emmagasines": "emmagasiner",
    "emmagasinez": "emmagasiner",
    "emmagasiniez": "emmagasiner",
    "emmagasinions": "emmagasiner",
    "emmagasinons": "emmagasiner",
    "emmagasinâmes": "emmagasiner",
    "emmagasinât": "emmagasiner",
    "emmagasinâtes": "emmagasiner",
    "emmagasinèrent": "emmagasiner",
    "emmagasiné": "emmagasiner",
    "emmagasinée": "emmagasiner",
    "emmagasinées": "emmagasiner",
    "emmagasinés": "emmagasiner",
    "emmaillota": "emmailloter",
    "emmaillotai": "emmailloter",
    "emmaillotaient": "emmailloter",
    "emmaillotais": "emmailloter",
    "emmaillotait": "emmailloter",
    "emmaillotant": "emmailloter",
    "emmaillotas": "emmailloter",
    "emmaillotasse": "emmailloter",
    "emmaillotassent": "emmailloter",
    "emmaillotasses": "emmailloter",
    "emmaillotassiez": "emmailloter",
    "emmaillotassions": "emmailloter",
    "emmaillote": "emmailloter",
    "emmaillotent": "emmailloter",
    "emmaillotera": "emmailloter",
    "emmailloterai": "emmailloter",
    "emmailloteraient": "emmailloter",
    "emmailloterais": "emmailloter",
    "emmailloterait": "emmailloter",
    "emmailloteras": "emmailloter",
    "emmailloterez": "emmailloter",
    "emmailloteriez": "emmailloter",
    "emmailloterions": "emmailloter",
    "emmailloterons": "emmailloter",
    "emmailloteront": "emmailloter",
    "emmaillotes": "emmailloter",
    "emmaillotez": "emmailloter",
    "emmaillotiez": "emmailloter",
    "emmaillotions": "emmailloter",
    "emmaillotons": "emmailloter",
    "emmaillotâmes": "emmailloter",
    "emmaillotât": "emmailloter",
    "emmaillotâtes": "emmailloter",
    "emmaillotèrent": "emmailloter",
    "emmailloté": "emmailloter",
    "emmaillotée": "emmailloter",
    "emmaillotées": "emmailloter",
    "emmaillotés": "emmailloter",
    "emmancha": "emmancher",
    "emmanchai": "emmancher",
    "emmanchaient": "emmancher",
    "emmanchais": "emmancher",
    "emmanchait": "emmancher",
    "emmanchant": "emmancher",
    "emmanchas": "emmancher",
    "emmanchasse": "emmancher",
    "emmanchassent": "emmancher",
    "emmanchasses": "emmancher",
    "emmanchassiez": "emmancher",
    "emmanchassions": "emmancher",
    "emmanche": "emmancher",
    "emmanchent": "emmancher",
    "emmanchera": "emmancher",
    "emmancherai": "emmancher",
    "emmancheraient": "emmancher",
    "emmancherais": "emmancher",
    "emmancherait": "emmancher",
    "emmancheras": "emmancher",
    "emmancherez": "emmancher",
    "emmancheriez": "emmancher",
    "emmancherions": "emmancher",
    "emmancherons": "emmancher",
    "emmancheront": "emmancher",
    "emmanches": "emmancher",
    "emmanchez": "emmancher",
    "emmanchiez": "emmancher",
    "emmanchions": "emmancher",
    "emmanchons": "emmancher",
    "emmanchures": "emmanchure",
    "emmanchâmes": "emmancher",
    "emmanchât": "emmancher",
    "emmanchâtes": "emmancher",
    "emmanchèrent": "emmancher",
    "emmanché": "emmancher",
    "emmanchée": "emmancher",
    "emmanchées": "emmancher",
    "emmanchés": "emmancher",
    "emmena": "emmener",
    "emmenai": "emmener",
    "emmenaient": "emmener",
    "emmenais": "emmener",
    "emmenait": "emmener",
    "emmenant": "emmener",
    "emmenas": "emmener",
    "emmenasse": "emmener",
    "emmenassent": "emmener",
    "emmenasses": "emmener",
    "emmenassiez": "emmener",
    "emmenassions": "emmener",
    "emmener": "expliquer",
    "emmenez": "emmener",
    "emmeniez": "emmener",
    "emmenions": "emmener",
    "emmenons": "emmener",
    "emmenotté": "emmenotter",
    "emmentals": "emmental",
    "emmenthals": "emmenthal",
    "emmenâmes": "emmener",
    "emmenât": "emmener",
    "emmenâtes": "emmener",
    "emmenèrent": "emmener",
    "emmené": "emmener",
    "emmenée": "emmener",
    "emmenées": "emmener",
    "emmenés": "emmener",
    "emmerda": "emmerder",
    "emmerdaient": "emmerder",
    "emmerdais": "emmerder",
    "emmerdait": "emmerder",
    "emmerdant": "emmerder",
    "emmerdante": "emmerdant",
    "emmerdantes": "emmerdant",
    "emmerdants": "emmerdant",
    "emmerdatoires": "emmerdatoire",
    "emmerde": "emmerder",
    "emmerdements": "emmerdement",
    "emmerdent": "emmerder",
    "emmerdera": "emmerder",
    "emmerderai": "emmerder",
    "emmerderaient": "emmerder",
    "emmerderais": "emmerder",
    "emmerderait": "emmerder",
    "emmerderez": "emmerder",
    "emmerderont": "emmerder",
    "emmerdes": "emmerder",
    "emmerdeurs": "emmerdeur",
    "emmerdeuse": "emmerdeur",
    "emmerdeuses": "emmerdeur",
    "emmerdez": "emmerder",
    "emmerdons": "emmerder",
    "emmerdé": "emmerder",
    "emmerdée": "emmerder",
    "emmerdés": "emmerder",
    "emmiella": "emmieller",
    "emmiellai": "emmieller",
    "emmiellaient": "emmieller",
    "emmiellais": "emmieller",
    "emmiellait": "emmieller",
    "emmiellant": "emmieller",
    "emmiellas": "emmieller",
    "emmiellasse": "emmieller",
    "emmiellassent": "emmieller",
    "emmiellasses": "emmieller",
    "emmiellassiez": "emmieller",
    "emmiellassions": "emmieller",
    "emmielle": "emmieller",
    "emmiellent": "emmieller",
    "emmiellera": "emmieller",
    "emmiellerai": "emmieller",
    "emmielleraient": "emmieller",
    "emmiellerais": "emmieller",
    "emmiellerait": "emmieller",
    "emmielleras": "emmieller",
    "emmiellerez": "emmieller",
    "emmielleriez": "emmieller",
    "emmiellerions": "emmieller",
    "emmiellerons": "emmieller",
    "emmielleront": "emmieller",
    "emmielles": "emmieller",
    "emmiellez": "emmieller",
    "emmielliez": "emmieller",
    "emmiellions": "emmieller",
    "emmiellons": "emmieller",
    "emmiellâmes": "emmieller",
    "emmiellât": "emmieller",
    "emmiellâtes": "emmieller",
    "emmiellèrent": "emmieller",
    "emmiellé": "emmieller",
    "emmiellée": "emmieller",
    "emmiellées": "emmieller",
    "emmiellés": "emmieller",
    "emmitoufla": "emmitoufler",
    "emmitouflai": "emmitoufler",
    "emmitouflaient": "emmitoufler",
    "emmitouflais": "emmitoufler",
    "emmitouflait": "emmitoufler",
    "emmitouflant": "emmitoufler",
    "emmitouflas": "emmitoufler",
    "emmitouflasse": "emmitoufler",
    "emmitouflassent": "emmitoufler",
    "emmitouflasses": "emmitoufler",
    "emmitouflassiez": "emmitoufler",
    "emmitouflassions": "emmitoufler",
    "emmitoufle": "emmitoufler",
    "emmitouflent": "emmitoufler",
    "emmitouflera": "emmitoufler",
    "emmitouflerai": "emmitoufler",
    "emmitoufleraient": "emmitoufler",
    "emmitouflerais": "emmitoufler",
    "emmitouflerait": "emmitoufler",
    "emmitoufleras": "emmitoufler",
    "emmitouflerez": "emmitoufler",
    "emmitoufleriez": "emmitoufler",
    "emmitouflerions": "emmitoufler",
    "emmitouflerons": "emmitoufler",
    "emmitoufleront": "emmitoufler",
    "emmitoufles": "emmitoufler",
    "emmitouflez": "emmitoufler",
    "emmitoufliez": "emmitoufler",
    "emmitouflions": "emmitoufler",
    "emmitouflons": "emmitoufler",
    "emmitouflâmes": "emmitoufler",
    "emmitouflât": "emmitoufler",
    "emmitouflâtes": "emmitoufler",
    "emmitouflèrent": "emmitoufler",
    "emmitouflé": "emmitoufler",
    "emmitouflée": "emmitoufler",
    "emmitouflées": "emmitoufler",
    "emmitouflés": "emmitoufler",
    "emmouflé": "emmoufler",
    "emmouscaillements": "emmouscaillement",
    "emmura": "emmurer",
    "emmurai": "emmurer",
    "emmuraient": "emmurer",
    "emmurais": "emmurer",
    "emmurait": "emmurer",
    "emmurant": "emmurer",
    "emmuras": "emmurer",
    "emmurasse": "emmurer",
    "emmurassent": "emmurer",
    "emmurasses": "emmurer",
    "emmurassiez": "emmurer",
    "emmurassions": "emmurer",
    "emmure": "emmurer",
    "emmurent": "emmurer",
    "emmurera": "emmurer",
    "emmurerai": "emmurer",
    "emmureraient": "emmurer",
    "emmurerais": "emmurer",
    "emmurerait": "emmurer",
    "emmureras": "emmurer",
    "emmurerez": "emmurer",
    "emmureriez": "emmurer",
    "emmurerions": "emmurer",
    "emmurerons": "emmurer",
    "emmureront": "emmurer",
    "emmures": "emmurer",
    "emmurez": "emmurer",
    "emmuriez": "emmurer",
    "emmurions": "emmurer",
    "emmurons": "emmurer",
    "emmurâmes": "emmurer",
    "emmurât": "emmurer",
    "emmurâtes": "emmurer",
    "emmurèrent": "emmurer",
    "emmuré": "emmurer",
    "emmurée": "emmurer",
    "emmurées": "emmurer",
    "emmurés": "emmurer",
    "emmène": "emmener",
    "emmènent": "emmener",
    "emmènera": "emmener",
    "emmènerai": "emmener",
    "emmèneraient": "emmener",
    "emmènerais": "emmener",
    "emmènerait": "emmener",
    "emmèneras": "emmener",
    "emmènerez": "emmener",
    "emmèneriez": "emmener",
    "emmènerions": "emmener",
    "emmènerons": "emmener",
    "emmèneront": "emmener",
    "emmènes": "emmener",
    "emménage": "emménager",
    "emménagea": "emménager",
    "emménageai": "emménager",
    "emménageaient": "emménager",
    "emménageais": "emménager",
    "emménageait": "emménager",
    "emménageant": "emménager",
    "emménageas": "emménager",
    "emménageasse": "emménager",
    "emménageassent": "emménager",
    "emménageasses": "emménager",
    "emménageassiez": "emménager",
    "emménageassions": "emménager",
    "emménagent": "emménager",
    "emménageons": "emménager",
    "emménagera": "emménager",
    "emménagerai": "emménager",
    "emménageraient": "emménager",
    "emménagerais": "emménager",
    "emménagerait": "emménager",
    "emménageras": "emménager",
    "emménagerez": "emménager",
    "emménageriez": "emménager",
    "emménagerions": "emménager",
    "emménagerons": "emménager",
    "emménageront": "emménager",
    "emménages": "emménager",
    "emménagez": "emménager",
    "emménageâmes": "emménager",
    "emménageât": "emménager",
    "emménageâtes": "emménager",
    "emménagiez": "emménager",
    "emménagions": "emménager",
    "emménagèrent": "emménager",
    "emménagé": "emménager",
    "emménagée": "emménager",
    "emménagées": "emménager",
    "emménagés": "emménager",
    "emmêla": "emmêler",
    "emmêlai": "emmêler",
    "emmêlaient": "emmêler",
    "emmêlais": "emmêler",
    "emmêlait": "emmêler",
    "emmêlant": "emmêler",
    "emmêlas": "emmêler",
    "emmêlasse": "emmêler",
    "emmêlassent": "emmêler",
    "emmêlasses": "emmêler",
    "emmêlassiez": "emmêler",
    "emmêlassions": "emmêler",
    "emmêle": "emmêler",
    "emmêlements": "emmêlement",
    "emmêlent": "emmêler",
    "emmêlera": "emmêler",
    "emmêlerai": "emmêler",
    "emmêleraient": "emmêler",
    "emmêlerais": "emmêler",
    "emmêlerait": "emmêler",
    "emmêleras": "emmêler",
    "emmêlerez": "emmêler",
    "emmêleriez": "emmêler",
    "emmêlerions": "emmêler",
    "emmêlerons": "emmêler",
    "emmêleront": "emmêler",
    "emmêles": "emmêler",
    "emmêlez": "emmêler",
    "emmêliez": "emmêler",
    "emmêlions": "emmêler",
    "emmêlons": "emmêler",
    "emmêlâmes": "emmêler",
    "emmêlât": "emmêler",
    "emmêlâtes": "emmêler",
    "emmêlèrent": "emmêler",
    "emmêlé": "emmêler",
    "emmêlée": "emmêler",
    "emmêlées": "emmêler",
    "emmêlés": "emmêler",
    "empaffe": "empaffer",
    "empaffés": "empaffé",
    "empailla": "empailler",
    "empaillai": "empailler",
    "empaillaient": "empailler",
    "empaillais": "empailler",
    "empaillait": "empailler",
    "empaillant": "empailler",
    "empaillas": "empailler",
    "empaillasse": "empailler",
    "empaillassent": "empailler",
    "empaillasses": "empailler",
    "empaillassiez": "empailler",
    "empaillassions": "empailler",
    "empaille": "empailler",
    "empaillent": "empailler",
    "empaillera": "empailler",
    "empaillerai": "empailler",
    "empailleraient": "empailler",
    "empaillerais": "empailler",
    "empaillerait": "empailler",
    "empailleras": "empailler",
    "empaillerez": "empailler",
    "empailleriez": "empailler",
    "empaillerions": "empailler",
    "empaillerons": "empailler",
    "empailleront": "empailler",
    "empailles": "empailler",
    "empailleurs": "empailleur",
    "empaillez": "empailler",
    "empailliez": "empailler",
    "empaillions": "empailler",
    "empaillons": "empailler",
    "empaillâmes": "empailler",
    "empaillât": "empailler",
    "empaillâtes": "empailler",
    "empaillèrent": "empailler",
    "empaillé": "empailler",
    "empaillée": "empailler",
    "empaillées": "empailler",
    "empaillés": "empailler",
    "empala": "empaler",
    "empalai": "empaler",
    "empalaient": "empaler",
    "empalais": "empaler",
    "empalait": "empaler",
    "empalant": "empaler",
    "empalas": "empaler",
    "empalasse": "empaler",
    "empalassent": "empaler",
    "empalasses": "empaler",
    "empalassiez": "empaler",
    "empalassions": "empaler",
    "empale": "empaler",
    "empalent": "empaler",
    "empalera": "empaler",
    "empalerai": "empaler",
    "empaleraient": "empaler",
    "empalerais": "empaler",
    "empalerait": "empaler",
    "empaleras": "empaler",
    "empalerez": "empaler",
    "empaleriez": "empaler",
    "empalerions": "empaler",
    "empalerons": "empaler",
    "empaleront": "empaler",
    "empales": "empaler",
    "empalez": "empaler",
    "empaliez": "empaler",
    "empalions": "empaler",
    "empalmait": "empalmer",
    "empalme": "empalmer",
    "empalmé": "empalmer",
    "empalons": "empaler",
    "empalâmes": "empaler",
    "empalât": "empaler",
    "empalâtes": "empaler",
    "empalèrent": "empaler",
    "empalé": "empaler",
    "empalée": "empaler",
    "empalées": "empaler",
    "empalés": "empaler",
    "empanacha": "empanacher",
    "empanachai": "empanacher",
    "empanachaient": "empanacher",
    "empanachais": "empanacher",
    "empanachait": "empanacher",
    "empanachant": "empanacher",
    "empanachas": "empanacher",
    "empanachasse": "empanacher",
    "empanachassent": "empanacher",
    "empanachasses": "empanacher",
    "empanachassiez": "empanacher",
    "empanachassions": "empanacher",
    "empanache": "empanacher",
    "empanachent": "empanacher",
    "empanachera": "empanacher",
    "empanacherai": "empanacher",
    "empanacheraient": "empanacher",
    "empanacherais": "empanacher",
    "empanacherait": "empanacher",
    "empanacheras": "empanacher",
    "empanacherez": "empanacher",
    "empanacheriez": "empanacher",
    "empanacherions": "empanacher",
    "empanacherons": "empanacher",
    "empanacheront": "empanacher",
    "empanaches": "empanacher",
    "empanachez": "empanacher",
    "empanachiez": "empanacher",
    "empanachions": "empanacher",
    "empanachons": "empanacher",
    "empanachâmes": "empanacher",
    "empanachât": "empanacher",
    "empanachâtes": "empanacher",
    "empanachèrent": "empanacher",
    "empanaché": "empanacher",
    "empanachée": "empanacher",
    "empanachées": "empanacher",
    "empanachés": "empanacher",
    "empans": "empan",
    "empapaoutent": "empapaouter",
    "empapaouté": "empapaouter",
    "empapaoutés": "empapaouter",
    "empaqueta": "empaqueter",
    "empaquetages": "empaquetage",
    "empaquetai": "empaqueter",
    "empaquetaient": "empaqueter",
    "empaquetais": "empaqueter",
    "empaquetait": "empaqueter",
    "empaquetant": "empaqueter",
    "empaquetas": "empaqueter",
    "empaquetasse": "empaqueter",
    "empaquetassent": "empaqueter",
    "empaquetasses": "empaqueter",
    "empaquetassiez": "empaqueter",
    "empaquetassions": "empaqueter",
    "empaquetez": "empaqueter",
    "empaquetiez": "empaqueter",
    "empaquetions": "empaqueter",
    "empaquetons": "empaqueter",
    "empaquette": "empaqueter",
    "empaquettent": "empaqueter",
    "empaquettera": "empaqueter",
    "empaquetterai": "empaqueter",
    "empaquetteraient": "empaqueter",
    "empaquetterais": "empaqueter",
    "empaquetterait": "empaqueter",
    "empaquetteras": "empaqueter",
    "empaquetterez": "empaqueter",
    "empaquetteriez": "empaqueter",
    "empaquetterions": "empaqueter",
    "empaquetterons": "empaqueter",
    "empaquetteront": "empaqueter",
    "empaquettes": "empaqueter",
    "empaquetâmes": "empaqueter",
    "empaquetât": "empaqueter",
    "empaquetâtes": "empaqueter",
    "empaquetèrent": "empaqueter",
    "empaqueté": "empaqueter",
    "empaquetée": "empaqueter",
    "empaquetées": "empaqueter",
    "empaquetés": "empaqueter",
    "empara": "emparer",
    "emparadisé": "emparadiser",
    "emparai": "emparer",
    "emparaient": "emparer",
    "emparais": "emparer",
    "emparait": "emparer",
    "emparant": "emparer",
    "emparas": "emparer",
    "emparasse": "emparer",
    "emparassent": "emparer",
    "emparasses": "emparer",
    "emparassiez": "emparer",
    "emparassions": "emparer",
    "empare": "emparer",
    "emparent": "emparer",
    "emparera": "emparer",
    "emparerai": "emparer",
    "empareraient": "emparer",
    "emparerais": "emparer",
    "emparerait": "emparer",
    "empareras": "emparer",
    "emparerez": "emparer",
    "empareriez": "emparer",
    "emparerions": "emparer",
    "emparerons": "emparer",
    "empareront": "emparer",
    "empares": "emparer",
    "emparez": "emparer",
    "empariez": "emparer",
    "emparions": "emparer",
    "emparons": "emparer",
    "emparâmes": "emparer",
    "emparât": "emparer",
    "emparâtes": "emparer",
    "emparèrent": "emparer",
    "emparé": "emparer",
    "emparée": "emparer",
    "emparées": "emparer",
    "emparés": "emparer",
    "empathies": "empathie",
    "empathiques": "empathique",
    "empattements": "empattement",
    "empauma": "empaumer",
    "empaumai": "empaumer",
    "empaumaient": "empaumer",
    "empaumais": "empaumer",
    "empaumait": "empaumer",
    "empaumant": "empaumer",
    "empaumas": "empaumer",
    "empaumasse": "empaumer",
    "empaumassent": "empaumer",
    "empaumasses": "empaumer",
    "empaumassiez": "empaumer",
    "empaumassions": "empaumer",
    "empaume": "empaumer",
    "empaument": "empaumer",
    "empaumera": "empaumer",
    "empaumerai": "empaumer",
    "empaumeraient": "empaumer",
    "empaumerais": "empaumer",
    "empaumerait": "empaumer",
    "empaumeras": "empaumer",
    "empaumerez": "empaumer",
    "empaumeriez": "empaumer",
    "empaumerions": "empaumer",
    "empaumerons": "empaumer",
    "empaumeront": "empaumer",
    "empaumes": "empaumer",
    "empaumez": "empaumer",
    "empaumiez": "empaumer",
    "empaumions": "empaumer",
    "empaumons": "empaumer",
    "empaumures": "empaumure",
    "empaumâmes": "empaumer",
    "empaumât": "empaumer",
    "empaumâtes": "empaumer",
    "empaumèrent": "empaumer",
    "empaumé": "empaumer",
    "empaumée": "empaumer",
    "empaumées": "empaumer",
    "empaumés": "empaumer",
    "empeigna": "empeigner",
    "empeignai": "empeigner",
    "empeignaient": "empeigner",
    "empeignais": "empeigner",
    "empeignait": "empeigner",
    "empeignant": "empeigner",
    "empeignas": "empeigner",
    "empeignasse": "empeigner",
    "empeignassent": "empeigner",
    "empeignasses": "empeigner",
    "empeignassiez": "empeigner",
    "empeignassions": "empeigner",
    "empeigne": "empeigner",
    "empeignent": "empeigner",
    "empeignera": "empeigner",
    "empeignerai": "empeigner",
    "empeigneraient": "empeigner",
    "empeignerais": "empeigner",
    "empeignerait": "empeigner",
    "empeigneras": "empeigner",
    "empeignerez": "empeigner",
    "empeigneriez": "empeigner",
    "empeignerions": "empeigner",
    "empeignerons": "empeigner",
    "empeigneront": "empeigner",
    "empeignes": "empeigner",
    "empeignez": "empeigner",
    "empeigniez": "empeigner",
    "empeignions": "empeigner",
    "empeignons": "empeigner",
    "empeignâmes": "empeigner",
    "empeignât": "empeigner",
    "empeignâtes": "empeigner",
    "empeignèrent": "empeigner",
    "empeigné": "empeigner",
    "empeignée": "empeigner",
    "empeignées": "empeigner",
    "empeignés": "empeigner",
    "empennait": "empenner",
    "empennée": "empenner",
    "empennées": "empenner",
    "empennés": "empenner",
    "empereurs": "empereur",
    "emperlait": "emperler",
    "emperlant": "emperler",
    "emperlousées": "emperlousé",
    "emperlé": "emperler",
    "emperlées": "emperlé",
    "emperlés": "emperler",
    "emperruqués": "emperruqué",
    "empesa": "empeser",
    "empesai": "empeser",
    "empesaient": "empeser",
    "empesais": "empeser",
    "empesait": "empeser",
    "empesant": "empeser",
    "empesas": "empeser",
    "empesasse": "empeser",
    "empesassent": "empeser",
    "empesasses": "empeser",
    "empesassiez": "empeser",
    "empesassions": "empeser",
    "empesez": "empeser",
    "empesiez": "empeser",
    "empesions": "empeser",
    "empesons": "empeser",
    "empesta": "empester",
    "empestai": "empester",
    "empestaient": "empester",
    "empestais": "empester",
    "empestait": "empester",
    "empestant": "empester",
    "empestas": "empester",
    "empestasse": "empester",
    "empestassent": "empester",
    "empestasses": "empester",
    "empestassiez": "empester",
    "empestassions": "empester",
    "empeste": "empester",
    "empestent": "empester",
    "empestera": "empester",
    "empesterai": "empester",
    "empesteraient": "empester",
    "empesterais": "empester",
    "empesterait": "empester",
    "empesteras": "empester",
    "empesterez": "empester",
    "empesteriez": "empester",
    "empesterions": "empester",
    "empesterons": "empester",
    "empesteront": "empester",
    "empestes": "empester",
    "empestez": "empester",
    "empestiez": "empester",
    "empestions": "empester",
    "empestons": "empester",
    "empestâmes": "empester",
    "empestât": "empester",
    "empestâtes": "empester",
    "empestèrent": "empester",
    "empesté": "empester",
    "empestée": "empester",
    "empestées": "empester",
    "empestés": "empester",
    "empesâmes": "empeser",
    "empesât": "empeser",
    "empesâtes": "empeser",
    "empesèrent": "empeser",
    "empesé": "empeser",
    "empesée": "empeser",
    "empesées": "empeser",
    "empesés": "empeser",
    "emphases": "emphase",
    "emphatiques": "emphatique",
    "emphatise": "emphatiser",
    "emphysèmes": "emphysème",
    "emphysémateuse": "emphysémateux",
    "empierra": "empierrer",
    "empierrai": "empierrer",
    "empierraient": "empierrer",
    "empierrais": "empierrer",
    "empierrait": "empierrer",
    "empierrant": "empierrer",
    "empierras": "empierrer",
    "empierrasse": "empierrer",
    "empierrassent": "empierrer",
    "empierrasses": "empierrer",
    "empierrassiez": "empierrer",
    "empierrassions": "empierrer",
    "empierre": "empierrer",
    "empierrements": "empierrement",
    "empierrent": "empierrer",
    "empierrera": "empierrer",
    "empierrerai": "empierrer",
    "empierreraient": "empierrer",
    "empierrerais": "empierrer",
    "empierrerait": "empierrer",
    "empierreras": "empierrer",
    "empierrerez": "empierrer",
    "empierreriez": "empierrer",
    "empierrerions": "empierrer",
    "empierrerons": "empierrer",
    "empierreront": "empierrer",
    "empierres": "empierrer",
    "empierrez": "empierrer",
    "empierriez": "empierrer",
    "empierrions": "empierrer",
    "empierrons": "empierrer",
    "empierrâmes": "empierrer",
    "empierrât": "empierrer",
    "empierrâtes": "empierrer",
    "empierrèrent": "empierrer",
    "empierré": "empierrer",
    "empierrée": "empierrer",
    "empierrées": "empierrer",
    "empierrés": "empierrer",
    "empiffra": "empiffrer",
    "empiffrai": "empiffrer",
    "empiffraient": "empiffrer",
    "empiffrais": "empiffrer",
    "empiffrait": "empiffrer",
    "empiffrant": "empiffrer",
    "empiffras": "empiffrer",
    "empiffrasse": "empiffrer",
    "empiffrassent": "empiffrer",
    "empiffrasses": "empiffrer",
    "empiffrassiez": "empiffrer",
    "empiffrassions": "empiffrer",
    "empiffre": "empiffrer",
    "empiffrent": "empiffrer",
    "empiffrera": "empiffrer",
    "empiffrerai": "empiffrer",
    "empiffreraient": "empiffrer",
    "empiffrerais": "empiffrer",
    "empiffrerait": "empiffrer",
    "empiffreras": "empiffrer",
    "empiffrerez": "empiffrer",
    "empiffreriez": "empiffrer",
    "empiffrerions": "empiffrer",
    "empiffrerons": "empiffrer",
    "empiffreront": "empiffrer",
    "empiffres": "empiffrer",
    "empiffrez": "empiffrer",
    "empiffriez": "empiffrer",
    "empiffrions": "empiffrer",
    "empiffrons": "empiffrer",
    "empiffrâmes": "empiffrer",
    "empiffrât": "empiffrer",
    "empiffrâtes": "empiffrer",
    "empiffrèrent": "empiffrer",
    "empiffré": "empiffrer",
    "empiffrée": "empiffrer",
    "empiffrées": "empiffrer",
    "empiffrés": "empiffrer",
    "empila": "empiler",
    "empilages": "empilage",
    "empilai": "empiler",
    "empilaient": "empiler",
    "empilais": "empiler",
    "empilait": "empiler",
    "empilant": "empiler",
    "empilas": "empiler",
    "empilasse": "empiler",
    "empilassent": "empiler",
    "empilasses": "empiler",
    "empilassiez": "empiler",
    "empilassions": "empiler",
    "empile": "empiler",
    "empilements": "empilement",
    "empilent": "empiler",
    "empilera": "empiler",
    "empilerai": "empiler",
    "empileraient": "empiler",
    "empilerais": "empiler",
    "empilerait": "empiler",
    "empileras": "empiler",
    "empilerez": "empiler",
    "empileriez": "empiler",
    "empilerions": "empiler",
    "empilerons": "empiler",
    "empileront": "empiler",
    "empiles": "empiler",
    "empilez": "empiler",
    "empiliez": "empiler",
    "empilions": "empiler",
    "empilons": "empiler",
    "empilâmes": "empiler",
    "empilât": "empiler",
    "empilâtes": "empiler",
    "empilèrent": "empiler",
    "empilé": "empiler",
    "empilée": "empiler",
    "empilées": "empiler",
    "empilés": "empiler",
    "empira": "empirer",
    "empirai": "empirer",
    "empiraient": "empirer",
    "empirais": "empirer",
    "empirait": "empirer",
    "empirant": "empirer",
    "empiras": "empirer",
    "empirasse": "empirer",
    "empirassent": "empirer",
    "empirasses": "empirer",
    "empirassiez": "empirer",
    "empirassions": "empirer",
    "empire": "empirer",
    "empirent": "empirer",
    "empirera": "empirer",
    "empirerai": "empirer",
    "empireraient": "empirer",
    "empirerais": "empirer",
    "empirerait": "empirer",
    "empireras": "empirer",
    "empirerez": "empirer",
    "empireriez": "empirer",
    "empirerions": "empirer",
    "empirerons": "empirer",
    "empireront": "empirer",
    "empires": "empirer",
    "empirez": "empirer",
    "empiriez": "empirer",
    "empirions": "empirer",
    "empiriques": "empirique",
    "empirismes": "empirisme",
    "empirons": "empirer",
    "empirâmes": "empirer",
    "empirât": "empirer",
    "empirâtes": "empirer",
    "empirèrent": "empirer",
    "empiré": "empirer",
    "empirée": "empirer",
    "empirées": "empirer",
    "empirés": "empirer",
    "empiècements": "empiècement",
    "empiète": "empiéter",
    "empiètements": "empiètement",
    "empiètent": "empiéter",
    "empiètes": "empiéter",
    "empiéta": "empiéter",
    "empiétai": "empiéter",
    "empiétaient": "empiéter",
    "empiétais": "empiéter",
    "empiétait": "empiéter",
    "empiétant": "empiéter",
    "empiétas": "empiéter",
    "empiétasse": "empiéter",
    "empiétassent": "empiéter",
    "empiétasses": "empiéter",
    "empiétassiez": "empiéter",
    "empiétassions": "empiéter",
    "empiétements": "empiétement",
    "empiétera": "empiéter",
    "empiéterai": "empiéter",
    "empiéteraient": "empiéter",
    "empiéterais": "empiéter",
    "empiéterait": "empiéter",
    "empiéteras": "empiéter",
    "empiéterez": "empiéter",
    "empiéteriez": "empiéter",
    "empiéterions": "empiéter",
    "empiéterons": "empiéter",
    "empiéteront": "empiéter",
    "empiétez": "empiéter",
    "empiétiez": "empiéter",
    "empiétions": "empiéter",
    "empiétons": "empiéter",
    "empiétâmes": "empiéter",
    "empiétât": "empiéter",
    "empiétâtes": "empiéter",
    "empiétèrent": "empiéter",
    "empiété": "empiéter",
    "emplacements": "emplacement",
    "emplafonne": "emplafonner",
    "emplafonnent": "emplafonner",
    "emplafonné": "emplafonner",
    "emplafonnée": "emplafonner",
    "emplettes": "emplette",
    "empli": "emplir",
    "emplie": "emplir",
    "emplies": "emplir",
    "emplira": "emplir",
    "emplirai": "emplir",
    "empliraient": "emplir",
    "emplirais": "emplir",
    "emplirait": "emplir",
    "empliras": "emplir",
    "emplirent": "emplir",
    "emplirez": "emplir",
    "empliriez": "emplir",
    "emplirions": "emplir",
    "emplirons": "emplir",
    "empliront": "emplir",
    "emplis": "emplir",
    "emplissaient": "emplir",
    "emplissais": "emplir",
    "emplissait": "emplir",
    "emplissant": "emplir",
    "emplisse": "emplir",
    "emplissent": "emplir",
    "emplisses": "emplir",
    "emplissez": "emplir",
    "emplissiez": "emplir",
    "emplissions": "emplir",
    "emplissons": "emplir",
    "emplit": "emplir",
    "emploie": "employer",
    "emploient": "employer",
    "emploiera": "employer",
    "emploierai": "employer",
    "emploieraient": "employer",
    "emploierais": "employer",
    "emploierait": "employer",
    "emploieras": "employer",
    "emploierez": "employer",
    "emploieriez": "employer",
    "emploierions": "employer",
    "emploierons": "employer",
    "emploieront": "employer",
    "emploies": "employer",
    "emplois": "emploi",
    "employa": "employer",
    "employai": "employer",
    "employaient": "employer",
    "employais": "employer",
    "employait": "employer",
    "employant": "employer",
    "employas": "employer",
    "employasse": "employer",
    "employassent": "employer",
    "employasses": "employer",
    "employassiez": "employer",
    "employassions": "employer",
    "employeurs": "employeur",
    "employez": "employer",
    "employiez": "employer",
    "employions": "employer",
    "employons": "employer",
    "employâmes": "employer",
    "employât": "employer",
    "employâtes": "employer",
    "employèrent": "employer",
    "employé": "employer",
    "employée": "employer",
    "employées": "employer",
    "employés": "employer",
    "empluma": "emplumer",
    "emplumai": "emplumer",
    "emplumaient": "emplumer",
    "emplumais": "emplumer",
    "emplumait": "emplumer",
    "emplumant": "emplumer",
    "emplumas": "emplumer",
    "emplumasse": "emplumer",
    "emplumassent": "emplumer",
    "emplumasses": "emplumer",
    "emplumassiez": "emplumer",
    "emplumassions": "emplumer",
    "emplume": "emplumer",
    "emplument": "emplumer",
    "emplumera": "emplumer",
    "emplumerai": "emplumer",
    "emplumeraient": "emplumer",
    "emplumerais": "emplumer",
    "emplumerait": "emplumer",
    "emplumeras": "emplumer",
    "emplumerez": "emplumer",
    "emplumeriez": "emplumer",
    "emplumerions": "emplumer",
    "emplumerons": "emplumer",
    "emplumeront": "emplumer",
    "emplumes": "emplumer",
    "emplumez": "emplumer",
    "emplumiez": "emplumer",
    "emplumions": "emplumer",
    "emplumons": "emplumer",
    "emplumâmes": "emplumer",
    "emplumât": "emplumer",
    "emplumâtes": "emplumer",
    "emplumèrent": "emplumer",
    "emplumé": "emplumer",
    "emplumée": "emplumer",
    "emplumées": "emplumer",
    "emplumés": "emplumer",
    "emplâtrais": "emplâtrer",
    "emplâtres": "emplâtre",
    "emplâtré": "emplâtrer",
    "emplîmes": "emplir",
    "emplît": "emplir",
    "emplîtes": "emplir",
    "empocha": "empocher",
    "empochai": "empocher",
    "empochaient": "empocher",
    "empochais": "empocher",
    "empochait": "empocher",
    "empochant": "empocher",
    "empochas": "empocher",
    "empochasse": "empocher",
    "empochassent": "empocher",
    "empochasses": "empocher",
    "empochassiez": "empocher",
    "empochassions": "empocher",
    "empoche": "empocher",
    "empochent": "empocher",
    "empochera": "empocher",
    "empocherai": "empocher",
    "empocheraient": "empocher",
    "empocherais": "empocher",
    "empocherait": "empocher",
    "empocheras": "empocher",
    "empocherez": "empocher",
    "empocheriez": "empocher",
    "empocherions": "empocher",
    "empocherons": "empocher",
    "empocheront": "empocher",
    "empoches": "empocher",
    "empochez": "empocher",
    "empochiez": "empocher",
    "empochions": "empocher",
    "empochons": "empocher",
    "empochâmes": "empocher",
    "empochât": "empocher",
    "empochâtes": "empocher",
    "empochèrent": "empocher",
    "empoché": "empocher",
    "empochée": "empocher",
    "empochées": "empocher",
    "empochés": "empocher",
    "empoigna": "empoigner",
    "empoignades": "empoignade",
    "empoignai": "empoigner",
    "empoignaient": "empoigner",
    "empoignais": "empoigner",
    "empoignait": "empoigner",
    "empoignant": "empoigner",
    "empoignas": "empoigner",
    "empoignasse": "empoigner",
    "empoignassent": "empoigner",
    "empoignasses": "empoigner",
    "empoignassiez": "empoigner",
    "empoignassions": "empoigner",
    "empoigne": "empoigner",
    "empoignent": "empoigner",
    "empoignera": "empoigner",
    "empoignerai": "empoigner",
    "empoigneraient": "empoigner",
    "empoignerais": "empoigner",
    "empoignerait": "empoigner",
    "empoigneras": "empoigner",
    "empoignerez": "empoigner",
    "empoigneriez": "empoigner",
    "empoignerions": "empoigner",
    "empoignerons": "empoigner",
    "empoigneront": "empoigner",
    "empoignes": "empoigner",
    "empoignez": "empoigner",
    "empoigniez": "empoigner",
    "empoignions": "empoigner",
    "empoignons": "empoigner",
    "empoignâmes": "empoigner",
    "empoignât": "empoigner",
    "empoignâtes": "empoigner",
    "empoignèrent": "empoigner",
    "empoigné": "empoigner",
    "empoignée": "empoigner",
    "empoignées": "empoigner",
    "empoignés": "empoigner",
    "empoilés": "empoiler",
    "empoisonna": "empoisonner",
    "empoisonnai": "empoisonner",
    "empoisonnaient": "empoisonner",
    "empoisonnais": "empoisonner",
    "empoisonnait": "empoisonner",
    "empoisonnant": "empoisonner",
    "empoisonnante": "empoisonnant",
    "empoisonnantes": "empoisonnant",
    "empoisonnas": "empoisonner",
    "empoisonnasse": "empoisonner",
    "empoisonnassent": "empoisonner",
    "empoisonnasses": "empoisonner",
    "empoisonnassiez": "empoisonner",
    "empoisonnassions": "empoisonner",
    "empoisonne": "empoisonner",
    "empoisonnements": "empoisonnement",
    "empoisonnent": "empoisonner",
    "empoisonnera": "empoisonner",
    "empoisonnerai": "empoisonner",
    "empoisonneraient": "empoisonner",
    "empoisonnerais": "empoisonner",
    "empoisonnerait": "empoisonner",
    "empoisonneras": "empoisonner",
    "empoisonnerez": "empoisonner",
    "empoisonneriez": "empoisonner",
    "empoisonnerions": "empoisonner",
    "empoisonnerons": "empoisonner",
    "empoisonneront": "empoisonner",
    "empoisonnes": "empoisonner",
    "empoisonneurs": "empoisonneur",
    "empoisonneuse": "empoisonneur",
    "empoisonneuses": "empoisonneur",
    "empoisonnez": "empoisonner",
    "empoisonniez": "empoisonner",
    "empoisonnions": "empoisonner",
    "empoisonnons": "empoisonner",
    "empoisonnâmes": "empoisonner",
    "empoisonnât": "empoisonner",
    "empoisonnâtes": "empoisonner",
    "empoisonnèrent": "empoisonner",
    "empoisonné": "empoisonner",
    "empoisonnée": "empoisonner",
    "empoisonnées": "empoisonner",
    "empoisonnés": "empoisonner",
    "empoissait": "empoisser",
    "empoisse": "empoisser",
    "empoissonna": "empoissonner",
    "empoissonnai": "empoissonner",
    "empoissonnaient": "empoissonner",
    "empoissonnais": "empoissonner",
    "empoissonnait": "empoissonner",
    "empoissonnant": "empoissonner",
    "empoissonnas": "empoissonner",
    "empoissonnasse": "empoissonner",
    "empoissonnassent": "empoissonner",
    "empoissonnasses": "empoissonner",
    "empoissonnassiez": "empoissonner",
    "empoissonnassions": "empoissonner",
    "empoissonne": "empoissonner",
    "empoissonnent": "empoissonner",
    "empoissonnera": "empoissonner",
    "empoissonnerai": "empoissonner",
    "empoissonneraient": "empoissonner",
    "empoissonnerais": "empoissonner",
    "empoissonnerait": "empoissonner",
    "empoissonneras": "empoissonner",
    "empoissonnerez": "empoissonner",
    "empoissonneriez": "empoissonner",
    "empoissonnerions": "empoissonner",
    "empoissonnerons": "empoissonner",
    "empoissonneront": "empoissonner",
    "empoissonnes": "empoissonner",
    "empoissonnez": "empoissonner",
    "empoissonniez": "empoissonner",
    "empoissonnions": "empoissonner",
    "empoissonnons": "empoissonner",
    "empoissonnâmes": "empoissonner",
    "empoissonnât": "empoissonner",
    "empoissonnâtes": "empoissonner",
    "empoissonnèrent": "empoissonner",
    "empoissonné": "empoissonner",
    "empoissonnée": "empoissonner",
    "empoissonnées": "empoissonner",
    "empoissonnés": "empoissonner",
    "empoissé": "empoisser",
    "empoissés": "empoisser",
    "emporiums": "emporium",
    "emporta": "emporter",
    "emportai": "emporter",
    "emportaient": "emporter",
    "emportais": "emporter",
    "emportait": "emporter",
    "emportant": "emporter",
    "emportas": "emporter",
    "emportasse": "emporter",
    "emportassent": "emporter",
    "emportasses": "emporter",
    "emportassiez": "emporter",
    "emportassions": "emporter",
    "emporte": "emporter",
    "emportements": "emportement",
    "emportent": "emporter",
    "emportera": "emporter",
    "emporterai": "emporter",
    "emporteraient": "emporter",
    "emporterais": "emporter",
    "emporterait": "emporter",
    "emporteras": "emporter",
    "emporterez": "emporter",
    "emporteriez": "emporter",
    "emporterions": "emporter",
    "emporterons": "emporter",
    "emporteront": "emporter",
    "emportes": "emporter",
    "emportez": "emporter",
    "emportiez": "emporter",
    "emportions": "emporter",
    "emportons": "emporter",
    "emportâmes": "emporter",
    "emportât": "emporter",
    "emportâtes": "emporter",
    "emportèrent": "emporter",
    "emporté": "emporter",
    "emportée": "emporter",
    "emportées": "emporter",
    "emportés": "emporter",
    "empota": "empoter",
    "empotai": "empoter",
    "empotaient": "empoter",
    "empotais": "empoter",
    "empotait": "empoter",
    "empotant": "empoter",
    "empotas": "empoter",
    "empotasse": "empoter",
    "empotassent": "empoter",
    "empotasses": "empoter",
    "empotassiez": "empoter",
    "empotassions": "empoter",
    "empote": "empoter",
    "empotent": "empoter",
    "empotera": "empoter",
    "empoterai": "empoter",
    "empoteraient": "empoter",
    "empoterais": "empoter",
    "empoterait": "empoter",
    "empoteras": "empoter",
    "empoterez": "empoter",
    "empoteriez": "empoter",
    "empoterions": "empoter",
    "empoterons": "empoter",
    "empoteront": "empoter",
    "empotes": "empoter",
    "empotez": "empoter",
    "empotiez": "empoter",
    "empotions": "empoter",
    "empotons": "empoter",
    "empotâmes": "empoter",
    "empotât": "empoter",
    "empotâtes": "empoter",
    "empotèrent": "empoter",
    "empoté": "empoter",
    "empotée": "empoter",
    "empotées": "empoter",
    "empotés": "empoter",
    "empourpra": "empourprer",
    "empourprai": "empourprer",
    "empourpraient": "empourprer",
    "empourprais": "empourprer",
    "empourprait": "empourprer",
    "empourprant": "empourprer",
    "empourpras": "empourprer",
    "empourprasse": "empourprer",
    "empourprassent": "empourprer",
    "empourprasses": "empourprer",
    "empourprassiez": "empourprer",
    "empourprassions": "empourprer",
    "empourpre": "empourprer",
    "empourprent": "empourprer",
    "empourprera": "empourprer",
    "empourprerai": "empourprer",
    "empourpreraient": "empourprer",
    "empourprerais": "empourprer",
    "empourprerait": "empourprer",
    "empourpreras": "empourprer",
    "empourprerez": "empourprer",
    "empourpreriez": "empourprer",
    "empourprerions": "empourprer",
    "empourprerons": "empourprer",
    "empourpreront": "empourprer",
    "empourpres": "empourprer",
    "empourprez": "empourprer",
    "empourpriez": "empourprer",
    "empourprions": "empourprer",
    "empourprons": "empourprer",
    "empourprâmes": "empourprer",
    "empourprât": "empourprer",
    "empourprâtes": "empourprer",
    "empourprèrent": "empourprer",
    "empourpré": "empourprer",
    "empourprée": "empourprer",
    "empourprées": "empourprer",
    "empourprés": "empourprer",
    "empoussière": "empoussiérer",
    "empoussièrent": "empoussiérer",
    "empoussiérait": "empoussiérer",
    "empoussiéré": "empoussiérer",
    "empoussiérée": "empoussiérer",
    "empoussiérées": "empoussiéré",
    "empoussiérés": "empoussiérer",
    "empreignaient": "empreindre",
    "empreignais": "empreindre",
    "empreignait": "empreindre",
    "empreignant": "empreindre",
    "empreigne": "empreindre",
    "empreignent": "empreindre",
    "empreignes": "empreindre",
    "empreignez": "empreindre",
    "empreigniez": "empreindre",
    "empreignions": "empreindre",
    "empreignirent": "empreindre",
    "empreignis": "empreindre",
    "empreignisse": "empreindre",
    "empreignissent": "empreindre",
    "empreignisses": "empreindre",
    "empreignissiez": "empreindre",
    "empreignissions": "empreindre",
    "empreignit": "empreindre",
    "empreignons": "empreindre",
    "empreignîmes": "empreindre",
    "empreignît": "empreindre",
    "empreignîtes": "empreindre",
    "empreindra": "empreindre",
    "empreindrai": "empreindre",
    "empreindraient": "empreindre",
    "empreindrais": "empreindre",
    "empreindrait": "empreindre",
    "empreindras": "empreindre",
    "empreindrez": "empreindre",
    "empreindriez": "empreindre",
    "empreindrions": "empreindre",
    "empreindrons": "empreindre",
    "empreindront": "empreindre",
    "empreins": "empreindre",
    "empreint": "empreindre",
    "empreinte": "empreint",
    "empreintes": "empreinte",
    "empreints": "empreint",
    "empressa": "empresser",
    "empressai": "empresser",
    "empressaient": "empresser",
    "empressais": "empresser",
    "empressait": "empresser",
    "empressant": "empresser",
    "empressas": "empresser",
    "empressasse": "empresser",
    "empressassent": "empresser",
    "empressasses": "empresser",
    "empressassiez": "empresser",
    "empressassions": "empresser",
    "empresse": "empresser",
    "empressements": "empressement",
    "empressent": "empresser",
    "empressera": "empresser",
    "empresserai": "empresser",
    "empresseraient": "empresser",
    "empresserais": "empresser",
    "empresserait": "empresser",
    "empresseras": "empresser",
    "empresserez": "empresser",
    "empresseriez": "empresser",
    "empresserions": "empresser",
    "empresserons": "empresser",
    "empresseront": "empresser",
    "empresses": "empresser",
    "empressez": "empresser",
    "empressiez": "empresser",
    "empressions": "empresser",
    "empressons": "empresser",
    "empressâmes": "empresser",
    "empressât": "empresser",
    "empressâtes": "empresser",
    "empressèrent": "empresser",
    "empressé": "empresser",
    "empressée": "empresser",
    "empressées": "empresser",
    "empressés": "empresser",
    "emprises": "emprise",
    "emprisonna": "emprisonner",
    "emprisonnai": "emprisonner",
    "emprisonnaient": "emprisonner",
    "emprisonnais": "emprisonner",
    "emprisonnait": "emprisonner",
    "emprisonnant": "emprisonner",
    "emprisonnas": "emprisonner",
    "emprisonnasse": "emprisonner",
    "emprisonnassent": "emprisonner",
    "emprisonnasses": "emprisonner",
    "emprisonnassiez": "emprisonner",
    "emprisonnassions": "emprisonner",
    "emprisonne": "emprisonner",
    "emprisonnements": "emprisonnement",
    "emprisonnent": "emprisonner",
    "emprisonnera": "emprisonner",
    "emprisonnerai": "emprisonner",
    "emprisonneraient": "emprisonner",
    "emprisonnerais": "emprisonner",
    "emprisonnerait": "emprisonner",
    "emprisonneras": "emprisonner",
    "emprisonnerez": "emprisonner",
    "emprisonneriez": "emprisonner",
    "emprisonnerions": "emprisonner",
    "emprisonnerons": "emprisonner",
    "emprisonneront": "emprisonner",
    "emprisonnes": "emprisonner",
    "emprisonnez": "emprisonner",
    "emprisonniez": "emprisonner",
    "emprisonnions": "emprisonner",
    "emprisonnons": "emprisonner",
    "emprisonnâmes": "emprisonner",
    "emprisonnât": "emprisonner",
    "emprisonnâtes": "emprisonner",
    "emprisonnèrent": "emprisonner",
    "emprisonné": "emprisonner",
    "emprisonnée": "emprisonner",
    "emprisonnées": "emprisonner",
    "emprisonnés": "emprisonner",
    "emprunta": "emprunter",
    "empruntai": "emprunter",
    "empruntaient": "emprunter",
    "empruntais": "emprunter",
    "empruntait": "emprunter",
    "empruntant": "emprunter",
    "empruntas": "emprunter",
    "empruntasse": "emprunter",
    "empruntassent": "emprunter",
    "empruntasses": "emprunter",
    "empruntassiez": "emprunter",
    "empruntassions": "emprunter",
    "emprunte": "emprunter",
    "empruntent": "emprunter",
    "empruntera": "emprunter",
    "emprunterai": "emprunter",
    "emprunteraient": "emprunter",
    "emprunterais": "emprunter",
    "emprunterait": "emprunter",
    "emprunteras": "emprunter",
    "emprunterez": "emprunter",
    "emprunteriez": "emprunter",
    "emprunterions": "emprunter",
    "emprunterons": "emprunter",
    "emprunteront": "emprunter",
    "empruntes": "emprunter",
    "emprunteurs": "emprunteur",
    "emprunteuse": "emprunteur",
    "emprunteuses": "emprunteur",
    "empruntez": "emprunter",
    "empruntiez": "emprunter",
    "empruntions": "emprunter",
    "empruntons": "emprunter",
    "emprunts": "emprunt",
    "empruntâmes": "emprunter",
    "empruntât": "emprunter",
    "empruntâtes": "emprunter",
    "empruntèrent": "emprunter",
    "emprunté": "emprunter",
    "empruntée": "emprunter",
    "empruntées": "emprunter",
    "empruntés": "emprunter",
    "empuanti": "empuantir",
    "empuantie": "empuantir",
    "empuanties": "empuantir",
    "empuantira": "empuantir",
    "empuantirai": "empuantir",
    "empuantiraient": "empuantir",
    "empuantirais": "empuantir",
    "empuantirait": "empuantir",
    "empuantiras": "empuantir",
    "empuantirent": "empuantir",
    "empuantirez": "empuantir",
    "empuantiriez": "empuantir",
    "empuantirions": "empuantir",
    "empuantirons": "empuantir",
    "empuantiront": "empuantir",
    "empuantis": "empuantir",
    "empuantissaient": "empuantir",
    "empuantissais": "empuantir",
    "empuantissait": "empuantir",
    "empuantissant": "empuantir",
    "empuantisse": "empuantir",
    "empuantissent": "empuantir",
    "empuantisses": "empuantir",
    "empuantissez": "empuantir",
    "empuantissiez": "empuantir",
    "empuantissions": "empuantir",
    "empuantissons": "empuantir",
    "empuantit": "empuantir",
    "empuantîmes": "empuantir",
    "empuantît": "empuantir",
    "empuantîtes": "empuantir",
    "empuses": "empuse",
    "empyreumes": "empyreume",
    "empyrées": "empyrée",
    "empâta": "empâter",
    "empâtai": "empâter",
    "empâtaient": "empâter",
    "empâtais": "empâter",
    "empâtait": "empâter",
    "empâtant": "empâter",
    "empâtas": "empâter",
    "empâtasse": "empâter",
    "empâtassent": "empâter",
    "empâtasses": "empâter",
    "empâtassiez": "empâter",
    "empâtassions": "empâter",
    "empâte": "empâter",
    "empâtements": "empâtement",
    "empâtent": "empâter",
    "empâtera": "empâter",
    "empâterai": "empâter",
    "empâteraient": "empâter",
    "empâterais": "empâter",
    "empâterait": "empâter",
    "empâteras": "empâter",
    "empâterez": "empâter",
    "empâteriez": "empâter",
    "empâterions": "empâter",
    "empâterons": "empâter",
    "empâteront": "empâter",
    "empâtes": "empâter",
    "empâtez": "empâter",
    "empâtiez": "empâter",
    "empâtions": "empâter",
    "empâtons": "empâter",
    "empâtâmes": "empâter",
    "empâtât": "empâter",
    "empâtâtes": "empâter",
    "empâtèrent": "empâter",
    "empâté": "empâter",
    "empâtée": "empâter",
    "empâtées": "empâter",
    "empâtés": "empâter",
    "empèse": "empeser",
    "empèsent": "empeser",
    "empèsera": "empeser",
    "empèserai": "empeser",
    "empèseraient": "empeser",
    "empèserais": "empeser",
    "empèserait": "empeser",
    "empèseras": "empeser",
    "empèserez": "empeser",
    "empèseriez": "empeser",
    "empèserions": "empeser",
    "empèserons": "empeser",
    "empèseront": "empeser",
    "empèses": "empeser",
    "empêcha": "empêcher",
    "empêchai": "empêcher",
    "empêchaient": "empêcher",
    "empêchais": "empêcher",
    "empêchait": "empêcher",
    "empêchant": "empêcher",
    "empêchas": "empêcher",
    "empêchasse": "empêcher",
    "empêchassent": "empêcher",
    "empêchasses": "empêcher",
    "empêchassiez": "empêcher",
    "empêchassions": "empêcher",
    "empêche": "empêcher",
    "empêchements": "empêchement",
    "empêchent": "empêcher",
    "empêchera": "empêcher",
    "empêcherai": "empêcher",
    "empêcheraient": "empêcher",
    "empêcherais": "empêcher",
    "empêcherait": "empêcher",
    "empêcheras": "empêcher",
    "empêcherez": "empêcher",
    "empêcheriez": "empêcher",
    "empêcherions": "empêcher",
    "empêcherons": "empêcher",
    "empêcheront": "empêcher",
    "empêches": "empêcher",
    "empêcheurs": "empêcheur",
    "empêcheuse": "empêcheur",
    "empêchez": "empêcher",
    "empêchiez": "empêcher",
    "empêchions": "empêcher",
    "empêchons": "empêcher",
    "empêchâmes": "empêcher",
    "empêchât": "empêcher",
    "empêchâtes": "empêcher",
    "empêchèrent": "empêcher",
    "empêché": "empêcher",
    "empêchée": "empêcher",
    "empêchées": "empêcher",
    "empêchés": "empêcher",
    "empêtra": "empêtrer",
    "empêtrai": "empêtrer",
    "empêtraient": "empêtrer",
    "empêtrais": "empêtrer",
    "empêtrait": "empêtrer",
    "empêtrant": "empêtrer",
    "empêtras": "empêtrer",
    "empêtrasse": "empêtrer",
    "empêtrassent": "empêtrer",
    "empêtrasses": "empêtrer",
    "empêtrassiez": "empêtrer",
    "empêtrassions": "empêtrer",
    "empêtre": "empêtrer",
    "empêtrent": "empêtrer",
    "empêtrera": "empêtrer",
    "empêtrerai": "empêtrer",
    "empêtreraient": "empêtrer",
    "empêtrerais": "empêtrer",
    "empêtrerait": "empêtrer",
    "empêtreras": "empêtrer",
    "empêtrerez": "empêtrer",
    "empêtreriez": "empêtrer",
    "empêtrerions": "empêtrer",
    "empêtrerons": "empêtrer",
    "empêtreront": "empêtrer",
    "empêtres": "empêtrer",
    "empêtrez": "empêtrer",
    "empêtriez": "empêtrer",
    "empêtrions": "empêtrer",
    "empêtrons": "empêtrer",
    "empêtrâmes": "empêtrer",
    "empêtrât": "empêtrer",
    "empêtrâtes": "empêtrer",
    "empêtrèrent": "empêtrer",
    "empêtré": "empêtrer",
    "empêtrée": "empêtrer",
    "empêtrées": "empêtrer",
    "empêtrés": "empêtrer",
    "en-têtes": "en-tête",
    "enamoura": "enamourer",
    "enamourai": "enamourer",
    "enamouraient": "enamourer",
    "enamourais": "enamourer",
    "enamourait": "enamourer",
    "enamourant": "enamourer",
    "enamouras": "enamourer",
    "enamourasse": "enamourer",
    "enamourassent": "enamourer",
    "enamourasses": "enamourer",
    "enamourassiez": "enamourer",
    "enamourassions": "enamourer",
    "enamoure": "enamourer",
    "enamourent": "enamourer",
    "enamourera": "enamourer",
    "enamourerai": "enamourer",
    "enamoureraient": "enamourer",
    "enamourerais": "enamourer",
    "enamourerait": "enamourer",
    "enamoureras": "enamourer",
    "enamourerez": "enamourer",
    "enamoureriez": "enamourer",
    "enamourerions": "enamourer",
    "enamourerons": "enamourer",
    "enamoureront": "enamourer",
    "enamoures": "enamourer",
    "enamourez": "enamourer",
    "enamouriez": "enamourer",
    "enamourions": "enamourer",
    "enamourons": "enamourer",
    "enamourâmes": "enamourer",
    "enamourât": "enamourer",
    "enamourâtes": "enamourer",
    "enamourèrent": "enamourer",
    "enamouré": "enamourer",
    "enamourée": "enamourer",
    "enamourées": "enamourer",
    "enamourés": "enamourer",
    "encabanée": "encabaner",
    "encablures": "encablure",
    "encadra": "encadrer",
    "encadrai": "encadrer",
    "encadraient": "encadrer",
    "encadrais": "encadrer",
    "encadrait": "encadrer",
    "encadrant": "encadrer",
    "encadras": "encadrer",
    "encadrasse": "encadrer",
    "encadrassent": "encadrer",
    "encadrasses": "encadrer",
    "encadrassiez": "encadrer",
    "encadrassions": "encadrer",
    "encadre": "encadrer",
    "encadrements": "encadrement",
    "encadrent": "encadrer",
    "encadrera": "encadrer",
    "encadrerai": "encadrer",
    "encadreraient": "encadrer",
    "encadrerais": "encadrer",
    "encadrerait": "encadrer",
    "encadreras": "encadrer",
    "encadrerez": "encadrer",
    "encadreriez": "encadrer",
    "encadrerions": "encadrer",
    "encadrerons": "encadrer",
    "encadreront": "encadrer",
    "encadres": "encadrer",
    "encadrez": "encadrer",
    "encadriez": "encadrer",
    "encadrions": "encadrer",
    "encadrons": "encadrer",
    "encadrâmes": "encadrer",
    "encadrât": "encadrer",
    "encadrâtes": "encadrer",
    "encadrèrent": "encadrer",
    "encadré": "encadrer",
    "encadrée": "encadrer",
    "encadrées": "encadrer",
    "encadrés": "encadrer",
    "encage": "encager",
    "encagea": "encager",
    "encageai": "encager",
    "encageaient": "encager",
    "encageais": "encager",
    "encageait": "encager",
    "encageant": "encager",
    "encageas": "encager",
    "encageasse": "encager",
    "encageassent": "encager",
    "encageasses": "encager",
    "encageassiez": "encager",
    "encageassions": "encager",
    "encagent": "encager",
    "encageons": "encager",
    "encagera": "encager",
    "encagerai": "encager",
    "encageraient": "encager",
    "encagerais": "encager",
    "encagerait": "encager",
    "encageras": "encager",
    "encagerez": "encager",
    "encageriez": "encager",
    "encagerions": "encager",
    "encagerons": "encager",
    "encageront": "encager",
    "encages": "encager",
    "encagez": "encager",
    "encageâmes": "encager",
    "encageât": "encager",
    "encageâtes": "encager",
    "encagiez": "encager",
    "encagions": "encager",
    "encagoulées": "encagoulé",
    "encagoulés": "encagoulé",
    "encagèrent": "encager",
    "encagé": "encager",
    "encagée": "encager",
    "encagées": "encager",
    "encagés": "encager",
    "encaissa": "encaisser",
    "encaissai": "encaisser",
    "encaissaient": "encaisser",
    "encaissais": "encaisser",
    "encaissait": "encaisser",
    "encaissant": "encaisser",
    "encaissas": "encaisser",
    "encaissasse": "encaisser",
    "encaissassent": "encaisser",
    "encaissasses": "encaisser",
    "encaissassiez": "encaisser",
    "encaissassions": "encaisser",
    "encaisse": "encaisser",
    "encaissements": "encaissement",
    "encaissent": "encaisser",
    "encaissera": "encaisser",
    "encaisserai": "encaisser",
    "encaisseraient": "encaisser",
    "encaisserais": "encaisser",
    "encaisserait": "encaisser",
    "encaisseras": "encaisser",
    "encaisserez": "encaisser",
    "encaisseriez": "encaisser",
    "encaisserions": "encaisser",
    "encaisserons": "encaisser",
    "encaisseront": "encaisser",
    "encaisses": "encaisser",
    "encaisseurs": "encaisseur",
    "encaissez": "encaisser",
    "encaissiez": "encaisser",
    "encaissions": "encaisser",
    "encaissons": "encaisser",
    "encaissâmes": "encaisser",
    "encaissât": "encaisser",
    "encaissâtes": "encaisser",
    "encaissèrent": "encaisser",
    "encaissé": "encaisser",
    "encaissée": "encaisser",
    "encaissées": "encaisser",
    "encaissés": "encaisser",
    "encalminés": "encalminé",
    "encanailla": "encanailler",
    "encanaillai": "encanailler",
    "encanaillaient": "encanailler",
    "encanaillais": "encanailler",
    "encanaillait": "encanailler",
    "encanaillant": "encanailler",
    "encanaillas": "encanailler",
    "encanaillasse": "encanailler",
    "encanaillassent": "encanailler",
    "encanaillasses": "encanailler",
    "encanaillassiez": "encanailler",
    "encanaillassions": "encanailler",
    "encanaille": "encanailler",
    "encanaillent": "encanailler",
    "encanaillera": "encanailler",
    "encanaillerai": "encanailler",
    "encanailleraient": "encanailler",
    "encanaillerais": "encanailler",
    "encanaillerait": "encanailler",
    "encanailleras": "encanailler",
    "encanaillerez": "encanailler",
    "encanailleriez": "encanailler",
    "encanaillerions": "encanailler",
    "encanaillerons": "encanailler",
    "encanailleront": "encanailler",
    "encanailles": "encanailler",
    "encanaillez": "encanailler",
    "encanailliez": "encanailler",
    "encanaillions": "encanailler",
    "encanaillons": "encanailler",
    "encanaillâmes": "encanailler",
    "encanaillât": "encanailler",
    "encanaillâtes": "encanailler",
    "encanaillèrent": "encanailler",
    "encanaillé": "encanailler",
    "encanaillée": "encanailler",
    "encanaillées": "encanailler",
    "encanaillés": "encanailler",
    "encapsulé": "encapsuler",
    "encapuchonna": "encapuchonner",
    "encapuchonnai": "encapuchonner",
    "encapuchonnaient": "encapuchonner",
    "encapuchonnais": "encapuchonner",
    "encapuchonnait": "encapuchonner",
    "encapuchonnant": "encapuchonner",
    "encapuchonnas": "encapuchonner",
    "encapuchonnasse": "encapuchonner",
    "encapuchonnassent": "encapuchonner",
    "encapuchonnasses": "encapuchonner",
    "encapuchonnassiez": "encapuchonner",
    "encapuchonnassions": "encapuchonner",
    "encapuchonne": "encapuchonner",
    "encapuchonnent": "encapuchonner",
    "encapuchonnera": "encapuchonner",
    "encapuchonnerai": "encapuchonner",
    "encapuchonneraient": "encapuchonner",
    "encapuchonnerais": "encapuchonner",
    "encapuchonnerait": "encapuchonner",
    "encapuchonneras": "encapuchonner",
    "encapuchonnerez": "encapuchonner",
    "encapuchonneriez": "encapuchonner",
    "encapuchonnerions": "encapuchonner",
    "encapuchonnerons": "encapuchonner",
    "encapuchonneront": "encapuchonner",
    "encapuchonnes": "encapuchonner",
    "encapuchonnez": "encapuchonner",
    "encapuchonniez": "encapuchonner",
    "encapuchonnions": "encapuchonner",
    "encapuchonnons": "encapuchonner",
    "encapuchonnâmes": "encapuchonner",
    "encapuchonnât": "encapuchonner",
    "encapuchonnâtes": "encapuchonner",
    "encapuchonnèrent": "encapuchonner",
    "encapuchonné": "encapuchonner",
    "encapuchonnée": "encapuchonner",
    "encapuchonnées": "encapuchonner",
    "encapuchonnés": "encapuchonner",
    "encaqua": "encaquer",
    "encaquai": "encaquer",
    "encaquaient": "encaquer",
    "encaquais": "encaquer",
    "encaquait": "encaquer",
    "encaquant": "encaquer",
    "encaquas": "encaquer",
    "encaquasse": "encaquer",
    "encaquassent": "encaquer",
    "encaquasses": "encaquer",
    "encaquassiez": "encaquer",
    "encaquassions": "encaquer",
    "encaque": "encaquer",
    "encaquent": "encaquer",
    "encaquera": "encaquer",
    "encaquerai": "encaquer",
    "encaqueraient": "encaquer",
    "encaquerais": "encaquer",
    "encaquerait": "encaquer",
    "encaqueras": "encaquer",
    "encaquerez": "encaquer",
    "encaqueriez": "encaquer",
    "encaquerions": "encaquer",
    "encaquerons": "encaquer",
    "encaqueront": "encaquer",
    "encaques": "encaquer",
    "encaquez": "encaquer",
    "encaquiez": "encaquer",
    "encaquions": "encaquer",
    "encaquons": "encaquer",
    "encaquâmes": "encaquer",
    "encaquât": "encaquer",
    "encaquâtes": "encaquer",
    "encaquèrent": "encaquer",
    "encaqué": "encaquer",
    "encaquée": "encaquer",
    "encaquées": "encaquer",
    "encaqués": "encaquer",
    "encarta": "encarter",
    "encartai": "encarter",
    "encartaient": "encarter",
    "encartais": "encarter",
    "encartait": "encarter",
    "encartant": "encarter",
    "encartas": "encarter",
    "encartasse": "encarter",
    "encartassent": "encarter",
    "encartasses": "encarter",
    "encartassiez": "encarter",
    "encartassions": "encarter",
    "encarte": "encarter",
    "encartent": "encarter",
    "encartera": "encarter",
    "encarterai": "encarter",
    "encarteraient": "encarter",
    "encarterais": "encarter",
    "encarterait": "encarter",
    "encarteras": "encarter",
    "encarterez": "encarter",
    "encarteriez": "encarter",
    "encarterions": "encarter",
    "encarterons": "encarter",
    "encarteront": "encarter",
    "encartes": "encarter",
    "encartez": "encarter",
    "encartiez": "encarter",
    "encartions": "encarter",
    "encartons": "encarter",
    "encarts": "encart",
    "encartâmes": "encarter",
    "encartât": "encarter",
    "encartâtes": "encarter",
    "encartèrent": "encarter",
    "encarté": "encarter",
    "encartée": "encarter",
    "encartées": "encarter",
    "encartés": "encarter",
    "encastelé": "encasteler",
    "encastra": "encastrer",
    "encastrai": "encastrer",
    "encastraient": "encastrer",
    "encastrais": "encastrer",
    "encastrait": "encastrer",
    "encastrant": "encastrer",
    "encastras": "encastrer",
    "encastrasse": "encastrer",
    "encastrassent": "encastrer",
    "encastrasses": "encastrer",
    "encastrassiez": "encastrer",
    "encastrassions": "encastrer",
    "encastre": "encastrer",
    "encastrent": "encastrer",
    "encastrera": "encastrer",
    "encastrerai": "encastrer",
    "encastreraient": "encastrer",
    "encastrerais": "encastrer",
    "encastrerait": "encastrer",
    "encastreras": "encastrer",
    "encastrerez": "encastrer",
    "encastreriez": "encastrer",
    "encastrerions": "encastrer",
    "encastrerons": "encastrer",
    "encastreront": "encastrer",
    "encastres": "encastrer",
    "encastrez": "encastrer",
    "encastriez": "encastrer",
    "encastrions": "encastrer",
    "encastrons": "encastrer",
    "encastrâmes": "encastrer",
    "encastrât": "encastrer",
    "encastrâtes": "encastrer",
    "encastrèrent": "encastrer",
    "encastré": "encastrer",
    "encastrée": "encastrer",
    "encastrées": "encastrer",
    "encastrés": "encastrer",
    "encaustiquait": "encaustiquer",
    "encaustique": "encaustiquer",
    "encaustiques": "encaustique",
    "encaustiquée": "encaustiqué",
    "encavée": "encaver",
    "enceignaient": "enceindre",
    "enceignais": "enceindre",
    "enceignait": "enceindre",
    "enceignant": "enceindre",
    "enceigne": "enceindre",
    "enceignent": "enceindre",
    "enceignes": "enceindre",
    "enceignez": "enceindre",
    "enceigniez": "enceindre",
    "enceignions": "enceindre",
    "enceignirent": "enceindre",
    "enceignis": "enceindre",
    "enceignisse": "enceindre",
    "enceignissent": "enceindre",
    "enceignisses": "enceindre",
    "enceignissiez": "enceindre",
    "enceignissions": "enceindre",
    "enceignit": "enceindre",
    "enceignons": "enceindre",
    "enceignîmes": "enceindre",
    "enceignît": "enceindre",
    "enceignîtes": "enceindre",
    "enceindra": "enceindre",
    "enceindrai": "enceindre",
    "enceindraient": "enceindre",
    "enceindrais": "enceindre",
    "enceindrait": "enceindre",
    "enceindras": "enceindre",
    "enceindrez": "enceindre",
    "enceindriez": "enceindre",
    "enceindrions": "enceindre",
    "enceindrons": "enceindre",
    "enceindront": "enceindre",
    "enceins": "enceindre",
    "enceint": "enceindre",
    "enceinte": "enceindre",
    "enceintes": "enceinte",
    "enceints": "enceindre",
    "encellulée": "encelluler",
    "encellulées": "encelluler",
    "encensa": "encenser",
    "encensai": "encenser",
    "encensaient": "encenser",
    "encensais": "encenser",
    "encensait": "encenser",
    "encensant": "encenser",
    "encensas": "encenser",
    "encensasse": "encenser",
    "encensassent": "encenser",
    "encensasses": "encenser",
    "encensassiez": "encenser",
    "encensassions": "encenser",
    "encense": "encenser",
    "encensent": "encenser",
    "encensera": "encenser",
    "encenserai": "encenser",
    "encenseraient": "encenser",
    "encenserais": "encenser",
    "encenserait": "encenser",
    "encenseras": "encenser",
    "encenserez": "encenser",
    "encenseriez": "encenser",
    "encenserions": "encenser",
    "encenserons": "encenser",
    "encenseront": "encenser",
    "encenses": "encenser",
    "encensez": "encenser",
    "encensiez": "encenser",
    "encensions": "encenser",
    "encensoirs": "encensoir",
    "encensons": "encenser",
    "encensâmes": "encenser",
    "encensât": "encenser",
    "encensâtes": "encenser",
    "encensèrent": "encenser",
    "encensé": "encenser",
    "encensée": "encenser",
    "encensées": "encenser",
    "encensés": "encenser",
    "encercla": "encercler",
    "encerclables": "encerclable",
    "encerclai": "encercler",
    "encerclaient": "encercler",
    "encerclais": "encercler",
    "encerclait": "encercler",
    "encerclant": "encercler",
    "encerclas": "encercler",
    "encerclasse": "encercler",
    "encerclassent": "encercler",
    "encerclasses": "encercler",
    "encerclassiez": "encercler",
    "encerclassions": "encercler",
    "encercle": "encercler",
    "encerclements": "encerclement",
    "encerclent": "encercler",
    "encerclera": "encercler",
    "encerclerai": "encercler",
    "encercleraient": "encercler",
    "encerclerais": "encercler",
    "encerclerait": "encercler",
    "encercleras": "encercler",
    "encerclerez": "encercler",
    "encercleriez": "encercler",
    "encerclerions": "encercler",
    "encerclerons": "encercler",
    "encercleront": "encercler",
    "encercles": "encercler",
    "encerclez": "encercler",
    "encercliez": "encercler",
    "encerclions": "encercler",
    "encerclons": "encercler",
    "encerclâmes": "encercler",
    "encerclât": "encercler",
    "encerclâtes": "encercler",
    "encerclèrent": "encercler",
    "encerclé": "encercler",
    "encerclée": "encercler",
    "encerclées": "encercler",
    "encerclés": "encercler",
    "enchanta": "enchanter",
    "enchantai": "enchanter",
    "enchantaient": "enchanter",
    "enchantais": "enchanter",
    "enchantait": "enchanter",
    "enchantant": "enchanter",
    "enchantas": "enchanter",
    "enchantasse": "enchanter",
    "enchantassent": "enchanter",
    "enchantasses": "enchanter",
    "enchantassiez": "enchanter",
    "enchantassions": "enchanter",
    "enchante": "enchanter",
    "enchantements": "enchantement",
    "enchantent": "enchanter",
    "enchantera": "enchanter",
    "enchanterai": "enchanter",
    "enchanteraient": "enchanter",
    "enchanterais": "enchanter",
    "enchanterait": "enchanter",
    "enchanteras": "enchanter",
    "enchanteresse": "enchanteur",
    "enchanteresses": "enchanteur",
    "enchanterez": "enchanter",
    "enchanteriez": "enchanter",
    "enchanterions": "enchanter",
    "enchanterons": "enchanter",
    "enchanteront": "enchanter",
    "enchantes": "enchanter",
    "enchanteurs": "enchanteur",
    "enchantez": "enchanter",
    "enchantiez": "enchanter",
    "enchantions": "enchanter",
    "enchantons": "enchanter",
    "enchantâmes": "enchanter",
    "enchantât": "enchanter",
    "enchantâtes": "enchanter",
    "enchantèrent": "enchanter",
    "enchanté": "enchanter",
    "enchantée": "enchanter",
    "enchantées": "enchanter",
    "enchantés": "enchanter",
    "enchatonna": "enchatonner",
    "enchatonnai": "enchatonner",
    "enchatonnaient": "enchatonner",
    "enchatonnais": "enchatonner",
    "enchatonnait": "enchatonner",
    "enchatonnant": "enchatonner",
    "enchatonnas": "enchatonner",
    "enchatonnasse": "enchatonner",
    "enchatonnassent": "enchatonner",
    "enchatonnasses": "enchatonner",
    "enchatonnassiez": "enchatonner",
    "enchatonnassions": "enchatonner",
    "enchatonne": "enchatonner",
    "enchatonnent": "enchatonner",
    "enchatonnera": "enchatonner",
    "enchatonnerai": "enchatonner",
    "enchatonneraient": "enchatonner",
    "enchatonnerais": "enchatonner",
    "enchatonnerait": "enchatonner",
    "enchatonneras": "enchatonner",
    "enchatonnerez": "enchatonner",
    "enchatonneriez": "enchatonner",
    "enchatonnerions": "enchatonner",
    "enchatonnerons": "enchatonner",
    "enchatonneront": "enchatonner",
    "enchatonnes": "enchatonner",
    "enchatonnez": "enchatonner",
    "enchatonniez": "enchatonner",
    "enchatonnions": "enchatonner",
    "enchatonnons": "enchatonner",
    "enchatonnâmes": "enchatonner",
    "enchatonnât": "enchatonner",
    "enchatonnâtes": "enchatonner",
    "enchatonnèrent": "enchatonner",
    "enchatonné": "enchatonner",
    "enchatonnée": "enchatonner",
    "enchatonnées": "enchatonner",
    "enchatonnés": "enchatonner",
    "enchaussa": "enchausser",
    "enchaussai": "enchausser",
    "enchaussaient": "enchausser",
    "enchaussais": "enchausser",
    "enchaussait": "enchausser",
    "enchaussant": "enchausser",
    "enchaussas": "enchausser",
    "enchaussasse": "enchausser",
    "enchaussassent": "enchausser",
    "enchaussasses": "enchausser",
    "enchaussassiez": "enchausser",
    "enchaussassions": "enchausser",
    "enchausse": "enchausser",
    "enchaussent": "enchausser",
    "enchaussera": "enchausser",
    "enchausserai": "enchausser",
    "enchausseraient": "enchausser",
    "enchausserais": "enchausser",
    "enchausserait": "enchausser",
    "enchausseras": "enchausser",
    "enchausserez": "enchausser",
    "enchausseriez": "enchausser",
    "enchausserions": "enchausser",
    "enchausserons": "enchausser",
    "enchausseront": "enchausser",
    "enchausses": "enchausser",
    "enchaussez": "enchausser",
    "enchaussiez": "enchausser",
    "enchaussions": "enchausser",
    "enchaussons": "enchausser",
    "enchaussâmes": "enchausser",
    "enchaussât": "enchausser",
    "enchaussâtes": "enchausser",
    "enchaussèrent": "enchausser",
    "enchaussé": "enchausser",
    "enchaussée": "enchausser",
    "enchaussées": "enchausser",
    "enchaussés": "enchausser",
    "enchaîna": "enchaîner",
    "enchaînai": "enchaîner",
    "enchaînaient": "enchaîner",
    "enchaînais": "enchaîner",
    "enchaînait": "enchaîner",
    "enchaînant": "enchaîner",
    "enchaînas": "enchaîner",
    "enchaînasse": "enchaîner",
    "enchaînassent": "enchaîner",
    "enchaînasses": "enchaîner",
    "enchaînassiez": "enchaîner",
    "enchaînassions": "enchaîner",
    "enchaîne": "enchaîner",
    "enchaînements": "enchaînement",
    "enchaînent": "enchaîner",
    "enchaînera": "enchaîner",
    "enchaînerai": "enchaîner",
    "enchaîneraient": "enchaîner",
    "enchaînerais": "enchaîner",
    "enchaînerait": "enchaîner",
    "enchaîneras": "enchaîner",
    "enchaînerez": "enchaîner",
    "enchaîneriez": "enchaîner",
    "enchaînerions": "enchaîner",
    "enchaînerons": "enchaîner",
    "enchaîneront": "enchaîner",
    "enchaînes": "enchaîner",
    "enchaînez": "enchaîner",
    "enchaîniez": "enchaîner",
    "enchaînions": "enchaîner",
    "enchaînons": "enchaîner",
    "enchaînâmes": "enchaîner",
    "enchaînât": "enchaîner",
    "enchaînâtes": "enchaîner",
    "enchaînèrent": "enchaîner",
    "enchaîné": "enchaîner",
    "enchaînée": "enchaîner",
    "enchaînées": "enchaîner",
    "enchaînés": "enchaîner",
    "enchemisé": "enchemiser",
    "enchevêtra": "enchevêtrer",
    "enchevêtrai": "enchevêtrer",
    "enchevêtraient": "enchevêtrer",
    "enchevêtrais": "enchevêtrer",
    "enchevêtrait": "enchevêtrer",
    "enchevêtrant": "enchevêtrer",
    "enchevêtras": "enchevêtrer",
    "enchevêtrasse": "enchevêtrer",
    "enchevêtrassent": "enchevêtrer",
    "enchevêtrasses": "enchevêtrer",
    "enchevêtrassiez": "enchevêtrer",
    "enchevêtrassions": "enchevêtrer",
    "enchevêtre": "enchevêtrer",
    "enchevêtrements": "enchevêtrement",
    "enchevêtrent": "enchevêtrer",
    "enchevêtrera": "enchevêtrer",
    "enchevêtrerai": "enchevêtrer",
    "enchevêtreraient": "enchevêtrer",
    "enchevêtrerais": "enchevêtrer",
    "enchevêtrerait": "enchevêtrer",
    "enchevêtreras": "enchevêtrer",
    "enchevêtrerez": "enchevêtrer",
    "enchevêtreriez": "enchevêtrer",
    "enchevêtrerions": "enchevêtrer",
    "enchevêtrerons": "enchevêtrer",
    "enchevêtreront": "enchevêtrer",
    "enchevêtres": "enchevêtrer",
    "enchevêtrez": "enchevêtrer",
    "enchevêtriez": "enchevêtrer",
    "enchevêtrions": "enchevêtrer",
    "enchevêtrons": "enchevêtrer",
    "enchevêtrâmes": "enchevêtrer",
    "enchevêtrât": "enchevêtrer",
    "enchevêtrâtes": "enchevêtrer",
    "enchevêtrèrent": "enchevêtrer",
    "enchevêtré": "enchevêtrer",
    "enchevêtrée": "enchevêtrer",
    "enchevêtrées": "enchevêtrer",
    "enchevêtrés": "enchevêtrer",
    "enchifrené": "enchifrener",
    "enchifrenée": "enchifrené",
    "enchifrenées": "enchifrené",
    "enchifrenés": "enchifrené",
    "enchriste": "enchrister",
    "enchristé": "enchrister",
    "enchristée": "enchrister",
    "enchtibé": "enchtiber",
    "enchtibés": "enchtiber",
    "enchâssa": "enchâsser",
    "enchâssai": "enchâsser",
    "enchâssaient": "enchâsser",
    "enchâssais": "enchâsser",
    "enchâssait": "enchâsser",
    "enchâssant": "enchâsser",
    "enchâssas": "enchâsser",
    "enchâssasse": "enchâsser",
    "enchâssassent": "enchâsser",
    "enchâssasses": "enchâsser",
    "enchâssassiez": "enchâsser",
    "enchâssassions": "enchâsser",
    "enchâsse": "enchâsser",
    "enchâssent": "enchâsser",
    "enchâssera": "enchâsser",
    "enchâsserai": "enchâsser",
    "enchâsseraient": "enchâsser",
    "enchâsserais": "enchâsser",
    "enchâsserait": "enchâsser",
    "enchâsseras": "enchâsser",
    "enchâsserez": "enchâsser",
    "enchâsseriez": "enchâsser",
    "enchâsserions": "enchâsser",
    "enchâsserons": "enchâsser",
    "enchâsseront": "enchâsser",
    "enchâsses": "enchâsser",
    "enchâssez": "enchâsser",
    "enchâssiez": "enchâsser",
    "enchâssions": "enchâsser",
    "enchâssons": "enchâsser",
    "enchâssâmes": "enchâsser",
    "enchâssât": "enchâsser",
    "enchâssâtes": "enchâsser",
    "enchâssèrent": "enchâsser",
    "enchâssé": "enchâsser",
    "enchâssée": "enchâsser",
    "enchâssées": "enchâsser",
    "enchâssés": "enchâsser",
    "enchères": "enchère",
    "enchéri": "enchérir",
    "enchérira": "enchérir",
    "enchérirai": "enchérir",
    "enchériraient": "enchérir",
    "enchérirais": "enchérir",
    "enchérirait": "enchérir",
    "enchériras": "enchérir",
    "enchérirent": "enchérir",
    "enchérirez": "enchérir",
    "enchéririez": "enchérir",
    "enchéririons": "enchérir",
    "enchérirons": "enchérir",
    "enchériront": "enchérir",
    "enchéris": "enchérir",
    "enchérissaient": "enchérir",
    "enchérissais": "enchérir",
    "enchérissait": "enchérir",
    "enchérissant": "enchérir",
    "enchérisse": "enchérir",
    "enchérissent": "enchérir",
    "enchérisses": "enchérir",
    "enchérisseurs": "enchérisseur",
    "enchérisseuse": "enchérisseur",
    "enchérissez": "enchérir",
    "enchérissiez": "enchérir",
    "enchérissions": "enchérir",
    "enchérissons": "enchérir",
    "enchérit": "enchérir",
    "enchérîmes": "enchérir",
    "enchérît": "enchérir",
    "enchérîtes": "enchérir",
    "encira": "encirer",
    "encirai": "encirer",
    "enciraient": "encirer",
    "encirais": "encirer",
    "encirait": "encirer",
    "encirant": "encirer",
    "enciras": "encirer",
    "encirasse": "encirer",
    "encirassent": "encirer",
    "encirasses": "encirer",
    "encirassiez": "encirer",
    "encirassions": "encirer",
    "encire": "encirer",
    "encirent": "encirer",
    "encirera": "encirer",
    "encirerai": "encirer",
    "encireraient": "encirer",
    "encirerais": "encirer",
    "encirerait": "encirer",
    "encireras": "encirer",
    "encirerez": "encirer",
    "encireriez": "encirer",
    "encirerions": "encirer",
    "encirerons": "encirer",
    "encireront": "encirer",
    "encires": "encirer",
    "encirez": "encirer",
    "enciriez": "encirer",
    "encirions": "encirer",
    "encirons": "encirer",
    "encirâmes": "encirer",
    "encirât": "encirer",
    "encirâtes": "encirer",
    "encirèrent": "encirer",
    "enciré": "encirer",
    "encirée": "encirer",
    "encirées": "encirer",
    "encirés": "encirer",
    "enclava": "enclaver",
    "enclavai": "enclaver",
    "enclavaient": "enclaver",
    "enclavais": "enclaver",
    "enclavait": "enclaver",
    "enclavant": "enclaver",
    "enclavas": "enclaver",
    "enclavasse": "enclaver",
    "enclavassent": "enclaver",
    "enclavasses": "enclaver",
    "enclavassiez": "enclaver",
    "enclavassions": "enclaver",
    "enclave": "enclaver",
    "enclavent": "enclaver",
    "enclavera": "enclaver",
    "enclaverai": "enclaver",
    "enclaveraient": "enclaver",
    "enclaverais": "enclaver",
    "enclaverait": "enclaver",
    "enclaveras": "enclaver",
    "enclaverez": "enclaver",
    "enclaveriez": "enclaver",
    "enclaverions": "enclaver",
    "enclaverons": "enclaver",
    "enclaveront": "enclaver",
    "enclaves": "enclaver",
    "enclavez": "enclaver",
    "enclaviez": "enclaver",
    "enclavions": "enclaver",
    "enclavons": "enclaver",
    "enclavâmes": "enclaver",
    "enclavât": "enclaver",
    "enclavâtes": "enclaver",
    "enclavèrent": "enclaver",
    "enclavé": "enclaver",
    "enclavée": "enclaver",
    "enclavées": "enclaver",
    "enclavés": "enclaver",
    "enclencha": "enclencher",
    "enclenchai": "enclencher",
    "enclenchaient": "enclencher",
    "enclenchais": "enclencher",
    "enclenchait": "enclencher",
    "enclenchant": "enclencher",
    "enclenchas": "enclencher",
    "enclenchasse": "enclencher",
    "enclenchassent": "enclencher",
    "enclenchasses": "enclencher",
    "enclenchassiez": "enclencher",
    "enclenchassions": "enclencher",
    "enclenche": "enclencher",
    "enclenchent": "enclencher",
    "enclenchera": "enclencher",
    "enclencherai": "enclencher",
    "enclencheraient": "enclencher",
    "enclencherais": "enclencher",
    "enclencherait": "enclencher",
    "enclencheras": "enclencher",
    "enclencherez": "enclencher",
    "enclencheriez": "enclencher",
    "enclencherions": "enclencher",
    "enclencherons": "enclencher",
    "enclencheront": "enclencher",
    "enclenches": "enclencher",
    "enclenchez": "enclencher",
    "enclenchiez": "enclencher",
    "enclenchions": "enclencher",
    "enclenchons": "enclencher",
    "enclenchâmes": "enclencher",
    "enclenchât": "enclencher",
    "enclenchâtes": "enclencher",
    "enclenchèrent": "enclencher",
    "enclenché": "enclencher",
    "enclenchée": "enclencher",
    "enclenchées": "enclencher",
    "enclenchés": "enclencher",
    "encline": "enclin",
    "enclines": "enclin",
    "enclins": "enclin",
    "enclises": "enclise",
    "enclitiques": "enclitique",
    "encloqué": "encloquer",
    "enclora": "enclore",
    "enclorai": "enclore",
    "encloraient": "enclore",
    "enclorais": "enclore",
    "enclorait": "enclore",
    "encloras": "enclore",
    "enclorez": "enclore",
    "encloriez": "enclore",
    "enclorions": "enclore",
    "enclorons": "enclore",
    "encloront": "enclore",
    "enclos": "enclore",
    "enclosant": "enclore",
    "enclose": "enclore",
    "enclosent": "enclore",
    "encloses": "enclore",
    "enclosiez": "enclore",
    "enclosions": "enclore",
    "enclot": "enclore",
    "encloua": "enclouer",
    "enclouai": "enclouer",
    "enclouaient": "enclouer",
    "enclouais": "enclouer",
    "enclouait": "enclouer",
    "enclouant": "enclouer",
    "enclouas": "enclouer",
    "enclouasse": "enclouer",
    "enclouassent": "enclouer",
    "enclouasses": "enclouer",
    "enclouassiez": "enclouer",
    "enclouassions": "enclouer",
    "encloue": "enclouer",
    "enclouent": "enclouer",
    "enclouera": "enclouer",
    "enclouerai": "enclouer",
    "encloueraient": "enclouer",
    "enclouerais": "enclouer",
    "enclouerait": "enclouer",
    "encloueras": "enclouer",
    "enclouerez": "enclouer",
    "encloueriez": "enclouer",
    "enclouerions": "enclouer",
    "enclouerons": "enclouer",
    "encloueront": "enclouer",
    "encloues": "enclouer",
    "enclouez": "enclouer",
    "enclouiez": "enclouer",
    "enclouions": "enclouer",
    "enclouons": "enclouer",
    "enclouâmes": "enclouer",
    "enclouât": "enclouer",
    "enclouâtes": "enclouer",
    "enclouèrent": "enclouer",
    "encloué": "enclouer",
    "enclouée": "enclouer",
    "enclouées": "enclouer",
    "encloués": "enclouer",
    "enclumes": "enclume",
    "encoches": "encoche",
    "encoché": "encocher",
    "encoconnée": "encoconner",
    "encode": "encoder",
    "encodé": "encoder",
    "encodée": "encoder",
    "encodés": "encoder",
    "encoignures": "encoignure",
    "encolla": "encoller",
    "encollai": "encoller",
    "encollaient": "encoller",
    "encollais": "encoller",
    "encollait": "encoller",
    "encollant": "encoller",
    "encollas": "encoller",
    "encollasse": "encoller",
    "encollassent": "encoller",
    "encollasses": "encoller",
    "encollassiez": "encoller",
    "encollassions": "encoller",
    "encolle": "encoller",
    "encollent": "encoller",
    "encollera": "encoller",
    "encollerai": "encoller",
    "encolleraient": "encoller",
    "encollerais": "encoller",
    "encollerait": "encoller",
    "encolleras": "encoller",
    "encollerez": "encoller",
    "encolleriez": "encoller",
    "encollerions": "encoller",
    "encollerons": "encoller",
    "encolleront": "encoller",
    "encolles": "encoller",
    "encolleuses": "encolleur",
    "encollez": "encoller",
    "encolliez": "encoller",
    "encollions": "encoller",
    "encollons": "encoller",
    "encollâmes": "encoller",
    "encollât": "encoller",
    "encollâtes": "encoller",
    "encollèrent": "encoller",
    "encollé": "encoller",
    "encollée": "encoller",
    "encollées": "encoller",
    "encollés": "encoller",
    "encolures": "encolure",
    "encolérée": "encoléré",
    "encolérés": "encoléré",
    "encombra": "encombrer",
    "encombrai": "encombrer",
    "encombraient": "encombrer",
    "encombrais": "encombrer",
    "encombrait": "encombrer",
    "encombrant": "encombrer",
    "encombrante": "encombrant",
    "encombrantes": "encombrant",
    "encombrants": "encombrant",
    "encombras": "encombrer",
    "encombrasse": "encombrer",
    "encombrassent": "encombrer",
    "encombrasses": "encombrer",
    "encombrassiez": "encombrer",
    "encombrassions": "encombrer",
    "encombre": "encombrer",
    "encombrements": "encombrement",
    "encombrent": "encombrer",
    "encombrera": "encombrer",
    "encombrerai": "encombrer",
    "encombreraient": "encombrer",
    "encombrerais": "encombrer",
    "encombrerait": "encombrer",
    "encombreras": "encombrer",
    "encombrerez": "encombrer",
    "encombreriez": "encombrer",
    "encombrerions": "encombrer",
    "encombrerons": "encombrer",
    "encombreront": "encombrer",
    "encombres": "encombrer",
    "encombrez": "encombrer",
    "encombriez": "encombrer",
    "encombrions": "encombrer",
    "encombrons": "encombrer",
    "encombrâmes": "encombrer",
    "encombrât": "encombrer",
    "encombrâtes": "encombrer",
    "encombrèrent": "encombrer",
    "encombré": "encombrer",
    "encombrée": "encombrer",
    "encombrées": "encombrer",
    "encombrés": "encombrer",
    "encorbellements": "encorbellement",
    "encorda": "encorder",
    "encordai": "encorder",
    "encordaient": "encorder",
    "encordais": "encorder",
    "encordait": "encorder",
    "encordant": "encorder",
    "encordas": "encorder",
    "encordasse": "encorder",
    "encordassent": "encorder",
    "encordasses": "encorder",
    "encordassiez": "encorder",
    "encordassions": "encorder",
    "encorde": "encorder",
    "encordent": "encorder",
    "encordera": "encorder",
    "encorderai": "encorder",
    "encorderaient": "encorder",
    "encorderais": "encorder",
    "encorderait": "encorder",
    "encorderas": "encorder",
    "encorderez": "encorder",
    "encorderiez": "encorder",
    "encorderions": "encorder",
    "encorderons": "encorder",
    "encorderont": "encorder",
    "encordes": "encorder",
    "encordez": "encorder",
    "encordiez": "encorder",
    "encordions": "encorder",
    "encordons": "encorder",
    "encordâmes": "encorder",
    "encordât": "encorder",
    "encordâtes": "encorder",
    "encordèrent": "encorder",
    "encordé": "encorder",
    "encordée": "encorder",
    "encordées": "encorder",
    "encordés": "encorder",
    "encorna": "encorner",
    "encornai": "encorner",
    "encornaient": "encorner",
    "encornais": "encorner",
    "encornait": "encorner",
    "encornant": "encorner",
    "encornas": "encorner",
    "encornasse": "encorner",
    "encornassent": "encorner",
    "encornasses": "encorner",
    "encornassiez": "encorner",
    "encornassions": "encorner",
    "encorne": "encorner",
    "encornent": "encorner",
    "encornera": "encorner",
    "encornerai": "encorner",
    "encorneraient": "encorner",
    "encornerais": "encorner",
    "encornerait": "encorner",
    "encorneras": "encorner",
    "encornerez": "encorner",
    "encorneriez": "encorner",
    "encornerions": "encorner",
    "encornerons": "encorner",
    "encorneront": "encorner",
    "encornes": "encorner",
    "encornets": "encornet",
    "encornez": "encorner",
    "encorniez": "encorner",
    "encornions": "encorner",
    "encornons": "encorner",
    "encornâmes": "encorner",
    "encornât": "encorner",
    "encornâtes": "encorner",
    "encornèrent": "encorner",
    "encorné": "encorner",
    "encornée": "encorner",
    "encornées": "encorner",
    "encornés": "encorner",
    "encotonne": "encotonner",
    "encourage": "encourager",
    "encouragea": "encourager",
    "encourageai": "encourager",
    "encourageaient": "encourager",
    "encourageais": "encourager",
    "encourageait": "encourager",
    "encourageant": "encourager",
    "encourageante": "encourageant",
    "encourageantes": "encourageant",
    "encourageants": "encourageant",
    "encourageas": "encourager",
    "encourageasse": "encourager",
    "encourageassent": "encourager",
    "encourageasses": "encourager",
    "encourageassiez": "encourager",
    "encourageassions": "encourager",
    "encouragements": "encouragement",
    "encouragent": "encourager",
    "encourageons": "encourager",
    "encouragera": "encourager",
    "encouragerai": "encourager",
    "encourageraient": "encourager",
    "encouragerais": "encourager",
    "encouragerait": "encourager",
    "encourageras": "encourager",
    "encouragerez": "encourager",
    "encourageriez": "encourager",
    "encouragerions": "encourager",
    "encouragerons": "encourager",
    "encourageront": "encourager",
    "encourages": "encourager",
    "encouragez": "encourager",
    "encourageâmes": "encourager",
    "encourageât": "encourager",
    "encourageâtes": "encourager",
    "encouragiez": "encourager",
    "encouragions": "encourager",
    "encouragèrent": "encourager",
    "encouragé": "encourager",
    "encouragée": "encourager",
    "encouragées": "encourager",
    "encouragés": "encourager",
    "encouraient": "encourir",
    "encourais": "encourir",
    "encourait": "encourir",
    "encourant": "encourir",
    "encoure": "encourir",
    "encourent": "encourir",
    "encoures": "encourir",
    "encourez": "encourir",
    "encouriez": "encourir",
    "encourions": "encourir",
    "encourons": "encourir",
    "encourra": "encourir",
    "encourrai": "encourir",
    "encourraient": "encourir",
    "encourrais": "encourir",
    "encourrait": "encourir",
    "encourras": "encourir",
    "encourrez": "encourir",
    "encourriez": "encourir",
    "encourrions": "encourir",
    "encourrons": "encourir",
    "encourront": "encourir",
    "encours": "encourir",
    "encourt": "encourir",
    "encouru": "encourir",
    "encourue": "encourir",
    "encourues": "encourir",
    "encoururent": "encourir",
    "encourus": "encourir",
    "encourusse": "encourir",
    "encourussent": "encourir",
    "encourusses": "encourir",
    "encourussiez": "encourir",
    "encourussions": "encourir",
    "encourut": "encourir",
    "encourûmes": "encourir",
    "encourût": "encourir",
    "encourûtes": "encourir",
    "encra": "encrer",
    "encrages": "encrage",
    "encrai": "encrer",
    "encraient": "encrer",
    "encrais": "encrer",
    "encrait": "encrer",
    "encrant": "encrer",
    "encras": "encrer",
    "encrassa": "encrasser",
    "encrassai": "encrasser",
    "encrassaient": "encrasser",
    "encrassais": "encrasser",
    "encrassait": "encrasser",
    "encrassant": "encrasser",
    "encrassas": "encrasser",
    "encrassasse": "encrasser",
    "encrassassent": "encrasser",
    "encrassasses": "encrasser",
    "encrassassiez": "encrasser",
    "encrassassions": "encrasser",
    "encrasse": "encrer",
    "encrassent": "encrer",
    "encrassera": "encrasser",
    "encrasserai": "encrasser",
    "encrasseraient": "encrasser",
    "encrasserais": "encrasser",
    "encrasserait": "encrasser",
    "encrasseras": "encrasser",
    "encrasserez": "encrasser",
    "encrasseriez": "encrasser",
    "encrasserions": "encrasser",
    "encrasserons": "encrasser",
    "encrasseront": "encrasser",
    "encrasses": "encrer",
    "encrassez": "encrasser",
    "encrassiez": "encrer",
    "encrassions": "encrer",
    "encrassons": "encrasser",
    "encrassâmes": "encrasser",
    "encrassât": "encrasser",
    "encrassâtes": "encrasser",
    "encrassèrent": "encrasser",
    "encrassé": "encrasser",
    "encrassée": "encrasser",
    "encrassées": "encrasser",
    "encrassés": "encrasser",
    "encre": "encrer",
    "encrent": "encrer",
    "encrera": "encrer",
    "encrerai": "encrer",
    "encreraient": "encrer",
    "encrerais": "encrer",
    "encrerait": "encrer",
    "encreras": "encrer",
    "encrerez": "encrer",
    "encreriez": "encrer",
    "encrerions": "encrer",
    "encrerons": "encrer",
    "encreront": "encrer",
    "encres": "encrer",
    "encreurs": "encreur",
    "encrez": "encrer",
    "encriers": "encrier",
    "encriez": "encrer",
    "encrions": "encrer",
    "encroisa": "encroiser",
    "encroisai": "encroiser",
    "encroisaient": "encroiser",
    "encroisais": "encroiser",
    "encroisait": "encroiser",
    "encroisant": "encroiser",
    "encroisas": "encroiser",
    "encroisasse": "encroiser",
    "encroisassent": "encroiser",
    "encroisasses": "encroiser",
    "encroisassiez": "encroiser",
    "encroisassions": "encroiser",
    "encroise": "encroiser",
    "encroisent": "encroiser",
    "encroisera": "encroiser",
    "encroiserai": "encroiser",
    "encroiseraient": "encroiser",
    "encroiserais": "encroiser",
    "encroiserait": "encroiser",
    "encroiseras": "encroiser",
    "encroiserez": "encroiser",
    "encroiseriez": "encroiser",
    "encroiserions": "encroiser",
    "encroiserons": "encroiser",
    "encroiseront": "encroiser",
    "encroises": "encroiser",
    "encroisez": "encroiser",
    "encroisiez": "encroiser",
    "encroisions": "encroiser",
    "encroisons": "encroiser",
    "encroisâmes": "encroiser",
    "encroisât": "encroiser",
    "encroisâtes": "encroiser",
    "encroisèrent": "encroiser",
    "encroisé": "encroiser",
    "encroisée": "encroiser",
    "encroisées": "encroiser",
    "encroisés": "encroiser",
    "encrons": "encrer",
    "encrotté": "encrotter",
    "encroûta": "encroûter",
    "encroûtai": "encroûter",
    "encroûtaient": "encroûter",
    "encroûtais": "encroûter",
    "encroûtait": "encroûter",
    "encroûtant": "encroûter",
    "encroûtas": "encroûter",
    "encroûtasse": "encroûter",
    "encroûtassent": "encroûter",
    "encroûtasses": "encroûter",
    "encroûtassiez": "encroûter",
    "encroûtassions": "encroûter",
    "encroûte": "encroûter",
    "encroûtent": "encroûter",
    "encroûtera": "encroûter",
    "encroûterai": "encroûter",
    "encroûteraient": "encroûter",
    "encroûterais": "encroûter",
    "encroûterait": "encroûter",
    "encroûteras": "encroûter",
    "encroûterez": "encroûter",
    "encroûteriez": "encroûter",
    "encroûterions": "encroûter",
    "encroûterons": "encroûter",
    "encroûteront": "encroûter",
    "encroûtes": "encroûter",
    "encroûtez": "encroûter",
    "encroûtiez": "encroûter",
    "encroûtions": "encroûter",
    "encroûtons": "encroûter",
    "encroûtâmes": "encroûter",
    "encroûtât": "encroûter",
    "encroûtâtes": "encroûter",
    "encroûtèrent": "encroûter",
    "encroûté": "encroûter",
    "encroûtée": "encroûter",
    "encroûtées": "encroûter",
    "encroûtés": "encroûter",
    "encrypté": "encrypter",
    "encrâmes": "encrer",
    "encrât": "encrer",
    "encrâtes": "encrer",
    "encrèrent": "encrer",
    "encré": "encrer",
    "encrée": "encrer",
    "encrées": "encrer",
    "encrés": "encrer",
    "enculades": "enculade",
    "enculant": "enculer",
    "encule": "enculer",
    "enculent": "enculer",
    "enculera": "enculer",
    "enculerais": "enculer",
    "enculerait": "enculer",
    "enculeries": "enculerie",
    "encules": "enculer",
    "enculeurs": "enculeur",
    "enculé": "enculer",
    "enculée": "enculer",
    "enculées": "enculé",
    "enculés": "enculer",
    "encuva": "encuver",
    "encuvai": "encuver",
    "encuvaient": "encuver",
    "encuvais": "encuver",
    "encuvait": "encuver",
    "encuvant": "encuver",
    "encuvas": "encuver",
    "encuvasse": "encuver",
    "encuvassent": "encuver",
    "encuvasses": "encuver",
    "encuvassiez": "encuver",
    "encuvassions": "encuver",
    "encuve": "encuver",
    "encuvent": "encuver",
    "encuvera": "encuver",
    "encuverai": "encuver",
    "encuveraient": "encuver",
    "encuverais": "encuver",
    "encuverait": "encuver",
    "encuveras": "encuver",
    "encuverez": "encuver",
    "encuveriez": "encuver",
    "encuverions": "encuver",
    "encuverons": "encuver",
    "encuveront": "encuver",
    "encuves": "encuver",
    "encuvez": "encuver",
    "encuviez": "encuver",
    "encuvions": "encuver",
    "encuvons": "encuver",
    "encuvâmes": "encuver",
    "encuvât": "encuver",
    "encuvâtes": "encuver",
    "encuvèrent": "encuver",
    "encuvé": "encuver",
    "encuvée": "encuver",
    "encuvées": "encuver",
    "encuvés": "encuver",
    "encycliques": "encyclique",
    "encyclopédies": "encyclopédie",
    "encyclopédiques": "encyclopédique",
    "encyclopédistes": "encyclopédiste",
    "encéphales": "encéphale",
    "encéphaliques": "encéphalique",
    "endenta": "endenter",
    "endentai": "endenter",
    "endentaient": "endenter",
    "endentais": "endenter",
    "endentait": "endenter",
    "endentant": "endenter",
    "endentas": "endenter",
    "endentasse": "endenter",
    "endentassent": "endenter",
    "endentasses": "endenter",
    "endentassiez": "endenter",
    "endentassions": "endenter",
    "endente": "endenter",
    "endentent": "endenter",
    "endentera": "endenter",
    "endenterai": "endenter",
    "endenteraient": "endenter",
    "endenterais": "endenter",
    "endenterait": "endenter",
    "endenteras": "endenter",
    "endenterez": "endenter",
    "endenteriez": "endenter",
    "endenterions": "endenter",
    "endenterons": "endenter",
    "endenteront": "endenter",
    "endentes": "endenter",
    "endentez": "endenter",
    "endentiez": "endenter",
    "endentions": "endenter",
    "endentons": "endenter",
    "endentâmes": "endenter",
    "endentât": "endenter",
    "endentâtes": "endenter",
    "endentèrent": "endenter",
    "endenté": "endenter",
    "endentée": "endenter",
    "endentées": "endenter",
    "endentés": "endenter",
    "endetta": "endetter",
    "endettai": "endetter",
    "endettaient": "endetter",
    "endettais": "endetter",
    "endettait": "endetter",
    "endettant": "endetter",
    "endettas": "endetter",
    "endettasse": "endetter",
    "endettassent": "endetter",
    "endettasses": "endetter",
    "endettassiez": "endetter",
    "endettassions": "endetter",
    "endette": "endetter",
    "endettements": "endettement",
    "endettent": "endetter",
    "endettera": "endetter",
    "endetterai": "endetter",
    "endetteraient": "endetter",
    "endetterais": "endetter",
    "endetterait": "endetter",
    "endetteras": "endetter",
    "endetterez": "endetter",
    "endetteriez": "endetter",
    "endetterions": "endetter",
    "endetterons": "endetter",
    "endetteront": "endetter",
    "endettes": "endetter",
    "endettez": "endetter",
    "endettiez": "endetter",
    "endettions": "endetter",
    "endettons": "endetter",
    "endettâmes": "endetter",
    "endettât": "endetter",
    "endettâtes": "endetter",
    "endettèrent": "endetter",
    "endetté": "endetter",
    "endettée": "endetter",
    "endettées": "endetter",
    "endettés": "endetter",
    "endeuilla": "endeuiller",
    "endeuillai": "endeuiller",
    "endeuillaient": "endeuiller",
    "endeuillais": "endeuiller",
    "endeuillait": "endeuiller",
    "endeuillant": "endeuiller",
    "endeuillas": "endeuiller",
    "endeuillasse": "endeuiller",
    "endeuillassent": "endeuiller",
    "endeuillasses": "endeuiller",
    "endeuillassiez": "endeuiller",
    "endeuillassions": "endeuiller",
    "endeuille": "endeuiller",
    "endeuillent": "endeuiller",
    "endeuillera": "endeuiller",
    "endeuillerai": "endeuiller",
    "endeuilleraient": "endeuiller",
    "endeuillerais": "endeuiller",
    "endeuillerait": "endeuiller",
    "endeuilleras": "endeuiller",
    "endeuillerez": "endeuiller",
    "endeuilleriez": "endeuiller",
    "endeuillerions": "endeuiller",
    "endeuillerons": "endeuiller",
    "endeuilleront": "endeuiller",
    "endeuilles": "endeuiller",
    "endeuillez": "endeuiller",
    "endeuilliez": "endeuiller",
    "endeuillions": "endeuiller",
    "endeuillons": "endeuiller",
    "endeuillâmes": "endeuiller",
    "endeuillât": "endeuiller",
    "endeuillâtes": "endeuiller",
    "endeuillèrent": "endeuiller",
    "endeuillé": "endeuiller",
    "endeuillée": "endeuiller",
    "endeuillées": "endeuiller",
    "endeuillés": "endeuiller",
    "endiable": "endiabler",
    "endiablent": "endiabler",
    "endiablerez": "endiabler",
    "endiablée": "endiabler",
    "endiablées": "endiabler",
    "endiablés": "endiablé",
    "endiamantée": "endiamanté",
    "endiamantées": "endiamanté",
    "endiamantés": "endiamanté",
    "endigua": "endiguer",
    "endiguai": "endiguer",
    "endiguaient": "endiguer",
    "endiguais": "endiguer",
    "endiguait": "endiguer",
    "endiguant": "endiguer",
    "endiguas": "endiguer",
    "endiguasse": "endiguer",
    "endiguassent": "endiguer",
    "endiguasses": "endiguer",
    "endiguassiez": "endiguer",
    "endiguassions": "endiguer",
    "endigue": "endiguer",
    "endiguent": "endiguer",
    "endiguera": "endiguer",
    "endiguerai": "endiguer",
    "endigueraient": "endiguer",
    "endiguerais": "endiguer",
    "endiguerait": "endiguer",
    "endigueras": "endiguer",
    "endiguerez": "endiguer",
    "endigueriez": "endiguer",
    "endiguerions": "endiguer",
    "endiguerons": "endiguer",
    "endigueront": "endiguer",
    "endigues": "endiguer",
    "endiguez": "endiguer",
    "endiguiez": "endiguer",
    "endiguions": "endiguer",
    "endiguons": "endiguer",
    "endiguâmes": "endiguer",
    "endiguât": "endiguer",
    "endiguâtes": "endiguer",
    "endiguèrent": "endiguer",
    "endigué": "endiguer",
    "endiguée": "endiguer",
    "endiguées": "endiguer",
    "endigués": "endiguer",
    "endimanchait": "endimancher",
    "endimanché": "endimancher",
    "endimanchée": "endimancher",
    "endimanchées": "endimancher",
    "endimanchés": "endimancher",
    "endives": "endive",
    "endivisionnés": "endivisionner",
    "endocardes": "endocarde",
    "endocarpes": "endocarpe",
    "endocrines": "endocrine",
    "endocrinienne": "endocrinien",
    "endocriniens": "endocrinien",
    "endocrinologies": "endocrinologie",
    "endoctrina": "endoctriner",
    "endoctrinai": "endoctriner",
    "endoctrinaient": "endoctriner",
    "endoctrinais": "endoctriner",
    "endoctrinait": "endoctriner",
    "endoctrinant": "endoctriner",
    "endoctrinas": "endoctriner",
    "endoctrinasse": "endoctriner",
    "endoctrinassent": "endoctriner",
    "endoctrinasses": "endoctriner",
    "endoctrinassiez": "endoctriner",
    "endoctrinassions": "endoctriner",
    "endoctrine": "endoctriner",
    "endoctrinements": "endoctrinement",
    "endoctrinent": "endoctriner",
    "endoctrinera": "endoctriner",
    "endoctrinerai": "endoctriner",
    "endoctrineraient": "endoctriner",
    "endoctrinerais": "endoctriner",
    "endoctrinerait": "endoctriner",
    "endoctrineras": "endoctriner",
    "endoctrinerez": "endoctriner",
    "endoctrineriez": "endoctriner",
    "endoctrinerions": "endoctriner",
    "endoctrinerons": "endoctriner",
    "endoctrineront": "endoctriner",
    "endoctrines": "endoctriner",
    "endoctrinez": "endoctriner",
    "endoctriniez": "endoctriner",
    "endoctrinions": "endoctriner",
    "endoctrinons": "endoctriner",
    "endoctrinâmes": "endoctriner",
    "endoctrinât": "endoctriner",
    "endoctrinâtes": "endoctriner",
    "endoctrinèrent": "endoctriner",
    "endoctriné": "endoctriner",
    "endoctrinée": "endoctriner",
    "endoctrinées": "endoctriner",
    "endoctrinés": "endoctriner",
    "endogamies": "endogamie",
    "endogènes": "endogène",
    "endolori": "endolorir",
    "endolorie": "endolorir",
    "endolories": "endolorir",
    "endolorira": "endolorir",
    "endolorirai": "endolorir",
    "endoloriraient": "endolorir",
    "endolorirais": "endolorir",
    "endolorirait": "endolorir",
    "endoloriras": "endolorir",
    "endolorirent": "endolorir",
    "endolorirez": "endolorir",
    "endoloririez": "endolorir",
    "endoloririons": "endolorir",
    "endolorirons": "endolorir",
    "endoloriront": "endolorir",
    "endoloris": "endolorir",
    "endolorissaient": "endolorir",
    "endolorissais": "endolorir",
    "endolorissait": "endolorir",
    "endolorissant": "endolorir",
    "endolorisse": "endolorir",
    "endolorissent": "endolorir",
    "endolorisses": "endolorir",
    "endolorissez": "endolorir",
    "endolorissiez": "endolorir",
    "endolorissions": "endolorir",
    "endolorissons": "endolorir",
    "endolorit": "endolorir",
    "endolorîmes": "endolorir",
    "endolorît": "endolorir",
    "endolorîtes": "endolorir",
    "endommage": "endommager",
    "endommagea": "endommager",
    "endommageai": "endommager",
    "endommageaient": "endommager",
    "endommageais": "endommager",
    "endommageait": "endommager",
    "endommageant": "endommager",
    "endommageas": "endommager",
    "endommageasse": "endommager",
    "endommageassent": "endommager",
    "endommageasses": "endommager",
    "endommageassiez": "endommager",
    "endommageassions": "endommager",
    "endommagements": "endommagement",
    "endommagent": "endommager",
    "endommageons": "endommager",
    "endommagera": "endommager",
    "endommagerai": "endommager",
    "endommageraient": "endommager",
    "endommagerais": "endommager",
    "endommagerait": "endommager",
    "endommageras": "endommager",
    "endommagerez": "endommager",
    "endommageriez": "endommager",
    "endommagerions": "endommager",
    "endommagerons": "endommager",
    "endommageront": "endommager",
    "endommages": "endommager",
    "endommagez": "endommager",
    "endommageâmes": "endommager",
    "endommageât": "endommager",
    "endommageâtes": "endommager",
    "endommagiez": "endommager",
    "endommagions": "endommager",
    "endommagèrent": "endommager",
    "endommagé": "endommager",
    "endommagée": "endommager",
    "endommagées": "endommager",
    "endommagés": "endommager",
    "endormaient": "endormir",
    "endormais": "endormir",
    "endormait": "endormir",
    "endormant": "endormir",
    "endormante": "endormant",
    "endorme": "endormir",
    "endorment": "endormir",
    "endormes": "endormir",
    "endormeurs": "endormeur",
    "endormez": "endormir",
    "endormi": "endormir",
    "endormie": "endormir",
    "endormies": "endormir",
    "endormiez": "endormir",
    "endormions": "endormir",
    "endormira": "endormir",
    "endormirai": "endormir",
    "endormiraient": "endormir",
    "endormirais": "endormir",
    "endormirait": "endormir",
    "endormiras": "endormir",
    "endormirent": "endormir",
    "endormirez": "endormir",
    "endormiriez": "endormir",
    "endormirions": "endormir",
    "endormirons": "endormir",
    "endormiront": "endormir",
    "endormis": "endormir",
    "endormisse": "endormir",
    "endormissements": "endormissement",
    "endormissent": "endormir",
    "endormisses": "endormir",
    "endormissiez": "endormir",
    "endormissions": "endormir",
    "endormit": "endormir",
    "endormons": "endormir",
    "endormîmes": "endormir",
    "endormît": "endormir",
    "endormîtes": "endormir",
    "endorphines": "endorphine",
    "endors": "endormir",
    "endort": "endormir",
    "endoréismes": "endoréisme",
    "endosmoses": "endosmose",
    "endossa": "endosser",
    "endossables": "endossable",
    "endossai": "endosser",
    "endossaient": "endosser",
    "endossais": "endosser",
    "endossait": "endosser",
    "endossant": "endosser",
    "endossas": "endosser",
    "endossasse": "endosser",
    "endossassent": "endosser",
    "endossasses": "endosser",
    "endossassiez": "endosser",
    "endossassions": "endosser",
    "endosse": "endosser",
    "endossements": "endossement",
    "endossent": "endosser",
    "endossera": "endosser",
    "endosserai": "endosser",
    "endosseraient": "endosser",
    "endosserais": "endosser",
    "endosserait": "endosser",
    "endosseras": "endosser",
    "endosserez": "endosser",
    "endosseriez": "endosser",
    "endosserions": "endosser",
    "endosserons": "endosser",
    "endosseront": "endosser",
    "endosses": "endosser",
    "endossez": "endosser",
    "endossiez": "endosser",
    "endossions": "endosser",
    "endossons": "endosser",
    "endossâmes": "endosser",
    "endossât": "endosser",
    "endossâtes": "endosser",
    "endossèrent": "endosser",
    "endossé": "endosser",
    "endossée": "endosser",
    "endossées": "endosser",
    "endossés": "endosser",
    "endothéliale": "endothélial",
    "endothéliales": "endothélial",
    "endothéliaux": "endothélial",
    "endothéliums": "endothélium",
    "endroits": "endroit",
    "enductions": "enduction",
    "enduira": "enduire",
    "enduirai": "enduire",
    "enduiraient": "enduire",
    "enduirais": "enduire",
    "enduirait": "enduire",
    "enduiras": "enduire",
    "enduirez": "enduire",
    "enduiriez": "enduire",
    "enduirions": "enduire",
    "enduirons": "enduire",
    "enduiront": "enduire",
    "enduis": "enduire",
    "enduisaient": "enduire",
    "enduisais": "enduire",
    "enduisait": "enduire",
    "enduisant": "enduire",
    "enduise": "enduire",
    "enduisent": "enduire",
    "enduises": "enduire",
    "enduisez": "enduire",
    "enduisiez": "enduire",
    "enduisions": "enduire",
    "enduisirent": "enduire",
    "enduisis": "enduire",
    "enduisisse": "enduire",
    "enduisissent": "enduire",
    "enduisisses": "enduire",
    "enduisissiez": "enduire",
    "enduisissions": "enduire",
    "enduisit": "enduire",
    "enduisons": "enduire",
    "enduisîmes": "enduire",
    "enduisît": "enduire",
    "enduisîtes": "enduire",
    "enduit": "enduire",
    "enduite": "enduire",
    "enduites": "enduire",
    "enduits": "enduit",
    "endura": "endurer",
    "endurai": "endurer",
    "enduraient": "endurer",
    "endurais": "endurer",
    "endurait": "endurer",
    "endurances": "endurance",
    "endurant": "endurer",
    "endurante": "endurant",
    "endurantes": "endurant",
    "endurants": "endurant",
    "enduras": "endurer",
    "endurasse": "endurer",
    "endurassent": "endurer",
    "endurasses": "endurer",
    "endurassiez": "endurer",
    "endurassions": "endurer",
    "endurci": "endurcir",
    "endurcie": "endurcir",
    "endurcies": "endurcir",
    "endurcira": "endurcir",
    "endurcirai": "endurcir",
    "endurciraient": "endurcir",
    "endurcirais": "endurcir",
    "endurcirait": "endurcir",
    "endurciras": "endurcir",
    "endurcirent": "endurcir",
    "endurcirez": "endurcir",
    "endurciriez": "endurcir",
    "endurcirions": "endurcir",
    "endurcirons": "endurcir",
    "endurciront": "endurcir",
    "endurcis": "endurcir",
    "endurcissaient": "endurcir",
    "endurcissais": "endurcir",
    "endurcissait": "endurcir",
    "endurcissant": "endurcir",
    "endurcisse": "endurcir",
    "endurcissent": "endurcir",
    "endurcisses": "endurcir",
    "endurcissez": "endurcir",
    "endurcissiez": "endurcir",
    "endurcissions": "endurcir",
    "endurcissons": "endurcir",
    "endurcit": "endurcir",
    "endurcîmes": "endurcir",
    "endurcît": "endurcir",
    "endurcîtes": "endurcir",
    "endure": "endurer",
    "endurent": "endurer",
    "endurera": "endurer",
    "endurerai": "endurer",
    "endureraient": "endurer",
    "endurerais": "endurer",
    "endurerait": "endurer",
    "endureras": "endurer",
    "endurerez": "endurer",
    "endureriez": "endurer",
    "endurerions": "endurer",
    "endurerons": "endurer",
    "endureront": "endurer",
    "endures": "endurer",
    "endurez": "endurer",
    "enduriez": "endurer",
    "endurions": "endurer",
    "endurons": "endurer",
    "endurâmes": "endurer",
    "endurât": "endurer",
    "endurâtes": "endurer",
    "endurèrent": "endurer",
    "enduré": "endurer",
    "endurée": "endurer",
    "endurées": "endurer",
    "endurés": "endurer",
    "endémiques": "endémique",
    "enfances": "enfance",
    "enfanta": "enfanter",
    "enfantai": "enfanter",
    "enfantaient": "enfanter",
    "enfantais": "enfanter",
    "enfantait": "enfanter",
    "enfantant": "enfanter",
    "enfantas": "enfanter",
    "enfantasse": "enfanter",
    "enfantassent": "enfanter",
    "enfantasses": "enfanter",
    "enfantassiez": "enfanter",
    "enfantassions": "enfanter",
    "enfante": "enfanter",
    "enfantelets": "enfantelet",
    "enfantements": "enfantement",
    "enfantent": "enfanter",
    "enfantera": "enfanter",
    "enfanterai": "enfanter",
    "enfanteraient": "enfanter",
    "enfanterais": "enfanter",
    "enfanterait": "enfanter",
    "enfanteras": "enfanter",
    "enfanterez": "enfanter",
    "enfanteriez": "enfanter",
    "enfanterions": "enfanter",
    "enfanterons": "enfanter",
    "enfanteront": "enfanter",
    "enfantes": "enfanter",
    "enfantez": "enfanter",
    "enfantiez": "enfanter",
    "enfantillages": "enfantillage",
    "enfantine": "enfantin",
    "enfantines": "enfantin",
    "enfantins": "enfantin",
    "enfantions": "enfanter",
    "enfantons": "enfanter",
    "enfants": "enfant",
    "enfants-robots": "enfant-robot",
    "enfants-rois": "enfant-roi",
    "enfantâmes": "enfanter",
    "enfantât": "enfanter",
    "enfantâtes": "enfanter",
    "enfantèrent": "enfanter",
    "enfanté": "enfanter",
    "enfantée": "enfanter",
    "enfantées": "enfanter",
    "enfantés": "enfanter",
    "enfançons": "enfançon",
    "enfarina": "enfariner",
    "enfarinai": "enfariner",
    "enfarinaient": "enfariner",
    "enfarinais": "enfariner",
    "enfarinait": "enfariner",
    "enfarinant": "enfariner",
    "enfarinas": "enfariner",
    "enfarinasse": "enfariner",
    "enfarinassent": "enfariner",
    "enfarinasses": "enfariner",
    "enfarinassiez": "enfariner",
    "enfarinassions": "enfariner",
    "enfarine": "enfariner",
    "enfarinent": "enfariner",
    "enfarinera": "enfariner",
    "enfarinerai": "enfariner",
    "enfarineraient": "enfariner",
    "enfarinerais": "enfariner",
    "enfarinerait": "enfariner",
    "enfarineras": "enfariner",
    "enfarinerez": "enfariner",
    "enfarineriez": "enfariner",
    "enfarinerions": "enfariner",
    "enfarinerons": "enfariner",
    "enfarineront": "enfariner",
    "enfarines": "enfariner",
    "enfarinez": "enfariner",
    "enfariniez": "enfariner",
    "enfarinions": "enfariner",
    "enfarinons": "enfariner",
    "enfarinâmes": "enfariner",
    "enfarinât": "enfariner",
    "enfarinâtes": "enfariner",
    "enfarinèrent": "enfariner",
    "enfariné": "enfariner",
    "enfarinée": "enfariner",
    "enfarinées": "enfariner",
    "enfarinés": "enfariner",
    "enferma": "enfermer",
    "enfermai": "enfermer",
    "enfermaient": "enfermer",
    "enfermais": "enfermer",
    "enfermait": "enfermer",
    "enfermant": "enfermer",
    "enfermas": "enfermer",
    "enfermasse": "enfermer",
    "enfermassent": "enfermer",
    "enfermasses": "enfermer",
    "enfermassiez": "enfermer",
    "enfermassions": "enfermer",
    "enferme": "enfermer",
    "enfermements": "enfermement",
    "enferment": "enfermer",
    "enfermera": "enfermer",
    "enfermerai": "enfermer",
    "enfermeraient": "enfermer",
    "enfermerais": "enfermer",
    "enfermerait": "enfermer",
    "enfermeras": "enfermer",
    "enfermerez": "enfermer",
    "enfermeriez": "enfermer",
    "enfermerions": "enfermer",
    "enfermerons": "enfermer",
    "enfermeront": "enfermer",
    "enfermes": "enfermer",
    "enfermez": "enfermer",
    "enfermiez": "enfermer",
    "enfermions": "enfermer",
    "enfermons": "enfermer",
    "enfermâmes": "enfermer",
    "enfermât": "enfermer",
    "enfermâtes": "enfermer",
    "enfermèrent": "enfermer",
    "enfermé": "enfermer",
    "enfermée": "enfermer",
    "enfermées": "enfermer",
    "enfermés": "enfermer",
    "enferra": "enferrer",
    "enferrai": "enferrer",
    "enferraient": "enferrer",
    "enferrais": "enferrer",
    "enferrait": "enferrer",
    "enferrant": "enferrer",
    "enferras": "enferrer",
    "enferrasse": "enferrer",
    "enferrassent": "enferrer",
    "enferrasses": "enferrer",
    "enferrassiez": "enferrer",
    "enferrassions": "enferrer",
    "enferre": "enferrer",
    "enferrent": "enferrer",
    "enferrera": "enferrer",
    "enferrerai": "enferrer",
    "enferreraient": "enferrer",
    "enferrerais": "enferrer",
    "enferrerait": "enferrer",
    "enferreras": "enferrer",
    "enferrerez": "enferrer",
    "enferreriez": "enferrer",
    "enferrerions": "enferrer",
    "enferrerons": "enferrer",
    "enferreront": "enferrer",
    "enferres": "enferrer",
    "enferrez": "enferrer",
    "enferriez": "enferrer",
    "enferrions": "enferrer",
    "enferrons": "enferrer",
    "enferrâmes": "enferrer",
    "enferrât": "enferrer",
    "enferrâtes": "enferrer",
    "enferrèrent": "enferrer",
    "enferré": "enferrer",
    "enferrée": "enferrer",
    "enferrées": "enferrer",
    "enferrés": "enferrer",
    "enfers": "enfer",
    "enfeus": "enfeu",
    "enfiche": "enficher",
    "enfila": "enfiler",
    "enfilades": "enfilade",
    "enfilai": "enfiler",
    "enfilaient": "enfiler",
    "enfilais": "enfiler",
    "enfilait": "enfiler",
    "enfilant": "enfiler",
    "enfilas": "enfiler",
    "enfilasse": "enfiler",
    "enfilassent": "enfiler",
    "enfilasses": "enfiler",
    "enfilassiez": "enfiler",
    "enfilassions": "enfiler",
    "enfile": "enfiler",
    "enfilent": "enfiler",
    "enfilera": "enfiler",
    "enfilerai": "enfiler",
    "enfileraient": "enfiler",
    "enfilerais": "enfiler",
    "enfilerait": "enfiler",
    "enfileras": "enfiler",
    "enfilerez": "enfiler",
    "enfileriez": "enfiler",
    "enfilerions": "enfiler",
    "enfilerons": "enfiler",
    "enfileront": "enfiler",
    "enfiles": "enfiler",
    "enfilez": "enfiler",
    "enfiliez": "enfiler",
    "enfilions": "enfiler",
    "enfilons": "enfiler",
    "enfilâmes": "enfiler",
    "enfilât": "enfiler",
    "enfilâtes": "enfiler",
    "enfilèrent": "enfiler",
    "enfilé": "enfiler",
    "enfilée": "enfiler",
    "enfilées": "enfiler",
    "enfilés": "enfiler",
    "enfièvre": "enfiévrer",
    "enfièvrent": "enfiévrer",
    "enfièvres": "enfiévrer",
    "enfiévra": "enfiévrer",
    "enfiévrai": "enfiévrer",
    "enfiévraient": "enfiévrer",
    "enfiévrais": "enfiévrer",
    "enfiévrait": "enfiévrer",
    "enfiévrant": "enfiévrer",
    "enfiévras": "enfiévrer",
    "enfiévrasse": "enfiévrer",
    "enfiévrassent": "enfiévrer",
    "enfiévrasses": "enfiévrer",
    "enfiévrassiez": "enfiévrer",
    "enfiévrassions": "enfiévrer",
    "enfiévrera": "enfiévrer",
    "enfiévrerai": "enfiévrer",
    "enfiévreraient": "enfiévrer",
    "enfiévrerais": "enfiévrer",
    "enfiévrerait": "enfiévrer",
    "enfiévreras": "enfiévrer",
    "enfiévrerez": "enfiévrer",
    "enfiévreriez": "enfiévrer",
    "enfiévrerions": "enfiévrer",
    "enfiévrerons": "enfiévrer",
    "enfiévreront": "enfiévrer",
    "enfiévrez": "enfiévrer",
    "enfiévriez": "enfiévrer",
    "enfiévrions": "enfiévrer",
    "enfiévrons": "enfiévrer",
    "enfiévrâmes": "enfiévrer",
    "enfiévrât": "enfiévrer",
    "enfiévrâtes": "enfiévrer",
    "enfiévrèrent": "enfiévrer",
    "enfiévré": "enfiévrer",
    "enfiévrée": "enfiévrer",
    "enfiévrées": "enfiévrer",
    "enfiévrés": "enfiévrer",
    "enfla": "enfler",
    "enflai": "enfler",
    "enflaient": "enfler",
    "enflais": "enfler",
    "enflait": "enfler",
    "enflamma": "enflammer",
    "enflammai": "enflammer",
    "enflammaient": "enflammer",
    "enflammais": "enflammer",
    "enflammait": "enflammer",
    "enflammant": "enflammer",
    "enflammas": "enflammer",
    "enflammasse": "enflammer",
    "enflammassent": "enflammer",
    "enflammasses": "enflammer",
    "enflammassiez": "enflammer",
    "enflammassions": "enflammer",
    "enflamme": "enflammer",
    "enflamment": "enflammer",
    "enflammera": "enflammer",
    "enflammerai": "enflammer",
    "enflammeraient": "enflammer",
    "enflammerais": "enflammer",
    "enflammerait": "enflammer",
    "enflammeras": "enflammer",
    "enflammerez": "enflammer",
    "enflammeriez": "enflammer",
    "enflammerions": "enflammer",
    "enflammerons": "enflammer",
    "enflammeront": "enflammer",
    "enflammes": "enflammer",
    "enflammez": "enflammer",
    "enflammiez": "enflammer",
    "enflammions": "enflammer",
    "enflammons": "enflammer",
    "enflammâmes": "enflammer",
    "enflammât": "enflammer",
    "enflammâtes": "enflammer",
    "enflammèrent": "enflammer",
    "enflammé": "enflammer",
    "enflammée": "enflammer",
    "enflammées": "enflammer",
    "enflammés": "enflammer",
    "enflant": "enfler",
    "enflas": "enfler",
    "enflasse": "enfler",
    "enflassent": "enfler",
    "enflasses": "enfler",
    "enflassiez": "enfler",
    "enflassions": "enfler",
    "enfle": "enfler",
    "enflent": "enfler",
    "enflera": "enfler",
    "enflerai": "enfler",
    "enfleraient": "enfler",
    "enflerais": "enfler",
    "enflerait": "enfler",
    "enfleras": "enfler",
    "enflerez": "enfler",
    "enfleriez": "enfler",
    "enflerions": "enfler",
    "enflerons": "enfler",
    "enfleront": "enfler",
    "enfles": "enfler",
    "enflez": "enfler",
    "enfliez": "enfler",
    "enflions": "enfler",
    "enflons": "enfler",
    "enflures": "enflure",
    "enflâmes": "enfler",
    "enflât": "enfler",
    "enflâtes": "enfler",
    "enflèrent": "enfler",
    "enflé": "enfler",
    "enflée": "enfler",
    "enflées": "enfler",
    "enflés": "enfler",
    "enfoirée": "enfoiré",
    "enfoirées": "enfoiré",
    "enfoirés": "enfoiré",
    "enfonce": "enfoncer",
    "enfoncements": "enfoncement",
    "enfoncent": "enfoncer",
    "enfoncera": "enfoncer",
    "enfoncerai": "enfoncer",
    "enfonceraient": "enfoncer",
    "enfoncerais": "enfoncer",
    "enfoncerait": "enfoncer",
    "enfonceras": "enfoncer",
    "enfoncerez": "enfoncer",
    "enfonceriez": "enfoncer",
    "enfoncerions": "enfoncer",
    "enfoncerons": "enfoncer",
    "enfonceront": "enfoncer",
    "enfonces": "enfoncer",
    "enfoncez": "enfoncer",
    "enfonciez": "enfoncer",
    "enfoncions": "enfoncer",
    "enfoncèrent": "enfoncer",
    "enfoncé": "enfoncer",
    "enfoncée": "enfoncer",
    "enfoncées": "enfoncer",
    "enfoncés": "enfoncer",
    "enfonça": "enfoncer",
    "enfonçai": "enfoncer",
    "enfonçaient": "enfoncer",
    "enfonçais": "enfoncer",
    "enfonçait": "enfoncer",
    "enfonçant": "enfoncer",
    "enfonças": "enfoncer",
    "enfonçasse": "enfoncer",
    "enfonçassent": "enfoncer",
    "enfonçasses": "enfoncer",
    "enfonçassiez": "enfoncer",
    "enfonçassions": "enfoncer",
    "enfonçons": "enfoncer",
    "enfonçâmes": "enfoncer",
    "enfonçât": "enfoncer",
    "enfonçâtes": "enfoncer",
    "enfoui": "enfouir",
    "enfouie": "enfouir",
    "enfouies": "enfouir",
    "enfouillais": "enfouiller",
    "enfouillant": "enfouiller",
    "enfouille": "enfouiller",
    "enfouillé": "enfouiller",
    "enfouillée": "enfouiller",
    "enfouira": "enfouir",
    "enfouirai": "enfouir",
    "enfouiraient": "enfouir",
    "enfouirais": "enfouir",
    "enfouirait": "enfouir",
    "enfouiras": "enfouir",
    "enfouirent": "enfouir",
    "enfouirez": "enfouir",
    "enfouiriez": "enfouir",
    "enfouirions": "enfouir",
    "enfouirons": "enfouir",
    "enfouiront": "enfouir",
    "enfouis": "enfouir",
    "enfouissaient": "enfouir",
    "enfouissais": "enfouir",
    "enfouissait": "enfouir",
    "enfouissant": "enfouir",
    "enfouisse": "enfouir",
    "enfouissements": "enfouissement",
    "enfouissent": "enfouir",
    "enfouisses": "enfouir",
    "enfouissez": "enfouir",
    "enfouissiez": "enfouir",
    "enfouissions": "enfouir",
    "enfouissons": "enfouir",
    "enfouit": "enfouir",
    "enfouraille": "enfourailler",
    "enfouraillée": "enfouraillé",
    "enfouraillés": "enfouraillé",
    "enfourcha": "enfourcher",
    "enfourchai": "enfourcher",
    "enfourchaient": "enfourcher",
    "enfourchais": "enfourcher",
    "enfourchait": "enfourcher",
    "enfourchant": "enfourcher",
    "enfourchas": "enfourcher",
    "enfourchasse": "enfourcher",
    "enfourchassent": "enfourcher",
    "enfourchasses": "enfourcher",
    "enfourchassiez": "enfourcher",
    "enfourchassions": "enfourcher",
    "enfourche": "enfourcher",
    "enfourchent": "enfourcher",
    "enfourchera": "enfourcher",
    "enfourcherai": "enfourcher",
    "enfourcheraient": "enfourcher",
    "enfourcherais": "enfourcher",
    "enfourcherait": "enfourcher",
    "enfourcheras": "enfourcher",
    "enfourcherez": "enfourcher",
    "enfourcheriez": "enfourcher",
    "enfourcherions": "enfourcher",
    "enfourcherons": "enfourcher",
    "enfourcheront": "enfourcher",
    "enfourches": "enfourcher",
    "enfourchez": "enfourcher",
    "enfourchiez": "enfourcher",
    "enfourchions": "enfourcher",
    "enfourchons": "enfourcher",
    "enfourchâmes": "enfourcher",
    "enfourchât": "enfourcher",
    "enfourchâtes": "enfourcher",
    "enfourchèrent": "enfourcher",
    "enfourché": "enfourcher",
    "enfourchée": "enfourcher",
    "enfourchées": "enfourcher",
    "enfourchés": "enfourcher",
    "enfourna": "enfourner",
    "enfournai": "enfourner",
    "enfournaient": "enfourner",
    "enfournais": "enfourner",
    "enfournait": "enfourner",
    "enfournant": "enfourner",
    "enfournas": "enfourner",
    "enfournasse": "enfourner",
    "enfournassent": "enfourner",
    "enfournasses": "enfourner",
    "enfournassiez": "enfourner",
    "enfournassions": "enfourner",
    "enfourne": "enfourner",
    "enfournent": "enfourner",
    "enfournera": "enfourner",
    "enfournerai": "enfourner",
    "enfourneraient": "enfourner",
    "enfournerais": "enfourner",
    "enfournerait": "enfourner",
    "enfourneras": "enfourner",
    "enfournerez": "enfourner",
    "enfourneriez": "enfourner",
    "enfournerions": "enfourner",
    "enfournerons": "enfourner",
    "enfourneront": "enfourner",
    "enfournes": "enfourner",
    "enfournez": "enfourner",
    "enfourniez": "enfourner",
    "enfournions": "enfourner",
    "enfournons": "enfourner",
    "enfournâmes": "enfourner",
    "enfournât": "enfourner",
    "enfournâtes": "enfourner",
    "enfournèrent": "enfourner",
    "enfourné": "enfourner",
    "enfournée": "enfourner",
    "enfournées": "enfourner",
    "enfournés": "enfourner",
    "enfouîmes": "enfouir",
    "enfouît": "enfouir",
    "enfouîtes": "enfouir",
    "enfreignaient": "enfreindre",
    "enfreignais": "enfreindre",
    "enfreignait": "enfreindre",
    "enfreignant": "enfreindre",
    "enfreigne": "enfreindre",
    "enfreignent": "enfreindre",
    "enfreignes": "enfreindre",
    "enfreignez": "enfreindre",
    "enfreigniez": "enfreindre",
    "enfreignions": "enfreindre",
    "enfreignirent": "enfreindre",
    "enfreignis": "enfreindre",
    "enfreignisse": "enfreindre",
    "enfreignissent": "enfreindre",
    "enfreignisses": "enfreindre",
    "enfreignissiez": "enfreindre",
    "enfreignissions": "enfreindre",
    "enfreignit": "enfreindre",
    "enfreignons": "enfreindre",
    "enfreignîmes": "enfreindre",
    "enfreignît": "enfreindre",
    "enfreignîtes": "enfreindre",
    "enfreindra": "enfreindre",
    "enfreindrai": "enfreindre",
    "enfreindraient": "enfreindre",
    "enfreindrais": "enfreindre",
    "enfreindrait": "enfreindre",
    "enfreindras": "enfreindre",
    "enfreindrez": "enfreindre",
    "enfreindriez": "enfreindre",
    "enfreindrions": "enfreindre",
    "enfreindrons": "enfreindre",
    "enfreindront": "enfreindre",
    "enfreins": "enfreindre",
    "enfreint": "enfreindre",
    "enfreinte": "enfreindre",
    "enfreintes": "enfreindre",
    "enfreints": "enfreindre",
    "enfui": "enfuir",
    "enfuie": "enfuir",
    "enfuient": "enfuir",
    "enfuies": "enfuir",
    "enfuira": "enfuir",
    "enfuirai": "enfuir",
    "enfuiraient": "enfuir",
    "enfuirais": "enfuir",
    "enfuirait": "enfuir",
    "enfuiras": "enfuir",
    "enfuirent": "enfuir",
    "enfuirez": "enfuir",
    "enfuiriez": "enfuir",
    "enfuirions": "enfuir",
    "enfuirons": "enfuir",
    "enfuiront": "enfuir",
    "enfuis": "enfuir",
    "enfuisse": "enfuir",
    "enfuissent": "enfuir",
    "enfuisses": "enfuir",
    "enfuissiez": "enfuir",
    "enfuissions": "enfuir",
    "enfuit": "enfuir",
    "enfuma": "enfumer",
    "enfumai": "enfumer",
    "enfumaient": "enfumer",
    "enfumais": "enfumer",
    "enfumait": "enfumer",
    "enfumant": "enfumer",
    "enfumas": "enfumer",
    "enfumasse": "enfumer",
    "enfumassent": "enfumer",
    "enfumasses": "enfumer",
    "enfumassiez": "enfumer",
    "enfumassions": "enfumer",
    "enfume": "enfumer",
    "enfument": "enfumer",
    "enfumera": "enfumer",
    "enfumerai": "enfumer",
    "enfumeraient": "enfumer",
    "enfumerais": "enfumer",
    "enfumerait": "enfumer",
    "enfumeras": "enfumer",
    "enfumerez": "enfumer",
    "enfumeriez": "enfumer",
    "enfumerions": "enfumer",
    "enfumerons": "enfumer",
    "enfumeront": "enfumer",
    "enfumes": "enfumer",
    "enfumez": "enfumer",
    "enfumiez": "enfumer",
    "enfumions": "enfumer",
    "enfumons": "enfumer",
    "enfumâmes": "enfumer",
    "enfumât": "enfumer",
    "enfumâtes": "enfumer",
    "enfumèrent": "enfumer",
    "enfumé": "enfumer",
    "enfumée": "enfumer",
    "enfumées": "enfumer",
    "enfumés": "enfumer",
    "enfuyaient": "enfuir",
    "enfuyais": "enfuir",
    "enfuyait": "enfuir",
    "enfuyant": "enfuir",
    "enfuyez": "enfuir",
    "enfuyiez": "enfuir",
    "enfuyions": "enfuir",
    "enfuyons": "enfuir",
    "enfuîmes": "enfuir",
    "enfuît": "enfuir",
    "enfuîtes": "enfuir",
    "engage": "engager",
    "engagea": "engager",
    "engageai": "engager",
    "engageaient": "engager",
    "engageais": "engager",
    "engageait": "engager",
    "engageant": "engager",
    "engageante": "engageant",
    "engageantes": "engageant",
    "engageants": "engageant",
    "engageas": "engager",
    "engageasse": "engager",
    "engageassent": "engager",
    "engageasses": "engager",
    "engageassiez": "engager",
    "engageassions": "engager",
    "engagements": "engagement",
    "engagent": "engager",
    "engageons": "engager",
    "engagera": "engager",
    "engagerai": "engager",
    "engageraient": "engager",
    "engagerais": "engager",
    "engagerait": "engager",
    "engageras": "engager",
    "engagerez": "engager",
    "engageriez": "engager",
    "engagerions": "engager",
    "engagerons": "engager",
    "engageront": "engager",
    "engages": "engager",
    "engagez": "engager",
    "engageâmes": "engager",
    "engageât": "engager",
    "engageâtes": "engager",
    "engagiez": "engager",
    "engagions": "engager",
    "engagèrent": "engager",
    "engagé": "engager",
    "engagée": "engager",
    "engagées": "engager",
    "engagés": "engager",
    "engaina": "engainer",
    "engainai": "engainer",
    "engainaient": "engainer",
    "engainais": "engainer",
    "engainait": "engainer",
    "engainant": "engainer",
    "engainas": "engainer",
    "engainasse": "engainer",
    "engainassent": "engainer",
    "engainasses": "engainer",
    "engainassiez": "engainer",
    "engainassions": "engainer",
    "engaine": "engainer",
    "engainent": "engainer",
    "engainera": "engainer",
    "engainerai": "engainer",
    "engaineraient": "engainer",
    "engainerais": "engainer",
    "engainerait": "engainer",
    "engaineras": "engainer",
    "engainerez": "engainer",
    "engaineriez": "engainer",
    "engainerions": "engainer",
    "engainerons": "engainer",
    "engaineront": "engainer",
    "engaines": "engainer",
    "engainez": "engainer",
    "engainiez": "engainer",
    "engainions": "engainer",
    "engainons": "engainer",
    "engainâmes": "engainer",
    "engainât": "engainer",
    "engainâtes": "engainer",
    "engainèrent": "engainer",
    "engainé": "engainer",
    "engainée": "engainer",
    "engainées": "engainer",
    "engainés": "engainer",
    "engazonnée": "engazonner",
    "engeances": "engeance",
    "engelures": "engelure",
    "engendra": "engendrer",
    "engendrai": "engendrer",
    "engendraient": "engendrer",
    "engendrais": "engendrer",
    "engendrait": "engendrer",
    "engendrant": "engendrer",
    "engendras": "engendrer",
    "engendrasse": "engendrer",
    "engendrassent": "engendrer",
    "engendrasses": "engendrer",
    "engendrassiez": "engendrer",
    "engendrassions": "engendrer",
    "engendre": "engendrer",
    "engendrent": "engendrer",
    "engendrera": "engendrer",
    "engendrerai": "engendrer",
    "engendreraient": "engendrer",
    "engendrerais": "engendrer",
    "engendrerait": "engendrer",
    "engendreras": "engendrer",
    "engendrerez": "engendrer",
    "engendreriez": "engendrer",
    "engendrerions": "engendrer",
    "engendrerons": "engendrer",
    "engendreront": "engendrer",
    "engendres": "engendrer",
    "engendreuse": "engendreur",
    "engendrez": "engendrer",
    "engendriez": "engendrer",
    "engendrions": "engendrer",
    "engendrons": "engendrer",
    "engendrâmes": "engendrer",
    "engendrât": "engendrer",
    "engendrâtes": "engendrer",
    "engendrèrent": "engendrer",
    "engendré": "engendrer",
    "engendrée": "engendrer",
    "engendrées": "engendrer",
    "engendrés": "engendrer",
    "engineerings": "engineering",
    "engins": "engin",
    "englace": "englacer",
    "englacent": "englacer",
    "englacera": "englacer",
    "englacerai": "englacer",
    "englaceraient": "englacer",
    "englacerais": "englacer",
    "englacerait": "englacer",
    "englaceras": "englacer",
    "englacerez": "englacer",
    "englaceriez": "englacer",
    "englacerions": "englacer",
    "englacerons": "englacer",
    "englaceront": "englacer",
    "englaces": "englacer",
    "englacez": "englacer",
    "englaciez": "englacer",
    "englacions": "englacer",
    "englacèrent": "englacer",
    "englacé": "englacer",
    "englacée": "englacer",
    "englacées": "englacer",
    "englacés": "englacer",
    "englande": "englander",
    "englandés": "englander",
    "englaça": "englacer",
    "englaçai": "englacer",
    "englaçaient": "englacer",
    "englaçais": "englacer",
    "englaçait": "englacer",
    "englaçant": "englacer",
    "englaças": "englacer",
    "englaçasse": "englacer",
    "englaçassent": "englacer",
    "englaçasses": "englacer",
    "englaçassiez": "englacer",
    "englaçassions": "englacer",
    "englaçons": "englacer",
    "englaçâmes": "englacer",
    "englaçât": "englacer",
    "englaçâtes": "englacer",
    "engloba": "englober",
    "englobai": "englober",
    "englobaient": "englober",
    "englobais": "englober",
    "englobait": "englober",
    "englobant": "englober",
    "englobas": "englober",
    "englobasse": "englober",
    "englobassent": "englober",
    "englobasses": "englober",
    "englobassiez": "englober",
    "englobassions": "englober",
    "englobe": "englober",
    "englobent": "englober",
    "englobera": "englober",
    "engloberai": "englober",
    "engloberaient": "englober",
    "engloberais": "englober",
    "engloberait": "englober",
    "engloberas": "englober",
    "engloberez": "englober",
    "engloberiez": "englober",
    "engloberions": "englober",
    "engloberons": "englober",
    "engloberont": "englober",
    "englobes": "englober",
    "englobez": "englober",
    "englobiez": "englober",
    "englobions": "englober",
    "englobons": "englober",
    "englobâmes": "englober",
    "englobât": "englober",
    "englobâtes": "englober",
    "englobèrent": "englober",
    "englobé": "englober",
    "englobée": "englober",
    "englobées": "englober",
    "englobés": "englober",
    "englouti": "engloutir",
    "engloutie": "engloutir",
    "englouties": "engloutir",
    "engloutira": "engloutir",
    "engloutirai": "engloutir",
    "engloutiraient": "engloutir",
    "engloutirais": "engloutir",
    "engloutirait": "engloutir",
    "engloutiras": "engloutir",
    "engloutirent": "engloutir",
    "engloutirez": "engloutir",
    "engloutiriez": "engloutir",
    "engloutirions": "engloutir",
    "engloutirons": "engloutir",
    "engloutiront": "engloutir",
    "engloutis": "engloutir",
    "engloutissaient": "engloutir",
    "engloutissais": "engloutir",
    "engloutissait": "engloutir",
    "engloutissant": "engloutir",
    "engloutisse": "engloutir",
    "engloutissent": "engloutir",
    "engloutisses": "engloutir",
    "engloutissez": "engloutir",
    "engloutissiez": "engloutir",
    "engloutissions": "engloutir",
    "engloutissons": "engloutir",
    "engloutit": "engloutir",
    "engloutîmes": "engloutir",
    "engloutît": "engloutir",
    "engloutîtes": "engloutir",
    "englua": "engluer",
    "engluai": "engluer",
    "engluaient": "engluer",
    "engluais": "engluer",
    "engluait": "engluer",
    "engluant": "engluer",
    "engluas": "engluer",
    "engluasse": "engluer",
    "engluassent": "engluer",
    "engluasses": "engluer",
    "engluassiez": "engluer",
    "engluassions": "engluer",
    "englue": "engluer",
    "engluent": "engluer",
    "engluera": "engluer",
    "engluerai": "engluer",
    "englueraient": "engluer",
    "engluerais": "engluer",
    "engluerait": "engluer",
    "englueras": "engluer",
    "engluerez": "engluer",
    "englueriez": "engluer",
    "engluerions": "engluer",
    "engluerons": "engluer",
    "englueront": "engluer",
    "englues": "engluer",
    "engluez": "engluer",
    "engluiez": "engluer",
    "engluions": "engluer",
    "engluons": "engluer",
    "engluâmes": "engluer",
    "engluât": "engluer",
    "engluâtes": "engluer",
    "engluèrent": "engluer",
    "englué": "engluer",
    "engluée": "engluer",
    "engluées": "engluer",
    "englués": "engluer",
    "engonce": "engoncer",
    "engoncent": "engoncer",
    "engoncera": "engoncer",
    "engoncerai": "engoncer",
    "engonceraient": "engoncer",
    "engoncerais": "engoncer",
    "engoncerait": "engoncer",
    "engonceras": "engoncer",
    "engoncerez": "engoncer",
    "engonceriez": "engoncer",
    "engoncerions": "engoncer",
    "engoncerons": "engoncer",
    "engonceront": "engoncer",
    "engonces": "engoncer",
    "engoncez": "engoncer",
    "engonciez": "engoncer",
    "engoncions": "engoncer",
    "engoncèrent": "engoncer",
    "engoncé": "engoncer",
    "engoncée": "engoncer",
    "engoncées": "engoncer",
    "engoncés": "engoncer",
    "engonça": "engoncer",
    "engonçai": "engoncer",
    "engonçaient": "engoncer",
    "engonçais": "engoncer",
    "engonçait": "engoncer",
    "engonçant": "engoncer",
    "engonças": "engoncer",
    "engonçasse": "engoncer",
    "engonçassent": "engoncer",
    "engonçasses": "engoncer",
    "engonçassiez": "engoncer",
    "engonçassions": "engoncer",
    "engonçons": "engoncer",
    "engonçâmes": "engoncer",
    "engonçât": "engoncer",
    "engonçâtes": "engoncer",
    "engorge": "engorger",
    "engorgea": "engorger",
    "engorgeai": "engorger",
    "engorgeaient": "engorger",
    "engorgeais": "engorger",
    "engorgeait": "engorger",
    "engorgeant": "engorger",
    "engorgeas": "engorger",
    "engorgeasse": "engorger",
    "engorgeassent": "engorger",
    "engorgeasses": "engorger",
    "engorgeassiez": "engorger",
    "engorgeassions": "engorger",
    "engorgements": "engorgement",
    "engorgent": "engorger",
    "engorgeons": "engorger",
    "engorgera": "engorger",
    "engorgerai": "engorger",
    "engorgeraient": "engorger",
    "engorgerais": "engorger",
    "engorgerait": "engorger",
    "engorgeras": "engorger",
    "engorgerez": "engorger",
    "engorgeriez": "engorger",
    "engorgerions": "engorger",
    "engorgerons": "engorger",
    "engorgeront": "engorger",
    "engorges": "engorger",
    "engorgez": "engorger",
    "engorgeâmes": "engorger",
    "engorgeât": "engorger",
    "engorgeâtes": "engorger",
    "engorgiez": "engorger",
    "engorgions": "engorger",
    "engorgèrent": "engorger",
    "engorgé": "engorger",
    "engorgée": "engorger",
    "engorgées": "engorger",
    "engorgés": "engorger",
    "engoua": "engouer",
    "engouai": "engouer",
    "engouaient": "engouer",
    "engouais": "engouer",
    "engouait": "engouer",
    "engouant": "engouer",
    "engouas": "engouer",
    "engouasse": "engouer",
    "engouassent": "engouer",
    "engouasses": "engouer",
    "engouassiez": "engouer",
    "engouassions": "engouer",
    "engoue": "engouer",
    "engouements": "engouement",
    "engouent": "engouer",
    "engouera": "engouer",
    "engouerai": "engouer",
    "engoueraient": "engouer",
    "engouerais": "engouer",
    "engouerait": "engouer",
    "engoueras": "engouer",
    "engouerez": "engouer",
    "engoueriez": "engouer",
    "engouerions": "engouer",
    "engouerons": "engouer",
    "engoueront": "engouer",
    "engoues": "engouer",
    "engouez": "engouer",
    "engouffra": "engouffrer",
    "engouffrai": "engouffrer",
    "engouffraient": "engouffrer",
    "engouffrais": "engouffrer",
    "engouffrait": "engouffrer",
    "engouffrant": "engouffrer",
    "engouffras": "engouffrer",
    "engouffrasse": "engouffrer",
    "engouffrassent": "engouffrer",
    "engouffrasses": "engouffrer",
    "engouffrassiez": "engouffrer",
    "engouffrassions": "engouffrer",
    "engouffre": "engouffrer",
    "engouffrent": "engouffrer",
    "engouffrera": "engouffrer",
    "engouffrerai": "engouffrer",
    "engouffreraient": "engouffrer",
    "engouffrerais": "engouffrer",
    "engouffrerait": "engouffrer",
    "engouffreras": "engouffrer",
    "engouffrerez": "engouffrer",
    "engouffreriez": "engouffrer",
    "engouffrerions": "engouffrer",
    "engouffrerons": "engouffrer",
    "engouffreront": "engouffrer",
    "engouffres": "engouffrer",
    "engouffrez": "engouffrer",
    "engouffriez": "engouffrer",
    "engouffrions": "engouffrer",
    "engouffrons": "engouffrer",
    "engouffrâmes": "engouffrer",
    "engouffrât": "engouffrer",
    "engouffrâtes": "engouffrer",
    "engouffrèrent": "engouffrer",
    "engouffré": "engouffrer",
    "engouffrée": "engouffrer",
    "engouffrées": "engouffrer",
    "engouffrés": "engouffrer",
    "engouiez": "engouer",
    "engouions": "engouer",
    "engoulevents": "engoulevent",
    "engouons": "engouer",
    "engourdi": "engourdir",
    "engourdie": "engourdir",
    "engourdies": "engourdir",
    "engourdira": "engourdir",
    "engourdirai": "engourdir",
    "engourdiraient": "engourdir",
    "engourdirais": "engourdir",
    "engourdirait": "engourdir",
    "engourdiras": "engourdir",
    "engourdirent": "engourdir",
    "engourdirez": "engourdir",
    "engourdiriez": "engourdir",
    "engourdirions": "engourdir",
    "engourdirons": "engourdir",
    "engourdiront": "engourdir",
    "engourdis": "engourdir",
    "engourdissaient": "engourdir",
    "engourdissais": "engourdir",
    "engourdissait": "engourdir",
    "engourdissant": "engourdir",
    "engourdissante": "engourdissant",
    "engourdissantes": "engourdissant",
    "engourdissants": "engourdissant",
    "engourdisse": "engourdir",
    "engourdissements": "engourdissement",
    "engourdissent": "engourdir",
    "engourdisses": "engourdir",
    "engourdissez": "engourdir",
    "engourdissiez": "engourdir",
    "engourdissions": "engourdir",
    "engourdissons": "engourdir",
    "engourdit": "engourdir",
    "engourdîmes": "engourdir",
    "engourdît": "engourdir",
    "engourdîtes": "engourdir",
    "engouâmes": "engouer",
    "engouât": "engouer",
    "engouâtes": "engouer",
    "engouèrent": "engouer",
    "engoué": "engouer",
    "engouée": "engouer",
    "engouées": "engouer",
    "engoués": "engouer",
    "engrainait": "engrainer",
    "engraissa": "engraisser",
    "engraissai": "engraisser",
    "engraissaient": "engraisser",
    "engraissais": "engraisser",
    "engraissait": "engraisser",
    "engraissant": "engraisser",
    "engraissas": "engraisser",
    "engraissasse": "engraisser",
    "engraissassent": "engraisser",
    "engraissasses": "engraisser",
    "engraissassiez": "engraisser",
    "engraissassions": "engraisser",
    "engraisse": "engraisser",
    "engraissent": "engraisser",
    "engraisser": "entrer",
    "engraissera": "engraisser",
    "engraisserai": "engraisser",
    "engraisseraient": "engraisser",
    "engraisserais": "engraisser",
    "engraisserait": "engraisser",
    "engraisseras": "engraisser",
    "engraisserez": "engraisser",
    "engraisseriez": "engraisser",
    "engraisserions": "engraisser",
    "engraisserons": "engraisser",
    "engraisseront": "engraisser",
    "engraisses": "engraisser",
    "engraissez": "engraisser",
    "engraissiez": "engraisser",
    "engraissions": "engraisser",
    "engraissons": "engraisser",
    "engraissâmes": "engraisser",
    "engraissât": "engraisser",
    "engraissâtes": "engraisser",
    "engraissèrent": "engraisser",
    "engraissé": "engraisser",
    "engraissée": "engraisser",
    "engraissées": "engraisser",
    "engraissés": "engraisser",
    "engrange": "engranger",
    "engrangea": "engranger",
    "engrangeai": "engranger",
    "engrangeaient": "engranger",
    "engrangeais": "engranger",
    "engrangeait": "engranger",
    "engrangeant": "engranger",
    "engrangeas": "engranger",
    "engrangeasse": "engranger",
    "engrangeassent": "engranger",
    "engrangeasses": "engranger",
    "engrangeassiez": "engranger",
    "engrangeassions": "engranger",
    "engrangent": "engranger",
    "engrangeons": "engranger",
    "engrangera": "engranger",
    "engrangerai": "engranger",
    "engrangeraient": "engranger",
    "engrangerais": "engranger",
    "engrangerait": "engranger",
    "engrangeras": "engranger",
    "engrangerez": "engranger",
    "engrangeriez": "engranger",
    "engrangerions": "engranger",
    "engrangerons": "engranger",
    "engrangeront": "engranger",
    "engranges": "engranger",
    "engrangez": "engranger",
    "engrangeâmes": "engranger",
    "engrangeât": "engranger",
    "engrangeâtes": "engranger",
    "engrangiez": "engranger",
    "engrangions": "engranger",
    "engrangèrent": "engranger",
    "engrangé": "engranger",
    "engrangée": "engranger",
    "engrangées": "engranger",
    "engrangés": "engranger",
    "engrena": "engrener",
    "engrenages": "engrenage",
    "engrenai": "engrener",
    "engrenaient": "engrener",
    "engrenais": "engrener",
    "engrenait": "engrener",
    "engrenant": "engrener",
    "engrenas": "engrener",
    "engrenasse": "engrener",
    "engrenassent": "engrener",
    "engrenasses": "engrener",
    "engrenassiez": "engrener",
    "engrenassions": "engrener",
    "engreneuses": "engreneuse",
    "engrenez": "engrener",
    "engreniez": "engrener",
    "engrenions": "engrener",
    "engrenons": "engrener",
    "engrenâmes": "engrener",
    "engrenât": "engrener",
    "engrenâtes": "engrener",
    "engrenèrent": "engrener",
    "engrené": "engrener",
    "engrenée": "engrener",
    "engrenées": "engrener",
    "engrenés": "engrener",
    "engrossait": "engrosser",
    "engrossant": "engrosser",
    "engrosse": "engrosser",
    "engrossent": "engrosser",
    "engrossera": "engrosser",
    "engrosses": "engrosser",
    "engrossé": "engrosser",
    "engrossée": "engrosser",
    "engrossées": "engrosser",
    "engrossés": "engrossé",
    "engrène": "engrener",
    "engrènements": "engrènement",
    "engrènent": "engrener",
    "engrènera": "engrener",
    "engrènerai": "engrener",
    "engrèneraient": "engrener",
    "engrènerais": "engrener",
    "engrènerait": "engrener",
    "engrèneras": "engrener",
    "engrènerez": "engrener",
    "engrèneriez": "engrener",
    "engrènerions": "engrener",
    "engrènerons": "engrener",
    "engrèneront": "engrener",
    "engrènes": "engrener",
    "engueula": "engueuler",
    "engueulades": "engueulade",
    "engueulai": "engueuler",
    "engueulaient": "engueuler",
    "engueulais": "engueuler",
    "engueulait": "engueuler",
    "engueulant": "engueuler",
    "engueulas": "engueuler",
    "engueulasse": "engueuler",
    "engueulassent": "engueuler",
    "engueulasses": "engueuler",
    "engueulassiez": "engueuler",
    "engueulassions": "engueuler",
    "engueule": "engueuler",
    "engueulent": "engueuler",
    "engueulera": "engueuler",
    "engueulerai": "engueuler",
    "engueuleraient": "engueuler",
    "engueulerais": "engueuler",
    "engueulerait": "engueuler",
    "engueuleras": "engueuler",
    "engueulerez": "engueuler",
    "engueuleriez": "engueuler",
    "engueulerions": "engueuler",
    "engueulerons": "engueuler",
    "engueuleront": "engueuler",
    "engueules": "engueuler",
    "engueulez": "engueuler",
    "engueuliez": "engueuler",
    "engueulions": "engueuler",
    "engueulons": "engueuler",
    "engueulâmes": "engueuler",
    "engueulât": "engueuler",
    "engueulâtes": "engueuler",
    "engueulèrent": "engueuler",
    "engueulé": "engueuler",
    "engueulée": "engueuler",
    "engueulées": "engueuler",
    "engueulés": "engueuler",
    "enguirlanda": "enguirlander",
    "enguirlandai": "enguirlander",
    "enguirlandaient": "enguirlander",
    "enguirlandais": "enguirlander",
    "enguirlandait": "enguirlander",
    "enguirlandant": "enguirlander",
    "enguirlandas": "enguirlander",
    "enguirlandasse": "enguirlander",
    "enguirlandassent": "enguirlander",
    "enguirlandasses": "enguirlander",
    "enguirlandassiez": "enguirlander",
    "enguirlandassions": "enguirlander",
    "enguirlande": "enguirlander",
    "enguirlandent": "enguirlander",
    "enguirlandera": "enguirlander",
    "enguirlanderai": "enguirlander",
    "enguirlanderaient": "enguirlander",
    "enguirlanderais": "enguirlander",
    "enguirlanderait": "enguirlander",
    "enguirlanderas": "enguirlander",
    "enguirlanderez": "enguirlander",
    "enguirlanderiez": "enguirlander",
    "enguirlanderions": "enguirlander",
    "enguirlanderons": "enguirlander",
    "enguirlanderont": "enguirlander",
    "enguirlandes": "enguirlander",
    "enguirlandez": "enguirlander",
    "enguirlandiez": "enguirlander",
    "enguirlandions": "enguirlander",
    "enguirlandons": "enguirlander",
    "enguirlandâmes": "enguirlander",
    "enguirlandât": "enguirlander",
    "enguirlandâtes": "enguirlander",
    "enguirlandèrent": "enguirlander",
    "enguirlandé": "enguirlander",
    "enguirlandée": "enguirlander",
    "enguirlandées": "enguirlander",
    "enguirlandés": "enguirlander",
    "enhardi": "enhardir",
    "enhardie": "enhardir",
    "enhardies": "enhardir",
    "enhardira": "enhardir",
    "enhardirai": "enhardir",
    "enhardiraient": "enhardir",
    "enhardirais": "enhardir",
    "enhardirait": "enhardir",
    "enhardiras": "enhardir",
    "enhardirent": "enhardir",
    "enhardirez": "enhardir",
    "enhardiriez": "enhardir",
    "enhardirions": "enhardir",
    "enhardirons": "enhardir",
    "enhardiront": "enhardir",
    "enhardis": "enhardir",
    "enhardissaient": "enhardir",
    "enhardissais": "enhardir",
    "enhardissait": "enhardir",
    "enhardissant": "enhardir",
    "enhardisse": "enhardir",
    "enhardissent": "enhardir",
    "enhardisses": "enhardir",
    "enhardissez": "enhardir",
    "enhardissiez": "enhardir",
    "enhardissions": "enhardir",
    "enhardissons": "enhardir",
    "enhardit": "enhardir",
    "enhardîmes": "enhardir",
    "enhardît": "enhardir",
    "enhardîtes": "enhardir",
    "enharnacha": "enharnacher",
    "enharnachai": "enharnacher",
    "enharnachaient": "enharnacher",
    "enharnachais": "enharnacher",
    "enharnachait": "enharnacher",
    "enharnachant": "enharnacher",
    "enharnachas": "enharnacher",
    "enharnachasse": "enharnacher",
    "enharnachassent": "enharnacher",
    "enharnachasses": "enharnacher",
    "enharnachassiez": "enharnacher",
    "enharnachassions": "enharnacher",
    "enharnache": "enharnacher",
    "enharnachent": "enharnacher",
    "enharnachera": "enharnacher",
    "enharnacherai": "enharnacher",
    "enharnacheraient": "enharnacher",
    "enharnacherais": "enharnacher",
    "enharnacherait": "enharnacher",
    "enharnacheras": "enharnacher",
    "enharnacherez": "enharnacher",
    "enharnacheriez": "enharnacher",
    "enharnacherions": "enharnacher",
    "enharnacherons": "enharnacher",
    "enharnacheront": "enharnacher",
    "enharnaches": "enharnacher",
    "enharnachez": "enharnacher",
    "enharnachiez": "enharnacher",
    "enharnachions": "enharnacher",
    "enharnachons": "enharnacher",
    "enharnachâmes": "enharnacher",
    "enharnachât": "enharnacher",
    "enharnachâtes": "enharnacher",
    "enharnachèrent": "enharnacher",
    "enharnaché": "enharnacher",
    "enharnachée": "enharnacher",
    "enharnachées": "enharnacher",
    "enharnachés": "enharnacher",
    "enivra": "enivrer",
    "enivrai": "enivrer",
    "enivraient": "enivrer",
    "enivrais": "enivrer",
    "enivrait": "enivrer",
    "enivrant": "enivrer",
    "enivrante": "enivrant",
    "enivrantes": "enivrant",
    "enivrants": "enivrant",
    "enivras": "enivrer",
    "enivrasse": "enivrer",
    "enivrassent": "enivrer",
    "enivrasses": "enivrer",
    "enivrassiez": "enivrer",
    "enivrassions": "enivrer",
    "enivre": "enivrer",
    "enivrent": "enivrer",
    "enivrera": "enivrer",
    "enivrerai": "enivrer",
    "enivreraient": "enivrer",
    "enivrerais": "enivrer",
    "enivrerait": "enivrer",
    "enivreras": "enivrer",
    "enivrerez": "enivrer",
    "enivreriez": "enivrer",
    "enivrerions": "enivrer",
    "enivrerons": "enivrer",
    "enivreront": "enivrer",
    "enivres": "enivrer",
    "enivrez": "enivrer",
    "enivriez": "enivrer",
    "enivrions": "enivrer",
    "enivrons": "enivrer",
    "enivrâmes": "enivrer",
    "enivrât": "enivrer",
    "enivrâtes": "enivrer",
    "enivrèrent": "enivrer",
    "enivré": "enivrer",
    "enivrée": "enivrer",
    "enivrées": "enivrer",
    "enivrés": "enivrer",
    "enjamba": "enjamber",
    "enjambai": "enjamber",
    "enjambaient": "enjamber",
    "enjambais": "enjamber",
    "enjambait": "enjamber",
    "enjambant": "enjamber",
    "enjambas": "enjamber",
    "enjambasse": "enjamber",
    "enjambassent": "enjamber",
    "enjambasses": "enjamber",
    "enjambassiez": "enjamber",
    "enjambassions": "enjamber",
    "enjambe": "enjamber",
    "enjambements": "enjambement",
    "enjambent": "enjamber",
    "enjambera": "enjamber",
    "enjamberai": "enjamber",
    "enjamberaient": "enjamber",
    "enjamberais": "enjamber",
    "enjamberait": "enjamber",
    "enjamberas": "enjamber",
    "enjamberez": "enjamber",
    "enjamberiez": "enjamber",
    "enjamberions": "enjamber",
    "enjamberons": "enjamber",
    "enjamberont": "enjamber",
    "enjambes": "enjamber",
    "enjambeurs": "enjambeur",
    "enjambez": "enjamber",
    "enjambiez": "enjamber",
    "enjambions": "enjamber",
    "enjambons": "enjamber",
    "enjambâmes": "enjamber",
    "enjambât": "enjamber",
    "enjambâtes": "enjamber",
    "enjambèrent": "enjamber",
    "enjambé": "enjamber",
    "enjambée": "enjamber",
    "enjambées": "enjamber",
    "enjambés": "enjamber",
    "enjeux": "enjeu",
    "enjoignaient": "enjoindre",
    "enjoignais": "enjoindre",
    "enjoignait": "enjoindre",
    "enjoignant": "enjoindre",
    "enjoigne": "enjoindre",
    "enjoignent": "enjoindre",
    "enjoignes": "enjoindre",
    "enjoignez": "enjoindre",
    "enjoigniez": "enjoindre",
    "enjoignions": "enjoindre",
    "enjoignirent": "enjoindre",
    "enjoignis": "enjoindre",
    "enjoignisse": "enjoindre",
    "enjoignissent": "enjoindre",
    "enjoignisses": "enjoindre",
    "enjoignissiez": "enjoindre",
    "enjoignissions": "enjoindre",
    "enjoignit": "enjoindre",
    "enjoignons": "enjoindre",
    "enjoignîmes": "enjoindre",
    "enjoignît": "enjoindre",
    "enjoignîtes": "enjoindre",
    "enjoindra": "enjoindre",
    "enjoindrai": "enjoindre",
    "enjoindraient": "enjoindre",
    "enjoindrais": "enjoindre",
    "enjoindrait": "enjoindre",
    "enjoindras": "enjoindre",
    "enjoindrez": "enjoindre",
    "enjoindriez": "enjoindre",
    "enjoindrions": "enjoindre",
    "enjoindrons": "enjoindre",
    "enjoindront": "enjoindre",
    "enjoins": "enjoindre",
    "enjoint": "enjoindre",
    "enjointe": "enjoindre",
    "enjointes": "enjoindre",
    "enjoints": "enjoindre",
    "enjoliva": "enjoliver",
    "enjolivai": "enjoliver",
    "enjolivaient": "enjoliver",
    "enjolivais": "enjoliver",
    "enjolivait": "enjoliver",
    "enjolivant": "enjoliver",
    "enjolivas": "enjoliver",
    "enjolivasse": "enjoliver",
    "enjolivassent": "enjoliver",
    "enjolivasses": "enjoliver",
    "enjolivassiez": "enjoliver",
    "enjolivassions": "enjoliver",
    "enjolive": "enjoliver",
    "enjolivements": "enjolivement",
    "enjolivent": "enjoliver",
    "enjolivera": "enjoliver",
    "enjoliverai": "enjoliver",
    "enjoliveraient": "enjoliver",
    "enjoliverais": "enjoliver",
    "enjoliverait": "enjoliver",
    "enjoliveras": "enjoliver",
    "enjoliverez": "enjoliver",
    "enjoliveriez": "enjoliver",
    "enjoliverions": "enjoliver",
    "enjoliverons": "enjoliver",
    "enjoliveront": "enjoliver",
    "enjolives": "enjoliver",
    "enjoliveurs": "enjoliveur",
    "enjolivez": "enjoliver",
    "enjoliviez": "enjoliver",
    "enjolivions": "enjoliver",
    "enjolivons": "enjoliver",
    "enjolivâmes": "enjoliver",
    "enjolivât": "enjoliver",
    "enjolivâtes": "enjoliver",
    "enjolivèrent": "enjoliver",
    "enjolivé": "enjoliver",
    "enjolivée": "enjoliver",
    "enjolivées": "enjoliver",
    "enjolivés": "enjoliver",
    "enjoua": "enjouer",
    "enjouai": "enjouer",
    "enjouaient": "enjouer",
    "enjouais": "enjouer",
    "enjouait": "enjouer",
    "enjouant": "enjouer",
    "enjouas": "enjouer",
    "enjouasse": "enjouer",
    "enjouassent": "enjouer",
    "enjouasses": "enjouer",
    "enjouassiez": "enjouer",
    "enjouassions": "enjouer",
    "enjoue": "enjouer",
    "enjouent": "enjouer",
    "enjouera": "enjouer",
    "enjouerai": "enjouer",
    "enjoueraient": "enjouer",
    "enjouerais": "enjouer",
    "enjouerait": "enjouer",
    "enjoueras": "enjouer",
    "enjouerez": "enjouer",
    "enjoueriez": "enjouer",
    "enjouerions": "enjouer",
    "enjouerons": "enjouer",
    "enjoueront": "enjouer",
    "enjoues": "enjouer",
    "enjouez": "enjouer",
    "enjouiez": "enjouer",
    "enjouions": "enjouer",
    "enjouons": "enjouer",
    "enjouâmes": "enjouer",
    "enjouât": "enjouer",
    "enjouâtes": "enjouer",
    "enjouèrent": "enjouer",
    "enjoué": "enjouer",
    "enjouée": "enjouer",
    "enjouées": "enjouer",
    "enjoués": "enjouer",
    "enjuivés": "enjuivé",
    "enjuponne": "enjuponner",
    "enjuponnée": "enjuponner",
    "enjôla": "enjôler",
    "enjôlai": "enjôler",
    "enjôlaient": "enjôler",
    "enjôlais": "enjôler",
    "enjôlait": "enjôler",
    "enjôlant": "enjôler",
    "enjôlas": "enjôler",
    "enjôlasse": "enjôler",
    "enjôlassent": "enjôler",
    "enjôlasses": "enjôler",
    "enjôlassiez": "enjôler",
    "enjôlassions": "enjôler",
    "enjôle": "enjôler",
    "enjôlent": "enjôler",
    "enjôlera": "enjôler",
    "enjôlerai": "enjôler",
    "enjôleraient": "enjôler",
    "enjôlerais": "enjôler",
    "enjôlerait": "enjôler",
    "enjôleras": "enjôler",
    "enjôlerez": "enjôler",
    "enjôleriez": "enjôler",
    "enjôlerions": "enjôler",
    "enjôlerons": "enjôler",
    "enjôleront": "enjôler",
    "enjôles": "enjôler",
    "enjôleurs": "enjôleur",
    "enjôleuse": "enjôleur",
    "enjôleuses": "enjôleur",
    "enjôlez": "enjôler",
    "enjôliez": "enjôler",
    "enjôlions": "enjôler",
    "enjôlons": "enjôler",
    "enjôlâmes": "enjôler",
    "enjôlât": "enjôler",
    "enjôlâtes": "enjôler",
    "enjôlèrent": "enjôler",
    "enjôlé": "enjôler",
    "enjôlée": "enjôler",
    "enjôlées": "enjôler",
    "enjôlés": "enjôler",
    "enkysta": "enkyster",
    "enkystai": "enkyster",
    "enkystaient": "enkyster",
    "enkystais": "enkyster",
    "enkystait": "enkyster",
    "enkystant": "enkyster",
    "enkystas": "enkyster",
    "enkystasse": "enkyster",
    "enkystassent": "enkyster",
    "enkystasses": "enkyster",
    "enkystassiez": "enkyster",
    "enkystassions": "enkyster",
    "enkyste": "enkyster",
    "enkystent": "enkyster",
    "enkystera": "enkyster",
    "enkysterai": "enkyster",
    "enkysteraient": "enkyster",
    "enkysterais": "enkyster",
    "enkysterait": "enkyster",
    "enkysteras": "enkyster",
    "enkysterez": "enkyster",
    "enkysteriez": "enkyster",
    "enkysterions": "enkyster",
    "enkysterons": "enkyster",
    "enkysteront": "enkyster",
    "enkystes": "enkyster",
    "enkystez": "enkyster",
    "enkystiez": "enkyster",
    "enkystions": "enkyster",
    "enkystons": "enkyster",
    "enkystâmes": "enkyster",
    "enkystât": "enkyster",
    "enkystâtes": "enkyster",
    "enkystèrent": "enkyster",
    "enkysté": "enkyster",
    "enkystée": "enkyster",
    "enkystées": "enkyster",
    "enkystés": "enkyster",
    "enlace": "enlacer",
    "enlacements": "enlacement",
    "enlacent": "enlacer",
    "enlacera": "enlacer",
    "enlacerai": "enlacer",
    "enlaceraient": "enlacer",
    "enlacerais": "enlacer",
    "enlacerait": "enlacer",
    "enlaceras": "enlacer",
    "enlacerez": "enlacer",
    "enlaceriez": "enlacer",
    "enlacerions": "enlacer",
    "enlacerons": "enlacer",
    "enlaceront": "enlacer",
    "enlaces": "enlacer",
    "enlacez": "enlacer",
    "enlaciez": "enlacer",
    "enlacions": "enlacer",
    "enlacèrent": "enlacer",
    "enlacé": "enlacer",
    "enlacée": "enlacer",
    "enlacées": "enlacer",
    "enlacés": "enlacer",
    "enlaidi": "enlaidir",
    "enlaidie": "enlaidir",
    "enlaidies": "enlaidir",
    "enlaidira": "enlaidir",
    "enlaidirai": "enlaidir",
    "enlaidiraient": "enlaidir",
    "enlaidirais": "enlaidir",
    "enlaidirait": "enlaidir",
    "enlaidiras": "enlaidir",
    "enlaidirent": "enlaidir",
    "enlaidirez": "enlaidir",
    "enlaidiriez": "enlaidir",
    "enlaidirions": "enlaidir",
    "enlaidirons": "enlaidir",
    "enlaidiront": "enlaidir",
    "enlaidis": "enlaidir",
    "enlaidissaient": "enlaidir",
    "enlaidissais": "enlaidir",
    "enlaidissait": "enlaidir",
    "enlaidissant": "enlaidir",
    "enlaidisse": "enlaidir",
    "enlaidissements": "enlaidissement",
    "enlaidissent": "enlaidir",
    "enlaidisses": "enlaidir",
    "enlaidissez": "enlaidir",
    "enlaidissiez": "enlaidir",
    "enlaidissions": "enlaidir",
    "enlaidissons": "enlaidir",
    "enlaidit": "enlaidir",
    "enlaidîmes": "enlaidir",
    "enlaidît": "enlaidir",
    "enlaidîtes": "enlaidir",
    "enlaça": "enlacer",
    "enlaçai": "enlacer",
    "enlaçaient": "enlacer",
    "enlaçais": "enlacer",
    "enlaçait": "enlacer",
    "enlaçant": "enlacer",
    "enlaças": "enlacer",
    "enlaçasse": "enlacer",
    "enlaçassent": "enlacer",
    "enlaçasses": "enlacer",
    "enlaçassiez": "enlacer",
    "enlaçassions": "enlacer",
    "enlaçons": "enlacer",
    "enlaçâmes": "enlacer",
    "enlaçât": "enlacer",
    "enlaçâtes": "enlacer",
    "enleva": "enlever",
    "enlevai": "enlever",
    "enlevaient": "enlever",
    "enlevais": "enlever",
    "enlevait": "enlever",
    "enlevant": "enlever",
    "enlevas": "enlever",
    "enlevasse": "enlever",
    "enlevassent": "enlever",
    "enlevasses": "enlever",
    "enlevassiez": "enlever",
    "enlevassions": "enlever",
    "enlevez": "enlever",
    "enleviez": "enlever",
    "enlevions": "enlever",
    "enlevons": "enlever",
    "enlevâmes": "enlever",
    "enlevât": "enlever",
    "enlevâtes": "enlever",
    "enlevèrent": "enlever",
    "enlevé": "enlever",
    "enlevée": "enlever",
    "enlevées": "enlever",
    "enlevés": "enlever",
    "enlia": "enlier",
    "enliai": "enlier",
    "enliaient": "enlier",
    "enliais": "enlier",
    "enliait": "enlier",
    "enliant": "enlier",
    "enlias": "enlier",
    "enliasse": "enlier",
    "enliassent": "enlier",
    "enliasses": "enlier",
    "enliassiez": "enlier",
    "enliassions": "enlier",
    "enlie": "enlier",
    "enlient": "enlier",
    "enliera": "enlier",
    "enlierai": "enlier",
    "enlieraient": "enlier",
    "enlierais": "enlier",
    "enlierait": "enlier",
    "enlieras": "enlier",
    "enlierez": "enlier",
    "enlieriez": "enlier",
    "enlierions": "enlier",
    "enlierons": "enlier",
    "enlieront": "enlier",
    "enlies": "enlier",
    "enliez": "enlier",
    "enliiez": "enlier",
    "enliions": "enlier",
    "enlions": "enlier",
    "enlisa": "enliser",
    "enlisai": "enliser",
    "enlisaient": "enliser",
    "enlisais": "enliser",
    "enlisait": "enliser",
    "enlisant": "enliser",
    "enlisas": "enliser",
    "enlisasse": "enliser",
    "enlisassent": "enliser",
    "enlisasses": "enliser",
    "enlisassiez": "enliser",
    "enlisassions": "enliser",
    "enlise": "enliser",
    "enlisements": "enlisement",
    "enlisent": "enliser",
    "enlisera": "enliser",
    "enliserai": "enliser",
    "enliseraient": "enliser",
    "enliserais": "enliser",
    "enliserait": "enliser",
    "enliseras": "enliser",
    "enliserez": "enliser",
    "enliseriez": "enliser",
    "enliserions": "enliser",
    "enliserons": "enliser",
    "enliseront": "enliser",
    "enlises": "enliser",
    "enlisez": "enliser",
    "enlisiez": "enliser",
    "enlisions": "enliser",
    "enlisons": "enliser",
    "enlisâmes": "enliser",
    "enlisât": "enliser",
    "enlisâtes": "enliser",
    "enlisèrent": "enliser",
    "enlisé": "enliser",
    "enlisée": "enliser",
    "enlisées": "enliser",
    "enlisés": "enliser",
    "enliâmes": "enlier",
    "enliât": "enlier",
    "enliâtes": "enlier",
    "enlièrent": "enlier",
    "enlié": "enlier",
    "enliée": "enlier",
    "enliées": "enlier",
    "enliés": "enlier",
    "enlumina": "enluminer",
    "enluminai": "enluminer",
    "enluminaient": "enluminer",
    "enluminais": "enluminer",
    "enluminait": "enluminer",
    "enluminant": "enluminer",
    "enluminas": "enluminer",
    "enluminasse": "enluminer",
    "enluminassent": "enluminer",
    "enluminasses": "enluminer",
    "enluminassiez": "enluminer",
    "enluminassions": "enluminer",
    "enlumine": "enluminer",
    "enluminent": "enluminer",
    "enluminera": "enluminer",
    "enluminerai": "enluminer",
    "enlumineraient": "enluminer",
    "enluminerais": "enluminer",
    "enluminerait": "enluminer",
    "enlumineras": "enluminer",
    "enluminerez": "enluminer",
    "enlumineriez": "enluminer",
    "enluminerions": "enluminer",
    "enluminerons": "enluminer",
    "enlumineront": "enluminer",
    "enlumines": "enluminer",
    "enlumineurs": "enlumineur",
    "enluminez": "enluminer",
    "enluminiez": "enluminer",
    "enluminions": "enluminer",
    "enluminons": "enluminer",
    "enluminures": "enluminure",
    "enluminâmes": "enluminer",
    "enluminât": "enluminer",
    "enluminâtes": "enluminer",
    "enluminèrent": "enluminer",
    "enluminé": "enluminer",
    "enluminée": "enluminer",
    "enluminées": "enluminer",
    "enluminés": "enluminer",
    "enlève": "enlever",
    "enlèvements": "enlèvement",
    "enlèvent": "enlever",
    "enlèvera": "enlever",
    "enlèverai": "enlever",
    "enlèveraient": "enlever",
    "enlèverais": "enlever",
    "enlèverait": "enlever",
    "enlèveras": "enlever",
    "enlèverez": "enlever",
    "enlèveriez": "enlever",
    "enlèverions": "enlever",
    "enlèverons": "enlever",
    "enlèveront": "enlever",
    "enlèves": "enlever",
    "enneige": "enneiger",
    "enneigea": "enneiger",
    "enneigeai": "enneiger",
    "enneigeaient": "enneiger",
    "enneigeais": "enneiger",
    "enneigeait": "enneiger",
    "enneigeant": "enneiger",
    "enneigeas": "enneiger",
    "enneigeasse": "enneiger",
    "enneigeassent": "enneiger",
    "enneigeasses": "enneiger",
    "enneigeassiez": "enneiger",
    "enneigeassions": "enneiger",
    "enneigent": "enneiger",
    "enneigeons": "enneiger",
    "enneigera": "enneiger",
    "enneigerai": "enneiger",
    "enneigeraient": "enneiger",
    "enneigerais": "enneiger",
    "enneigerait": "enneiger",
    "enneigeras": "enneiger",
    "enneigerez": "enneiger",
    "enneigeriez": "enneiger",
    "enneigerions": "enneiger",
    "enneigerons": "enneiger",
    "enneigeront": "enneiger",
    "enneiges": "enneiger",
    "enneigez": "enneiger",
    "enneigeâmes": "enneiger",
    "enneigeât": "enneiger",
    "enneigeâtes": "enneiger",
    "enneigiez": "enneiger",
    "enneigions": "enneiger",
    "enneigèrent": "enneiger",
    "enneigé": "enneiger",
    "enneigée": "enneiger",
    "enneigées": "enneiger",
    "enneigés": "enneiger",
    "ennemie": "ennemi",
    "ennemies": "ennemi",
    "ennemis": "ennemi",
    "ennobli": "ennoblir",
    "ennoblie": "ennoblir",
    "ennoblies": "ennoblir",
    "ennoblira": "ennoblir",
    "ennoblirai": "ennoblir",
    "ennobliraient": "ennoblir",
    "ennoblirais": "ennoblir",
    "ennoblirait": "ennoblir",
    "ennobliras": "ennoblir",
    "ennoblirent": "ennoblir",
    "ennoblirez": "ennoblir",
    "ennobliriez": "ennoblir",
    "ennoblirions": "ennoblir",
    "ennoblirons": "ennoblir",
    "ennobliront": "ennoblir",
    "ennoblis": "ennoblir",
    "ennoblissaient": "ennoblir",
    "ennoblissais": "ennoblir",
    "ennoblissait": "ennoblir",
    "ennoblissant": "ennoblir",
    "ennoblisse": "ennoblir",
    "ennoblissent": "ennoblir",
    "ennoblisses": "ennoblir",
    "ennoblissez": "ennoblir",
    "ennoblissiez": "ennoblir",
    "ennoblissions": "ennoblir",
    "ennoblissons": "ennoblir",
    "ennoblit": "ennoblir",
    "ennoblîmes": "ennoblir",
    "ennoblît": "ennoblir",
    "ennoblîtes": "ennoblir",
    "ennuagent": "ennuager",
    "ennuagé": "ennuager",
    "ennuie": "ennuyer",
    "ennuient": "ennuyer",
    "ennuiera": "ennuyer",
    "ennuierai": "ennuyer",
    "ennuieraient": "ennuyer",
    "ennuierais": "ennuyer",
    "ennuierait": "ennuyer",
    "ennuieras": "ennuyer",
    "ennuierez": "ennuyer",
    "ennuieriez": "ennuyer",
    "ennuierions": "ennuyer",
    "ennuierons": "ennuyer",
    "ennuieront": "ennuyer",
    "ennuies": "ennuyer",
    "ennuis": "ennui",
    "ennuya": "ennuyer",
    "ennuyai": "ennuyer",
    "ennuyaient": "ennuyer",
    "ennuyais": "ennuyer",
    "ennuyait": "ennuyer",
    "ennuyant": "ennuyer",
    "ennuyante": "ennuyant",
    "ennuyas": "ennuyer",
    "ennuyasse": "ennuyer",
    "ennuyassent": "ennuyer",
    "ennuyasses": "ennuyer",
    "ennuyassiez": "ennuyer",
    "ennuyassions": "ennuyer",
    "ennuyeuse": "ennuyeux",
    "ennuyeuses": "ennuyeux",
    "ennuyez": "ennuyer",
    "ennuyiez": "ennuyer",
    "ennuyions": "ennuyer",
    "ennuyons": "ennuyer",
    "ennuyâmes": "ennuyer",
    "ennuyât": "ennuyer",
    "ennuyâtes": "ennuyer",
    "ennuyèrent": "ennuyer",
    "ennuyé": "ennuyer",
    "ennuyée": "ennuyer",
    "ennuyées": "ennuyer",
    "ennuyés": "ennuyer",
    "enorgueilli": "enorgueillir",
    "enorgueillie": "enorgueillir",
    "enorgueillies": "enorgueillir",
    "enorgueillira": "enorgueillir",
    "enorgueillirai": "enorgueillir",
    "enorgueilliraient": "enorgueillir",
    "enorgueillirais": "enorgueillir",
    "enorgueillirait": "enorgueillir",
    "enorgueilliras": "enorgueillir",
    "enorgueillirent": "enorgueillir",
    "enorgueillirez": "enorgueillir",
    "enorgueilliriez": "enorgueillir",
    "enorgueillirions": "enorgueillir",
    "enorgueillirons": "enorgueillir",
    "enorgueilliront": "enorgueillir",
    "enorgueillis": "enorgueillir",
    "enorgueillissaient": "enorgueillir",
    "enorgueillissais": "enorgueillir",
    "enorgueillissait": "enorgueillir",
    "enorgueillissant": "enorgueillir",
    "enorgueillisse": "enorgueillir",
    "enorgueillissent": "enorgueillir",
    "enorgueillisses": "enorgueillir",
    "enorgueillissez": "enorgueillir",
    "enorgueillissiez": "enorgueillir",
    "enorgueillissions": "enorgueillir",
    "enorgueillissons": "enorgueillir",
    "enorgueillit": "enorgueillir",
    "enorgueillîmes": "enorgueillir",
    "enorgueillît": "enorgueillir",
    "enorgueillîtes": "enorgueillir",
    "enquerra": "enquérir",
    "enquerrai": "enquérir",
    "enquerraient": "enquérir",
    "enquerrais": "enquérir",
    "enquerrait": "enquérir",
    "enquerras": "enquérir",
    "enquerrez": "enquérir",
    "enquerriez": "enquérir",
    "enquerrions": "enquérir",
    "enquerrons": "enquérir",
    "enquerront": "enquérir",
    "enquiers": "enquérir",
    "enquiert": "enquérir",
    "enquillais": "enquiller",
    "enquillait": "enquiller",
    "enquillant": "enquiller",
    "enquille": "enquiller",
    "enquillent": "enquiller",
    "enquillons": "enquiller",
    "enquillé": "enquiller",
    "enquillés": "enquiller",
    "enquiquinaient": "enquiquiner",
    "enquiquinait": "enquiquiner",
    "enquiquinant": "enquiquiner",
    "enquiquinante": "enquiquinant",
    "enquiquinants": "enquiquinant",
    "enquiquine": "enquiquiner",
    "enquiquinent": "enquiquiner",
    "enquiquineraient": "enquiquiner",
    "enquiquines": "enquiquiner",
    "enquiquineurs": "enquiquineur",
    "enquiquineuse": "enquiquineur",
    "enquiquiné": "enquiquiner",
    "enquirent": "enquérir",
    "enquis": "enquérir",
    "enquise": "enquérir",
    "enquises": "enquérir",
    "enquisse": "enquérir",
    "enquissent": "enquérir",
    "enquisses": "enquérir",
    "enquissiez": "enquérir",
    "enquissions": "enquérir",
    "enquit": "enquérir",
    "enquière": "enquérir",
    "enquièrent": "enquérir",
    "enquières": "enquérir",
    "enquéraient": "enquérir",
    "enquérais": "enquérir",
    "enquérait": "enquérir",
    "enquérant": "enquérir",
    "enquérez": "enquérir",
    "enquériez": "enquérir",
    "enquérions": "enquérir",
    "enquérons": "enquérir",
    "enquêta": "enquêter",
    "enquêtai": "enquêter",
    "enquêtaient": "enquêter",
    "enquêtais": "enquêter",
    "enquêtait": "enquêter",
    "enquêtant": "enquêter",
    "enquêtas": "enquêter",
    "enquêtasse": "enquêter",
    "enquêtassent": "enquêter",
    "enquêtasses": "enquêter",
    "enquêtassiez": "enquêter",
    "enquêtassions": "enquêter",
    "enquête": "enquêter",
    "enquêtent": "enquêter",
    "enquêtera": "enquêter",
    "enquêterai": "enquêter",
    "enquêteraient": "enquêter",
    "enquêterais": "enquêter",
    "enquêterait": "enquêter",
    "enquêteras": "enquêter",
    "enquêterez": "enquêter",
    "enquêteriez": "enquêter",
    "enquêterions": "enquêter",
    "enquêterons": "enquêter",
    "enquêteront": "enquêter",
    "enquêtes": "enquêter",
    "enquêtes-minute": "enquête-minute",
    "enquêteurs": "enquêteur",
    "enquêteuse": "enquêteur",
    "enquêtez": "enquêter",
    "enquêtiez": "enquêter",
    "enquêtions": "enquêter",
    "enquêtons": "enquêter",
    "enquêtrices": "enquêteur",
    "enquêtâmes": "enquêter",
    "enquêtât": "enquêter",
    "enquêtâtes": "enquêter",
    "enquêtèrent": "enquêter",
    "enquêté": "enquêter",
    "enquêtée": "enquêter",
    "enquêtées": "enquêter",
    "enquêtés": "enquêter",
    "enquîmes": "enquérir",
    "enquît": "enquérir",
    "enquîtes": "enquérir",
    "enracina": "enraciner",
    "enracinai": "enraciner",
    "enracinaient": "enraciner",
    "enracinais": "enraciner",
    "enracinait": "enraciner",
    "enracinant": "enraciner",
    "enracinas": "enraciner",
    "enracinasse": "enraciner",
    "enracinassent": "enraciner",
    "enracinasses": "enraciner",
    "enracinassiez": "enraciner",
    "enracinassions": "enraciner",
    "enracine": "enraciner",
    "enracinements": "enracinement",
    "enracinent": "enraciner",
    "enracinera": "enraciner",
    "enracinerai": "enraciner",
    "enracineraient": "enraciner",
    "enracinerais": "enraciner",
    "enracinerait": "enraciner",
    "enracineras": "enraciner",
    "enracinerez": "enraciner",
    "enracineriez": "enraciner",
    "enracinerions": "enraciner",
    "enracinerons": "enraciner",
    "enracineront": "enraciner",
    "enracines": "enraciner",
    "enracinez": "enraciner",
    "enraciniez": "enraciner",
    "enracinions": "enraciner",
    "enracinons": "enraciner",
    "enracinâmes": "enraciner",
    "enracinât": "enraciner",
    "enracinâtes": "enraciner",
    "enracinèrent": "enraciner",
    "enraciné": "enraciner",
    "enracinée": "enraciner",
    "enracinées": "enraciner",
    "enracinés": "enraciner",
    "enrage": "enrager",
    "enragea": "enrager",
    "enrageai": "enrager",
    "enrageaient": "enrager",
    "enrageais": "enrager",
    "enrageait": "enrager",
    "enrageant": "enrager",
    "enrageante": "enrageant",
    "enrageas": "enrager",
    "enrageasse": "enrager",
    "enrageassent": "enrager",
    "enrageasses": "enrager",
    "enrageassiez": "enrager",
    "enrageassions": "enrager",
    "enragent": "enrager",
    "enrageons": "enrager",
    "enragera": "enrager",
    "enragerai": "enrager",
    "enrageraient": "enrager",
    "enragerais": "enrager",
    "enragerait": "enrager",
    "enrageras": "enrager",
    "enragerez": "enrager",
    "enrageriez": "enrager",
    "enragerions": "enrager",
    "enragerons": "enrager",
    "enrageront": "enrager",
    "enrages": "enrager",
    "enragez": "enrager",
    "enrageâmes": "enrager",
    "enrageât": "enrager",
    "enrageâtes": "enrager",
    "enragiez": "enrager",
    "enragions": "enrager",
    "enragèrent": "enrager",
    "enragé": "enrager",
    "enragée": "enrager",
    "enragées": "enrager",
    "enragés": "enrager",
    "enraie": "enrayer",
    "enraiements": "enraiement",
    "enraient": "enrayer",
    "enraiera": "enrayer",
    "enraierai": "enrayer",
    "enraieraient": "enrayer",
    "enraierais": "enrayer",
    "enraierait": "enrayer",
    "enraieras": "enrayer",
    "enraierez": "enrayer",
    "enraieriez": "enrayer",
    "enraierions": "enrayer",
    "enraierons": "enrayer",
    "enraieront": "enrayer",
    "enraies": "enrayer",
    "enraillée": "enrailler",
    "enraya": "enrayer",
    "enrayai": "enrayer",
    "enrayaient": "enrayer",
    "enrayais": "enrayer",
    "enrayait": "enrayer",
    "enrayant": "enrayer",
    "enrayas": "enrayer",
    "enrayasse": "enrayer",
    "enrayassent": "enrayer",
    "enrayasses": "enrayer",
    "enrayassiez": "enrayer",
    "enrayassions": "enrayer",
    "enraye": "enrayer",
    "enrayements": "enrayement",
    "enrayent": "enrayer",
    "enrayera": "enrayer",
    "enrayerai": "enrayer",
    "enrayeraient": "enrayer",
    "enrayerais": "enrayer",
    "enrayerait": "enrayer",
    "enrayeras": "enrayer",
    "enrayerez": "enrayer",
    "enrayeriez": "enrayer",
    "enrayerions": "enrayer",
    "enrayerons": "enrayer",
    "enrayeront": "enrayer",
    "enrayes": "enrayer",
    "enrayez": "enrayer",
    "enrayiez": "enrayer",
    "enrayions": "enrayer",
    "enrayons": "enrayer",
    "enrayâmes": "enrayer",
    "enrayât": "enrayer",
    "enrayâtes": "enrayer",
    "enrayèrent": "enrayer",
    "enrayé": "enrayer",
    "enrayée": "enrayer",
    "enrayées": "enrayer",
    "enrayés": "enrayer",
    "enregistra": "enregistrer",
    "enregistrai": "enregistrer",
    "enregistraient": "enregistrer",
    "enregistrais": "enregistrer",
    "enregistrait": "enregistrer",
    "enregistrant": "enregistrer",
    "enregistras": "enregistrer",
    "enregistrasse": "enregistrer",
    "enregistrassent": "enregistrer",
    "enregistrasses": "enregistrer",
    "enregistrassiez": "enregistrer",
    "enregistrassions": "enregistrer",
    "enregistre": "enregistrer",
    "enregistrements": "enregistrement",
    "enregistrent": "enregistrer",
    "enregistrera": "enregistrer",
    "enregistrerai": "enregistrer",
    "enregistreraient": "enregistrer",
    "enregistrerais": "enregistrer",
    "enregistrerait": "enregistrer",
    "enregistreras": "enregistrer",
    "enregistrerez": "enregistrer",
    "enregistreriez": "enregistrer",
    "enregistrerions": "enregistrer",
    "enregistrerons": "enregistrer",
    "enregistreront": "enregistrer",
    "enregistres": "enregistrer",
    "enregistreurs": "enregistreur",
    "enregistreuse": "enregistreur",
    "enregistreuses": "enregistreuse",
    "enregistrez": "enregistrer",
    "enregistriez": "enregistrer",
    "enregistrions": "enregistrer",
    "enregistrons": "enregistrer",
    "enregistrâmes": "enregistrer",
    "enregistrât": "enregistrer",
    "enregistrâtes": "enregistrer",
    "enregistrèrent": "enregistrer",
    "enregistré": "enregistrer",
    "enregistrée": "enregistrer",
    "enregistrées": "enregistrer",
    "enregistrés": "enregistrer",
    "enrhuma": "enrhumer",
    "enrhumai": "enrhumer",
    "enrhumaient": "enrhumer",
    "enrhumais": "enrhumer",
    "enrhumait": "enrhumer",
    "enrhumant": "enrhumer",
    "enrhumas": "enrhumer",
    "enrhumasse": "enrhumer",
    "enrhumassent": "enrhumer",
    "enrhumasses": "enrhumer",
    "enrhumassiez": "enrhumer",
    "enrhumassions": "enrhumer",
    "enrhume": "enrhumer",
    "enrhument": "enrhumer",
    "enrhumera": "enrhumer",
    "enrhumerai": "enrhumer",
    "enrhumeraient": "enrhumer",
    "enrhumerais": "enrhumer",
    "enrhumerait": "enrhumer",
    "enrhumeras": "enrhumer",
    "enrhumerez": "enrhumer",
    "enrhumeriez": "enrhumer",
    "enrhumerions": "enrhumer",
    "enrhumerons": "enrhumer",
    "enrhumeront": "enrhumer",
    "enrhumes": "enrhumer",
    "enrhumez": "enrhumer",
    "enrhumiez": "enrhumer",
    "enrhumions": "enrhumer",
    "enrhumons": "enrhumer",
    "enrhumâmes": "enrhumer",
    "enrhumât": "enrhumer",
    "enrhumâtes": "enrhumer",
    "enrhumèrent": "enrhumer",
    "enrhumé": "enrhumer",
    "enrhumée": "enrhumer",
    "enrhumées": "enrhumer",
    "enrhumés": "enrhumer",
    "enrichi": "enrichir",
    "enrichie": "enrichir",
    "enrichies": "enrichir",
    "enrichira": "enrichir",
    "enrichirai": "enrichir",
    "enrichiraient": "enrichir",
    "enrichirais": "enrichir",
    "enrichirait": "enrichir",
    "enrichiras": "enrichir",
    "enrichirent": "enrichir",
    "enrichirez": "enrichir",
    "enrichiriez": "enrichir",
    "enrichirions": "enrichir",
    "enrichirons": "enrichir",
    "enrichiront": "enrichir",
    "enrichis": "enrichir",
    "enrichissaient": "enrichir",
    "enrichissais": "enrichir",
    "enrichissait": "enrichir",
    "enrichissant": "enrichir",
    "enrichissante": "enrichissant",
    "enrichissantes": "enrichissant",
    "enrichissants": "enrichissant",
    "enrichisse": "enrichir",
    "enrichissements": "enrichissement",
    "enrichissent": "enrichir",
    "enrichisses": "enrichir",
    "enrichissez": "enrichir",
    "enrichissiez": "enrichir",
    "enrichissions": "enrichir",
    "enrichissons": "enrichir",
    "enrichit": "enrichir",
    "enrichîmes": "enrichir",
    "enrichît": "enrichir",
    "enrichîtes": "enrichir",
    "enroba": "enrober",
    "enrobai": "enrober",
    "enrobaient": "enrober",
    "enrobais": "enrober",
    "enrobait": "enrober",
    "enrobant": "enrober",
    "enrobas": "enrober",
    "enrobasse": "enrober",
    "enrobassent": "enrober",
    "enrobasses": "enrober",
    "enrobassiez": "enrober",
    "enrobassions": "enrober",
    "enrobe": "enrober",
    "enrobent": "enrober",
    "enrobera": "enrober",
    "enroberai": "enrober",
    "enroberaient": "enrober",
    "enroberais": "enrober",
    "enroberait": "enrober",
    "enroberas": "enrober",
    "enroberez": "enrober",
    "enroberiez": "enrober",
    "enroberions": "enrober",
    "enroberons": "enrober",
    "enroberont": "enrober",
    "enrobes": "enrober",
    "enrobez": "enrober",
    "enrobiez": "enrober",
    "enrobions": "enrober",
    "enrobons": "enrober",
    "enrobâmes": "enrober",
    "enrobât": "enrober",
    "enrobâtes": "enrober",
    "enrobèrent": "enrober",
    "enrobé": "enrober",
    "enrobée": "enrober",
    "enrobées": "enrober",
    "enrobés": "enrober",
    "enrochements": "enrochement",
    "enroua": "enrouer",
    "enrouai": "enrouer",
    "enrouaient": "enrouer",
    "enrouais": "enrouer",
    "enrouait": "enrouer",
    "enrouant": "enrouer",
    "enrouas": "enrouer",
    "enrouasse": "enrouer",
    "enrouassent": "enrouer",
    "enrouasses": "enrouer",
    "enrouassiez": "enrouer",
    "enrouassions": "enrouer",
    "enroue": "enrouer",
    "enrouements": "enrouement",
    "enrouent": "enrouer",
    "enrouera": "enrouer",
    "enrouerai": "enrouer",
    "enroueraient": "enrouer",
    "enrouerais": "enrouer",
    "enrouerait": "enrouer",
    "enroueras": "enrouer",
    "enrouerez": "enrouer",
    "enroueriez": "enrouer",
    "enrouerions": "enrouer",
    "enrouerons": "enrouer",
    "enroueront": "enrouer",
    "enroues": "enrouer",
    "enrouez": "enrouer",
    "enrouiez": "enrouer",
    "enrouilla": "enrouiller",
    "enrouillai": "enrouiller",
    "enrouillaient": "enrouiller",
    "enrouillais": "enrouiller",
    "enrouillait": "enrouiller",
    "enrouillant": "enrouiller",
    "enrouillas": "enrouiller",
    "enrouillasse": "enrouiller",
    "enrouillassent": "enrouiller",
    "enrouillasses": "enrouiller",
    "enrouillassiez": "enrouiller",
    "enrouillassions": "enrouiller",
    "enrouille": "enrouiller",
    "enrouillent": "enrouiller",
    "enrouillera": "enrouiller",
    "enrouillerai": "enrouiller",
    "enrouilleraient": "enrouiller",
    "enrouillerais": "enrouiller",
    "enrouillerait": "enrouiller",
    "enrouilleras": "enrouiller",
    "enrouillerez": "enrouiller",
    "enrouilleriez": "enrouiller",
    "enrouillerions": "enrouiller",
    "enrouillerons": "enrouiller",
    "enrouilleront": "enrouiller",
    "enrouilles": "enrouiller",
    "enrouillez": "enrouiller",
    "enrouilliez": "enrouiller",
    "enrouillions": "enrouiller",
    "enrouillons": "enrouiller",
    "enrouillâmes": "enrouiller",
    "enrouillât": "enrouiller",
    "enrouillâtes": "enrouiller",
    "enrouillèrent": "enrouiller",
    "enrouillé": "enrouiller",
    "enrouillée": "enrouiller",
    "enrouillées": "enrouiller",
    "enrouillés": "enrouiller",
    "enrouions": "enrouer",
    "enroula": "enrouler",
    "enroulai": "enrouler",
    "enroulaient": "enrouler",
    "enroulais": "enrouler",
    "enroulait": "enrouler",
    "enroulant": "enrouler",
    "enroulas": "enrouler",
    "enroulasse": "enrouler",
    "enroulassent": "enrouler",
    "enroulasses": "enrouler",
    "enroulassiez": "enrouler",
    "enroulassions": "enrouler",
    "enroule": "enrouler",
    "enroulements": "enroulement",
    "enroulent": "enrouler",
    "enroulera": "enrouler",
    "enroulerai": "enrouler",
    "enrouleraient": "enrouler",
    "enroulerais": "enrouler",
    "enroulerait": "enrouler",
    "enrouleras": "enrouler",
    "enroulerez": "enrouler",
    "enrouleriez": "enrouler",
    "enroulerions": "enrouler",
    "enroulerons": "enrouler",
    "enrouleront": "enrouler",
    "enroules": "enrouler",
    "enroulez": "enrouler",
    "enrouliez": "enrouler",
    "enroulions": "enrouler",
    "enroulons": "enrouler",
    "enroulâmes": "enrouler",
    "enroulât": "enrouler",
    "enroulâtes": "enrouler",
    "enroulèrent": "enrouler",
    "enroulé": "enrouler",
    "enroulée": "enrouler",
    "enroulées": "enrouler",
    "enroulés": "enrouler",
    "enrouons": "enrouer",
    "enrouâmes": "enrouer",
    "enrouât": "enrouer",
    "enrouâtes": "enrouer",
    "enrouèrent": "enrouer",
    "enroué": "enrouer",
    "enrouée": "enrouer",
    "enrouées": "enrouer",
    "enroués": "enrouer",
    "enrubanna": "enrubanner",
    "enrubannai": "enrubanner",
    "enrubannaient": "enrubanner",
    "enrubannais": "enrubanner",
    "enrubannait": "enrubanner",
    "enrubannant": "enrubanner",
    "enrubannas": "enrubanner",
    "enrubannasse": "enrubanner",
    "enrubannassent": "enrubanner",
    "enrubannasses": "enrubanner",
    "enrubannassiez": "enrubanner",
    "enrubannassions": "enrubanner",
    "enrubanne": "enrubanner",
    "enrubannent": "enrubanner",
    "enrubannera": "enrubanner",
    "enrubannerai": "enrubanner",
    "enrubanneraient": "enrubanner",
    "enrubannerais": "enrubanner",
    "enrubannerait": "enrubanner",
    "enrubanneras": "enrubanner",
    "enrubannerez": "enrubanner",
    "enrubanneriez": "enrubanner",
    "enrubannerions": "enrubanner",
    "enrubannerons": "enrubanner",
    "enrubanneront": "enrubanner",
    "enrubannes": "enrubanner",
    "enrubannez": "enrubanner",
    "enrubanniez": "enrubanner",
    "enrubannions": "enrubanner",
    "enrubannons": "enrubanner",
    "enrubannâmes": "enrubanner",
    "enrubannât": "enrubanner",
    "enrubannâtes": "enrubanner",
    "enrubannèrent": "enrubanner",
    "enrubanné": "enrubanner",
    "enrubannée": "enrubanner",
    "enrubannées": "enrubanner",
    "enrubannés": "enrubanner",
    "enrégimenta": "enrégimenter",
    "enrégimentai": "enrégimenter",
    "enrégimentaient": "enrégimenter",
    "enrégimentais": "enrégimenter",
    "enrégimentait": "enrégimenter",
    "enrégimentant": "enrégimenter",
    "enrégimentas": "enrégimenter",
    "enrégimentasse": "enrégimenter",
    "enrégimentassent": "enrégimenter",
    "enrégimentasses": "enrégimenter",
    "enrégimentassiez": "enrégimenter",
    "enrégimentassions": "enrégimenter",
    "enrégimente": "enrégimenter",
    "enrégimentent": "enrégimenter",
    "enrégimentera": "enrégimenter",
    "enrégimenterai": "enrégimenter",
    "enrégimenteraient": "enrégimenter",
    "enrégimenterais": "enrégimenter",
    "enrégimenterait": "enrégimenter",
    "enrégimenteras": "enrégimenter",
    "enrégimenterez": "enrégimenter",
    "enrégimenteriez": "enrégimenter",
    "enrégimenterions": "enrégimenter",
    "enrégimenterons": "enrégimenter",
    "enrégimenteront": "enrégimenter",
    "enrégimentes": "enrégimenter",
    "enrégimentez": "enrégimenter",
    "enrégimentiez": "enrégimenter",
    "enrégimentions": "enrégimenter",
    "enrégimentons": "enrégimenter",
    "enrégimentâmes": "enrégimenter",
    "enrégimentât": "enrégimenter",
    "enrégimentâtes": "enrégimenter",
    "enrégimentèrent": "enrégimenter",
    "enrégimenté": "enrégimenter",
    "enrégimentée": "enrégimenter",
    "enrégimentées": "enrégimenter",
    "enrégimentés": "enrégimenter",
    "enrôla": "enrôler",
    "enrôlai": "enrôler",
    "enrôlaient": "enrôler",
    "enrôlais": "enrôler",
    "enrôlait": "enrôler",
    "enrôlant": "enrôler",
    "enrôlas": "enrôler",
    "enrôlasse": "enrôler",
    "enrôlassent": "enrôler",
    "enrôlasses": "enrôler",
    "enrôlassiez": "enrôler",
    "enrôlassions": "enrôler",
    "enrôle": "enrôler",
    "enrôlements": "enrôlement",
    "enrôlent": "enrôler",
    "enrôlera": "enrôler",
    "enrôlerai": "enrôler",
    "enrôleraient": "enrôler",
    "enrôlerais": "enrôler",
    "enrôlerait": "enrôler",
    "enrôleras": "enrôler",
    "enrôlerez": "enrôler",
    "enrôleriez": "enrôler",
    "enrôlerions": "enrôler",
    "enrôlerons": "enrôler",
    "enrôleront": "enrôler",
    "enrôles": "enrôler",
    "enrôlez": "enrôler",
    "enrôliez": "enrôler",
    "enrôlions": "enrôler",
    "enrôlons": "enrôler",
    "enrôlâmes": "enrôler",
    "enrôlât": "enrôler",
    "enrôlâtes": "enrôler",
    "enrôlèrent": "enrôler",
    "enrôlé": "enrôler",
    "enrôlée": "enrôler",
    "enrôlées": "enrôler",
    "enrôlés": "enrôler",
    "ensabla": "ensabler",
    "ensablai": "ensabler",
    "ensablaient": "ensabler",
    "ensablais": "ensabler",
    "ensablait": "ensabler",
    "ensablant": "ensabler",
    "ensablas": "ensabler",
    "ensablasse": "ensabler",
    "ensablassent": "ensabler",
    "ensablasses": "ensabler",
    "ensablassiez": "ensabler",
    "ensablassions": "ensabler",
    "ensable": "ensabler",
    "ensablent": "ensabler",
    "ensablera": "ensabler",
    "ensablerai": "ensabler",
    "ensableraient": "ensabler",
    "ensablerais": "ensabler",
    "ensablerait": "ensabler",
    "ensableras": "ensabler",
    "ensablerez": "ensabler",
    "ensableriez": "ensabler",
    "ensablerions": "ensabler",
    "ensablerons": "ensabler",
    "ensableront": "ensabler",
    "ensables": "ensabler",
    "ensablez": "ensabler",
    "ensabliez": "ensabler",
    "ensablions": "ensabler",
    "ensablons": "ensabler",
    "ensablâmes": "ensabler",
    "ensablât": "ensabler",
    "ensablâtes": "ensabler",
    "ensablèrent": "ensabler",
    "ensablé": "ensabler",
    "ensablée": "ensabler",
    "ensablées": "ensabler",
    "ensablés": "ensabler",
    "ensacha": "ensacher",
    "ensachai": "ensacher",
    "ensachaient": "ensacher",
    "ensachais": "ensacher",
    "ensachait": "ensacher",
    "ensachant": "ensacher",
    "ensachas": "ensacher",
    "ensachasse": "ensacher",
    "ensachassent": "ensacher",
    "ensachasses": "ensacher",
    "ensachassiez": "ensacher",
    "ensachassions": "ensacher",
    "ensache": "ensacher",
    "ensachent": "ensacher",
    "ensachera": "ensacher",
    "ensacherai": "ensacher",
    "ensacheraient": "ensacher",
    "ensacherais": "ensacher",
    "ensacherait": "ensacher",
    "ensacheras": "ensacher",
    "ensacherez": "ensacher",
    "ensacheriez": "ensacher",
    "ensacherions": "ensacher",
    "ensacherons": "ensacher",
    "ensacheront": "ensacher",
    "ensaches": "ensacher",
    "ensachez": "ensacher",
    "ensachiez": "ensacher",
    "ensachions": "ensacher",
    "ensachons": "ensacher",
    "ensachâmes": "ensacher",
    "ensachât": "ensacher",
    "ensachâtes": "ensacher",
    "ensachèrent": "ensacher",
    "ensaché": "ensacher",
    "ensachée": "ensacher",
    "ensachées": "ensacher",
    "ensachés": "ensacher",
    "ensanglanta": "ensanglanter",
    "ensanglantai": "ensanglanter",
    "ensanglantaient": "ensanglanter",
    "ensanglantais": "ensanglanter",
    "ensanglantait": "ensanglanter",
    "ensanglantant": "ensanglanter",
    "ensanglantas": "ensanglanter",
    "ensanglantasse": "ensanglanter",
    "ensanglantassent": "ensanglanter",
    "ensanglantasses": "ensanglanter",
    "ensanglantassiez": "ensanglanter",
    "ensanglantassions": "ensanglanter",
    "ensanglante": "ensanglanter",
    "ensanglantent": "ensanglanter",
    "ensanglantera": "ensanglanter",
    "ensanglanterai": "ensanglanter",
    "ensanglanteraient": "ensanglanter",
    "ensanglanterais": "ensanglanter",
    "ensanglanterait": "ensanglanter",
    "ensanglanteras": "ensanglanter",
    "ensanglanterez": "ensanglanter",
    "ensanglanteriez": "ensanglanter",
    "ensanglanterions": "ensanglanter",
    "ensanglanterons": "ensanglanter",
    "ensanglanteront": "ensanglanter",
    "ensanglantes": "ensanglanter",
    "ensanglantez": "ensanglanter",
    "ensanglantiez": "ensanglanter",
    "ensanglantions": "ensanglanter",
    "ensanglantons": "ensanglanter",
    "ensanglantâmes": "ensanglanter",
    "ensanglantât": "ensanglanter",
    "ensanglantâtes": "ensanglanter",
    "ensanglantèrent": "ensanglanter",
    "ensanglanté": "ensanglanter",
    "ensanglantée": "ensanglanter",
    "ensanglantées": "ensanglanter",
    "ensanglantés": "ensanglanter",
    "ensauva": "ensauver",
    "ensauvageait": "ensauvager",
    "ensauvagé": "ensauvager",
    "ensauvagée": "ensauvager",
    "ensauvagées": "ensauvager",
    "ensauvagés": "ensauvager",
    "ensauvai": "ensauver",
    "ensauvaient": "ensauver",
    "ensauvais": "ensauver",
    "ensauvait": "ensauver",
    "ensauvant": "ensauver",
    "ensauvas": "ensauver",
    "ensauvasse": "ensauver",
    "ensauvassent": "ensauver",
    "ensauvasses": "ensauver",
    "ensauvassiez": "ensauver",
    "ensauvassions": "ensauver",
    "ensauve": "ensauver",
    "ensauvent": "ensauver",
    "ensauvera": "ensauver",
    "ensauverai": "ensauver",
    "ensauveraient": "ensauver",
    "ensauverais": "ensauver",
    "ensauverait": "ensauver",
    "ensauveras": "ensauver",
    "ensauverez": "ensauver",
    "ensauveriez": "ensauver",
    "ensauverions": "ensauver",
    "ensauverons": "ensauver",
    "ensauveront": "ensauver",
    "ensauves": "ensauver",
    "ensauvez": "ensauver",
    "ensauviez": "ensauver",
    "ensauvions": "ensauver",
    "ensauvons": "ensauver",
    "ensauvâmes": "ensauver",
    "ensauvât": "ensauver",
    "ensauvâtes": "ensauver",
    "ensauvèrent": "ensauver",
    "ensauvé": "ensauver",
    "ensauvée": "ensauver",
    "ensauvées": "ensauver",
    "ensauvés": "ensauver",
    "enseigna": "enseigner",
    "enseignai": "enseigner",
    "enseignaient": "enseigner",
    "enseignais": "enseigner",
    "enseignait": "enseigner",
    "enseignant": "enseigner",
    "enseignante": "enseignant",
    "enseignantes": "enseignant",
    "enseignants": "enseignant",
    "enseignas": "enseigner",
    "enseignasse": "enseigner",
    "enseignassent": "enseigner",
    "enseignasses": "enseigner",
    "enseignassiez": "enseigner",
    "enseignassions": "enseigner",
    "enseigne": "enseigner",
    "enseignements": "enseignement",
    "enseignent": "enseigner",
    "enseignera": "enseigner",
    "enseignerai": "enseigner",
    "enseigneraient": "enseigner",
    "enseignerais": "enseigner",
    "enseignerait": "enseigner",
    "enseigneras": "enseigner",
    "enseignerez": "enseigner",
    "enseigneriez": "enseigner",
    "enseignerions": "enseigner",
    "enseignerons": "enseigner",
    "enseigneront": "enseigner",
    "enseignes": "enseigner",
    "enseignez": "enseigner",
    "enseigniez": "enseigner",
    "enseignions": "enseigner",
    "enseignons": "enseigner",
    "enseignâmes": "enseigner",
    "enseignât": "enseigner",
    "enseignâtes": "enseigner",
    "enseignèrent": "enseigner",
    "enseigné": "enseigner",
    "enseignée": "enseigner",
    "enseignées": "enseigner",
    "enseignés": "enseigner",
    "ensellés": "ensellé",
    "ensembles": "ensemble",
    "ensemence": "ensemencer",
    "ensemencements": "ensemencement",
    "ensemencent": "ensemencer",
    "ensemencera": "ensemencer",
    "ensemencerai": "ensemencer",
    "ensemenceraient": "ensemencer",
    "ensemencerais": "ensemencer",
    "ensemencerait": "ensemencer",
    "ensemenceras": "ensemencer",
    "ensemencerez": "ensemencer",
    "ensemenceriez": "ensemencer",
    "ensemencerions": "ensemencer",
    "ensemencerons": "ensemencer",
    "ensemenceront": "ensemencer",
    "ensemences": "ensemencer",
    "ensemencez": "ensemencer",
    "ensemenciez": "ensemencer",
    "ensemencions": "ensemencer",
    "ensemencèrent": "ensemencer",
    "ensemencé": "ensemencer",
    "ensemencée": "ensemencer",
    "ensemencées": "ensemencer",
    "ensemencés": "ensemencer",
    "ensemença": "ensemencer",
    "ensemençai": "ensemencer",
    "ensemençaient": "ensemencer",
    "ensemençais": "ensemencer",
    "ensemençait": "ensemencer",
    "ensemençant": "ensemencer",
    "ensemenças": "ensemencer",
    "ensemençasse": "ensemencer",
    "ensemençassent": "ensemencer",
    "ensemençasses": "ensemencer",
    "ensemençassiez": "ensemencer",
    "ensemençassions": "ensemencer",
    "ensemençons": "ensemencer",
    "ensemençâmes": "ensemencer",
    "ensemençât": "ensemencer",
    "ensemençâtes": "ensemencer",
    "enserra": "enserrer",
    "enserrai": "enserrer",
    "enserraient": "enserrer",
    "enserrais": "enserrer",
    "enserrait": "enserrer",
    "enserrant": "enserrer",
    "enserras": "enserrer",
    "enserrasse": "enserrer",
    "enserrassent": "enserrer",
    "enserrasses": "enserrer",
    "enserrassiez": "enserrer",
    "enserrassions": "enserrer",
    "enserre": "enserrer",
    "enserrent": "enserrer",
    "enserrera": "enserrer",
    "enserrerai": "enserrer",
    "enserreraient": "enserrer",
    "enserrerais": "enserrer",
    "enserrerait": "enserrer",
    "enserreras": "enserrer",
    "enserrerez": "enserrer",
    "enserreriez": "enserrer",
    "enserrerions": "enserrer",
    "enserrerons": "enserrer",
    "enserreront": "enserrer",
    "enserres": "enserrer",
    "enserrez": "enserrer",
    "enserriez": "enserrer",
    "enserrions": "enserrer",
    "enserrons": "enserrer",
    "enserrâmes": "enserrer",
    "enserrât": "enserrer",
    "enserrâtes": "enserrer",
    "enserrèrent": "enserrer",
    "enserré": "enserrer",
    "enserrée": "enserrer",
    "enserrées": "enserrer",
    "enserrés": "enserrer",
    "enseveli": "ensevelir",
    "ensevelie": "ensevelir",
    "ensevelies": "ensevelir",
    "ensevelira": "ensevelir",
    "ensevelirai": "ensevelir",
    "enseveliraient": "ensevelir",
    "ensevelirais": "ensevelir",
    "ensevelirait": "ensevelir",
    "enseveliras": "ensevelir",
    "ensevelirent": "ensevelir",
    "ensevelirez": "ensevelir",
    "enseveliriez": "ensevelir",
    "ensevelirions": "ensevelir",
    "ensevelirons": "ensevelir",
    "enseveliront": "ensevelir",
    "ensevelis": "ensevelir",
    "ensevelissaient": "ensevelir",
    "ensevelissais": "ensevelir",
    "ensevelissait": "ensevelir",
    "ensevelissant": "ensevelir",
    "ensevelisse": "ensevelir",
    "ensevelissent": "ensevelir",
    "ensevelisses": "ensevelir",
    "ensevelisseuse": "ensevelisseur",
    "ensevelissez": "ensevelir",
    "ensevelissiez": "ensevelir",
    "ensevelissions": "ensevelir",
    "ensevelissons": "ensevelir",
    "ensevelit": "ensevelir",
    "ensevelîmes": "ensevelir",
    "ensevelît": "ensevelir",
    "ensevelîtes": "ensevelir",
    "ensilée": "ensilé",
    "ensilées": "ensilé",
    "ensilés": "ensilé",
    "ensoleilla": "ensoleiller",
    "ensoleillai": "ensoleiller",
    "ensoleillaient": "ensoleiller",
    "ensoleillais": "ensoleiller",
    "ensoleillait": "ensoleiller",
    "ensoleillant": "ensoleiller",
    "ensoleillas": "ensoleiller",
    "ensoleillasse": "ensoleiller",
    "ensoleillassent": "ensoleiller",
    "ensoleillasses": "ensoleiller",
    "ensoleillassiez": "ensoleiller",
    "ensoleillassions": "ensoleiller",
    "ensoleille": "ensoleiller",
    "ensoleillements": "ensoleillement",
    "ensoleillent": "ensoleiller",
    "ensoleillera": "ensoleiller",
    "ensoleillerai": "ensoleiller",
    "ensoleilleraient": "ensoleiller",
    "ensoleillerais": "ensoleiller",
    "ensoleillerait": "ensoleiller",
    "ensoleilleras": "ensoleiller",
    "ensoleillerez": "ensoleiller",
    "ensoleilleriez": "ensoleiller",
    "ensoleillerions": "ensoleiller",
    "ensoleillerons": "ensoleiller",
    "ensoleilleront": "ensoleiller",
    "ensoleilles": "ensoleiller",
    "ensoleillez": "ensoleiller",
    "ensoleilliez": "ensoleiller",
    "ensoleillions": "ensoleiller",
    "ensoleillons": "ensoleiller",
    "ensoleillâmes": "ensoleiller",
    "ensoleillât": "ensoleiller",
    "ensoleillâtes": "ensoleiller",
    "ensoleillèrent": "ensoleiller",
    "ensoleillé": "ensoleiller",
    "ensoleillée": "ensoleiller",
    "ensoleillées": "ensoleiller",
    "ensoleillés": "ensoleiller",
    "ensommeilla": "ensommeiller",
    "ensommeillaient": "ensommeiller",
    "ensommeillait": "ensommeiller",
    "ensommeillé": "ensommeiller",
    "ensommeillée": "ensommeiller",
    "ensommeillées": "ensommeiller",
    "ensommeillés": "ensommeillé",
    "ensorcela": "ensorceler",
    "ensorcelai": "ensorceler",
    "ensorcelaient": "ensorceler",
    "ensorcelais": "ensorceler",
    "ensorcelait": "ensorceler",
    "ensorcelant": "ensorceler",
    "ensorcelante": "ensorcelant",
    "ensorcelantes": "ensorcelant",
    "ensorcelas": "ensorceler",
    "ensorcelasse": "ensorceler",
    "ensorcelassent": "ensorceler",
    "ensorcelasses": "ensorceler",
    "ensorcelassiez": "ensorceler",
    "ensorcelassions": "ensorceler",
    "ensorceleuse": "ensorceleur",
    "ensorceleuses": "ensorceleur",
    "ensorcelez": "ensorceler",
    "ensorceliez": "ensorceler",
    "ensorcelions": "ensorceler",
    "ensorcelle": "ensorceler",
    "ensorcellent": "ensorceler",
    "ensorcellera": "ensorceler",
    "ensorcellerai": "ensorceler",
    "ensorcelleraient": "ensorceler",
    "ensorcellerais": "ensorceler",
    "ensorcellerait": "ensorceler",
    "ensorcelleras": "ensorceler",
    "ensorcellerez": "ensorceler",
    "ensorcelleriez": "ensorceler",
    "ensorcellerions": "ensorceler",
    "ensorcellerons": "ensorceler",
    "ensorcelleront": "ensorceler",
    "ensorcelles": "ensorceler",
    "ensorcelons": "ensorceler",
    "ensorcelâmes": "ensorceler",
    "ensorcelât": "ensorceler",
    "ensorcelâtes": "ensorceler",
    "ensorcelèrent": "ensorceler",
    "ensorcelé": "ensorceler",
    "ensorcelée": "ensorceler",
    "ensorcelées": "ensorceler",
    "ensorcelés": "ensorceler",
    "ensoutanée": "ensoutané",
    "ensoutanées": "ensoutaner",
    "ensuit": "ensuivre",
    "ensuivaient": "ensuivre",
    "ensuivait": "ensuivre",
    "ensuivant": "ensuivre",
    "ensuive": "ensuivre",
    "ensuivent": "ensuivre",
    "ensuivi": "ensuivre",
    "ensuivie": "ensuivre",
    "ensuivies": "ensuivre",
    "ensuivirent": "ensuivre",
    "ensuivis": "ensuivre",
    "ensuivissent": "ensuivre",
    "ensuivit": "ensuivre",
    "ensuivra": "ensuivre",
    "ensuivraient": "ensuivre",
    "ensuivrait": "ensuivre",
    "ensuivront": "ensuivre",
    "ensuivît": "ensuivre",
    "ensuquent": "ensuquer",
    "ensuqué": "ensuquer",
    "ensuquée": "ensuquer",
    "enta": "enter",
    "entabla": "entabler",
    "entablai": "entabler",
    "entablaient": "entabler",
    "entablais": "entabler",
    "entablait": "entabler",
    "entablant": "entabler",
    "entablas": "entabler",
    "entablasse": "entabler",
    "entablassent": "entabler",
    "entablasses": "entabler",
    "entablassiez": "entabler",
    "entablassions": "entabler",
    "entable": "entabler",
    "entablements": "entablement",
    "entablent": "entabler",
    "entablera": "entabler",
    "entablerai": "entabler",
    "entableraient": "entabler",
    "entablerais": "entabler",
    "entablerait": "entabler",
    "entableras": "entabler",
    "entablerez": "entabler",
    "entableriez": "entabler",
    "entablerions": "entabler",
    "entablerons": "entabler",
    "entableront": "entabler",
    "entables": "entabler",
    "entablez": "entabler",
    "entabliez": "entabler",
    "entablions": "entabler",
    "entablons": "entabler",
    "entablâmes": "entabler",
    "entablât": "entabler",
    "entablâtes": "entabler",
    "entablèrent": "entabler",
    "entablé": "entabler",
    "entablée": "entabler",
    "entablées": "entabler",
    "entablés": "entabler",
    "entacha": "entacher",
    "entachai": "entacher",
    "entachaient": "entacher",
    "entachais": "entacher",
    "entachait": "entacher",
    "entachant": "entacher",
    "entachas": "entacher",
    "entachasse": "entacher",
    "entachassent": "entacher",
    "entachasses": "entacher",
    "entachassiez": "entacher",
    "entachassions": "entacher",
    "entache": "entacher",
    "entachent": "entacher",
    "entachera": "entacher",
    "entacherai": "entacher",
    "entacheraient": "entacher",
    "entacherais": "entacher",
    "entacherait": "entacher",
    "entacheras": "entacher",
    "entacherez": "entacher",
    "entacheriez": "entacher",
    "entacherions": "entacher",
    "entacherons": "entacher",
    "entacheront": "entacher",
    "entaches": "entacher",
    "entachez": "entacher",
    "entachiez": "entacher",
    "entachions": "entacher",
    "entachons": "entacher",
    "entachâmes": "entacher",
    "entachât": "entacher",
    "entachâtes": "entacher",
    "entachèrent": "entacher",
    "entaché": "entacher",
    "entachée": "entacher",
    "entachées": "entacher",
    "entachés": "entacher",
    "entai": "enter",
    "entaient": "enter",
    "entailla": "entailler",
    "entaillai": "entailler",
    "entaillaient": "entailler",
    "entaillais": "entailler",
    "entaillait": "entailler",
    "entaillant": "entailler",
    "entaillas": "entailler",
    "entaillasse": "entailler",
    "entaillassent": "entailler",
    "entaillasses": "entailler",
    "entaillassiez": "entailler",
    "entaillassions": "entailler",
    "entaille": "entailler",
    "entaillent": "entailler",
    "entaillera": "entailler",
    "entaillerai": "entailler",
    "entailleraient": "entailler",
    "entaillerais": "entailler",
    "entaillerait": "entailler",
    "entailleras": "entailler",
    "entaillerez": "entailler",
    "entailleriez": "entailler",
    "entaillerions": "entailler",
    "entaillerons": "entailler",
    "entailleront": "entailler",
    "entailles": "entailler",
    "entaillez": "entailler",
    "entailliez": "entailler",
    "entaillions": "entailler",
    "entaillons": "entailler",
    "entaillâmes": "entailler",
    "entaillât": "entailler",
    "entaillâtes": "entailler",
    "entaillèrent": "entailler",
    "entaillé": "entailler",
    "entaillée": "entailler",
    "entaillées": "entailler",
    "entaillés": "entailler",
    "entais": "enter",
    "entait": "enter",
    "entama": "entamer",
    "entamai": "entamer",
    "entamaient": "entamer",
    "entamais": "entamer",
    "entamait": "entamer",
    "entamant": "entamer",
    "entamas": "entamer",
    "entamasse": "entamer",
    "entamassent": "entamer",
    "entamasses": "entamer",
    "entamassiez": "entamer",
    "entamassions": "entamer",
    "entame": "entamer",
    "entament": "entamer",
    "entamera": "entamer",
    "entamerai": "entamer",
    "entameraient": "entamer",
    "entamerais": "entamer",
    "entamerait": "entamer",
    "entameras": "entamer",
    "entamerez": "entamer",
    "entameriez": "entamer",
    "entamerions": "entamer",
    "entamerons": "entamer",
    "entameront": "entamer",
    "entames": "entamer",
    "entamez": "entamer",
    "entamiez": "entamer",
    "entamions": "entamer",
    "entamons": "entamer",
    "entamâmes": "entamer",
    "entamât": "entamer",
    "entamâtes": "entamer",
    "entamèrent": "entamer",
    "entamé": "entamer",
    "entamée": "entamer",
    "entamées": "entamer",
    "entamés": "entamer",
    "entant": "enter",
    "entartra": "entartrer",
    "entartrai": "entartrer",
    "entartraient": "entartrer",
    "entartrais": "entartrer",
    "entartrait": "entartrer",
    "entartrant": "entartrer",
    "entartras": "entartrer",
    "entartrasse": "entartrer",
    "entartrassent": "entartrer",
    "entartrasses": "entartrer",
    "entartrassiez": "entartrer",
    "entartrassions": "entartrer",
    "entartre": "entartrer",
    "entartrent": "entartrer",
    "entartrera": "entartrer",
    "entartrerai": "entartrer",
    "entartreraient": "entartrer",
    "entartrerais": "entartrer",
    "entartrerait": "entartrer",
    "entartreras": "entartrer",
    "entartrerez": "entartrer",
    "entartreriez": "entartrer",
    "entartrerions": "entartrer",
    "entartrerons": "entartrer",
    "entartreront": "entartrer",
    "entartres": "entartrer",
    "entartrez": "entartrer",
    "entartriez": "entartrer",
    "entartrions": "entartrer",
    "entartrons": "entartrer",
    "entartrâmes": "entartrer",
    "entartrât": "entartrer",
    "entartrâtes": "entartrer",
    "entartrèrent": "entartrer",
    "entartré": "entartrer",
    "entartrée": "entartrer",
    "entartrées": "entartrer",
    "entartrés": "entartrer",
    "entas": "enter",
    "entassa": "entasser",
    "entassai": "entasser",
    "entassaient": "entasser",
    "entassais": "entasser",
    "entassait": "entasser",
    "entassant": "entasser",
    "entassas": "entasser",
    "entassasse": "entasser",
    "entassassent": "entasser",
    "entassasses": "entasser",
    "entassassiez": "entasser",
    "entassassions": "entasser",
    "entasse": "enter",
    "entassements": "entassement",
    "entassent": "enter",
    "entassera": "entasser",
    "entasserai": "entasser",
    "entasseraient": "entasser",
    "entasserais": "entasser",
    "entasserait": "entasser",
    "entasseras": "entasser",
    "entasserez": "entasser",
    "entasseriez": "entasser",
    "entasserions": "entasser",
    "entasserons": "entasser",
    "entasseront": "entasser",
    "entasses": "enter",
    "entassez": "entasser",
    "entassiez": "enter",
    "entassions": "enter",
    "entassons": "entasser",
    "entassâmes": "entasser",
    "entassât": "entasser",
    "entassâtes": "entasser",
    "entassèrent": "entasser",
    "entassé": "entasser",
    "entassée": "entasser",
    "entassées": "entasser",
    "entassés": "entasser",
    "ente": "enter",
    "entend": "entendre",
    "entendaient": "entendre",
    "entendais": "entendre",
    "entendait": "entendre",
    "entendant": "entendre",
    "entendante": "entendant",
    "entendantes": "entendant",
    "entendants": "entendant",
    "entende": "entendre",
    "entendements": "entendement",
    "entendent": "entendre",
    "entendes": "entendre",
    "entendeurs": "entendeur",
    "entendez": "entendre",
    "entendiez": "entendre",
    "entendions": "entendre",
    "entendirent": "entendre",
    "entendis": "entendre",
    "entendisse": "entendre",
    "entendissent": "entendre",
    "entendisses": "entendre",
    "entendissiez": "entendre",
    "entendissions": "entendre",
    "entendit": "entendre",
    "entendons": "entendre",
    "entendra": "entendre",
    "entendrai": "entendre",
    "entendraient": "entendre",
    "entendrais": "entendre",
    "entendrait": "entendre",
    "entendras": "entendre",
    "entendrez": "entendre",
    "entendriez": "entendre",
    "entendrions": "entendre",
    "entendrons": "entendre",
    "entendront": "entendre",
    "entends": "entendre",
    "entendu": "entendre",
    "entendue": "entendu",
    "entendues": "entendu",
    "entendus": "entendu",
    "entendîmes": "entendre",
    "entendît": "entendre",
    "entendîtes": "entendre",
    "entent": "enter",
    "ententes": "entente",
    "entera": "enter",
    "enterai": "enter",
    "enteraient": "enter",
    "enterais": "enter",
    "enterait": "enter",
    "enteras": "enter",
    "enterez": "enter",
    "enteriez": "enter",
    "enterions": "enter",
    "enterons": "enter",
    "enteront": "enter",
    "enterra": "enterrer",
    "enterrai": "enterrer",
    "enterraient": "enterrer",
    "enterrais": "enterrer",
    "enterrait": "enterrer",
    "enterrant": "enterrer",
    "enterras": "enterrer",
    "enterrasse": "enterrer",
    "enterrassent": "enterrer",
    "enterrasses": "enterrer",
    "enterrassiez": "enterrer",
    "enterrassions": "enterrer",
    "enterre": "enterrer",
    "enterrements": "enterrement",
    "enterrent": "enterrer",
    "enterrera": "enterrer",
    "enterrerai": "enterrer",
    "enterreraient": "enterrer",
    "enterrerais": "enterrer",
    "enterrerait": "enterrer",
    "enterreras": "enterrer",
    "enterrerez": "enterrer",
    "enterreriez": "enterrer",
    "enterrerions": "enterrer",
    "enterrerons": "enterrer",
    "enterreront": "enterrer",
    "enterres": "enterrer",
    "enterrez": "enterrer",
    "enterriez": "enterrer",
    "enterrions": "enterrer",
    "enterrons": "enterrer",
    "enterrâmes": "enterrer",
    "enterrât": "enterrer",
    "enterrâtes": "enterrer",
    "enterrèrent": "enterrer",
    "enterré": "enterrer",
    "enterrée": "enterrer",
    "enterrées": "enterrer",
    "enterrés": "enterrer",
    "entes": "enter",
    "entez": "enter",
    "enthousiasma": "enthousiasmer",
    "enthousiasmai": "enthousiasmer",
    "enthousiasmaient": "enthousiasmer",
    "enthousiasmais": "enthousiasmer",
    "enthousiasmait": "enthousiasmer",
    "enthousiasmant": "enthousiasmer",
    "enthousiasmante": "enthousiasmant",
    "enthousiasmantes": "enthousiasmant",
    "enthousiasmants": "enthousiasmant",
    "enthousiasmas": "enthousiasmer",
    "enthousiasmasse": "enthousiasmer",
    "enthousiasmassent": "enthousiasmer",
    "enthousiasmasses": "enthousiasmer",
    "enthousiasmassiez": "enthousiasmer",
    "enthousiasmassions": "enthousiasmer",
    "enthousiasme": "enthousiasmer",
    "enthousiasment": "enthousiasmer",
    "enthousiasmera": "enthousiasmer",
    "enthousiasmerai": "enthousiasmer",
    "enthousiasmeraient": "enthousiasmer",
    "enthousiasmerais": "enthousiasmer",
    "enthousiasmerait": "enthousiasmer",
    "enthousiasmeras": "enthousiasmer",
    "enthousiasmerez": "enthousiasmer",
    "enthousiasmeriez": "enthousiasmer",
    "enthousiasmerions": "enthousiasmer",
    "enthousiasmerons": "enthousiasmer",
    "enthousiasmeront": "enthousiasmer",
    "enthousiasmes": "enthousiasmer",
    "enthousiasmez": "enthousiasmer",
    "enthousiasmiez": "enthousiasmer",
    "enthousiasmions": "enthousiasmer",
    "enthousiasmons": "enthousiasmer",
    "enthousiasmâmes": "enthousiasmer",
    "enthousiasmât": "enthousiasmer",
    "enthousiasmâtes": "enthousiasmer",
    "enthousiasmèrent": "enthousiasmer",
    "enthousiasmé": "enthousiasmer",
    "enthousiasmée": "enthousiasmer",
    "enthousiasmées": "enthousiasmer",
    "enthousiasmés": "enthousiasmer",
    "enthousiastes": "enthousiaste",
    "enticha": "enticher",
    "entichai": "enticher",
    "entichaient": "enticher",
    "entichais": "enticher",
    "entichait": "enticher",
    "entichant": "enticher",
    "entichas": "enticher",
    "entichasse": "enticher",
    "entichassent": "enticher",
    "entichasses": "enticher",
    "entichassiez": "enticher",
    "entichassions": "enticher",
    "entiche": "enticher",
    "entichent": "enticher",
    "entichera": "enticher",
    "enticherai": "enticher",
    "enticheraient": "enticher",
    "enticherais": "enticher",
    "enticherait": "enticher",
    "enticheras": "enticher",
    "enticherez": "enticher",
    "enticheriez": "enticher",
    "enticherions": "enticher",
    "enticherons": "enticher",
    "enticheront": "enticher",
    "entiches": "enticher",
    "entichez": "enticher",
    "entichiez": "enticher",
    "entichions": "enticher",
    "entichons": "enticher",
    "entichâmes": "enticher",
    "entichât": "enticher",
    "entichâtes": "enticher",
    "entichèrent": "enticher",
    "entiché": "enticher",
    "entichée": "enticher",
    "entichées": "enticher",
    "entichés": "enticher",
    "entiers": "entier",
    "entiez": "enter",
    "entiflé": "entifler",
    "entions": "enter",
    "entités": "entité",
    "entière": "entier",
    "entières": "entier",
    "entièretés": "entièreté",
    "entoila": "entoiler",
    "entoilai": "entoiler",
    "entoilaient": "entoiler",
    "entoilais": "entoiler",
    "entoilait": "entoiler",
    "entoilant": "entoiler",
    "entoilas": "entoiler",
    "entoilasse": "entoiler",
    "entoilassent": "entoiler",
    "entoilasses": "entoiler",
    "entoilassiez": "entoiler",
    "entoilassions": "entoiler",
    "entoile": "entoiler",
    "entoilent": "entoiler",
    "entoilera": "entoiler",
    "entoilerai": "entoiler",
    "entoileraient": "entoiler",
    "entoilerais": "entoiler",
    "entoilerait": "entoiler",
    "entoileras": "entoiler",
    "entoilerez": "entoiler",
    "entoileriez": "entoiler",
    "entoilerions": "entoiler",
    "entoilerons": "entoiler",
    "entoileront": "entoiler",
    "entoiles": "entoiler",
    "entoilez": "entoiler",
    "entoiliez": "entoiler",
    "entoilions": "entoiler",
    "entoilons": "entoiler",
    "entoilâmes": "entoiler",
    "entoilât": "entoiler",
    "entoilâtes": "entoiler",
    "entoilèrent": "entoiler",
    "entoilé": "entoiler",
    "entoilée": "entoiler",
    "entoilées": "entoiler",
    "entoilés": "entoiler",
    "entolomes": "entolome",
    "entomologies": "entomologie",
    "entomologiques": "entomologique",
    "entomologistes": "entomologiste",
    "entonna": "entonner",
    "entonnai": "entonner",
    "entonnaient": "entonner",
    "entonnais": "entonner",
    "entonnait": "entonner",
    "entonnant": "entonner",
    "entonnas": "entonner",
    "entonnasse": "entonner",
    "entonnassent": "entonner",
    "entonnasses": "entonner",
    "entonnassiez": "entonner",
    "entonnassions": "entonner",
    "entonne": "entonner",
    "entonnent": "entonner",
    "entonnera": "entonner",
    "entonnerai": "entonner",
    "entonneraient": "entonner",
    "entonnerais": "entonner",
    "entonnerait": "entonner",
    "entonneras": "entonner",
    "entonnerez": "entonner",
    "entonneriez": "entonner",
    "entonnerions": "entonner",
    "entonnerons": "entonner",
    "entonneront": "entonner",
    "entonnes": "entonner",
    "entonnez": "entonner",
    "entonniez": "entonner",
    "entonnions": "entonner",
    "entonnoirs": "entonnoir",
    "entonnons": "entonner",
    "entonnâmes": "entonner",
    "entonnât": "entonner",
    "entonnâtes": "entonner",
    "entonnèrent": "entonner",
    "entonné": "entonner",
    "entonnée": "entonner",
    "entonnées": "entonner",
    "entonnés": "entonner",
    "entons": "enter",
    "entorses": "entorse",
    "entortilla": "entortiller",
    "entortillages": "entortillage",
    "entortillai": "entortiller",
    "entortillaient": "entortiller",
    "entortillais": "entortiller",
    "entortillait": "entortiller",
    "entortillant": "entortiller",
    "entortillas": "entortiller",
    "entortillasse": "entortiller",
    "entortillassent": "entortiller",
    "entortillasses": "entortiller",
    "entortillassiez": "entortiller",
    "entortillassions": "entortiller",
    "entortille": "entortiller",
    "entortillent": "entortiller",
    "entortillera": "entortiller",
    "entortillerai": "entortiller",
    "entortilleraient": "entortiller",
    "entortillerais": "entortiller",
    "entortillerait": "entortiller",
    "entortilleras": "entortiller",
    "entortillerez": "entortiller",
    "entortilleriez": "entortiller",
    "entortillerions": "entortiller",
    "entortillerons": "entortiller",
    "entortilleront": "entortiller",
    "entortilles": "entortiller",
    "entortillez": "entortiller",
    "entortilliez": "entortiller",
    "entortillions": "entortiller",
    "entortillons": "entortiller",
    "entortillâmes": "entortiller",
    "entortillât": "entortiller",
    "entortillâtes": "entortiller",
    "entortillèrent": "entortiller",
    "entortillé": "entortiller",
    "entortillée": "entortiller",
    "entortillées": "entortiller",
    "entortillés": "entortiller",
    "entoura": "entourer",
    "entourages": "entourage",
    "entourai": "entourer",
    "entouraient": "entourer",
    "entourais": "entourer",
    "entourait": "entourer",
    "entourant": "entourer",
    "entouras": "entourer",
    "entourasse": "entourer",
    "entourassent": "entourer",
    "entourasses": "entourer",
    "entourassiez": "entourer",
    "entourassions": "entourer",
    "entoure": "entourer",
    "entourent": "entourer",
    "entourera": "entourer",
    "entourerai": "entourer",
    "entoureraient": "entourer",
    "entourerais": "entourer",
    "entourerait": "entourer",
    "entoureras": "entourer",
    "entourerez": "entourer",
    "entoureriez": "entourer",
    "entourerions": "entourer",
    "entourerons": "entourer",
    "entoureront": "entourer",
    "entoures": "entourer",
    "entourez": "entourer",
    "entouriez": "entourer",
    "entourions": "entourer",
    "entourloupent": "entourlouper",
    "entourloupes": "entourloupe",
    "entourloupettes": "entourloupette",
    "entournures": "entournure",
    "entourons": "entourer",
    "entours": "entour",
    "entourâmes": "entourer",
    "entourât": "entourer",
    "entourâtes": "entourer",
    "entourèrent": "entourer",
    "entouré": "entourer",
    "entourée": "entourer",
    "entourées": "entourer",
    "entourés": "entourer",
    "entr'actes": "entr'acte",
    "entr'aima": "entr'aimer",
    "entr'aimai": "entr'aimer",
    "entr'aimaient": "entr'aimer",
    "entr'aimais": "entr'aimer",
    "entr'aimait": "entr'aimer",
    "entr'aimant": "entr'aimer",
    "entr'aimas": "entr'aimer",
    "entr'aimasse": "entr'aimer",
    "entr'aimassent": "entr'aimer",
    "entr'aimasses": "entr'aimer",
    "entr'aimassiez": "entr'aimer",
    "entr'aimassions": "entr'aimer",
    "entr'aime": "entr'aimer",
    "entr'aiment": "entr'aimer",
    "entr'aimera": "entr'aimer",
    "entr'aimerai": "entr'aimer",
    "entr'aimeraient": "entr'aimer",
    "entr'aimerais": "entr'aimer",
    "entr'aimerait": "entr'aimer",
    "entr'aimeras": "entr'aimer",
    "entr'aimerez": "entr'aimer",
    "entr'aimeriez": "entr'aimer",
    "entr'aimerions": "entr'aimer",
    "entr'aimerons": "entr'aimer",
    "entr'aimeront": "entr'aimer",
    "entr'aimes": "entr'aimer",
    "entr'aimez": "entr'aimer",
    "entr'aimiez": "entr'aimer",
    "entr'aimions": "entr'aimer",
    "entr'aimons": "entr'aimer",
    "entr'aimâmes": "entr'aimer",
    "entr'aimât": "entr'aimer",
    "entr'aimâtes": "entr'aimer",
    "entr'aimèrent": "entr'aimer",
    "entr'aimé": "entr'aimer",
    "entr'aimée": "entr'aimer",
    "entr'aimées": "entr'aimer",
    "entr'aimés": "entr'aimer",
    "entr'apercevaient": "entr'apercevoir",
    "entr'apercevais": "entr'apercevoir",
    "entr'apercevait": "entr'apercevoir",
    "entr'apercevant": "entr'apercevoir",
    "entr'apercevez": "entr'apercevoir",
    "entr'aperceviez": "entr'apercevoir",
    "entr'apercevions": "entr'apercevoir",
    "entr'apercevons": "entr'apercevoir",
    "entr'apercevra": "entr'apercevoir",
    "entr'apercevrai": "entr'apercevoir",
    "entr'apercevraient": "entr'apercevoir",
    "entr'apercevrais": "entr'apercevoir",
    "entr'apercevrait": "entr'apercevoir",
    "entr'apercevras": "entr'apercevoir",
    "entr'apercevrez": "entr'apercevoir",
    "entr'apercevriez": "entr'apercevoir",
    "entr'apercevrions": "entr'apercevoir",
    "entr'apercevrons": "entr'apercevoir",
    "entr'apercevront": "entr'apercevoir",
    "entr'aperçois": "entr'apercevoir",
    "entr'aperçoit": "entr'apercevoir",
    "entr'aperçoive": "entr'apercevoir",
    "entr'aperçoivent": "entr'apercevoir",
    "entr'aperçoives": "entr'apercevoir",
    "entr'aperçu": "entr'apercevoir",
    "entr'aperçue": "entr'apercevoir",
    "entr'aperçues": "entr'apercevoir",
    "entr'aperçurent": "entr'apercevoir",
    "entr'aperçus": "entr'apercevoir",
    "entr'aperçusse": "entr'apercevoir",
    "entr'aperçussent": "entr'apercevoir",
    "entr'aperçusses": "entr'apercevoir",
    "entr'aperçussiez": "entr'apercevoir",
    "entr'aperçussions": "entr'apercevoir",
    "entr'aperçut": "entr'apercevoir",
    "entr'aperçûmes": "entr'apercevoir",
    "entr'aperçût": "entr'apercevoir",
    "entr'aperçûtes": "entr'apercevoir",
    "entr'appellent": "entr'appeler",
    "entr'averti": "entr'avertir",
    "entr'avertie": "entr'avertir",
    "entr'averties": "entr'avertir",
    "entr'avertira": "entr'avertir",
    "entr'avertirai": "entr'avertir",
    "entr'avertiraient": "entr'avertir",
    "entr'avertirais": "entr'avertir",
    "entr'avertirait": "entr'avertir",
    "entr'avertiras": "entr'avertir",
    "entr'avertirent": "entr'avertir",
    "entr'avertirez": "entr'avertir",
    "entr'avertiriez": "entr'avertir",
    "entr'avertirions": "entr'avertir",
    "entr'avertirons": "entr'avertir",
    "entr'avertiront": "entr'avertir",
    "entr'avertis": "entr'avertir",
    "entr'avertissaient": "entr'avertir",
    "entr'avertissais": "entr'avertir",
    "entr'avertissait": "entr'avertir",
    "entr'avertissant": "entr'avertir",
    "entr'avertisse": "entr'avertir",
    "entr'avertissent": "entr'avertir",
    "entr'avertisses": "entr'avertir",
    "entr'avertissez": "entr'avertir",
    "entr'avertissiez": "entr'avertir",
    "entr'avertissions": "entr'avertir",
    "entr'avertissons": "entr'avertir",
    "entr'avertit": "entr'avertir",
    "entr'avertîmes": "entr'avertir",
    "entr'avertît": "entr'avertir",
    "entr'avertîtes": "entr'avertir",
    "entr'ouverte": "entr'ouvert",
    "entr'ouvertes": "entr'ouvert",
    "entr'ouverts": "entr'ouvert",
    "entr'égorge": "entr'égorger",
    "entr'égorgea": "entr'égorger",
    "entr'égorgeai": "entr'égorger",
    "entr'égorgeaient": "entr'égorger",
    "entr'égorgeais": "entr'égorger",
    "entr'égorgeait": "entr'égorger",
    "entr'égorgeant": "entr'égorger",
    "entr'égorgeas": "entr'égorger",
    "entr'égorgeasse": "entr'égorger",
    "entr'égorgeassent": "entr'égorger",
    "entr'égorgeasses": "entr'égorger",
    "entr'égorgeassiez": "entr'égorger",
    "entr'égorgeassions": "entr'égorger",
    "entr'égorgent": "entr'égorger",
    "entr'égorgeons": "entr'égorger",
    "entr'égorgera": "entr'égorger",
    "entr'égorgerai": "entr'égorger",
    "entr'égorgeraient": "entr'égorger",
    "entr'égorgerais": "entr'égorger",
    "entr'égorgerait": "entr'égorger",
    "entr'égorgeras": "entr'égorger",
    "entr'égorgerez": "entr'égorger",
    "entr'égorgeriez": "entr'égorger",
    "entr'égorgerions": "entr'égorger",
    "entr'égorgerons": "entr'égorger",
    "entr'égorgeront": "entr'égorger",
    "entr'égorges": "entr'égorger",
    "entr'égorgez": "entr'égorger",
    "entr'égorgeâmes": "entr'égorger",
    "entr'égorgeât": "entr'égorger",
    "entr'égorgeâtes": "entr'égorger",
    "entr'égorgiez": "entr'égorger",
    "entr'égorgions": "entr'égorger",
    "entr'égorgèrent": "entr'égorger",
    "entr'égorgé": "entr'égorger",
    "entr'égorgée": "entr'égorger",
    "entr'égorgées": "entr'égorger",
    "entr'égorgés": "entr'égorger",
    "entra": "entrer",
    "entraccorda": "entraccorder",
    "entraccordai": "entraccorder",
    "entraccordaient": "entraccorder",
    "entraccordais": "entraccorder",
    "entraccordait": "entraccorder",
    "entraccordant": "entraccorder",
    "entraccordas": "entraccorder",
    "entraccordasse": "entraccorder",
    "entraccordassent": "entraccorder",
    "entraccordasses": "entraccorder",
    "entraccordassiez": "entraccorder",
    "entraccordassions": "entraccorder",
    "entraccorde": "entraccorder",
    "entraccordent": "entraccorder",
    "entraccordera": "entraccorder",
    "entraccorderai": "entraccorder",
    "entraccorderaient": "entraccorder",
    "entraccorderais": "entraccorder",
    "entraccorderait": "entraccorder",
    "entraccorderas": "entraccorder",
    "entraccorderez": "entraccorder",
    "entraccorderiez": "entraccorder",
    "entraccorderions": "entraccorder",
    "entraccorderons": "entraccorder",
    "entraccorderont": "entraccorder",
    "entraccordes": "entraccorder",
    "entraccordez": "entraccorder",
    "entraccordiez": "entraccorder",
    "entraccordions": "entraccorder",
    "entraccordons": "entraccorder",
    "entraccordâmes": "entraccorder",
    "entraccordât": "entraccorder",
    "entraccordâtes": "entraccorder",
    "entraccordèrent": "entraccorder",
    "entraccordé": "entraccorder",
    "entraccordée": "entraccorder",
    "entraccordées": "entraccorder",
    "entraccordés": "entraccorder",
    "entraccusa": "entraccuser",
    "entraccusai": "entraccuser",
    "entraccusaient": "entraccuser",
    "entraccusais": "entraccuser",
    "entraccusait": "entraccuser",
    "entraccusant": "entraccuser",
    "entraccusas": "entraccuser",
    "entraccusasse": "entraccuser",
    "entraccusassent": "entraccuser",
    "entraccusasses": "entraccuser",
    "entraccusassiez": "entraccuser",
    "entraccusassions": "entraccuser",
    "entraccuse": "entraccuser",
    "entraccusent": "entraccuser",
    "entraccusera": "entraccuser",
    "entraccuserai": "entraccuser",
    "entraccuseraient": "entraccuser",
    "entraccuserais": "entraccuser",
    "entraccuserait": "entraccuser",
    "entraccuseras": "entraccuser",
    "entraccuserez": "entraccuser",
    "entraccuseriez": "entraccuser",
    "entraccuserions": "entraccuser",
    "entraccuserons": "entraccuser",
    "entraccuseront": "entraccuser",
    "entraccuses": "entraccuser",
    "entraccusez": "entraccuser",
    "entraccusiez": "entraccuser",
    "entraccusions": "entraccuser",
    "entraccusons": "entraccuser",
    "entraccusâmes": "entraccuser",
    "entraccusât": "entraccuser",
    "entraccusâtes": "entraccuser",
    "entraccusèrent": "entraccuser",
    "entraccusé": "entraccuser",
    "entraccusée": "entraccuser",
    "entraccusées": "entraccuser",
    "entraccusés": "entraccuser",
    "entractes": "entracte",
    "entradmira": "entradmirer",
    "entradmirai": "entradmirer",
    "entradmiraient": "entradmirer",
    "entradmirais": "entradmirer",
    "entradmirait": "entradmirer",
    "entradmirant": "entradmirer",
    "entradmiras": "entradmirer",
    "entradmirasse": "entradmirer",
    "entradmirassent": "entradmirer",
    "entradmirasses": "entradmirer",
    "entradmirassiez": "entradmirer",
    "entradmirassions": "entradmirer",
    "entradmire": "entradmirer",
    "entradmirent": "entradmirer",
    "entradmirera": "entradmirer",
    "entradmirerai": "entradmirer",
    "entradmireraient": "entradmirer",
    "entradmirerais": "entradmirer",
    "entradmirerait": "entradmirer",
    "entradmireras": "entradmirer",
    "entradmirerez": "entradmirer",
    "entradmireriez": "entradmirer",
    "entradmirerions": "entradmirer",
    "entradmirerons": "entradmirer",
    "entradmireront": "entradmirer",
    "entradmires": "entradmirer",
    "entradmirez": "entradmirer",
    "entradmiriez": "entradmirer",
    "entradmirions": "entradmirer",
    "entradmirons": "entradmirer",
    "entradmirâmes": "entradmirer",
    "entradmirât": "entradmirer",
    "entradmirâtes": "entradmirer",
    "entradmirèrent": "entradmirer",
    "entradmiré": "entradmirer",
    "entradmirée": "entradmirer",
    "entradmirées": "entradmirer",
    "entradmirés": "entradmirer",
    "entrai": "entrer",
    "entraida": "entraider",
    "entraidai": "entraider",
    "entraidaient": "entraider",
    "entraidais": "entraider",
    "entraidait": "entraider",
    "entraidant": "entraider",
    "entraidas": "entraider",
    "entraidasse": "entraider",
    "entraidassent": "entraider",
    "entraidasses": "entraider",
    "entraidassiez": "entraider",
    "entraidassions": "entraider",
    "entraide": "entraider",
    "entraident": "entraider",
    "entraidera": "entraider",
    "entraiderai": "entraider",
    "entraideraient": "entraider",
    "entraiderais": "entraider",
    "entraiderait": "entraider",
    "entraideras": "entraider",
    "entraiderez": "entraider",
    "entraideriez": "entraider",
    "entraiderions": "entraider",
    "entraiderons": "entraider",
    "entraideront": "entraider",
    "entraides": "entraider",
    "entraidez": "entraider",
    "entraidiez": "entraider",
    "entraidions": "entraider",
    "entraidons": "entraider",
    "entraidâmes": "entraider",
    "entraidât": "entraider",
    "entraidâtes": "entraider",
    "entraidèrent": "entraider",
    "entraidé": "entraider",
    "entraidée": "entraider",
    "entraidées": "entraider",
    "entraidés": "entraider",
    "entraient": "entrer",
    "entrains": "entrain",
    "entrais": "entrer",
    "entrait": "entrer",
    "entraits": "entrait",
    "entrant": "entrer",
    "entrante": "entrant",
    "entrantes": "entrant",
    "entrants": "entrant",
    "entraperçu": "entrapercevoir",
    "entraperçues": "entrapercevoir",
    "entraperçus": "entrapercevoir",
    "entras": "entrer",
    "entrasse": "entrer",
    "entrassent": "entrer",
    "entrasses": "entrer",
    "entrassiez": "entrer",
    "entrassions": "entrer",
    "entrava": "entraver",
    "entravai": "entraver",
    "entravaient": "entraver",
    "entravais": "entraver",
    "entravait": "entraver",
    "entravant": "entraver",
    "entravas": "entraver",
    "entravasse": "entraver",
    "entravassent": "entraver",
    "entravasses": "entraver",
    "entravassiez": "entraver",
    "entravassions": "entraver",
    "entrave": "entraver",
    "entravent": "entraver",
    "entravera": "entraver",
    "entraverai": "entraver",
    "entraveraient": "entraver",
    "entraverais": "entraver",
    "entraverait": "entraver",
    "entraveras": "entraver",
    "entraverez": "entraver",
    "entraveriez": "entraver",
    "entraverions": "entraver",
    "entraverons": "entraver",
    "entraveront": "entraver",
    "entraves": "entraver",
    "entravez": "entraver",
    "entraviez": "entraver",
    "entravions": "entraver",
    "entravons": "entraver",
    "entravâmes": "entraver",
    "entravât": "entraver",
    "entravâtes": "entraver",
    "entravèrent": "entraver",
    "entravé": "entraver",
    "entravée": "entraver",
    "entravées": "entraver",
    "entravés": "entraver",
    "entraîna": "entraîner",
    "entraînai": "entraîner",
    "entraînaient": "entraîner",
    "entraînais": "entraîner",
    "entraînait": "entraîner",
    "entraînant": "entraîner",
    "entraînante": "entraînant",
    "entraînants": "entraînant",
    "entraînas": "entraîner",
    "entraînasse": "entraîner",
    "entraînassent": "entraîner",
    "entraînasses": "entraîner",
    "entraînassiez": "entraîner",
    "entraînassions": "entraîner",
    "entraîne": "entraîner",
    "entraînements": "entraînement",
    "entraînent": "entraîner",
    "entraînera": "entraîner",
    "entraînerai": "entraîner",
    "entraîneraient": "entraîner",
    "entraînerais": "entraîner",
    "entraînerait": "entraîner",
    "entraîneras": "entraîner",
    "entraînerez": "entraîner",
    "entraîneriez": "entraîner",
    "entraînerions": "entraîner",
    "entraînerons": "entraîner",
    "entraîneront": "entraîner",
    "entraînes": "entraîner",
    "entraîneurs": "entraîneur",
    "entraîneuse": "entraîneur",
    "entraîneuses": "entraîneur",
    "entraînez": "entraîner",
    "entraîniez": "entraîner",
    "entraînions": "entraîner",
    "entraînons": "entraîner",
    "entraînâmes": "entraîner",
    "entraînât": "entraîner",
    "entraînâtes": "entraîner",
    "entraînèrent": "entraîner",
    "entraîné": "entraîner",
    "entraînée": "entraîner",
    "entraînées": "entraîner",
    "entraînés": "entraîner",
    "entre": "entrer",
    "entre-bandes": "entre-bande",
    "entre-déchira": "entre-déchirer",
    "entre-déchirai": "entre-déchirer",
    "entre-déchiraient": "entre-déchirer",
    "entre-déchirais": "entre-déchirer",
    "entre-déchirait": "entre-déchirer",
    "entre-déchirant": "entre-déchirer",
    "entre-déchiras": "entre-déchirer",
    "entre-déchirasse": "entre-déchirer",
    "entre-déchirassent": "entre-déchirer",
    "entre-déchirasses": "entre-déchirer",
    "entre-déchirassiez": "entre-déchirer",
    "entre-déchirassions": "entre-déchirer",
    "entre-déchire": "entre-déchirer",
    "entre-déchirent": "entre-déchirer",
    "entre-déchirera": "entre-déchirer",
    "entre-déchirerai": "entre-déchirer",
    "entre-déchireraient": "entre-déchirer",
    "entre-déchirerais": "entre-déchirer",
    "entre-déchirerait": "entre-déchirer",
    "entre-déchireras": "entre-déchirer",
    "entre-déchirerez": "entre-déchirer",
    "entre-déchireriez": "entre-déchirer",
    "entre-déchirerions": "entre-déchirer",
    "entre-déchirerons": "entre-déchirer",
    "entre-déchireront": "entre-déchirer",
    "entre-déchires": "entre-déchirer",
    "entre-déchirez": "entre-déchirer",
    "entre-déchiriez": "entre-déchirer",
    "entre-déchirions": "entre-déchirer",
    "entre-déchirons": "entre-déchirer",
    "entre-déchirâmes": "entre-déchirer",
    "entre-déchirât": "entre-déchirer",
    "entre-déchirâtes": "entre-déchirer",
    "entre-déchirèrent": "entre-déchirer",
    "entre-déchiré": "entre-déchirer",
    "entre-déchirée": "entre-déchirer",
    "entre-déchirées": "entre-déchirer",
    "entre-déchirés": "entre-déchirer",
    "entre-détruira": "entre-détruire",
    "entre-détruirai": "entre-détruire",
    "entre-détruiraient": "entre-détruire",
    "entre-détruirais": "entre-détruire",
    "entre-détruirait": "entre-détruire",
    "entre-détruiras": "entre-détruire",
    "entre-détruirez": "entre-détruire",
    "entre-détruiriez": "entre-détruire",
    "entre-détruirions": "entre-détruire",
    "entre-détruirons": "entre-détruire",
    "entre-détruiront": "entre-détruire",
    "entre-détruis": "entre-détruire",
    "entre-détruisaient": "entre-détruire",
    "entre-détruisais": "entre-détruire",
    "entre-détruisait": "entre-détruire",
    "entre-détruisant": "entre-détruire",
    "entre-détruise": "entre-détruire",
    "entre-détruisent": "entre-détruire",
    "entre-détruises": "entre-détruire",
    "entre-détruisez": "entre-détruire",
    "entre-détruisiez": "entre-détruire",
    "entre-détruisions": "entre-détruire",
    "entre-détruisirent": "entre-détruire",
    "entre-détruisis": "entre-détruire",
    "entre-détruisisse": "entre-détruire",
    "entre-détruisissent": "entre-détruire",
    "entre-détruisisses": "entre-détruire",
    "entre-détruisissiez": "entre-détruire",
    "entre-détruisissions": "entre-détruire",
    "entre-détruisit": "entre-détruire",
    "entre-détruisons": "entre-détruire",
    "entre-détruisîmes": "entre-détruire",
    "entre-détruisît": "entre-détruire",
    "entre-détruisîtes": "entre-détruire",
    "entre-détruit": "entre-détruire",
    "entre-détruite": "entre-détruire",
    "entre-détruites": "entre-détruire",
    "entre-détruits": "entre-détruire",
    "entre-dévora": "entre-dévorer",
    "entre-dévorai": "entre-dévorer",
    "entre-dévoraient": "entre-dévorer",
    "entre-dévorais": "entre-dévorer",
    "entre-dévorait": "entre-dévorer",
    "entre-dévorant": "entre-dévorer",
    "entre-dévoras": "entre-dévorer",
    "entre-dévorasse": "entre-dévorer",
    "entre-dévorassent": "entre-dévorer",
    "entre-dévorasses": "entre-dévorer",
    "entre-dévorassiez": "entre-dévorer",
    "entre-dévorassions": "entre-dévorer",
    "entre-dévore": "entre-dévorer",
    "entre-dévorent": "entre-dévorer",
    "entre-dévorera": "entre-dévorer",
    "entre-dévorerai": "entre-dévorer",
    "entre-dévoreraient": "entre-dévorer",
    "entre-dévorerais": "entre-dévorer",
    "entre-dévorerait": "entre-dévorer",
    "entre-dévoreras": "entre-dévorer",
    "entre-dévorerez": "entre-dévorer",
    "entre-dévoreriez": "entre-dévorer",
    "entre-dévorerions": "entre-dévorer",
    "entre-dévorerons": "entre-dévorer",
    "entre-dévoreront": "entre-dévorer",
    "entre-dévores": "entre-dévorer",
    "entre-dévorez": "entre-dévorer",
    "entre-dévoriez": "entre-dévorer",
    "entre-dévorions": "entre-dévorer",
    "entre-dévorons": "entre-dévorer",
    "entre-dévorâmes": "entre-dévorer",
    "entre-dévorât": "entre-dévorer",
    "entre-dévorâtes": "entre-dévorer",
    "entre-dévorèrent": "entre-dévorer",
    "entre-dévoré": "entre-dévorer",
    "entre-dévorée": "entre-dévorer",
    "entre-dévorées": "entre-dévorer",
    "entre-dévorés": "entre-dévorer",
    "entre-frappa": "entre-frapper",
    "entre-frappai": "entre-frapper",
    "entre-frappaient": "entre-frapper",
    "entre-frappais": "entre-frapper",
    "entre-frappait": "entre-frapper",
    "entre-frappant": "entre-frapper",
    "entre-frappas": "entre-frapper",
    "entre-frappasse": "entre-frapper",
    "entre-frappassent": "entre-frapper",
    "entre-frappasses": "entre-frapper",
    "entre-frappassiez": "entre-frapper",
    "entre-frappassions": "entre-frapper",
    "entre-frappe": "entre-frapper",
    "entre-frappent": "entre-frapper",
    "entre-frappera": "entre-frapper",
    "entre-frapperai": "entre-frapper",
    "entre-frapperaient": "entre-frapper",
    "entre-frapperais": "entre-frapper",
    "entre-frapperait": "entre-frapper",
    "entre-frapperas": "entre-frapper",
    "entre-frapperez": "entre-frapper",
    "entre-frapperiez": "entre-frapper",
    "entre-frapperions": "entre-frapper",
    "entre-frapperons": "entre-frapper",
    "entre-frapperont": "entre-frapper",
    "entre-frappes": "entre-frapper",
    "entre-frappez": "entre-frapper",
    "entre-frappiez": "entre-frapper",
    "entre-frappions": "entre-frapper",
    "entre-frappons": "entre-frapper",
    "entre-frappâmes": "entre-frapper",
    "entre-frappât": "entre-frapper",
    "entre-frappâtes": "entre-frapper",
    "entre-frappèrent": "entre-frapper",
    "entre-frappé": "entre-frapper",
    "entre-frappée": "entre-frapper",
    "entre-frappées": "entre-frapper",
    "entre-frappés": "entre-frapper",
    "entre-hais": "entre-haïr",
    "entre-hait": "entre-haïr",
    "entre-haï": "entre-haïr",
    "entre-haïe": "entre-haïr",
    "entre-haïes": "entre-haïr",
    "entre-haïmes": "entre-haïr",
    "entre-haïra": "entre-haïr",
    "entre-haïrai": "entre-haïr",
    "entre-haïraient": "entre-haïr",
    "entre-haïrais": "entre-haïr",
    "entre-haïrait": "entre-haïr",
    "entre-haïras": "entre-haïr",
    "entre-haïrent": "entre-haïr",
    "entre-haïrez": "entre-haïr",
    "entre-haïriez": "entre-haïr",
    "entre-haïrions": "entre-haïr",
    "entre-haïrons": "entre-haïr",
    "entre-haïront": "entre-haïr",
    "entre-haïs": "entre-haïr",
    "entre-haïssaient": "entre-haïr",
    "entre-haïssais": "entre-haïr",
    "entre-haïssait": "entre-haïr",
    "entre-haïssant": "entre-haïr",
    "entre-haïsse": "entre-haïr",
    "entre-haïssent": "entre-haïr",
    "entre-haïsses": "entre-haïr",
    "entre-haïssez": "entre-haïr",
    "entre-haïssiez": "entre-haïr",
    "entre-haïssions": "entre-haïr",
    "entre-haïssons": "entre-haïr",
    "entre-haït": "entre-haïr",
    "entre-haïtes": "entre-haïr",
    "entre-loua": "entre-louer",
    "entre-louai": "entre-louer",
    "entre-louaient": "entre-louer",
    "entre-louais": "entre-louer",
    "entre-louait": "entre-louer",
    "entre-louant": "entre-louer",
    "entre-louas": "entre-louer",
    "entre-louasse": "entre-louer",
    "entre-louassent": "entre-louer",
    "entre-louasses": "entre-louer",
    "entre-louassiez": "entre-louer",
    "entre-louassions": "entre-louer",
    "entre-loue": "entre-louer",
    "entre-louent": "entre-louer",
    "entre-louera": "entre-louer",
    "entre-louerai": "entre-louer",
    "entre-loueraient": "entre-louer",
    "entre-louerais": "entre-louer",
    "entre-louerait": "entre-louer",
    "entre-loueras": "entre-louer",
    "entre-louerez": "entre-louer",
    "entre-loueriez": "entre-louer",
    "entre-louerions": "entre-louer",
    "entre-louerons": "entre-louer",
    "entre-loueront": "entre-louer",
    "entre-loues": "entre-louer",
    "entre-louez": "entre-louer",
    "entre-louiez": "entre-louer",
    "entre-louions": "entre-louer",
    "entre-louons": "entre-louer",
    "entre-louâmes": "entre-louer",
    "entre-louât": "entre-louer",
    "entre-louâtes": "entre-louer",
    "entre-louèrent": "entre-louer",
    "entre-loué": "entre-louer",
    "entre-louée": "entre-louer",
    "entre-louées": "entre-louer",
    "entre-loués": "entre-louer",
    "entre-lui": "entre-luire",
    "entre-luira": "entre-luire",
    "entre-luirai": "entre-luire",
    "entre-luiraient": "entre-luire",
    "entre-luirais": "entre-luire",
    "entre-luirait": "entre-luire",
    "entre-luiras": "entre-luire",
    "entre-luirent": "entre-luire",
    "entre-luirez": "entre-luire",
    "entre-luiriez": "entre-luire",
    "entre-luirions": "entre-luire",
    "entre-luirons": "entre-luire",
    "entre-luiront": "entre-luire",
    "entre-luis": "entre-luire",
    "entre-luisaient": "entre-luire",
    "entre-luisais": "entre-luire",
    "entre-luisait": "entre-luire",
    "entre-luisant": "entre-luire",
    "entre-luise": "entre-luire",
    "entre-luisent": "entre-luire",
    "entre-luises": "entre-luire",
    "entre-luisez": "entre-luire",
    "entre-luisiez": "entre-luire",
    "entre-luisions": "entre-luire",
    "entre-luisisse": "entre-luire",
    "entre-luisissent": "entre-luire",
    "entre-luisisses": "entre-luire",
    "entre-luisissiez": "entre-luire",
    "entre-luisissions": "entre-luire",
    "entre-luisons": "entre-luire",
    "entre-luisît": "entre-luire",
    "entre-luit": "entre-luire",
    "entre-luîmes": "entre-luire",
    "entre-luîtes": "entre-luire",
    "entre-mange": "entre-manger",
    "entre-mangea": "entre-manger",
    "entre-mangeai": "entre-manger",
    "entre-mangeaient": "entre-manger",
    "entre-mangeais": "entre-manger",
    "entre-mangeait": "entre-manger",
    "entre-mangeant": "entre-manger",
    "entre-mangeas": "entre-manger",
    "entre-mangeasse": "entre-manger",
    "entre-mangeassent": "entre-manger",
    "entre-mangeasses": "entre-manger",
    "entre-mangeassiez": "entre-manger",
    "entre-mangeassions": "entre-manger",
    "entre-mangent": "entre-manger",
    "entre-mangeons": "entre-manger",
    "entre-mangera": "entre-manger",
    "entre-mangerai": "entre-manger",
    "entre-mangeraient": "entre-manger",
    "entre-mangerais": "entre-manger",
    "entre-mangerait": "entre-manger",
    "entre-mangeras": "entre-manger",
    "entre-mangerez": "entre-manger",
    "entre-mangeriez": "entre-manger",
    "entre-mangerions": "entre-manger",
    "entre-mangerons": "entre-manger",
    "entre-mangeront": "entre-manger",
    "entre-manges": "entre-manger",
    "entre-mangez": "entre-manger",
    "entre-mangeâmes": "entre-manger",
    "entre-mangeât": "entre-manger",
    "entre-mangeâtes": "entre-manger",
    "entre-mangiez": "entre-manger",
    "entre-mangions": "entre-manger",
    "entre-mangèrent": "entre-manger",
    "entre-mangé": "entre-manger",
    "entre-mangée": "entre-manger",
    "entre-mangées": "entre-manger",
    "entre-mangés": "entre-manger",
    "entre-noeuds": "entre-noeud",
    "entre-nui": "entre-nuire",
    "entre-nuira": "entre-nuire",
    "entre-nuirai": "entre-nuire",
    "entre-nuiraient": "entre-nuire",
    "entre-nuirais": "entre-nuire",
    "entre-nuirait": "entre-nuire",
    "entre-nuiras": "entre-nuire",
    "entre-nuirez": "entre-nuire",
    "entre-nuiriez": "entre-nuire",
    "entre-nuirions": "entre-nuire",
    "entre-nuirons": "entre-nuire",
    "entre-nuiront": "entre-nuire",
    "entre-nuis": "entre-nuire",
    "entre-nuisaient": "entre-nuire",
    "entre-nuisais": "entre-nuire",
    "entre-nuisait": "entre-nuire",
    "entre-nuisant": "entre-nuire",
    "entre-nuise": "entre-nuire",
    "entre-nuisent": "entre-nuire",
    "entre-nuises": "entre-nuire",
    "entre-nuisez": "entre-nuire",
    "entre-nuisiez": "entre-nuire",
    "entre-nuisions": "entre-nuire",
    "entre-nuisirent": "entre-nuire",
    "entre-nuisis": "entre-nuire",
    "entre-nuisisse": "entre-nuire",
    "entre-nuisissent": "entre-nuire",
    "entre-nuisisses": "entre-nuire",
    "entre-nuisissiez": "entre-nuire",
    "entre-nuisissions": "entre-nuire",
    "entre-nuisit": "entre-nuire",
    "entre-nuisons": "entre-nuire",
    "entre-nuisîmes": "entre-nuire",
    "entre-nuisît": "entre-nuire",
    "entre-nuisîtes": "entre-nuire",
    "entre-nuit": "entre-nuire",
    "entre-regarda": "entre-regarder",
    "entre-regardai": "entre-regarder",
    "entre-regardaient": "entre-regarder",
    "entre-regardais": "entre-regarder",
    "entre-regardait": "entre-regarder",
    "entre-regardant": "entre-regarder",
    "entre-regardas": "entre-regarder",
    "entre-regardasse": "entre-regarder",
    "entre-regardassent": "entre-regarder",
    "entre-regardasses": "entre-regarder",
    "entre-regardassiez": "entre-regarder",
    "entre-regardassions": "entre-regarder",
    "entre-regarde": "entre-regarder",
    "entre-regardent": "entre-regarder",
    "entre-regardera": "entre-regarder",
    "entre-regarderai": "entre-regarder",
    "entre-regarderaient": "entre-regarder",
    "entre-regarderais": "entre-regarder",
    "entre-regarderait": "entre-regarder",
    "entre-regarderas": "entre-regarder",
    "entre-regarderez": "entre-regarder",
    "entre-regarderiez": "entre-regarder",
    "entre-regarderions": "entre-regarder",
    "entre-regarderons": "entre-regarder",
    "entre-regarderont": "entre-regarder",
    "entre-regardes": "entre-regarder",
    "entre-regardez": "entre-regarder",
    "entre-regardiez": "entre-regarder",
    "entre-regardions": "entre-regarder",
    "entre-regardons": "entre-regarder",
    "entre-regardâmes": "entre-regarder",
    "entre-regardât": "entre-regarder",
    "entre-regardâtes": "entre-regarder",
    "entre-regardèrent": "entre-regarder",
    "entre-regardé": "entre-regarder",
    "entre-regardée": "entre-regarder",
    "entre-regardées": "entre-regarder",
    "entre-regardés": "entre-regarder",
    "entre-tua": "entre-tuer",
    "entre-tuai": "entre-tuer",
    "entre-tuaient": "entre-tuer",
    "entre-tuais": "entre-tuer",
    "entre-tuait": "entre-tuer",
    "entre-tuant": "entre-tuer",
    "entre-tuas": "entre-tuer",
    "entre-tuasse": "entre-tuer",
    "entre-tuassent": "entre-tuer",
    "entre-tuasses": "entre-tuer",
    "entre-tuassiez": "entre-tuer",
    "entre-tuassions": "entre-tuer",
    "entre-tue": "entre-tuer",
    "entre-tuent": "entre-tuer",
    "entre-tuera": "entre-tuer",
    "entre-tuerai": "entre-tuer",
    "entre-tueraient": "entre-tuer",
    "entre-tuerais": "entre-tuer",
    "entre-tuerait": "entre-tuer",
    "entre-tueras": "entre-tuer",
    "entre-tuerez": "entre-tuer",
    "entre-tueriez": "entre-tuer",
    "entre-tuerions": "entre-tuer",
    "entre-tuerons": "entre-tuer",
    "entre-tueront": "entre-tuer",
    "entre-tues": "entre-tuer",
    "entre-tuez": "entre-tuer",
    "entre-tuiez": "entre-tuer",
    "entre-tuions": "entre-tuer",
    "entre-tuons": "entre-tuer",
    "entre-tuâmes": "entre-tuer",
    "entre-tuât": "entre-tuer",
    "entre-tuâtes": "entre-tuer",
    "entre-tuèrent": "entre-tuer",
    "entre-tué": "entre-tuer",
    "entre-tuée": "entre-tuer",
    "entre-tuées": "entre-tuer",
    "entre-tués": "entre-tuer",
    "entrebat": "entrebattre",
    "entrebats": "entrebattre",
    "entrebattaient": "entrebattre",
    "entrebattais": "entrebattre",
    "entrebattait": "entrebattre",
    "entrebattant": "entrebattre",
    "entrebatte": "entrebattre",
    "entrebattent": "entrebattre",
    "entrebattes": "entrebattre",
    "entrebattez": "entrebattre",
    "entrebattiez": "entrebattre",
    "entrebattions": "entrebattre",
    "entrebattirent": "entrebattre",
    "entrebattis": "entrebattre",
    "entrebattisse": "entrebattre",
    "entrebattissent": "entrebattre",
    "entrebattisses": "entrebattre",
    "entrebattissiez": "entrebattre",
    "entrebattissions": "entrebattre",
    "entrebattit": "entrebattre",
    "entrebattons": "entrebattre",
    "entrebattra": "entrebattre",
    "entrebattrai": "entrebattre",
    "entrebattraient": "entrebattre",
    "entrebattrais": "entrebattre",
    "entrebattrait": "entrebattre",
    "entrebattras": "entrebattre",
    "entrebattrez": "entrebattre",
    "entrebattriez": "entrebattre",
    "entrebattrions": "entrebattre",
    "entrebattrons": "entrebattre",
    "entrebattront": "entrebattre",
    "entrebattu": "entrebattre",
    "entrebattue": "entrebattre",
    "entrebattues": "entrebattre",
    "entrebattus": "entrebattre",
    "entrebattîmes": "entrebattre",
    "entrebattît": "entrebattre",
    "entrebattîtes": "entrebattre",
    "entrebâilla": "entrebâiller",
    "entrebâillai": "entrebâiller",
    "entrebâillaient": "entrebâiller",
    "entrebâillais": "entrebâiller",
    "entrebâillait": "entrebâiller",
    "entrebâillant": "entrebâiller",
    "entrebâillas": "entrebâiller",
    "entrebâillasse": "entrebâiller",
    "entrebâillassent": "entrebâiller",
    "entrebâillasses": "entrebâiller",
    "entrebâillassiez": "entrebâiller",
    "entrebâillassions": "entrebâiller",
    "entrebâille": "entrebâiller",
    "entrebâillent": "entrebâiller",
    "entrebâillera": "entrebâiller",
    "entrebâillerai": "entrebâiller",
    "entrebâilleraient": "entrebâiller",
    "entrebâillerais": "entrebâiller",
    "entrebâillerait": "entrebâiller",
    "entrebâilleras": "entrebâiller",
    "entrebâillerez": "entrebâiller",
    "entrebâilleriez": "entrebâiller",
    "entrebâillerions": "entrebâiller",
    "entrebâillerons": "entrebâiller",
    "entrebâilleront": "entrebâiller",
    "entrebâilles": "entrebâiller",
    "entrebâillez": "entrebâiller",
    "entrebâilliez": "entrebâiller",
    "entrebâillions": "entrebâiller",
    "entrebâillons": "entrebâiller",
    "entrebâillâmes": "entrebâiller",
    "entrebâillât": "entrebâiller",
    "entrebâillâtes": "entrebâiller",
    "entrebâillèrent": "entrebâiller",
    "entrebâillé": "entrebâiller",
    "entrebâillée": "entrebâiller",
    "entrebâillées": "entrebâiller",
    "entrebâillés": "entrebâiller",
    "entrechats": "entrechat",
    "entrechocs": "entrechoc",
    "entrechoqua": "entrechoquer",
    "entrechoquai": "entrechoquer",
    "entrechoquaient": "entrechoquer",
    "entrechoquais": "entrechoquer",
    "entrechoquait": "entrechoquer",
    "entrechoquant": "entrechoquer",
    "entrechoquas": "entrechoquer",
    "entrechoquasse": "entrechoquer",
    "entrechoquassent": "entrechoquer",
    "entrechoquasses": "entrechoquer",
    "entrechoquassiez": "entrechoquer",
    "entrechoquassions": "entrechoquer",
    "entrechoque": "entrechoquer",
    "entrechoquent": "entrechoquer",
    "entrechoquera": "entrechoquer",
    "entrechoquerai": "entrechoquer",
    "entrechoqueraient": "entrechoquer",
    "entrechoquerais": "entrechoquer",
    "entrechoquerait": "entrechoquer",
    "entrechoqueras": "entrechoquer",
    "entrechoquerez": "entrechoquer",
    "entrechoqueriez": "entrechoquer",
    "entrechoquerions": "entrechoquer",
    "entrechoquerons": "entrechoquer",
    "entrechoqueront": "entrechoquer",
    "entrechoques": "entrechoquer",
    "entrechoquez": "entrechoquer",
    "entrechoquiez": "entrechoquer",
    "entrechoquions": "entrechoquer",
    "entrechoquons": "entrechoquer",
    "entrechoquâmes": "entrechoquer",
    "entrechoquât": "entrechoquer",
    "entrechoquâtes": "entrechoquer",
    "entrechoquèrent": "entrechoquer",
    "entrechoqué": "entrechoquer",
    "entrechoquée": "entrechoquer",
    "entrechoquées": "entrechoquer",
    "entrechoqués": "entrechoquer",
    "entreclos": "entreclore",
    "entrecloses": "entreclos",
    "entrecoupa": "entrecouper",
    "entrecoupai": "entrecouper",
    "entrecoupaient": "entrecouper",
    "entrecoupais": "entrecouper",
    "entrecoupait": "entrecouper",
    "entrecoupant": "entrecouper",
    "entrecoupas": "entrecouper",
    "entrecoupasse": "entrecouper",
    "entrecoupassent": "entrecouper",
    "entrecoupasses": "entrecouper",
    "entrecoupassiez": "entrecouper",
    "entrecoupassions": "entrecouper",
    "entrecoupe": "entrecouper",
    "entrecoupent": "entrecouper",
    "entrecoupera": "entrecouper",
    "entrecouperai": "entrecouper",
    "entrecouperaient": "entrecouper",
    "entrecouperais": "entrecouper",
    "entrecouperait": "entrecouper",
    "entrecouperas": "entrecouper",
    "entrecouperez": "entrecouper",
    "entrecouperiez": "entrecouper",
    "entrecouperions": "entrecouper",
    "entrecouperons": "entrecouper",
    "entrecouperont": "entrecouper",
    "entrecoupes": "entrecouper",
    "entrecoupez": "entrecouper",
    "entrecoupiez": "entrecouper",
    "entrecoupions": "entrecouper",
    "entrecoupons": "entrecouper",
    "entrecoupâmes": "entrecouper",
    "entrecoupât": "entrecouper",
    "entrecoupâtes": "entrecouper",
    "entrecoupèrent": "entrecouper",
    "entrecoupé": "entrecouper",
    "entrecoupée": "entrecouper",
    "entrecoupées": "entrecouper",
    "entrecoupés": "entrecouper",
    "entrecroisa": "entrecroiser",
    "entrecroisai": "entrecroiser",
    "entrecroisaient": "entrecroiser",
    "entrecroisais": "entrecroiser",
    "entrecroisait": "entrecroiser",
    "entrecroisant": "entrecroiser",
    "entrecroisas": "entrecroiser",
    "entrecroisasse": "entrecroiser",
    "entrecroisassent": "entrecroiser",
    "entrecroisasses": "entrecroiser",
    "entrecroisassiez": "entrecroiser",
    "entrecroisassions": "entrecroiser",
    "entrecroise": "entrecroiser",
    "entrecroisements": "entrecroisement",
    "entrecroisent": "entrecroiser",
    "entrecroisera": "entrecroiser",
    "entrecroiserai": "entrecroiser",
    "entrecroiseraient": "entrecroiser",
    "entrecroiserais": "entrecroiser",
    "entrecroiserait": "entrecroiser",
    "entrecroiseras": "entrecroiser",
    "entrecroiserez": "entrecroiser",
    "entrecroiseriez": "entrecroiser",
    "entrecroiserions": "entrecroiser",
    "entrecroiserons": "entrecroiser",
    "entrecroiseront": "entrecroiser",
    "entrecroises": "entrecroiser",
    "entrecroisez": "entrecroiser",
    "entrecroisiez": "entrecroiser",
    "entrecroisions": "entrecroiser",
    "entrecroisons": "entrecroiser",
    "entrecroisâmes": "entrecroiser",
    "entrecroisât": "entrecroiser",
    "entrecroisâtes": "entrecroiser",
    "entrecroisèrent": "entrecroiser",
    "entrecroisé": "entrecroiser",
    "entrecroisée": "entrecroiser",
    "entrecroisées": "entrecroiser",
    "entrecroisés": "entrecroiser",
    "entrecuisses": "entrecuisse",
    "entrecôtes": "entrecôte",
    "entredéchire": "entredéchirer",
    "entredévorait": "entredévorer",
    "entrefaites": "entrefaite",
    "entreferma": "entrefermer",
    "entrefermée": "entrefermer",
    "entrefermées": "entrefermer",
    "entrefilets": "entrefilet",
    "entregents": "entregent",
    "entrejambes": "entrejambe",
    "entrelace": "entrelacer",
    "entrelacent": "entrelacer",
    "entrelacera": "entrelacer",
    "entrelacerai": "entrelacer",
    "entrelaceraient": "entrelacer",
    "entrelacerais": "entrelacer",
    "entrelacerait": "entrelacer",
    "entrelaceras": "entrelacer",
    "entrelacerez": "entrelacer",
    "entrelaceriez": "entrelacer",
    "entrelacerions": "entrelacer",
    "entrelacerons": "entrelacer",
    "entrelaceront": "entrelacer",
    "entrelaces": "entrelacer",
    "entrelacez": "entrelacer",
    "entrelaciez": "entrelacer",
    "entrelacions": "entrelacer",
    "entrelacèrent": "entrelacer",
    "entrelacé": "entrelacer",
    "entrelacée": "entrelacer",
    "entrelacées": "entrelacer",
    "entrelacés": "entrelacer",
    "entrelarda": "entrelarder",
    "entrelardai": "entrelarder",
    "entrelardaient": "entrelarder",
    "entrelardais": "entrelarder",
    "entrelardait": "entrelarder",
    "entrelardant": "entrelarder",
    "entrelardas": "entrelarder",
    "entrelardasse": "entrelarder",
    "entrelardassent": "entrelarder",
    "entrelardasses": "entrelarder",
    "entrelardassiez": "entrelarder",
    "entrelardassions": "entrelarder",
    "entrelarde": "entrelarder",
    "entrelardent": "entrelarder",
    "entrelardera": "entrelarder",
    "entrelarderai": "entrelarder",
    "entrelarderaient": "entrelarder",
    "entrelarderais": "entrelarder",
    "entrelarderait": "entrelarder",
    "entrelarderas": "entrelarder",
    "entrelarderez": "entrelarder",
    "entrelarderiez": "entrelarder",
    "entrelarderions": "entrelarder",
    "entrelarderons": "entrelarder",
    "entrelarderont": "entrelarder",
    "entrelardes": "entrelarder",
    "entrelardez": "entrelarder",
    "entrelardiez": "entrelarder",
    "entrelardions": "entrelarder",
    "entrelardons": "entrelarder",
    "entrelardâmes": "entrelarder",
    "entrelardât": "entrelarder",
    "entrelardâtes": "entrelarder",
    "entrelardèrent": "entrelarder",
    "entrelardé": "entrelarder",
    "entrelardée": "entrelarder",
    "entrelardées": "entrelarder",
    "entrelardés": "entrelarder",
    "entrelaça": "entrelacer",
    "entrelaçai": "entrelacer",
    "entrelaçaient": "entrelacer",
    "entrelaçais": "entrelacer",
    "entrelaçait": "entrelacer",
    "entrelaçant": "entrelacer",
    "entrelaças": "entrelacer",
    "entrelaçasse": "entrelacer",
    "entrelaçassent": "entrelacer",
    "entrelaçasses": "entrelacer",
    "entrelaçassiez": "entrelacer",
    "entrelaçassions": "entrelacer",
    "entrelaçons": "entrelacer",
    "entrelaçâmes": "entrelacer",
    "entrelaçât": "entrelacer",
    "entrelaçâtes": "entrelacer",
    "entremet": "entremettre",
    "entremets": "entremettre",
    "entremettaient": "entremettre",
    "entremettais": "entremettre",
    "entremettait": "entremettre",
    "entremettant": "entremettre",
    "entremette": "entremettre",
    "entremettent": "entremettre",
    "entremettes": "entremettre",
    "entremetteurs": "entremetteur",
    "entremetteuse": "entremetteur",
    "entremettez": "entremettre",
    "entremettiez": "entremettre",
    "entremettions": "entremettre",
    "entremettons": "entremettre",
    "entremettra": "entremettre",
    "entremettrai": "entremettre",
    "entremettraient": "entremettre",
    "entremettrais": "entremettre",
    "entremettrait": "entremettre",
    "entremettras": "entremettre",
    "entremettrez": "entremettre",
    "entremettriez": "entremettre",
    "entremettrions": "entremettre",
    "entremettrons": "entremettre",
    "entremettront": "entremettre",
    "entremirent": "entremettre",
    "entremis": "entremettre",
    "entremise": "entremettre",
    "entremises": "entremettre",
    "entremisse": "entremettre",
    "entremissent": "entremettre",
    "entremisses": "entremettre",
    "entremissiez": "entremettre",
    "entremissions": "entremettre",
    "entremit": "entremettre",
    "entremêla": "entremêler",
    "entremêlai": "entremêler",
    "entremêlaient": "entremêler",
    "entremêlais": "entremêler",
    "entremêlait": "entremêler",
    "entremêlant": "entremêler",
    "entremêlas": "entremêler",
    "entremêlasse": "entremêler",
    "entremêlassent": "entremêler",
    "entremêlasses": "entremêler",
    "entremêlassiez": "entremêler",
    "entremêlassions": "entremêler",
    "entremêle": "entremêler",
    "entremêlent": "entremêler",
    "entremêlera": "entremêler",
    "entremêlerai": "entremêler",
    "entremêleraient": "entremêler",
    "entremêlerais": "entremêler",
    "entremêlerait": "entremêler",
    "entremêleras": "entremêler",
    "entremêlerez": "entremêler",
    "entremêleriez": "entremêler",
    "entremêlerions": "entremêler",
    "entremêlerons": "entremêler",
    "entremêleront": "entremêler",
    "entremêles": "entremêler",
    "entremêlez": "entremêler",
    "entremêliez": "entremêler",
    "entremêlions": "entremêler",
    "entremêlons": "entremêler",
    "entremêlâmes": "entremêler",
    "entremêlât": "entremêler",
    "entremêlâtes": "entremêler",
    "entremêlèrent": "entremêler",
    "entremêlé": "entremêler",
    "entremêlée": "entremêler",
    "entremêlées": "entremêler",
    "entremêlés": "entremêler",
    "entremîmes": "entremettre",
    "entremît": "entremettre",
    "entremîtes": "entremettre",
    "entrent": "entrer",
    "entreponts": "entrepont",
    "entreposa": "entreposer",
    "entreposages": "entreposage",
    "entreposai": "entreposer",
    "entreposaient": "entreposer",
    "entreposais": "entreposer",
    "entreposait": "entreposer",
    "entreposant": "entreposer",
    "entreposas": "entreposer",
    "entreposasse": "entreposer",
    "entreposassent": "entreposer",
    "entreposasses": "entreposer",
    "entreposassiez": "entreposer",
    "entreposassions": "entreposer",
    "entrepose": "entreposer",
    "entreposent": "entreposer",
    "entreposera": "entreposer",
    "entreposerai": "entreposer",
    "entreposeraient": "entreposer",
    "entreposerais": "entreposer",
    "entreposerait": "entreposer",
    "entreposeras": "entreposer",
    "entreposerez": "entreposer",
    "entreposeriez": "entreposer",
    "entreposerions": "entreposer",
    "entreposerons": "entreposer",
    "entreposeront": "entreposer",
    "entreposes": "entreposer",
    "entreposez": "entreposer",
    "entreposiez": "entreposer",
    "entreposions": "entreposer",
    "entrepositaires": "entrepositaire",
    "entreposons": "entreposer",
    "entreposâmes": "entreposer",
    "entreposât": "entreposer",
    "entreposâtes": "entreposer",
    "entreposèrent": "entreposer",
    "entreposé": "entreposer",
    "entreposée": "entreposer",
    "entreposées": "entreposer",
    "entreposés": "entreposer",
    "entreprenaient": "entreprendre",
    "entreprenais": "entreprendre",
    "entreprenait": "entreprendre",
    "entreprenant": "entreprendre",
    "entreprenante": "entreprenant",
    "entreprenantes": "entreprenant",
    "entreprenants": "entreprenant",
    "entreprend": "entreprendre",
    "entreprendra": "entreprendre",
    "entreprendrai": "entreprendre",
    "entreprendraient": "entreprendre",
    "entreprendrais": "entreprendre",
    "entreprendrait": "entreprendre",
    "entreprendras": "entreprendre",
    "entreprendrez": "entreprendre",
    "entreprendriez": "entreprendre",
    "entreprendrions": "entreprendre",
    "entreprendrons": "entreprendre",
    "entreprendront": "entreprendre",
    "entreprends": "entreprendre",
    "entrepreneurs": "entrepreneur",
    "entrepreneuse": "entrepreneur",
    "entrepreneuses": "entrepreneur",
    "entreprenez": "entreprendre",
    "entrepreniez": "entreprendre",
    "entreprenions": "entreprendre",
    "entreprenne": "entreprendre",
    "entreprennent": "entreprendre",
    "entreprennes": "entreprendre",
    "entreprenons": "entreprendre",
    "entreprirent": "entreprendre",
    "entrepris": "entreprendre",
    "entreprise": "entreprendre",
    "entreprises": "entreprise",
    "entreprisse": "entreprendre",
    "entreprissent": "entreprendre",
    "entreprisses": "entreprendre",
    "entreprissiez": "entreprendre",
    "entreprissions": "entreprendre",
    "entreprit": "entreprendre",
    "entreprîmes": "entreprendre",
    "entreprît": "entreprendre",
    "entreprîtes": "entreprendre",
    "entrepôts": "entrepôt",
    "entrera": "entrer",
    "entrerai": "entrer",
    "entreraient": "entrer",
    "entrerais": "entrer",
    "entrerait": "entrer",
    "entreras": "entrer",
    "entreregardèrent": "entreregarder",
    "entrerez": "entrer",
    "entreriez": "entrer",
    "entrerions": "entrer",
    "entrerons": "entrer",
    "entreront": "entrer",
    "entres": "entrer",
    "entresols": "entresol",
    "entretailla": "entretailler",
    "entretaillai": "entretailler",
    "entretaillaient": "entretailler",
    "entretaillais": "entretailler",
    "entretaillait": "entretailler",
    "entretaillant": "entretailler",
    "entretaillas": "entretailler",
    "entretaillasse": "entretailler",
    "entretaillassent": "entretailler",
    "entretaillasses": "entretailler",
    "entretaillassiez": "entretailler",
    "entretaillassions": "entretailler",
    "entretaille": "entretailler",
    "entretaillent": "entretailler",
    "entretaillera": "entretailler",
    "entretaillerai": "entretailler",
    "entretailleraient": "entretailler",
    "entretaillerais": "entretailler",
    "entretaillerait": "entretailler",
    "entretailleras": "entretailler",
    "entretaillerez": "entretailler",
    "entretailleriez": "entretailler",
    "entretaillerions": "entretailler",
    "entretaillerons": "entretailler",
    "entretailleront": "entretailler",
    "entretailles": "entretailler",
    "entretaillez": "entretailler",
    "entretailliez": "entretailler",
    "entretaillions": "entretailler",
    "entretaillons": "entretailler",
    "entretaillâmes": "entretailler",
    "entretaillât": "entretailler",
    "entretaillâtes": "entretailler",
    "entretaillèrent": "entretailler",
    "entretaillé": "entretailler",
    "entretaillée": "entretailler",
    "entretaillées": "entretailler",
    "entretaillés": "entretailler",
    "entretenaient": "entretenir",
    "entretenais": "entretenir",
    "entretenait": "entretenir",
    "entretenant": "entretenir",
    "entreteneuse": "entreteneur",
    "entretenez": "entretenir",
    "entreteniez": "entretenir",
    "entretenions": "entretenir",
    "entretenons": "entretenir",
    "entretenu": "entretenir",
    "entretenue": "entretenu",
    "entretenues": "entretenu",
    "entretenus": "entretenu",
    "entretiendra": "entretenir",
    "entretiendrai": "entretenir",
    "entretiendraient": "entretenir",
    "entretiendrais": "entretenir",
    "entretiendrait": "entretenir",
    "entretiendras": "entretenir",
    "entretiendrez": "entretenir",
    "entretiendriez": "entretenir",
    "entretiendrions": "entretenir",
    "entretiendrons": "entretenir",
    "entretiendront": "entretenir",
    "entretienne": "entretenir",
    "entretiennent": "entretenir",
    "entretiennes": "entretenir",
    "entretiens": "entretien",
    "entretient": "entretenir",
    "entretinrent": "entretenir",
    "entretins": "entretenir",
    "entretinsse": "entretenir",
    "entretinssent": "entretenir",
    "entretinsses": "entretenir",
    "entretinssiez": "entretenir",
    "entretinssions": "entretenir",
    "entretint": "entretenir",
    "entretissait": "entretisser",
    "entretissé": "entretisser",
    "entretissées": "entretisser",
    "entretoisaient": "entretoiser",
    "entretoises": "entretoise",
    "entretuaient": "entretuer",
    "entretuant": "entretuer",
    "entretue": "entretuer",
    "entretuent": "entretuer",
    "entretueraient": "entretuer",
    "entretuerait": "entretuer",
    "entretueront": "entretuer",
    "entretuez": "entretuer",
    "entretuées": "entretuer",
    "entretués": "entretuer",
    "entretînmes": "entretenir",
    "entretînt": "entretenir",
    "entretîntes": "entretenir",
    "entreverra": "entrevoir",
    "entreverrai": "entrevoir",
    "entreverraient": "entrevoir",
    "entreverrais": "entrevoir",
    "entreverrait": "entrevoir",
    "entreverras": "entrevoir",
    "entreverrez": "entrevoir",
    "entreverriez": "entrevoir",
    "entreverrions": "entrevoir",
    "entreverrons": "entrevoir",
    "entreverront": "entrevoir",
    "entrevirent": "entrevoir",
    "entrevis": "entrevoir",
    "entrevisse": "entrevoir",
    "entrevissent": "entrevoir",
    "entrevisses": "entrevoir",
    "entrevissiez": "entrevoir",
    "entrevissions": "entrevoir",
    "entrevit": "entrevoir",
    "entrevoie": "entrevoir",
    "entrevoient": "entrevoir",
    "entrevoies": "entrevoir",
    "entrevois": "entrevoir",
    "entrevoit": "entrevoir",
    "entrevoyaient": "entrevoir",
    "entrevoyais": "entrevoir",
    "entrevoyait": "entrevoir",
    "entrevoyant": "entrevoir",
    "entrevoyez": "entrevoir",
    "entrevoyiez": "entrevoir",
    "entrevoyions": "entrevoir",
    "entrevoyons": "entrevoir",
    "entrevu": "entrevoir",
    "entrevue": "entrevoir",
    "entrevues": "entrevue",
    "entrevus": "entrevoir",
    "entrevîmes": "entrevoir",
    "entrevît": "entrevoir",
    "entrevîtes": "entrevoir",
    "entrez": "entrer",
    "entriez": "entrer",
    "entrions": "entrer",
    "entroblige": "entrobliger",
    "entrobligea": "entrobliger",
    "entrobligeai": "entrobliger",
    "entrobligeaient": "entrobliger",
    "entrobligeais": "entrobliger",
    "entrobligeait": "entrobliger",
    "entrobligeant": "entrobliger",
    "entrobligeas": "entrobliger",
    "entrobligeasse": "entrobliger",
    "entrobligeassent": "entrobliger",
    "entrobligeasses": "entrobliger",
    "entrobligeassiez": "entrobliger",
    "entrobligeassions": "entrobliger",
    "entrobligent": "entrobliger",
    "entrobligeons": "entrobliger",
    "entrobligera": "entrobliger",
    "entrobligerai": "entrobliger",
    "entrobligeraient": "entrobliger",
    "entrobligerais": "entrobliger",
    "entrobligerait": "entrobliger",
    "entrobligeras": "entrobliger",
    "entrobligerez": "entrobliger",
    "entrobligeriez": "entrobliger",
    "entrobligerions": "entrobliger",
    "entrobligerons": "entrobliger",
    "entrobligeront": "entrobliger",
    "entrobliges": "entrobliger",
    "entrobligez": "entrobliger",
    "entrobligeâmes": "entrobliger",
    "entrobligeât": "entrobliger",
    "entrobligeâtes": "entrobliger",
    "entrobligiez": "entrobliger",
    "entrobligions": "entrobliger",
    "entrobligèrent": "entrobliger",
    "entrobligé": "entrobliger",
    "entrobligée": "entrobliger",
    "entrobligées": "entrobliger",
    "entrobligés": "entrobliger",
    "entrons": "entrer",
    "entropies": "entropie",
    "entropiques": "entropique",
    "entrouvert": "entrouvrir",
    "entrouverte": "entrouvrir",
    "entrouvertes": "entrouvrir",
    "entrouverts": "entrouvrir",
    "entrouvraient": "entrouvrir",
    "entrouvrais": "entrouvrir",
    "entrouvrait": "entrouvrir",
    "entrouvrant": "entrouvrir",
    "entrouvre": "entrouvrir",
    "entrouvrent": "entrouvrir",
    "entrouvres": "entrouvrir",
    "entrouvrez": "entrouvrir",
    "entrouvriez": "entrouvrir",
    "entrouvrions": "entrouvrir",
    "entrouvrira": "entrouvrir",
    "entrouvrirai": "entrouvrir",
    "entrouvriraient": "entrouvrir",
    "entrouvrirais": "entrouvrir",
    "entrouvrirait": "entrouvrir",
    "entrouvriras": "entrouvrir",
    "entrouvrirent": "entrouvrir",
    "entrouvrirez": "entrouvrir",
    "entrouvririez": "entrouvrir",
    "entrouvririons": "entrouvrir",
    "entrouvrirons": "entrouvrir",
    "entrouvriront": "entrouvrir",
    "entrouvris": "entrouvrir",
    "entrouvrisse": "entrouvrir",
    "entrouvrissent": "entrouvrir",
    "entrouvrisses": "entrouvrir",
    "entrouvrissiez": "entrouvrir",
    "entrouvrissions": "entrouvrir",
    "entrouvrit": "entrouvrir",
    "entrouvrons": "entrouvrir",
    "entrouvrîmes": "entrouvrir",
    "entrouvrît": "entrouvrir",
    "entrouvrîtes": "entrouvrir",
    "entrâmes": "entrer",
    "entrât": "entrer",
    "entrâtes": "entrer",
    "entrèrent": "entrer",
    "entré": "entrer",
    "entrée": "entrer",
    "entrées": "entrer",
    "entrés": "entrer",
    "entuba": "entuber",
    "entubai": "entuber",
    "entubaient": "entuber",
    "entubais": "entuber",
    "entubait": "entuber",
    "entubant": "entuber",
    "entubas": "entuber",
    "entubasse": "entuber",
    "entubassent": "entuber",
    "entubasses": "entuber",
    "entubassiez": "entuber",
    "entubassions": "entuber",
    "entube": "entuber",
    "entubent": "entuber",
    "entubera": "entuber",
    "entuberai": "entuber",
    "entuberaient": "entuber",
    "entuberais": "entuber",
    "entuberait": "entuber",
    "entuberas": "entuber",
    "entuberez": "entuber",
    "entuberiez": "entuber",
    "entuberions": "entuber",
    "entuberons": "entuber",
    "entuberont": "entuber",
    "entubes": "entuber",
    "entubez": "entuber",
    "entubiez": "entuber",
    "entubions": "entuber",
    "entubons": "entuber",
    "entubâmes": "entuber",
    "entubât": "entuber",
    "entubâtes": "entuber",
    "entubèrent": "entuber",
    "entubé": "entuber",
    "entubée": "entuber",
    "entubées": "entuber",
    "entubés": "entuber",
    "enturbanné": "enturbanner",
    "enturbannée": "enturbanner",
    "enturbannées": "enturbanné",
    "enturbannés": "enturbanner",
    "entâmes": "enter",
    "entât": "enter",
    "entâtes": "enter",
    "entèrent": "enter",
    "enté": "enter",
    "entée": "enter",
    "entées": "enter",
    "entéléchies": "entéléchie",
    "enténèbre": "enténébrer",
    "enténèbrent": "enténébrer",
    "enténébra": "enténébrer",
    "enténébrait": "enténébrer",
    "enténébrant": "enténébrer",
    "enténébré": "enténébrer",
    "enténébrée": "enténébrer",
    "enténébrées": "enténébrer",
    "enténébrés": "enténébrer",
    "entérina": "entériner",
    "entérinai": "entériner",
    "entérinaient": "entériner",
    "entérinais": "entériner",
    "entérinait": "entériner",
    "entérinant": "entériner",
    "entérinas": "entériner",
    "entérinasse": "entériner",
    "entérinassent": "entériner",
    "entérinasses": "entériner",
    "entérinassiez": "entériner",
    "entérinassions": "entériner",
    "entérine": "entériner",
    "entérinent": "entériner",
    "entérinera": "entériner",
    "entérinerai": "entériner",
    "entérineraient": "entériner",
    "entérinerais": "entériner",
    "entérinerait": "entériner",
    "entérineras": "entériner",
    "entérinerez": "entériner",
    "entérineriez": "entériner",
    "entérinerions": "entériner",
    "entérinerons": "entériner",
    "entérineront": "entériner",
    "entérines": "entériner",
    "entérinez": "entériner",
    "entériniez": "entériner",
    "entérinions": "entériner",
    "entérinons": "entériner",
    "entérinâmes": "entériner",
    "entérinât": "entériner",
    "entérinâtes": "entériner",
    "entérinèrent": "entériner",
    "entériné": "entériner",
    "entérinée": "entériner",
    "entérinées": "entériner",
    "entérinés": "entériner",
    "entérites": "entérite",
    "entés": "enter",
    "entêta": "entêter",
    "entêtai": "entêter",
    "entêtaient": "entêter",
    "entêtais": "entêter",
    "entêtait": "entêter",
    "entêtant": "entêter",
    "entêtante": "entêtant",
    "entêtantes": "entêtant",
    "entêtants": "entêtant",
    "entêtas": "entêter",
    "entêtasse": "entêter",
    "entêtassent": "entêter",
    "entêtasses": "entêter",
    "entêtassiez": "entêter",
    "entêtassions": "entêter",
    "entête": "entêter",
    "entêtements": "entêtement",
    "entêtent": "entêter",
    "entêtera": "entêter",
    "entêterai": "entêter",
    "entêteraient": "entêter",
    "entêterais": "entêter",
    "entêterait": "entêter",
    "entêteras": "entêter",
    "entêterez": "entêter",
    "entêteriez": "entêter",
    "entêterions": "entêter",
    "entêterons": "entêter",
    "entêteront": "entêter",
    "entêtes": "entêter",
    "entêtez": "entêter",
    "entêtiez": "entêter",
    "entêtions": "entêter",
    "entêtons": "entêter",
    "entêtâmes": "entêter",
    "entêtât": "entêter",
    "entêtâtes": "entêter",
    "entêtèrent": "entêter",
    "entêté": "entêter",
    "entêtée": "entêter",
    "entêtées": "entêter",
    "entêtés": "entêter",
    "entôlé": "entôler",
    "entôlée": "entôler",
    "envahi": "envahir",
    "envahie": "envahir",
    "envahies": "envahir",
    "envahira": "envahir",
    "envahirai": "envahir",
    "envahiraient": "envahir",
    "envahirais": "envahir",
    "envahirait": "envahir",
    "envahiras": "envahir",
    "envahirent": "envahir",
    "envahirez": "envahir",
    "envahiriez": "envahir",
    "envahirions": "envahir",
    "envahirons": "envahir",
    "envahiront": "envahir",
    "envahis": "envahir",
    "envahissaient": "envahir",
    "envahissais": "envahir",
    "envahissait": "envahir",
    "envahissant": "envahir",
    "envahissante": "envahissant",
    "envahissantes": "envahissant",
    "envahissants": "envahissant",
    "envahisse": "envahir",
    "envahissements": "envahissement",
    "envahissent": "envahir",
    "envahisses": "envahir",
    "envahisseurs": "envahisseur",
    "envahissez": "envahir",
    "envahissiez": "envahir",
    "envahissions": "envahir",
    "envahissons": "envahir",
    "envahit": "envahir",
    "envahîmes": "envahir",
    "envahît": "envahir",
    "envahîtes": "envahir",
    "envasa": "envaser",
    "envasai": "envaser",
    "envasaient": "envaser",
    "envasais": "envaser",
    "envasait": "envaser",
    "envasant": "envaser",
    "envasas": "envaser",
    "envasasse": "envaser",
    "envasassent": "envaser",
    "envasasses": "envaser",
    "envasassiez": "envaser",
    "envasassions": "envaser",
    "envase": "envaser",
    "envasent": "envaser",
    "envasera": "envaser",
    "envaserai": "envaser",
    "envaseraient": "envaser",
    "envaserais": "envaser",
    "envaserait": "envaser",
    "envaseras": "envaser",
    "envaserez": "envaser",
    "envaseriez": "envaser",
    "envaserions": "envaser",
    "envaserons": "envaser",
    "envaseront": "envaser",
    "envases": "envaser",
    "envasez": "envaser",
    "envasiez": "envaser",
    "envasions": "envaser",
    "envasons": "envaser",
    "envasâmes": "envaser",
    "envasât": "envaser",
    "envasâtes": "envaser",
    "envasèrent": "envaser",
    "envasé": "envaser",
    "envasée": "envaser",
    "envasées": "envaser",
    "envasés": "envaser",
    "enveloppa": "envelopper",
    "enveloppai": "envelopper",
    "enveloppaient": "envelopper",
    "enveloppais": "envelopper",
    "enveloppait": "envelopper",
    "enveloppant": "envelopper",
    "enveloppante": "enveloppant",
    "enveloppantes": "enveloppant",
    "enveloppants": "enveloppant",
    "enveloppas": "envelopper",
    "enveloppasse": "envelopper",
    "enveloppassent": "envelopper",
    "enveloppasses": "envelopper",
    "enveloppassiez": "envelopper",
    "enveloppassions": "envelopper",
    "enveloppe": "envelopper",
    "enveloppements": "enveloppement",
    "enveloppent": "envelopper",
    "enveloppera": "envelopper",
    "envelopperai": "envelopper",
    "envelopperaient": "envelopper",
    "envelopperais": "envelopper",
    "envelopperait": "envelopper",
    "envelopperas": "envelopper",
    "envelopperez": "envelopper",
    "envelopperiez": "envelopper",
    "envelopperions": "envelopper",
    "envelopperons": "envelopper",
    "envelopperont": "envelopper",
    "enveloppes": "envelopper",
    "enveloppez": "envelopper",
    "enveloppiez": "envelopper",
    "enveloppions": "envelopper",
    "enveloppons": "envelopper",
    "enveloppâmes": "envelopper",
    "enveloppât": "envelopper",
    "enveloppâtes": "envelopper",
    "enveloppèrent": "envelopper",
    "enveloppé": "envelopper",
    "enveloppée": "envelopper",
    "enveloppées": "envelopper",
    "enveloppés": "envelopper",
    "envenima": "envenimer",
    "envenimai": "envenimer",
    "envenimaient": "envenimer",
    "envenimais": "envenimer",
    "envenimait": "envenimer",
    "envenimant": "envenimer",
    "envenimas": "envenimer",
    "envenimasse": "envenimer",
    "envenimassent": "envenimer",
    "envenimasses": "envenimer",
    "envenimassiez": "envenimer",
    "envenimassions": "envenimer",
    "envenime": "envenimer",
    "enveniment": "envenimer",
    "envenimera": "envenimer",
    "envenimerai": "envenimer",
    "envenimeraient": "envenimer",
    "envenimerais": "envenimer",
    "envenimerait": "envenimer",
    "envenimeras": "envenimer",
    "envenimerez": "envenimer",
    "envenimeriez": "envenimer",
    "envenimerions": "envenimer",
    "envenimerons": "envenimer",
    "envenimeront": "envenimer",
    "envenimes": "envenimer",
    "envenimez": "envenimer",
    "envenimiez": "envenimer",
    "envenimions": "envenimer",
    "envenimons": "envenimer",
    "envenimâmes": "envenimer",
    "envenimât": "envenimer",
    "envenimâtes": "envenimer",
    "envenimèrent": "envenimer",
    "envenimé": "envenimer",
    "envenimée": "envenimer",
    "envenimées": "envenimer",
    "envenimés": "envenimer",
    "envergures": "envergure",
    "enverguée": "enverguer",
    "enverra": "envoyer",
    "enverrai": "envoyer",
    "enverraient": "envoyer",
    "enverrais": "envoyer",
    "enverrait": "envoyer",
    "enverras": "envoyer",
    "enverrez": "envoyer",
    "enverriez": "envoyer",
    "enverrions": "envoyer",
    "enverrons": "envoyer",
    "enverront": "envoyer",
    "enverss": "envers",
    "envia": "envier",
    "enviables": "enviable",
    "enviai": "envier",
    "enviaient": "envier",
    "enviais": "envier",
    "enviait": "envier",
    "enviandait": "enviander",
    "enviandés": "enviandé",
    "enviant": "envier",
    "envias": "envier",
    "enviasse": "envier",
    "enviassent": "envier",
    "enviasses": "envier",
    "enviassiez": "envier",
    "enviassions": "envier",
    "envida": "envider",
    "envidai": "envider",
    "envidaient": "envider",
    "envidais": "envider",
    "envidait": "envider",
    "envidant": "envider",
    "envidas": "envider",
    "envidasse": "envider",
    "envidassent": "envider",
    "envidasses": "envider",
    "envidassiez": "envider",
    "envidassions": "envider",
    "envide": "envider",
    "envident": "envider",
    "envidera": "envider",
    "enviderai": "envider",
    "envideraient": "envider",
    "enviderais": "envider",
    "enviderait": "envider",
    "envideras": "envider",
    "enviderez": "envider",
    "envideriez": "envider",
    "enviderions": "envider",
    "enviderons": "envider",
    "envideront": "envider",
    "envides": "envider",
    "envidez": "envider",
    "envidiez": "envider",
    "envidions": "envider",
    "envidons": "envider",
    "envidâmes": "envider",
    "envidât": "envider",
    "envidâtes": "envider",
    "envidèrent": "envider",
    "envidé": "envider",
    "envidée": "envider",
    "envidées": "envider",
    "envidés": "envider",
    "envie": "envier",
    "envieilli": "envieillir",
    "envieillie": "envieillir",
    "envieillies": "envieillir",
    "envieillira": "envieillir",
    "envieillirai": "envieillir",
    "envieilliraient": "envieillir",
    "envieillirais": "envieillir",
    "envieillirait": "envieillir",
    "envieilliras": "envieillir",
    "envieillirent": "envieillir",
    "envieillirez": "envieillir",
    "envieilliriez": "envieillir",
    "envieillirions": "envieillir",
    "envieillirons": "envieillir",
    "envieilliront": "envieillir",
    "envieillis": "envieillir",
    "envieillissaient": "envieillir",
    "envieillissais": "envieillir",
    "envieillissait": "envieillir",
    "envieillissant": "envieillir",
    "envieillisse": "envieillir",
    "envieillissent": "envieillir",
    "envieillisses": "envieillir",
    "envieillissez": "envieillir",
    "envieillissiez": "envieillir",
    "envieillissions": "envieillir",
    "envieillissons": "envieillir",
    "envieillit": "envieillir",
    "envieillîmes": "envieillir",
    "envieillît": "envieillir",
    "envieillîtes": "envieillir",
    "envient": "envier",
    "enviera": "envier",
    "envierai": "envier",
    "envieraient": "envier",
    "envierais": "envier",
    "envierait": "envier",
    "envieras": "envier",
    "envierez": "envier",
    "envieriez": "envier",
    "envierions": "envier",
    "envierons": "envier",
    "envieront": "envier",
    "envies": "envier",
    "envieuse": "envieux",
    "envieuses": "envieux",
    "enviez": "envier",
    "enviiez": "envier",
    "enviions": "envier",
    "envions": "envier",
    "environna": "environner",
    "environnai": "environner",
    "environnaient": "environner",
    "environnais": "environner",
    "environnait": "environner",
    "environnant": "environner",
    "environnante": "environnant",
    "environnantes": "environnant",
    "environnants": "environnant",
    "environnas": "environner",
    "environnasse": "environner",
    "environnassent": "environner",
    "environnasses": "environner",
    "environnassiez": "environner",
    "environnassions": "environner",
    "environne": "environner",
    "environnementale": "environnemental",
    "environnementales": "environnemental",
    "environnementalismes": "environnementalisme",
    "environnementaux": "environnemental",
    "environnements": "environnement",
    "environnent": "environner",
    "environnera": "environner",
    "environnerai": "environner",
    "environneraient": "environner",
    "environnerais": "environner",
    "environnerait": "environner",
    "environneras": "environner",
    "environnerez": "environner",
    "environneriez": "environner",
    "environnerions": "environner",
    "environnerons": "environner",
    "environneront": "environner",
    "environnes": "environner",
    "environnez": "environner",
    "environniez": "environner",
    "environnions": "environner",
    "environnons": "environner",
    "environnâmes": "environner",
    "environnât": "environner",
    "environnâtes": "environner",
    "environnèrent": "environner",
    "environné": "environner",
    "environnée": "environner",
    "environnées": "environner",
    "environnés": "environner",
    "environs": "environ",
    "envisage": "envisager",
    "envisagea": "envisager",
    "envisageables": "envisageable",
    "envisageai": "envisager",
    "envisageaient": "envisager",
    "envisageais": "envisager",
    "envisageait": "envisager",
    "envisageant": "envisager",
    "envisageas": "envisager",
    "envisageasse": "envisager",
    "envisageassent": "envisager",
    "envisageasses": "envisager",
    "envisageassiez": "envisager",
    "envisageassions": "envisager",
    "envisagent": "envisager",
    "envisageons": "envisager",
    "envisagera": "envisager",
    "envisagerai": "envisager",
    "envisageraient": "envisager",
    "envisagerais": "envisager",
    "envisagerait": "envisager",
    "envisageras": "envisager",
    "envisagerez": "envisager",
    "envisageriez": "envisager",
    "envisagerions": "envisager",
    "envisagerons": "envisager",
    "envisageront": "envisager",
    "envisages": "envisager",
    "envisagez": "envisager",
    "envisageâmes": "envisager",
    "envisageât": "envisager",
    "envisageâtes": "envisager",
    "envisagiez": "envisager",
    "envisagions": "envisager",
    "envisagèrent": "envisager",
    "envisagé": "envisager",
    "envisagée": "envisager",
    "envisagées": "envisager",
    "envisagés": "envisager",
    "enviâmes": "envier",
    "enviât": "envier",
    "enviâtes": "envier",
    "envièrent": "envier",
    "envié": "envier",
    "enviée": "envier",
    "enviées": "envier",
    "enviés": "envier",
    "envoie": "envoyer",
    "envoient": "envoyer",
    "envoies": "envoyer",
    "envoila": "envoiler",
    "envoilai": "envoiler",
    "envoilaient": "envoiler",
    "envoilais": "envoiler",
    "envoilait": "envoiler",
    "envoilant": "envoiler",
    "envoilas": "envoiler",
    "envoilasse": "envoiler",
    "envoilassent": "envoiler",
    "envoilasses": "envoiler",
    "envoilassiez": "envoiler",
    "envoilassions": "envoiler",
    "envoile": "envoiler",
    "envoilent": "envoiler",
    "envoilera": "envoiler",
    "envoilerai": "envoiler",
    "envoileraient": "envoiler",
    "envoilerais": "envoiler",
    "envoilerait": "envoiler",
    "envoileras": "envoiler",
    "envoilerez": "envoiler",
    "envoileriez": "envoiler",
    "envoilerions": "envoiler",
    "envoilerons": "envoiler",
    "envoileront": "envoiler",
    "envoiles": "envoiler",
    "envoilez": "envoiler",
    "envoiliez": "envoiler",
    "envoilions": "envoiler",
    "envoilons": "envoiler",
    "envoilâmes": "envoiler",
    "envoilât": "envoiler",
    "envoilâtes": "envoiler",
    "envoilèrent": "envoiler",
    "envoilé": "envoiler",
    "envoilée": "envoiler",
    "envoilées": "envoiler",
    "envoilés": "envoiler",
    "envois": "envoi",
    "envola": "envoler",
    "envolai": "envoler",
    "envolaient": "envoler",
    "envolais": "envoler",
    "envolait": "envoler",
    "envolant": "envoler",
    "envolas": "envoler",
    "envolasse": "envoler",
    "envolassent": "envoler",
    "envolasses": "envoler",
    "envolassiez": "envoler",
    "envolassions": "envoler",
    "envole": "envoler",
    "envolent": "envoler",
    "envolera": "envoler",
    "envolerai": "envoler",
    "envoleraient": "envoler",
    "envolerais": "envoler",
    "envolerait": "envoler",
    "envoleras": "envoler",
    "envolerez": "envoler",
    "envoleriez": "envoler",
    "envolerions": "envoler",
    "envolerons": "envoler",
    "envoleront": "envoler",
    "envoles": "envoler",
    "envolez": "envoler",
    "envoliez": "envoler",
    "envolions": "envoler",
    "envolons": "envoler",
    "envols": "envol",
    "envolâmes": "envoler",
    "envolât": "envoler",
    "envolâtes": "envoler",
    "envolèrent": "envoler",
    "envolé": "envoler",
    "envolée": "envoler",
    "envolées": "envoler",
    "envolés": "envoler",
    "envoya": "envoyer",
    "envoyai": "envoyer",
    "envoyaient": "envoyer",
    "envoyais": "envoyer",
    "envoyait": "envoyer",
    "envoyant": "envoyer",
    "envoyas": "envoyer",
    "envoyasse": "envoyer",
    "envoyassent": "envoyer",
    "envoyasses": "envoyer",
    "envoyassiez": "envoyer",
    "envoyassions": "envoyer",
    "envoyeurs": "envoyeur",
    "envoyeuse": "envoyeur",
    "envoyeuses": "envoyeur",
    "envoyez": "envoyer",
    "envoyiez": "envoyer",
    "envoyions": "envoyer",
    "envoyons": "envoyer",
    "envoyâmes": "envoyer",
    "envoyât": "envoyer",
    "envoyâtes": "envoyer",
    "envoyèrent": "envoyer",
    "envoyé": "envoyer",
    "envoyée": "envoyer",
    "envoyées": "envoyer",
    "envoyés": "envoyer",
    "envoûta": "envoûter",
    "envoûtai": "envoûter",
    "envoûtaient": "envoûter",
    "envoûtais": "envoûter",
    "envoûtait": "envoûter",
    "envoûtant": "envoûter",
    "envoûtante": "envoûtant",
    "envoûtantes": "envoûtant",
    "envoûtants": "envoûtant",
    "envoûtas": "envoûter",
    "envoûtasse": "envoûter",
    "envoûtassent": "envoûter",
    "envoûtasses": "envoûter",
    "envoûtassiez": "envoûter",
    "envoûtassions": "envoûter",
    "envoûte": "envoûter",
    "envoûtements": "envoûtement",
    "envoûtent": "envoûter",
    "envoûtera": "envoûter",
    "envoûterai": "envoûter",
    "envoûteraient": "envoûter",
    "envoûterais": "envoûter",
    "envoûterait": "envoûter",
    "envoûteras": "envoûter",
    "envoûterez": "envoûter",
    "envoûteriez": "envoûter",
    "envoûterions": "envoûter",
    "envoûterons": "envoûter",
    "envoûteront": "envoûter",
    "envoûtes": "envoûter",
    "envoûteurs": "envoûteur",
    "envoûtez": "envoûter",
    "envoûtiez": "envoûter",
    "envoûtions": "envoûter",
    "envoûtons": "envoûter",
    "envoûtâmes": "envoûter",
    "envoûtât": "envoûter",
    "envoûtâtes": "envoûter",
    "envoûtèrent": "envoûter",
    "envoûté": "envoûter",
    "envoûtée": "envoûter",
    "envoûtées": "envoûter",
    "envoûtés": "envoûter",
    "enzymatiques": "enzymatique",
    "enzymes": "enzyme",
    "epsilons": "epsilon",
    "ergastules": "ergastule",
    "ergota": "ergoter",
    "ergotai": "ergoter",
    "ergotaient": "ergoter",
    "ergotais": "ergoter",
    "ergotait": "ergoter",
    "ergotant": "ergoter",
    "ergotas": "ergoter",
    "ergotasse": "ergoter",
    "ergotassent": "ergoter",
    "ergotasses": "ergoter",
    "ergotassiez": "ergoter",
    "ergotassions": "ergoter",
    "ergote": "ergoter",
    "ergotent": "ergoter",
    "ergotera": "ergoter",
    "ergoterai": "ergoter",
    "ergoteraient": "ergoter",
    "ergoterais": "ergoter",
    "ergoterait": "ergoter",
    "ergoteras": "ergoter",
    "ergoterez": "ergoter",
    "ergoteriez": "ergoter",
    "ergoterions": "ergoter",
    "ergoterons": "ergoter",
    "ergoteront": "ergoter",
    "ergotes": "ergoter",
    "ergoteurs": "ergoteur",
    "ergoteuse": "ergoteur",
    "ergotez": "ergoter",
    "ergotiez": "ergoter",
    "ergotines": "ergotine",
    "ergotions": "ergoter",
    "ergotons": "ergoter",
    "ergots": "ergot",
    "ergotâmes": "ergoter",
    "ergotât": "ergoter",
    "ergotâtes": "ergoter",
    "ergotèrent": "ergoter",
    "ergoté": "ergoter",
    "ergs": "erg",
    "ermitages": "ermitage",
    "ermites": "ermite",
    "erra": "errer",
    "errai": "errer",
    "erraient": "errer",
    "errais": "errer",
    "errait": "errer",
    "errances": "errance",
    "errant": "errer",
    "errante": "errant",
    "errantes": "errant",
    "errants": "errant",
    "erras": "errer",
    "errasse": "errer",
    "errassent": "errer",
    "errasses": "errer",
    "errassiez": "errer",
    "errassions": "errer",
    "errata": "erratum",
    "erratiques": "erratique",
    "erratums": "erratum",
    "erre": "errer",
    "errements": "errement",
    "errent": "errer",
    "errera": "errer",
    "errerai": "errer",
    "erreraient": "errer",
    "errerais": "errer",
    "errerait": "errer",
    "erreras": "errer",
    "errerez": "errer",
    "erreriez": "errer",
    "errerions": "errer",
    "errerons": "errer",
    "erreront": "errer",
    "erres": "errer",
    "erreurs": "erreur",
    "errez": "errer",
    "erriez": "errer",
    "errions": "errer",
    "errons": "errer",
    "erronée": "erroné",
    "erronées": "erroné",
    "erronés": "erroné",
    "errâmes": "errer",
    "errât": "errer",
    "errâtes": "errer",
    "errèrent": "errer",
    "erré": "errer",
    "errés": "errer",
    "erses": "erse",
    "es": "être",
    "esbignais": "esbigner",
    "esbignait": "esbigner",
    "esbigne": "esbigner",
    "esbignent": "esbigner",
    "esbigné": "esbigner",
    "esbroufa": "esbroufer",
    "esbroufai": "esbroufer",
    "esbroufaient": "esbroufer",
    "esbroufais": "esbroufer",
    "esbroufait": "esbroufer",
    "esbroufant": "esbroufer",
    "esbroufas": "esbroufer",
    "esbroufasse": "esbroufer",
    "esbroufassent": "esbroufer",
    "esbroufasses": "esbroufer",
    "esbroufassiez": "esbroufer",
    "esbroufassions": "esbroufer",
    "esbroufe": "esbroufer",
    "esbroufent": "esbroufer",
    "esbroufera": "esbroufer",
    "esbrouferai": "esbroufer",
    "esbrouferaient": "esbroufer",
    "esbrouferais": "esbroufer",
    "esbrouferait": "esbroufer",
    "esbrouferas": "esbroufer",
    "esbrouferez": "esbroufer",
    "esbrouferiez": "esbroufer",
    "esbrouferions": "esbroufer",
    "esbrouferons": "esbroufer",
    "esbrouferont": "esbroufer",
    "esbroufes": "esbroufer",
    "esbroufeurs": "esbroufeur",
    "esbroufez": "esbroufer",
    "esbroufiez": "esbroufer",
    "esbroufions": "esbroufer",
    "esbroufons": "esbroufer",
    "esbroufâmes": "esbroufer",
    "esbroufât": "esbroufer",
    "esbroufâtes": "esbroufer",
    "esbroufèrent": "esbroufer",
    "esbroufé": "esbroufer",
    "esbroufée": "esbroufer",
    "esbroufées": "esbroufer",
    "esbroufés": "esbroufer",
    "escabeaux": "escabeau",
    "escabèches": "escabèche",
    "escadres": "escadre",
    "escadrilles": "escadrille",
    "escadrons": "escadron",
    "escagasse": "escagasser",
    "escalada": "escalader",
    "escaladai": "escalader",
    "escaladaient": "escalader",
    "escaladais": "escalader",
    "escaladait": "escalader",
    "escaladant": "escalader",
    "escaladas": "escalader",
    "escaladasse": "escalader",
    "escaladassent": "escalader",
    "escaladasses": "escalader",
    "escaladassiez": "escalader",
    "escaladassions": "escalader",
    "escalade": "escalader",
    "escaladent": "escalader",
    "escaladera": "escalader",
    "escaladerai": "escalader",
    "escaladeraient": "escalader",
    "escaladerais": "escalader",
    "escaladerait": "escalader",
    "escaladeras": "escalader",
    "escaladerez": "escalader",
    "escaladeriez": "escalader",
    "escaladerions": "escalader",
    "escaladerons": "escalader",
    "escaladeront": "escalader",
    "escalades": "escalader",
    "escaladeuse": "escaladeur",
    "escaladeuses": "escaladeur",
    "escaladez": "escalader",
    "escaladiez": "escalader",
    "escaladions": "escalader",
    "escaladons": "escalader",
    "escaladâmes": "escalader",
    "escaladât": "escalader",
    "escaladâtes": "escalader",
    "escaladèrent": "escalader",
    "escaladé": "escalader",
    "escaladée": "escalader",
    "escaladées": "escalader",
    "escaladés": "escalader",
    "escalais": "escaler",
    "escalators": "escalator",
    "escalera": "escaler",
    "escales": "escale",
    "escaliers": "escalier",
    "escalopes": "escalope",
    "escamota": "escamoter",
    "escamotables": "escamotable",
    "escamotages": "escamotage",
    "escamotai": "escamoter",
    "escamotaient": "escamoter",
    "escamotais": "escamoter",
    "escamotait": "escamoter",
    "escamotant": "escamoter",
    "escamotas": "escamoter",
    "escamotasse": "escamoter",
    "escamotassent": "escamoter",
    "escamotasses": "escamoter",
    "escamotassiez": "escamoter",
    "escamotassions": "escamoter",
    "escamote": "escamoter",
    "escamotent": "escamoter",
    "escamotera": "escamoter",
    "escamoterai": "escamoter",
    "escamoteraient": "escamoter",
    "escamoterais": "escamoter",
    "escamoterait": "escamoter",
    "escamoteras": "escamoter",
    "escamoterez": "escamoter",
    "escamoteriez": "escamoter",
    "escamoterions": "escamoter",
    "escamoterons": "escamoter",
    "escamoteront": "escamoter",
    "escamotes": "escamoter",
    "escamotez": "escamoter",
    "escamotiez": "escamoter",
    "escamotions": "escamoter",
    "escamotons": "escamoter",
    "escamotâmes": "escamoter",
    "escamotât": "escamoter",
    "escamotâtes": "escamoter",
    "escamotèrent": "escamoter",
    "escamoté": "escamoter",
    "escamotée": "escamoter",
    "escamotées": "escamoter",
    "escamotés": "escamoter",
    "escampettes": "escampette",
    "escapades": "escapade",
    "escarbilles": "escarbille",
    "escarbots": "escarbot",
    "escarboucles": "escarboucle",
    "escarcelles": "escarcelle",
    "escargots": "escargot",
    "escarmouchaient": "escarmoucher",
    "escarmouchent": "escarmoucher",
    "escarmouches": "escarmouche",
    "escarpements": "escarpement",
    "escarpes": "escarpe",
    "escarpins": "escarpin",
    "escarpolettes": "escarpolette",
    "escarpé": "escarper",
    "escarpée": "escarper",
    "escarpées": "escarper",
    "escarpés": "escarpé",
    "escarres": "escarre",
    "eschatologies": "eschatologie",
    "esches": "esche",
    "escients": "escient",
    "esclaffa": "esclaffer",
    "esclaffai": "esclaffer",
    "esclaffaient": "esclaffer",
    "esclaffais": "esclaffer",
    "esclaffait": "esclaffer",
    "esclaffant": "esclaffer",
    "esclaffas": "esclaffer",
    "esclaffasse": "esclaffer",
    "esclaffassent": "esclaffer",
    "esclaffasses": "esclaffer",
    "esclaffassiez": "esclaffer",
    "esclaffassions": "esclaffer",
    "esclaffe": "esclaffer",
    "esclaffements": "esclaffement",
    "esclaffent": "esclaffer",
    "esclaffera": "esclaffer",
    "esclafferai": "esclaffer",
    "esclafferaient": "esclaffer",
    "esclafferais": "esclaffer",
    "esclafferait": "esclaffer",
    "esclafferas": "esclaffer",
    "esclafferez": "esclaffer",
    "esclafferiez": "esclaffer",
    "esclafferions": "esclaffer",
    "esclafferons": "esclaffer",
    "esclafferont": "esclaffer",
    "esclaffes": "esclaffer",
    "esclaffez": "esclaffer",
    "esclaffiez": "esclaffer",
    "esclaffions": "esclaffer",
    "esclaffons": "esclaffer",
    "esclaffâmes": "esclaffer",
    "esclaffât": "esclaffer",
    "esclaffâtes": "esclaffer",
    "esclaffèrent": "esclaffer",
    "esclaffé": "esclaffer",
    "esclaffée": "esclaffer",
    "esclaffées": "esclaffer",
    "esclaffés": "esclaffer",
    "esclandres": "esclandre",
    "esclavagea": "esclavager",
    "esclavages": "esclavage",
    "esclavagistes": "esclavagiste",
    "esclavagé": "esclavager",
    "esclaves": "esclave",
    "esclavons": "esclavon",
    "escogriffes": "escogriffe",
    "escompta": "escompter",
    "escomptai": "escompter",
    "escomptaient": "escompter",
    "escomptais": "escompter",
    "escomptait": "escompter",
    "escomptant": "escompter",
    "escomptas": "escompter",
    "escomptasse": "escompter",
    "escomptassent": "escompter",
    "escomptasses": "escompter",
    "escomptassiez": "escompter",
    "escomptassions": "escompter",
    "escompte": "escompter",
    "escomptent": "escompter",
    "escomptera": "escompter",
    "escompterai": "escompter",
    "escompteraient": "escompter",
    "escompterais": "escompter",
    "escompterait": "escompter",
    "escompteras": "escompter",
    "escompterez": "escompter",
    "escompteriez": "escompter",
    "escompterions": "escompter",
    "escompterons": "escompter",
    "escompteront": "escompter",
    "escomptes": "escompter",
    "escomptez": "escompter",
    "escomptiez": "escompter",
    "escomptions": "escompter",
    "escomptons": "escompter",
    "escomptâmes": "escompter",
    "escomptât": "escompter",
    "escomptâtes": "escompter",
    "escomptèrent": "escompter",
    "escompté": "escompter",
    "escomptée": "escompter",
    "escomptées": "escompter",
    "escomptés": "escompter",
    "escopettes": "escopette",
    "escorta": "escorter",
    "escortai": "escorter",
    "escortaient": "escorter",
    "escortais": "escorter",
    "escortait": "escorter",
    "escortant": "escorter",
    "escortas": "escorter",
    "escortasse": "escorter",
    "escortassent": "escorter",
    "escortasses": "escorter",
    "escortassiez": "escorter",
    "escortassions": "escorter",
    "escorte": "escorter",
    "escortent": "escorter",
    "escortera": "escorter",
    "escorterai": "escorter",
    "escorteraient": "escorter",
    "escorterais": "escorter",
    "escorterait": "escorter",
    "escorteras": "escorter",
    "escorterez": "escorter",
    "escorteriez": "escorter",
    "escorterions": "escorter",
    "escorterons": "escorter",
    "escorteront": "escorter",
    "escortes": "escorter",
    "escorteurs": "escorteur",
    "escortez": "escorter",
    "escortiez": "escorter",
    "escortions": "escorter",
    "escortons": "escorter",
    "escortâmes": "escorter",
    "escortât": "escorter",
    "escortâtes": "escorter",
    "escortèrent": "escorter",
    "escorté": "escorter",
    "escortée": "escorter",
    "escortées": "escorter",
    "escortés": "escorter",
    "escouades": "escouade",
    "escourgeons": "escourgeon",
    "escrimai": "escrimer",
    "escrimaient": "escrimer",
    "escrimais": "escrimer",
    "escrimait": "escrimer",
    "escrimant": "escrimer",
    "escrime": "escrimer",
    "escriment": "escrimer",
    "escrimera": "escrimer",
    "escrimeraient": "escrimer",
    "escrimes": "escrimer",
    "escrimeurs": "escrimeur",
    "escrimeuses": "escrimeur",
    "escrocs": "escroc",
    "escroqua": "escroquer",
    "escroquai": "escroquer",
    "escroquaient": "escroquer",
    "escroquais": "escroquer",
    "escroquait": "escroquer",
    "escroquant": "escroquer",
    "escroquas": "escroquer",
    "escroquasse": "escroquer",
    "escroquassent": "escroquer",
    "escroquasses": "escroquer",
    "escroquassiez": "escroquer",
    "escroquassions": "escroquer",
    "escroque": "escroquer",
    "escroquent": "escroquer",
    "escroquera": "escroquer",
    "escroquerai": "escroquer",
    "escroqueraient": "escroquer",
    "escroquerais": "escroquer",
    "escroquerait": "escroquer",
    "escroqueras": "escroquer",
    "escroquerez": "escroquer",
    "escroqueries": "escroquerie",
    "escroqueriez": "escroquer",
    "escroquerions": "escroquer",
    "escroquerons": "escroquer",
    "escroqueront": "escroquer",
    "escroques": "escroquer",
    "escroqueuse": "escroqueur",
    "escroquez": "escroquer",
    "escroquiez": "escroquer",
    "escroquions": "escroquer",
    "escroquons": "escroquer",
    "escroquâmes": "escroquer",
    "escroquât": "escroquer",
    "escroquâtes": "escroquer",
    "escroquèrent": "escroquer",
    "escroqué": "escroquer",
    "escroquée": "escroquer",
    "escroquées": "escroquer",
    "escroqués": "escroquer",
    "escudos": "escudo",
    "esgourdai": "esgourder",
    "esgourdant": "esgourder",
    "esgourdes": "esgourde",
    "esgourdé": "esgourder",
    "esgourdée": "esgourder",
    "eskimos": "eskimo",
    "espace": "espacer",
    "espacements": "espacement",
    "espacent": "espacer",
    "espacerait": "espacer",
    "espaceront": "espacer",
    "espaces": "espace",
    "espacez": "espacer",
    "espacions": "espacer",
    "espacèrent": "espacer",
    "espacé": "espacer",
    "espacée": "espacer",
    "espacées": "espacer",
    "espacés": "espacer",
    "espadas": "espada",
    "espadons": "espadon",
    "espadrilles": "espadrille",
    "espagnole": "espagnol",
    "espagnoles": "espagnol",
    "espagnolettes": "espagnolette",
    "espagnols": "espagnol",
    "espaliers": "espalier",
    "espaça": "espacer",
    "espaçaient": "espacer",
    "espaçait": "espacer",
    "espaçant": "espacer",
    "esperantos": "esperanto",
    "espingoles": "espingole",
    "espingos": "espingo",
    "espingouins": "espingouin",
    "espionna": "espionner",
    "espionnages": "espionnage",
    "espionnai": "espionner",
    "espionnaient": "espionner",
    "espionnais": "espionner",
    "espionnait": "espionner",
    "espionnant": "espionner",
    "espionnas": "espionner",
    "espionnasse": "espionner",
    "espionnassent": "espionner",
    "espionnasses": "espionner",
    "espionnassiez": "espionner",
    "espionnassions": "espionner",
    "espionne": "espionner",
    "espionnent": "espionner",
    "espionnera": "espionner",
    "espionnerai": "espionner",
    "espionneraient": "espionner",
    "espionnerais": "espionner",
    "espionnerait": "espionner",
    "espionneras": "espionner",
    "espionnerez": "espionner",
    "espionneriez": "espionner",
    "espionnerions": "espionner",
    "espionnerons": "espionner",
    "espionneront": "espionner",
    "espionnes": "espionner",
    "espionnez": "espionner",
    "espionniez": "espionner",
    "espionnions": "espionner",
    "espionnons": "espionner",
    "espionnâmes": "espionner",
    "espionnât": "espionner",
    "espionnâtes": "espionner",
    "espionnèrent": "espionner",
    "espionné": "espionner",
    "espionnée": "espionner",
    "espionnées": "espionner",
    "espionnés": "espionner",
    "espions": "espion",
    "espiègleries": "espièglerie",
    "espiègles": "espiègle",
    "esplanades": "esplanade",
    "espoirs": "espoir",
    "esprits": "esprit",
    "espèces": "espèce",
    "espère": "espérer",
    "espèrent": "espérer",
    "espères": "espérer",
    "espéra": "espérer",
    "espérai": "espérer",
    "espéraient": "espérer",
    "espérais": "espérer",
    "espérait": "espérer",
    "espérances": "espérance",
    "espérant": "espérer",
    "espérantos": "espéranto",
    "espéras": "espérer",
    "espérasse": "espérer",
    "espérassent": "espérer",
    "espérasses": "espérer",
    "espérassiez": "espérer",
    "espérassions": "espérer",
    "espérera": "espérer",
    "espérerai": "espérer",
    "espéreraient": "espérer",
    "espérerais": "espérer",
    "espérerait": "espérer",
    "espéreras": "espérer",
    "espérerez": "espérer",
    "espéreriez": "espérer",
    "espérerions": "espérer",
    "espérerons": "espérer",
    "espéreront": "espérer",
    "espérez": "espérer",
    "espériez": "espérer",
    "espérions": "espérer",
    "espérons": "espérer",
    "espérâmes": "espérer",
    "espérât": "espérer",
    "espérâtes": "espérer",
    "espérèrent": "espérer",
    "espéré": "espérer",
    "espérée": "espérer",
    "espérées": "espérer",
    "espérés": "espérer",
    "esquifs": "esquif",
    "esquilles": "esquille",
    "esquimaude": "esquimaud",
    "esquimaudes": "esquimaud",
    "esquimaux": "esquimau",
    "esquinta": "esquinter",
    "esquintai": "esquinter",
    "esquintaient": "esquinter",
    "esquintais": "esquinter",
    "esquintait": "esquinter",
    "esquintant": "esquinter",
    "esquintas": "esquinter",
    "esquintasse": "esquinter",
    "esquintassent": "esquinter",
    "esquintasses": "esquinter",
    "esquintassiez": "esquinter",
    "esquintassions": "esquinter",
    "esquinte": "esquinter",
    "esquintent": "esquinter",
    "esquintera": "esquinter",
    "esquinterai": "esquinter",
    "esquinteraient": "esquinter",
    "esquinterais": "esquinter",
    "esquinterait": "esquinter",
    "esquinteras": "esquinter",
    "esquinterez": "esquinter",
    "esquinteriez": "esquinter",
    "esquinterions": "esquinter",
    "esquinterons": "esquinter",
    "esquinteront": "esquinter",
    "esquintes": "esquinter",
    "esquintez": "esquinter",
    "esquintiez": "esquinter",
    "esquintions": "esquinter",
    "esquintons": "esquinter",
    "esquintâmes": "esquinter",
    "esquintât": "esquinter",
    "esquintâtes": "esquinter",
    "esquintèrent": "esquinter",
    "esquinté": "esquinter",
    "esquintée": "esquinter",
    "esquintées": "esquinter",
    "esquintés": "esquinter",
    "esquissa": "esquisser",
    "esquissai": "esquisser",
    "esquissaient": "esquisser",
    "esquissais": "esquisser",
    "esquissait": "esquisser",
    "esquissant": "esquisser",
    "esquissas": "esquisser",
    "esquissasse": "esquisser",
    "esquissassent": "esquisser",
    "esquissasses": "esquisser",
    "esquissassiez": "esquisser",
    "esquissassions": "esquisser",
    "esquisse": "esquisser",
    "esquissent": "esquisser",
    "esquissera": "esquisser",
    "esquisserai": "esquisser",
    "esquisseraient": "esquisser",
    "esquisserais": "esquisser",
    "esquisserait": "esquisser",
    "esquisseras": "esquisser",
    "esquisserez": "esquisser",
    "esquisseriez": "esquisser",
    "esquisserions": "esquisser",
    "esquisserons": "esquisser",
    "esquisseront": "esquisser",
    "esquisses": "esquisser",
    "esquissez": "esquisser",
    "esquissiez": "esquisser",
    "esquissions": "esquisser",
    "esquissons": "esquisser",
    "esquissâmes": "esquisser",
    "esquissât": "esquisser",
    "esquissâtes": "esquisser",
    "esquissèrent": "esquisser",
    "esquissé": "esquisser",
    "esquissée": "esquisser",
    "esquissées": "esquisser",
    "esquissés": "esquisser",
    "esquiva": "esquiver",
    "esquivai": "esquiver",
    "esquivaient": "esquiver",
    "esquivais": "esquiver",
    "esquivait": "esquiver",
    "esquivant": "esquiver",
    "esquivas": "esquiver",
    "esquivasse": "esquiver",
    "esquivassent": "esquiver",
    "esquivasses": "esquiver",
    "esquivassiez": "esquiver",
    "esquivassions": "esquiver",
    "esquive": "esquiver",
    "esquivent": "esquiver",
    "esquivera": "esquiver",
    "esquiverai": "esquiver",
    "esquiveraient": "esquiver",
    "esquiverais": "esquiver",
    "esquiverait": "esquiver",
    "esquiveras": "esquiver",
    "esquiverez": "esquiver",
    "esquiveriez": "esquiver",
    "esquiverions": "esquiver",
    "esquiverons": "esquiver",
    "esquiveront": "esquiver",
    "esquives": "esquiver",
    "esquivez": "esquiver",
    "esquiviez": "esquiver",
    "esquivions": "esquiver",
    "esquivons": "esquiver",
    "esquivâmes": "esquiver",
    "esquivât": "esquiver",
    "esquivâtes": "esquiver",
    "esquivèrent": "esquiver",
    "esquivé": "esquiver",
    "esquivée": "esquiver",
    "esquivées": "esquiver",
    "esquivés": "esquiver",
    "essaie": "essayer",
    "essaient": "essayer",
    "essaiera": "essayer",
    "essaierai": "essayer",
    "essaieraient": "essayer",
    "essaierais": "essayer",
    "essaierait": "essayer",
    "essaieras": "essayer",
    "essaierez": "essayer",
    "essaieriez": "essayer",
    "essaierions": "essayer",
    "essaierons": "essayer",
    "essaieront": "essayer",
    "essaies": "essayer",
    "essaima": "essaimer",
    "essaimages": "essaimage",
    "essaimai": "essaimer",
    "essaimaient": "essaimer",
    "essaimais": "essaimer",
    "essaimait": "essaimer",
    "essaimant": "essaimer",
    "essaimas": "essaimer",
    "essaimasse": "essaimer",
    "essaimassent": "essaimer",
    "essaimasses": "essaimer",
    "essaimassiez": "essaimer",
    "essaimassions": "essaimer",
    "essaime": "essaimer",
    "essaiment": "essaimer",
    "essaimera": "essaimer",
    "essaimerai": "essaimer",
    "essaimeraient": "essaimer",
    "essaimerais": "essaimer",
    "essaimerait": "essaimer",
    "essaimeras": "essaimer",
    "essaimerez": "essaimer",
    "essaimeriez": "essaimer",
    "essaimerions": "essaimer",
    "essaimerons": "essaimer",
    "essaimeront": "essaimer",
    "essaimes": "essaimer",
    "essaimez": "essaimer",
    "essaimiez": "essaimer",
    "essaimions": "essaimer",
    "essaimons": "essaimer",
    "essaims": "essaim",
    "essaimâmes": "essaimer",
    "essaimât": "essaimer",
    "essaimâtes": "essaimer",
    "essaimèrent": "essaimer",
    "essaimé": "essaimer",
    "essaimée": "essaimer",
    "essaimées": "essaimer",
    "essaimés": "essaimer",
    "essais": "essai",
    "essangent": "essanger",
    "essarta": "essarter",
    "essartai": "essarter",
    "essartaient": "essarter",
    "essartais": "essarter",
    "essartait": "essarter",
    "essartant": "essarter",
    "essartas": "essarter",
    "essartasse": "essarter",
    "essartassent": "essarter",
    "essartasses": "essarter",
    "essartassiez": "essarter",
    "essartassions": "essarter",
    "essarte": "essarter",
    "essartent": "essarter",
    "essartera": "essarter",
    "essarterai": "essarter",
    "essarteraient": "essarter",
    "essarterais": "essarter",
    "essarterait": "essarter",
    "essarteras": "essarter",
    "essarterez": "essarter",
    "essarteriez": "essarter",
    "essarterions": "essarter",
    "essarterons": "essarter",
    "essarteront": "essarter",
    "essartes": "essarter",
    "essartez": "essarter",
    "essartiez": "essarter",
    "essartions": "essarter",
    "essartons": "essarter",
    "essarts": "essart",
    "essartâmes": "essarter",
    "essartât": "essarter",
    "essartâtes": "essarter",
    "essartèrent": "essarter",
    "essarté": "essarter",
    "essartée": "essarter",
    "essartées": "essarter",
    "essartés": "essarter",
    "essaya": "essayer",
    "essayages": "essayage",
    "essayai": "essayer",
    "essayaient": "essayer",
    "essayais": "essayer",
    "essayait": "essayer",
    "essayant": "essayer",
    "essayas": "essayer",
    "essayasse": "essayer",
    "essayassent": "essayer",
    "essayasses": "essayer",
    "essayassiez": "essayer",
    "essayassions": "essayer",
    "essaye": "essayer",
    "essayent": "essayer",
    "essayera": "essayer",
    "essayerai": "essayer",
    "essayeraient": "essayer",
    "essayerais": "essayer",
    "essayerait": "essayer",
    "essayeras": "essayer",
    "essayerez": "essayer",
    "essayeriez": "essayer",
    "essayerions": "essayer",
    "essayerons": "essayer",
    "essayeront": "essayer",
    "essayes": "essayer",
    "essayeuses": "essayeur",
    "essayez": "essayer",
    "essayiez": "essayer",
    "essayions": "essayer",
    "essayistes": "essayiste",
    "essayons": "essayer",
    "essayâmes": "essayer",
    "essayât": "essayer",
    "essayâtes": "essayer",
    "essayèrent": "essayer",
    "essayé": "essayer",
    "essayée": "essayer",
    "essayées": "essayer",
    "essayés": "essayer",
    "essences": "essence",
    "essentielle": "essentiel",
    "essentielles": "essentiel",
    "essentiels": "essentiel",
    "esses": "esse",
    "esseulé": "esseuler",
    "esseulée": "esseuler",
    "esseulées": "esseuler",
    "esseulés": "esseuler",
    "essieux": "essieu",
    "essora": "essorer",
    "essorai": "essorer",
    "essoraient": "essorer",
    "essorais": "essorer",
    "essorait": "essorer",
    "essorant": "essorer",
    "essoras": "essorer",
    "essorasse": "essorer",
    "essorassent": "essorer",
    "essorasses": "essorer",
    "essorassiez": "essorer",
    "essorassions": "essorer",
    "essore": "essorer",
    "essorent": "essorer",
    "essorera": "essorer",
    "essorerai": "essorer",
    "essoreraient": "essorer",
    "essorerais": "essorer",
    "essorerait": "essorer",
    "essoreras": "essorer",
    "essorerez": "essorer",
    "essoreriez": "essorer",
    "essorerions": "essorer",
    "essorerons": "essorer",
    "essoreront": "essorer",
    "essores": "essorer",
    "essorez": "essorer",
    "essoriez": "essorer",
    "essorilla": "essoriller",
    "essorillai": "essoriller",
    "essorillaient": "essoriller",
    "essorillais": "essoriller",
    "essorillait": "essoriller",
    "essorillant": "essoriller",
    "essorillas": "essoriller",
    "essorillasse": "essoriller",
    "essorillassent": "essoriller",
    "essorillasses": "essoriller",
    "essorillassiez": "essoriller",
    "essorillassions": "essoriller",
    "essorille": "essoriller",
    "essorillent": "essoriller",
    "essorillera": "essoriller",
    "essorillerai": "essoriller",
    "essorilleraient": "essoriller",
    "essorillerais": "essoriller",
    "essorillerait": "essoriller",
    "essorilleras": "essoriller",
    "essorillerez": "essoriller",
    "essorilleriez": "essoriller",
    "essorillerions": "essoriller",
    "essorillerons": "essoriller",
    "essorilleront": "essoriller",
    "essorilles": "essoriller",
    "essorillez": "essoriller",
    "essorilliez": "essoriller",
    "essorillions": "essoriller",
    "essorillons": "essoriller",
    "essorillâmes": "essoriller",
    "essorillât": "essoriller",
    "essorillâtes": "essoriller",
    "essorillèrent": "essoriller",
    "essorillé": "essoriller",
    "essorillée": "essoriller",
    "essorillées": "essoriller",
    "essorillés": "essoriller",
    "essorions": "essorer",
    "essorons": "essorer",
    "essors": "essor",
    "essorâmes": "essorer",
    "essorât": "essorer",
    "essorâtes": "essorer",
    "essorèrent": "essorer",
    "essoré": "essorer",
    "essorée": "essorer",
    "essorées": "essorer",
    "essorés": "essorer",
    "essoucha": "essoucher",
    "essouchai": "essoucher",
    "essouchaient": "essoucher",
    "essouchais": "essoucher",
    "essouchait": "essoucher",
    "essouchant": "essoucher",
    "essouchas": "essoucher",
    "essouchasse": "essoucher",
    "essouchassent": "essoucher",
    "essouchasses": "essoucher",
    "essouchassiez": "essoucher",
    "essouchassions": "essoucher",
    "essouche": "essoucher",
    "essouchent": "essoucher",
    "essouchera": "essoucher",
    "essoucherai": "essoucher",
    "essoucheraient": "essoucher",
    "essoucherais": "essoucher",
    "essoucherait": "essoucher",
    "essoucheras": "essoucher",
    "essoucherez": "essoucher",
    "essoucheriez": "essoucher",
    "essoucherions": "essoucher",
    "essoucherons": "essoucher",
    "essoucheront": "essoucher",
    "essouches": "essoucher",
    "essouchez": "essoucher",
    "essouchiez": "essoucher",
    "essouchions": "essoucher",
    "essouchons": "essoucher",
    "essouchâmes": "essoucher",
    "essouchât": "essoucher",
    "essouchâtes": "essoucher",
    "essouchèrent": "essoucher",
    "essouché": "essoucher",
    "essouchée": "essoucher",
    "essouchées": "essoucher",
    "essouchés": "essoucher",
    "essouffla": "essouffler",
    "essoufflai": "essouffler",
    "essoufflaient": "essouffler",
    "essoufflais": "essouffler",
    "essoufflait": "essouffler",
    "essoufflant": "essouffler",
    "essoufflas": "essouffler",
    "essoufflasse": "essouffler",
    "essoufflassent": "essouffler",
    "essoufflasses": "essouffler",
    "essoufflassiez": "essouffler",
    "essoufflassions": "essouffler",
    "essouffle": "essouffler",
    "essoufflements": "essoufflement",
    "essoufflent": "essouffler",
    "essoufflera": "essouffler",
    "essoufflerai": "essouffler",
    "essouffleraient": "essouffler",
    "essoufflerais": "essouffler",
    "essoufflerait": "essouffler",
    "essouffleras": "essouffler",
    "essoufflerez": "essouffler",
    "essouffleriez": "essouffler",
    "essoufflerions": "essouffler",
    "essoufflerons": "essouffler",
    "essouffleront": "essouffler",
    "essouffles": "essouffler",
    "essoufflez": "essouffler",
    "essouffliez": "essouffler",
    "essoufflions": "essouffler",
    "essoufflons": "essouffler",
    "essoufflâmes": "essouffler",
    "essoufflât": "essouffler",
    "essoufflâtes": "essouffler",
    "essoufflèrent": "essouffler",
    "essoufflé": "essouffler",
    "essoufflée": "essouffler",
    "essoufflées": "essouffler",
    "essoufflés": "essouffler",
    "essuie": "essuyer",
    "essuie-glaces": "essuie-glace",
    "essuie-meubles": "essuie-meuble",
    "essuie-verres": "essuie-verre",
    "essuient": "essuyer",
    "essuiera": "essuyer",
    "essuierai": "essuyer",
    "essuieraient": "essuyer",
    "essuierais": "essuyer",
    "essuierait": "essuyer",
    "essuieras": "essuyer",
    "essuierez": "essuyer",
    "essuieriez": "essuyer",
    "essuierions": "essuyer",
    "essuierons": "essuyer",
    "essuieront": "essuyer",
    "essuies": "essuyer",
    "essuya": "essuyer",
    "essuyages": "essuyage",
    "essuyai": "essuyer",
    "essuyaient": "essuyer",
    "essuyais": "essuyer",
    "essuyait": "essuyer",
    "essuyant": "essuyer",
    "essuyas": "essuyer",
    "essuyasse": "essuyer",
    "essuyassent": "essuyer",
    "essuyasses": "essuyer",
    "essuyassiez": "essuyer",
    "essuyassions": "essuyer",
    "essuyez": "essuyer",
    "essuyiez": "essuyer",
    "essuyions": "essuyer",
    "essuyons": "essuyer",
    "essuyâmes": "essuyer",
    "essuyât": "essuyer",
    "essuyâtes": "essuyer",
    "essuyèrent": "essuyer",
    "essuyé": "essuyer",
    "essuyée": "essuyer",
    "essuyées": "essuyer",
    "essuyés": "essuyer",
    "est": "être",
    "est-allemande": "est-allemand",
    "est-allemands": "est-allemand",
    "establishments": "establishment",
    "estacades": "estacade",
    "estafettes": "estafette",
    "estafiers": "estafier",
    "estafilades": "estafilade",
    "estaminets": "estaminet",
    "estampa": "estamper",
    "estampai": "estamper",
    "estampaient": "estamper",
    "estampais": "estamper",
    "estampait": "estamper",
    "estampant": "estamper",
    "estampas": "estamper",
    "estampasse": "estamper",
    "estampassent": "estamper",
    "estampasses": "estamper",
    "estampassiez": "estamper",
    "estampassions": "estamper",
    "estampe": "estamper",
    "estampent": "estamper",
    "estampera": "estamper",
    "estamperai": "estamper",
    "estamperaient": "estamper",
    "estamperais": "estamper",
    "estamperait": "estamper",
    "estamperas": "estamper",
    "estamperez": "estamper",
    "estamperiez": "estamper",
    "estamperions": "estamper",
    "estamperons": "estamper",
    "estamperont": "estamper",
    "estampes": "estamper",
    "estampez": "estamper",
    "estampiez": "estamper",
    "estampilla": "estampiller",
    "estampillaient": "estampiller",
    "estampilles": "estampille",
    "estampillé": "estampiller",
    "estampillées": "estampillé",
    "estampillés": "estampiller",
    "estampions": "estamper",
    "estampons": "estamper",
    "estampâmes": "estamper",
    "estampât": "estamper",
    "estampâtes": "estamper",
    "estampèrent": "estamper",
    "estampé": "estamper",
    "estampée": "estamper",
    "estampées": "estamper",
    "estampés": "estamper",
    "estancias": "estancia",
    "estes": "este",
    "esthètes": "esthète",
    "esthéticienne": "esthéticien",
    "esthéticiennes": "esthéticien",
    "esthétiques": "esthétique",
    "esthétisait": "esthétiser",
    "estima": "estimer",
    "estimables": "estimable",
    "estimai": "estimer",
    "estimaient": "estimer",
    "estimais": "estimer",
    "estimait": "estimer",
    "estimant": "estimer",
    "estimas": "estimer",
    "estimasse": "estimer",
    "estimassent": "estimer",
    "estimasses": "estimer",
    "estimassiez": "estimer",
    "estimassions": "estimer",
    "estimatifs": "estimatif",
    "estimations": "estimation",
    "estimatives": "estimatif",
    "estime": "estimer",
    "estiment": "estimer",
    "estimera": "estimer",
    "estimerai": "estimer",
    "estimeraient": "estimer",
    "estimerais": "estimer",
    "estimerait": "estimer",
    "estimeras": "estimer",
    "estimerez": "estimer",
    "estimeriez": "estimer",
    "estimerions": "estimer",
    "estimerons": "estimer",
    "estimeront": "estimer",
    "estimes": "estimer",
    "estimez": "estimer",
    "estimiez": "estimer",
    "estimions": "estimer",
    "estimons": "estimer",
    "estimâmes": "estimer",
    "estimât": "estimer",
    "estimâtes": "estimer",
    "estimèrent": "estimer",
    "estimé": "estimer",
    "estimée": "estimer",
    "estimées": "estimer",
    "estimés": "estimer",
    "estivale": "estival",
    "estivales": "estival",
    "estivante": "estivant",
    "estivantes": "estivant",
    "estivants": "estivant",
    "estivaux": "estival",
    "estocades": "estocade",
    "estocs": "estoc",
    "estomacs": "estomac",
    "estomaqua": "estomaquer",
    "estomaquai": "estomaquer",
    "estomaquaient": "estomaquer",
    "estomaquais": "estomaquer",
    "estomaquait": "estomaquer",
    "estomaquant": "estomaquer",
    "estomaquas": "estomaquer",
    "estomaquasse": "estomaquer",
    "estomaquassent": "estomaquer",
    "estomaquasses": "estomaquer",
    "estomaquassiez": "estomaquer",
    "estomaquassions": "estomaquer",
    "estomaque": "estomaquer",
    "estomaquent": "estomaquer",
    "estomaquera": "estomaquer",
    "estomaquerai": "estomaquer",
    "estomaqueraient": "estomaquer",
    "estomaquerais": "estomaquer",
    "estomaquerait": "estomaquer",
    "estomaqueras": "estomaquer",
    "estomaquerez": "estomaquer",
    "estomaqueriez": "estomaquer",
    "estomaquerions": "estomaquer",
    "estomaquerons": "estomaquer",
    "estomaqueront": "estomaquer",
    "estomaques": "estomaquer",
    "estomaquez": "estomaquer",
    "estomaquiez": "estomaquer",
    "estomaquions": "estomaquer",
    "estomaquons": "estomaquer",
    "estomaquâmes": "estomaquer",
    "estomaquât": "estomaquer",
    "estomaquâtes": "estomaquer",
    "estomaquèrent": "estomaquer",
    "estomaqué": "estomaquer",
    "estomaquée": "estomaquer",
    "estomaquées": "estomaquer",
    "estomaqués": "estomaquer",
    "estompa": "estomper",
    "estompai": "estomper",
    "estompaient": "estomper",
    "estompais": "estomper",
    "estompait": "estomper",
    "estompant": "estomper",
    "estompas": "estomper",
    "estompasse": "estomper",
    "estompassent": "estomper",
    "estompasses": "estomper",
    "estompassiez": "estomper",
    "estompassions": "estomper",
    "estompe": "estomper",
    "estompent": "estomper",
    "estompera": "estomper",
    "estomperai": "estomper",
    "estomperaient": "estomper",
    "estomperais": "estomper",
    "estomperait": "estomper",
    "estomperas": "estomper",
    "estomperez": "estomper",
    "estomperiez": "estomper",
    "estomperions": "estomper",
    "estomperons": "estomper",
    "estomperont": "estomper",
    "estompes": "estomper",
    "estompez": "estomper",
    "estompiez": "estomper",
    "estompions": "estomper",
    "estompons": "estomper",
    "estompâmes": "estomper",
    "estompât": "estomper",
    "estompâtes": "estomper",
    "estompèrent": "estomper",
    "estompé": "estomper",
    "estompée": "estomper",
    "estompées": "estomper",
    "estompés": "estomper",
    "estonienne": "estonien",
    "estoniennes": "estonien",
    "estoniens": "estonien",
    "estoqua": "estoquer",
    "estoque": "estoquer",
    "estoqué": "estoquer",
    "estourbi": "estourbir",
    "estourbie": "estourbir",
    "estourbies": "estourbir",
    "estourbira": "estourbir",
    "estourbirai": "estourbir",
    "estourbiraient": "estourbir",
    "estourbirais": "estourbir",
    "estourbirait": "estourbir",
    "estourbiras": "estourbir",
    "estourbirent": "estourbir",
    "estourbirez": "estourbir",
    "estourbiriez": "estourbir",
    "estourbirions": "estourbir",
    "estourbirons": "estourbir",
    "estourbiront": "estourbir",
    "estourbis": "estourbir",
    "estourbissaient": "estourbir",
    "estourbissais": "estourbir",
    "estourbissait": "estourbir",
    "estourbissant": "estourbir",
    "estourbisse": "estourbir",
    "estourbissent": "estourbir",
    "estourbisses": "estourbir",
    "estourbissez": "estourbir",
    "estourbissiez": "estourbir",
    "estourbissions": "estourbir",
    "estourbissons": "estourbir",
    "estourbit": "estourbir",
    "estourbîmes": "estourbir",
    "estourbît": "estourbir",
    "estourbîtes": "estourbir",
    "estrades": "estrade",
    "estragons": "estragon",
    "estrangers": "estranger",
    "estrapades": "estrapade",
    "estrapassée": "estrapasser",
    "estropiait": "estropier",
    "estropie": "estropier",
    "estropierai": "estropier",
    "estropierait": "estropier",
    "estropiez": "estropier",
    "estropié": "estropier",
    "estropiée": "estropier",
    "estropiés": "estropier",
    "estuaires": "estuaire",
    "estudiantine": "estudiantin",
    "estudiantines": "estudiantin",
    "estudiantins": "estudiantin",
    "esturgeons": "esturgeon",
    "ethmoïdaux": "ethmoïdal",
    "ethnies": "ethnie",
    "ethniques": "ethnique",
    "ethnocentrismes": "ethnocentrisme",
    "ethnographiques": "ethnographique",
    "ethnologies": "ethnologie",
    "ethnologiques": "ethnologique",
    "ethnologues": "ethnologue",
    "ethnozootechnies": "ethnozootechnie",
    "ets.": "établissement",
    "eu": "avoir",
    "eucharisties": "eucharistie",
    "eucharistiques": "eucharistique",
    "euclidienne": "euclidien",
    "euclidiens": "euclidien",
    "eudistes": "eudiste",
    "eue": "avoir",
    "eues": "eue",
    "eugéniques": "eugénique",
    "eugénismes": "eugénisme",
    "eunuques": "eunuque",
    "eunuques-espions": "eunuques-espion",
    "euphonies": "euphonie",
    "euphoniques": "euphonique",
    "euphorbes": "euphorbe",
    "euphories": "euphorie",
    "euphoriques": "euphorique",
    "euphorisante": "euphorisant",
    "euphorisantes": "euphorisant",
    "euphorisants": "euphorisant",
    "euphorisent": "euphoriser",
    "euphorisé": "euphoriser",
    "euphorisée": "euphoriser",
    "euphémiques": "euphémique",
    "euphémismes": "euphémisme",
    "eurafricaine": "eurafricain",
    "eurafricaines": "eurafricain",
    "eurafricains": "eurafricain",
    "eurasienne": "eurasien",
    "eurent": "avoir",
    "euristiques": "euristique",
    "euro-africaines": "euro-africain",
    "eurobanques": "eurobanque",
    "eurobaromètres": "eurobaromètre",
    "eurocotres": "eurocotre",
    "eurodollars": "eurodollar",
    "eurofrancs": "eurofranc",
    "euromaghrébins": "euromaghrébin",
    "euromarchés": "euromarché",
    "européenne": "européen",
    "européennes": "européen",
    "européens": "européen",
    "euros": "euro",
    "eurovillages": "eurovillage",
    "eurythmies": "eurythmie",
    "eurythmiques": "eurythmique",
    "eus": "avoir",
    "eusse": "avoir",
    "eussent": "avoir",
    "eusses": "avoir",
    "eussiez": "avoir",
    "eussions": "avoir",
    "eussé": "avoir",
    "eustaches": "eustache",
    "eut": "avoir",
    "euthanasies": "euthanasie",
    "eutrophisations": "eutrophisation",
    "eux": "lui",
    "evzones": "evzone",
    "ex-amante": "ex-amant",
    "ex-amants": "ex-amant",
    "ex-assistante": "ex-assistant",
    "ex-associés": "ex-associé",
    "ex-branleurs": "ex-branleur",
    "ex-camarades": "ex-camarade",
    "ex-championne": "ex-champion",
    "ex-champions": "ex-champion",
    "ex-chanteuse": "ex-chanteur",
    "ex-civils": "ex-civil",
    "ex-collègues": "ex-collègue",
    "ex-copains": "ex-copain",
    "ex-copines": "ex-copine",
    "ex-danseuse": "ex-danseur",
    "ex-démons": "ex-démon",
    "ex-enzymes": "ex-enzyme",
    "ex-esclavagistes": "ex-esclavagiste",
    "ex-femmes": "ex-femme",
    "ex-fiancée": "ex-fiancé",
    "ex-flics": "ex-flic",
    "ex-forçats": "ex-forçat",
    "ex-fusilleurs": "ex-fusilleur",
    "ex-gardes": "ex-garde",
    "ex-guenilles": "ex-guenille",
    "ex-hippies": "ex-hippie",
    "ex-inspecteurs": "ex-inspecteur",
    "ex-maris": "ex-mari",
    "ex-mecs": "ex-mec",
    "ex-mercenaires": "ex-mercenaire",
    "ex-militaires": "ex-militaire",
    "ex-ministres": "ex-ministre",
    "ex-palmes": "ex-palme",
    "ex-pensionnaires": "ex-pensionnaire",
    "ex-petite": "ex-petit",
    "ex-petits": "ex-petit",
    "ex-pharmaciennes": "ex-pharmacien",
    "ex-plaquée": "ex-plaqué",
    "ex-poivrots": "ex-poivrot",
    "ex-présidents": "ex-président",
    "ex-putes": "ex-pute",
    "ex-républiques": "ex-république",
    "ex-sacs": "ex-sac",
    "ex-sergents": "ex-sergent",
    "ex-soldats": "ex-soldat",
    "ex-solistes": "ex-soliste",
    "ex-strip-teaseuse": "ex-strip-teaseur",
    "ex-taulards": "ex-taulard",
    "ex-violeurs": "ex-violeur",
    "ex-épouses": "ex-épouse",
    "ex.": "exemple",
    "exacerba": "exacerber",
    "exacerbai": "exacerber",
    "exacerbaient": "exacerber",
    "exacerbais": "exacerber",
    "exacerbait": "exacerber",
    "exacerbant": "exacerber",
    "exacerbas": "exacerber",
    "exacerbasse": "exacerber",
    "exacerbassent": "exacerber",
    "exacerbasses": "exacerber",
    "exacerbassiez": "exacerber",
    "exacerbassions": "exacerber",
    "exacerbations": "exacerbation",
    "exacerbe": "exacerber",
    "exacerbent": "exacerber",
    "exacerbera": "exacerber",
    "exacerberai": "exacerber",
    "exacerberaient": "exacerber",
    "exacerberais": "exacerber",
    "exacerberait": "exacerber",
    "exacerberas": "exacerber",
    "exacerberez": "exacerber",
    "exacerberiez": "exacerber",
    "exacerberions": "exacerber",
    "exacerberons": "exacerber",
    "exacerberont": "exacerber",
    "exacerbes": "exacerber",
    "exacerbez": "exacerber",
    "exacerbiez": "exacerber",
    "exacerbions": "exacerber",
    "exacerbons": "exacerber",
    "exacerbâmes": "exacerber",
    "exacerbât": "exacerber",
    "exacerbâtes": "exacerber",
    "exacerbèrent": "exacerber",
    "exacerbé": "exacerber",
    "exacerbée": "exacerber",
    "exacerbées": "exacerber",
    "exacerbés": "exacerber",
    "exacte": "exact",
    "exactes": "exact",
    "exactions": "exaction",
    "exactitudes": "exactitude",
    "exacts": "exact",
    "exagère": "exagérer",
    "exagèrent": "exagérer",
    "exagères": "exagérer",
    "exagéra": "exagérer",
    "exagérai": "exagérer",
    "exagéraient": "exagérer",
    "exagérais": "exagérer",
    "exagérait": "exagérer",
    "exagérant": "exagérer",
    "exagéras": "exagérer",
    "exagérasse": "exagérer",
    "exagérassent": "exagérer",
    "exagérasses": "exagérer",
    "exagérassiez": "exagérer",
    "exagérassions": "exagérer",
    "exagérations": "exagération",
    "exagérera": "exagérer",
    "exagérerai": "exagérer",
    "exagéreraient": "exagérer",
    "exagérerais": "exagérer",
    "exagérerait": "exagérer",
    "exagéreras": "exagérer",
    "exagérerez": "exagérer",
    "exagéreriez": "exagérer",
    "exagérerions": "exagérer",
    "exagérerons": "exagérer",
    "exagéreront": "exagérer",
    "exagérez": "exagérer",
    "exagériez": "exagérer",
    "exagérions": "exagérer",
    "exagérons": "exagérer",
    "exagérâmes": "exagérer",
    "exagérât": "exagérer",
    "exagérâtes": "exagérer",
    "exagérèrent": "exagérer",
    "exagéré": "exagérer",
    "exagérée": "exagérer",
    "exagérées": "exagérer",
    "exagérés": "exagérer",
    "exalta": "exalter",
    "exaltai": "exalter",
    "exaltaient": "exalter",
    "exaltais": "exalter",
    "exaltait": "exalter",
    "exaltant": "exalter",
    "exaltante": "exaltant",
    "exaltantes": "exaltant",
    "exaltants": "exaltant",
    "exaltas": "exalter",
    "exaltasse": "exalter",
    "exaltassent": "exalter",
    "exaltasses": "exalter",
    "exaltassiez": "exalter",
    "exaltassions": "exalter",
    "exaltations": "exaltation",
    "exalte": "exalter",
    "exaltent": "exalter",
    "exaltera": "exalter",
    "exalterai": "exalter",
    "exalteraient": "exalter",
    "exalterais": "exalter",
    "exalterait": "exalter",
    "exalteras": "exalter",
    "exalterez": "exalter",
    "exalteriez": "exalter",
    "exalterions": "exalter",
    "exalterons": "exalter",
    "exalteront": "exalter",
    "exaltes": "exalter",
    "exaltez": "exalter",
    "exaltiez": "exalter",
    "exaltions": "exalter",
    "exaltons": "exalter",
    "exaltâmes": "exalter",
    "exaltât": "exalter",
    "exaltâtes": "exalter",
    "exaltèrent": "exalter",
    "exalté": "exalter",
    "exaltée": "exalter",
    "exaltées": "exalter",
    "exaltés": "exalter",
    "examens": "examen",
    "examina": "examiner",
    "examinai": "examiner",
    "examinaient": "examiner",
    "examinais": "examiner",
    "examinait": "examiner",
    "examinant": "examiner",
    "examinas": "examiner",
    "examinasse": "examiner",
    "examinassent": "examiner",
    "examinasses": "examiner",
    "examinassiez": "examiner",
    "examinassions": "examiner",
    "examinateurs": "examinateur",
    "examinatrice": "examinateur",
    "examinatrices": "examinateur",
    "examine": "examiner",
    "examinent": "examiner",
    "examinera": "examiner",
    "examinerai": "examiner",
    "examineraient": "examiner",
    "examinerais": "examiner",
    "examinerait": "examiner",
    "examineras": "examiner",
    "examinerez": "examiner",
    "examineriez": "examiner",
    "examinerions": "examiner",
    "examinerons": "examiner",
    "examineront": "examiner",
    "examines": "examiner",
    "examinez": "examiner",
    "examiniez": "examiner",
    "examinions": "examiner",
    "examinons": "examiner",
    "examinâmes": "examiner",
    "examinât": "examiner",
    "examinâtes": "examiner",
    "examinèrent": "examiner",
    "examiné": "examiner",
    "examinée": "examiner",
    "examinées": "examiner",
    "examinés": "examiner",
    "exams": "exam",
    "exarchats": "exarchat",
    "exarques": "exarque",
    "exaspère": "exaspérer",
    "exaspèrent": "exaspérer",
    "exaspères": "exaspérer",
    "exaspéra": "exaspérer",
    "exaspérai": "exaspérer",
    "exaspéraient": "exaspérer",
    "exaspérais": "exaspérer",
    "exaspérait": "exaspérer",
    "exaspérant": "exaspérer",
    "exaspérante": "exaspérant",
    "exaspérantes": "exaspérant",
    "exaspérants": "exaspérant",
    "exaspéras": "exaspérer",
    "exaspérasse": "exaspérer",
    "exaspérassent": "exaspérer",
    "exaspérasses": "exaspérer",
    "exaspérassiez": "exaspérer",
    "exaspérassions": "exaspérer",
    "exaspérations": "exaspération",
    "exaspérera": "exaspérer",
    "exaspérerai": "exaspérer",
    "exaspéreraient": "exaspérer",
    "exaspérerais": "exaspérer",
    "exaspérerait": "exaspérer",
    "exaspéreras": "exaspérer",
    "exaspérerez": "exaspérer",
    "exaspéreriez": "exaspérer",
    "exaspérerions": "exaspérer",
    "exaspérerons": "exaspérer",
    "exaspéreront": "exaspérer",
    "exaspérez": "exaspérer",
    "exaspériez": "exaspérer",
    "exaspérions": "exaspérer",
    "exaspérons": "exaspérer",
    "exaspérâmes": "exaspérer",
    "exaspérât": "exaspérer",
    "exaspérâtes": "exaspérer",
    "exaspérèrent": "exaspérer",
    "exaspéré": "exaspérer",
    "exaspérée": "exaspérer",
    "exaspérées": "exaspérer",
    "exaspérés": "exaspérer",
    "exauce": "exaucer",
    "exaucent": "exaucer",
    "exaucera": "exaucer",
    "exaucerai": "exaucer",
    "exauceraient": "exaucer",
    "exaucerais": "exaucer",
    "exaucerait": "exaucer",
    "exauceras": "exaucer",
    "exaucerez": "exaucer",
    "exauceriez": "exaucer",
    "exaucerions": "exaucer",
    "exaucerons": "exaucer",
    "exauceront": "exaucer",
    "exauces": "exaucer",
    "exaucez": "exaucer",
    "exauciez": "exaucer",
    "exaucions": "exaucer",
    "exaucèrent": "exaucer",
    "exaucé": "exaucer",
    "exaucée": "exaucer",
    "exaucées": "exaucer",
    "exaucés": "exaucer",
    "exauça": "exaucer",
    "exauçai": "exaucer",
    "exauçaient": "exaucer",
    "exauçais": "exaucer",
    "exauçait": "exaucer",
    "exauçant": "exaucer",
    "exauças": "exaucer",
    "exauçasse": "exaucer",
    "exauçassent": "exaucer",
    "exauçasses": "exaucer",
    "exauçassiez": "exaucer",
    "exauçassions": "exaucer",
    "exauçons": "exaucer",
    "exauçâmes": "exaucer",
    "exauçât": "exaucer",
    "exauçâtes": "exaucer",
    "excava": "excaver",
    "excavai": "excaver",
    "excavaient": "excaver",
    "excavais": "excaver",
    "excavait": "excaver",
    "excavant": "excaver",
    "excavas": "excaver",
    "excavasse": "excaver",
    "excavassent": "excaver",
    "excavasses": "excaver",
    "excavassiez": "excaver",
    "excavassions": "excaver",
    "excavateurs": "excavateur",
    "excavations": "excavation",
    "excavatrice": "excavateur",
    "excavatrices": "excavatrice",
    "excave": "excaver",
    "excavent": "excaver",
    "excavera": "excaver",
    "excaverai": "excaver",
    "excaveraient": "excaver",
    "excaverais": "excaver",
    "excaverait": "excaver",
    "excaveras": "excaver",
    "excaverez": "excaver",
    "excaveriez": "excaver",
    "excaverions": "excaver",
    "excaverons": "excaver",
    "excaveront": "excaver",
    "excaves": "excaver",
    "excavez": "excaver",
    "excaviez": "excaver",
    "excavions": "excaver",
    "excavons": "excaver",
    "excavâmes": "excaver",
    "excavât": "excaver",
    "excavâtes": "excaver",
    "excavèrent": "excaver",
    "excavé": "excaver",
    "excavée": "excaver",
    "excavées": "excaver",
    "excavés": "excaver",
    "excella": "exceller",
    "excellai": "exceller",
    "excellaient": "exceller",
    "excellais": "exceller",
    "excellait": "exceller",
    "excellant": "exceller",
    "excellas": "exceller",
    "excellasse": "exceller",
    "excellassent": "exceller",
    "excellasses": "exceller",
    "excellassiez": "exceller",
    "excellassions": "exceller",
    "excelle": "exceller",
    "excellences": "excellence",
    "excellent": "exceller",
    "excellente": "excellent",
    "excellentes": "excellent",
    "excellents": "excellent",
    "excellera": "exceller",
    "excellerai": "exceller",
    "excelleraient": "exceller",
    "excellerais": "exceller",
    "excellerait": "exceller",
    "excelleras": "exceller",
    "excellerez": "exceller",
    "excelleriez": "exceller",
    "excellerions": "exceller",
    "excellerons": "exceller",
    "excelleront": "exceller",
    "excelles": "exceller",
    "excellez": "exceller",
    "excelliez": "exceller",
    "excellions": "exceller",
    "excellons": "exceller",
    "excellâmes": "exceller",
    "excellât": "exceller",
    "excellâtes": "exceller",
    "excellèrent": "exceller",
    "excellé": "exceller",
    "excentra": "excentrer",
    "excentrai": "excentrer",
    "excentraient": "excentrer",
    "excentrais": "excentrer",
    "excentrait": "excentrer",
    "excentrant": "excentrer",
    "excentras": "excentrer",
    "excentrasse": "excentrer",
    "excentrassent": "excentrer",
    "excentrasses": "excentrer",
    "excentrassiez": "excentrer",
    "excentrassions": "excentrer",
    "excentre": "excentrer",
    "excentrent": "excentrer",
    "excentrera": "excentrer",
    "excentrerai": "excentrer",
    "excentreraient": "excentrer",
    "excentrerais": "excentrer",
    "excentrerait": "excentrer",
    "excentreras": "excentrer",
    "excentrerez": "excentrer",
    "excentreriez": "excentrer",
    "excentrerions": "excentrer",
    "excentrerons": "excentrer",
    "excentreront": "excentrer",
    "excentres": "excentrer",
    "excentrez": "excentrer",
    "excentricités": "excentricité",
    "excentriez": "excentrer",
    "excentrions": "excentrer",
    "excentriques": "excentrique",
    "excentrons": "excentrer",
    "excentrâmes": "excentrer",
    "excentrât": "excentrer",
    "excentrâtes": "excentrer",
    "excentrèrent": "excentrer",
    "excentré": "excentrer",
    "excentrée": "excentrer",
    "excentrées": "excentrer",
    "excentrés": "excentrer",
    "excepta": "excepter",
    "exceptai": "excepter",
    "exceptaient": "excepter",
    "exceptais": "excepter",
    "exceptait": "excepter",
    "exceptant": "excepter",
    "exceptas": "excepter",
    "exceptasse": "excepter",
    "exceptassent": "excepter",
    "exceptasses": "excepter",
    "exceptassiez": "excepter",
    "exceptassions": "excepter",
    "excepte": "excepter",
    "exceptent": "excepter",
    "exceptera": "excepter",
    "excepterai": "excepter",
    "excepteraient": "excepter",
    "excepterais": "excepter",
    "excepterait": "excepter",
    "excepteras": "excepter",
    "excepterez": "excepter",
    "excepteriez": "excepter",
    "excepterions": "excepter",
    "excepterons": "excepter",
    "excepteront": "excepter",
    "exceptes": "excepter",
    "exceptez": "excepter",
    "exceptiez": "excepter",
    "exceptionnalismes": "exceptionnalisme",
    "exceptionnelle": "exceptionnel",
    "exceptionnelles": "exceptionnel",
    "exceptionnels": "exceptionnel",
    "exceptions": "exception",
    "exceptons": "excepter",
    "exceptâmes": "excepter",
    "exceptât": "excepter",
    "exceptâtes": "excepter",
    "exceptèrent": "excepter",
    "excepté": "excepter",
    "exceptée": "excepter",
    "exceptées": "excepter",
    "exceptés": "excepter",
    "excessifs": "excessif",
    "excessive": "excessif",
    "excessives": "excessif",
    "excipa": "exciper",
    "excipai": "exciper",
    "excipaient": "exciper",
    "excipais": "exciper",
    "excipait": "exciper",
    "excipant": "exciper",
    "excipas": "exciper",
    "excipasse": "exciper",
    "excipassent": "exciper",
    "excipasses": "exciper",
    "excipassiez": "exciper",
    "excipassions": "exciper",
    "excipe": "exciper",
    "excipent": "exciper",
    "excipera": "exciper",
    "exciperai": "exciper",
    "exciperaient": "exciper",
    "exciperais": "exciper",
    "exciperait": "exciper",
    "exciperas": "exciper",
    "exciperez": "exciper",
    "exciperiez": "exciper",
    "exciperions": "exciper",
    "exciperons": "exciper",
    "exciperont": "exciper",
    "excipes": "exciper",
    "excipez": "exciper",
    "excipients": "excipient",
    "excipiez": "exciper",
    "excipions": "exciper",
    "excipons": "exciper",
    "excipâmes": "exciper",
    "excipât": "exciper",
    "excipâtes": "exciper",
    "excipèrent": "exciper",
    "excipé": "exciper",
    "excisa": "exciser",
    "excisai": "exciser",
    "excisaient": "exciser",
    "excisais": "exciser",
    "excisait": "exciser",
    "excisant": "exciser",
    "excisas": "exciser",
    "excisasse": "exciser",
    "excisassent": "exciser",
    "excisasses": "exciser",
    "excisassiez": "exciser",
    "excisassions": "exciser",
    "excise": "exciser",
    "excisent": "exciser",
    "excisera": "exciser",
    "exciserai": "exciser",
    "exciseraient": "exciser",
    "exciserais": "exciser",
    "exciserait": "exciser",
    "exciseras": "exciser",
    "exciserez": "exciser",
    "exciseriez": "exciser",
    "exciserions": "exciser",
    "exciserons": "exciser",
    "exciseront": "exciser",
    "excises": "exciser",
    "exciseuse": "exciseur",
    "exciseuses": "exciseur",
    "excisez": "exciser",
    "excisiez": "exciser",
    "excisions": "excision",
    "excisons": "exciser",
    "excisâmes": "exciser",
    "excisât": "exciser",
    "excisâtes": "exciser",
    "excisèrent": "exciser",
    "excisé": "exciser",
    "excisée": "exciser",
    "excisées": "exciser",
    "excisés": "exciser",
    "excita": "exciter",
    "excitai": "exciter",
    "excitaient": "exciter",
    "excitais": "exciter",
    "excitait": "exciter",
    "excitant": "exciter",
    "excitante": "excitant",
    "excitantes": "excitant",
    "excitants": "excitant",
    "excitas": "exciter",
    "excitasse": "exciter",
    "excitassent": "exciter",
    "excitasses": "exciter",
    "excitassiez": "exciter",
    "excitassions": "exciter",
    "excitations": "excitation",
    "excite": "exciter",
    "excitent": "exciter",
    "excitera": "exciter",
    "exciterai": "exciter",
    "exciteraient": "exciter",
    "exciterais": "exciter",
    "exciterait": "exciter",
    "exciteras": "exciter",
    "exciterez": "exciter",
    "exciteriez": "exciter",
    "exciterions": "exciter",
    "exciterons": "exciter",
    "exciteront": "exciter",
    "excites": "exciter",
    "excitez": "exciter",
    "excitiez": "exciter",
    "excitions": "exciter",
    "excitons": "exciter",
    "excitâmes": "exciter",
    "excitât": "exciter",
    "excitâtes": "exciter",
    "excitèrent": "exciter",
    "excité": "exciter",
    "excitée": "exciter",
    "excitées": "exciter",
    "excités": "exciter",
    "exclama": "exclamer",
    "exclamai": "exclamer",
    "exclamaient": "exclamer",
    "exclamais": "exclamer",
    "exclamait": "exclamer",
    "exclamant": "exclamer",
    "exclamas": "exclamer",
    "exclamasse": "exclamer",
    "exclamassent": "exclamer",
    "exclamasses": "exclamer",
    "exclamassiez": "exclamer",
    "exclamassions": "exclamer",
    "exclamations": "exclamation",
    "exclamative": "exclamatif",
    "exclame": "exclamer",
    "exclament": "exclamer",
    "exclamera": "exclamer",
    "exclamerai": "exclamer",
    "exclameraient": "exclamer",
    "exclamerais": "exclamer",
    "exclamerait": "exclamer",
    "exclameras": "exclamer",
    "exclamerez": "exclamer",
    "exclameriez": "exclamer",
    "exclamerions": "exclamer",
    "exclamerons": "exclamer",
    "exclameront": "exclamer",
    "exclames": "exclamer",
    "exclamez": "exclamer",
    "exclamiez": "exclamer",
    "exclamions": "exclamer",
    "exclamons": "exclamer",
    "exclamâmes": "exclamer",
    "exclamât": "exclamer",
    "exclamâtes": "exclamer",
    "exclamèrent": "exclamer",
    "exclamé": "exclamer",
    "exclamée": "exclamer",
    "exclamées": "exclamer",
    "exclamés": "exclamer",
    "exclu": "exclure",
    "excluaient": "exclure",
    "excluais": "exclure",
    "excluait": "exclure",
    "excluant": "exclure",
    "exclue": "exclure",
    "excluent": "exclure",
    "exclues": "exclure",
    "excluez": "exclure",
    "excluiez": "exclure",
    "excluions": "exclure",
    "excluons": "exclure",
    "exclura": "exclure",
    "exclurai": "exclure",
    "excluraient": "exclure",
    "exclurais": "exclure",
    "exclurait": "exclure",
    "excluras": "exclure",
    "exclurent": "exclure",
    "exclurez": "exclure",
    "excluriez": "exclure",
    "exclurions": "exclure",
    "exclurons": "exclure",
    "excluront": "exclure",
    "exclus": "exclure",
    "exclusifs": "exclusif",
    "exclusions": "exclusion",
    "exclusive": "exclusif",
    "exclusives": "exclusif",
    "exclusivités": "exclusivité",
    "exclusse": "exclure",
    "exclussent": "exclure",
    "exclusses": "exclure",
    "exclussiez": "exclure",
    "exclussions": "exclure",
    "exclut": "exclure",
    "exclûmes": "exclure",
    "exclût": "exclure",
    "exclûtes": "exclure",
    "excommunia": "excommunier",
    "excommuniai": "excommunier",
    "excommuniaient": "excommunier",
    "excommuniais": "excommunier",
    "excommuniait": "excommunier",
    "excommuniant": "excommunier",
    "excommunias": "excommunier",
    "excommuniasse": "excommunier",
    "excommuniassent": "excommunier",
    "excommuniasses": "excommunier",
    "excommuniassiez": "excommunier",
    "excommuniassions": "excommunier",
    "excommunications": "excommunication",
    "excommunie": "excommunier",
    "excommunient": "excommunier",
    "excommuniera": "excommunier",
    "excommunierai": "excommunier",
    "excommunieraient": "excommunier",
    "excommunierais": "excommunier",
    "excommunierait": "excommunier",
    "excommunieras": "excommunier",
    "excommunierez": "excommunier",
    "excommunieriez": "excommunier",
    "excommunierions": "excommunier",
    "excommunierons": "excommunier",
    "excommunieront": "excommunier",
    "excommunies": "excommunier",
    "excommuniez": "excommunier",
    "excommuniiez": "excommunier",
    "excommuniions": "excommunier",
    "excommunions": "excommunier",
    "excommuniâmes": "excommunier",
    "excommuniât": "excommunier",
    "excommuniâtes": "excommunier",
    "excommunièrent": "excommunier",
    "excommunié": "excommunier",
    "excommuniée": "excommunier",
    "excommuniées": "excommunier",
    "excommuniés": "excommunier",
    "excoriée": "excorier",
    "excoriées": "excorier",
    "excroissances": "excroissance",
    "excrète": "excréter",
    "excrètent": "excréter",
    "excrètes": "excréter",
    "excrémentielle": "excrémentiel",
    "excréments": "excrément",
    "excréta": "excréter",
    "excrétai": "excréter",
    "excrétaient": "excréter",
    "excrétais": "excréter",
    "excrétait": "excréter",
    "excrétant": "excréter",
    "excrétas": "excréter",
    "excrétasse": "excréter",
    "excrétassent": "excréter",
    "excrétasses": "excréter",
    "excrétassiez": "excréter",
    "excrétassions": "excréter",
    "excrétera": "excréter",
    "excréterai": "excréter",
    "excréteraient": "excréter",
    "excréterais": "excréter",
    "excréterait": "excréter",
    "excréteras": "excréter",
    "excréterez": "excréter",
    "excréteriez": "excréter",
    "excréterions": "excréter",
    "excréterons": "excréter",
    "excréteront": "excréter",
    "excrétez": "excréter",
    "excrétiez": "excréter",
    "excrétions": "excrétion",
    "excrétons": "excréter",
    "excrétâmes": "excréter",
    "excrétât": "excréter",
    "excrétâtes": "excréter",
    "excrétèrent": "excréter",
    "excrété": "excréter",
    "excrétée": "excréter",
    "excrétées": "excréter",
    "excrétés": "excréter",
    "excursionna": "excursionner",
    "excursionnai": "excursionner",
    "excursionnaient": "excursionner",
    "excursionnais": "excursionner",
    "excursionnait": "excursionner",
    "excursionnant": "excursionner",
    "excursionnas": "excursionner",
    "excursionnasse": "excursionner",
    "excursionnassent": "excursionner",
    "excursionnasses": "excursionner",
    "excursionnassiez": "excursionner",
    "excursionnassions": "excursionner",
    "excursionne": "excursionner",
    "excursionnent": "excursionner",
    "excursionnera": "excursionner",
    "excursionnerai": "excursionner",
    "excursionneraient": "excursionner",
    "excursionnerais": "excursionner",
    "excursionnerait": "excursionner",
    "excursionneras": "excursionner",
    "excursionnerez": "excursionner",
    "excursionneriez": "excursionner",
    "excursionnerions": "excursionner",
    "excursionnerons": "excursionner",
    "excursionneront": "excursionner",
    "excursionnes": "excursionner",
    "excursionnez": "excursionner",
    "excursionniez": "excursionner",
    "excursionnions": "excursionner",
    "excursionnistes": "excursionniste",
    "excursionnons": "excursionner",
    "excursionnâmes": "excursionner",
    "excursionnât": "excursionner",
    "excursionnâtes": "excursionner",
    "excursionnèrent": "excursionner",
    "excursionné": "excursionner",
    "excursions": "excursion",
    "excusa": "excuser",
    "excusables": "excusable",
    "excusai": "excuser",
    "excusaient": "excuser",
    "excusais": "excuser",
    "excusait": "excuser",
    "excusant": "excuser",
    "excusas": "excuser",
    "excusasse": "excuser",
    "excusassent": "excuser",
    "excusasses": "excuser",
    "excusassiez": "excuser",
    "excusassions": "excuser",
    "excuse": "excuser",
    "excusent": "excuser",
    "excusera": "excuser",
    "excuserai": "excuser",
    "excuseraient": "excuser",
    "excuserais": "excuser",
    "excuserait": "excuser",
    "excuseras": "excuser",
    "excuserez": "excuser",
    "excuseriez": "excuser",
    "excuserions": "excuser",
    "excuserons": "excuser",
    "excuseront": "excuser",
    "excuses": "excuser",
    "excusez": "excuser",
    "excusiez": "excuser",
    "excusions": "excuser",
    "excusons": "excuser",
    "excusâmes": "excuser",
    "excusât": "excuser",
    "excusâtes": "excuser",
    "excusèrent": "excuser",
    "excusé": "excuser",
    "excusée": "excuser",
    "excusées": "excuser",
    "excusés": "excuser",
    "excède": "excéder",
    "excèdent": "excéder",
    "excèdes": "excéder",
    "excéda": "excéder",
    "excédai": "excéder",
    "excédaient": "excéder",
    "excédais": "excéder",
    "excédait": "excéder",
    "excédant": "excéder",
    "excédas": "excéder",
    "excédasse": "excéder",
    "excédassent": "excéder",
    "excédasses": "excéder",
    "excédassiez": "excéder",
    "excédassions": "excéder",
    "excédentaires": "excédentaire",
    "excédents": "excédent",
    "excédera": "excéder",
    "excéderai": "excéder",
    "excéderaient": "excéder",
    "excéderais": "excéder",
    "excéderait": "excéder",
    "excéderas": "excéder",
    "excéderez": "excéder",
    "excéderiez": "excéder",
    "excéderions": "excéder",
    "excéderons": "excéder",
    "excéderont": "excéder",
    "excédez": "excéder",
    "excédiez": "excéder",
    "excédions": "excéder",
    "excédons": "excéder",
    "excédâmes": "excéder",
    "excédât": "excéder",
    "excédâtes": "excéder",
    "excédèrent": "excéder",
    "excédé": "excéder",
    "excédée": "excéder",
    "excédées": "excéder",
    "excédés": "excéder",
    "exemplaires": "exemplaire",
    "exemplarités": "exemplarité",
    "exemples": "exemple",
    "exempta": "exempter",
    "exemptai": "exempter",
    "exemptaient": "exempter",
    "exemptais": "exempter",
    "exemptait": "exempter",
    "exemptant": "exempter",
    "exemptas": "exempter",
    "exemptasse": "exempter",
    "exemptassent": "exempter",
    "exemptasses": "exempter",
    "exemptassiez": "exempter",
    "exemptassions": "exempter",
    "exempte": "exempter",
    "exemptent": "exempter",
    "exemptera": "exempter",
    "exempterai": "exempter",
    "exempteraient": "exempter",
    "exempterais": "exempter",
    "exempterait": "exempter",
    "exempteras": "exempter",
    "exempterez": "exempter",
    "exempteriez": "exempter",
    "exempterions": "exempter",
    "exempterons": "exempter",
    "exempteront": "exempter",
    "exemptes": "exempter",
    "exemptez": "exempter",
    "exemptiez": "exempter",
    "exemptions": "exemption",
    "exemptons": "exempter",
    "exempts": "exempt",
    "exemptâmes": "exempter",
    "exemptât": "exempter",
    "exemptâtes": "exempter",
    "exemptèrent": "exempter",
    "exempté": "exempter",
    "exemptée": "exempter",
    "exemptées": "exempter",
    "exemptés": "exempter",
    "exerce": "exercer",
    "exercent": "exercer",
    "exercera": "exercer",
    "exercerai": "exercer",
    "exerceraient": "exercer",
    "exercerais": "exercer",
    "exercerait": "exercer",
    "exerceras": "exercer",
    "exercerez": "exercer",
    "exerceriez": "exercer",
    "exercerions": "exercer",
    "exercerons": "exercer",
    "exerceront": "exercer",
    "exerces": "exercer",
    "exercez": "exercer",
    "exercices": "exercice",
    "exerciez": "exercer",
    "exercions": "exercer",
    "exercèrent": "exercer",
    "exercé": "exercer",
    "exercée": "exercer",
    "exercées": "exercer",
    "exercés": "exercer",
    "exergues": "exergue",
    "exerça": "exercer",
    "exerçai": "exercer",
    "exerçaient": "exercer",
    "exerçais": "exercer",
    "exerçait": "exercer",
    "exerçant": "exercer",
    "exerças": "exercer",
    "exerçasse": "exercer",
    "exerçassent": "exercer",
    "exerçasses": "exercer",
    "exerçassiez": "exercer",
    "exerçassions": "exercer",
    "exerçons": "exercer",
    "exerçâmes": "exercer",
    "exerçât": "exercer",
    "exerçâtes": "exercer",
    "exfiltré": "exfiltrer",
    "exfolions": "exfolier",
    "exfoliée": "exfolier",
    "exhala": "exhaler",
    "exhalai": "exhaler",
    "exhalaient": "exhaler",
    "exhalais": "exhaler",
    "exhalaisons": "exhalaison",
    "exhalait": "exhaler",
    "exhalant": "exhaler",
    "exhalas": "exhaler",
    "exhalasse": "exhaler",
    "exhalassent": "exhaler",
    "exhalasses": "exhaler",
    "exhalassiez": "exhaler",
    "exhalassions": "exhaler",
    "exhalations": "exhalation",
    "exhale": "exhaler",
    "exhalent": "exhaler",
    "exhalera": "exhaler",
    "exhalerai": "exhaler",
    "exhaleraient": "exhaler",
    "exhalerais": "exhaler",
    "exhalerait": "exhaler",
    "exhaleras": "exhaler",
    "exhalerez": "exhaler",
    "exhaleriez": "exhaler",
    "exhalerions": "exhaler",
    "exhalerons": "exhaler",
    "exhaleront": "exhaler",
    "exhales": "exhaler",
    "exhalez": "exhaler",
    "exhaliez": "exhaler",
    "exhalions": "exhaler",
    "exhalons": "exhaler",
    "exhalâmes": "exhaler",
    "exhalât": "exhaler",
    "exhalâtes": "exhaler",
    "exhalèrent": "exhaler",
    "exhalé": "exhaler",
    "exhalée": "exhaler",
    "exhalées": "exhaler",
    "exhalés": "exhaler",
    "exhaussa": "exhausser",
    "exhaussai": "exhausser",
    "exhaussaient": "exhausser",
    "exhaussais": "exhausser",
    "exhaussait": "exhausser",
    "exhaussant": "exhausser",
    "exhaussas": "exhausser",
    "exhaussasse": "exhausser",
    "exhaussassent": "exhausser",
    "exhaussasses": "exhausser",
    "exhaussassiez": "exhausser",
    "exhaussassions": "exhausser",
    "exhausse": "exhausser",
    "exhaussent": "exhausser",
    "exhaussera": "exhausser",
    "exhausserai": "exhausser",
    "exhausseraient": "exhausser",
    "exhausserais": "exhausser",
    "exhausserait": "exhausser",
    "exhausseras": "exhausser",
    "exhausserez": "exhausser",
    "exhausseriez": "exhausser",
    "exhausserions": "exhausser",
    "exhausserons": "exhausser",
    "exhausseront": "exhausser",
    "exhausses": "exhausser",
    "exhaussez": "exhausser",
    "exhaussiez": "exhausser",
    "exhaussions": "exhausser",
    "exhaussons": "exhausser",
    "exhaussâmes": "exhausser",
    "exhaussât": "exhausser",
    "exhaussâtes": "exhausser",
    "exhaussèrent": "exhausser",
    "exhaussé": "exhausser",
    "exhaussée": "exhausser",
    "exhaussées": "exhausser",
    "exhaussés": "exhausser",
    "exhaustifs": "exhaustif",
    "exhaustive": "exhaustif",
    "exhaustives": "exhaustif",
    "exhaustivités": "exhaustivité",
    "exhiba": "exhiber",
    "exhibai": "exhiber",
    "exhibaient": "exhiber",
    "exhibais": "exhiber",
    "exhibait": "exhiber",
    "exhibant": "exhiber",
    "exhibas": "exhiber",
    "exhibasse": "exhiber",
    "exhibassent": "exhiber",
    "exhibasses": "exhiber",
    "exhibassiez": "exhiber",
    "exhibassions": "exhiber",
    "exhibe": "exhiber",
    "exhibent": "exhiber",
    "exhibera": "exhiber",
    "exhiberai": "exhiber",
    "exhiberaient": "exhiber",
    "exhiberais": "exhiber",
    "exhiberait": "exhiber",
    "exhiberas": "exhiber",
    "exhiberez": "exhiber",
    "exhiberiez": "exhiber",
    "exhiberions": "exhiber",
    "exhiberons": "exhiber",
    "exhiberont": "exhiber",
    "exhibes": "exhiber",
    "exhibez": "exhiber",
    "exhibiez": "exhiber",
    "exhibions": "exhiber",
    "exhibitionnismes": "exhibitionnisme",
    "exhibitionnistes": "exhibitionniste",
    "exhibitions": "exhibition",
    "exhibons": "exhiber",
    "exhibâmes": "exhiber",
    "exhibât": "exhiber",
    "exhibâtes": "exhiber",
    "exhibèrent": "exhiber",
    "exhibé": "exhiber",
    "exhibée": "exhiber",
    "exhibées": "exhiber",
    "exhibés": "exhiber",
    "exhorta": "exhorter",
    "exhortai": "exhorter",
    "exhortaient": "exhorter",
    "exhortais": "exhorter",
    "exhortait": "exhorter",
    "exhortant": "exhorter",
    "exhortas": "exhorter",
    "exhortasse": "exhorter",
    "exhortassent": "exhorter",
    "exhortasses": "exhorter",
    "exhortassiez": "exhorter",
    "exhortassions": "exhorter",
    "exhortations": "exhortation",
    "exhorte": "exhorter",
    "exhortent": "exhorter",
    "exhortera": "exhorter",
    "exhorterai": "exhorter",
    "exhorteraient": "exhorter",
    "exhorterais": "exhorter",
    "exhorterait": "exhorter",
    "exhorteras": "exhorter",
    "exhorterez": "exhorter",
    "exhorteriez": "exhorter",
    "exhorterions": "exhorter",
    "exhorterons": "exhorter",
    "exhorteront": "exhorter",
    "exhortes": "exhorter",
    "exhortez": "exhorter",
    "exhortiez": "exhorter",
    "exhortions": "exhorter",
    "exhortons": "exhorter",
    "exhortâmes": "exhorter",
    "exhortât": "exhorter",
    "exhortâtes": "exhorter",
    "exhortèrent": "exhorter",
    "exhorté": "exhorter",
    "exhortée": "exhorter",
    "exhortées": "exhorter",
    "exhortés": "exhorter",
    "exhubérances": "exhubérance",
    "exhuma": "exhumer",
    "exhumai": "exhumer",
    "exhumaient": "exhumer",
    "exhumais": "exhumer",
    "exhumait": "exhumer",
    "exhumant": "exhumer",
    "exhumas": "exhumer",
    "exhumasse": "exhumer",
    "exhumassent": "exhumer",
    "exhumasses": "exhumer",
    "exhumassiez": "exhumer",
    "exhumassions": "exhumer",
    "exhume": "exhumer",
    "exhument": "exhumer",
    "exhumera": "exhumer",
    "exhumerai": "exhumer",
    "exhumeraient": "exhumer",
    "exhumerais": "exhumer",
    "exhumerait": "exhumer",
    "exhumeras": "exhumer",
    "exhumerez": "exhumer",
    "exhumeriez": "exhumer",
    "exhumerions": "exhumer",
    "exhumerons": "exhumer",
    "exhumeront": "exhumer",
    "exhumes": "exhumer",
    "exhumez": "exhumer",
    "exhumiez": "exhumer",
    "exhumions": "exhumer",
    "exhumons": "exhumer",
    "exhumâmes": "exhumer",
    "exhumât": "exhumer",
    "exhumâtes": "exhumer",
    "exhumèrent": "exhumer",
    "exhumé": "exhumer",
    "exhumée": "exhumer",
    "exhumées": "exhumer",
    "exhumés": "exhumer",
    "exige": "exiger",
    "exigea": "exiger",
    "exigeai": "exiger",
    "exigeaient": "exiger",
    "exigeais": "exiger",
    "exigeait": "exiger",
    "exigeant": "exiger",
    "exigeante": "exigeant",
    "exigeantes": "exigeant",
    "exigeants": "exigeant",
    "exigeas": "exiger",
    "exigeasse": "exiger",
    "exigeassent": "exiger",
    "exigeasses": "exiger",
    "exigeassiez": "exiger",
    "exigeassions": "exiger",
    "exigences": "exigence",
    "exigent": "exiger",
    "exigeons": "exiger",
    "exigera": "exiger",
    "exigerai": "exiger",
    "exigeraient": "exiger",
    "exigerais": "exiger",
    "exigerait": "exiger",
    "exigeras": "exiger",
    "exigerez": "exiger",
    "exigeriez": "exiger",
    "exigerions": "exiger",
    "exigerons": "exiger",
    "exigeront": "exiger",
    "exiges": "exiger",
    "exigez": "exiger",
    "exigeâmes": "exiger",
    "exigeât": "exiger",
    "exigeâtes": "exiger",
    "exigibles": "exigible",
    "exigiez": "exiger",
    "exigions": "exiger",
    "exigus": "exigu",
    "exiguë": "exigu",
    "exiguës": "exigu",
    "exiguïtés": "exiguïté",
    "exigèrent": "exiger",
    "exigé": "exiger",
    "exigée": "exiger",
    "exigées": "exiger",
    "exigés": "exiger",
    "exila": "exiler",
    "exilai": "exiler",
    "exilaient": "exiler",
    "exilais": "exiler",
    "exilait": "exiler",
    "exilant": "exiler",
    "exilas": "exiler",
    "exilasse": "exiler",
    "exilassent": "exiler",
    "exilasses": "exiler",
    "exilassiez": "exiler",
    "exilassions": "exiler",
    "exile": "exiler",
    "exilent": "exiler",
    "exilera": "exiler",
    "exilerai": "exiler",
    "exileraient": "exiler",
    "exilerais": "exiler",
    "exilerait": "exiler",
    "exileras": "exiler",
    "exilerez": "exiler",
    "exileriez": "exiler",
    "exilerions": "exiler",
    "exilerons": "exiler",
    "exileront": "exiler",
    "exiles": "exiler",
    "exilez": "exiler",
    "exiliez": "exiler",
    "exilions": "exiler",
    "exilons": "exiler",
    "exils": "exil",
    "exilâmes": "exiler",
    "exilât": "exiler",
    "exilâtes": "exiler",
    "exilèrent": "exiler",
    "exilé": "exiler",
    "exilée": "exiler",
    "exilées": "exiler",
    "exilés": "exiler",
    "exista": "exister",
    "existai": "exister",
    "existaient": "exister",
    "existais": "exister",
    "existait": "exister",
    "existances": "existance",
    "existant": "exister",
    "existante": "existant",
    "existantes": "existant",
    "existants": "existant",
    "existas": "exister",
    "existasse": "exister",
    "existassent": "exister",
    "existasses": "exister",
    "existassiez": "exister",
    "existassions": "exister",
    "existe": "exister",
    "existences": "existence",
    "existent": "exister",
    "existentialismes": "existentialisme",
    "existentialistes": "existentialiste",
    "existentielle": "existentiel",
    "existentielles": "existentiel",
    "existentiels": "existentiel",
    "existera": "exister",
    "existerai": "exister",
    "existeraient": "exister",
    "existerais": "exister",
    "existerait": "exister",
    "existeras": "exister",
    "existerez": "exister",
    "existeriez": "exister",
    "existerions": "exister",
    "existerons": "exister",
    "existeront": "exister",
    "existes": "exister",
    "existez": "exister",
    "existiez": "exister",
    "existions": "exister",
    "existons": "exister",
    "existâmes": "exister",
    "existât": "exister",
    "existâtes": "exister",
    "existèrent": "exister",
    "existé": "exister",
    "existée": "exister",
    "existés": "exister",
    "exlusifs": "exlusif",
    "exlusives": "exlusif",
    "exocets": "exocet",
    "exodes": "exode",
    "exogames": "exogame",
    "exonère": "exonérer",
    "exonèrent": "exonérer",
    "exonères": "exonérer",
    "exonéra": "exonérer",
    "exonérai": "exonérer",
    "exonéraient": "exonérer",
    "exonérais": "exonérer",
    "exonérait": "exonérer",
    "exonérant": "exonérer",
    "exonéras": "exonérer",
    "exonérasse": "exonérer",
    "exonérassent": "exonérer",
    "exonérasses": "exonérer",
    "exonérassiez": "exonérer",
    "exonérassions": "exonérer",
    "exonérations": "exonération",
    "exonérera": "exonérer",
    "exonérerai": "exonérer",
    "exonéreraient": "exonérer",
    "exonérerais": "exonérer",
    "exonérerait": "exonérer",
    "exonéreras": "exonérer",
    "exonérerez": "exonérer",
    "exonéreriez": "exonérer",
    "exonérerions": "exonérer",
    "exonérerons": "exonérer",
    "exonéreront": "exonérer",
    "exonérez": "exonérer",
    "exonériez": "exonérer",
    "exonérions": "exonérer",
    "exonérons": "exonérer",
    "exonérâmes": "exonérer",
    "exonérât": "exonérer",
    "exonérâtes": "exonérer",
    "exonérèrent": "exonérer",
    "exonéré": "exonérer",
    "exonérée": "exonérer",
    "exonérées": "exonérer",
    "exonérés": "exonérer",
    "exorbitaient": "exorbiter",
    "exorbitait": "exorbiter",
    "exorbitante": "exorbitant",
    "exorbitantes": "exorbitant",
    "exorbitants": "exorbitant",
    "exorbitées": "exorbiter",
    "exorbités": "exorbiter",
    "exorcisa": "exorciser",
    "exorcisai": "exorciser",
    "exorcisaient": "exorciser",
    "exorcisais": "exorciser",
    "exorcisait": "exorciser",
    "exorcisant": "exorciser",
    "exorcisas": "exorciser",
    "exorcisasse": "exorciser",
    "exorcisassent": "exorciser",
    "exorcisasses": "exorciser",
    "exorcisassiez": "exorciser",
    "exorcisassions": "exorciser",
    "exorcise": "exorciser",
    "exorcisent": "exorciser",
    "exorcisera": "exorciser",
    "exorciserai": "exorciser",
    "exorciseraient": "exorciser",
    "exorciserais": "exorciser",
    "exorciserait": "exorciser",
    "exorciseras": "exorciser",
    "exorciserez": "exorciser",
    "exorciseriez": "exorciser",
    "exorciserions": "exorciser",
    "exorciserons": "exorciser",
    "exorciseront": "exorciser",
    "exorcises": "exorciser",
    "exorcisez": "exorciser",
    "exorcisiez": "exorciser",
    "exorcisions": "exorciser",
    "exorcismes": "exorcisme",
    "exorcisons": "exorciser",
    "exorcistes": "exorciste",
    "exorcisâmes": "exorciser",
    "exorcisât": "exorciser",
    "exorcisâtes": "exorciser",
    "exorcisèrent": "exorciser",
    "exorcisé": "exorciser",
    "exorcisée": "exorciser",
    "exorcisées": "exorciser",
    "exorcisés": "exorciser",
    "exordes": "exorde",
    "exos": "exo",
    "exosmoses": "exosmose",
    "exostoses": "exostose",
    "exotiques": "exotique",
    "exotismes": "exotisme",
    "exotériques": "exotérique",
    "expansifs": "expansif",
    "expansionnismes": "expansionnisme",
    "expansionnistes": "expansionniste",
    "expansions": "expansion",
    "expansive": "expansif",
    "expansives": "expansif",
    "expatria": "expatrier",
    "expatriai": "expatrier",
    "expatriaient": "expatrier",
    "expatriais": "expatrier",
    "expatriait": "expatrier",
    "expatriant": "expatrier",
    "expatrias": "expatrier",
    "expatriasse": "expatrier",
    "expatriassent": "expatrier",
    "expatriasses": "expatrier",
    "expatriassiez": "expatrier",
    "expatriassions": "expatrier",
    "expatrie": "expatrier",
    "expatrient": "expatrier",
    "expatriera": "expatrier",
    "expatrierai": "expatrier",
    "expatrieraient": "expatrier",
    "expatrierais": "expatrier",
    "expatrierait": "expatrier",
    "expatrieras": "expatrier",
    "expatrierez": "expatrier",
    "expatrieriez": "expatrier",
    "expatrierions": "expatrier",
    "expatrierons": "expatrier",
    "expatrieront": "expatrier",
    "expatries": "expatrier",
    "expatriez": "expatrier",
    "expatriiez": "expatrier",
    "expatriions": "expatrier",
    "expatrions": "expatrier",
    "expatriâmes": "expatrier",
    "expatriât": "expatrier",
    "expatriâtes": "expatrier",
    "expatrièrent": "expatrier",
    "expatrié": "expatrier",
    "expatriée": "expatrier",
    "expatriées": "expatrier",
    "expatriés": "expatrier",
    "expectatives": "expectative",
    "expectora": "expectorer",
    "expectorai": "expectorer",
    "expectoraient": "expectorer",
    "expectorais": "expectorer",
    "expectorait": "expectorer",
    "expectorant": "expectorer",
    "expectoras": "expectorer",
    "expectorasse": "expectorer",
    "expectorassent": "expectorer",
    "expectorasses": "expectorer",
    "expectorassiez": "expectorer",
    "expectorassions": "expectorer",
    "expectore": "expectorer",
    "expectorent": "expectorer",
    "expectorera": "expectorer",
    "expectorerai": "expectorer",
    "expectoreraient": "expectorer",
    "expectorerais": "expectorer",
    "expectorerait": "expectorer",
    "expectoreras": "expectorer",
    "expectorerez": "expectorer",
    "expectoreriez": "expectorer",
    "expectorerions": "expectorer",
    "expectorerons": "expectorer",
    "expectoreront": "expectorer",
    "expectores": "expectorer",
    "expectorez": "expectorer",
    "expectoriez": "expectorer",
    "expectorions": "expectorer",
    "expectorons": "expectorer",
    "expectorâmes": "expectorer",
    "expectorât": "expectorer",
    "expectorâtes": "expectorer",
    "expectorèrent": "expectorer",
    "expectoré": "expectorer",
    "expectorée": "expectorer",
    "expectorées": "expectorer",
    "expectorés": "expectorer",
    "experte": "expert",
    "expertes": "expert",
    "expertisaient": "expertiser",
    "expertisait": "expertiser",
    "expertisant": "expertiser",
    "expertise": "expertiser",
    "expertises": "expertise",
    "experts": "expert",
    "experts-comptables": "expert-comptable",
    "expia": "expier",
    "expiai": "expier",
    "expiaient": "expier",
    "expiais": "expier",
    "expiait": "expier",
    "expiant": "expier",
    "expias": "expier",
    "expiasse": "expier",
    "expiassent": "expier",
    "expiasses": "expier",
    "expiassiez": "expier",
    "expiassions": "expier",
    "expiations": "expiation",
    "expiatoires": "expiatoire",
    "expiatrice": "expiateur",
    "expie": "expier",
    "expient": "expier",
    "expiera": "expier",
    "expierai": "expier",
    "expieraient": "expier",
    "expierais": "expier",
    "expierait": "expier",
    "expieras": "expier",
    "expierez": "expier",
    "expieriez": "expier",
    "expierions": "expier",
    "expierons": "expier",
    "expieront": "expier",
    "expies": "expier",
    "expiez": "expier",
    "expiiez": "expier",
    "expiions": "expier",
    "expions": "expier",
    "expira": "expirer",
    "expirai": "expirer",
    "expiraient": "expirer",
    "expirais": "expirer",
    "expirait": "expirer",
    "expirant": "expirer",
    "expirante": "expirant",
    "expirantes": "expirant",
    "expiras": "expirer",
    "expirasse": "expirer",
    "expirassent": "expirer",
    "expirasses": "expirer",
    "expirassiez": "expirer",
    "expirassions": "expirer",
    "expirations": "expiration",
    "expire": "expirer",
    "expirent": "expirer",
    "expirera": "expirer",
    "expirerai": "expirer",
    "expireraient": "expirer",
    "expirerais": "expirer",
    "expirerait": "expirer",
    "expireras": "expirer",
    "expirerez": "expirer",
    "expireriez": "expirer",
    "expirerions": "expirer",
    "expirerons": "expirer",
    "expireront": "expirer",
    "expires": "expirer",
    "expirez": "expirer",
    "expiriez": "expirer",
    "expirions": "expirer",
    "expirons": "expirer",
    "expirâmes": "expirer",
    "expirât": "expirer",
    "expirâtes": "expirer",
    "expirèrent": "expirer",
    "expiré": "expirer",
    "expirée": "expirer",
    "expirées": "expirer",
    "expirés": "expirer",
    "expiâmes": "expier",
    "expiât": "expier",
    "expiâtes": "expier",
    "expièrent": "expier",
    "expié": "expier",
    "expiée": "expier",
    "expiées": "expier",
    "expiés": "expier",
    "explicables": "explicable",
    "explicatifs": "explicatif",
    "explications": "explication",
    "explicative": "explicatif",
    "explicatives": "explicatif",
    "explicita": "expliciter",
    "explicitai": "expliciter",
    "explicitaient": "expliciter",
    "explicitais": "expliciter",
    "explicitait": "expliciter",
    "explicitant": "expliciter",
    "explicitas": "expliciter",
    "explicitasse": "expliciter",
    "explicitassent": "expliciter",
    "explicitasses": "expliciter",
    "explicitassiez": "expliciter",
    "explicitassions": "expliciter",
    "explicite": "expliciter",
    "explicitent": "expliciter",
    "explicitera": "expliciter",
    "expliciterai": "expliciter",
    "expliciteraient": "expliciter",
    "expliciterais": "expliciter",
    "expliciterait": "expliciter",
    "expliciteras": "expliciter",
    "expliciterez": "expliciter",
    "expliciteriez": "expliciter",
    "expliciterions": "expliciter",
    "expliciterons": "expliciter",
    "expliciteront": "expliciter",
    "explicites": "expliciter",
    "explicitez": "expliciter",
    "explicitiez": "expliciter",
    "explicitions": "expliciter",
    "explicitons": "expliciter",
    "explicitâmes": "expliciter",
    "explicitât": "expliciter",
    "explicitâtes": "expliciter",
    "explicitèrent": "expliciter",
    "explicité": "expliciter",
    "explicitée": "expliciter",
    "explicitées": "expliciter",
    "explicités": "expliciter",
    "expliqua": "expliquer",
    "expliquai": "expliquer",
    "expliquaient": "expliquer",
    "expliquais": "expliquer",
    "expliquait": "expliquer",
    "expliquant": "expliquer",
    "expliquas": "expliquer",
    "expliquasse": "expliquer",
    "expliquassent": "expliquer",
    "expliquasses": "expliquer",
    "expliquassiez": "expliquer",
    "expliquassions": "expliquer",
    "explique": "expliquer",
    "expliquent": "expliquer",
    "expliquera": "expliquer",
    "expliquerai": "expliquer",
    "expliqueraient": "expliquer",
    "expliquerais": "expliquer",
    "expliquerait": "expliquer",
    "expliqueras": "expliquer",
    "expliquerez": "expliquer",
    "expliqueriez": "expliquer",
    "expliquerions": "expliquer",
    "expliquerons": "expliquer",
    "expliqueront": "expliquer",
    "expliques": "expliquer",
    "expliquez": "expliquer",
    "expliquiez": "expliquer",
    "expliquions": "expliquer",
    "expliquons": "expliquer",
    "expliquâmes": "expliquer",
    "expliquât": "expliquer",
    "expliquâtes": "expliquer",
    "expliquèrent": "expliquer",
    "expliqué": "expliquer",
    "expliquée": "expliquer",
    "expliquées": "expliquer",
    "expliqués": "expliquer",
    "exploita": "exploiter",
    "exploitables": "exploitable",
    "exploitai": "exploiter",
    "exploitaient": "exploiter",
    "exploitais": "exploiter",
    "exploitait": "exploiter",
    "exploitant": "exploiter",
    "exploitante": "exploitant",
    "exploitantes": "exploitant",
    "exploitants": "exploitant",
    "exploitas": "exploiter",
    "exploitasse": "exploiter",
    "exploitassent": "exploiter",
    "exploitasses": "exploiter",
    "exploitassiez": "exploiter",
    "exploitassions": "exploiter",
    "exploitations": "exploitation",
    "exploite": "exploiter",
    "exploitent": "exploiter",
    "exploitera": "exploiter",
    "exploiterai": "exploiter",
    "exploiteraient": "exploiter",
    "exploiterais": "exploiter",
    "exploiterait": "exploiter",
    "exploiteras": "exploiter",
    "exploiterez": "exploiter",
    "exploiteriez": "exploiter",
    "exploiterions": "exploiter",
    "exploiterons": "exploiter",
    "exploiteront": "exploiter",
    "exploites": "exploiter",
    "exploiteurs": "exploiteur",
    "exploiteuses": "exploiteur",
    "exploitez": "exploiter",
    "exploitiez": "exploiter",
    "exploitions": "exploiter",
    "exploitons": "exploiter",
    "exploits": "exploit",
    "exploitâmes": "exploiter",
    "exploitât": "exploiter",
    "exploitâtes": "exploiter",
    "exploitèrent": "exploiter",
    "exploité": "exploiter",
    "exploitée": "exploiter",
    "exploitées": "exploiter",
    "exploités": "exploiter",
    "explora": "explorer",
    "explorai": "explorer",
    "exploraient": "explorer",
    "explorais": "explorer",
    "explorait": "explorer",
    "explorant": "explorer",
    "exploras": "explorer",
    "explorasse": "explorer",
    "explorassent": "explorer",
    "explorasses": "explorer",
    "explorassiez": "explorer",
    "explorassions": "explorer",
    "explorateurs": "explorateur",
    "explorations": "exploration",
    "exploratoires": "exploratoire",
    "exploratrice": "explorateur",
    "exploratrices": "explorateur",
    "explore": "explorer",
    "explorent": "explorer",
    "explorera": "explorer",
    "explorerai": "explorer",
    "exploreraient": "explorer",
    "explorerais": "explorer",
    "explorerait": "explorer",
    "exploreras": "explorer",
    "explorerez": "explorer",
    "exploreriez": "explorer",
    "explorerions": "explorer",
    "explorerons": "explorer",
    "exploreront": "explorer",
    "explores": "explorer",
    "explorez": "explorer",
    "exploriez": "explorer",
    "explorions": "explorer",
    "explorons": "explorer",
    "explorâmes": "explorer",
    "explorât": "explorer",
    "explorâtes": "explorer",
    "explorèrent": "explorer",
    "exploré": "explorer",
    "explorée": "explorer",
    "explorées": "explorer",
    "explorés": "explorer",
    "explosa": "exploser",
    "explosai": "exploser",
    "explosaient": "exploser",
    "explosais": "exploser",
    "explosait": "exploser",
    "explosant": "exploser",
    "explosas": "exploser",
    "explosasse": "exploser",
    "explosassent": "exploser",
    "explosasses": "exploser",
    "explosassiez": "exploser",
    "explosassions": "exploser",
    "explose": "exploser",
    "explosent": "exploser",
    "explosera": "exploser",
    "exploserai": "exploser",
    "exploseraient": "exploser",
    "exploserais": "exploser",
    "exploserait": "exploser",
    "exploseras": "exploser",
    "exploserez": "exploser",
    "exploseriez": "exploser",
    "exploserions": "exploser",
    "exploserons": "exploser",
    "exploseront": "exploser",
    "exploses": "exploser",
    "explosez": "exploser",
    "explosiez": "exploser",
    "explosifs": "explosif",
    "explosions": "explosion",
    "explosive": "explosif",
    "explosives": "explosif",
    "explosons": "exploser",
    "explosâmes": "exploser",
    "explosât": "exploser",
    "explosâtes": "exploser",
    "explosèrent": "exploser",
    "explosé": "exploser",
    "explosée": "exploser",
    "explosées": "exploser",
    "explosés": "exploser",
    "explétifs": "explétif",
    "explétive": "explétif",
    "explétives": "explétif",
    "expoliations": "expoliation",
    "exponentielle": "exponentiel",
    "exponentielles": "exponentiel",
    "exponentiels": "exponentiel",
    "exporta": "exporter",
    "exportai": "exporter",
    "exportaient": "exporter",
    "exportais": "exporter",
    "exportait": "exporter",
    "exportant": "exporter",
    "exportas": "exporter",
    "exportasse": "exporter",
    "exportassent": "exporter",
    "exportasses": "exporter",
    "exportassiez": "exporter",
    "exportassions": "exporter",
    "exportateurs": "exportateur",
    "exportations": "exportation",
    "exportatrice": "exportateur",
    "exportatrices": "exportateur",
    "exporte": "exporter",
    "exportent": "exporter",
    "exportera": "exporter",
    "exporterai": "exporter",
    "exporteraient": "exporter",
    "exporterais": "exporter",
    "exporterait": "exporter",
    "exporteras": "exporter",
    "exporterez": "exporter",
    "exporteriez": "exporter",
    "exporterions": "exporter",
    "exporterons": "exporter",
    "exporteront": "exporter",
    "exportes": "exporter",
    "exportez": "exporter",
    "exportiez": "exporter",
    "exportions": "exporter",
    "exportons": "exporter",
    "exports": "export",
    "exportâmes": "exporter",
    "exportât": "exporter",
    "exportâtes": "exporter",
    "exportèrent": "exporter",
    "exporté": "exporter",
    "exportée": "exporter",
    "exportées": "exporter",
    "exportés": "exporter",
    "expos": "expo",
    "exposa": "exposer",
    "exposai": "exposer",
    "exposaient": "exposer",
    "exposais": "exposer",
    "exposait": "exposer",
    "exposant": "exposer",
    "exposants": "exposant",
    "exposas": "exposer",
    "exposasse": "exposer",
    "exposassent": "exposer",
    "exposasses": "exposer",
    "exposassiez": "exposer",
    "exposassions": "exposer",
    "expose": "exposer",
    "exposent": "exposer",
    "exposera": "exposer",
    "exposerai": "exposer",
    "exposeraient": "exposer",
    "exposerais": "exposer",
    "exposerait": "exposer",
    "exposeras": "exposer",
    "exposerez": "exposer",
    "exposeriez": "exposer",
    "exposerions": "exposer",
    "exposerons": "exposer",
    "exposeront": "exposer",
    "exposes": "exposer",
    "exposez": "exposer",
    "exposiez": "exposer",
    "exposions": "exposer",
    "expositions": "exposition",
    "exposons": "exposer",
    "exposâmes": "exposer",
    "exposât": "exposer",
    "exposâtes": "exposer",
    "exposèrent": "exposer",
    "exposé": "exposer",
    "exposée": "exposer",
    "exposées": "exposer",
    "exposés": "exposer",
    "expresse": "exprès",
    "expresses": "exprès",
    "expressifs": "expressif",
    "expressionnismes": "expressionnisme",
    "expressionnistes": "expressionniste",
    "expressions": "expression",
    "expressive": "expressif",
    "expressives": "expressif",
    "exprima": "exprimer",
    "exprimai": "exprimer",
    "exprimaient": "exprimer",
    "exprimais": "exprimer",
    "exprimait": "exprimer",
    "exprimant": "exprimer",
    "exprimas": "exprimer",
    "exprimasse": "exprimer",
    "exprimassent": "exprimer",
    "exprimasses": "exprimer",
    "exprimassiez": "exprimer",
    "exprimassions": "exprimer",
    "exprime": "exprimer",
    "expriment": "exprimer",
    "exprimera": "exprimer",
    "exprimerai": "exprimer",
    "exprimeraient": "exprimer",
    "exprimerais": "exprimer",
    "exprimerait": "exprimer",
    "exprimeras": "exprimer",
    "exprimerez": "exprimer",
    "exprimeriez": "exprimer",
    "exprimerions": "exprimer",
    "exprimerons": "exprimer",
    "exprimeront": "exprimer",
    "exprimes": "exprimer",
    "exprimez": "exprimer",
    "exprimiez": "exprimer",
    "exprimions": "exprimer",
    "exprimons": "exprimer",
    "exprimâmes": "exprimer",
    "exprimât": "exprimer",
    "exprimâtes": "exprimer",
    "exprimèrent": "exprimer",
    "exprimé": "exprimer",
    "exprimée": "exprimer",
    "exprimées": "exprimer",
    "exprimés": "exprimer",
    "expropria": "exproprier",
    "expropriai": "exproprier",
    "expropriaient": "exproprier",
    "expropriais": "exproprier",
    "expropriait": "exproprier",
    "expropriant": "exproprier",
    "exproprias": "exproprier",
    "expropriasse": "exproprier",
    "expropriassent": "exproprier",
    "expropriasses": "exproprier",
    "expropriassiez": "exproprier",
    "expropriassions": "exproprier",
    "expropriations": "expropriation",
    "exproprie": "exproprier",
    "exproprient": "exproprier",
    "expropriera": "exproprier",
    "exproprierai": "exproprier",
    "exproprieraient": "exproprier",
    "exproprierais": "exproprier",
    "exproprierait": "exproprier",
    "exproprieras": "exproprier",
    "exproprierez": "exproprier",
    "exproprieriez": "exproprier",
    "exproprierions": "exproprier",
    "exproprierons": "exproprier",
    "exproprieront": "exproprier",
    "expropries": "exproprier",
    "expropriez": "exproprier",
    "expropriiez": "exproprier",
    "expropriions": "exproprier",
    "exproprions": "exproprier",
    "expropriâmes": "exproprier",
    "expropriât": "exproprier",
    "expropriâtes": "exproprier",
    "exproprièrent": "exproprier",
    "exproprié": "exproprier",
    "expropriée": "exproprier",
    "expropriées": "exproprier",
    "expropriés": "exproprier",
    "expulsa": "expulser",
    "expulsai": "expulser",
    "expulsaient": "expulser",
    "expulsais": "expulser",
    "expulsait": "expulser",
    "expulsant": "expulser",
    "expulsas": "expulser",
    "expulsasse": "expulser",
    "expulsassent": "expulser",
    "expulsasses": "expulser",
    "expulsassiez": "expulser",
    "expulsassions": "expulser",
    "expulse": "expulser",
    "expulsent": "expulser",
    "expulsera": "expulser",
    "expulserai": "expulser",
    "expulseraient": "expulser",
    "expulserais": "expulser",
    "expulserait": "expulser",
    "expulseras": "expulser",
    "expulserez": "expulser",
    "expulseriez": "expulser",
    "expulserions": "expulser",
    "expulserons": "expulser",
    "expulseront": "expulser",
    "expulses": "expulser",
    "expulsez": "expulser",
    "expulsiez": "expulser",
    "expulsions": "expulsion",
    "expulsive": "expulsif",
    "expulsons": "expulser",
    "expulsâmes": "expulser",
    "expulsât": "expulser",
    "expulsâtes": "expulser",
    "expulsèrent": "expulser",
    "expulsé": "expulser",
    "expulsée": "expulser",
    "expulsées": "expulser",
    "expulsés": "expulser",
    "expurge": "expurger",
    "expurgea": "expurger",
    "expurgeai": "expurger",
    "expurgeaient": "expurger",
    "expurgeais": "expurger",
    "expurgeait": "expurger",
    "expurgeant": "expurger",
    "expurgeas": "expurger",
    "expurgeasse": "expurger",
    "expurgeassent": "expurger",
    "expurgeasses": "expurger",
    "expurgeassiez": "expurger",
    "expurgeassions": "expurger",
    "expurgent": "expurger",
    "expurgeons": "expurger",
    "expurgera": "expurger",
    "expurgerai": "expurger",
    "expurgeraient": "expurger",
    "expurgerais": "expurger",
    "expurgerait": "expurger",
    "expurgeras": "expurger",
    "expurgerez": "expurger",
    "expurgeriez": "expurger",
    "expurgerions": "expurger",
    "expurgerons": "expurger",
    "expurgeront": "expurger",
    "expurges": "expurger",
    "expurgez": "expurger",
    "expurgeâmes": "expurger",
    "expurgeât": "expurger",
    "expurgeâtes": "expurger",
    "expurgiez": "expurger",
    "expurgions": "expurger",
    "expurgèrent": "expurger",
    "expurgé": "expurger",
    "expurgée": "expurger",
    "expurgées": "expurger",
    "expurgés": "expurger",
    "expédia": "expédier",
    "expédiai": "expédier",
    "expédiaient": "expédier",
    "expédiais": "expédier",
    "expédiait": "expédier",
    "expédiant": "expédier",
    "expédias": "expédier",
    "expédiasse": "expédier",
    "expédiassent": "expédier",
    "expédiasses": "expédier",
    "expédiassiez": "expédier",
    "expédiassions": "expédier",
    "expédie": "expédier",
    "expédient": "expédier",
    "expédientes": "expédient",
    "expédients": "expédient",
    "expédiera": "expédier",
    "expédierai": "expédier",
    "expédieraient": "expédier",
    "expédierais": "expédier",
    "expédierait": "expédier",
    "expédieras": "expédier",
    "expédierez": "expédier",
    "expédieriez": "expédier",
    "expédierions": "expédier",
    "expédierons": "expédier",
    "expédieront": "expédier",
    "expédies": "expédier",
    "expédiez": "expédier",
    "expédiiez": "expédier",
    "expédiions": "expédier",
    "expédions": "expédier",
    "expéditeurs": "expéditeur",
    "expéditifs": "expéditif",
    "expéditionnaires": "expéditionnaire",
    "expéditions": "expédition",
    "expéditive": "expéditif",
    "expéditives": "expéditif",
    "expéditrice": "expéditeur",
    "expéditrices": "expéditeur",
    "expédiâmes": "expédier",
    "expédiât": "expédier",
    "expédiâtes": "expédier",
    "expédièrent": "expédier",
    "expédié": "expédier",
    "expédiée": "expédier",
    "expédiées": "expédier",
    "expédiés": "expédier",
    "expériences": "expérience",
    "expérimenta": "expérimenter",
    "expérimentai": "expérimenter",
    "expérimentaient": "expérimenter",
    "expérimentais": "expérimenter",
    "expérimentait": "expérimenter",
    "expérimentale": "expérimental",
    "expérimentales": "expérimental",
    "expérimentant": "expérimenter",
    "expérimentas": "expérimenter",
    "expérimentasse": "expérimenter",
    "expérimentassent": "expérimenter",
    "expérimentasses": "expérimenter",
    "expérimentassiez": "expérimenter",
    "expérimentassions": "expérimenter",
    "expérimentateurs": "expérimentateur",
    "expérimentations": "expérimentation",
    "expérimentatrice": "expérimentateur",
    "expérimentatrices": "expérimentateur",
    "expérimentaux": "expérimental",
    "expérimente": "expérimenter",
    "expérimentent": "expérimenter",
    "expérimentera": "expérimenter",
    "expérimenterai": "expérimenter",
    "expérimenteraient": "expérimenter",
    "expérimenterais": "expérimenter",
    "expérimenterait": "expérimenter",
    "expérimenteras": "expérimenter",
    "expérimenterez": "expérimenter",
    "expérimenteriez": "expérimenter",
    "expérimenterions": "expérimenter",
    "expérimenterons": "expérimenter",
    "expérimenteront": "expérimenter",
    "expérimentes": "expérimenter",
    "expérimentez": "expérimenter",
    "expérimentiez": "expérimenter",
    "expérimentions": "expérimenter",
    "expérimentons": "expérimenter",
    "expérimentâmes": "expérimenter",
    "expérimentât": "expérimenter",
    "expérimentâtes": "expérimenter",
    "expérimentèrent": "expérimenter",
    "expérimenté": "expérimenter",
    "expérimentée": "expérimenter",
    "expérimentées": "expérimenter",
    "expérimentés": "expérimenter",
    "exquise": "exquis",
    "exquises": "exquis",
    "exsangues": "exsangue",
    "exsanguino-transfusions": "exsanguino-transfusion",
    "exsuda": "exsuder",
    "exsudai": "exsuder",
    "exsudaient": "exsuder",
    "exsudais": "exsuder",
    "exsudait": "exsuder",
    "exsudant": "exsuder",
    "exsudas": "exsuder",
    "exsudasse": "exsuder",
    "exsudassent": "exsuder",
    "exsudasses": "exsuder",
    "exsudassiez": "exsuder",
    "exsudassions": "exsuder",
    "exsude": "exsuder",
    "exsudent": "exsuder",
    "exsudera": "exsuder",
    "exsuderai": "exsuder",
    "exsuderaient": "exsuder",
    "exsuderais": "exsuder",
    "exsuderait": "exsuder",
    "exsuderas": "exsuder",
    "exsuderez": "exsuder",
    "exsuderiez": "exsuder",
    "exsuderions": "exsuder",
    "exsuderons": "exsuder",
    "exsuderont": "exsuder",
    "exsudes": "exsuder",
    "exsudez": "exsuder",
    "exsudiez": "exsuder",
    "exsudions": "exsuder",
    "exsudons": "exsuder",
    "exsudâmes": "exsuder",
    "exsudât": "exsuder",
    "exsudâtes": "exsuder",
    "exsudèrent": "exsuder",
    "exsudé": "exsuder",
    "exsudée": "exsuder",
    "exsudées": "exsuder",
    "exsudés": "exsuder",
    "extases": "extase",
    "extasia": "extasier",
    "extasiaient": "extasier",
    "extasiais": "extasier",
    "extasiait": "extasier",
    "extasiant": "extasier",
    "extasiantes": "extasiant",
    "extasie": "extasier",
    "extasient": "extasier",
    "extasieront": "extasier",
    "extasiez": "extasier",
    "extasions": "extasier",
    "extasiât": "extasier",
    "extasièrent": "extasier",
    "extasié": "extasier",
    "extasiée": "extasier",
    "extasiées": "extasier",
    "extasiés": "extasier",
    "extatiques": "extatique",
    "extenseurs": "extenseur",
    "extensibles": "extensible",
    "extensifications": "extensification",
    "extensifs": "extensif",
    "extensions": "extension",
    "extensive": "extensif",
    "extensives": "extensif",
    "extermina": "exterminer",
    "exterminai": "exterminer",
    "exterminaient": "exterminer",
    "exterminais": "exterminer",
    "exterminait": "exterminer",
    "exterminant": "exterminer",
    "exterminas": "exterminer",
    "exterminasse": "exterminer",
    "exterminassent": "exterminer",
    "exterminasses": "exterminer",
    "exterminassiez": "exterminer",
    "exterminassions": "exterminer",
    "exterminateurs": "exterminateur",
    "exterminations": "extermination",
    "exterminatrice": "exterminateur",
    "exterminatrices": "exterminateur",
    "extermine": "exterminer",
    "exterminent": "exterminer",
    "exterminera": "exterminer",
    "exterminerai": "exterminer",
    "extermineraient": "exterminer",
    "exterminerais": "exterminer",
    "exterminerait": "exterminer",
    "extermineras": "exterminer",
    "exterminerez": "exterminer",
    "extermineriez": "exterminer",
    "exterminerions": "exterminer",
    "exterminerons": "exterminer",
    "extermineront": "exterminer",
    "extermines": "exterminer",
    "exterminez": "exterminer",
    "exterminiez": "exterminer",
    "exterminions": "exterminer",
    "exterminons": "exterminer",
    "exterminâmes": "exterminer",
    "exterminât": "exterminer",
    "exterminâtes": "exterminer",
    "exterminèrent": "exterminer",
    "exterminé": "exterminer",
    "exterminée": "exterminer",
    "exterminées": "exterminer",
    "exterminés": "exterminer",
    "externes": "externe",
    "exterritorialités": "exterritorialité",
    "extincteurs": "extincteur",
    "extinctions": "extinction",
    "extirpa": "extirper",
    "extirpai": "extirper",
    "extirpaient": "extirper",
    "extirpais": "extirper",
    "extirpait": "extirper",
    "extirpant": "extirper",
    "extirpas": "extirper",
    "extirpasse": "extirper",
    "extirpassent": "extirper",
    "extirpasses": "extirper",
    "extirpassiez": "extirper",
    "extirpassions": "extirper",
    "extirpe": "extirper",
    "extirpent": "extirper",
    "extirpera": "extirper",
    "extirperai": "extirper",
    "extirperaient": "extirper",
    "extirperais": "extirper",
    "extirperait": "extirper",
    "extirperas": "extirper",
    "extirperez": "extirper",
    "extirperiez": "extirper",
    "extirperions": "extirper",
    "extirperons": "extirper",
    "extirperont": "extirper",
    "extirpes": "extirper",
    "extirpez": "extirper",
    "extirpiez": "extirper",
    "extirpions": "extirper",
    "extirpons": "extirper",
    "extirpâmes": "extirper",
    "extirpât": "extirper",
    "extirpâtes": "extirper",
    "extirpèrent": "extirper",
    "extirpé": "extirper",
    "extirpée": "extirper",
    "extirpées": "extirper",
    "extirpés": "extirper",
    "extorqua": "extorquer",
    "extorquai": "extorquer",
    "extorquaient": "extorquer",
    "extorquais": "extorquer",
    "extorquait": "extorquer",
    "extorquant": "extorquer",
    "extorquas": "extorquer",
    "extorquasse": "extorquer",
    "extorquassent": "extorquer",
    "extorquasses": "extorquer",
    "extorquassiez": "extorquer",
    "extorquassions": "extorquer",
    "extorque": "extorquer",
    "extorquent": "extorquer",
    "extorquera": "extorquer",
    "extorquerai": "extorquer",
    "extorqueraient": "extorquer",
    "extorquerais": "extorquer",
    "extorquerait": "extorquer",
    "extorqueras": "extorquer",
    "extorquerez": "extorquer",
    "extorqueriez": "extorquer",
    "extorquerions": "extorquer",
    "extorquerons": "extorquer",
    "extorqueront": "extorquer",
    "extorques": "extorquer",
    "extorquez": "extorquer",
    "extorquiez": "extorquer",
    "extorquions": "extorquer",
    "extorquons": "extorquer",
    "extorquâmes": "extorquer",
    "extorquât": "extorquer",
    "extorquâtes": "extorquer",
    "extorquèrent": "extorquer",
    "extorqué": "extorquer",
    "extorquée": "extorquer",
    "extorquées": "extorquer",
    "extorqués": "extorquer",
    "extorsions": "extorsion",
    "extra-fine": "extra-fin",
    "extra-fines": "extra-fin",
    "extra-fins": "extra-fin",
    "extra-forte": "extra-fort",
    "extra-forts": "extra-fort",
    "extra-lucides": "extra-lucide",
    "extra-sensorielle": "extra-sensoriel",
    "extra-souples": "extra-souple",
    "extra-terrestres": "extra-terrestre",
    "extra-utérine": "extra-utérin",
    "extra-utérines": "extra-utérin",
    "extra-utérins": "extra-utérin",
    "extrabudgétaires": "extrabudgétaire",
    "extracommunautaires": "extracommunautaire",
    "extraconjugale": "extraconjugal",
    "extraconjugales": "extraconjugal",
    "extraconjugaux": "extraconjugal",
    "extracontractuelle": "extracontractuel",
    "extracontractuelles": "extracontractuel",
    "extracontractuels": "extracontractuel",
    "extracorporelle": "extracorporel",
    "extracteurs": "extracteur",
    "extractifs": "extractif",
    "extractions": "extraction",
    "extractive": "extractif",
    "extractives": "extractif",
    "extrada": "extrader",
    "extradables": "extradable",
    "extradai": "extrader",
    "extradaient": "extrader",
    "extradais": "extrader",
    "extradait": "extrader",
    "extradant": "extrader",
    "extradas": "extrader",
    "extradasse": "extrader",
    "extradassent": "extrader",
    "extradasses": "extrader",
    "extradassiez": "extrader",
    "extradassions": "extrader",
    "extrade": "extrader",
    "extradent": "extrader",
    "extradera": "extrader",
    "extraderai": "extrader",
    "extraderaient": "extrader",
    "extraderais": "extrader",
    "extraderait": "extrader",
    "extraderas": "extrader",
    "extraderez": "extrader",
    "extraderiez": "extrader",
    "extraderions": "extrader",
    "extraderons": "extrader",
    "extraderont": "extrader",
    "extrades": "extrader",
    "extradez": "extrader",
    "extradiez": "extrader",
    "extradions": "extrader",
    "extraditionnelle": "extraditionnel",
    "extraditionnelles": "extraditionnel",
    "extraditionnels": "extraditionnel",
    "extraditions": "extradition",
    "extradons": "extrader",
    "extradâmes": "extrader",
    "extradât": "extrader",
    "extradâtes": "extrader",
    "extradèrent": "extrader",
    "extradé": "extrader",
    "extradée": "extrader",
    "extradées": "extrader",
    "extradés": "extrader",
    "extraforte": "extrafort",
    "extraie": "extraire",
    "extraient": "extraire",
    "extraies": "extraire",
    "extraira": "extraire",
    "extrairai": "extraire",
    "extrairaient": "extraire",
    "extrairais": "extraire",
    "extrairait": "extraire",
    "extrairas": "extraire",
    "extrairez": "extraire",
    "extrairiez": "extraire",
    "extrairions": "extraire",
    "extrairons": "extraire",
    "extrairont": "extraire",
    "extrais": "extraire",
    "extrait": "extraire",
    "extraite": "extraire",
    "extraites": "extraire",
    "extraits": "extrait",
    "extrajudiciaires": "extrajudiciaire",
    "extralucides": "extralucide",
    "extralégale": "extralégal",
    "extralégales": "extralégal",
    "extralégaux": "extralégal",
    "extraordinaires": "extraordinaire",
    "extrapola": "extrapoler",
    "extrapolai": "extrapoler",
    "extrapolaient": "extrapoler",
    "extrapolais": "extrapoler",
    "extrapolait": "extrapoler",
    "extrapolant": "extrapoler",
    "extrapolas": "extrapoler",
    "extrapolasse": "extrapoler",
    "extrapolassent": "extrapoler",
    "extrapolasses": "extrapoler",
    "extrapolassiez": "extrapoler",
    "extrapolassions": "extrapoler",
    "extrapolations": "extrapolation",
    "extrapole": "extrapoler",
    "extrapolent": "extrapoler",
    "extrapolera": "extrapoler",
    "extrapolerai": "extrapoler",
    "extrapoleraient": "extrapoler",
    "extrapolerais": "extrapoler",
    "extrapolerait": "extrapoler",
    "extrapoleras": "extrapoler",
    "extrapolerez": "extrapoler",
    "extrapoleriez": "extrapoler",
    "extrapolerions": "extrapoler",
    "extrapolerons": "extrapoler",
    "extrapoleront": "extrapoler",
    "extrapoles": "extrapoler",
    "extrapolez": "extrapoler",
    "extrapoliez": "extrapoler",
    "extrapolions": "extrapoler",
    "extrapolons": "extrapoler",
    "extrapolâmes": "extrapoler",
    "extrapolât": "extrapoler",
    "extrapolâtes": "extrapoler",
    "extrapolèrent": "extrapoler",
    "extrapolé": "extrapoler",
    "extrapolée": "extrapoler",
    "extrapolées": "extrapoler",
    "extrapolés": "extrapoler",
    "extras": "extra",
    "extrascolaires": "extrascolaire",
    "extrasensorielle": "extrasensoriel",
    "extrasensoriels": "extrasensoriel",
    "extraterrestres": "extraterrestre",
    "extraterritoriale": "extraterritorial",
    "extraterritoriales": "extraterritorial",
    "extraterritorialités": "extraterritorialité",
    "extraterritoriaux": "extraterritorial",
    "extravagances": "extravagance",
    "extravagante": "extravagant",
    "extravagantes": "extravagant",
    "extravagants": "extravagant",
    "extravaguait": "extravaguer",
    "extravague": "extravaguer",
    "extravagué": "extravaguer",
    "extraversions": "extraversion",
    "extravertie": "extraverti",
    "extraverties": "extraverti",
    "extravertis": "extraverti",
    "extrayaient": "extraire",
    "extrayais": "extraire",
    "extrayait": "extraire",
    "extrayant": "extraire",
    "extrayez": "extraire",
    "extrayiez": "extraire",
    "extrayions": "extraire",
    "extrayons": "extraire",
    "extrinsèques": "extrinsèque",
    "extrovertie": "extroverti",
    "extrudée": "extrudé",
    "extrudées": "extrudé",
    "extrudés": "extrudé",
    "extrusions": "extrusion",
    "extrémismes": "extrémisme",
    "extrémistes": "extrémiste",
    "extrémités": "extrémité",
    "extrême-orientale": "extrême-oriental",
    "extrême-orientales": "extrême-oriental",
    "extrême-orientaux": "extrême-oriental",
    "extrêmes": "extrême",
    "extrêmes-gauches": "extrême-gauche",
    "extrêmes-onctions": "extrême-onction",
    "exténua": "exténuer",
    "exténuai": "exténuer",
    "exténuaient": "exténuer",
    "exténuais": "exténuer",
    "exténuait": "exténuer",
    "exténuant": "exténuer",
    "exténuante": "exténuant",
    "exténuantes": "exténuant",
    "exténuants": "exténuant",
    "exténuas": "exténuer",
    "exténuasse": "exténuer",
    "exténuassent": "exténuer",
    "exténuasses": "exténuer",
    "exténuassiez": "exténuer",
    "exténuassions": "exténuer",
    "exténue": "exténuer",
    "exténuements": "exténuement",
    "exténuent": "exténuer",
    "exténuera": "exténuer",
    "exténuerai": "exténuer",
    "exténueraient": "exténuer",
    "exténuerais": "exténuer",
    "exténuerait": "exténuer",
    "exténueras": "exténuer",
    "exténuerez": "exténuer",
    "exténueriez": "exténuer",
    "exténuerions": "exténuer",
    "exténuerons": "exténuer",
    "exténueront": "exténuer",
    "exténues": "exténuer",
    "exténuez": "exténuer",
    "exténuiez": "exténuer",
    "exténuions": "exténuer",
    "exténuons": "exténuer",
    "exténuâmes": "exténuer",
    "exténuât": "exténuer",
    "exténuâtes": "exténuer",
    "exténuèrent": "exténuer",
    "exténué": "exténuer",
    "exténuée": "exténuer",
    "exténuées": "exténuer",
    "exténués": "exténuer",
    "extérieure": "extérieur",
    "extérieures": "extérieur",
    "extérieurs": "extérieur",
    "extériorisa": "extérioriser",
    "extériorisai": "extérioriser",
    "extériorisaient": "extérioriser",
    "extériorisais": "extérioriser",
    "extériorisait": "extérioriser",
    "extériorisant": "extérioriser",
    "extériorisas": "extérioriser",
    "extériorisasse": "extérioriser",
    "extériorisassent": "extérioriser",
    "extériorisasses": "extérioriser",
    "extériorisassiez": "extérioriser",
    "extériorisassions": "extérioriser",
    "extériorise": "extérioriser",
    "extériorisent": "extérioriser",
    "extériorisera": "extérioriser",
    "extérioriserai": "extérioriser",
    "extérioriseraient": "extérioriser",
    "extérioriserais": "extérioriser",
    "extérioriserait": "extérioriser",
    "extérioriseras": "extérioriser",
    "extérioriserez": "extérioriser",
    "extérioriseriez": "extérioriser",
    "extérioriserions": "extérioriser",
    "extérioriserons": "extérioriser",
    "extérioriseront": "extérioriser",
    "extériorises": "extérioriser",
    "extériorisez": "extérioriser",
    "extériorisiez": "extérioriser",
    "extériorisions": "extérioriser",
    "extériorisons": "extérioriser",
    "extériorisâmes": "extérioriser",
    "extériorisât": "extérioriser",
    "extériorisâtes": "extérioriser",
    "extériorisèrent": "extérioriser",
    "extériorisé": "extérioriser",
    "extériorisée": "extérioriser",
    "extériorisées": "extérioriser",
    "extériorisés": "extérioriser",
    "exubérances": "exubérance",
    "exubérante": "exubérant",
    "exubérantes": "exubérant",
    "exubérants": "exubérant",
    "exulta": "exulter",
    "exultai": "exulter",
    "exultaient": "exulter",
    "exultais": "exulter",
    "exultait": "exulter",
    "exultant": "exulter",
    "exultante": "exultant",
    "exultantes": "exultant",
    "exultants": "exultant",
    "exultas": "exulter",
    "exultasse": "exulter",
    "exultassent": "exulter",
    "exultasses": "exulter",
    "exultassiez": "exulter",
    "exultassions": "exulter",
    "exulte": "exulter",
    "exultent": "exulter",
    "exultera": "exulter",
    "exulterai": "exulter",
    "exulteraient": "exulter",
    "exulterais": "exulter",
    "exulterait": "exulter",
    "exulteras": "exulter",
    "exulterez": "exulter",
    "exulteriez": "exulter",
    "exulterions": "exulter",
    "exulterons": "exulter",
    "exulteront": "exulter",
    "exultes": "exulter",
    "exultez": "exulter",
    "exultiez": "exulter",
    "exultions": "exulter",
    "exultons": "exulter",
    "exultâmes": "exulter",
    "exultât": "exulter",
    "exultâtes": "exulter",
    "exultèrent": "exulter",
    "exulté": "exulter",
    "exutoires": "exutoire",
    "exècre": "exécrer",
    "exècrent": "exécrer",
    "exècres": "exécrer",
    "exécra": "exécrer",
    "exécrables": "exécrable",
    "exécrai": "exécrer",
    "exécraient": "exécrer",
    "exécrais": "exécrer",
    "exécrait": "exécrer",
    "exécrant": "exécrer",
    "exécras": "exécrer",
    "exécrasse": "exécrer",
    "exécrassent": "exécrer",
    "exécrasses": "exécrer",
    "exécrassiez": "exécrer",
    "exécrassions": "exécrer",
    "exécrations": "exécration",
    "exécrera": "exécrer",
    "exécrerai": "exécrer",
    "exécreraient": "exécrer",
    "exécrerais": "exécrer",
    "exécrerait": "exécrer",
    "exécreras": "exécrer",
    "exécrerez": "exécrer",
    "exécreriez": "exécrer",
    "exécrerions": "exécrer",
    "exécrerons": "exécrer",
    "exécreront": "exécrer",
    "exécrez": "exécrer",
    "exécriez": "exécrer",
    "exécrions": "exécrer",
    "exécrons": "exécrer",
    "exécrâmes": "exécrer",
    "exécrât": "exécrer",
    "exécrâtes": "exécrer",
    "exécrèrent": "exécrer",
    "exécré": "exécrer",
    "exécrée": "exécrer",
    "exécrées": "exécrer",
    "exécrés": "exécrer",
    "exécuta": "exécuter",
    "exécutai": "exécuter",
    "exécutaient": "exécuter",
    "exécutais": "exécuter",
    "exécutait": "exécuter",
    "exécutant": "exécuter",
    "exécutante": "exécutant",
    "exécutantes": "exécutant",
    "exécutants": "exécutant",
    "exécutas": "exécuter",
    "exécutasse": "exécuter",
    "exécutassent": "exécuter",
    "exécutasses": "exécuter",
    "exécutassiez": "exécuter",
    "exécutassions": "exécuter",
    "exécute": "exécuter",
    "exécutent": "exécuter",
    "exécutera": "exécuter",
    "exécuterai": "exécuter",
    "exécuteraient": "exécuter",
    "exécuterais": "exécuter",
    "exécuterait": "exécuter",
    "exécuteras": "exécuter",
    "exécuterez": "exécuter",
    "exécuteriez": "exécuter",
    "exécuterions": "exécuter",
    "exécuterons": "exécuter",
    "exécuteront": "exécuter",
    "exécutes": "exécuter",
    "exécuteurs": "exécuteur",
    "exécutez": "exécuter",
    "exécutiez": "exécuter",
    "exécutifs": "exécutif",
    "exécutions": "exécution",
    "exécutive": "exécutif",
    "exécutives": "exécutif",
    "exécutoires": "exécutoire",
    "exécutons": "exécuter",
    "exécutrice": "exécuteur",
    "exécutâmes": "exécuter",
    "exécutât": "exécuter",
    "exécutâtes": "exécuter",
    "exécutèrent": "exécuter",
    "exécuté": "exécuter",
    "exécutée": "exécuter",
    "exécutées": "exécuter",
    "exécutés": "exécuter",
    "exégèses": "exégèse",
    "exégètes": "exégète",
    "exégétiques": "exégétique",
    "exérèses": "exérèse",
    "eye-liners": "eye-liner",
    "eûmes": "avoir",
    "eût": "avoir",
    "eûtes": "avoir",
    "fabiens": "fabien",
    "fabiusienne": "fabiusien",
    "fabiusiennes": "fabiusien",
    "fabiusiens": "fabiusien",
    "fables": "fable",
    "fabliaux": "fabliau",
    "fabricante": "fabricant",
    "fabricantes": "fabricant",
    "fabricants": "fabricant",
    "fabrications": "fabrication",
    "fabriqua": "fabriquer",
    "fabriquai": "fabriquer",
    "fabriquaient": "fabriquer",
    "fabriquais": "fabriquer",
    "fabriquait": "fabriquer",
    "fabriquant": "fabriquer",
    "fabriquas": "fabriquer",
    "fabriquasse": "fabriquer",
    "fabriquassent": "fabriquer",
    "fabriquasses": "fabriquer",
    "fabriquassiez": "fabriquer",
    "fabriquassions": "fabriquer",
    "fabrique": "fabriquer",
    "fabriquent": "fabriquer",
    "fabriquera": "fabriquer",
    "fabriquerai": "fabriquer",
    "fabriqueraient": "fabriquer",
    "fabriquerais": "fabriquer",
    "fabriquerait": "fabriquer",
    "fabriqueras": "fabriquer",
    "fabriquerez": "fabriquer",
    "fabriqueriez": "fabriquer",
    "fabriquerions": "fabriquer",
    "fabriquerons": "fabriquer",
    "fabriqueront": "fabriquer",
    "fabriques": "fabriquer",
    "fabriquez": "fabriquer",
    "fabriquiez": "fabriquer",
    "fabriquions": "fabriquer",
    "fabriquons": "fabriquer",
    "fabriquâmes": "fabriquer",
    "fabriquât": "fabriquer",
    "fabriquâtes": "fabriquer",
    "fabriquèrent": "fabriquer",
    "fabriqué": "fabriquer",
    "fabriquée": "fabriquer",
    "fabriquées": "fabriquer",
    "fabriqués": "fabriquer",
    "fabulations": "fabulation",
    "fabulatrice": "fabulateur",
    "fabule": "fabuler",
    "fabuleuse": "fabuleux",
    "fabuleuses": "fabuleux",
    "fabulez": "fabuler",
    "fabulé": "fabuler",
    "fac-similé": "fac-similer",
    "fac-similés": "fac-similé",
    "faces": "face",
    "faces-à-main": "face-à-main",
    "facettes": "facette",
    "facettés": "facetter",
    "fachos": "facho",
    "faciale": "facial",
    "faciales": "facial",
    "faciaux": "facial",
    "faciles": "facile",
    "facilita": "faciliter",
    "facilitai": "faciliter",
    "facilitaient": "faciliter",
    "facilitais": "faciliter",
    "facilitait": "faciliter",
    "facilitant": "faciliter",
    "facilitas": "faciliter",
    "facilitasse": "faciliter",
    "facilitassent": "faciliter",
    "facilitasses": "faciliter",
    "facilitassiez": "faciliter",
    "facilitassions": "faciliter",
    "facilitations": "facilitation",
    "facilite": "faciliter",
    "facilitent": "faciliter",
    "facilitera": "faciliter",
    "faciliterai": "faciliter",
    "faciliteraient": "faciliter",
    "faciliterais": "faciliter",
    "faciliterait": "faciliter",
    "faciliteras": "faciliter",
    "faciliterez": "faciliter",
    "faciliteriez": "faciliter",
    "faciliterions": "faciliter",
    "faciliterons": "faciliter",
    "faciliteront": "faciliter",
    "facilites": "faciliter",
    "facilitez": "faciliter",
    "facilitiez": "faciliter",
    "facilitions": "faciliter",
    "facilitons": "faciliter",
    "facilitâmes": "faciliter",
    "facilitât": "faciliter",
    "facilitâtes": "faciliter",
    "facilitèrent": "faciliter",
    "facilité": "faciliter",
    "facilitée": "faciliter",
    "facilitées": "faciliter",
    "facilités": "faciliter",
    "facondes": "faconde",
    "facs": "fac",
    "facteurs": "facteur",
    "factices": "factice",
    "factieuse": "factieux",
    "factieuses": "factieux",
    "factionnaires": "factionnaire",
    "factions": "faction",
    "factitifs": "factitif",
    "factitive": "factitif",
    "factitives": "factitif",
    "factorielle": "factoriel",
    "factorielles": "factoriel",
    "factotums": "factotum",
    "factrice": "facteur",
    "factrices": "facteur",
    "factuelle": "factuel",
    "factuelles": "factuel",
    "factuels": "factuel",
    "factums": "factum",
    "factura": "facturer",
    "facturai": "facturer",
    "facturaient": "facturer",
    "facturais": "facturer",
    "facturait": "facturer",
    "facturant": "facturer",
    "facturas": "facturer",
    "facturasse": "facturer",
    "facturassent": "facturer",
    "facturasses": "facturer",
    "facturassiez": "facturer",
    "facturassions": "facturer",
    "facturations": "facturation",
    "facture": "facturer",
    "facturent": "facturer",
    "facturera": "facturer",
    "facturerai": "facturer",
    "factureraient": "facturer",
    "facturerais": "facturer",
    "facturerait": "facturer",
    "factureras": "facturer",
    "facturerez": "facturer",
    "factureriez": "facturer",
    "facturerions": "facturer",
    "facturerons": "facturer",
    "factureront": "facturer",
    "factures": "facturer",
    "facturez": "facturer",
    "facturiez": "facturer",
    "facturions": "facturer",
    "facturière": "facturier",
    "facturons": "facturer",
    "facturâmes": "facturer",
    "facturât": "facturer",
    "facturâtes": "facturer",
    "facturèrent": "facturer",
    "facturé": "facturer",
    "facturée": "facturer",
    "facturées": "facturer",
    "facturés": "facturer",
    "facultatifs": "facultatif",
    "facultative": "facultatif",
    "facultatives": "facultatif",
    "facultés": "faculté",
    "facéties": "facétie",
    "facétieuse": "facétieux",
    "facétieuses": "facétieux",
    "fadaises": "fadaise",
    "fadas": "fada",
    "fadasses": "fadasse",
    "fade": "fader",
    "fadent": "fader",
    "faderas": "fader",
    "fades": "fade",
    "fadeurs": "fadeur",
    "fadings": "fading",
    "fadé": "fader",
    "fadée": "fadé",
    "fadés": "fader",
    "fafiots": "fafiot",
    "fafs": "faf",
    "fagnes": "fagne",
    "fagota": "fagoter",
    "fagotai": "fagoter",
    "fagotaient": "fagoter",
    "fagotais": "fagoter",
    "fagotait": "fagoter",
    "fagotant": "fagoter",
    "fagotas": "fagoter",
    "fagotasse": "fagoter",
    "fagotassent": "fagoter",
    "fagotasses": "fagoter",
    "fagotassiez": "fagoter",
    "fagotassions": "fagoter",
    "fagote": "fagoter",
    "fagotent": "fagoter",
    "fagotera": "fagoter",
    "fagoterai": "fagoter",
    "fagoteraient": "fagoter",
    "fagoterais": "fagoter",
    "fagoterait": "fagoter",
    "fagoteras": "fagoter",
    "fagoterez": "fagoter",
    "fagoteriez": "fagoter",
    "fagoterions": "fagoter",
    "fagoterons": "fagoter",
    "fagoteront": "fagoter",
    "fagotes": "fagoter",
    "fagotez": "fagoter",
    "fagotiers": "fagotier",
    "fagotiez": "fagoter",
    "fagotins": "fagotin",
    "fagotions": "fagoter",
    "fagotons": "fagoter",
    "fagots": "fagot",
    "fagotâmes": "fagoter",
    "fagotât": "fagoter",
    "fagotâtes": "fagoter",
    "fagotèrent": "fagoter",
    "fagoté": "fagoter",
    "fagotée": "fagoter",
    "fagotées": "fagoter",
    "fagotés": "fagoter",
    "faiblarde": "faiblard",
    "faiblards": "faiblard",
    "faibles": "faible",
    "faiblesses": "faiblesse",
    "faibli": "faiblir",
    "faiblira": "faiblir",
    "faiblirai": "faiblir",
    "faibliraient": "faiblir",
    "faiblirais": "faiblir",
    "faiblirait": "faiblir",
    "faibliras": "faiblir",
    "faiblirent": "faiblir",
    "faiblirez": "faiblir",
    "faibliriez": "faiblir",
    "faiblirions": "faiblir",
    "faiblirons": "faiblir",
    "faibliront": "faiblir",
    "faiblis": "faiblir",
    "faiblissaient": "faiblir",
    "faiblissais": "faiblir",
    "faiblissait": "faiblir",
    "faiblissant": "faiblir",
    "faiblissante": "faiblissant",
    "faiblissantes": "faiblissant",
    "faiblisse": "faiblir",
    "faiblissent": "faiblir",
    "faiblisses": "faiblir",
    "faiblissez": "faiblir",
    "faiblissiez": "faiblir",
    "faiblissions": "faiblir",
    "faiblissons": "faiblir",
    "faiblit": "faiblir",
    "faiblîmes": "faiblir",
    "faiblît": "faiblir",
    "faiblîtes": "faiblir",
    "faignante": "faignanter",
    "faignantes": "faignant",
    "faignants": "faignant",
    "faillaient": "faillir",
    "faillais": "faillir",
    "faillait": "faillir",
    "faillant": "faillir",
    "faille": "falloir",
    "faillent": "faillir",
    "failles": "faillir",
    "faillez": "faillir",
    "failli": "faillir",
    "faillibilités": "faillibilité",
    "faillibles": "faillible",
    "faillie": "failli",
    "faillies": "faillie",
    "failliez": "faillir",
    "faillions": "faillir",
    "faillira": "faillir",
    "faillirai": "faillir",
    "failliraient": "faillir",
    "faillirais": "faillir",
    "faillirait": "faillir",
    "failliras": "faillir",
    "faillirent": "faillir",
    "faillirez": "faillir",
    "failliriez": "faillir",
    "faillirions": "faillir",
    "faillirons": "faillir",
    "failliront": "faillir",
    "faillis": "faillir",
    "faillisse": "faillir",
    "faillissent": "faillir",
    "faillisses": "faillir",
    "faillissiez": "faillir",
    "faillissions": "faillir",
    "faillit": "faillir",
    "faillites": "faillite",
    "faillons": "faillir",
    "faillîmes": "faillir",
    "faillît": "faillir",
    "faillîtes": "faillir",
    "faims": "faim",
    "fainéanta": "fainéanter",
    "fainéantai": "fainéanter",
    "fainéantaient": "fainéanter",
    "fainéantais": "fainéanter",
    "fainéantait": "fainéanter",
    "fainéantant": "fainéanter",
    "fainéantas": "fainéanter",
    "fainéantasse": "fainéanter",
    "fainéantassent": "fainéanter",
    "fainéantasses": "fainéanter",
    "fainéantassiez": "fainéanter",
    "fainéantassions": "fainéanter",
    "fainéante": "fainéanter",
    "fainéantent": "fainéanter",
    "fainéantera": "fainéanter",
    "fainéanterai": "fainéanter",
    "fainéanteraient": "fainéanter",
    "fainéanterais": "fainéanter",
    "fainéanterait": "fainéanter",
    "fainéanteras": "fainéanter",
    "fainéanterez": "fainéanter",
    "fainéanteriez": "fainéanter",
    "fainéanterions": "fainéanter",
    "fainéanterons": "fainéanter",
    "fainéanteront": "fainéanter",
    "fainéantes": "fainéanter",
    "fainéantez": "fainéanter",
    "fainéantiez": "fainéanter",
    "fainéantions": "fainéanter",
    "fainéantons": "fainéanter",
    "fainéants": "fainéant",
    "fainéantâmes": "fainéanter",
    "fainéantât": "fainéanter",
    "fainéantâtes": "fainéanter",
    "fainéantèrent": "fainéanter",
    "fainéanté": "fainéanter",
    "fais": "faire",
    "faisabilités": "faisabilité",
    "faisables": "faisable",
    "faisaient": "faire",
    "faisais": "faire",
    "faisait": "faire",
    "faisandeaux": "faisandeau",
    "faisandé": "faisander",
    "faisandée": "faisander",
    "faisandées": "faisander",
    "faisandés": "faisandé",
    "faisane": "faisan",
    "faisanes": "faisan",
    "faisans": "faisan",
    "faisant": "faire",
    "faisceaux": "faisceau",
    "faiseurs": "faiseur",
    "faiseuse": "faiseur",
    "faiseuses": "faiseur",
    "faisiez": "faire",
    "faisions": "faire",
    "faisons": "faire",
    "fait": "faire",
    "faite": "fait",
    "faites": "fait",
    "faitouts": "faitout",
    "faits": "fait",
    "fakirs": "fakir",
    "falaises": "falaise",
    "falbalas": "falbala",
    "fallacieuse": "fallacieux",
    "fallacieuses": "fallacieux",
    "fallait": "falloir",
    "fallu": "falloir",
    "fallut": "falloir",
    "fallût": "falloir",
    "falote": "falot",
    "falotes": "falot",
    "falots": "falot",
    "falourdes": "falourde",
    "falsifia": "falsifier",
    "falsifiai": "falsifier",
    "falsifiaient": "falsifier",
    "falsifiais": "falsifier",
    "falsifiait": "falsifier",
    "falsifiant": "falsifier",
    "falsifias": "falsifier",
    "falsifiasse": "falsifier",
    "falsifiassent": "falsifier",
    "falsifiasses": "falsifier",
    "falsifiassiez": "falsifier",
    "falsifiassions": "falsifier",
    "falsificateurs": "falsificateur",
    "falsifications": "falsification",
    "falsificatrice": "falsificateur",
    "falsificatrices": "falsificateur",
    "falsifie": "falsifier",
    "falsifient": "falsifier",
    "falsifiera": "falsifier",
    "falsifierai": "falsifier",
    "falsifieraient": "falsifier",
    "falsifierais": "falsifier",
    "falsifierait": "falsifier",
    "falsifieras": "falsifier",
    "falsifierez": "falsifier",
    "falsifieriez": "falsifier",
    "falsifierions": "falsifier",
    "falsifierons": "falsifier",
    "falsifieront": "falsifier",
    "falsifies": "falsifier",
    "falsifiez": "falsifier",
    "falsifiiez": "falsifier",
    "falsifiions": "falsifier",
    "falsifions": "falsifier",
    "falsifiâmes": "falsifier",
    "falsifiât": "falsifier",
    "falsifiâtes": "falsifier",
    "falsifièrent": "falsifier",
    "falsifié": "falsifier",
    "falsifiée": "falsifier",
    "falsifiées": "falsifier",
    "falsifiés": "falsifier",
    "falzars": "falzar",
    "fameuse": "fameux",
    "fameuses": "fameux",
    "familiale": "familial",
    "familiales": "familiale",
    "familialismes": "familialisme",
    "familiarisa": "familiariser",
    "familiarisai": "familiariser",
    "familiarisaient": "familiariser",
    "familiarisais": "familiariser",
    "familiarisait": "familiariser",
    "familiarisant": "familiariser",
    "familiarisas": "familiariser",
    "familiarisasse": "familiariser",
    "familiarisassent": "familiariser",
    "familiarisasses": "familiariser",
    "familiarisassiez": "familiariser",
    "familiarisassions": "familiariser",
    "familiarise": "familiariser",
    "familiarisent": "familiariser",
    "familiarisera": "familiariser",
    "familiariserai": "familiariser",
    "familiariseraient": "familiariser",
    "familiariserais": "familiariser",
    "familiariserait": "familiariser",
    "familiariseras": "familiariser",
    "familiariserez": "familiariser",
    "familiariseriez": "familiariser",
    "familiariserions": "familiariser",
    "familiariserons": "familiariser",
    "familiariseront": "familiariser",
    "familiarises": "familiariser",
    "familiarisez": "familiariser",
    "familiarisiez": "familiariser",
    "familiarisions": "familiariser",
    "familiarisons": "familiariser",
    "familiarisâmes": "familiariser",
    "familiarisât": "familiariser",
    "familiarisâtes": "familiariser",
    "familiarisèrent": "familiariser",
    "familiarisé": "familiariser",
    "familiarisée": "familiariser",
    "familiarisées": "familiariser",
    "familiarisés": "familiariser",
    "familiarités": "familiarité",
    "familiaux": "familial",
    "familiers": "familier",
    "familière": "familier",
    "familières": "familier",
    "familles": "famille",
    "famines": "famine",
    "famée": "famé",
    "famées": "famé",
    "faméliques": "famélique",
    "famés": "famé",
    "fanaient": "faner",
    "fanait": "faner",
    "fanant": "faner",
    "fanas": "fana",
    "fanatiques": "fanatique",
    "fanatisait": "fanatiser",
    "fanatise": "fanatiser",
    "fanatismes": "fanatisme",
    "fanatisé": "fanatiser",
    "fanatisée": "fanatisé",
    "fanatisées": "fanatisé",
    "fanatisés": "fanatiser",
    "fanaux": "fanal",
    "fandangos": "fandango",
    "fane": "faner",
    "fanent": "faner",
    "fanera": "faner",
    "faneraient": "faner",
    "fanerait": "faner",
    "faneras": "faner",
    "fanerions": "faner",
    "faneront": "faner",
    "fanes": "faner",
    "faneuse": "faneur",
    "faneuses": "faneur",
    "fanez": "faner",
    "fanfares": "fanfare",
    "fanfaronna": "fanfaronner",
    "fanfaronnades": "fanfaronnade",
    "fanfaronnai": "fanfaronner",
    "fanfaronnaient": "fanfaronner",
    "fanfaronnais": "fanfaronner",
    "fanfaronnait": "fanfaronner",
    "fanfaronnant": "fanfaronner",
    "fanfaronnas": "fanfaronner",
    "fanfaronnasse": "fanfaronner",
    "fanfaronnassent": "fanfaronner",
    "fanfaronnasses": "fanfaronner",
    "fanfaronnassiez": "fanfaronner",
    "fanfaronnassions": "fanfaronner",
    "fanfaronne": "fanfaronner",
    "fanfaronnent": "fanfaronner",
    "fanfaronnera": "fanfaronner",
    "fanfaronnerai": "fanfaronner",
    "fanfaronneraient": "fanfaronner",
    "fanfaronnerais": "fanfaronner",
    "fanfaronnerait": "fanfaronner",
    "fanfaronneras": "fanfaronner",
    "fanfaronnerez": "fanfaronner",
    "fanfaronneriez": "fanfaronner",
    "fanfaronnerions": "fanfaronner",
    "fanfaronnerons": "fanfaronner",
    "fanfaronneront": "fanfaronner",
    "fanfaronnes": "fanfaronner",
    "fanfaronnez": "fanfaronner",
    "fanfaronniez": "fanfaronner",
    "fanfaronnions": "fanfaronner",
    "fanfaronnons": "fanfaronner",
    "fanfaronnâmes": "fanfaronner",
    "fanfaronnât": "fanfaronner",
    "fanfaronnâtes": "fanfaronner",
    "fanfaronnèrent": "fanfaronner",
    "fanfaronné": "fanfaronner",
    "fanfaronnée": "fanfaronner",
    "fanfaronnées": "fanfaronner",
    "fanfaronnés": "fanfaronner",
    "fanfarons": "fanfaron",
    "fanfreluches": "fanfreluche",
    "fanges": "fange",
    "fangeuse": "fangeux",
    "fangeuses": "fangeux",
    "fanions": "fanion",
    "fanons": "fanon",
    "fans": "fan",
    "fantaisies": "fantaisie",
    "fantaisistes": "fantaisiste",
    "fantasias": "fantasia",
    "fantasmagories": "fantasmagorie",
    "fantasmaient": "fantasmer",
    "fantasmais": "fantasmer",
    "fantasmait": "fantasmer",
    "fantasmatiques": "fantasmatique",
    "fantasme": "fantasmer",
    "fantasment": "fantasmer",
    "fantasmes": "fantasmer",
    "fantasmez": "fantasmer",
    "fantasmé": "fantasmer",
    "fantasmés": "fantasmer",
    "fantasques": "fantasque",
    "fantassins": "fantassin",
    "fantastiques": "fantastique",
    "fantoches": "fantoche",
    "fantomale": "fantomal",
    "fantomales": "fantomal",
    "fantomatiques": "fantomatique",
    "fantômes": "fantôme",
    "fanzines": "fanzine",
    "fané": "faner",
    "fanée": "faner",
    "fanées": "faner",
    "fanés": "faner",
    "faons": "faon",
    "faquins": "faquin",
    "farads": "farad",
    "faramineuse": "faramineux",
    "faramineuses": "faramineux",
    "farandolaient": "farandoler",
    "farandoles": "farandole",
    "faraude": "faraud",
    "faraudes": "faraud",
    "farauds": "faraud",
    "farce": "farcer",
    "farces": "farcer",
    "farceurs": "farceur",
    "farceuse": "farceur",
    "farceuses": "farceur",
    "farci": "farcir",
    "farcie": "farcir",
    "farcies": "farcir",
    "farcira": "farcir",
    "farcirai": "farcir",
    "farciraient": "farcir",
    "farcirais": "farcir",
    "farcirait": "farcir",
    "farciras": "farcir",
    "farcirent": "farcir",
    "farcirez": "farcir",
    "farciriez": "farcir",
    "farcirions": "farcir",
    "farcirons": "farcir",
    "farciront": "farcir",
    "farcis": "farcir",
    "farcissaient": "farcir",
    "farcissais": "farcir",
    "farcissait": "farcir",
    "farcissant": "farcir",
    "farcisse": "farcir",
    "farcissent": "farcir",
    "farcisses": "farcir",
    "farcissez": "farcir",
    "farcissiez": "farcir",
    "farcissions": "farcir",
    "farcissons": "farcir",
    "farcit": "farcir",
    "farcîmes": "farcir",
    "farcît": "farcir",
    "farcîtes": "farcir",
    "fardaient": "farder",
    "fardait": "farder",
    "fardant": "farder",
    "farde": "farder",
    "fardeaux": "fardeau",
    "fardent": "farder",
    "fardiers": "fardier",
    "fards": "fard",
    "fardé": "farder",
    "fardée": "farder",
    "fardées": "farder",
    "fardés": "farder",
    "farfadets": "farfadet",
    "farfelue": "farfelu",
    "farfelues": "farfelu",
    "farfelus": "farfelu",
    "farfouilla": "farfouiller",
    "farfouillai": "farfouiller",
    "farfouillaient": "farfouiller",
    "farfouillais": "farfouiller",
    "farfouillait": "farfouiller",
    "farfouillant": "farfouiller",
    "farfouillas": "farfouiller",
    "farfouillasse": "farfouiller",
    "farfouillassent": "farfouiller",
    "farfouillasses": "farfouiller",
    "farfouillassiez": "farfouiller",
    "farfouillassions": "farfouiller",
    "farfouille": "farfouiller",
    "farfouillent": "farfouiller",
    "farfouillera": "farfouiller",
    "farfouillerai": "farfouiller",
    "farfouilleraient": "farfouiller",
    "farfouillerais": "farfouiller",
    "farfouillerait": "farfouiller",
    "farfouilleras": "farfouiller",
    "farfouillerez": "farfouiller",
    "farfouilleriez": "farfouiller",
    "farfouillerions": "farfouiller",
    "farfouillerons": "farfouiller",
    "farfouilleront": "farfouiller",
    "farfouilles": "farfouiller",
    "farfouilleurs": "farfouilleur",
    "farfouillez": "farfouiller",
    "farfouilliez": "farfouiller",
    "farfouillions": "farfouiller",
    "farfouillons": "farfouiller",
    "farfouillâmes": "farfouiller",
    "farfouillât": "farfouiller",
    "farfouillâtes": "farfouiller",
    "farfouillèrent": "farfouiller",
    "farfouillé": "farfouiller",
    "fariboles": "faribole",
    "farines": "farine",
    "farineuse": "farineux",
    "farineuses": "farineux",
    "farinée": "fariner",
    "farinés": "fariner",
    "farnientes": "farniente",
    "farouches": "farouche",
    "fars": "far",
    "farta": "farter",
    "fartai": "farter",
    "fartaient": "farter",
    "fartais": "farter",
    "fartait": "farter",
    "fartant": "farter",
    "fartas": "farter",
    "fartasse": "farter",
    "fartassent": "farter",
    "fartasses": "farter",
    "fartassiez": "farter",
    "fartassions": "farter",
    "farte": "farter",
    "fartent": "farter",
    "fartera": "farter",
    "farterai": "farter",
    "farteraient": "farter",
    "farterais": "farter",
    "farterait": "farter",
    "farteras": "farter",
    "farterez": "farter",
    "farteriez": "farter",
    "farterions": "farter",
    "farterons": "farter",
    "farteront": "farter",
    "fartes": "farter",
    "fartez": "farter",
    "fartiez": "farter",
    "fartions": "farter",
    "fartons": "farter",
    "farts": "fart",
    "fartâmes": "farter",
    "fartât": "farter",
    "fartâtes": "farter",
    "fartèrent": "farter",
    "farté": "farter",
    "fartée": "farter",
    "fartées": "farter",
    "fartés": "farter",
    "fascicules": "fascicule",
    "fascina": "fasciner",
    "fascinai": "fasciner",
    "fascinaient": "fasciner",
    "fascinais": "fasciner",
    "fascinait": "fasciner",
    "fascinant": "fasciner",
    "fascinante": "fascinant",
    "fascinantes": "fascinant",
    "fascinants": "fascinant",
    "fascinas": "fasciner",
    "fascinasse": "fasciner",
    "fascinassent": "fasciner",
    "fascinasses": "fasciner",
    "fascinassiez": "fasciner",
    "fascinassions": "fasciner",
    "fascinations": "fascination",
    "fascine": "fasciner",
    "fascinent": "fasciner",
    "fascinera": "fasciner",
    "fascinerai": "fasciner",
    "fascineraient": "fasciner",
    "fascinerais": "fasciner",
    "fascinerait": "fasciner",
    "fascineras": "fasciner",
    "fascinerez": "fasciner",
    "fascineriez": "fasciner",
    "fascinerions": "fasciner",
    "fascinerons": "fasciner",
    "fascineront": "fasciner",
    "fascines": "fasciner",
    "fascinez": "fasciner",
    "fasciniez": "fasciner",
    "fascinions": "fasciner",
    "fascinons": "fasciner",
    "fascinâmes": "fasciner",
    "fascinât": "fasciner",
    "fascinâtes": "fasciner",
    "fascinèrent": "fasciner",
    "fasciné": "fasciner",
    "fascinée": "fasciner",
    "fascinées": "fasciner",
    "fascinés": "fasciner",
    "fascismes": "fascisme",
    "fascistes": "fasciste",
    "fascisée": "fasciser",
    "faseya": "faseyer",
    "faseyai": "faseyer",
    "faseyaient": "faseyer",
    "faseyais": "faseyer",
    "faseyait": "faseyer",
    "faseyant": "faseyer",
    "faseyas": "faseyer",
    "faseyasse": "faseyer",
    "faseyassent": "faseyer",
    "faseyasses": "faseyer",
    "faseyassiez": "faseyer",
    "faseyassions": "faseyer",
    "faseye": "faseyer",
    "faseyent": "faseyer",
    "faseyera": "faseyer",
    "faseyerai": "faseyer",
    "faseyeraient": "faseyer",
    "faseyerais": "faseyer",
    "faseyerait": "faseyer",
    "faseyeras": "faseyer",
    "faseyerez": "faseyer",
    "faseyeriez": "faseyer",
    "faseyerions": "faseyer",
    "faseyerons": "faseyer",
    "faseyeront": "faseyer",
    "faseyes": "faseyer",
    "faseyez": "faseyer",
    "faseyiez": "faseyer",
    "faseyions": "faseyer",
    "faseyons": "faseyer",
    "faseyâmes": "faseyer",
    "faseyât": "faseyer",
    "faseyâtes": "faseyer",
    "faseyèrent": "faseyer",
    "faseyé": "faseyer",
    "faseyée": "faseyer",
    "faseyées": "faseyer",
    "faseyés": "faseyer",
    "fasse": "faire",
    "fassent": "faire",
    "fasses": "faire",
    "fassiez": "faire",
    "fassions": "faire",
    "fast food": "fast-food",
    "fast-foods": "fast-food",
    "fastes": "faste",
    "fastidieuse": "fastidieux",
    "fastidieuses": "fastidieux",
    "fastueuse": "fastueux",
    "fastueuses": "fastueux",
    "fasèye": "faséyer",
    "fasèyent": "faséyer",
    "fasèyes": "faséyer",
    "faséya": "faséyer",
    "faséyai": "faséyer",
    "faséyaient": "faséyer",
    "faséyais": "faséyer",
    "faséyait": "faséyer",
    "faséyant": "faséyer",
    "faséyas": "faséyer",
    "faséyasse": "faséyer",
    "faséyassent": "faséyer",
    "faséyasses": "faséyer",
    "faséyassiez": "faséyer",
    "faséyassions": "faséyer",
    "faséyera": "faséyer",
    "faséyerai": "faséyer",
    "faséyeraient": "faséyer",
    "faséyerais": "faséyer",
    "faséyerait": "faséyer",
    "faséyeras": "faséyer",
    "faséyerez": "faséyer",
    "faséyeriez": "faséyer",
    "faséyerions": "faséyer",
    "faséyerons": "faséyer",
    "faséyeront": "faséyer",
    "faséyez": "faséyer",
    "faséyiez": "faséyer",
    "faséyions": "faséyer",
    "faséyons": "faséyer",
    "faséyâmes": "faséyer",
    "faséyât": "faséyer",
    "faséyâtes": "faséyer",
    "faséyèrent": "faséyer",
    "faséyé": "faséyer",
    "faséyée": "faséyer",
    "faséyées": "faséyer",
    "faséyés": "faséyer",
    "fatale": "fatal",
    "fatales": "fatal",
    "fatalise": "fataliser",
    "fatalismes": "fatalisme",
    "fatalistes": "fataliste",
    "fatalisé": "fataliser",
    "fatalités": "fatalité",
    "fatals": "fatal",
    "fate": "fat",
    "fatidiques": "fatidique",
    "fatigables": "fatigable",
    "fatigante": "fatigant",
    "fatigantes": "fatigant",
    "fatigants": "fatigant",
    "fatigua": "fatiguer",
    "fatiguai": "fatiguer",
    "fatiguaient": "fatiguer",
    "fatiguais": "fatiguer",
    "fatiguait": "fatiguer",
    "fatiguant": "fatiguer",
    "fatiguas": "fatiguer",
    "fatiguasse": "fatiguer",
    "fatiguassent": "fatiguer",
    "fatiguasses": "fatiguer",
    "fatiguassiez": "fatiguer",
    "fatiguassions": "fatiguer",
    "fatigue": "fatiguer",
    "fatiguent": "fatiguer",
    "fatiguera": "fatiguer",
    "fatiguerai": "fatiguer",
    "fatigueraient": "fatiguer",
    "fatiguerais": "fatiguer",
    "fatiguerait": "fatiguer",
    "fatigueras": "fatiguer",
    "fatiguerez": "fatiguer",
    "fatigueriez": "fatiguer",
    "fatiguerions": "fatiguer",
    "fatiguerons": "fatiguer",
    "fatigueront": "fatiguer",
    "fatigues": "fatiguer",
    "fatiguez": "fatiguer",
    "fatiguiez": "fatiguer",
    "fatiguions": "fatiguer",
    "fatiguons": "fatiguer",
    "fatiguâmes": "fatiguer",
    "fatiguât": "fatiguer",
    "fatiguâtes": "fatiguer",
    "fatiguèrent": "fatiguer",
    "fatigué": "fatiguer",
    "fatiguée": "fatiguer",
    "fatiguées": "fatiguer",
    "fatigués": "fatiguer",
    "fatmas": "fatma",
    "fats": "fat",
    "fatuités": "fatuité",
    "faubourgs": "faubourg",
    "faubourienne": "faubourien",
    "faubouriennes": "faubourien",
    "faubouriens": "faubourien",
    "faucardé": "faucarder",
    "faucardée": "faucarder",
    "faucardées": "faucarder",
    "faucardés": "faucarder",
    "faucha": "faucher",
    "fauchai": "faucher",
    "fauchaient": "faucher",
    "fauchais": "faucher",
    "fauchait": "faucher",
    "fauchant": "faucher",
    "fauchas": "faucher",
    "fauchasse": "faucher",
    "fauchassent": "faucher",
    "fauchasses": "faucher",
    "fauchassiez": "faucher",
    "fauchassions": "faucher",
    "fauche": "faucher",
    "fauchent": "faucher",
    "fauchera": "faucher",
    "faucherai": "faucher",
    "faucheraient": "faucher",
    "faucherais": "faucher",
    "faucherait": "faucher",
    "faucheras": "faucher",
    "faucherez": "faucher",
    "faucheriez": "faucher",
    "faucherions": "faucher",
    "faucherons": "faucher",
    "faucheront": "faucher",
    "fauches": "faucher",
    "faucheurs": "faucheur",
    "faucheuse": "faucheur",
    "faucheuses": "faucheur",
    "fauchez": "faucher",
    "fauchiez": "faucher",
    "fauchions": "faucher",
    "fauchons": "faucher",
    "fauchâmes": "faucher",
    "fauchât": "faucher",
    "fauchâtes": "faucher",
    "fauchèrent": "faucher",
    "fauché": "faucher",
    "fauchée": "faucher",
    "fauchées": "faucher",
    "fauchés": "faucher",
    "faucilles": "faucille",
    "fauconneaux": "fauconneau",
    "fauconniers": "fauconnier",
    "faucons": "faucon",
    "faudra": "falloir",
    "faudrait": "falloir",
    "faufila": "faufiler",
    "faufilai": "faufiler",
    "faufilaient": "faufiler",
    "faufilais": "faufiler",
    "faufilait": "faufiler",
    "faufilant": "faufiler",
    "faufilas": "faufiler",
    "faufilasse": "faufiler",
    "faufilassent": "faufiler",
    "faufilasses": "faufiler",
    "faufilassiez": "faufiler",
    "faufilassions": "faufiler",
    "faufile": "faufiler",
    "faufilent": "faufiler",
    "faufilera": "faufiler",
    "faufilerai": "faufiler",
    "faufileraient": "faufiler",
    "faufilerais": "faufiler",
    "faufilerait": "faufiler",
    "faufileras": "faufiler",
    "faufilerez": "faufiler",
    "faufileriez": "faufiler",
    "faufilerions": "faufiler",
    "faufilerons": "faufiler",
    "faufileront": "faufiler",
    "faufiles": "faufiler",
    "faufilez": "faufiler",
    "faufiliez": "faufiler",
    "faufilions": "faufiler",
    "faufilons": "faufiler",
    "faufilâmes": "faufiler",
    "faufilât": "faufiler",
    "faufilâtes": "faufiler",
    "faufilèrent": "faufiler",
    "faufilé": "faufiler",
    "faufilée": "faufiler",
    "faufilées": "faufiler",
    "faufilés": "faufiler",
    "faunes": "faune",
    "faunesques": "faunesque",
    "faunesse": "faune",
    "faunesses": "faune",
    "faunistiques": "faunistique",
    "faussa": "fausser",
    "faussai": "fausser",
    "faussaient": "fausser",
    "faussaires": "faussaire",
    "faussais": "fausser",
    "faussait": "fausser",
    "faussant": "fausser",
    "faussas": "fausser",
    "faussasse": "fausser",
    "faussassent": "fausser",
    "faussasses": "fausser",
    "faussassiez": "fausser",
    "faussassions": "fausser",
    "fausse": "faux",
    "faussent": "fausser",
    "faussera": "fausser",
    "fausserai": "fausser",
    "fausseraient": "fausser",
    "fausserais": "fausser",
    "fausserait": "fausser",
    "fausseras": "fausser",
    "fausserez": "fausser",
    "fausseriez": "fausser",
    "fausserions": "fausser",
    "fausserons": "fausser",
    "fausseront": "fausser",
    "fausses": "faux",
    "faussets": "fausset",
    "faussetés": "fausseté",
    "faussez": "fausser",
    "faussiez": "fausser",
    "faussions": "fausser",
    "faussons": "fausser",
    "faussâmes": "fausser",
    "faussât": "fausser",
    "faussâtes": "fausser",
    "faussèrent": "fausser",
    "faussé": "fausser",
    "faussée": "fausser",
    "faussées": "fausser",
    "faussés": "fausser",
    "faustienne": "faustien",
    "faut": "falloir",
    "faute": "fauter",
    "fautes": "fauter",
    "fauteuils": "fauteuil",
    "fauteurs": "fauteur",
    "fauteuse": "fauteur",
    "fautifs": "fautif",
    "fautive": "fautif",
    "fautives": "fautif",
    "fautrice": "fauteur",
    "fautrices": "fauteur",
    "fauté": "fauter",
    "fauves": "fauve",
    "fauvettes": "fauvette",
    "fauvismes": "fauvisme",
    "faux": "faillir",
    "faux-bourdons": "faux-bourdon",
    "faux-fuyants": "faux-fuyant",
    "faux-monnayeurs": "faux-monnayeur",
    "faux-ponts": "faux-pont",
    "faux-sauniers": "faux-saunier",
    "faux-semblants": "faux-semblant",
    "favelas": "favela",
    "faveurs": "faveur",
    "favorables": "favorable",
    "favoris": "favori",
    "favorisa": "favoriser",
    "favorisai": "favoriser",
    "favorisaient": "favoriser",
    "favorisais": "favoriser",
    "favorisait": "favoriser",
    "favorisant": "favoriser",
    "favorisas": "favoriser",
    "favorisasse": "favoriser",
    "favorisassent": "favoriser",
    "favorisasses": "favoriser",
    "favorisassiez": "favoriser",
    "favorisassions": "favoriser",
    "favorise": "favoriser",
    "favorisent": "favoriser",
    "favorisera": "favoriser",
    "favoriserai": "favoriser",
    "favoriseraient": "favoriser",
    "favoriserais": "favoriser",
    "favoriserait": "favoriser",
    "favoriseras": "favoriser",
    "favoriserez": "favoriser",
    "favoriseriez": "favoriser",
    "favoriserions": "favoriser",
    "favoriserons": "favoriser",
    "favoriseront": "favoriser",
    "favorises": "favoriser",
    "favorisez": "favoriser",
    "favorisiez": "favoriser",
    "favorisions": "favoriser",
    "favorisons": "favoriser",
    "favorisâmes": "favoriser",
    "favorisât": "favoriser",
    "favorisâtes": "favoriser",
    "favorisèrent": "favoriser",
    "favorisé": "favoriser",
    "favorisée": "favoriser",
    "favorisées": "favoriser",
    "favorisés": "favoriser",
    "favorite": "favori",
    "favorites": "favorite",
    "faxe": "faxer",
    "faxera": "faxer",
    "faxerai": "faxer",
    "faxes": "faxer",
    "faxez": "faxer",
    "faxons": "faxer",
    "faxé": "faxer",
    "faxés": "faxer",
    "fayards": "fayard",
    "fayota": "fayoter",
    "fayotai": "fayoter",
    "fayotaient": "fayoter",
    "fayotais": "fayoter",
    "fayotait": "fayoter",
    "fayotant": "fayoter",
    "fayotas": "fayoter",
    "fayotasse": "fayoter",
    "fayotassent": "fayoter",
    "fayotasses": "fayoter",
    "fayotassiez": "fayoter",
    "fayotassions": "fayoter",
    "fayote": "fayoter",
    "fayotent": "fayoter",
    "fayotera": "fayoter",
    "fayoterai": "fayoter",
    "fayoteraient": "fayoter",
    "fayoterais": "fayoter",
    "fayoterait": "fayoter",
    "fayoteras": "fayoter",
    "fayoterez": "fayoter",
    "fayoteriez": "fayoter",
    "fayoterions": "fayoter",
    "fayoterons": "fayoter",
    "fayoteront": "fayoter",
    "fayotes": "fayoter",
    "fayotez": "fayoter",
    "fayotiez": "fayoter",
    "fayotions": "fayoter",
    "fayotons": "fayoter",
    "fayots": "fayot",
    "fayotte": "fayotter",
    "fayotâmes": "fayoter",
    "fayotât": "fayoter",
    "fayotâtes": "fayoter",
    "fayotèrent": "fayoter",
    "fayoté": "fayoter",
    "fayotée": "fayoter",
    "façades": "façade",
    "façonna": "façonner",
    "façonnages": "façonnage",
    "façonnai": "façonner",
    "façonnaient": "façonner",
    "façonnais": "façonner",
    "façonnait": "façonner",
    "façonnant": "façonner",
    "façonnas": "façonner",
    "façonnasse": "façonner",
    "façonnassent": "façonner",
    "façonnasses": "façonner",
    "façonnassiez": "façonner",
    "façonnassions": "façonner",
    "façonne": "façonner",
    "façonnent": "façonner",
    "façonnera": "façonner",
    "façonnerai": "façonner",
    "façonneraient": "façonner",
    "façonnerais": "façonner",
    "façonnerait": "façonner",
    "façonneras": "façonner",
    "façonnerez": "façonner",
    "façonneriez": "façonner",
    "façonnerions": "façonner",
    "façonnerons": "façonner",
    "façonneront": "façonner",
    "façonnes": "façonner",
    "façonnez": "façonner",
    "façonniez": "façonner",
    "façonnions": "façonner",
    "façonnière": "façonnier",
    "façonnons": "façonner",
    "façonnâmes": "façonner",
    "façonnât": "façonner",
    "façonnâtes": "façonner",
    "façonnèrent": "façonner",
    "façonné": "façonner",
    "façonnée": "façonner",
    "façonnées": "façonner",
    "façonnés": "façonner",
    "façons": "façon",
    "faînes": "faîne",
    "faîtages": "faîtage",
    "faîtes": "faîte",
    "faîtière": "faîtier",
    "faîtières": "faîtier",
    "faïences": "faïence",
    "faïenciers": "faïencier",
    "feedbacks": "feedback",
    "feeders": "feeder",
    "feelings": "feeling",
    "feignaient": "feindre",
    "feignais": "feindre",
    "feignait": "feindre",
    "feignant": "feindre",
    "feignante": "feignant",
    "feignantes": "feignant",
    "feignants": "feignant",
    "feignasses": "feignasse",
    "feigne": "feindre",
    "feignent": "feindre",
    "feignes": "feindre",
    "feignez": "feindre",
    "feigniez": "feindre",
    "feignions": "feindre",
    "feignirent": "feindre",
    "feignis": "feindre",
    "feignisse": "feindre",
    "feignissent": "feindre",
    "feignisses": "feindre",
    "feignissiez": "feindre",
    "feignissions": "feindre",
    "feignit": "feindre",
    "feignons": "feindre",
    "feignîmes": "feindre",
    "feignît": "feindre",
    "feignîtes": "feindre",
    "feindra": "feindre",
    "feindrai": "feindre",
    "feindraient": "feindre",
    "feindrais": "feindre",
    "feindrait": "feindre",
    "feindras": "feindre",
    "feindrez": "feindre",
    "feindriez": "feindre",
    "feindrions": "feindre",
    "feindrons": "feindre",
    "feindront": "feindre",
    "feins": "feindre",
    "feint": "feindre",
    "feintait": "feinter",
    "feintant": "feinter",
    "feinte": "feinter",
    "feinterez": "feinter",
    "feintes": "feinter",
    "feints": "feint",
    "feinté": "feinter",
    "feintés": "feinter",
    "feld-maréchaux": "feld-maréchal",
    "feldwebels": "feldwebel",
    "fellagas": "fellaga",
    "fellaghas": "fellagha",
    "fellahs": "fellah",
    "fellationne": "fellationner",
    "fellations": "fellation",
    "fellinienne": "fellinien",
    "felouques": "felouque",
    "femelles": "femelle",
    "femmelettes": "femmelette",
    "femmes": "femme",
    "fenaisons": "fenaison",
    "fend": "fendre",
    "fendaient": "fendre",
    "fendais": "fendre",
    "fendait": "fendre",
    "fendant": "fendre",
    "fendants": "fendant",
    "fende": "fendre",
    "fendent": "fendre",
    "fendes": "fendre",
    "fendeurs": "fendeur",
    "fendez": "fendre",
    "fendiez": "fendre",
    "fendillaient": "fendiller",
    "fendillait": "fendiller",
    "fendille": "fendiller",
    "fendillements": "fendillement",
    "fendillèrent": "fendiller",
    "fendillé": "fendiller",
    "fendillée": "fendiller",
    "fendillées": "fendillé",
    "fendillés": "fendiller",
    "fendions": "fendre",
    "fendirent": "fendre",
    "fendis": "fendre",
    "fendisse": "fendre",
    "fendissent": "fendre",
    "fendisses": "fendre",
    "fendissiez": "fendre",
    "fendissions": "fendre",
    "fendit": "fendre",
    "fendons": "fendre",
    "fendra": "fendre",
    "fendrai": "fendre",
    "fendraient": "fendre",
    "fendrais": "fendre",
    "fendrait": "fendre",
    "fendras": "fendre",
    "fendrez": "fendre",
    "fendriez": "fendre",
    "fendrions": "fendre",
    "fendrons": "fendre",
    "fendront": "fendre",
    "fends": "fendre",
    "fendu": "fendre",
    "fendue": "fendu",
    "fendues": "fendu",
    "fendus": "fendu",
    "fendîmes": "fendre",
    "fendît": "fendre",
    "fendîtes": "fendre",
    "fenestrages": "fenestrage",
    "fenians": "fenian",
    "fenils": "fenil",
    "fennecs": "fennec",
    "fenouils": "fenouil",
    "fentes": "fente",
    "fenêtres": "fenêtre",
    "fera": "faire",
    "ferai": "faire",
    "feraient": "faire",
    "ferais": "faire",
    "ferait": "faire",
    "feras": "faire",
    "ferblantiers": "ferblantier",
    "ferez": "faire",
    "ferias": "feria",
    "feriez": "faire",
    "ferions": "faire",
    "ferlez": "ferler",
    "ferlée": "ferler",
    "ferma": "fermer",
    "fermages": "fermage",
    "fermai": "fermer",
    "fermaient": "fermer",
    "fermais": "fermer",
    "fermait": "fermer",
    "fermant": "fermer",
    "fermas": "fermer",
    "fermasse": "fermer",
    "fermassent": "fermer",
    "fermasses": "fermer",
    "fermassiez": "fermer",
    "fermassions": "fermer",
    "fermaux": "fermail",
    "ferme": "fermer",
    "ferment": "fermer",
    "fermenta": "fermenter",
    "fermentai": "fermenter",
    "fermentaient": "fermenter",
    "fermentais": "fermenter",
    "fermentait": "fermenter",
    "fermentant": "fermenter",
    "fermentas": "fermenter",
    "fermentasse": "fermenter",
    "fermentassent": "fermenter",
    "fermentasses": "fermenter",
    "fermentassiez": "fermenter",
    "fermentassions": "fermenter",
    "fermentations": "fermentation",
    "fermente": "fermenter",
    "fermentent": "fermenter",
    "fermentera": "fermenter",
    "fermenterai": "fermenter",
    "fermenteraient": "fermenter",
    "fermenterais": "fermenter",
    "fermenterait": "fermenter",
    "fermenteras": "fermenter",
    "fermenterez": "fermenter",
    "fermenteriez": "fermenter",
    "fermenterions": "fermenter",
    "fermenterons": "fermenter",
    "fermenteront": "fermenter",
    "fermentes": "fermenter",
    "fermentez": "fermenter",
    "fermentiez": "fermenter",
    "fermentions": "fermenter",
    "fermentons": "fermenter",
    "ferments": "ferment",
    "fermentâmes": "fermenter",
    "fermentât": "fermenter",
    "fermentâtes": "fermenter",
    "fermentèrent": "fermenter",
    "fermenté": "fermenter",
    "fermentée": "fermenter",
    "fermentées": "fermenter",
    "fermentés": "fermenter",
    "fermera": "fermer",
    "fermerai": "fermer",
    "fermeraient": "fermer",
    "fermerais": "fermer",
    "fermerait": "fermer",
    "fermeras": "fermer",
    "fermerez": "fermer",
    "fermeriez": "fermer",
    "fermerions": "fermer",
    "fermerons": "fermer",
    "fermeront": "fermer",
    "fermes": "fermer",
    "fermes-hôtels": "fermes-hôtel",
    "fermetures": "fermeture",
    "fermetés": "fermeté",
    "fermez": "fermer",
    "fermiers": "fermier",
    "fermiez": "fermer",
    "fermions": "fermion",
    "fermière": "fermier",
    "fermières": "fermier",
    "fermoirs": "fermoir",
    "fermons": "fermer",
    "fermâmes": "fermer",
    "fermât": "fermer",
    "fermâtes": "fermer",
    "fermèrent": "fermer",
    "fermé": "fermer",
    "fermée": "fermer",
    "fermées": "fermer",
    "fermés": "fermer",
    "ferons": "faire",
    "feront": "faire",
    "ferra": "ferrer",
    "ferrages": "ferrage",
    "ferrai": "ferrer",
    "ferraient": "ferrer",
    "ferrailla": "ferrailler",
    "ferraillai": "ferrailler",
    "ferraillaient": "ferrailler",
    "ferraillais": "ferrailler",
    "ferraillait": "ferrailler",
    "ferraillant": "ferrailler",
    "ferraillante": "ferraillant",
    "ferraillas": "ferrailler",
    "ferraillasse": "ferrailler",
    "ferraillassent": "ferrailler",
    "ferraillasses": "ferrailler",
    "ferraillassiez": "ferrailler",
    "ferraillassions": "ferrailler",
    "ferraille": "ferrailler",
    "ferraillent": "ferrailler",
    "ferraillera": "ferrailler",
    "ferraillerai": "ferrailler",
    "ferrailleraient": "ferrailler",
    "ferraillerais": "ferrailler",
    "ferraillerait": "ferrailler",
    "ferrailleras": "ferrailler",
    "ferraillerez": "ferrailler",
    "ferrailleriez": "ferrailler",
    "ferraillerions": "ferrailler",
    "ferraillerons": "ferrailler",
    "ferrailleront": "ferrailler",
    "ferrailles": "ferrailler",
    "ferrailleurs": "ferrailleur",
    "ferraillez": "ferrailler",
    "ferrailliez": "ferrailler",
    "ferraillions": "ferrailler",
    "ferraillons": "ferrailler",
    "ferraillâmes": "ferrailler",
    "ferraillât": "ferrailler",
    "ferraillâtes": "ferrailler",
    "ferraillèrent": "ferrailler",
    "ferraillé": "ferrailler",
    "ferraillée": "ferrailler",
    "ferraillées": "ferrailler",
    "ferraillés": "ferrailler",
    "ferrais": "ferrer",
    "ferrait": "ferrer",
    "ferrant": "ferrer",
    "ferras": "ferrer",
    "ferrasse": "ferrer",
    "ferrassent": "ferrer",
    "ferrasses": "ferrer",
    "ferrassiez": "ferrer",
    "ferrassions": "ferrer",
    "ferre": "ferrer",
    "ferrent": "ferrer",
    "ferrera": "ferrer",
    "ferrerai": "ferrer",
    "ferreraient": "ferrer",
    "ferrerais": "ferrer",
    "ferrerait": "ferrer",
    "ferreras": "ferrer",
    "ferrerez": "ferrer",
    "ferreriez": "ferrer",
    "ferrerions": "ferrer",
    "ferrerons": "ferrer",
    "ferreront": "ferrer",
    "ferres": "ferrer",
    "ferrets": "ferret",
    "ferreuse": "ferreux",
    "ferreuses": "ferreux",
    "ferrez": "ferrer",
    "ferries": "ferry",
    "ferriez": "ferrer",
    "ferrions": "ferrer",
    "ferriques": "ferrique",
    "ferronneries": "ferronnerie",
    "ferronniers": "ferronnier",
    "ferronnière": "ferronnier",
    "ferronnières": "ferronnier",
    "ferrons": "ferrer",
    "ferroviaires": "ferroviaire",
    "ferrugineuse": "ferrugineux",
    "ferrugineuses": "ferrugineux",
    "ferrures": "ferrure",
    "ferry-boats": "ferry-boat",
    "ferrâmes": "ferrer",
    "ferrât": "ferrer",
    "ferrâtes": "ferrer",
    "ferrèrent": "ferrer",
    "ferré": "ferrer",
    "ferrée": "ferrer",
    "ferrées": "ferrer",
    "ferrés": "ferrer",
    "fers": "fer",
    "fers-blancs": "fer-blanc",
    "fertiles": "fertile",
    "fertilisa": "fertiliser",
    "fertilisai": "fertiliser",
    "fertilisaient": "fertiliser",
    "fertilisais": "fertiliser",
    "fertilisait": "fertiliser",
    "fertilisant": "fertiliser",
    "fertilisante": "fertilisant",
    "fertilisantes": "fertilisant",
    "fertilisants": "fertilisant",
    "fertilisas": "fertiliser",
    "fertilisasse": "fertiliser",
    "fertilisassent": "fertiliser",
    "fertilisasses": "fertiliser",
    "fertilisassiez": "fertiliser",
    "fertilisassions": "fertiliser",
    "fertilise": "fertiliser",
    "fertilisent": "fertiliser",
    "fertilisera": "fertiliser",
    "fertiliserai": "fertiliser",
    "fertiliseraient": "fertiliser",
    "fertiliserais": "fertiliser",
    "fertiliserait": "fertiliser",
    "fertiliseras": "fertiliser",
    "fertiliserez": "fertiliser",
    "fertiliseriez": "fertiliser",
    "fertiliserions": "fertiliser",
    "fertiliserons": "fertiliser",
    "fertiliseront": "fertiliser",
    "fertilises": "fertiliser",
    "fertilisez": "fertiliser",
    "fertilisiez": "fertiliser",
    "fertilisions": "fertiliser",
    "fertilisons": "fertiliser",
    "fertilisâmes": "fertiliser",
    "fertilisât": "fertiliser",
    "fertilisâtes": "fertiliser",
    "fertilisèrent": "fertiliser",
    "fertilisé": "fertiliser",
    "fertilisée": "fertiliser",
    "fertilisées": "fertiliser",
    "fertilisés": "fertiliser",
    "fertilités": "fertilité",
    "fervente": "fervent",
    "ferventes": "fervent",
    "fervents": "fervent",
    "ferveurs": "ferveur",
    "fessait": "fesser",
    "fesse": "fesser",
    "fesse-mathieux": "fesse-mathieu",
    "fesserai": "fesser",
    "fesserais": "fesser",
    "fesses": "fesser",
    "fesseuse": "fesseur",
    "fessiers": "fessier",
    "fessiez": "fesser",
    "fessière": "fessier",
    "fessières": "fessier",
    "fessue": "fessu",
    "fessues": "fessu",
    "fessé": "fesser",
    "fessée": "fesser",
    "fessées": "fesser",
    "fessés": "fesser",
    "festifs": "festif",
    "festins": "festin",
    "festivaliers": "festivalier",
    "festivals": "festival",
    "festive": "festif",
    "festives": "festif",
    "festivités": "festivité",
    "festoie": "festoyer",
    "festoiements": "festoiement",
    "festoient": "festoyer",
    "festoiera": "festoyer",
    "festoierai": "festoyer",
    "festoieraient": "festoyer",
    "festoierais": "festoyer",
    "festoierait": "festoyer",
    "festoieras": "festoyer",
    "festoierez": "festoyer",
    "festoieriez": "festoyer",
    "festoierions": "festoyer",
    "festoierons": "festoyer",
    "festoieront": "festoyer",
    "festoies": "festoyer",
    "festonna": "festonner",
    "festonnai": "festonner",
    "festonnaient": "festonner",
    "festonnais": "festonner",
    "festonnait": "festonner",
    "festonnant": "festonner",
    "festonnas": "festonner",
    "festonnasse": "festonner",
    "festonnassent": "festonner",
    "festonnasses": "festonner",
    "festonnassiez": "festonner",
    "festonnassions": "festonner",
    "festonne": "festonner",
    "festonnements": "festonnement",
    "festonnent": "festonner",
    "festonnera": "festonner",
    "festonnerai": "festonner",
    "festonneraient": "festonner",
    "festonnerais": "festonner",
    "festonnerait": "festonner",
    "festonneras": "festonner",
    "festonnerez": "festonner",
    "festonneriez": "festonner",
    "festonnerions": "festonner",
    "festonnerons": "festonner",
    "festonneront": "festonner",
    "festonnes": "festonner",
    "festonnez": "festonner",
    "festonniez": "festonner",
    "festonnions": "festonner",
    "festonnons": "festonner",
    "festonnâmes": "festonner",
    "festonnât": "festonner",
    "festonnâtes": "festonner",
    "festonnèrent": "festonner",
    "festonné": "festonner",
    "festonnée": "festonner",
    "festonnées": "festonner",
    "festonnés": "festonner",
    "festons": "feston",
    "festoya": "festoyer",
    "festoyai": "festoyer",
    "festoyaient": "festoyer",
    "festoyais": "festoyer",
    "festoyait": "festoyer",
    "festoyant": "festoyer",
    "festoyas": "festoyer",
    "festoyasse": "festoyer",
    "festoyassent": "festoyer",
    "festoyasses": "festoyer",
    "festoyassiez": "festoyer",
    "festoyassions": "festoyer",
    "festoyez": "festoyer",
    "festoyiez": "festoyer",
    "festoyions": "festoyer",
    "festoyons": "festoyer",
    "festoyâmes": "festoyer",
    "festoyât": "festoyer",
    "festoyâtes": "festoyer",
    "festoyèrent": "festoyer",
    "festoyé": "festoyer",
    "festoyée": "festoyer",
    "festoyées": "festoyer",
    "festoyés": "festoyer",
    "feue": "feu",
    "feues": "feu",
    "feuilla": "feuiller",
    "feuillages": "feuillage",
    "feuillai": "feuiller",
    "feuillaient": "feuiller",
    "feuillais": "feuiller",
    "feuillait": "feuiller",
    "feuillant": "feuiller",
    "feuillantines": "feuillantine",
    "feuillas": "feuiller",
    "feuillasse": "feuiller",
    "feuillassent": "feuiller",
    "feuillasses": "feuiller",
    "feuillassiez": "feuiller",
    "feuillassions": "feuiller",
    "feuille": "feuiller",
    "feuillent": "feuiller",
    "feuillera": "feuiller",
    "feuillerai": "feuiller",
    "feuilleraient": "feuiller",
    "feuillerais": "feuiller",
    "feuillerait": "feuiller",
    "feuilleras": "feuiller",
    "feuillerez": "feuiller",
    "feuilleriez": "feuiller",
    "feuillerions": "feuiller",
    "feuillerons": "feuiller",
    "feuilleront": "feuiller",
    "feuilles": "feuiller",
    "feuilleta": "feuilleter",
    "feuilletai": "feuilleter",
    "feuilletaient": "feuilleter",
    "feuilletais": "feuilleter",
    "feuilletait": "feuilleter",
    "feuilletant": "feuilleter",
    "feuilletas": "feuilleter",
    "feuilletasse": "feuilleter",
    "feuilletassent": "feuilleter",
    "feuilletasses": "feuilleter",
    "feuilletassiez": "feuilleter",
    "feuilletassions": "feuilleter",
    "feuilletez": "feuilleter",
    "feuilletiez": "feuilleter",
    "feuilletions": "feuilleter",
    "feuilletonistes": "feuilletoniste",
    "feuilletons": "feuilleton",
    "feuillets": "feuillet",
    "feuillette": "feuilleter",
    "feuillettent": "feuilleter",
    "feuillettera": "feuilleter",
    "feuilletterai": "feuilleter",
    "feuilletteraient": "feuilleter",
    "feuilletterais": "feuilleter",
    "feuilletterait": "feuilleter",
    "feuilletteras": "feuilleter",
    "feuilletterez": "feuilleter",
    "feuilletteriez": "feuilleter",
    "feuilletterions": "feuilleter",
    "feuilletterons": "feuilleter",
    "feuilletteront": "feuilleter",
    "feuillettes": "feuillette",
    "feuilletâmes": "feuilleter",
    "feuilletât": "feuilleter",
    "feuilletâtes": "feuilleter",
    "feuilletèrent": "feuilleter",
    "feuilleté": "feuilleter",
    "feuilletée": "feuilleter",
    "feuilletées": "feuilleter",
    "feuilletés": "feuilleter",
    "feuillez": "feuiller",
    "feuilliez": "feuiller",
    "feuillions": "feuiller",
    "feuillons": "feuiller",
    "feuillue": "feuillu",
    "feuillues": "feuillu",
    "feuillures": "feuillure",
    "feuillus": "feuillu",
    "feuillâmes": "feuiller",
    "feuillât": "feuiller",
    "feuillâtes": "feuiller",
    "feuillèrent": "feuiller",
    "feuillé": "feuiller",
    "feuillée": "feuiller",
    "feuillées": "feuiller",
    "feuillés": "feuiller",
    "feula": "feuler",
    "feulai": "feuler",
    "feulaient": "feuler",
    "feulais": "feuler",
    "feulait": "feuler",
    "feulant": "feuler",
    "feulas": "feuler",
    "feulasse": "feuler",
    "feulassent": "feuler",
    "feulasses": "feuler",
    "feulassiez": "feuler",
    "feulassions": "feuler",
    "feule": "feuler",
    "feulements": "feulement",
    "feulent": "feuler",
    "feulera": "feuler",
    "feulerai": "feuler",
    "feuleraient": "feuler",
    "feulerais": "feuler",
    "feulerait": "feuler",
    "feuleras": "feuler",
    "feulerez": "feuler",
    "feuleriez": "feuler",
    "feulerions": "feuler",
    "feulerons": "feuler",
    "feuleront": "feuler",
    "feules": "feuler",
    "feulez": "feuler",
    "feuliez": "feuler",
    "feulions": "feuler",
    "feulons": "feuler",
    "feulâmes": "feuler",
    "feulât": "feuler",
    "feulâtes": "feuler",
    "feulèrent": "feuler",
    "feulé": "feuler",
    "feulée": "feuler",
    "feus": "feu",
    "feutra": "feutrer",
    "feutrages": "feutrage",
    "feutrait": "feutrer",
    "feutrant": "feutrer",
    "feutre": "feutrer",
    "feutrent": "feutrer",
    "feutres": "feutrer",
    "feutré": "feutrer",
    "feutrée": "feutrer",
    "feutrées": "feutrer",
    "feutrés": "feutrer",
    "feux": "feu",
    "fia": "fier",
    "fiabilités": "fiabilité",
    "fiables": "fiable",
    "fiacres": "fiacre",
    "fiai": "fier",
    "fiaient": "fier",
    "fiais": "fier",
    "fiait": "fier",
    "fiance": "fiancer",
    "fiancent": "fiancer",
    "fiancera": "fiancer",
    "fiancerai": "fiancer",
    "fianceraient": "fiancer",
    "fiancerais": "fiancer",
    "fiancerait": "fiancer",
    "fianceras": "fiancer",
    "fiancerez": "fiancer",
    "fianceriez": "fiancer",
    "fiancerions": "fiancer",
    "fiancerons": "fiancer",
    "fianceront": "fiancer",
    "fiances": "fiancer",
    "fiancez": "fiancer",
    "fianciez": "fiancer",
    "fiancions": "fiancer",
    "fiancèrent": "fiancer",
    "fiancé": "fiancer",
    "fiancée": "fiancer",
    "fiancées": "fiancer",
    "fiancés": "fiancer",
    "fiant": "fier",
    "fiança": "fiancer",
    "fiançai": "fiancer",
    "fiançaient": "fiancer",
    "fiançais": "fiancer",
    "fiançait": "fiancer",
    "fiançant": "fiancer",
    "fianças": "fiancer",
    "fiançasse": "fiancer",
    "fiançassent": "fiancer",
    "fiançasses": "fiancer",
    "fiançassiez": "fiancer",
    "fiançassions": "fiancer",
    "fiançons": "fiancer",
    "fiançâmes": "fiancer",
    "fiançât": "fiancer",
    "fiançâtes": "fiancer",
    "fias": "fier",
    "fiascos": "fiasco",
    "fiasques": "fiasque",
    "fiasse": "fier",
    "fiassent": "fier",
    "fiasses": "fier",
    "fiassiez": "fier",
    "fiassions": "fier",
    "fibrannes": "fibranne",
    "fibres": "fibre",
    "fibreuse": "fibreux",
    "fibreuses": "fibreux",
    "fibrilles": "fibrille",
    "fibromateuse": "fibromateux",
    "fibromes": "fibrome",
    "fibules": "fibule",
    "ficaires": "ficaire",
    "ficela": "ficeler",
    "ficelai": "ficeler",
    "ficelaient": "ficeler",
    "ficelais": "ficeler",
    "ficelait": "ficeler",
    "ficelant": "ficeler",
    "ficelas": "ficeler",
    "ficelasse": "ficeler",
    "ficelassent": "ficeler",
    "ficelasses": "ficeler",
    "ficelassiez": "ficeler",
    "ficelassions": "ficeler",
    "ficelez": "ficeler",
    "ficeliez": "ficeler",
    "ficelions": "ficeler",
    "ficelle": "ficeler",
    "ficellent": "ficeler",
    "ficellera": "ficeler",
    "ficellerai": "ficeler",
    "ficelleraient": "ficeler",
    "ficellerais": "ficeler",
    "ficellerait": "ficeler",
    "ficelleras": "ficeler",
    "ficellerez": "ficeler",
    "ficelleriez": "ficeler",
    "ficellerions": "ficeler",
    "ficellerons": "ficeler",
    "ficelleront": "ficeler",
    "ficelles": "ficelle",
    "ficelons": "ficeler",
    "ficelâmes": "ficeler",
    "ficelât": "ficeler",
    "ficelâtes": "ficeler",
    "ficelèrent": "ficeler",
    "ficelé": "ficeler",
    "ficelée": "ficeler",
    "ficelées": "ficeler",
    "ficelés": "ficeler",
    "ficha": "ficher",
    "fichai": "ficher",
    "fichaient": "ficher",
    "fichais": "ficher",
    "fichaises": "fichaise",
    "fichait": "ficher",
    "fichant": "ficher",
    "fichas": "ficher",
    "fichasse": "ficher",
    "fichassent": "ficher",
    "fichasses": "ficher",
    "fichassiez": "ficher",
    "fichassions": "ficher",
    "fiche": "ficher",
    "fichent": "ficher",
    "fichera": "ficher",
    "ficherai": "ficher",
    "ficheraient": "ficher",
    "ficherais": "ficher",
    "ficherait": "ficher",
    "ficheras": "ficher",
    "ficherez": "ficher",
    "ficheriez": "ficher",
    "ficherions": "ficher",
    "ficherons": "ficher",
    "ficheront": "ficher",
    "fiches": "ficher",
    "fichez": "ficher",
    "fichiers": "fichier",
    "fichiez": "ficher",
    "fichions": "ficher",
    "fichons": "ficher",
    "fichu": "ficher",
    "fichue": "fichu",
    "fichues": "fichu",
    "fichus": "fichu",
    "fichâmes": "ficher",
    "fichât": "ficher",
    "fichâtes": "ficher",
    "fichèrent": "ficher",
    "fiché": "ficher",
    "fichée": "ficher",
    "fichées": "ficher",
    "fichés": "ficher",
    "fictifs": "fictif",
    "fictions": "fiction",
    "fictive": "fictif",
    "fictives": "fictif",
    "fiduciaires": "fiduciaire",
    "fidèles": "fidèle",
    "fidélisa": "fidéliser",
    "fidélisai": "fidéliser",
    "fidélisaient": "fidéliser",
    "fidélisais": "fidéliser",
    "fidélisait": "fidéliser",
    "fidélisant": "fidéliser",
    "fidélisas": "fidéliser",
    "fidélisasse": "fidéliser",
    "fidélisassent": "fidéliser",
    "fidélisasses": "fidéliser",
    "fidélisassiez": "fidéliser",
    "fidélisassions": "fidéliser",
    "fidélisations": "fidélisation",
    "fidélise": "fidéliser",
    "fidélisent": "fidéliser",
    "fidélisera": "fidéliser",
    "fidéliserai": "fidéliser",
    "fidéliseraient": "fidéliser",
    "fidéliserais": "fidéliser",
    "fidéliserait": "fidéliser",
    "fidéliseras": "fidéliser",
    "fidéliserez": "fidéliser",
    "fidéliseriez": "fidéliser",
    "fidéliserions": "fidéliser",
    "fidéliserons": "fidéliser",
    "fidéliseront": "fidéliser",
    "fidélises": "fidéliser",
    "fidélisez": "fidéliser",
    "fidélisiez": "fidéliser",
    "fidélisions": "fidéliser",
    "fidélisons": "fidéliser",
    "fidélisâmes": "fidéliser",
    "fidélisât": "fidéliser",
    "fidélisâtes": "fidéliser",
    "fidélisèrent": "fidéliser",
    "fidélisé": "fidéliser",
    "fidélisée": "fidéliser",
    "fidélisées": "fidéliser",
    "fidélisés": "fidéliser",
    "fidélités": "fidélité",
    "fie": "fier",
    "fieffé": "fieffer",
    "fieffée": "fieffer",
    "fieffées": "fieffé",
    "fieffés": "fieffé",
    "fiefs": "fief",
    "fielleuse": "fielleux",
    "fielleuses": "fielleux",
    "fiels": "fiel",
    "fient": "fier",
    "fiente": "fienter",
    "fientes": "fiente",
    "fienteuse": "fienteux",
    "fienté": "fienter",
    "fiera": "fier",
    "fierai": "fier",
    "fieraient": "fier",
    "fierais": "fier",
    "fierait": "fier",
    "fieras": "fier",
    "fierez": "fier",
    "fieriez": "fier",
    "fierions": "fier",
    "fierons": "fier",
    "fieront": "fier",
    "fiers": "fier",
    "fiers-à-bras": "fier-à-bras",
    "fiertés": "fierté",
    "fies": "fier",
    "fiestas": "fiesta",
    "fiez": "fier",
    "fifis": "fifi",
    "fifrelins": "fifrelin",
    "fifres": "fifre",
    "fifty-fifties": "fifty-fifty",
    "figaros": "figaro",
    "fige": "figer",
    "figea": "figer",
    "figeai": "figer",
    "figeaient": "figer",
    "figeais": "figer",
    "figeait": "figer",
    "figeant": "figer",
    "figeas": "figer",
    "figeasse": "figer",
    "figeassent": "figer",
    "figeasses": "figer",
    "figeassiez": "figer",
    "figeassions": "figer",
    "figent": "figer",
    "figeons": "figer",
    "figera": "figer",
    "figerai": "figer",
    "figeraient": "figer",
    "figerais": "figer",
    "figerait": "figer",
    "figeras": "figer",
    "figerez": "figer",
    "figeriez": "figer",
    "figerions": "figer",
    "figerons": "figer",
    "figeront": "figer",
    "figes": "figer",
    "figez": "figer",
    "figeâmes": "figer",
    "figeât": "figer",
    "figeâtes": "figer",
    "figiez": "figer",
    "figions": "figer",
    "fignola": "fignoler",
    "fignolages": "fignolage",
    "fignolai": "fignoler",
    "fignolaient": "fignoler",
    "fignolais": "fignoler",
    "fignolait": "fignoler",
    "fignolant": "fignoler",
    "fignolas": "fignoler",
    "fignolasse": "fignoler",
    "fignolassent": "fignoler",
    "fignolasses": "fignoler",
    "fignolassiez": "fignoler",
    "fignolassions": "fignoler",
    "fignole": "fignoler",
    "fignolent": "fignoler",
    "fignolera": "fignoler",
    "fignolerai": "fignoler",
    "fignoleraient": "fignoler",
    "fignolerais": "fignoler",
    "fignolerait": "fignoler",
    "fignoleras": "fignoler",
    "fignolerez": "fignoler",
    "fignoleriez": "fignoler",
    "fignolerions": "fignoler",
    "fignolerons": "fignoler",
    "fignoleront": "fignoler",
    "fignoles": "fignoler",
    "fignolez": "fignoler",
    "fignoliez": "fignoler",
    "fignolions": "fignoler",
    "fignolons": "fignoler",
    "fignolâmes": "fignoler",
    "fignolât": "fignoler",
    "fignolâtes": "fignoler",
    "fignolèrent": "fignoler",
    "fignolé": "fignoler",
    "fignolée": "fignoler",
    "fignolées": "fignoler",
    "fignolés": "fignoler",
    "figues": "figue",
    "figuiers": "figuier",
    "figura": "figurer",
    "figurai": "figurer",
    "figuraient": "figurer",
    "figurais": "figurer",
    "figurait": "figurer",
    "figurant": "figurer",
    "figurante": "figurant",
    "figurantes": "figurant",
    "figurants": "figurant",
    "figuras": "figurer",
    "figurasse": "figurer",
    "figurassent": "figurer",
    "figurasses": "figurer",
    "figurassiez": "figurer",
    "figurassions": "figurer",
    "figuratifs": "figuratif",
    "figurations": "figuration",
    "figurative": "figuratif",
    "figuratives": "figuratif",
    "figure": "figurer",
    "figurent": "figurer",
    "figurera": "figurer",
    "figurerai": "figurer",
    "figureraient": "figurer",
    "figurerais": "figurer",
    "figurerait": "figurer",
    "figureras": "figurer",
    "figurerez": "figurer",
    "figureriez": "figurer",
    "figurerions": "figurer",
    "figurerons": "figurer",
    "figureront": "figurer",
    "figures": "figurer",
    "figurez": "figurer",
    "figuriez": "figurer",
    "figurines": "figurine",
    "figurions": "figurer",
    "figurons": "figurer",
    "figurâmes": "figurer",
    "figurât": "figurer",
    "figurâtes": "figurer",
    "figurèrent": "figurer",
    "figuré": "figurer",
    "figurée": "figurer",
    "figurées": "figurer",
    "figurés": "figurer",
    "figèrent": "figer",
    "figé": "figer",
    "figée": "figer",
    "figées": "figer",
    "figés": "figer",
    "fiiez": "fier",
    "fiions": "fier",
    "fila": "filer",
    "filai": "filer",
    "filaient": "filer",
    "filais": "filer",
    "filait": "filer",
    "filaments": "filament",
    "filandières": "filandière",
    "filandres": "filandre",
    "filandreuse": "filandreux",
    "filandreuses": "filandreux",
    "filant": "filer",
    "filante": "filant",
    "filantes": "filant",
    "filanzanes": "filanzane",
    "filaos": "filao",
    "filas": "filer",
    "filasse": "filer",
    "filassent": "filer",
    "filasses": "filer",
    "filassiez": "filer",
    "filassions": "filer",
    "filateurs": "filateur",
    "filatures": "filature",
    "file": "filer",
    "filent": "filer",
    "filera": "filer",
    "filerai": "filer",
    "fileraient": "filer",
    "filerais": "filer",
    "filerait": "filer",
    "fileras": "filer",
    "filerez": "filer",
    "fileriez": "filer",
    "filerions": "filer",
    "filerons": "filer",
    "fileront": "filer",
    "files": "filer",
    "filets": "filet",
    "fileté": "fileter",
    "filetée": "fileter",
    "fileuse": "fileur",
    "filez": "filer",
    "filiale": "filial",
    "filiales": "filiale",
    "filialisations": "filialisation",
    "filiations": "filiation",
    "filiaux": "filial",
    "filiez": "filer",
    "filiformes": "filiforme",
    "filigranes": "filigrane",
    "filigranés": "filigraner",
    "filins": "filin",
    "filions": "filer",
    "filières": "filière",
    "fillasses": "fillasse",
    "filles": "fille",
    "fillettes": "fillette",
    "filleule": "filleul",
    "filleules": "filleul",
    "filleuls": "filleul",
    "filma": "filmer",
    "filmai": "filmer",
    "filmaient": "filmer",
    "filmais": "filmer",
    "filmait": "filmer",
    "filmant": "filmer",
    "filmas": "filmer",
    "filmasse": "filmer",
    "filmassent": "filmer",
    "filmasses": "filmer",
    "filmassiez": "filmer",
    "filmassions": "filmer",
    "filme": "filmer",
    "filment": "filmer",
    "filmera": "filmer",
    "filmerai": "filmer",
    "filmeraient": "filmer",
    "filmerais": "filmer",
    "filmerait": "filmer",
    "filmeras": "filmer",
    "filmerez": "filmer",
    "filmeriez": "filmer",
    "filmerions": "filmer",
    "filmerons": "filmer",
    "filmeront": "filmer",
    "filmes": "filmer",
    "filmez": "filmer",
    "filmiez": "filmer",
    "filmions": "filmer",
    "filmographies": "filmographie",
    "filmons": "filmer",
    "films": "film",
    "films-annonces": "films-annonce",
    "filmâmes": "filmer",
    "filmât": "filmer",
    "filmâtes": "filmer",
    "filmèrent": "filmer",
    "filmé": "filmer",
    "filmée": "filmer",
    "filmées": "filmer",
    "filmés": "filmer",
    "filochez": "filocher",
    "filoché": "filocher",
    "filons": "filon",
    "filous": "filou",
    "filouta": "filouter",
    "filoutai": "filouter",
    "filoutaient": "filouter",
    "filoutais": "filouter",
    "filoutait": "filouter",
    "filoutant": "filouter",
    "filoutas": "filouter",
    "filoutasse": "filouter",
    "filoutassent": "filouter",
    "filoutasses": "filouter",
    "filoutassiez": "filouter",
    "filoutassions": "filouter",
    "filoute": "filouter",
    "filoutent": "filouter",
    "filoutera": "filouter",
    "filouterai": "filouter",
    "filouteraient": "filouter",
    "filouterais": "filouter",
    "filouterait": "filouter",
    "filouteras": "filouter",
    "filouterez": "filouter",
    "filouteries": "filouterie",
    "filouteriez": "filouter",
    "filouterions": "filouter",
    "filouterons": "filouter",
    "filouteront": "filouter",
    "filoutes": "filouter",
    "filoutez": "filouter",
    "filoutiez": "filouter",
    "filoutions": "filouter",
    "filoutons": "filouter",
    "filoutâmes": "filouter",
    "filoutât": "filouter",
    "filoutâtes": "filouter",
    "filoutèrent": "filouter",
    "filouté": "filouter",
    "filoutée": "filouter",
    "filoutées": "filouter",
    "filoutés": "filouter",
    "fils": "fil",
    "filtra": "filtrer",
    "filtrages": "filtrage",
    "filtrai": "filtrer",
    "filtraient": "filtrer",
    "filtrais": "filtrer",
    "filtrait": "filtrer",
    "filtrant": "filtrer",
    "filtrantes": "filtrant",
    "filtrants": "filtrant",
    "filtras": "filtrer",
    "filtrasse": "filtrer",
    "filtrassent": "filtrer",
    "filtrasses": "filtrer",
    "filtrassiez": "filtrer",
    "filtrassions": "filtrer",
    "filtrations": "filtration",
    "filtre": "filtrer",
    "filtrent": "filtrer",
    "filtrera": "filtrer",
    "filtrerai": "filtrer",
    "filtreraient": "filtrer",
    "filtrerais": "filtrer",
    "filtrerait": "filtrer",
    "filtreras": "filtrer",
    "filtrerez": "filtrer",
    "filtreriez": "filtrer",
    "filtrerions": "filtrer",
    "filtrerons": "filtrer",
    "filtreront": "filtrer",
    "filtres": "filtrer",
    "filtres-presses": "filtre-presse",
    "filtrez": "filtrer",
    "filtriez": "filtrer",
    "filtrions": "filtrer",
    "filtrons": "filtrer",
    "filtrâmes": "filtrer",
    "filtrât": "filtrer",
    "filtrâtes": "filtrer",
    "filtrèrent": "filtrer",
    "filtré": "filtrer",
    "filtrée": "filtrer",
    "filtrées": "filtrer",
    "filtrés": "filtrer",
    "filâmes": "filer",
    "filât": "filer",
    "filâtes": "filer",
    "filèrent": "filer",
    "filé": "filer",
    "filée": "filer",
    "filées": "filer",
    "filés": "filer",
    "finale": "final",
    "finales": "finale",
    "finalisa": "finaliser",
    "finalisai": "finaliser",
    "finalisaient": "finaliser",
    "finalisais": "finaliser",
    "finalisait": "finaliser",
    "finalisant": "finaliser",
    "finalisas": "finaliser",
    "finalisasse": "finaliser",
    "finalisassent": "finaliser",
    "finalisasses": "finaliser",
    "finalisassiez": "finaliser",
    "finalisassions": "finaliser",
    "finalisations": "finalisation",
    "finalise": "finaliser",
    "finalisent": "finaliser",
    "finalisera": "finaliser",
    "finaliserai": "finaliser",
    "finaliseraient": "finaliser",
    "finaliserais": "finaliser",
    "finaliserait": "finaliser",
    "finaliseras": "finaliser",
    "finaliserez": "finaliser",
    "finaliseriez": "finaliser",
    "finaliserions": "finaliser",
    "finaliserons": "finaliser",
    "finaliseront": "finaliser",
    "finalises": "finaliser",
    "finalisez": "finaliser",
    "finalisiez": "finaliser",
    "finalisions": "finaliser",
    "finalisons": "finaliser",
    "finalistes": "finaliste",
    "finalisâmes": "finaliser",
    "finalisât": "finaliser",
    "finalisâtes": "finaliser",
    "finalisèrent": "finaliser",
    "finalisé": "finaliser",
    "finalisée": "finaliser",
    "finalisées": "finaliser",
    "finalisés": "finaliser",
    "finalités": "finalité",
    "finals": "final",
    "finance": "financer",
    "financements": "financement",
    "financent": "financer",
    "financera": "financer",
    "financerai": "financer",
    "financeraient": "financer",
    "financerais": "financer",
    "financerait": "financer",
    "financeras": "financer",
    "financerez": "financer",
    "financeriez": "financer",
    "financerions": "financer",
    "financerons": "financer",
    "financeront": "financer",
    "finances": "financer",
    "financeurs": "financeur",
    "financez": "financer",
    "financiers": "financier",
    "financiez": "financer",
    "financions": "financer",
    "financière": "financier",
    "financières": "financier",
    "financèrent": "financer",
    "financé": "financer",
    "financée": "financer",
    "financées": "financer",
    "financés": "financer",
    "finança": "financer",
    "finançai": "financer",
    "finançaient": "financer",
    "finançais": "financer",
    "finançait": "financer",
    "finançant": "financer",
    "finanças": "financer",
    "finançasse": "financer",
    "finançassent": "financer",
    "finançasses": "financer",
    "finançassiez": "financer",
    "finançassions": "financer",
    "finançons": "financer",
    "finançâmes": "financer",
    "finançât": "financer",
    "finançâtes": "financer",
    "finassa": "finasser",
    "finassai": "finasser",
    "finassaient": "finasser",
    "finassais": "finasser",
    "finassait": "finasser",
    "finassant": "finasser",
    "finassas": "finasser",
    "finassasse": "finasser",
    "finassassent": "finasser",
    "finassasses": "finasser",
    "finassassiez": "finasser",
    "finassassions": "finasser",
    "finasse": "finasser",
    "finassent": "finasser",
    "finassera": "finasser",
    "finasserai": "finasser",
    "finasseraient": "finasser",
    "finasserais": "finasser",
    "finasserait": "finasser",
    "finasseras": "finasser",
    "finasserez": "finasser",
    "finasseries": "finasserie",
    "finasseriez": "finasser",
    "finasserions": "finasser",
    "finasserons": "finasser",
    "finasseront": "finasser",
    "finasses": "finasser",
    "finassez": "finasser",
    "finassiers": "finassier",
    "finassiez": "finasser",
    "finassions": "finasser",
    "finassière": "finassier",
    "finassières": "finassier",
    "finassons": "finasser",
    "finassâmes": "finasser",
    "finassât": "finasser",
    "finassâtes": "finasser",
    "finassèrent": "finasser",
    "finassé": "finasser",
    "finaude": "finaud",
    "finaudes": "finaud",
    "finauds": "finaud",
    "finaux": "final",
    "fine": "fin",
    "fines": "fine",
    "finesses": "finesse",
    "finettes": "finette",
    "fini": "finir",
    "finie": "finir",
    "finies": "finir",
    "finira": "finir",
    "finirai": "finir",
    "finiraient": "finir",
    "finirais": "finir",
    "finirait": "finir",
    "finiras": "finir",
    "finirent": "finir",
    "finirez": "finir",
    "finiriez": "finir",
    "finirions": "finir",
    "finirons": "finir",
    "finiront": "finir",
    "finis": "finir",
    "finishs": "finish",
    "finissaient": "finir",
    "finissais": "finir",
    "finissait": "finir",
    "finissant": "finir",
    "finissante": "finissant",
    "finissantes": "finissant",
    "finissants": "finissant",
    "finisse": "finir",
    "finissent": "finir",
    "finisses": "finir",
    "finisseuse": "finisseur",
    "finissez": "finir",
    "finissiez": "finir",
    "finissions": "finir",
    "finissons": "finir",
    "finit": "finir",
    "finitions": "finition",
    "finitudes": "finitude",
    "finlandaise": "finlandais",
    "finlandaises": "finlandais",
    "fins": "fin",
    "finîmes": "finir",
    "finît": "finir",
    "finîtes": "finir",
    "fioles": "fiole",
    "fions": "fion",
    "fioritures": "fioriture",
    "fiouls": "fioul",
    "firent": "faire",
    "firmaments": "firmament",
    "firmans": "firman",
    "firmes": "firme",
    "fis": "faire",
    "fiscale": "fiscal",
    "fiscales": "fiscal",
    "fiscalistes": "fiscaliste",
    "fiscalités": "fiscalité",
    "fiscaux": "fiscal",
    "fiscs": "fisc",
    "fisse": "faire",
    "fissent": "faire",
    "fisses": "faire",
    "fissibles": "fissible",
    "fissiez": "faire",
    "fissiles": "fissile",
    "fissionné": "fissionner",
    "fissions": "fission",
    "fissura": "fissurer",
    "fissurai": "fissurer",
    "fissuraient": "fissurer",
    "fissurais": "fissurer",
    "fissurait": "fissurer",
    "fissurant": "fissurer",
    "fissuras": "fissurer",
    "fissurasse": "fissurer",
    "fissurassent": "fissurer",
    "fissurasses": "fissurer",
    "fissurassiez": "fissurer",
    "fissurassions": "fissurer",
    "fissure": "fissurer",
    "fissurent": "fissurer",
    "fissurera": "fissurer",
    "fissurerai": "fissurer",
    "fissureraient": "fissurer",
    "fissurerais": "fissurer",
    "fissurerait": "fissurer",
    "fissureras": "fissurer",
    "fissurerez": "fissurer",
    "fissureriez": "fissurer",
    "fissurerions": "fissurer",
    "fissurerons": "fissurer",
    "fissureront": "fissurer",
    "fissures": "fissurer",
    "fissurez": "fissurer",
    "fissuriez": "fissurer",
    "fissurions": "fissurer",
    "fissurons": "fissurer",
    "fissurâmes": "fissurer",
    "fissurât": "fissurer",
    "fissurâtes": "fissurer",
    "fissurèrent": "fissurer",
    "fissuré": "fissurer",
    "fissurée": "fissurer",
    "fissurées": "fissurer",
    "fissurés": "fissurer",
    "fistons": "fiston",
    "fistules": "fistule",
    "fit": "faire",
    "fitzgéraldiennes": "fitzgéraldien",
    "fixa": "fixer",
    "fixai": "fixer",
    "fixaient": "fixer",
    "fixais": "fixer",
    "fixait": "fixer",
    "fixant": "fixer",
    "fixas": "fixer",
    "fixasse": "fixer",
    "fixassent": "fixer",
    "fixasses": "fixer",
    "fixassiez": "fixer",
    "fixassions": "fixer",
    "fixations": "fixation",
    "fixe": "fixer",
    "fixe-chaussettes": "fixe-chaussette",
    "fixent": "fixer",
    "fixera": "fixer",
    "fixerai": "fixer",
    "fixeraient": "fixer",
    "fixerais": "fixer",
    "fixerait": "fixer",
    "fixeras": "fixer",
    "fixerez": "fixer",
    "fixeriez": "fixer",
    "fixerions": "fixer",
    "fixerons": "fixer",
    "fixeront": "fixer",
    "fixes": "fixer",
    "fixez": "fixer",
    "fixiez": "fixer",
    "fixings": "fixing",
    "fixions": "fixer",
    "fixités": "fixité",
    "fixons": "fixer",
    "fixâmes": "fixer",
    "fixât": "fixer",
    "fixâtes": "fixer",
    "fixèrent": "fixer",
    "fixé": "fixer",
    "fixée": "fixer",
    "fixées": "fixer",
    "fixés": "fixer",
    "fiâmes": "fier",
    "fiât": "fier",
    "fiâtes": "fier",
    "fière": "fier",
    "fièrent": "fier",
    "fières": "fier",
    "fièvres": "fièvre",
    "fié": "fier",
    "fiée": "fier",
    "fiées": "fier",
    "fiérote": "fiérot",
    "fiérotes": "fiérot",
    "fiérots": "fiérot",
    "fiés": "fier",
    "fiévreuse": "fiévreux",
    "fiévreuses": "fiévreux",
    "fjords": "fjord",
    "flaccidités": "flaccidité",
    "flaches": "flache",
    "flaconnages": "flaconnage",
    "flacons": "flacon",
    "flagella": "flageller",
    "flagellai": "flageller",
    "flagellaient": "flageller",
    "flagellais": "flageller",
    "flagellait": "flageller",
    "flagellant": "flageller",
    "flagellants": "flagellant",
    "flagellas": "flageller",
    "flagellasse": "flageller",
    "flagellassent": "flageller",
    "flagellasses": "flageller",
    "flagellassiez": "flageller",
    "flagellassions": "flageller",
    "flagellations": "flagellation",
    "flagelle": "flageller",
    "flagellent": "flageller",
    "flagellera": "flageller",
    "flagellerai": "flageller",
    "flagelleraient": "flageller",
    "flagellerais": "flageller",
    "flagellerait": "flageller",
    "flagelleras": "flageller",
    "flagellerez": "flageller",
    "flagelleriez": "flageller",
    "flagellerions": "flageller",
    "flagellerons": "flageller",
    "flagelleront": "flageller",
    "flagelles": "flageller",
    "flagellez": "flageller",
    "flagelliez": "flageller",
    "flagellions": "flageller",
    "flagellons": "flageller",
    "flagellâmes": "flageller",
    "flagellât": "flageller",
    "flagellâtes": "flageller",
    "flagellèrent": "flageller",
    "flagellé": "flageller",
    "flagellée": "flageller",
    "flagellées": "flageller",
    "flagellés": "flageller",
    "flageola": "flageoler",
    "flageolai": "flageoler",
    "flageolaient": "flageoler",
    "flageolais": "flageoler",
    "flageolait": "flageoler",
    "flageolant": "flageoler",
    "flageolante": "flageolant",
    "flageolantes": "flageolant",
    "flageolants": "flageolant",
    "flageolas": "flageoler",
    "flageolasse": "flageoler",
    "flageolassent": "flageoler",
    "flageolasses": "flageoler",
    "flageolassiez": "flageoler",
    "flageolassions": "flageoler",
    "flageole": "flageoler",
    "flageolent": "flageoler",
    "flageolera": "flageoler",
    "flageolerai": "flageoler",
    "flageoleraient": "flageoler",
    "flageolerais": "flageoler",
    "flageolerait": "flageoler",
    "flageoleras": "flageoler",
    "flageolerez": "flageoler",
    "flageoleriez": "flageoler",
    "flageolerions": "flageoler",
    "flageolerons": "flageoler",
    "flageoleront": "flageoler",
    "flageoles": "flageoler",
    "flageolets": "flageolet",
    "flageolez": "flageoler",
    "flageoliez": "flageoler",
    "flageolions": "flageoler",
    "flageolons": "flageoler",
    "flageolâmes": "flageoler",
    "flageolât": "flageoler",
    "flageolâtes": "flageoler",
    "flageolèrent": "flageoler",
    "flageolé": "flageoler",
    "flageolée": "flageoler",
    "flageolées": "flageoler",
    "flageolés": "flageoler",
    "flagorna": "flagorner",
    "flagornai": "flagorner",
    "flagornaient": "flagorner",
    "flagornais": "flagorner",
    "flagornait": "flagorner",
    "flagornant": "flagorner",
    "flagornas": "flagorner",
    "flagornasse": "flagorner",
    "flagornassent": "flagorner",
    "flagornasses": "flagorner",
    "flagornassiez": "flagorner",
    "flagornassions": "flagorner",
    "flagorne": "flagorner",
    "flagornent": "flagorner",
    "flagornera": "flagorner",
    "flagornerai": "flagorner",
    "flagorneraient": "flagorner",
    "flagornerais": "flagorner",
    "flagornerait": "flagorner",
    "flagorneras": "flagorner",
    "flagornerez": "flagorner",
    "flagorneries": "flagornerie",
    "flagorneriez": "flagorner",
    "flagornerions": "flagorner",
    "flagornerons": "flagorner",
    "flagorneront": "flagorner",
    "flagornes": "flagorner",
    "flagorneurs": "flagorneur",
    "flagorneuse": "flagorneur",
    "flagornez": "flagorner",
    "flagorniez": "flagorner",
    "flagornions": "flagorner",
    "flagornons": "flagorner",
    "flagornâmes": "flagorner",
    "flagornât": "flagorner",
    "flagornâtes": "flagorner",
    "flagornèrent": "flagorner",
    "flagorné": "flagorner",
    "flagornée": "flagorner",
    "flagornées": "flagorner",
    "flagornés": "flagorner",
    "flagrante": "flagrant",
    "flagrantes": "flagrant",
    "flagrants": "flagrant",
    "flahutes": "flahute",
    "flaira": "flairer",
    "flairaient": "flairer",
    "flairais": "flairer",
    "flairait": "flairer",
    "flairant": "flairer",
    "flaire": "flairer",
    "flairent": "flairer",
    "flairera": "flairer",
    "flairerait": "flairer",
    "flaires": "flairer",
    "flaireurs": "flaireur",
    "flaireuse": "flaireur",
    "flairez": "flairer",
    "flairs": "flair",
    "flairé": "flairer",
    "flairée": "flairer",
    "flairées": "flairé",
    "flairés": "flairer",
    "flamande": "flamand",
    "flamandes": "flamand",
    "flamands": "flamand",
    "flamants": "flamant",
    "flamba": "flamber",
    "flambages": "flambage",
    "flambai": "flamber",
    "flambaient": "flamber",
    "flambais": "flamber",
    "flambait": "flamber",
    "flambant": "flamber",
    "flambante": "flambant",
    "flambantes": "flambant",
    "flambants": "flambant",
    "flambards": "flambard",
    "flambas": "flamber",
    "flambasse": "flamber",
    "flambassent": "flamber",
    "flambasses": "flamber",
    "flambassiez": "flamber",
    "flambassions": "flamber",
    "flambe": "flamber",
    "flambeaux": "flambeau",
    "flambent": "flamber",
    "flambera": "flamber",
    "flamberai": "flamber",
    "flamberaient": "flamber",
    "flamberais": "flamber",
    "flamberait": "flamber",
    "flamberas": "flamber",
    "flamberez": "flamber",
    "flamberges": "flamberge",
    "flamberiez": "flamber",
    "flamberions": "flamber",
    "flamberons": "flamber",
    "flamberont": "flamber",
    "flambes": "flamber",
    "flambeurs": "flambeur",
    "flambeuse": "flambeur",
    "flambez": "flamber",
    "flambiez": "flamber",
    "flambions": "flamber",
    "flamboie": "flamboyer",
    "flamboiements": "flamboiement",
    "flamboient": "flamboyer",
    "flamboiera": "flamboyer",
    "flamboierai": "flamboyer",
    "flamboieraient": "flamboyer",
    "flamboierais": "flamboyer",
    "flamboierait": "flamboyer",
    "flamboieras": "flamboyer",
    "flamboierez": "flamboyer",
    "flamboieriez": "flamboyer",
    "flamboierions": "flamboyer",
    "flamboierons": "flamboyer",
    "flamboieront": "flamboyer",
    "flamboies": "flamboyer",
    "flambons": "flamber",
    "flamboya": "flamboyer",
    "flamboyai": "flamboyer",
    "flamboyaient": "flamboyer",
    "flamboyais": "flamboyer",
    "flamboyait": "flamboyer",
    "flamboyant": "flamboyer",
    "flamboyante": "flamboyant",
    "flamboyantes": "flamboyant",
    "flamboyants": "flamboyant",
    "flamboyas": "flamboyer",
    "flamboyasse": "flamboyer",
    "flamboyassent": "flamboyer",
    "flamboyasses": "flamboyer",
    "flamboyassiez": "flamboyer",
    "flamboyassions": "flamboyer",
    "flamboyez": "flamboyer",
    "flamboyiez": "flamboyer",
    "flamboyions": "flamboyer",
    "flamboyons": "flamboyer",
    "flamboyâmes": "flamboyer",
    "flamboyât": "flamboyer",
    "flamboyâtes": "flamboyer",
    "flamboyèrent": "flamboyer",
    "flamboyé": "flamboyer",
    "flambâmes": "flamber",
    "flambât": "flamber",
    "flambâtes": "flamber",
    "flambèrent": "flamber",
    "flambé": "flamber",
    "flambée": "flamber",
    "flambées": "flamber",
    "flambés": "flamber",
    "flamencos": "flamenco",
    "flamingante": "flamingant",
    "flamingantes": "flamingant",
    "flamingants": "flamingant",
    "flammes": "flamme",
    "flammèches": "flammèche",
    "flammée": "flammé",
    "flammés": "flammé",
    "flancha": "flancher",
    "flanchai": "flancher",
    "flanchaient": "flancher",
    "flanchais": "flancher",
    "flanchait": "flancher",
    "flanchant": "flancher",
    "flanchas": "flancher",
    "flanchasse": "flancher",
    "flanchassent": "flancher",
    "flanchasses": "flancher",
    "flanchassiez": "flancher",
    "flanchassions": "flancher",
    "flanche": "flancher",
    "flanchent": "flancher",
    "flanchera": "flancher",
    "flancherai": "flancher",
    "flancheraient": "flancher",
    "flancherais": "flancher",
    "flancherait": "flancher",
    "flancheras": "flancher",
    "flancherez": "flancher",
    "flancheriez": "flancher",
    "flancherions": "flancher",
    "flancherons": "flancher",
    "flancheront": "flancher",
    "flanches": "flancher",
    "flanchez": "flancher",
    "flanchiez": "flancher",
    "flanchions": "flancher",
    "flanchons": "flancher",
    "flanchâmes": "flancher",
    "flanchât": "flancher",
    "flanchâtes": "flancher",
    "flanchèrent": "flancher",
    "flanché": "flancher",
    "flancs": "flanc",
    "flancs-gardes": "flanc-garde",
    "flandrins": "flandrin",
    "flanelles": "flanelle",
    "flanqua": "flanquer",
    "flanquai": "flanquer",
    "flanquaient": "flanquer",
    "flanquais": "flanquer",
    "flanquait": "flanquer",
    "flanquant": "flanquer",
    "flanquas": "flanquer",
    "flanquasse": "flanquer",
    "flanquassent": "flanquer",
    "flanquasses": "flanquer",
    "flanquassiez": "flanquer",
    "flanquassions": "flanquer",
    "flanque": "flanquer",
    "flanquent": "flanquer",
    "flanquera": "flanquer",
    "flanquerai": "flanquer",
    "flanqueraient": "flanquer",
    "flanquerais": "flanquer",
    "flanquerait": "flanquer",
    "flanqueras": "flanquer",
    "flanquerez": "flanquer",
    "flanqueriez": "flanquer",
    "flanquerions": "flanquer",
    "flanquerons": "flanquer",
    "flanqueront": "flanquer",
    "flanques": "flanquer",
    "flanquez": "flanquer",
    "flanquiez": "flanquer",
    "flanquions": "flanquer",
    "flanquons": "flanquer",
    "flanquâmes": "flanquer",
    "flanquât": "flanquer",
    "flanquâtes": "flanquer",
    "flanquèrent": "flanquer",
    "flanqué": "flanquer",
    "flanquée": "flanquer",
    "flanquées": "flanquer",
    "flanqués": "flanquer",
    "flans": "flan",
    "flapie": "flapi",
    "flapies": "flapi",
    "flapis": "flapi",
    "flaques": "flaque",
    "flashaient": "flasher",
    "flashant": "flasher",
    "flashe": "flasher",
    "flashent": "flasher",
    "flashes": "flashe",
    "flashs": "flash",
    "flashé": "flasher",
    "flasques": "flasque",
    "flats": "flat",
    "flatta": "flatter",
    "flattai": "flatter",
    "flattaient": "flatter",
    "flattais": "flatter",
    "flattait": "flatter",
    "flattant": "flatter",
    "flattas": "flatter",
    "flattasse": "flatter",
    "flattassent": "flatter",
    "flattasses": "flatter",
    "flattassiez": "flatter",
    "flattassions": "flatter",
    "flatte": "flatter",
    "flattent": "flatter",
    "flattera": "flatter",
    "flatterai": "flatter",
    "flatteraient": "flatter",
    "flatterais": "flatter",
    "flatterait": "flatter",
    "flatteras": "flatter",
    "flatterez": "flatter",
    "flatteries": "flatterie",
    "flatteriez": "flatter",
    "flatterions": "flatter",
    "flatterons": "flatter",
    "flatteront": "flatter",
    "flattes": "flatter",
    "flatteurs": "flatteur",
    "flatteuse": "flatteur",
    "flatteuses": "flatteur",
    "flattez": "flatter",
    "flattiez": "flatter",
    "flattions": "flatter",
    "flattons": "flatter",
    "flattâmes": "flatter",
    "flattât": "flatter",
    "flattâtes": "flatter",
    "flattèrent": "flatter",
    "flatté": "flatter",
    "flattée": "flatter",
    "flattées": "flatter",
    "flattés": "flatter",
    "flatulences": "flatulence",
    "flatulente": "flatulent",
    "flatulentes": "flatulent",
    "flatulents": "flatulent",
    "flatuosités": "flatuosité",
    "flavescente": "flavescent",
    "flavescentes": "flavescent",
    "flavescents": "flavescent",
    "flegmatiques": "flegmatique",
    "flegmes": "flegme",
    "flemmardais": "flemmarder",
    "flemmardant": "flemmarder",
    "flemmarde": "flemmarder",
    "flemmardes": "flemmarder",
    "flemmards": "flemmard",
    "flemmes": "flemme",
    "fleura": "fleurer",
    "fleurai": "fleurer",
    "fleuraient": "fleurer",
    "fleurais": "fleurer",
    "fleurait": "fleurer",
    "fleurant": "fleurer",
    "fleuras": "fleurer",
    "fleurasse": "fleurer",
    "fleurassent": "fleurer",
    "fleurasses": "fleurer",
    "fleurassiez": "fleurer",
    "fleurassions": "fleurer",
    "fleurdelisée": "fleurdeliser",
    "fleurdelisées": "fleurdelisé",
    "fleurdelisés": "fleurdelisé",
    "fleure": "fleurer",
    "fleurent": "fleurer",
    "fleurera": "fleurer",
    "fleurerai": "fleurer",
    "fleureraient": "fleurer",
    "fleurerais": "fleurer",
    "fleurerait": "fleurer",
    "fleureras": "fleurer",
    "fleurerez": "fleurer",
    "fleureriez": "fleurer",
    "fleurerions": "fleurer",
    "fleurerons": "fleurer",
    "fleureront": "fleurer",
    "fleures": "fleurer",
    "fleuretais": "fleureter",
    "fleuretait": "fleureter",
    "fleurets": "fleuret",
    "fleurettes": "fleurette",
    "fleurez": "fleurer",
    "fleuri": "fleurir",
    "fleurie": "fleurir",
    "fleuries": "fleurir",
    "fleuriez": "fleurer",
    "fleurions": "fleurer",
    "fleurira": "fleurir",
    "fleurirai": "fleurir",
    "fleuriraient": "fleurir",
    "fleurirais": "fleurir",
    "fleurirait": "fleurir",
    "fleuriras": "fleurir",
    "fleurirent": "fleurir",
    "fleurirez": "fleurir",
    "fleuririez": "fleurir",
    "fleuririons": "fleurir",
    "fleurirons": "fleurir",
    "fleuriront": "fleurir",
    "fleuris": "fleurir",
    "fleurissaient": "fleurir",
    "fleurissais": "fleurir",
    "fleurissait": "fleurir",
    "fleurissant": "fleurir",
    "fleurisse": "fleurir",
    "fleurissent": "fleurir",
    "fleurisses": "fleurir",
    "fleurissez": "fleurir",
    "fleurissiez": "fleurir",
    "fleurissions": "fleurir",
    "fleurissons": "fleurir",
    "fleuristes": "fleuriste",
    "fleurit": "fleurir",
    "fleuronnée": "fleuronné",
    "fleurons": "fleuron",
    "fleurs": "fleur",
    "fleurâmes": "fleurer",
    "fleurât": "fleurer",
    "fleurâtes": "fleurer",
    "fleurèrent": "fleurer",
    "fleuré": "fleurer",
    "fleurîmes": "fleurir",
    "fleurît": "fleurir",
    "fleurîtes": "fleurir",
    "fleuves": "fleuve",
    "flexibilités": "flexibilité",
    "flexibles": "flexible",
    "flexions": "flexion",
    "flexueuse": "flexueux",
    "flexueuses": "flexueux",
    "flibustes": "flibuste",
    "flibustiers": "flibustier",
    "flicailles": "flicaille",
    "flicarde": "flicard",
    "flicardes": "flicard",
    "flicards": "flicard",
    "flics": "flic",
    "flingots": "flingot",
    "flingoté": "flingoter",
    "flingua": "flinguer",
    "flinguai": "flinguer",
    "flinguaient": "flinguer",
    "flinguais": "flinguer",
    "flinguait": "flinguer",
    "flinguant": "flinguer",
    "flinguas": "flinguer",
    "flinguasse": "flinguer",
    "flinguassent": "flinguer",
    "flinguasses": "flinguer",
    "flinguassiez": "flinguer",
    "flinguassions": "flinguer",
    "flingue": "flinguer",
    "flinguent": "flinguer",
    "flinguera": "flinguer",
    "flinguerai": "flinguer",
    "flingueraient": "flinguer",
    "flinguerais": "flinguer",
    "flinguerait": "flinguer",
    "flingueras": "flinguer",
    "flinguerez": "flinguer",
    "flingueriez": "flinguer",
    "flinguerions": "flinguer",
    "flinguerons": "flinguer",
    "flingueront": "flinguer",
    "flingues": "flinguer",
    "flingueurs": "flingueur",
    "flingueuse": "flingueur",
    "flingueuses": "flingueur",
    "flinguez": "flinguer",
    "flinguiez": "flinguer",
    "flinguions": "flinguer",
    "flinguons": "flinguer",
    "flinguâmes": "flinguer",
    "flinguât": "flinguer",
    "flinguâtes": "flinguer",
    "flinguèrent": "flinguer",
    "flingué": "flinguer",
    "flinguée": "flinguer",
    "flinguées": "flinguer",
    "flingués": "flinguer",
    "flippa": "flipper",
    "flippai": "flipper",
    "flippaient": "flipper",
    "flippais": "flipper",
    "flippait": "flipper",
    "flippant": "flipper",
    "flippas": "flipper",
    "flippasse": "flipper",
    "flippassent": "flipper",
    "flippasses": "flipper",
    "flippassiez": "flipper",
    "flippassions": "flipper",
    "flippe": "flipper",
    "flippent": "flipper",
    "flippera": "flipper",
    "flipperai": "flipper",
    "flipperaient": "flipper",
    "flipperais": "flipper",
    "flipperait": "flipper",
    "flipperas": "flipper",
    "flipperez": "flipper",
    "flipperiez": "flipper",
    "flipperions": "flipper",
    "flipperons": "flipper",
    "flipperont": "flipper",
    "flippers": "flipper",
    "flippes": "flipper",
    "flippez": "flipper",
    "flippiez": "flipper",
    "flippions": "flipper",
    "flippons": "flipper",
    "flippâmes": "flipper",
    "flippât": "flipper",
    "flippâtes": "flipper",
    "flippèrent": "flipper",
    "flippé": "flipper",
    "flippée": "flipper",
    "flippés": "flipper",
    "flips": "flip",
    "fliqués": "fliqué",
    "flirta": "flirter",
    "flirtai": "flirter",
    "flirtaient": "flirter",
    "flirtais": "flirter",
    "flirtait": "flirter",
    "flirtant": "flirter",
    "flirtas": "flirter",
    "flirtasse": "flirter",
    "flirtassent": "flirter",
    "flirtasses": "flirter",
    "flirtassiez": "flirter",
    "flirtassions": "flirter",
    "flirte": "flirter",
    "flirtent": "flirter",
    "flirtera": "flirter",
    "flirterai": "flirter",
    "flirteraient": "flirter",
    "flirterais": "flirter",
    "flirterait": "flirter",
    "flirteras": "flirter",
    "flirterez": "flirter",
    "flirteriez": "flirter",
    "flirterions": "flirter",
    "flirterons": "flirter",
    "flirteront": "flirter",
    "flirtes": "flirter",
    "flirteuse": "flirteur",
    "flirteuses": "flirteur",
    "flirtez": "flirter",
    "flirtiez": "flirter",
    "flirtions": "flirter",
    "flirtons": "flirter",
    "flirts": "flirt",
    "flirtâmes": "flirter",
    "flirtât": "flirter",
    "flirtâtes": "flirter",
    "flirtèrent": "flirter",
    "flirté": "flirter",
    "floches": "floche",
    "floconna": "floconner",
    "floconnai": "floconner",
    "floconnaient": "floconner",
    "floconnais": "floconner",
    "floconnait": "floconner",
    "floconnant": "floconner",
    "floconnas": "floconner",
    "floconnasse": "floconner",
    "floconnassent": "floconner",
    "floconnasses": "floconner",
    "floconnassiez": "floconner",
    "floconnassions": "floconner",
    "floconne": "floconner",
    "floconnent": "floconner",
    "floconnera": "floconner",
    "floconnerai": "floconner",
    "floconneraient": "floconner",
    "floconnerais": "floconner",
    "floconnerait": "floconner",
    "floconneras": "floconner",
    "floconnerez": "floconner",
    "floconneriez": "floconner",
    "floconnerions": "floconner",
    "floconnerons": "floconner",
    "floconneront": "floconner",
    "floconnes": "floconner",
    "floconneuse": "floconneux",
    "floconneuses": "floconneux",
    "floconnez": "floconner",
    "floconniez": "floconner",
    "floconnions": "floconner",
    "floconnons": "floconner",
    "floconnâmes": "floconner",
    "floconnât": "floconner",
    "floconnâtes": "floconner",
    "floconnèrent": "floconner",
    "floconné": "floconner",
    "floconnée": "floconner",
    "floconnées": "floconner",
    "floconnés": "floconner",
    "flocons": "flocon",
    "flocula": "floculer",
    "floculai": "floculer",
    "floculaient": "floculer",
    "floculais": "floculer",
    "floculait": "floculer",
    "floculant": "floculer",
    "floculas": "floculer",
    "floculasse": "floculer",
    "floculassent": "floculer",
    "floculasses": "floculer",
    "floculassiez": "floculer",
    "floculassions": "floculer",
    "flocule": "floculer",
    "floculent": "floculer",
    "floculera": "floculer",
    "floculerai": "floculer",
    "floculeraient": "floculer",
    "floculerais": "floculer",
    "floculerait": "floculer",
    "floculeras": "floculer",
    "floculerez": "floculer",
    "floculeriez": "floculer",
    "floculerions": "floculer",
    "floculerons": "floculer",
    "floculeront": "floculer",
    "flocules": "floculer",
    "floculez": "floculer",
    "floculiez": "floculer",
    "floculions": "floculer",
    "floculons": "floculer",
    "floculâmes": "floculer",
    "floculât": "floculer",
    "floculâtes": "floculer",
    "floculèrent": "floculer",
    "floculé": "floculer",
    "floculée": "floculer",
    "floculées": "floculer",
    "floculés": "floculer",
    "flonflons": "flonflon",
    "flops": "flop",
    "flopées": "flopée",
    "floraisons": "floraison",
    "florale": "floral",
    "florales": "floral",
    "floraux": "floral",
    "florentine": "florentin",
    "florentines": "florentin",
    "florentins": "florentin",
    "flores": "flore",
    "florescences": "florescence",
    "floriculteurs": "floriculteur",
    "floricultrice": "floriculteur",
    "floricultrices": "floriculteur",
    "floricultures": "floriculture",
    "florilèges": "florilège",
    "florins": "florin",
    "florissaient": "fleurir",
    "florissais": "fleurir",
    "florissait": "fleurir",
    "florissant": "florir",
    "florissante": "florissant",
    "florissantes": "florissant",
    "florissants": "florissant",
    "florissiez": "fleurir",
    "florissions": "fleurir",
    "floristiques": "floristique",
    "floréals": "floréal",
    "flotilles": "flotille",
    "flots": "flot",
    "flotta": "flotter",
    "flottai": "flotter",
    "flottaient": "flotter",
    "flottais": "flotter",
    "flottaisons": "flottaison",
    "flottait": "flotter",
    "flottant": "flotter",
    "flottante": "flottant",
    "flottantes": "flottant",
    "flottants": "flottant",
    "flottas": "flotter",
    "flottasse": "flotter",
    "flottassent": "flotter",
    "flottasses": "flotter",
    "flottassiez": "flotter",
    "flottassions": "flotter",
    "flotte": "flotter",
    "flottements": "flottement",
    "flottent": "flotter",
    "flottera": "flotter",
    "flotterai": "flotter",
    "flotteraient": "flotter",
    "flotterais": "flotter",
    "flotterait": "flotter",
    "flotteras": "flotter",
    "flotterez": "flotter",
    "flotteriez": "flotter",
    "flotterions": "flotter",
    "flotterons": "flotter",
    "flotteront": "flotter",
    "flottes": "flotter",
    "flotteurs": "flotteur",
    "flottez": "flotter",
    "flottiez": "flotter",
    "flottilles": "flottille",
    "flottions": "flotter",
    "flottons": "flotter",
    "flottâmes": "flotter",
    "flottât": "flotter",
    "flottâtes": "flotter",
    "flottèrent": "flotter",
    "flotté": "flotter",
    "flottée": "flotter",
    "flottées": "flotter",
    "flottés": "flotter",
    "floua": "flouer",
    "flouai": "flouer",
    "flouaient": "flouer",
    "flouais": "flouer",
    "flouait": "flouer",
    "flouant": "flouer",
    "flouas": "flouer",
    "flouasse": "flouer",
    "flouassent": "flouer",
    "flouasses": "flouer",
    "flouassiez": "flouer",
    "flouassions": "flouer",
    "floue": "flouer",
    "flouent": "flouer",
    "flouera": "flouer",
    "flouerai": "flouer",
    "floueraient": "flouer",
    "flouerais": "flouer",
    "flouerait": "flouer",
    "floueras": "flouer",
    "flouerez": "flouer",
    "floueriez": "flouer",
    "flouerions": "flouer",
    "flouerons": "flouer",
    "floueront": "flouer",
    "floues": "flouer",
    "flouez": "flouer",
    "flouiez": "flouer",
    "flouions": "flouer",
    "flouons": "flouer",
    "flous": "flou",
    "flouâmes": "flouer",
    "flouât": "flouer",
    "flouâtes": "flouer",
    "flouèrent": "flouer",
    "floué": "flouer",
    "flouée": "flouer",
    "flouées": "flouer",
    "floués": "flouer",
    "flua": "fluer",
    "fluages": "fluage",
    "fluai": "fluer",
    "fluaient": "fluer",
    "fluais": "fluer",
    "fluait": "fluer",
    "fluant": "fluer",
    "fluas": "fluer",
    "fluasse": "fluer",
    "fluassent": "fluer",
    "fluasses": "fluer",
    "fluassiez": "fluer",
    "fluassions": "fluer",
    "flubes": "fluber",
    "fluctua": "fluctuer",
    "fluctuai": "fluctuer",
    "fluctuaient": "fluctuer",
    "fluctuais": "fluctuer",
    "fluctuait": "fluctuer",
    "fluctuant": "fluctuer",
    "fluctuante": "fluctuant",
    "fluctuas": "fluctuer",
    "fluctuasse": "fluctuer",
    "fluctuassent": "fluctuer",
    "fluctuasses": "fluctuer",
    "fluctuassiez": "fluctuer",
    "fluctuassions": "fluctuer",
    "fluctuations": "fluctuation",
    "fluctue": "fluctuer",
    "fluctuent": "fluctuer",
    "fluctuera": "fluctuer",
    "fluctuerai": "fluctuer",
    "fluctueraient": "fluctuer",
    "fluctuerais": "fluctuer",
    "fluctuerait": "fluctuer",
    "fluctueras": "fluctuer",
    "fluctuerez": "fluctuer",
    "fluctueriez": "fluctuer",
    "fluctuerions": "fluctuer",
    "fluctuerons": "fluctuer",
    "fluctueront": "fluctuer",
    "fluctues": "fluctuer",
    "fluctuez": "fluctuer",
    "fluctuiez": "fluctuer",
    "fluctuions": "fluctuer",
    "fluctuons": "fluctuer",
    "fluctuâmes": "fluctuer",
    "fluctuât": "fluctuer",
    "fluctuâtes": "fluctuer",
    "fluctuèrent": "fluctuer",
    "fluctué": "fluctuer",
    "flue": "fluer",
    "fluent": "fluer",
    "fluente": "fluent",
    "fluentes": "fluent",
    "fluents": "fluent",
    "fluera": "fluer",
    "fluerai": "fluer",
    "flueraient": "fluer",
    "fluerais": "fluer",
    "fluerait": "fluer",
    "flueras": "fluer",
    "fluerez": "fluer",
    "flueriez": "fluer",
    "fluerions": "fluer",
    "fluerons": "fluer",
    "flueront": "fluer",
    "flues": "fluer",
    "fluets": "fluet",
    "fluette": "fluet",
    "fluettes": "fluet",
    "fluez": "fluer",
    "fluides": "fluide",
    "fluidifié": "fluidifier",
    "fluidiques": "fluidique",
    "fluidisée": "fluidisé",
    "fluidisées": "fluidisé",
    "fluidisés": "fluidisé",
    "fluidités": "fluidité",
    "fluiez": "fluer",
    "fluions": "fluer",
    "fluons": "fluer",
    "fluorescences": "fluorescence",
    "fluorescente": "fluorescent",
    "fluorescentes": "fluorescent",
    "fluorescents": "fluorescent",
    "fluorhydriques": "fluorhydrique",
    "fluors": "fluor",
    "fluorée": "fluoré",
    "fluos": "fluo",
    "fluviale": "fluvial",
    "fluviales": "fluvial",
    "fluviaux": "fluvial",
    "fluvioglaciaires": "fluvioglaciaire",
    "fluxe": "fluxer",
    "fluxions": "fluxion",
    "fluâmes": "fluer",
    "fluât": "fluer",
    "fluâtes": "fluer",
    "fluèrent": "fluer",
    "flué": "fluer",
    "fluée": "fluer",
    "fluées": "fluer",
    "flués": "fluer",
    "flâna": "flâner",
    "flânai": "flâner",
    "flânaient": "flâner",
    "flânais": "flâner",
    "flânait": "flâner",
    "flânant": "flâner",
    "flânas": "flâner",
    "flânasse": "flâner",
    "flânassent": "flâner",
    "flânasses": "flâner",
    "flânassiez": "flâner",
    "flânassions": "flâner",
    "flâne": "flâner",
    "flânent": "flâner",
    "flânera": "flâner",
    "flânerai": "flâner",
    "flâneraient": "flâner",
    "flânerais": "flâner",
    "flânerait": "flâner",
    "flâneras": "flâner",
    "flânerez": "flâner",
    "flâneries": "flânerie",
    "flâneriez": "flâner",
    "flânerions": "flâner",
    "flânerons": "flâner",
    "flâneront": "flâner",
    "flânes": "flâner",
    "flâneurs": "flâneur",
    "flâneuse": "flâneur",
    "flâneuses": "flâneur",
    "flânez": "flâner",
    "flâniez": "flâner",
    "flânions": "flâner",
    "flânochent": "flânocher",
    "flânons": "flâner",
    "flânâmes": "flâner",
    "flânât": "flâner",
    "flânâtes": "flâner",
    "flânèrent": "flâner",
    "flâné": "flâner",
    "flèches": "flèche",
    "fléaux": "fléau",
    "fléchettes": "fléchette",
    "fléchi": "fléchir",
    "fléchie": "fléchir",
    "fléchies": "fléchir",
    "fléchira": "fléchir",
    "fléchirai": "fléchir",
    "fléchiraient": "fléchir",
    "fléchirais": "fléchir",
    "fléchirait": "fléchir",
    "fléchiras": "fléchir",
    "fléchirent": "fléchir",
    "fléchirez": "fléchir",
    "fléchiriez": "fléchir",
    "fléchirions": "fléchir",
    "fléchirons": "fléchir",
    "fléchiront": "fléchir",
    "fléchis": "fléchir",
    "fléchissaient": "fléchir",
    "fléchissais": "fléchir",
    "fléchissait": "fléchir",
    "fléchissant": "fléchir",
    "fléchisse": "fléchir",
    "fléchissements": "fléchissement",
    "fléchissent": "fléchir",
    "fléchisses": "fléchir",
    "fléchissez": "fléchir",
    "fléchissiez": "fléchir",
    "fléchissions": "fléchir",
    "fléchissons": "fléchir",
    "fléchit": "fléchir",
    "fléché": "flécher",
    "fléchée": "flécher",
    "fléchées": "flécher",
    "fléchés": "flécher",
    "fléchîmes": "fléchir",
    "fléchît": "fléchir",
    "fléchîtes": "fléchir",
    "flétans": "flétan",
    "flétri": "flétrir",
    "flétrie": "flétrir",
    "flétries": "flétrir",
    "flétrira": "flétrir",
    "flétrirai": "flétrir",
    "flétriraient": "flétrir",
    "flétrirais": "flétrir",
    "flétrirait": "flétrir",
    "flétriras": "flétrir",
    "flétrirent": "flétrir",
    "flétrirez": "flétrir",
    "flétririez": "flétrir",
    "flétririons": "flétrir",
    "flétrirons": "flétrir",
    "flétriront": "flétrir",
    "flétris": "flétrir",
    "flétrissaient": "flétrir",
    "flétrissais": "flétrir",
    "flétrissait": "flétrir",
    "flétrissant": "flétrir",
    "flétrisse": "flétrir",
    "flétrissent": "flétrir",
    "flétrisses": "flétrir",
    "flétrissez": "flétrir",
    "flétrissiez": "flétrir",
    "flétrissions": "flétrir",
    "flétrissons": "flétrir",
    "flétrissures": "flétrissure",
    "flétrit": "flétrir",
    "flétrîmes": "flétrir",
    "flétrît": "flétrir",
    "flétrîtes": "flétrir",
    "flûta": "flûter",
    "flûtes": "flûte",
    "flûtistes": "flûtiste",
    "flûtée": "flûter",
    "flûtés": "flûté",
    "focale": "focal",
    "focales": "focal",
    "focalisa": "focaliser",
    "focalisai": "focaliser",
    "focalisaient": "focaliser",
    "focalisais": "focaliser",
    "focalisait": "focaliser",
    "focalisant": "focaliser",
    "focalisas": "focaliser",
    "focalisasse": "focaliser",
    "focalisassent": "focaliser",
    "focalisasses": "focaliser",
    "focalisassiez": "focaliser",
    "focalisassions": "focaliser",
    "focalise": "focaliser",
    "focalisent": "focaliser",
    "focalisera": "focaliser",
    "focaliserai": "focaliser",
    "focaliseraient": "focaliser",
    "focaliserais": "focaliser",
    "focaliserait": "focaliser",
    "focaliseras": "focaliser",
    "focaliserez": "focaliser",
    "focaliseriez": "focaliser",
    "focaliserions": "focaliser",
    "focaliserons": "focaliser",
    "focaliseront": "focaliser",
    "focalises": "focaliser",
    "focalisez": "focaliser",
    "focalisiez": "focaliser",
    "focalisions": "focaliser",
    "focalisons": "focaliser",
    "focalisâmes": "focaliser",
    "focalisât": "focaliser",
    "focalisâtes": "focaliser",
    "focalisèrent": "focaliser",
    "focalisé": "focaliser",
    "focalisée": "focaliser",
    "focalisées": "focaliser",
    "focalisés": "focaliser",
    "focaux": "focal",
    "focs": "foc",
    "foehns": "foehn",
    "foetale": "foetal",
    "foetales": "foetal",
    "foetaux": "foetal",
    "fofolles": "fofolle",
    "foies": "foie",
    "foins": "foin",
    "foira": "foirer",
    "foirades": "foirade",
    "foiraient": "foirer",
    "foirails": "foirail",
    "foirais": "foirer",
    "foirait": "foirer",
    "foirals": "foiral",
    "foire": "foirer",
    "foirent": "foirer",
    "foirera": "foirer",
    "foires": "foirer",
    "foireuse": "foireux",
    "foireuses": "foireux",
    "foirez": "foirer",
    "foiré": "foirer",
    "foirée": "foirer",
    "foirées": "foirer",
    "foirés": "foirer",
    "fois": "foi",
    "foisonna": "foisonner",
    "foisonnai": "foisonner",
    "foisonnaient": "foisonner",
    "foisonnais": "foisonner",
    "foisonnait": "foisonner",
    "foisonnant": "foisonner",
    "foisonnante": "foisonnant",
    "foisonnantes": "foisonnant",
    "foisonnas": "foisonner",
    "foisonnasse": "foisonner",
    "foisonnassent": "foisonner",
    "foisonnasses": "foisonner",
    "foisonnassiez": "foisonner",
    "foisonnassions": "foisonner",
    "foisonne": "foisonner",
    "foisonnements": "foisonnement",
    "foisonnent": "foisonner",
    "foisonnera": "foisonner",
    "foisonnerai": "foisonner",
    "foisonneraient": "foisonner",
    "foisonnerais": "foisonner",
    "foisonnerait": "foisonner",
    "foisonneras": "foisonner",
    "foisonnerez": "foisonner",
    "foisonneriez": "foisonner",
    "foisonnerions": "foisonner",
    "foisonnerons": "foisonner",
    "foisonneront": "foisonner",
    "foisonnes": "foisonner",
    "foisonnez": "foisonner",
    "foisonniez": "foisonner",
    "foisonnions": "foisonner",
    "foisonnons": "foisonner",
    "foisonnâmes": "foisonner",
    "foisonnât": "foisonner",
    "foisonnâtes": "foisonner",
    "foisonnèrent": "foisonner",
    "foisonné": "foisonner",
    "fol": "fou",
    "foldingues": "foldingue",
    "foliacée": "foliacé",
    "folichonnait": "folichonner",
    "folichonne": "folichonner",
    "folichonneries": "folichonnerie",
    "folichonnes": "folichon",
    "folichons": "folichon",
    "folies": "folie",
    "folingues": "folingue",
    "folioles": "foliole",
    "folios": "folio",
    "foliota": "folioter",
    "foliotai": "folioter",
    "foliotaient": "folioter",
    "foliotais": "folioter",
    "foliotait": "folioter",
    "foliotant": "folioter",
    "foliotas": "folioter",
    "foliotasse": "folioter",
    "foliotassent": "folioter",
    "foliotasses": "folioter",
    "foliotassiez": "folioter",
    "foliotassions": "folioter",
    "foliote": "folioter",
    "foliotent": "folioter",
    "foliotera": "folioter",
    "folioterai": "folioter",
    "folioteraient": "folioter",
    "folioterais": "folioter",
    "folioterait": "folioter",
    "folioteras": "folioter",
    "folioterez": "folioter",
    "folioteriez": "folioter",
    "folioterions": "folioter",
    "folioterons": "folioter",
    "folioteront": "folioter",
    "foliotes": "folioter",
    "foliotez": "folioter",
    "foliotiez": "folioter",
    "foliotions": "folioter",
    "foliotons": "folioter",
    "foliotâmes": "folioter",
    "foliotât": "folioter",
    "foliotâtes": "folioter",
    "foliotèrent": "folioter",
    "folioté": "folioter",
    "foliotée": "folioter",
    "foliotées": "folioter",
    "foliotés": "folioter",
    "folklores": "folklore",
    "folkloriques": "folklorique",
    "folkloristes": "folkloriste",
    "folks": "folk",
    "folle": "fou",
    "folles": "fou",
    "follets": "follet",
    "follette": "follet",
    "follettes": "follet",
    "folliculaires": "folliculaire",
    "follicules": "follicule",
    "fols": "fol",
    "folâtraient": "folâtrer",
    "folâtrait": "folâtrer",
    "folâtre": "folâtrer",
    "folâtrent": "folâtrer",
    "folâtreries": "folâtrerie",
    "folâtres": "folâtre",
    "fomenta": "fomenter",
    "fomentai": "fomenter",
    "fomentaient": "fomenter",
    "fomentais": "fomenter",
    "fomentait": "fomenter",
    "fomentant": "fomenter",
    "fomentas": "fomenter",
    "fomentasse": "fomenter",
    "fomentassent": "fomenter",
    "fomentasses": "fomenter",
    "fomentassiez": "fomenter",
    "fomentassions": "fomenter",
    "fomentateurs": "fomentateur",
    "fomente": "fomenter",
    "fomentent": "fomenter",
    "fomentera": "fomenter",
    "fomenterai": "fomenter",
    "fomenteraient": "fomenter",
    "fomenterais": "fomenter",
    "fomenterait": "fomenter",
    "fomenteras": "fomenter",
    "fomenterez": "fomenter",
    "fomenteriez": "fomenter",
    "fomenterions": "fomenter",
    "fomenterons": "fomenter",
    "fomenteront": "fomenter",
    "fomentes": "fomenter",
    "fomentez": "fomenter",
    "fomentiez": "fomenter",
    "fomentions": "fomenter",
    "fomentons": "fomenter",
    "fomentâmes": "fomenter",
    "fomentât": "fomenter",
    "fomentâtes": "fomenter",
    "fomentèrent": "fomenter",
    "fomenté": "fomenter",
    "fomentée": "fomenter",
    "fomentées": "fomenter",
    "fomentés": "fomenter",
    "fonce": "foncer",
    "foncent": "foncer",
    "foncera": "foncer",
    "foncerai": "foncer",
    "fonceraient": "foncer",
    "foncerais": "foncer",
    "foncerait": "foncer",
    "fonceras": "foncer",
    "foncerez": "foncer",
    "fonceriez": "foncer",
    "foncerions": "foncer",
    "foncerons": "foncer",
    "fonceront": "foncer",
    "fonces": "foncer",
    "fonceurs": "fonceur",
    "fonceuse": "fonceur",
    "foncez": "foncer",
    "fonciers": "foncier",
    "fonciez": "foncer",
    "foncions": "foncer",
    "foncière": "foncier",
    "foncières": "foncier",
    "fonctionna": "fonctionner",
    "fonctionnai": "fonctionner",
    "fonctionnaient": "fonctionner",
    "fonctionnaires": "fonctionnaire",
    "fonctionnais": "fonctionner",
    "fonctionnait": "fonctionner",
    "fonctionnalités": "fonctionnalité",
    "fonctionnant": "fonctionner",
    "fonctionnarisations": "fonctionnarisation",
    "fonctionnarisé": "fonctionnariser",
    "fonctionnarisée": "fonctionnariser",
    "fonctionnas": "fonctionner",
    "fonctionnasse": "fonctionner",
    "fonctionnassent": "fonctionner",
    "fonctionnasses": "fonctionner",
    "fonctionnassiez": "fonctionner",
    "fonctionnassions": "fonctionner",
    "fonctionne": "fonctionner",
    "fonctionnelle": "fonctionnel",
    "fonctionnelles": "fonctionnel",
    "fonctionnels": "fonctionnel",
    "fonctionnements": "fonctionnement",
    "fonctionnent": "fonctionner",
    "fonctionnera": "fonctionner",
    "fonctionnerai": "fonctionner",
    "fonctionneraient": "fonctionner",
    "fonctionnerais": "fonctionner",
    "fonctionnerait": "fonctionner",
    "fonctionneras": "fonctionner",
    "fonctionnerez": "fonctionner",
    "fonctionneriez": "fonctionner",
    "fonctionnerions": "fonctionner",
    "fonctionnerons": "fonctionner",
    "fonctionneront": "fonctionner",
    "fonctionnes": "fonctionner",
    "fonctionnez": "fonctionner",
    "fonctionniez": "fonctionner",
    "fonctionnions": "fonctionner",
    "fonctionnons": "fonctionner",
    "fonctionnâmes": "fonctionner",
    "fonctionnât": "fonctionner",
    "fonctionnâtes": "fonctionner",
    "fonctionnèrent": "fonctionner",
    "fonctionné": "fonctionner",
    "fonctions": "fonction",
    "foncèrent": "foncer",
    "foncé": "foncer",
    "foncée": "foncer",
    "foncées": "foncer",
    "foncés": "foncer",
    "fond": "fondre",
    "fonda": "fonder",
    "fondai": "fonder",
    "fondaient": "fondre",
    "fondais": "fondre",
    "fondait": "fondre",
    "fondamentale": "fondamental",
    "fondamentales": "fondamental",
    "fondamentalismes": "fondamentalisme",
    "fondamentalistes": "fondamentaliste",
    "fondamentaux": "fondamental",
    "fondant": "fondre",
    "fondante": "fondant",
    "fondantes": "fondant",
    "fondants": "fondant",
    "fondas": "fonder",
    "fondasse": "fonder",
    "fondassent": "fonder",
    "fondasses": "fonder",
    "fondassiez": "fonder",
    "fondassions": "fonder",
    "fondateurs": "fondateur",
    "fondations": "fondation",
    "fondatrice": "fondateur",
    "fondatrices": "fondateur",
    "fonde": "fondre",
    "fondements": "fondement",
    "fondent": "fondre",
    "fondera": "fonder",
    "fonderai": "fonder",
    "fonderaient": "fonder",
    "fonderais": "fonder",
    "fonderait": "fonder",
    "fonderas": "fonder",
    "fonderez": "fonder",
    "fonderies": "fonderie",
    "fonderiez": "fonder",
    "fonderions": "fonder",
    "fonderons": "fonder",
    "fonderont": "fonder",
    "fondes": "fondre",
    "fondez": "fondre",
    "fondiez": "fondre",
    "fondions": "fondre",
    "fondirent": "fondre",
    "fondis": "fondre",
    "fondisse": "fondre",
    "fondissent": "fondre",
    "fondisses": "fondre",
    "fondissiez": "fondre",
    "fondissions": "fondre",
    "fondit": "fondre",
    "fondons": "fondre",
    "fondra": "fondre",
    "fondrai": "fondre",
    "fondraient": "fondre",
    "fondrais": "fondre",
    "fondrait": "fondre",
    "fondras": "fondre",
    "fondrez": "fondre",
    "fondriez": "fondre",
    "fondrions": "fondre",
    "fondrières": "fondrière",
    "fondrons": "fondre",
    "fondront": "fondre",
    "fonds": "fondre",
    "fondu": "fondre",
    "fondue": "fondre",
    "fondues": "fondue",
    "fondus": "fondu",
    "fondâmes": "fonder",
    "fondât": "fonder",
    "fondâtes": "fonder",
    "fondèrent": "fonder",
    "fondé": "fonder",
    "fondée": "fonder",
    "fondées": "fonder",
    "fondés": "fonder",
    "fondîmes": "fondre",
    "fondît": "fondre",
    "fondîtes": "fondre",
    "fongueuse": "fongueux",
    "fongueuses": "fongueux",
    "font": "faire",
    "fontaines": "fontaine",
    "fontanelle": "fontanel",
    "fontanelles": "fontanelle",
    "fontanges": "fontange",
    "fontes": "fonte",
    "fonça": "foncer",
    "fonçai": "foncer",
    "fonçaient": "foncer",
    "fonçais": "foncer",
    "fonçait": "foncer",
    "fonçant": "foncer",
    "fonças": "foncer",
    "fonçasse": "foncer",
    "fonçassent": "foncer",
    "fonçasses": "foncer",
    "fonçassiez": "foncer",
    "fonçassions": "foncer",
    "fonçons": "foncer",
    "fonçâmes": "foncer",
    "fonçât": "foncer",
    "fonçâtes": "foncer",
    "footballeurs": "footballeur",
    "footballeuse": "footballeur",
    "footballistiques": "footballistique",
    "footballs": "football",
    "footeuse": "footeux",
    "footings": "footing",
    "foots": "foot",
    "fora": "forer",
    "forages": "forage",
    "forai": "forer",
    "foraient": "forer",
    "foraine": "forain",
    "foraines": "forain",
    "forains": "forain",
    "forais": "forer",
    "forait": "forer",
    "foraminifères": "foraminifère",
    "forant": "forer",
    "foras": "forer",
    "forasse": "forer",
    "forassent": "forer",
    "forasses": "forer",
    "forassiez": "forer",
    "forassions": "forer",
    "forbans": "forban",
    "force": "forcer",
    "forcent": "forcer",
    "forcenée": "forcené",
    "forcenées": "forcené",
    "forcenés": "forcené",
    "forcera": "forcer",
    "forcerai": "forcer",
    "forceraient": "forcer",
    "forcerais": "forcer",
    "forcerait": "forcer",
    "forceras": "forcer",
    "forcerez": "forcer",
    "forceriez": "forcer",
    "forcerions": "forcer",
    "forcerons": "forcer",
    "forceront": "forcer",
    "forces": "forcer",
    "forceurs": "forceur",
    "forcez": "forcer",
    "forci": "forcir",
    "forcie": "forcir",
    "forcies": "forcir",
    "forciez": "forcer",
    "forcings": "forcing",
    "forcions": "forcer",
    "forcira": "forcir",
    "forcirai": "forcir",
    "forciraient": "forcir",
    "forcirais": "forcir",
    "forcirait": "forcir",
    "forciras": "forcir",
    "forcirent": "forcir",
    "forcirez": "forcir",
    "forciriez": "forcir",
    "forcirions": "forcir",
    "forcirons": "forcir",
    "forciront": "forcir",
    "forcis": "forcir",
    "forcissaient": "forcir",
    "forcissais": "forcir",
    "forcissait": "forcir",
    "forcissant": "forcir",
    "forcisse": "forcir",
    "forcissent": "forcir",
    "forcisses": "forcir",
    "forcissez": "forcir",
    "forcissiez": "forcir",
    "forcissions": "forcir",
    "forcissons": "forcir",
    "forcit": "forcir",
    "forclose": "forclos",
    "forcloses": "forclos",
    "forclusions": "forclusion",
    "forcèrent": "forcer",
    "forcé": "forcer",
    "forcée": "forcer",
    "forcées": "forcer",
    "forcés": "forcer",
    "forcîmes": "forcir",
    "forcît": "forcir",
    "forcîtes": "forcir",
    "fore": "forer",
    "forent": "forer",
    "forera": "forer",
    "forerai": "forer",
    "foreraient": "forer",
    "forerais": "forer",
    "forerait": "forer",
    "foreras": "forer",
    "forerez": "forer",
    "foreriez": "forer",
    "forerions": "forer",
    "forerons": "forer",
    "foreront": "forer",
    "fores": "forer",
    "forestiers": "forestier",
    "forestière": "forestier",
    "forestières": "forestier",
    "forets": "foret",
    "foreurs": "foreur",
    "foreuse": "foreur",
    "foreuses": "foreur",
    "forez": "forer",
    "forfait": "forfaire",
    "forfaitaires": "forfaitaire",
    "forfaite": "forfaire",
    "forfaites": "forfaire",
    "forfaits": "forfait",
    "forfanteries": "forfanterie",
    "forficules": "forficule",
    "forge": "forger",
    "forgea": "forger",
    "forgeai": "forger",
    "forgeaient": "forger",
    "forgeais": "forger",
    "forgeait": "forger",
    "forgeant": "forger",
    "forgeas": "forger",
    "forgeasse": "forger",
    "forgeassent": "forger",
    "forgeasses": "forger",
    "forgeassiez": "forger",
    "forgeassions": "forger",
    "forgent": "forger",
    "forgeons": "forger",
    "forgera": "forger",
    "forgerai": "forger",
    "forgeraient": "forger",
    "forgerais": "forger",
    "forgerait": "forger",
    "forgeras": "forger",
    "forgerez": "forger",
    "forgeries": "forgerie",
    "forgeriez": "forger",
    "forgerions": "forger",
    "forgeronne": "forgeron",
    "forgerons": "forgeron",
    "forgeront": "forger",
    "forges": "forger",
    "forgez": "forger",
    "forgeâmes": "forger",
    "forgeât": "forger",
    "forgeâtes": "forger",
    "forgiez": "forger",
    "forgions": "forger",
    "forgèrent": "forger",
    "forgé": "forger",
    "forgée": "forger",
    "forgées": "forger",
    "forgés": "forger",
    "foriez": "forer",
    "forints": "forint",
    "forions": "forer",
    "forjeta": "forjeter",
    "forjetai": "forjeter",
    "forjetaient": "forjeter",
    "forjetais": "forjeter",
    "forjetait": "forjeter",
    "forjetant": "forjeter",
    "forjetas": "forjeter",
    "forjetasse": "forjeter",
    "forjetassent": "forjeter",
    "forjetasses": "forjeter",
    "forjetassiez": "forjeter",
    "forjetassions": "forjeter",
    "forjetez": "forjeter",
    "forjetiez": "forjeter",
    "forjetions": "forjeter",
    "forjetons": "forjeter",
    "forjette": "forjeter",
    "forjettent": "forjeter",
    "forjettera": "forjeter",
    "forjetterai": "forjeter",
    "forjetteraient": "forjeter",
    "forjetterais": "forjeter",
    "forjetterait": "forjeter",
    "forjetteras": "forjeter",
    "forjetterez": "forjeter",
    "forjetteriez": "forjeter",
    "forjetterions": "forjeter",
    "forjetterons": "forjeter",
    "forjetteront": "forjeter",
    "forjettes": "forjeter",
    "forjetâmes": "forjeter",
    "forjetât": "forjeter",
    "forjetâtes": "forjeter",
    "forjetèrent": "forjeter",
    "forjeté": "forjeter",
    "forjetée": "forjeter",
    "forjetées": "forjeter",
    "forjetés": "forjeter",
    "forlance": "forlancer",
    "forlancent": "forlancer",
    "forlancera": "forlancer",
    "forlancerai": "forlancer",
    "forlanceraient": "forlancer",
    "forlancerais": "forlancer",
    "forlancerait": "forlancer",
    "forlanceras": "forlancer",
    "forlancerez": "forlancer",
    "forlanceriez": "forlancer",
    "forlancerions": "forlancer",
    "forlancerons": "forlancer",
    "forlanceront": "forlancer",
    "forlances": "forlancer",
    "forlancez": "forlancer",
    "forlanciez": "forlancer",
    "forlancions": "forlancer",
    "forlancèrent": "forlancer",
    "forlancé": "forlancer",
    "forlancée": "forlancer",
    "forlancées": "forlancer",
    "forlancés": "forlancer",
    "forlança": "forlancer",
    "forlançai": "forlancer",
    "forlançaient": "forlancer",
    "forlançais": "forlancer",
    "forlançait": "forlancer",
    "forlançant": "forlancer",
    "forlanças": "forlancer",
    "forlançasse": "forlancer",
    "forlançassent": "forlancer",
    "forlançasses": "forlancer",
    "forlançassiez": "forlancer",
    "forlançassions": "forlancer",
    "forlançons": "forlancer",
    "forlançâmes": "forlancer",
    "forlançât": "forlancer",
    "forlançâtes": "forlancer",
    "forlonge": "forlonger",
    "forlongea": "forlonger",
    "forlongeai": "forlonger",
    "forlongeaient": "forlonger",
    "forlongeais": "forlonger",
    "forlongeait": "forlonger",
    "forlongeant": "forlonger",
    "forlongeas": "forlonger",
    "forlongeasse": "forlonger",
    "forlongeassent": "forlonger",
    "forlongeasses": "forlonger",
    "forlongeassiez": "forlonger",
    "forlongeassions": "forlonger",
    "forlongent": "forlonger",
    "forlongeons": "forlonger",
    "forlongera": "forlonger",
    "forlongerai": "forlonger",
    "forlongeraient": "forlonger",
    "forlongerais": "forlonger",
    "forlongerait": "forlonger",
    "forlongeras": "forlonger",
    "forlongerez": "forlonger",
    "forlongeriez": "forlonger",
    "forlongerions": "forlonger",
    "forlongerons": "forlonger",
    "forlongeront": "forlonger",
    "forlonges": "forlonger",
    "forlongez": "forlonger",
    "forlongeâmes": "forlonger",
    "forlongeât": "forlonger",
    "forlongeâtes": "forlonger",
    "forlongiez": "forlonger",
    "forlongions": "forlonger",
    "forlongèrent": "forlonger",
    "forlongé": "forlonger",
    "forlongée": "forlonger",
    "forlongées": "forlonger",
    "forlongés": "forlonger",
    "forma": "former",
    "formai": "former",
    "formaient": "former",
    "formais": "former",
    "formait": "former",
    "formaldéhydes": "formaldéhyde",
    "formalisa": "formaliser",
    "formalisai": "formaliser",
    "formalisaient": "formaliser",
    "formalisais": "formaliser",
    "formalisait": "formaliser",
    "formalisant": "formaliser",
    "formalisas": "formaliser",
    "formalisasse": "formaliser",
    "formalisassent": "formaliser",
    "formalisasses": "formaliser",
    "formalisassiez": "formaliser",
    "formalisassions": "formaliser",
    "formalise": "formaliser",
    "formalisent": "formaliser",
    "formalisera": "formaliser",
    "formaliserai": "formaliser",
    "formaliseraient": "formaliser",
    "formaliserais": "formaliser",
    "formaliserait": "formaliser",
    "formaliseras": "formaliser",
    "formaliserez": "formaliser",
    "formaliseriez": "formaliser",
    "formaliserions": "formaliser",
    "formaliserons": "formaliser",
    "formaliseront": "formaliser",
    "formalises": "formaliser",
    "formalisez": "formaliser",
    "formalisiez": "formaliser",
    "formalisions": "formaliser",
    "formalismes": "formalisme",
    "formalisons": "formaliser",
    "formalistes": "formaliste",
    "formalisâmes": "formaliser",
    "formalisât": "formaliser",
    "formalisâtes": "formaliser",
    "formalisèrent": "formaliser",
    "formalisé": "formaliser",
    "formalisée": "formaliser",
    "formalisées": "formaliser",
    "formalisés": "formaliser",
    "formalités": "formalité",
    "formant": "former",
    "formas": "former",
    "formasse": "former",
    "formassent": "former",
    "formasses": "former",
    "formassiez": "former",
    "formassions": "former",
    "formateurs": "formateur",
    "formatifs": "formatif",
    "formations": "formation",
    "formative": "formatif",
    "formatives": "formatif",
    "formatrice": "formateur",
    "formatrices": "formateur",
    "formats": "format",
    "formaté": "formater",
    "forme": "former",
    "formelle": "formel",
    "formelles": "formel",
    "formels": "formel",
    "forment": "former",
    "formera": "former",
    "formerai": "former",
    "formeraient": "former",
    "formerais": "former",
    "formerait": "former",
    "formeras": "former",
    "formerets": "formeret",
    "formerez": "former",
    "formeriez": "former",
    "formerions": "former",
    "formerons": "former",
    "formeront": "former",
    "formes": "former",
    "formez": "former",
    "formicas": "formica",
    "formications": "formication",
    "formidables": "formidable",
    "formides": "formide",
    "formids": "formid",
    "formiez": "former",
    "formions": "former",
    "formols": "formol",
    "formons": "former",
    "formula": "formuler",
    "formulai": "formuler",
    "formulaient": "formuler",
    "formulaires": "formulaire",
    "formulais": "formuler",
    "formulait": "formuler",
    "formulant": "formuler",
    "formulas": "formuler",
    "formulasse": "formuler",
    "formulassent": "formuler",
    "formulasses": "formuler",
    "formulassiez": "formuler",
    "formulassions": "formuler",
    "formulations": "formulation",
    "formule": "formuler",
    "formulent": "formuler",
    "formulera": "formuler",
    "formulerai": "formuler",
    "formuleraient": "formuler",
    "formulerais": "formuler",
    "formulerait": "formuler",
    "formuleras": "formuler",
    "formulerez": "formuler",
    "formuleriez": "formuler",
    "formulerions": "formuler",
    "formulerons": "formuler",
    "formuleront": "formuler",
    "formules": "formuler",
    "formulettes": "formulette",
    "formulez": "formuler",
    "formuliez": "formuler",
    "formulions": "formuler",
    "formulons": "formuler",
    "formulâmes": "formuler",
    "formulât": "formuler",
    "formulâtes": "formuler",
    "formulèrent": "formuler",
    "formulé": "formuler",
    "formulée": "formuler",
    "formulées": "formuler",
    "formulés": "formuler",
    "formâmes": "former",
    "formât": "former",
    "formâtes": "former",
    "formèrent": "former",
    "formé": "former",
    "formée": "former",
    "formées": "former",
    "formés": "former",
    "fornicateurs": "fornicateur",
    "fornications": "fornication",
    "fornicatrice": "fornicateur",
    "forniqua": "forniquer",
    "forniquai": "forniquer",
    "forniquaient": "forniquer",
    "forniquais": "forniquer",
    "forniquait": "forniquer",
    "forniquant": "forniquer",
    "forniquas": "forniquer",
    "forniquasse": "forniquer",
    "forniquassent": "forniquer",
    "forniquasses": "forniquer",
    "forniquassiez": "forniquer",
    "forniquassions": "forniquer",
    "fornique": "forniquer",
    "forniquent": "forniquer",
    "forniquera": "forniquer",
    "forniquerai": "forniquer",
    "forniqueraient": "forniquer",
    "forniquerais": "forniquer",
    "forniquerait": "forniquer",
    "forniqueras": "forniquer",
    "forniquerez": "forniquer",
    "forniqueriez": "forniquer",
    "forniquerions": "forniquer",
    "forniquerons": "forniquer",
    "forniqueront": "forniquer",
    "forniques": "forniquer",
    "forniquez": "forniquer",
    "forniquiez": "forniquer",
    "forniquions": "forniquer",
    "forniquons": "forniquer",
    "forniquâmes": "forniquer",
    "forniquât": "forniquer",
    "forniquâtes": "forniquer",
    "forniquèrent": "forniquer",
    "forniqué": "forniquer",
    "forniquée": "forniquer",
    "forniquées": "forniquer",
    "forniqués": "forniquer",
    "forons": "forer",
    "forsythias": "forsythia",
    "forte": "fort",
    "forte-pianos": "forte-piano",
    "forteresses": "forteresse",
    "fortes": "fort",
    "fortiches": "fortiche",
    "fortifia": "fortifier",
    "fortifiai": "fortifier",
    "fortifiaient": "fortifier",
    "fortifiais": "fortifier",
    "fortifiait": "fortifier",
    "fortifiant": "fortifier",
    "fortifiants": "fortifiant",
    "fortifias": "fortifier",
    "fortifiasse": "fortifier",
    "fortifiassent": "fortifier",
    "fortifiasses": "fortifier",
    "fortifiassiez": "fortifier",
    "fortifiassions": "fortifier",
    "fortifications": "fortification",
    "fortifie": "fortifier",
    "fortifient": "fortifier",
    "fortifiera": "fortifier",
    "fortifierai": "fortifier",
    "fortifieraient": "fortifier",
    "fortifierais": "fortifier",
    "fortifierait": "fortifier",
    "fortifieras": "fortifier",
    "fortifierez": "fortifier",
    "fortifieriez": "fortifier",
    "fortifierions": "fortifier",
    "fortifierons": "fortifier",
    "fortifieront": "fortifier",
    "fortifies": "fortifier",
    "fortifiez": "fortifier",
    "fortifiiez": "fortifier",
    "fortifiions": "fortifier",
    "fortifions": "fortifier",
    "fortifiâmes": "fortifier",
    "fortifiât": "fortifier",
    "fortifiâtes": "fortifier",
    "fortifièrent": "fortifier",
    "fortifié": "fortifier",
    "fortifiée": "fortifier",
    "fortifiées": "fortifier",
    "fortifiés": "fortifier",
    "fortifs": "fortif",
    "fortins": "fortin",
    "forts": "fort",
    "fortuite": "fortuit",
    "fortuites": "fortuit",
    "fortuits": "fortuit",
    "fortunes": "fortune",
    "fortunée": "fortuné",
    "fortunées": "fortuné",
    "fortunés": "fortuné",
    "forums": "forum",
    "forâmes": "forer",
    "forât": "forer",
    "forâtes": "forer",
    "força": "forcer",
    "forçai": "forcer",
    "forçaient": "forcer",
    "forçais": "forcer",
    "forçait": "forcer",
    "forçant": "forcer",
    "forças": "forcer",
    "forçasse": "forcer",
    "forçassent": "forcer",
    "forçasses": "forcer",
    "forçassiez": "forcer",
    "forçassions": "forcer",
    "forçats": "forçat",
    "forçons": "forcer",
    "forçâmes": "forcer",
    "forçât": "forcer",
    "forçâtes": "forcer",
    "forèrent": "forer",
    "foré": "forer",
    "forée": "forer",
    "forées": "forer",
    "forés": "forer",
    "forêts": "forêt",
    "fosses": "fosse",
    "fossettes": "fossette",
    "fossiles": "fossile",
    "fossilisé": "fossiliser",
    "fossilisés": "fossiliser",
    "fossoyeurs": "fossoyeur",
    "fossés": "fossé",
    "fouaces": "fouace",
    "fouailla": "fouailler",
    "fouaillai": "fouailler",
    "fouaillaient": "fouailler",
    "fouaillais": "fouailler",
    "fouaillait": "fouailler",
    "fouaillant": "fouailler",
    "fouaillas": "fouailler",
    "fouaillasse": "fouailler",
    "fouaillassent": "fouailler",
    "fouaillasses": "fouailler",
    "fouaillassiez": "fouailler",
    "fouaillassions": "fouailler",
    "fouaille": "fouailler",
    "fouaillent": "fouailler",
    "fouaillera": "fouailler",
    "fouaillerai": "fouailler",
    "fouailleraient": "fouailler",
    "fouaillerais": "fouailler",
    "fouaillerait": "fouailler",
    "fouailleras": "fouailler",
    "fouaillerez": "fouailler",
    "fouailleriez": "fouailler",
    "fouaillerions": "fouailler",
    "fouaillerons": "fouailler",
    "fouailleront": "fouailler",
    "fouailles": "fouailler",
    "fouaillez": "fouailler",
    "fouailliez": "fouailler",
    "fouaillions": "fouailler",
    "fouaillons": "fouailler",
    "fouaillâmes": "fouailler",
    "fouaillât": "fouailler",
    "fouaillâtes": "fouailler",
    "fouaillèrent": "fouailler",
    "fouaillé": "fouailler",
    "fouaillée": "fouailler",
    "fouaillées": "fouailler",
    "fouaillés": "fouailler",
    "foucades": "foucade",
    "foudres": "foudre",
    "foudroie": "foudroyer",
    "foudroiements": "foudroiement",
    "foudroient": "foudroyer",
    "foudroiera": "foudroyer",
    "foudroierai": "foudroyer",
    "foudroieraient": "foudroyer",
    "foudroierais": "foudroyer",
    "foudroierait": "foudroyer",
    "foudroieras": "foudroyer",
    "foudroierez": "foudroyer",
    "foudroieriez": "foudroyer",
    "foudroierions": "foudroyer",
    "foudroierons": "foudroyer",
    "foudroieront": "foudroyer",
    "foudroies": "foudroyer",
    "foudroya": "foudroyer",
    "foudroyai": "foudroyer",
    "foudroyaient": "foudroyer",
    "foudroyais": "foudroyer",
    "foudroyait": "foudroyer",
    "foudroyant": "foudroyer",
    "foudroyante": "foudroyant",
    "foudroyantes": "foudroyant",
    "foudroyants": "foudroyant",
    "foudroyas": "foudroyer",
    "foudroyasse": "foudroyer",
    "foudroyassent": "foudroyer",
    "foudroyasses": "foudroyer",
    "foudroyassiez": "foudroyer",
    "foudroyassions": "foudroyer",
    "foudroyez": "foudroyer",
    "foudroyiez": "foudroyer",
    "foudroyions": "foudroyer",
    "foudroyons": "foudroyer",
    "foudroyâmes": "foudroyer",
    "foudroyât": "foudroyer",
    "foudroyâtes": "foudroyer",
    "foudroyèrent": "foudroyer",
    "foudroyé": "foudroyer",
    "foudroyée": "foudroyer",
    "foudroyées": "foudroyer",
    "foudroyés": "foudroyer",
    "fouets": "fouet",
    "fouetta": "fouetter",
    "fouettai": "fouetter",
    "fouettaient": "fouetter",
    "fouettais": "fouetter",
    "fouettait": "fouetter",
    "fouettant": "fouetter",
    "fouettards": "fouettard",
    "fouettas": "fouetter",
    "fouettasse": "fouetter",
    "fouettassent": "fouetter",
    "fouettasses": "fouetter",
    "fouettassiez": "fouetter",
    "fouettassions": "fouetter",
    "fouette": "fouetter",
    "fouettements": "fouettement",
    "fouettent": "fouetter",
    "fouettera": "fouetter",
    "fouetterai": "fouetter",
    "fouetteraient": "fouetter",
    "fouetterais": "fouetter",
    "fouetterait": "fouetter",
    "fouetteras": "fouetter",
    "fouetterez": "fouetter",
    "fouetteriez": "fouetter",
    "fouetterions": "fouetter",
    "fouetterons": "fouetter",
    "fouetteront": "fouetter",
    "fouettes": "fouetter",
    "fouetteurs": "fouetteur",
    "fouetteuse": "fouetteur",
    "fouettez": "fouetter",
    "fouettiez": "fouetter",
    "fouettions": "fouetter",
    "fouettons": "fouetter",
    "fouettâmes": "fouetter",
    "fouettât": "fouetter",
    "fouettâtes": "fouetter",
    "fouettèrent": "fouetter",
    "fouetté": "fouetter",
    "fouettée": "fouetter",
    "fouettées": "fouetter",
    "fouettés": "fouetter",
    "foufounes": "foufoune",
    "foufous": "foufou",
    "fougasses": "fougasse",
    "fouge": "fouger",
    "fougeraies": "fougeraie",
    "fougues": "fougue",
    "fougueuse": "fougueux",
    "fougueuses": "fougueux",
    "fougères": "fougère",
    "foui": "fouir",
    "fouie": "fouir",
    "fouies": "fouir",
    "fouilla": "fouiller",
    "fouillai": "fouiller",
    "fouillaient": "fouiller",
    "fouillais": "fouiller",
    "fouillait": "fouiller",
    "fouillant": "fouiller",
    "fouillas": "fouiller",
    "fouillasse": "fouiller",
    "fouillassent": "fouiller",
    "fouillasses": "fouiller",
    "fouillassiez": "fouiller",
    "fouillassions": "fouiller",
    "fouille": "fouiller",
    "fouillent": "fouiller",
    "fouillera": "fouiller",
    "fouillerai": "fouiller",
    "fouilleraient": "fouiller",
    "fouillerais": "fouiller",
    "fouillerait": "fouiller",
    "fouilleras": "fouiller",
    "fouillerez": "fouiller",
    "fouilleriez": "fouiller",
    "fouillerions": "fouiller",
    "fouillerons": "fouiller",
    "fouilleront": "fouiller",
    "fouilles": "fouiller",
    "fouilleurs": "fouilleur",
    "fouilleuse": "fouilleur",
    "fouillez": "fouiller",
    "fouilliez": "fouiller",
    "fouillions": "fouiller",
    "fouillons": "fouiller",
    "fouillâmes": "fouiller",
    "fouillât": "fouiller",
    "fouillâtes": "fouiller",
    "fouillèrent": "fouiller",
    "fouillé": "fouiller",
    "fouillée": "fouiller",
    "fouillées": "fouiller",
    "fouillés": "fouiller",
    "fouina": "fouiner",
    "fouinai": "fouiner",
    "fouinaient": "fouiner",
    "fouinais": "fouiner",
    "fouinait": "fouiner",
    "fouinant": "fouiner",
    "fouinards": "fouinard",
    "fouinas": "fouiner",
    "fouinasse": "fouiner",
    "fouinassent": "fouiner",
    "fouinasses": "fouiner",
    "fouinassiez": "fouiner",
    "fouinassions": "fouiner",
    "fouine": "fouiner",
    "fouinent": "fouiner",
    "fouinera": "fouiner",
    "fouinerai": "fouiner",
    "fouineraient": "fouiner",
    "fouinerais": "fouiner",
    "fouinerait": "fouiner",
    "fouineras": "fouiner",
    "fouinerez": "fouiner",
    "fouineriez": "fouiner",
    "fouinerions": "fouiner",
    "fouinerons": "fouiner",
    "fouineront": "fouiner",
    "fouines": "fouiner",
    "fouineurs": "fouineur",
    "fouineuse": "fouineur",
    "fouineuses": "fouineur",
    "fouinez": "fouiner",
    "fouiniez": "fouiner",
    "fouinions": "fouiner",
    "fouinons": "fouiner",
    "fouinâmes": "fouiner",
    "fouinât": "fouiner",
    "fouinâtes": "fouiner",
    "fouinèrent": "fouiner",
    "fouiné": "fouiner",
    "fouira": "fouir",
    "fouirai": "fouir",
    "fouiraient": "fouir",
    "fouirais": "fouir",
    "fouirait": "fouir",
    "fouiras": "fouir",
    "fouirent": "fouir",
    "fouirez": "fouir",
    "fouiriez": "fouir",
    "fouirions": "fouir",
    "fouirons": "fouir",
    "fouiront": "fouir",
    "fouis": "fouir",
    "fouissaient": "fouir",
    "fouissais": "fouir",
    "fouissait": "fouir",
    "fouissant": "fouir",
    "fouisse": "fouir",
    "fouissent": "fouir",
    "fouisses": "fouir",
    "fouisseurs": "fouisseur",
    "fouisseuse": "fouisseur",
    "fouisseuses": "fouisseur",
    "fouissez": "fouir",
    "fouissiez": "fouir",
    "fouissions": "fouir",
    "fouissons": "fouir",
    "fouit": "fouir",
    "foula": "fouler",
    "foulai": "fouler",
    "foulaient": "fouler",
    "foulais": "fouler",
    "foulait": "fouler",
    "foulant": "fouler",
    "foulards": "foulard",
    "foulas": "fouler",
    "foulasse": "fouler",
    "foulassent": "fouler",
    "foulasses": "fouler",
    "foulassiez": "fouler",
    "foulassions": "fouler",
    "foule": "fouler",
    "foulent": "fouler",
    "foulera": "fouler",
    "foulerai": "fouler",
    "fouleraient": "fouler",
    "foulerais": "fouler",
    "foulerait": "fouler",
    "fouleras": "fouler",
    "foulerez": "fouler",
    "fouleriez": "fouler",
    "foulerions": "fouler",
    "foulerons": "fouler",
    "fouleront": "fouler",
    "foules": "fouler",
    "foulez": "fouler",
    "fouliez": "fouler",
    "foulions": "fouler",
    "foulons": "fouler",
    "foulques": "foulque",
    "foulures": "foulure",
    "foulâmes": "fouler",
    "foulât": "fouler",
    "foulâtes": "fouler",
    "foulèrent": "fouler",
    "foulé": "fouler",
    "foulée": "fouler",
    "foulées": "fouler",
    "foulés": "fouler",
    "fourbais": "fourber",
    "fourberies": "fourberie",
    "fourbes": "fourbe",
    "fourbi": "fourbir",
    "fourbie": "fourbir",
    "fourbies": "fourbir",
    "fourbira": "fourbir",
    "fourbirai": "fourbir",
    "fourbiraient": "fourbir",
    "fourbirais": "fourbir",
    "fourbirait": "fourbir",
    "fourbiras": "fourbir",
    "fourbirent": "fourbir",
    "fourbirez": "fourbir",
    "fourbiriez": "fourbir",
    "fourbirions": "fourbir",
    "fourbirons": "fourbir",
    "fourbiront": "fourbir",
    "fourbis": "fourbir",
    "fourbissaient": "fourbir",
    "fourbissais": "fourbir",
    "fourbissait": "fourbir",
    "fourbissant": "fourbir",
    "fourbisse": "fourbir",
    "fourbissent": "fourbir",
    "fourbisses": "fourbir",
    "fourbissez": "fourbir",
    "fourbissiez": "fourbir",
    "fourbissions": "fourbir",
    "fourbissons": "fourbir",
    "fourbit": "fourbir",
    "fourbue": "fourbu",
    "fourbues": "fourbu",
    "fourbus": "fourbu",
    "fourbîmes": "fourbir",
    "fourbît": "fourbir",
    "fourbîtes": "fourbir",
    "fourcha": "fourcher",
    "fourche": "fourcher",
    "fourchent": "fourcher",
    "fourches": "fourche",
    "fourchets": "fourchet",
    "fourchettes": "fourchette",
    "fourchez": "fourcher",
    "fourchue": "fourchu",
    "fourchues": "fourchu",
    "fourchures": "fourchure",
    "fourchus": "fourchu",
    "fourché": "fourcher",
    "fourchée": "fourcher",
    "fourgonna": "fourgonner",
    "fourgonnai": "fourgonner",
    "fourgonnaient": "fourgonner",
    "fourgonnais": "fourgonner",
    "fourgonnait": "fourgonner",
    "fourgonnant": "fourgonner",
    "fourgonnas": "fourgonner",
    "fourgonnasse": "fourgonner",
    "fourgonnassent": "fourgonner",
    "fourgonnasses": "fourgonner",
    "fourgonnassiez": "fourgonner",
    "fourgonnassions": "fourgonner",
    "fourgonne": "fourgonner",
    "fourgonnent": "fourgonner",
    "fourgonnera": "fourgonner",
    "fourgonnerai": "fourgonner",
    "fourgonneraient": "fourgonner",
    "fourgonnerais": "fourgonner",
    "fourgonnerait": "fourgonner",
    "fourgonneras": "fourgonner",
    "fourgonnerez": "fourgonner",
    "fourgonneriez": "fourgonner",
    "fourgonnerions": "fourgonner",
    "fourgonnerons": "fourgonner",
    "fourgonneront": "fourgonner",
    "fourgonnes": "fourgonner",
    "fourgonnettes": "fourgonnette",
    "fourgonnez": "fourgonner",
    "fourgonniez": "fourgonner",
    "fourgonnions": "fourgonner",
    "fourgonnons": "fourgonner",
    "fourgonnâmes": "fourgonner",
    "fourgonnât": "fourgonner",
    "fourgonnâtes": "fourgonner",
    "fourgonnèrent": "fourgonner",
    "fourgonné": "fourgonner",
    "fourgons": "fourgon",
    "fourgons-pompes": "fourgon-pompe",
    "fourguais": "fourguer",
    "fourguait": "fourguer",
    "fourguant": "fourguer",
    "fourgue": "fourguer",
    "fourguent": "fourguer",
    "fourgueraient": "fourguer",
    "fourguerais": "fourguer",
    "fourguerait": "fourguer",
    "fourgues": "fourguer",
    "fourguez": "fourguer",
    "fourgué": "fourguer",
    "fourguée": "fourguer",
    "fourguées": "fourguer",
    "fourgués": "fourguer",
    "fourmes": "fourme",
    "fourmiliers": "fourmilier",
    "fourmilions": "fourmilion",
    "fourmilière": "fourmilier",
    "fourmilières": "fourmilière",
    "fourmilla": "fourmiller",
    "fourmillai": "fourmiller",
    "fourmillaient": "fourmiller",
    "fourmillais": "fourmiller",
    "fourmillait": "fourmiller",
    "fourmillant": "fourmiller",
    "fourmillante": "fourmillant",
    "fourmillantes": "fourmillant",
    "fourmillants": "fourmillant",
    "fourmillas": "fourmiller",
    "fourmillasse": "fourmiller",
    "fourmillassent": "fourmiller",
    "fourmillasses": "fourmiller",
    "fourmillassiez": "fourmiller",
    "fourmillassions": "fourmiller",
    "fourmille": "fourmiller",
    "fourmillements": "fourmillement",
    "fourmillent": "fourmiller",
    "fourmillera": "fourmiller",
    "fourmillerai": "fourmiller",
    "fourmilleraient": "fourmiller",
    "fourmillerais": "fourmiller",
    "fourmillerait": "fourmiller",
    "fourmilleras": "fourmiller",
    "fourmillerez": "fourmiller",
    "fourmilleriez": "fourmiller",
    "fourmillerions": "fourmiller",
    "fourmillerons": "fourmiller",
    "fourmilleront": "fourmiller",
    "fourmilles": "fourmiller",
    "fourmillez": "fourmiller",
    "fourmilliez": "fourmiller",
    "fourmillions": "fourmiller",
    "fourmillons": "fourmiller",
    "fourmillâmes": "fourmiller",
    "fourmillât": "fourmiller",
    "fourmillâtes": "fourmiller",
    "fourmillèrent": "fourmiller",
    "fourmillé": "fourmiller",
    "fourmis": "fourmi",
    "fourmis-lions": "fourmi-lion",
    "fournaises": "fournaise",
    "fourneaux": "fourneau",
    "fourni": "fournir",
    "fournie": "fournir",
    "fournies": "fournir",
    "fournils": "fournil",
    "fourniments": "fourniment",
    "fournira": "fournir",
    "fournirai": "fournir",
    "fourniraient": "fournir",
    "fournirais": "fournir",
    "fournirait": "fournir",
    "fourniras": "fournir",
    "fournirent": "fournir",
    "fournirez": "fournir",
    "fourniriez": "fournir",
    "fournirions": "fournir",
    "fournirons": "fournir",
    "fourniront": "fournir",
    "fournis": "fournir",
    "fournissaient": "fournir",
    "fournissais": "fournir",
    "fournissait": "fournir",
    "fournissant": "fournir",
    "fournisse": "fournir",
    "fournissent": "fournir",
    "fournisses": "fournir",
    "fournisseurs": "fournisseur",
    "fournisseuses": "fournisseur",
    "fournissez": "fournir",
    "fournissiez": "fournir",
    "fournissions": "fournir",
    "fournissons": "fournir",
    "fournit": "fournir",
    "fournitures": "fourniture",
    "fournées": "fournée",
    "fournîmes": "fournir",
    "fournît": "fournir",
    "fournîtes": "fournir",
    "fourra": "fourrer",
    "fourrage": "fourrager",
    "fourragea": "fourrager",
    "fourrageai": "fourrager",
    "fourrageaient": "fourrager",
    "fourrageais": "fourrager",
    "fourrageait": "fourrager",
    "fourrageant": "fourrager",
    "fourrageas": "fourrager",
    "fourrageasse": "fourrager",
    "fourrageassent": "fourrager",
    "fourrageasses": "fourrager",
    "fourrageassiez": "fourrager",
    "fourrageassions": "fourrager",
    "fourragent": "fourrager",
    "fourrageons": "fourrager",
    "fourragera": "fourrager",
    "fourragerai": "fourrager",
    "fourrageraient": "fourrager",
    "fourragerais": "fourrager",
    "fourragerait": "fourrager",
    "fourrageras": "fourrager",
    "fourragerez": "fourrager",
    "fourrageriez": "fourrager",
    "fourragerions": "fourrager",
    "fourragerons": "fourrager",
    "fourrageront": "fourrager",
    "fourrages": "fourrager",
    "fourrageurs": "fourrageur",
    "fourragez": "fourrager",
    "fourrageâmes": "fourrager",
    "fourrageât": "fourrager",
    "fourrageâtes": "fourrager",
    "fourragiez": "fourrager",
    "fourragions": "fourrager",
    "fourragère": "fourrager",
    "fourragèrent": "fourrager",
    "fourragères": "fourragère",
    "fourragé": "fourrager",
    "fourrai": "fourrer",
    "fourraient": "fourrer",
    "fourrais": "fourrer",
    "fourrait": "fourrer",
    "fourrant": "fourrer",
    "fourras": "fourrer",
    "fourrasse": "fourrer",
    "fourrassent": "fourrer",
    "fourrasses": "fourrer",
    "fourrassiez": "fourrer",
    "fourrassions": "fourrer",
    "fourre": "fourrer",
    "fourreaux": "fourreau",
    "fourrent": "fourrer",
    "fourrera": "fourrer",
    "fourrerai": "fourrer",
    "fourreraient": "fourrer",
    "fourrerais": "fourrer",
    "fourrerait": "fourrer",
    "fourreras": "fourrer",
    "fourrerez": "fourrer",
    "fourreriez": "fourrer",
    "fourrerions": "fourrer",
    "fourrerons": "fourrer",
    "fourreront": "fourrer",
    "fourres": "fourrer",
    "fourreurs": "fourreur",
    "fourrez": "fourrer",
    "fourriers": "fourrier",
    "fourriez": "fourrer",
    "fourrions": "fourrer",
    "fourrières": "fourrière",
    "fourrons": "fourrer",
    "fourrures": "fourrure",
    "fourrâmes": "fourrer",
    "fourrât": "fourrer",
    "fourrâtes": "fourrer",
    "fourrèrent": "fourrer",
    "fourré": "fourrer",
    "fourrée": "fourrer",
    "fourrées": "fourrer",
    "fourrés": "fourrer",
    "fours": "four",
    "fourvoie": "fourvoyer",
    "fourvoiements": "fourvoiement",
    "fourvoient": "fourvoyer",
    "fourvoiera": "fourvoyer",
    "fourvoierai": "fourvoyer",
    "fourvoieraient": "fourvoyer",
    "fourvoierais": "fourvoyer",
    "fourvoierait": "fourvoyer",
    "fourvoieras": "fourvoyer",
    "fourvoierez": "fourvoyer",
    "fourvoieriez": "fourvoyer",
    "fourvoierions": "fourvoyer",
    "fourvoierons": "fourvoyer",
    "fourvoieront": "fourvoyer",
    "fourvoies": "fourvoyer",
    "fourvoya": "fourvoyer",
    "fourvoyai": "fourvoyer",
    "fourvoyaient": "fourvoyer",
    "fourvoyais": "fourvoyer",
    "fourvoyait": "fourvoyer",
    "fourvoyant": "fourvoyer",
    "fourvoyas": "fourvoyer",
    "fourvoyasse": "fourvoyer",
    "fourvoyassent": "fourvoyer",
    "fourvoyasses": "fourvoyer",
    "fourvoyassiez": "fourvoyer",
    "fourvoyassions": "fourvoyer",
    "fourvoyez": "fourvoyer",
    "fourvoyiez": "fourvoyer",
    "fourvoyions": "fourvoyer",
    "fourvoyons": "fourvoyer",
    "fourvoyâmes": "fourvoyer",
    "fourvoyât": "fourvoyer",
    "fourvoyâtes": "fourvoyer",
    "fourvoyèrent": "fourvoyer",
    "fourvoyé": "fourvoyer",
    "fourvoyée": "fourvoyer",
    "fourvoyées": "fourvoyer",
    "fourvoyés": "fourvoyer",
    "fous": "foutre",
    "fout": "foutre",
    "foutaient": "foutre",
    "foutais": "foutre",
    "foutaises": "foutaise",
    "foutait": "foutre",
    "foutant": "foutre",
    "foute": "foutre",
    "foutent": "foutre",
    "fouteries": "fouterie",
    "foutes": "foutre",
    "fouteurs": "fouteur",
    "foutez": "foutre",
    "foutiez": "foutre",
    "foutions": "foutre",
    "foutit": "foutre",
    "foutoirs": "foutoir",
    "foutons": "foutre",
    "foutra": "foutre",
    "foutrai": "foutre",
    "foutraient": "foutre",
    "foutrais": "foutre",
    "foutrait": "foutre",
    "foutrale": "foutral",
    "foutrales": "foutral",
    "foutrals": "foutral",
    "foutras": "foutre",
    "foutrez": "foutre",
    "foutriez": "foutre",
    "foutrions": "foutre",
    "foutriquets": "foutriquet",
    "foutrons": "foutre",
    "foutront": "foutre",
    "foutu": "foutre",
    "foutue": "foutu",
    "foutues": "foutu",
    "foutus": "foutu",
    "foutît": "foutre",
    "fouënes": "fouëne",
    "fouîmes": "fouir",
    "fouît": "fouir",
    "fouîtes": "fouir",
    "fox-terriers": "fox-terrier",
    "foyards": "foyard",
    "foyers": "foyer",
    "foènes": "foène",
    "fracassa": "fracasser",
    "fracassai": "fracasser",
    "fracassaient": "fracasser",
    "fracassais": "fracasser",
    "fracassait": "fracasser",
    "fracassant": "fracasser",
    "fracassante": "fracassant",
    "fracassantes": "fracassant",
    "fracassants": "fracassant",
    "fracassas": "fracasser",
    "fracassasse": "fracasser",
    "fracassassent": "fracasser",
    "fracassasses": "fracasser",
    "fracassassiez": "fracasser",
    "fracassassions": "fracasser",
    "fracasse": "fracasser",
    "fracassent": "fracasser",
    "fracassera": "fracasser",
    "fracasserai": "fracasser",
    "fracasseraient": "fracasser",
    "fracasserais": "fracasser",
    "fracasserait": "fracasser",
    "fracasseras": "fracasser",
    "fracasserez": "fracasser",
    "fracasseriez": "fracasser",
    "fracasserions": "fracasser",
    "fracasserons": "fracasser",
    "fracasseront": "fracasser",
    "fracasses": "fracasser",
    "fracassez": "fracasser",
    "fracassiez": "fracasser",
    "fracassions": "fracasser",
    "fracassons": "fracasser",
    "fracassâmes": "fracasser",
    "fracassât": "fracasser",
    "fracassâtes": "fracasser",
    "fracassèrent": "fracasser",
    "fracassé": "fracasser",
    "fracassée": "fracasser",
    "fracassées": "fracasser",
    "fracassés": "fracasser",
    "fracs": "frac",
    "fractale": "fractal",
    "fractales": "fractal",
    "fractals": "fractal",
    "fractionna": "fractionner",
    "fractionnai": "fractionner",
    "fractionnaient": "fractionner",
    "fractionnais": "fractionner",
    "fractionnait": "fractionner",
    "fractionnant": "fractionner",
    "fractionnas": "fractionner",
    "fractionnasse": "fractionner",
    "fractionnassent": "fractionner",
    "fractionnasses": "fractionner",
    "fractionnassiez": "fractionner",
    "fractionnassions": "fractionner",
    "fractionne": "fractionner",
    "fractionnelles": "fractionnel",
    "fractionnent": "fractionner",
    "fractionnera": "fractionner",
    "fractionnerai": "fractionner",
    "fractionneraient": "fractionner",
    "fractionnerais": "fractionner",
    "fractionnerait": "fractionner",
    "fractionneras": "fractionner",
    "fractionnerez": "fractionner",
    "fractionneriez": "fractionner",
    "fractionnerions": "fractionner",
    "fractionnerons": "fractionner",
    "fractionneront": "fractionner",
    "fractionnes": "fractionner",
    "fractionnez": "fractionner",
    "fractionniez": "fractionner",
    "fractionnions": "fractionner",
    "fractionnons": "fractionner",
    "fractionnâmes": "fractionner",
    "fractionnât": "fractionner",
    "fractionnâtes": "fractionner",
    "fractionnèrent": "fractionner",
    "fractionné": "fractionner",
    "fractionnée": "fractionner",
    "fractionnées": "fractionner",
    "fractionnés": "fractionner",
    "fractions": "fraction",
    "fractura": "fracturer",
    "fracturai": "fracturer",
    "fracturaient": "fracturer",
    "fracturais": "fracturer",
    "fracturait": "fracturer",
    "fracturant": "fracturer",
    "fracturas": "fracturer",
    "fracturasse": "fracturer",
    "fracturassent": "fracturer",
    "fracturasses": "fracturer",
    "fracturassiez": "fracturer",
    "fracturassions": "fracturer",
    "fracture": "fracturer",
    "fracturent": "fracturer",
    "fracturera": "fracturer",
    "fracturerai": "fracturer",
    "fractureraient": "fracturer",
    "fracturerais": "fracturer",
    "fracturerait": "fracturer",
    "fractureras": "fracturer",
    "fracturerez": "fracturer",
    "fractureriez": "fracturer",
    "fracturerions": "fracturer",
    "fracturerons": "fracturer",
    "fractureront": "fracturer",
    "fractures": "fracturer",
    "fracturez": "fracturer",
    "fracturiez": "fracturer",
    "fracturions": "fracturer",
    "fracturons": "fracturer",
    "fracturâmes": "fracturer",
    "fracturât": "fracturer",
    "fracturâtes": "fracturer",
    "fracturèrent": "fracturer",
    "fracturé": "fracturer",
    "fracturée": "fracturer",
    "fracturées": "fracturer",
    "fracturés": "fracturer",
    "fragiles": "fragile",
    "fragilisa": "fragiliser",
    "fragilisai": "fragiliser",
    "fragilisaient": "fragiliser",
    "fragilisais": "fragiliser",
    "fragilisait": "fragiliser",
    "fragilisant": "fragiliser",
    "fragilisas": "fragiliser",
    "fragilisasse": "fragiliser",
    "fragilisassent": "fragiliser",
    "fragilisasses": "fragiliser",
    "fragilisassiez": "fragiliser",
    "fragilisassions": "fragiliser",
    "fragilise": "fragiliser",
    "fragilisent": "fragiliser",
    "fragilisera": "fragiliser",
    "fragiliserai": "fragiliser",
    "fragiliseraient": "fragiliser",
    "fragiliserais": "fragiliser",
    "fragiliserait": "fragiliser",
    "fragiliseras": "fragiliser",
    "fragiliserez": "fragiliser",
    "fragiliseriez": "fragiliser",
    "fragiliserions": "fragiliser",
    "fragiliserons": "fragiliser",
    "fragiliseront": "fragiliser",
    "fragilises": "fragiliser",
    "fragilisez": "fragiliser",
    "fragilisiez": "fragiliser",
    "fragilisions": "fragiliser",
    "fragilisons": "fragiliser",
    "fragilisâmes": "fragiliser",
    "fragilisât": "fragiliser",
    "fragilisâtes": "fragiliser",
    "fragilisèrent": "fragiliser",
    "fragilisé": "fragiliser",
    "fragilisée": "fragiliser",
    "fragilisées": "fragiliser",
    "fragilisés": "fragiliser",
    "fragilités": "fragilité",
    "fragmentaient": "fragmenter",
    "fragmentaires": "fragmentaire",
    "fragmentait": "fragmenter",
    "fragmentant": "fragmenter",
    "fragmentations": "fragmentation",
    "fragmente": "fragmenter",
    "fragmentent": "fragmenter",
    "fragments": "fragment",
    "fragmentèrent": "fragmenter",
    "fragmenté": "fragmenter",
    "fragmentée": "fragmenter",
    "fragmentées": "fragmenter",
    "fragmentés": "fragmenter",
    "fragrances": "fragrance",
    "fraie": "frayer",
    "fraient": "frayer",
    "fraiera": "frayer",
    "fraierai": "frayer",
    "fraieraient": "frayer",
    "fraierais": "frayer",
    "fraierait": "frayer",
    "fraieras": "frayer",
    "fraierez": "frayer",
    "fraieriez": "frayer",
    "fraierions": "frayer",
    "fraierons": "frayer",
    "fraieront": "frayer",
    "fraies": "frayer",
    "frais": "frai",
    "fraisa": "fraiser",
    "fraisai": "fraiser",
    "fraisaient": "fraiser",
    "fraisais": "fraiser",
    "fraisait": "fraiser",
    "fraisant": "fraiser",
    "fraisas": "fraiser",
    "fraisasse": "fraiser",
    "fraisassent": "fraiser",
    "fraisasses": "fraiser",
    "fraisassiez": "fraiser",
    "fraisassions": "fraiser",
    "fraise": "fraiser",
    "fraisent": "fraiser",
    "fraisera": "fraiser",
    "fraiserai": "fraiser",
    "fraiseraient": "fraiser",
    "fraiserais": "fraiser",
    "fraiserait": "fraiser",
    "fraiseras": "fraiser",
    "fraiserez": "fraiser",
    "fraiseriez": "fraiser",
    "fraiserions": "fraiser",
    "fraiserons": "fraiser",
    "fraiseront": "fraiser",
    "fraises": "fraiser",
    "fraiseurs": "fraiseur",
    "fraiseuse": "fraiseur",
    "fraisez": "fraiser",
    "fraisiers": "fraisier",
    "fraisiez": "fraiser",
    "fraisils": "fraisil",
    "fraisions": "fraiser",
    "fraisons": "fraiser",
    "fraisâmes": "fraiser",
    "fraisât": "fraiser",
    "fraisâtes": "fraiser",
    "fraisèrent": "fraiser",
    "fraisé": "fraiser",
    "fraisée": "fraiser",
    "fraisées": "fraiser",
    "fraisés": "fraiser",
    "framboises": "framboise",
    "framboisiers": "framboisier",
    "framées": "framée",
    "franc-comtoise": "franc-comtois",
    "franc-comtoises": "franc-comtois",
    "franc-maçonne": "franc-maçon",
    "franc-maçonneries": "franc-maçonnerie",
    "franc-maçonnes": "franc-maçon",
    "francforts": "francfort",
    "franche": "franc",
    "franches": "franc",
    "franchi": "franchir",
    "franchie": "franchir",
    "franchies": "franchir",
    "franchira": "franchir",
    "franchirai": "franchir",
    "franchiraient": "franchir",
    "franchirais": "franchir",
    "franchirait": "franchir",
    "franchiras": "franchir",
    "franchirent": "franchir",
    "franchirez": "franchir",
    "franchiriez": "franchir",
    "franchirions": "franchir",
    "franchirons": "franchir",
    "franchiront": "franchir",
    "franchis": "franchir",
    "franchisant": "franchiser",
    "franchises": "franchise",
    "franchissables": "franchissable",
    "franchissaient": "franchir",
    "franchissais": "franchir",
    "franchissait": "franchir",
    "franchissant": "franchir",
    "franchisse": "franchir",
    "franchissements": "franchissement",
    "franchissent": "franchir",
    "franchisses": "franchir",
    "franchissez": "franchir",
    "franchissiez": "franchir",
    "franchissions": "franchir",
    "franchissons": "franchir",
    "franchisé": "franchiser",
    "franchisée": "franchiser",
    "franchisées": "franchisé",
    "franchisés": "franchisé",
    "franchit": "franchir",
    "franchouillarde": "franchouillard",
    "franchouillards": "franchouillard",
    "franchîmes": "franchir",
    "franchît": "franchir",
    "franchîtes": "franchir",
    "francilienne": "francilien",
    "franciliennes": "francilien",
    "franciliens": "francilien",
    "francisant": "franciser",
    "franciscaine": "franciscain",
    "franciscains": "franciscain",
    "francisques": "francisque",
    "francisé": "franciser",
    "francisés": "franciser",
    "franco-algérienne": "franco-algérien",
    "franco-allemande": "franco-allemand",
    "franco-allemandes": "franco-allemand",
    "franco-américaine": "franco-américain",
    "franco-américaines": "franco-américain",
    "franco-américains": "franco-américain",
    "franco-anglaise": "franco-anglais",
    "franco-anglaises": "franco-anglais",
    "franco-britanniques": "franco-britannique",
    "franco-chinoises": "franco-chinois",
    "franco-italienne": "franco-italien",
    "franco-japonaise": "franco-japonais",
    "franco-mongole": "franco-mongol",
    "franco-polonaise": "franco-polonais",
    "franco-russes": "franco-russe",
    "francolins": "francolin",
    "francophiles": "francophile",
    "francophones": "francophone",
    "francophonies": "francophonie",
    "francs": "franc",
    "francs-alleux": "franc-alleu",
    "francs-bords": "franc-bord",
    "francs-bourgeois": "franc-bourgeois",
    "francs-comtois": "franc-comtois",
    "francs-jeux": "franc-jeu",
    "francs-maçons": "franc-maçon",
    "francs-parlers": "franc-parler",
    "francs-tireurs": "franc-tireur",
    "frange": "franger",
    "frangeaient": "franger",
    "frangeait": "franger",
    "frangeant": "franger",
    "frangent": "franger",
    "franges": "frange",
    "frangine": "frangin",
    "frangines": "frangin",
    "frangins": "frangin",
    "frangipanes": "frangipane",
    "frangipaniers": "frangipanier",
    "frangé": "franger",
    "frangée": "franger",
    "frangées": "franger",
    "frangés": "franger",
    "franque": "franc",
    "franques": "franque",
    "franquismes": "franquisme",
    "franquistes": "franquiste",
    "française": "français",
    "françaises": "français",
    "frapadingues": "frapadingue",
    "frappa": "frapper",
    "frappadingues": "frappadingue",
    "frappai": "frapper",
    "frappaient": "frapper",
    "frappais": "frapper",
    "frappait": "frapper",
    "frappant": "frapper",
    "frappante": "frappant",
    "frappantes": "frappant",
    "frappants": "frappant",
    "frappas": "frapper",
    "frappasse": "frapper",
    "frappassent": "frapper",
    "frappasses": "frapper",
    "frappassiez": "frapper",
    "frappassions": "frapper",
    "frappe": "frapper",
    "frappements": "frappement",
    "frappent": "frapper",
    "frappera": "frapper",
    "frapperai": "frapper",
    "frapperaient": "frapper",
    "frapperais": "frapper",
    "frapperait": "frapper",
    "frapperas": "frapper",
    "frapperez": "frapper",
    "frapperiez": "frapper",
    "frapperions": "frapper",
    "frapperons": "frapper",
    "frapperont": "frapper",
    "frappes": "frapper",
    "frappeurs": "frappeur",
    "frappez": "frapper",
    "frappiez": "frapper",
    "frappions": "frapper",
    "frappons": "frapper",
    "frappâmes": "frapper",
    "frappât": "frapper",
    "frappâtes": "frapper",
    "frappèrent": "frapper",
    "frappé": "frapper",
    "frappée": "frapper",
    "frappées": "frapper",
    "frappés": "frapper",
    "frasques": "frasque",
    "fraternelle": "fraternel",
    "fraternelles": "fraternel",
    "fraternels": "fraternel",
    "fraternisa": "fraterniser",
    "fraternisai": "fraterniser",
    "fraternisaient": "fraterniser",
    "fraternisais": "fraterniser",
    "fraternisait": "fraterniser",
    "fraternisant": "fraterniser",
    "fraternisas": "fraterniser",
    "fraternisasse": "fraterniser",
    "fraternisassent": "fraterniser",
    "fraternisasses": "fraterniser",
    "fraternisassiez": "fraterniser",
    "fraternisassions": "fraterniser",
    "fraternise": "fraterniser",
    "fraternisent": "fraterniser",
    "fraternisera": "fraterniser",
    "fraterniserai": "fraterniser",
    "fraterniseraient": "fraterniser",
    "fraterniserais": "fraterniser",
    "fraterniserait": "fraterniser",
    "fraterniseras": "fraterniser",
    "fraterniserez": "fraterniser",
    "fraterniseriez": "fraterniser",
    "fraterniserions": "fraterniser",
    "fraterniserons": "fraterniser",
    "fraterniseront": "fraterniser",
    "fraternises": "fraterniser",
    "fraternisez": "fraterniser",
    "fraternisiez": "fraterniser",
    "fraternisions": "fraterniser",
    "fraternisons": "fraterniser",
    "fraternisâmes": "fraterniser",
    "fraternisât": "fraterniser",
    "fraternisâtes": "fraterniser",
    "fraternisèrent": "fraterniser",
    "fraternisé": "fraterniser",
    "fraternités": "fraternité",
    "fratricides": "fratricide",
    "fratries": "fratrie",
    "frauda": "frauder",
    "fraudai": "frauder",
    "fraudaient": "frauder",
    "fraudais": "frauder",
    "fraudait": "frauder",
    "fraudant": "frauder",
    "fraudas": "frauder",
    "fraudasse": "frauder",
    "fraudassent": "frauder",
    "fraudasses": "frauder",
    "fraudassiez": "frauder",
    "fraudassions": "frauder",
    "fraude": "frauder",
    "fraudent": "frauder",
    "fraudera": "frauder",
    "frauderai": "frauder",
    "frauderaient": "frauder",
    "frauderais": "frauder",
    "frauderait": "frauder",
    "frauderas": "frauder",
    "frauderez": "frauder",
    "frauderiez": "frauder",
    "frauderions": "frauder",
    "frauderons": "frauder",
    "frauderont": "frauder",
    "fraudes": "frauder",
    "fraudeurs": "fraudeur",
    "fraudeuse": "fraudeur",
    "fraudeuses": "fraudeur",
    "fraudez": "frauder",
    "fraudiez": "frauder",
    "fraudions": "frauder",
    "fraudons": "frauder",
    "frauduleuse": "frauduleux",
    "frauduleuses": "frauduleux",
    "fraudâmes": "frauder",
    "fraudât": "frauder",
    "fraudâtes": "frauder",
    "fraudèrent": "frauder",
    "fraudé": "frauder",
    "fraudée": "frauder",
    "fraudées": "frauder",
    "fraudés": "frauder",
    "fraxinelles": "fraxinelle",
    "fraya": "frayer",
    "frayai": "frayer",
    "frayaient": "frayer",
    "frayais": "frayer",
    "frayait": "frayer",
    "frayant": "frayer",
    "frayas": "frayer",
    "frayasse": "frayer",
    "frayassent": "frayer",
    "frayasses": "frayer",
    "frayassiez": "frayer",
    "frayassions": "frayer",
    "fraye": "frayer",
    "frayent": "frayer",
    "frayera": "frayer",
    "frayerai": "frayer",
    "frayeraient": "frayer",
    "frayerais": "frayer",
    "frayerait": "frayer",
    "frayeras": "frayer",
    "frayerez": "frayer",
    "frayeriez": "frayer",
    "frayerions": "frayer",
    "frayerons": "frayer",
    "frayeront": "frayer",
    "frayes": "frayer",
    "frayeurs": "frayeur",
    "frayez": "frayer",
    "frayiez": "frayer",
    "frayions": "frayer",
    "frayons": "frayer",
    "frayâmes": "frayer",
    "frayât": "frayer",
    "frayâtes": "frayer",
    "frayèrent": "frayer",
    "frayé": "frayer",
    "frayée": "frayer",
    "frayées": "frayer",
    "frayés": "frayer",
    "fraîche": "frais",
    "fraîches": "frais",
    "fraîcheurs": "fraîcheur",
    "fraîchi": "fraîchir",
    "fraîchira": "fraîchir",
    "fraîchirai": "fraîchir",
    "fraîchiraient": "fraîchir",
    "fraîchirais": "fraîchir",
    "fraîchirait": "fraîchir",
    "fraîchiras": "fraîchir",
    "fraîchirent": "fraîchir",
    "fraîchirez": "fraîchir",
    "fraîchiriez": "fraîchir",
    "fraîchirions": "fraîchir",
    "fraîchirons": "fraîchir",
    "fraîchiront": "fraîchir",
    "fraîchis": "fraîchir",
    "fraîchissaient": "fraîchir",
    "fraîchissais": "fraîchir",
    "fraîchissait": "fraîchir",
    "fraîchissant": "fraîchir",
    "fraîchisse": "fraîchir",
    "fraîchissent": "fraîchir",
    "fraîchisses": "fraîchir",
    "fraîchissez": "fraîchir",
    "fraîchissiez": "fraîchir",
    "fraîchissions": "fraîchir",
    "fraîchissons": "fraîchir",
    "fraîchit": "fraîchir",
    "fraîchîmes": "fraîchir",
    "fraîchît": "fraîchir",
    "fraîchîtes": "fraîchir",
    "freaks": "freak",
    "fredaines": "fredaine",
    "fredonna": "fredonner",
    "fredonnai": "fredonner",
    "fredonnaient": "fredonner",
    "fredonnais": "fredonner",
    "fredonnait": "fredonner",
    "fredonnant": "fredonner",
    "fredonnas": "fredonner",
    "fredonnasse": "fredonner",
    "fredonnassent": "fredonner",
    "fredonnasses": "fredonner",
    "fredonnassiez": "fredonner",
    "fredonnassions": "fredonner",
    "fredonne": "fredonner",
    "fredonnent": "fredonner",
    "fredonnera": "fredonner",
    "fredonnerai": "fredonner",
    "fredonneraient": "fredonner",
    "fredonnerais": "fredonner",
    "fredonnerait": "fredonner",
    "fredonneras": "fredonner",
    "fredonnerez": "fredonner",
    "fredonneriez": "fredonner",
    "fredonnerions": "fredonner",
    "fredonnerons": "fredonner",
    "fredonneront": "fredonner",
    "fredonnes": "fredonner",
    "fredonnez": "fredonner",
    "fredonniez": "fredonner",
    "fredonnions": "fredonner",
    "fredonnons": "fredonner",
    "fredonnâmes": "fredonner",
    "fredonnât": "fredonner",
    "fredonnâtes": "fredonner",
    "fredonnèrent": "fredonner",
    "fredonné": "fredonner",
    "fredonnée": "fredonner",
    "fredonnées": "fredonner",
    "fredonnés": "fredonner",
    "freesias": "freesia",
    "freezers": "freezer",
    "freina": "freiner",
    "freinages": "freinage",
    "freinai": "freiner",
    "freinaient": "freiner",
    "freinais": "freiner",
    "freinait": "freiner",
    "freinant": "freiner",
    "freinas": "freiner",
    "freinasse": "freiner",
    "freinassent": "freiner",
    "freinasses": "freiner",
    "freinassiez": "freiner",
    "freinassions": "freiner",
    "freine": "freiner",
    "freinent": "freiner",
    "freinera": "freiner",
    "freinerai": "freiner",
    "freineraient": "freiner",
    "freinerais": "freiner",
    "freinerait": "freiner",
    "freineras": "freiner",
    "freinerez": "freiner",
    "freineriez": "freiner",
    "freinerions": "freiner",
    "freinerons": "freiner",
    "freineront": "freiner",
    "freines": "freiner",
    "freineurs": "freineur",
    "freinez": "freiner",
    "freiniez": "freiner",
    "freinions": "freiner",
    "freinons": "freiner",
    "freins": "frein",
    "freinâmes": "freiner",
    "freinât": "freiner",
    "freinâtes": "freiner",
    "freinèrent": "freiner",
    "freiné": "freiner",
    "freinée": "freiner",
    "freinées": "freiner",
    "freinés": "freiner",
    "frelata": "frelater",
    "frelatai": "frelater",
    "frelataient": "frelater",
    "frelatais": "frelater",
    "frelatait": "frelater",
    "frelatant": "frelater",
    "frelatas": "frelater",
    "frelatasse": "frelater",
    "frelatassent": "frelater",
    "frelatasses": "frelater",
    "frelatassiez": "frelater",
    "frelatassions": "frelater",
    "frelate": "frelater",
    "frelatent": "frelater",
    "frelatera": "frelater",
    "frelaterai": "frelater",
    "frelateraient": "frelater",
    "frelaterais": "frelater",
    "frelaterait": "frelater",
    "frelateras": "frelater",
    "frelaterez": "frelater",
    "frelateriez": "frelater",
    "frelaterions": "frelater",
    "frelaterons": "frelater",
    "frelateront": "frelater",
    "frelates": "frelater",
    "frelatez": "frelater",
    "frelatiez": "frelater",
    "frelations": "frelater",
    "frelatons": "frelater",
    "frelatâmes": "frelater",
    "frelatât": "frelater",
    "frelatâtes": "frelater",
    "frelatèrent": "frelater",
    "frelaté": "frelater",
    "frelatée": "frelater",
    "frelatées": "frelater",
    "frelatés": "frelater",
    "frelons": "frelon",
    "freluquets": "freluquet",
    "fresques": "fresque",
    "fressures": "fressure",
    "fretins": "fretin",
    "frets": "fret",
    "fretta": "fretter",
    "freudienne": "freudien",
    "freudiennes": "freudien",
    "freudiens": "freudien",
    "friabilités": "friabilité",
    "friables": "friable",
    "friande": "friand",
    "friandes": "friand",
    "friandises": "friandise",
    "friands": "friand",
    "fribourgeoise": "fribourgeois",
    "fricadelles": "fricadelle",
    "fricandeaux": "fricandeau",
    "fricassa": "fricasser",
    "fricassai": "fricasser",
    "fricassaient": "fricasser",
    "fricassais": "fricasser",
    "fricassait": "fricasser",
    "fricassant": "fricasser",
    "fricassas": "fricasser",
    "fricassasse": "fricasser",
    "fricassassent": "fricasser",
    "fricassasses": "fricasser",
    "fricassassiez": "fricasser",
    "fricassassions": "fricasser",
    "fricasse": "fricasser",
    "fricassent": "fricasser",
    "fricassera": "fricasser",
    "fricasserai": "fricasser",
    "fricasseraient": "fricasser",
    "fricasserais": "fricasser",
    "fricasserait": "fricasser",
    "fricasseras": "fricasser",
    "fricasserez": "fricasser",
    "fricasseriez": "fricasser",
    "fricasserions": "fricasser",
    "fricasserons": "fricasser",
    "fricasseront": "fricasser",
    "fricasses": "fricasser",
    "fricassez": "fricasser",
    "fricassiez": "fricasser",
    "fricassions": "fricasser",
    "fricassons": "fricasser",
    "fricassâmes": "fricasser",
    "fricassât": "fricasser",
    "fricassâtes": "fricasser",
    "fricassèrent": "fricasser",
    "fricassé": "fricasser",
    "fricassée": "fricasser",
    "fricassées": "fricasser",
    "fricassés": "fricasser",
    "fricatives": "fricative",
    "friches": "friche",
    "frichtis": "frichti",
    "fricota": "fricoter",
    "fricotages": "fricotage",
    "fricotai": "fricoter",
    "fricotaient": "fricoter",
    "fricotais": "fricoter",
    "fricotait": "fricoter",
    "fricotant": "fricoter",
    "fricotas": "fricoter",
    "fricotasse": "fricoter",
    "fricotassent": "fricoter",
    "fricotasses": "fricoter",
    "fricotassiez": "fricoter",
    "fricotassions": "fricoter",
    "fricote": "fricoter",
    "fricotent": "fricoter",
    "fricotera": "fricoter",
    "fricoterai": "fricoter",
    "fricoteraient": "fricoter",
    "fricoterais": "fricoter",
    "fricoterait": "fricoter",
    "fricoteras": "fricoter",
    "fricoterez": "fricoter",
    "fricoteriez": "fricoter",
    "fricoterions": "fricoter",
    "fricoterons": "fricoter",
    "fricoteront": "fricoter",
    "fricotes": "fricoter",
    "fricoteurs": "fricoteur",
    "fricotez": "fricoter",
    "fricotiez": "fricoter",
    "fricotions": "fricoter",
    "fricotons": "fricoter",
    "fricots": "fricot",
    "fricotâmes": "fricoter",
    "fricotât": "fricoter",
    "fricotâtes": "fricoter",
    "fricotèrent": "fricoter",
    "fricoté": "fricoter",
    "fricotée": "fricoter",
    "fricotées": "fricoter",
    "fricotés": "fricoter",
    "frics": "fric",
    "frictionna": "frictionner",
    "frictionnai": "frictionner",
    "frictionnaient": "frictionner",
    "frictionnais": "frictionner",
    "frictionnait": "frictionner",
    "frictionnant": "frictionner",
    "frictionnas": "frictionner",
    "frictionnasse": "frictionner",
    "frictionnassent": "frictionner",
    "frictionnasses": "frictionner",
    "frictionnassiez": "frictionner",
    "frictionnassions": "frictionner",
    "frictionne": "frictionner",
    "frictionnent": "frictionner",
    "frictionnera": "frictionner",
    "frictionnerai": "frictionner",
    "frictionneraient": "frictionner",
    "frictionnerais": "frictionner",
    "frictionnerait": "frictionner",
    "frictionneras": "frictionner",
    "frictionnerez": "frictionner",
    "frictionneriez": "frictionner",
    "frictionnerions": "frictionner",
    "frictionnerons": "frictionner",
    "frictionneront": "frictionner",
    "frictionnes": "frictionner",
    "frictionnez": "frictionner",
    "frictionniez": "frictionner",
    "frictionnions": "frictionner",
    "frictionnons": "frictionner",
    "frictionnâmes": "frictionner",
    "frictionnât": "frictionner",
    "frictionnâtes": "frictionner",
    "frictionnèrent": "frictionner",
    "frictionné": "frictionner",
    "frictionnée": "frictionner",
    "frictionnées": "frictionner",
    "frictionnés": "frictionner",
    "frictions": "friction",
    "fridolins": "fridolin",
    "frigidaires": "frigidaire",
    "frigides": "frigide",
    "frigorifia": "frigorifier",
    "frigorifiai": "frigorifier",
    "frigorifiaient": "frigorifier",
    "frigorifiais": "frigorifier",
    "frigorifiait": "frigorifier",
    "frigorifiant": "frigorifier",
    "frigorifias": "frigorifier",
    "frigorifiasse": "frigorifier",
    "frigorifiassent": "frigorifier",
    "frigorifiasses": "frigorifier",
    "frigorifiassiez": "frigorifier",
    "frigorifiassions": "frigorifier",
    "frigorifie": "frigorifier",
    "frigorifient": "frigorifier",
    "frigorifiera": "frigorifier",
    "frigorifierai": "frigorifier",
    "frigorifieraient": "frigorifier",
    "frigorifierais": "frigorifier",
    "frigorifierait": "frigorifier",
    "frigorifieras": "frigorifier",
    "frigorifierez": "frigorifier",
    "frigorifieriez": "frigorifier",
    "frigorifierions": "frigorifier",
    "frigorifierons": "frigorifier",
    "frigorifieront": "frigorifier",
    "frigorifies": "frigorifier",
    "frigorifiez": "frigorifier",
    "frigorifiiez": "frigorifier",
    "frigorifiions": "frigorifier",
    "frigorifions": "frigorifier",
    "frigorifiques": "frigorifique",
    "frigorifiâmes": "frigorifier",
    "frigorifiât": "frigorifier",
    "frigorifiâtes": "frigorifier",
    "frigorifièrent": "frigorifier",
    "frigorifié": "frigorifier",
    "frigorifiée": "frigorifier",
    "frigorifiées": "frigorifier",
    "frigorifiés": "frigorifier",
    "frigos": "frigo",
    "frileuse": "frileux",
    "frileuses": "frileux",
    "frilosités": "frilosité",
    "frima": "frimer",
    "frimaient": "frimer",
    "frimaires": "frimaire",
    "frimais": "frimer",
    "frimait": "frimer",
    "frimant": "frimer",
    "frime": "frimer",
    "friment": "frimer",
    "frimerais": "frimer",
    "frimes": "frimer",
    "frimeurs": "frimeur",
    "frimeuse": "frimeur",
    "frimez": "frimer",
    "frimiez": "frimer",
    "frimousses": "frimousse",
    "frimé": "frimer",
    "frimée": "frimer",
    "frimées": "frimer",
    "frimés": "frimer",
    "fringales": "fringale",
    "fringante": "fringant",
    "fringantes": "fringant",
    "fringants": "fringant",
    "fringua": "fringuer",
    "fringuai": "fringuer",
    "fringuaient": "fringuer",
    "fringuais": "fringuer",
    "fringuait": "fringuer",
    "fringuant": "fringuer",
    "fringuas": "fringuer",
    "fringuasse": "fringuer",
    "fringuassent": "fringuer",
    "fringuasses": "fringuer",
    "fringuassiez": "fringuer",
    "fringuassions": "fringuer",
    "fringue": "fringuer",
    "fringuent": "fringuer",
    "fringuera": "fringuer",
    "fringuerai": "fringuer",
    "fringueraient": "fringuer",
    "fringuerais": "fringuer",
    "fringuerait": "fringuer",
    "fringueras": "fringuer",
    "fringuerez": "fringuer",
    "fringueriez": "fringuer",
    "fringuerions": "fringuer",
    "fringuerons": "fringuer",
    "fringueront": "fringuer",
    "fringues": "fringuer",
    "fringuez": "fringuer",
    "fringuiez": "fringuer",
    "fringuions": "fringuer",
    "fringuons": "fringuer",
    "fringuâmes": "fringuer",
    "fringuât": "fringuer",
    "fringuâtes": "fringuer",
    "fringuèrent": "fringuer",
    "fringué": "fringuer",
    "fringuée": "fringuer",
    "fringuées": "fringuer",
    "fringués": "fringuer",
    "fripa": "friper",
    "fripai": "friper",
    "fripaient": "friper",
    "fripais": "friper",
    "fripait": "friper",
    "fripant": "friper",
    "fripas": "friper",
    "fripasse": "friper",
    "fripassent": "friper",
    "fripasses": "friper",
    "fripassiez": "friper",
    "fripassions": "friper",
    "fripe": "friper",
    "fripent": "friper",
    "fripera": "friper",
    "friperai": "friper",
    "friperaient": "friper",
    "friperais": "friper",
    "friperait": "friper",
    "friperas": "friper",
    "friperez": "friper",
    "friperiez": "friper",
    "friperions": "friper",
    "friperons": "friper",
    "friperont": "friper",
    "fripes": "friper",
    "fripez": "friper",
    "fripiers": "fripier",
    "fripiez": "friper",
    "fripions": "friper",
    "friponne": "fripon",
    "friponneries": "friponnerie",
    "friponnes": "fripon",
    "fripons": "fripon",
    "fripouillarde": "fripouillard",
    "fripouillardes": "fripouillard",
    "fripouillards": "fripouillard",
    "fripouilleries": "fripouillerie",
    "fripouilles": "fripouille",
    "fripâmes": "friper",
    "fripât": "friper",
    "fripâtes": "friper",
    "fripèrent": "friper",
    "fripé": "friper",
    "fripée": "friper",
    "fripées": "friper",
    "fripés": "friper",
    "friquée": "friqué",
    "friquées": "friqué",
    "friqués": "friqué",
    "frira": "frire",
    "frirai": "frire",
    "frirais": "frire",
    "frirait": "frire",
    "friras": "frire",
    "fris": "frire",
    "frisa": "friser",
    "frisai": "friser",
    "frisaient": "friser",
    "frisais": "friser",
    "frisait": "friser",
    "frisant": "friser",
    "frisante": "frisant",
    "frisants": "frisant",
    "frisas": "friser",
    "frisasse": "friser",
    "frisassent": "friser",
    "frisasses": "friser",
    "frisassiez": "friser",
    "frisassions": "friser",
    "frise": "friser",
    "frisent": "friser",
    "frisera": "friser",
    "friserai": "friser",
    "friseraient": "friser",
    "friserais": "friser",
    "friserait": "friser",
    "friseras": "friser",
    "friserez": "friser",
    "friseriez": "friser",
    "friserions": "friser",
    "friserons": "friser",
    "friseront": "friser",
    "frises": "friser",
    "frisettes": "frisette",
    "frisez": "friser",
    "frisiez": "friser",
    "frisions": "friser",
    "frisonne": "frison",
    "frisonnes": "frison",
    "frisons": "frison",
    "frisottaient": "frisotter",
    "frisottants": "frisottant",
    "frisottent": "frisotter",
    "frisotté": "frisotter",
    "frisottée": "frisotter",
    "frisottées": "frisotter",
    "frisottés": "frisotter",
    "frisous": "frisou",
    "frisquets": "frisquet",
    "frisquette": "frisquet",
    "frisquettes": "frisquet",
    "frissonna": "frissonner",
    "frissonnai": "frissonner",
    "frissonnaient": "frissonner",
    "frissonnais": "frissonner",
    "frissonnait": "frissonner",
    "frissonnant": "frissonner",
    "frissonnante": "frissonnant",
    "frissonnantes": "frissonnant",
    "frissonnants": "frissonnant",
    "frissonnas": "frissonner",
    "frissonnasse": "frissonner",
    "frissonnassent": "frissonner",
    "frissonnasses": "frissonner",
    "frissonnassiez": "frissonner",
    "frissonnassions": "frissonner",
    "frissonne": "frissonner",
    "frissonnements": "frissonnement",
    "frissonnent": "frissonner",
    "frissonnera": "frissonner",
    "frissonnerai": "frissonner",
    "frissonneraient": "frissonner",
    "frissonnerais": "frissonner",
    "frissonnerait": "frissonner",
    "frissonneras": "frissonner",
    "frissonnerez": "frissonner",
    "frissonneriez": "frissonner",
    "frissonnerions": "frissonner",
    "frissonnerons": "frissonner",
    "frissonneront": "frissonner",
    "frissonnes": "frissonner",
    "frissonnez": "frissonner",
    "frissonniez": "frissonner",
    "frissonnions": "frissonner",
    "frissonnons": "frissonner",
    "frissonnâmes": "frissonner",
    "frissonnât": "frissonner",
    "frissonnâtes": "frissonner",
    "frissonnèrent": "frissonner",
    "frissonné": "frissonner",
    "frissons": "frisson",
    "frisures": "frisure",
    "frisâmes": "friser",
    "frisât": "friser",
    "frisâtes": "friser",
    "frisèrent": "friser",
    "frisé": "friser",
    "frisée": "friser",
    "frisées": "friser",
    "frisés": "friser",
    "frit": "frire",
    "frite": "frit",
    "friteries": "friterie",
    "frites": "frite",
    "friteuse": "friteur",
    "friteuses": "friteur",
    "fritillaires": "fritillaire",
    "fritons": "friton",
    "frits": "frit",
    "frittés": "fritter",
    "fritures": "friture",
    "frivoles": "frivole",
    "frivolités": "frivolité",
    "frocards": "frocard",
    "frocs": "froc",
    "froide": "froid",
    "froides": "froid",
    "froideurs": "froideur",
    "froidi": "froidir",
    "froidie": "froidir",
    "froidies": "froidir",
    "froidira": "froidir",
    "froidirai": "froidir",
    "froidiraient": "froidir",
    "froidirais": "froidir",
    "froidirait": "froidir",
    "froidiras": "froidir",
    "froidirent": "froidir",
    "froidirez": "froidir",
    "froidiriez": "froidir",
    "froidirions": "froidir",
    "froidirons": "froidir",
    "froidiront": "froidir",
    "froidis": "froidir",
    "froidissaient": "froidir",
    "froidissais": "froidir",
    "froidissait": "froidir",
    "froidissant": "froidir",
    "froidisse": "froidir",
    "froidissent": "froidir",
    "froidisses": "froidir",
    "froidissez": "froidir",
    "froidissiez": "froidir",
    "froidissions": "froidir",
    "froidissons": "froidir",
    "froidit": "froidir",
    "froids": "froid",
    "froidures": "froidure",
    "froidîmes": "froidir",
    "froidît": "froidir",
    "froidîtes": "froidir",
    "froissa": "froisser",
    "froissai": "froisser",
    "froissaient": "froisser",
    "froissais": "froisser",
    "froissait": "froisser",
    "froissant": "froisser",
    "froissas": "froisser",
    "froissasse": "froisser",
    "froissassent": "froisser",
    "froissasses": "froisser",
    "froissassiez": "froisser",
    "froissassions": "froisser",
    "froisse": "froisser",
    "froissements": "froissement",
    "froissent": "froisser",
    "froissera": "froisser",
    "froisserai": "froisser",
    "froisseraient": "froisser",
    "froisserais": "froisser",
    "froisserait": "froisser",
    "froisseras": "froisser",
    "froisserez": "froisser",
    "froisseriez": "froisser",
    "froisserions": "froisser",
    "froisserons": "froisser",
    "froisseront": "froisser",
    "froisses": "froisser",
    "froissez": "froisser",
    "froissiez": "froisser",
    "froissions": "froisser",
    "froissons": "froisser",
    "froissâmes": "froisser",
    "froissât": "froisser",
    "froissâtes": "froisser",
    "froissèrent": "froisser",
    "froissé": "froisser",
    "froissée": "froisser",
    "froissées": "froisser",
    "froissés": "froisser",
    "fromageries": "fromagerie",
    "fromagers": "fromager",
    "fromages": "fromage",
    "fromagère": "fromager",
    "froments": "froment",
    "frometons": "frometon",
    "fronce": "froncer",
    "froncements": "froncement",
    "froncent": "froncer",
    "froncera": "froncer",
    "froncerai": "froncer",
    "fronceraient": "froncer",
    "froncerais": "froncer",
    "froncerait": "froncer",
    "fronceras": "froncer",
    "froncerez": "froncer",
    "fronceriez": "froncer",
    "froncerions": "froncer",
    "froncerons": "froncer",
    "fronceront": "froncer",
    "fronces": "froncer",
    "froncez": "froncer",
    "fronciez": "froncer",
    "froncions": "froncer",
    "froncèrent": "froncer",
    "froncé": "froncer",
    "froncée": "froncer",
    "froncées": "froncer",
    "froncés": "froncer",
    "fronda": "fronder",
    "frondai": "fronder",
    "frondaient": "fronder",
    "frondais": "fronder",
    "frondaisons": "frondaison",
    "frondait": "fronder",
    "frondant": "fronder",
    "frondas": "fronder",
    "frondasse": "fronder",
    "frondassent": "fronder",
    "frondasses": "fronder",
    "frondassiez": "fronder",
    "frondassions": "fronder",
    "fronde": "fronder",
    "frondent": "fronder",
    "frondera": "fronder",
    "fronderai": "fronder",
    "fronderaient": "fronder",
    "fronderais": "fronder",
    "fronderait": "fronder",
    "fronderas": "fronder",
    "fronderez": "fronder",
    "fronderiez": "fronder",
    "fronderions": "fronder",
    "fronderons": "fronder",
    "fronderont": "fronder",
    "frondes": "fronder",
    "frondeurs": "frondeur",
    "frondeuse": "frondeur",
    "frondeuses": "frondeur",
    "frondez": "fronder",
    "frondiez": "fronder",
    "frondions": "fronder",
    "frondons": "fronder",
    "frondâmes": "fronder",
    "frondât": "fronder",
    "frondâtes": "fronder",
    "frondèrent": "fronder",
    "frondé": "fronder",
    "frondée": "fronder",
    "frondées": "fronder",
    "frondés": "fronder",
    "frontale": "frontal",
    "frontales": "frontal",
    "frontaliers": "frontalier",
    "frontalière": "frontalier",
    "frontalières": "frontalier",
    "frontaux": "frontal",
    "frontispices": "frontispice",
    "frontières": "frontière",
    "frontons": "fronton",
    "fronts": "front",
    "fronça": "froncer",
    "fronçai": "froncer",
    "fronçaient": "froncer",
    "fronçais": "froncer",
    "fronçait": "froncer",
    "fronçant": "froncer",
    "fronças": "froncer",
    "fronçasse": "froncer",
    "fronçassent": "froncer",
    "fronçasses": "froncer",
    "fronçassiez": "froncer",
    "fronçassions": "froncer",
    "fronçons": "froncer",
    "fronçâmes": "froncer",
    "fronçât": "froncer",
    "fronçâtes": "froncer",
    "frotta": "frotter",
    "frottages": "frottage",
    "frottai": "frotter",
    "frottaient": "frotter",
    "frottais": "frotter",
    "frottait": "frotter",
    "frottant": "frotter",
    "frottas": "frotter",
    "frottasse": "frotter",
    "frottassent": "frotter",
    "frottasses": "frotter",
    "frottassiez": "frotter",
    "frottassions": "frotter",
    "frotte": "frotter",
    "frottements": "frottement",
    "frottent": "frotter",
    "frottera": "frotter",
    "frotterai": "frotter",
    "frotteraient": "frotter",
    "frotterais": "frotter",
    "frotterait": "frotter",
    "frotteras": "frotter",
    "frotterez": "frotter",
    "frotteriez": "frotter",
    "frotterions": "frotter",
    "frotterons": "frotter",
    "frotteront": "frotter",
    "frottes": "frotter",
    "frotteurs": "frotteur",
    "frotteuse": "frotteur",
    "frotteuses": "frotteur",
    "frottez": "frotter",
    "frottiez": "frotter",
    "frottions": "frotter",
    "frottoirs": "frottoir",
    "frottons": "frotton",
    "frottâmes": "frotter",
    "frottât": "frotter",
    "frottâtes": "frotter",
    "frottèrent": "frotter",
    "frotté": "frotter",
    "frottée": "frotter",
    "frottées": "frotter",
    "frottés": "frotter",
    "frouements": "frouement",
    "froufrous": "froufrou",
    "froufrouta": "froufrouter",
    "froufroutai": "froufrouter",
    "froufroutaient": "froufrouter",
    "froufroutais": "froufrouter",
    "froufroutait": "froufrouter",
    "froufroutant": "froufrouter",
    "froufroutante": "froufroutant",
    "froufroutantes": "froufroutant",
    "froufroutants": "froufroutant",
    "froufroutas": "froufrouter",
    "froufroutasse": "froufrouter",
    "froufroutassent": "froufrouter",
    "froufroutasses": "froufrouter",
    "froufroutassiez": "froufrouter",
    "froufroutassions": "froufrouter",
    "froufroute": "froufrouter",
    "froufroutent": "froufrouter",
    "froufroutera": "froufrouter",
    "froufrouterai": "froufrouter",
    "froufrouteraient": "froufrouter",
    "froufrouterais": "froufrouter",
    "froufrouterait": "froufrouter",
    "froufrouteras": "froufrouter",
    "froufrouterez": "froufrouter",
    "froufrouteriez": "froufrouter",
    "froufrouterions": "froufrouter",
    "froufrouterons": "froufrouter",
    "froufrouteront": "froufrouter",
    "froufroutes": "froufrouter",
    "froufroutez": "froufrouter",
    "froufroutiez": "froufrouter",
    "froufroutions": "froufrouter",
    "froufroutons": "froufrouter",
    "froufroutâmes": "froufrouter",
    "froufroutât": "froufrouter",
    "froufroutâtes": "froufrouter",
    "froufroutèrent": "froufrouter",
    "froufrouté": "froufrouter",
    "frous-frous": "frou-frou",
    "froussarde": "froussard",
    "froussards": "froussard",
    "frousses": "frousse",
    "fructidors": "fructidor",
    "fructifia": "fructifier",
    "fructifiai": "fructifier",
    "fructifiaient": "fructifier",
    "fructifiais": "fructifier",
    "fructifiait": "fructifier",
    "fructifiant": "fructifier",
    "fructifias": "fructifier",
    "fructifiasse": "fructifier",
    "fructifiassent": "fructifier",
    "fructifiasses": "fructifier",
    "fructifiassiez": "fructifier",
    "fructifiassions": "fructifier",
    "fructifie": "fructifier",
    "fructifient": "fructifier",
    "fructifiera": "fructifier",
    "fructifierai": "fructifier",
    "fructifieraient": "fructifier",
    "fructifierais": "fructifier",
    "fructifierait": "fructifier",
    "fructifieras": "fructifier",
    "fructifierez": "fructifier",
    "fructifieriez": "fructifier",
    "fructifierions": "fructifier",
    "fructifierons": "fructifier",
    "fructifieront": "fructifier",
    "fructifies": "fructifier",
    "fructifiez": "fructifier",
    "fructifiiez": "fructifier",
    "fructifiions": "fructifier",
    "fructifions": "fructifier",
    "fructifiâmes": "fructifier",
    "fructifiât": "fructifier",
    "fructifiâtes": "fructifier",
    "fructifièrent": "fructifier",
    "fructifié": "fructifier",
    "fructoses": "fructose",
    "fructueuse": "fructueux",
    "fructueuses": "fructueux",
    "frugale": "frugal",
    "frugales": "frugal",
    "frugaux": "frugal",
    "frugivores": "frugivore",
    "fruiteries": "fruiterie",
    "fruitiers": "fruitier",
    "fruitière": "fruitier",
    "fruitières": "fruitier",
    "fruits": "fruit",
    "fruité": "fruiter",
    "fruitée": "fruiter",
    "fruitées": "fruité",
    "fruités": "fruiter",
    "frusques": "frusque",
    "frusquée": "frusquer",
    "frustes": "fruste",
    "frustra": "frustrer",
    "frustrai": "frustrer",
    "frustraient": "frustrer",
    "frustrais": "frustrer",
    "frustrait": "frustrer",
    "frustrant": "frustrer",
    "frustrante": "frustrant",
    "frustrantes": "frustrant",
    "frustras": "frustrer",
    "frustrasse": "frustrer",
    "frustrassent": "frustrer",
    "frustrasses": "frustrer",
    "frustrassiez": "frustrer",
    "frustrassions": "frustrer",
    "frustrations": "frustration",
    "frustre": "frustrer",
    "frustrent": "frustrer",
    "frustrera": "frustrer",
    "frustrerai": "frustrer",
    "frustreraient": "frustrer",
    "frustrerais": "frustrer",
    "frustrerait": "frustrer",
    "frustreras": "frustrer",
    "frustrerez": "frustrer",
    "frustreriez": "frustrer",
    "frustrerions": "frustrer",
    "frustrerons": "frustrer",
    "frustreront": "frustrer",
    "frustres": "frustrer",
    "frustrez": "frustrer",
    "frustriez": "frustrer",
    "frustrions": "frustrer",
    "frustrons": "frustrer",
    "frustrâmes": "frustrer",
    "frustrât": "frustrer",
    "frustrâtes": "frustrer",
    "frustrèrent": "frustrer",
    "frustré": "frustrer",
    "frustrée": "frustrer",
    "frustrées": "frustrer",
    "frustrés": "frustrer",
    "frères": "frère",
    "frète": "fréter",
    "frètent": "fréter",
    "frètes": "fréter",
    "frégates": "frégate",
    "frémi": "frémir",
    "frémira": "frémir",
    "frémirai": "frémir",
    "frémiraient": "frémir",
    "frémirais": "frémir",
    "frémirait": "frémir",
    "frémiras": "frémir",
    "frémirent": "frémir",
    "frémirez": "frémir",
    "frémiriez": "frémir",
    "frémirions": "frémir",
    "frémirons": "frémir",
    "frémiront": "frémir",
    "frémis": "frémir",
    "frémissaient": "frémir",
    "frémissais": "frémir",
    "frémissait": "frémir",
    "frémissant": "frémir",
    "frémissante": "frémissant",
    "frémissantes": "frémissant",
    "frémissants": "frémissant",
    "frémisse": "frémir",
    "frémissements": "frémissement",
    "frémissent": "frémir",
    "frémisses": "frémir",
    "frémissez": "frémir",
    "frémissiez": "frémir",
    "frémissions": "frémir",
    "frémissons": "frémir",
    "frémit": "frémir",
    "frémîmes": "frémir",
    "frémît": "frémir",
    "frémîtes": "frémir",
    "frénésies": "frénésie",
    "frénétiques": "frénétique",
    "fréquences": "fréquence",
    "fréquenta": "fréquenter",
    "fréquentables": "fréquentable",
    "fréquentai": "fréquenter",
    "fréquentaient": "fréquenter",
    "fréquentais": "fréquenter",
    "fréquentait": "fréquenter",
    "fréquentant": "fréquenter",
    "fréquentas": "fréquenter",
    "fréquentasse": "fréquenter",
    "fréquentassent": "fréquenter",
    "fréquentasses": "fréquenter",
    "fréquentassiez": "fréquenter",
    "fréquentassions": "fréquenter",
    "fréquentations": "fréquentation",
    "fréquente": "fréquenter",
    "fréquentent": "fréquenter",
    "fréquentera": "fréquenter",
    "fréquenterai": "fréquenter",
    "fréquenteraient": "fréquenter",
    "fréquenterais": "fréquenter",
    "fréquenterait": "fréquenter",
    "fréquenteras": "fréquenter",
    "fréquenterez": "fréquenter",
    "fréquenteriez": "fréquenter",
    "fréquenterions": "fréquenter",
    "fréquenterons": "fréquenter",
    "fréquenteront": "fréquenter",
    "fréquentes": "fréquenter",
    "fréquentez": "fréquenter",
    "fréquentiez": "fréquenter",
    "fréquentions": "fréquenter",
    "fréquentons": "fréquenter",
    "fréquents": "fréquent",
    "fréquentâmes": "fréquenter",
    "fréquentât": "fréquenter",
    "fréquentâtes": "fréquenter",
    "fréquentèrent": "fréquenter",
    "fréquenté": "fréquenter",
    "fréquentée": "fréquenter",
    "fréquentées": "fréquenter",
    "fréquentés": "fréquenter",
    "frérots": "frérot",
    "fréta": "fréter",
    "frétai": "fréter",
    "frétaient": "fréter",
    "frétais": "fréter",
    "frétait": "fréter",
    "frétant": "fréter",
    "frétas": "fréter",
    "frétasse": "fréter",
    "frétassent": "fréter",
    "frétasses": "fréter",
    "frétassiez": "fréter",
    "frétassions": "fréter",
    "frétera": "fréter",
    "fréterai": "fréter",
    "fréteraient": "fréter",
    "fréterais": "fréter",
    "fréterait": "fréter",
    "fréteras": "fréter",
    "fréterez": "fréter",
    "fréteriez": "fréter",
    "fréterions": "fréter",
    "fréterons": "fréter",
    "fréteront": "fréter",
    "frétez": "fréter",
    "frétiez": "fréter",
    "frétilla": "frétiller",
    "frétillai": "frétiller",
    "frétillaient": "frétiller",
    "frétillais": "frétiller",
    "frétillait": "frétiller",
    "frétillant": "frétiller",
    "frétillante": "frétillant",
    "frétillantes": "frétillant",
    "frétillants": "frétillant",
    "frétillarde": "frétillard",
    "frétillas": "frétiller",
    "frétillasse": "frétiller",
    "frétillassent": "frétiller",
    "frétillasses": "frétiller",
    "frétillassiez": "frétiller",
    "frétillassions": "frétiller",
    "frétille": "frétiller",
    "frétillements": "frétillement",
    "frétillent": "frétiller",
    "frétillera": "frétiller",
    "frétillerai": "frétiller",
    "frétilleraient": "frétiller",
    "frétillerais": "frétiller",
    "frétillerait": "frétiller",
    "frétilleras": "frétiller",
    "frétillerez": "frétiller",
    "frétilleriez": "frétiller",
    "frétillerions": "frétiller",
    "frétillerons": "frétiller",
    "frétilleront": "frétiller",
    "frétilles": "frétiller",
    "frétillez": "frétiller",
    "frétilliez": "frétiller",
    "frétillions": "frétiller",
    "frétillons": "frétiller",
    "frétillâmes": "frétiller",
    "frétillât": "frétiller",
    "frétillâtes": "frétiller",
    "frétillèrent": "frétiller",
    "frétillé": "frétiller",
    "frétions": "fréter",
    "frétons": "fréter",
    "frétâmes": "fréter",
    "frétât": "fréter",
    "frétâtes": "fréter",
    "frétèrent": "fréter",
    "frété": "fréter",
    "frétée": "fréter",
    "frétées": "fréter",
    "frétés": "fréter",
    "frêles": "frêle",
    "frênes": "frêne",
    "frêts": "frêt",
    "frôla": "frôler",
    "frôlai": "frôler",
    "frôlaient": "frôler",
    "frôlais": "frôler",
    "frôlait": "frôler",
    "frôlant": "frôler",
    "frôlas": "frôler",
    "frôlasse": "frôler",
    "frôlassent": "frôler",
    "frôlasses": "frôler",
    "frôlassiez": "frôler",
    "frôlassions": "frôler",
    "frôle": "frôler",
    "frôlements": "frôlement",
    "frôlent": "frôler",
    "frôlera": "frôler",
    "frôlerai": "frôler",
    "frôleraient": "frôler",
    "frôlerais": "frôler",
    "frôlerait": "frôler",
    "frôleras": "frôler",
    "frôlerez": "frôler",
    "frôleriez": "frôler",
    "frôlerions": "frôler",
    "frôlerons": "frôler",
    "frôleront": "frôler",
    "frôles": "frôler",
    "frôleurs": "frôleur",
    "frôleuse": "frôleur",
    "frôleuses": "frôleur",
    "frôlez": "frôler",
    "frôliez": "frôler",
    "frôlions": "frôler",
    "frôlons": "frôler",
    "frôlâmes": "frôler",
    "frôlât": "frôler",
    "frôlâtes": "frôler",
    "frôlèrent": "frôler",
    "frôlé": "frôler",
    "frôlée": "frôler",
    "frôlées": "frôler",
    "frôlés": "frôler",
    "fuchsias": "fuchsia",
    "fuchsines": "fuchsine",
    "fuel-oils": "fuel-oil",
    "fuels": "fuel",
    "fugaces": "fugace",
    "fugitifs": "fugitif",
    "fugitive": "fugitif",
    "fugitives": "fugitif",
    "fuguaient": "fuguer",
    "fuguait": "fuguer",
    "fugue": "fuguer",
    "fuguent": "fuguer",
    "fuguerais": "fuguer",
    "fugues": "fuguer",
    "fugueurs": "fugueur",
    "fugueuse": "fugueur",
    "fugueuses": "fugueur",
    "fuguèrent": "fuguer",
    "fugué": "fuguer",
    "fuguées": "fugué",
    "fui": "fuir",
    "fuie": "fuir",
    "fuient": "fuir",
    "fuies": "fuir",
    "fuira": "fuir",
    "fuirai": "fuir",
    "fuiraient": "fuir",
    "fuirais": "fuir",
    "fuirait": "fuir",
    "fuiras": "fuir",
    "fuirent": "fuir",
    "fuirez": "fuir",
    "fuiriez": "fuir",
    "fuirions": "fuir",
    "fuirons": "fuir",
    "fuiront": "fuir",
    "fuis": "fuir",
    "fuisse": "fuir",
    "fuissent": "fuir",
    "fuisses": "fuir",
    "fuissiez": "fuir",
    "fuissions": "fuir",
    "fuit": "fuir",
    "fuites": "fuite",
    "fulgores": "fulgore",
    "fulgura": "fulgurer",
    "fulgurai": "fulgurer",
    "fulguraient": "fulgurer",
    "fulgurais": "fulgurer",
    "fulgurait": "fulgurer",
    "fulgurances": "fulgurance",
    "fulgurant": "fulgurer",
    "fulgurante": "fulgurant",
    "fulgurantes": "fulgurant",
    "fulgurants": "fulgurant",
    "fulguras": "fulgurer",
    "fulgurasse": "fulgurer",
    "fulgurassent": "fulgurer",
    "fulgurasses": "fulgurer",
    "fulgurassiez": "fulgurer",
    "fulgurassions": "fulgurer",
    "fulgurations": "fulguration",
    "fulgure": "fulgurer",
    "fulgurent": "fulgurer",
    "fulgurera": "fulgurer",
    "fulgurerai": "fulgurer",
    "fulgureraient": "fulgurer",
    "fulgurerais": "fulgurer",
    "fulgurerait": "fulgurer",
    "fulgureras": "fulgurer",
    "fulgurerez": "fulgurer",
    "fulgureriez": "fulgurer",
    "fulgurerions": "fulgurer",
    "fulgurerons": "fulgurer",
    "fulgureront": "fulgurer",
    "fulgures": "fulgurer",
    "fulgurez": "fulgurer",
    "fulguriez": "fulgurer",
    "fulgurions": "fulgurer",
    "fulgurons": "fulgurer",
    "fulgurâmes": "fulgurer",
    "fulgurât": "fulgurer",
    "fulgurâtes": "fulgurer",
    "fulgurèrent": "fulgurer",
    "fulguré": "fulgurer",
    "fuligineuse": "fuligineux",
    "fuligineuses": "fuligineux",
    "fulls": "full",
    "fulmicotons": "fulmicoton",
    "fulmina": "fulminer",
    "fulminai": "fulminer",
    "fulminaient": "fulminer",
    "fulminais": "fulminer",
    "fulminait": "fulminer",
    "fulminant": "fulminer",
    "fulminante": "fulminant",
    "fulminantes": "fulminant",
    "fulminants": "fulminant",
    "fulminas": "fulminer",
    "fulminasse": "fulminer",
    "fulminassent": "fulminer",
    "fulminasses": "fulminer",
    "fulminassiez": "fulminer",
    "fulminassions": "fulminer",
    "fulminates": "fulminate",
    "fulminations": "fulmination",
    "fulmine": "fulminer",
    "fulminent": "fulminer",
    "fulminera": "fulminer",
    "fulminerai": "fulminer",
    "fulmineraient": "fulminer",
    "fulminerais": "fulminer",
    "fulminerait": "fulminer",
    "fulmineras": "fulminer",
    "fulminerez": "fulminer",
    "fulmineriez": "fulminer",
    "fulminerions": "fulminer",
    "fulminerons": "fulminer",
    "fulmineront": "fulminer",
    "fulmines": "fulminer",
    "fulminez": "fulminer",
    "fulminiez": "fulminer",
    "fulminions": "fulminer",
    "fulminons": "fulminer",
    "fulminâmes": "fulminer",
    "fulminât": "fulminer",
    "fulminâtes": "fulminer",
    "fulminèrent": "fulminer",
    "fulminé": "fulminer",
    "fulminée": "fulminer",
    "fulminées": "fulminer",
    "fulminés": "fulminer",
    "fuma": "fumer",
    "fumables": "fumable",
    "fumai": "fumer",
    "fumaient": "fumer",
    "fumaillé": "fumailler",
    "fumais": "fumer",
    "fumait": "fumer",
    "fumant": "fumer",
    "fumante": "fumant",
    "fumantes": "fumant",
    "fumants": "fumant",
    "fumas": "fumer",
    "fumasse": "fumer",
    "fumassent": "fumer",
    "fumasses": "fumer",
    "fumassiez": "fumer",
    "fumassions": "fumer",
    "fume": "fumer",
    "fume-cigares": "fume-cigare",
    "fume-cigarettes": "fume-cigarette",
    "fument": "fumer",
    "fumera": "fumer",
    "fumerai": "fumer",
    "fumeraient": "fumer",
    "fumerais": "fumer",
    "fumerait": "fumer",
    "fumeras": "fumer",
    "fumerez": "fumer",
    "fumeries": "fumerie",
    "fumeriez": "fumer",
    "fumerions": "fumer",
    "fumerolles": "fumerolle",
    "fumeronne": "fumeronner",
    "fumerons": "fumeron",
    "fumeront": "fumer",
    "fumes": "fumer",
    "fumeterres": "fumeterre",
    "fumets": "fumet",
    "fumeurs": "fumeur",
    "fumeuse": "fumeur",
    "fumeuses": "fumeur",
    "fumez": "fumer",
    "fumiers": "fumier",
    "fumiez": "fumer",
    "fumigateurs": "fumigateur",
    "fumigations": "fumigation",
    "fumige": "fumiger",
    "fumigea": "fumiger",
    "fumigeai": "fumiger",
    "fumigeaient": "fumiger",
    "fumigeais": "fumiger",
    "fumigeait": "fumiger",
    "fumigeant": "fumiger",
    "fumigeas": "fumiger",
    "fumigeasse": "fumiger",
    "fumigeassent": "fumiger",
    "fumigeasses": "fumiger",
    "fumigeassiez": "fumiger",
    "fumigeassions": "fumiger",
    "fumigent": "fumiger",
    "fumigeons": "fumiger",
    "fumigera": "fumiger",
    "fumigerai": "fumiger",
    "fumigeraient": "fumiger",
    "fumigerais": "fumiger",
    "fumigerait": "fumiger",
    "fumigeras": "fumiger",
    "fumigerez": "fumiger",
    "fumigeriez": "fumiger",
    "fumigerions": "fumiger",
    "fumigerons": "fumiger",
    "fumigeront": "fumiger",
    "fumiges": "fumiger",
    "fumigez": "fumiger",
    "fumigeâmes": "fumiger",
    "fumigeât": "fumiger",
    "fumigeâtes": "fumiger",
    "fumigiez": "fumiger",
    "fumigions": "fumiger",
    "fumigènes": "fumigène",
    "fumigèrent": "fumiger",
    "fumigé": "fumiger",
    "fumigée": "fumiger",
    "fumigées": "fumiger",
    "fumigés": "fumiger",
    "fumions": "fumer",
    "fumisteries": "fumisterie",
    "fumistes": "fumiste",
    "fumière": "fumier",
    "fumons": "fumer",
    "fumures": "fumure",
    "fumâmes": "fumer",
    "fumât": "fumer",
    "fumâtes": "fumer",
    "fumèrent": "fumer",
    "fumé": "fumer",
    "fumée": "fumer",
    "fumées": "fumer",
    "fumés": "fumer",
    "funambules": "funambule",
    "funestes": "funeste",
    "funiculaires": "funiculaire",
    "funs": "fun",
    "funèbres": "funèbre",
    "funéraires": "funéraire",
    "funérariums": "funérarium",
    "furent": "être",
    "fureta": "fureter",
    "furetai": "fureter",
    "furetaient": "fureter",
    "furetais": "fureter",
    "furetait": "fureter",
    "furetant": "fureter",
    "furetas": "fureter",
    "furetasse": "fureter",
    "furetassent": "fureter",
    "furetasses": "fureter",
    "furetassiez": "fureter",
    "furetassions": "fureter",
    "fureteurs": "fureteur",
    "fureteuse": "fureteur",
    "fureteuses": "fureteur",
    "furetez": "fureter",
    "furetiez": "fureter",
    "furetions": "fureter",
    "furetons": "fureter",
    "furets": "furet",
    "furetâmes": "fureter",
    "furetât": "fureter",
    "furetâtes": "fureter",
    "furetèrent": "fureter",
    "fureté": "fureter",
    "fureurs": "fureur",
    "furibarde": "furibard",
    "furibardes": "furibard",
    "furibonde": "furibond",
    "furibondes": "furibond",
    "furibonds": "furibond",
    "furies": "furie",
    "furieuse": "furieux",
    "furieuses": "furieux",
    "furoncles": "furoncle",
    "furonculoses": "furonculose",
    "furtifs": "furtif",
    "furtive": "furtif",
    "furtives": "furtif",
    "furète": "fureter",
    "furètent": "fureter",
    "furètera": "fureter",
    "furèterai": "fureter",
    "furèteraient": "fureter",
    "furèterais": "fureter",
    "furèterait": "fureter",
    "furèteras": "fureter",
    "furèterez": "fureter",
    "furèteriez": "fureter",
    "furèterions": "fureter",
    "furèterons": "fureter",
    "furèteront": "fureter",
    "furètes": "fureter",
    "fus": "être",
    "fusa": "fuser",
    "fusai": "fuser",
    "fusaient": "fuser",
    "fusains": "fusain",
    "fusais": "fuser",
    "fusait": "fuser",
    "fusant": "fuser",
    "fusante": "fusant",
    "fusants": "fusant",
    "fusas": "fuser",
    "fusasse": "fuser",
    "fusassent": "fuser",
    "fusasses": "fuser",
    "fusassiez": "fuser",
    "fusassions": "fuser",
    "fuse": "fuser",
    "fuseaux": "fuseau",
    "fusela": "fuseler",
    "fuselages": "fuselage",
    "fuselai": "fuseler",
    "fuselaient": "fuseler",
    "fuselais": "fuseler",
    "fuselait": "fuseler",
    "fuselant": "fuseler",
    "fuselas": "fuseler",
    "fuselasse": "fuseler",
    "fuselassent": "fuseler",
    "fuselasses": "fuseler",
    "fuselassiez": "fuseler",
    "fuselassions": "fuseler",
    "fuselez": "fuseler",
    "fuseliez": "fuseler",
    "fuselions": "fuseler",
    "fuselle": "fuseler",
    "fusellent": "fuseler",
    "fusellera": "fuseler",
    "fusellerai": "fuseler",
    "fuselleraient": "fuseler",
    "fusellerais": "fuseler",
    "fusellerait": "fuseler",
    "fuselleras": "fuseler",
    "fusellerez": "fuseler",
    "fuselleriez": "fuseler",
    "fusellerions": "fuseler",
    "fusellerons": "fuseler",
    "fuselleront": "fuseler",
    "fuselles": "fuseler",
    "fuselons": "fuseler",
    "fuselâmes": "fuseler",
    "fuselât": "fuseler",
    "fuselâtes": "fuseler",
    "fuselèrent": "fuseler",
    "fuselé": "fuseler",
    "fuselée": "fuseler",
    "fuselées": "fuseler",
    "fuselés": "fuseler",
    "fusent": "fuser",
    "fusera": "fuser",
    "fuserai": "fuser",
    "fuseraient": "fuser",
    "fuserais": "fuser",
    "fuserait": "fuser",
    "fuseras": "fuser",
    "fuserez": "fuser",
    "fuseriez": "fuser",
    "fuserions": "fuser",
    "fuserons": "fuser",
    "fuseront": "fuser",
    "fuses": "fuser",
    "fusez": "fuser",
    "fusibles": "fusible",
    "fusiez": "fuser",
    "fusiliers": "fusilier",
    "fusiliers-marins": "fusilier-marin",
    "fusilla": "fusiller",
    "fusillades": "fusillade",
    "fusillai": "fusiller",
    "fusillaient": "fusiller",
    "fusillais": "fusiller",
    "fusillait": "fusiller",
    "fusillant": "fusiller",
    "fusillas": "fusiller",
    "fusillasse": "fusiller",
    "fusillassent": "fusiller",
    "fusillasses": "fusiller",
    "fusillassiez": "fusiller",
    "fusillassions": "fusiller",
    "fusille": "fusiller",
    "fusillent": "fusiller",
    "fusillera": "fusiller",
    "fusillerai": "fusiller",
    "fusilleraient": "fusiller",
    "fusillerais": "fusiller",
    "fusillerait": "fusiller",
    "fusilleras": "fusiller",
    "fusillerez": "fusiller",
    "fusilleriez": "fusiller",
    "fusillerions": "fusiller",
    "fusillerons": "fusiller",
    "fusilleront": "fusiller",
    "fusilles": "fusiller",
    "fusilleurs": "fusilleur",
    "fusillez": "fusiller",
    "fusilliez": "fusiller",
    "fusillions": "fusiller",
    "fusillons": "fusiller",
    "fusillâmes": "fusiller",
    "fusillât": "fusiller",
    "fusillâtes": "fusiller",
    "fusillèrent": "fusiller",
    "fusillé": "fusiller",
    "fusillée": "fusiller",
    "fusillées": "fusiller",
    "fusillés": "fusiller",
    "fusils": "fusil",
    "fusils-mitrailleurs": "fusil-mitrailleur",
    "fusionna": "fusionner",
    "fusionnai": "fusionner",
    "fusionnaient": "fusionner",
    "fusionnais": "fusionner",
    "fusionnait": "fusionner",
    "fusionnant": "fusionner",
    "fusionnas": "fusionner",
    "fusionnasse": "fusionner",
    "fusionnassent": "fusionner",
    "fusionnasses": "fusionner",
    "fusionnassiez": "fusionner",
    "fusionnassions": "fusionner",
    "fusionne": "fusionner",
    "fusionnelle": "fusionnel",
    "fusionnent": "fusionner",
    "fusionnera": "fusionner",
    "fusionnerai": "fusionner",
    "fusionneraient": "fusionner",
    "fusionnerais": "fusionner",
    "fusionnerait": "fusionner",
    "fusionneras": "fusionner",
    "fusionnerez": "fusionner",
    "fusionneriez": "fusionner",
    "fusionnerions": "fusionner",
    "fusionnerons": "fusionner",
    "fusionneront": "fusionner",
    "fusionnes": "fusionner",
    "fusionnez": "fusionner",
    "fusionniez": "fusionner",
    "fusionnions": "fusionner",
    "fusionnites": "fusionnite",
    "fusionnons": "fusionner",
    "fusionnâmes": "fusionner",
    "fusionnât": "fusionner",
    "fusionnâtes": "fusionner",
    "fusionnèrent": "fusionner",
    "fusionné": "fusionner",
    "fusionnée": "fusionner",
    "fusionnées": "fusionner",
    "fusionnés": "fusionner",
    "fusions": "fusion",
    "fusons": "fuser",
    "fusse": "être",
    "fussent": "être",
    "fusses": "être",
    "fussiez": "être",
    "fussions": "être",
    "fustanelles": "fustanelle",
    "fustigations": "fustigation",
    "fustige": "fustiger",
    "fustigea": "fustiger",
    "fustigeai": "fustiger",
    "fustigeaient": "fustiger",
    "fustigeais": "fustiger",
    "fustigeait": "fustiger",
    "fustigeant": "fustiger",
    "fustigeas": "fustiger",
    "fustigeasse": "fustiger",
    "fustigeassent": "fustiger",
    "fustigeasses": "fustiger",
    "fustigeassiez": "fustiger",
    "fustigeassions": "fustiger",
    "fustigent": "fustiger",
    "fustigeons": "fustiger",
    "fustigera": "fustiger",
    "fustigerai": "fustiger",
    "fustigeraient": "fustiger",
    "fustigerais": "fustiger",
    "fustigerait": "fustiger",
    "fustigeras": "fustiger",
    "fustigerez": "fustiger",
    "fustigeriez": "fustiger",
    "fustigerions": "fustiger",
    "fustigerons": "fustiger",
    "fustigeront": "fustiger",
    "fustiges": "fustiger",
    "fustigez": "fustiger",
    "fustigeâmes": "fustiger",
    "fustigeât": "fustiger",
    "fustigeâtes": "fustiger",
    "fustigiez": "fustiger",
    "fustigions": "fustiger",
    "fustigèrent": "fustiger",
    "fustigé": "fustiger",
    "fustigée": "fustiger",
    "fustigées": "fustiger",
    "fustigés": "fustiger",
    "fusâmes": "fuser",
    "fusât": "fuser",
    "fusâtes": "fuser",
    "fusèrent": "fuser",
    "fusé": "fuser",
    "fusée": "fuser",
    "fusées": "fuser",
    "fusées-sondes": "fusée-sonde",
    "fut": "être",
    "futaies": "futaie",
    "futailles": "futaille",
    "futaines": "futaine",
    "futals": "futal",
    "futiles": "futile",
    "futilités": "futilité",
    "futons": "futon",
    "future": "futur",
    "futures": "futur",
    "futurismes": "futurisme",
    "futuristes": "futuriste",
    "futurologues": "futurologue",
    "futurs": "futur",
    "futée": "futé",
    "futées": "futé",
    "futés": "futé",
    "fuyaient": "fuir",
    "fuyais": "fuir",
    "fuyait": "fuir",
    "fuyant": "fuir",
    "fuyante": "fuyant",
    "fuyantes": "fuyant",
    "fuyants": "fuyant",
    "fuyarde": "fuyard",
    "fuyards": "fuyard",
    "fuyez": "fuir",
    "fuyiez": "fuir",
    "fuyions": "fuir",
    "fuyons": "fuir",
    "fuîmes": "fuir",
    "fuît": "fuir",
    "fuîtes": "fuir",
    "fâcha": "fâcher",
    "fâchai": "fâcher",
    "fâchaient": "fâcher",
    "fâchais": "fâcher",
    "fâchait": "fâcher",
    "fâchant": "fâcher",
    "fâchas": "fâcher",
    "fâchasse": "fâcher",
    "fâchassent": "fâcher",
    "fâchasses": "fâcher",
    "fâchassiez": "fâcher",
    "fâchassions": "fâcher",
    "fâche": "fâcher",
    "fâchent": "fâcher",
    "fâchera": "fâcher",
    "fâcherai": "fâcher",
    "fâcheraient": "fâcher",
    "fâcherais": "fâcher",
    "fâcherait": "fâcher",
    "fâcheras": "fâcher",
    "fâcherez": "fâcher",
    "fâcheries": "fâcherie",
    "fâcheriez": "fâcher",
    "fâcherions": "fâcher",
    "fâcherons": "fâcher",
    "fâcheront": "fâcher",
    "fâches": "fâcher",
    "fâcheuse": "fâcheux",
    "fâcheuses": "fâcheux",
    "fâchez": "fâcher",
    "fâchiez": "fâcher",
    "fâchions": "fâcher",
    "fâchons": "fâcher",
    "fâchâmes": "fâcher",
    "fâchât": "fâcher",
    "fâchâtes": "fâcher",
    "fâchèrent": "fâcher",
    "fâché": "fâcher",
    "fâchée": "fâcher",
    "fâchées": "fâcher",
    "fâchés": "fâcher",
    "fère": "fer",
    "fèves": "fève",
    "féale": "féal",
    "féales": "féal",
    "féaux": "féal",
    "fébriles": "fébrile",
    "fébrilités": "fébrilité",
    "fécale": "fécal",
    "fécales": "fécal",
    "fécaux": "fécal",
    "féconda": "féconder",
    "fécondai": "féconder",
    "fécondaient": "féconder",
    "fécondais": "féconder",
    "fécondait": "féconder",
    "fécondant": "féconder",
    "fécondante": "fécondant",
    "fécondas": "féconder",
    "fécondasse": "féconder",
    "fécondassent": "féconder",
    "fécondasses": "féconder",
    "fécondassiez": "féconder",
    "fécondassions": "féconder",
    "fécondations": "fécondation",
    "féconde": "féconder",
    "fécondent": "féconder",
    "fécondera": "féconder",
    "féconderai": "féconder",
    "féconderaient": "féconder",
    "féconderais": "féconder",
    "féconderait": "féconder",
    "féconderas": "féconder",
    "féconderez": "féconder",
    "féconderiez": "féconder",
    "féconderions": "féconder",
    "féconderons": "féconder",
    "féconderont": "féconder",
    "fécondes": "féconder",
    "fécondez": "féconder",
    "fécondiez": "féconder",
    "fécondions": "féconder",
    "fécondités": "fécondité",
    "fécondons": "féconder",
    "féconds": "fécond",
    "fécondâmes": "féconder",
    "fécondât": "féconder",
    "fécondâtes": "féconder",
    "fécondèrent": "féconder",
    "fécondé": "féconder",
    "fécondée": "féconder",
    "fécondées": "féconder",
    "fécondés": "féconder",
    "féculents": "féculent",
    "fécules": "fécule",
    "fédère": "fédérer",
    "fédèrent": "fédérer",
    "fédères": "fédérer",
    "fédéra": "fédérer",
    "fédérai": "fédérer",
    "fédéraient": "fédérer",
    "fédérais": "fédérer",
    "fédérait": "fédérer",
    "fédérale": "fédéral",
    "fédérales": "fédéral",
    "fédéralismes": "fédéralisme",
    "fédéralistes": "fédéraliste",
    "fédérant": "fédérer",
    "fédéras": "fédérer",
    "fédérasse": "fédérer",
    "fédérassent": "fédérer",
    "fédérasses": "fédérer",
    "fédérassiez": "fédérer",
    "fédérassions": "fédérer",
    "fédérateurs": "fédérateur",
    "fédératifs": "fédératif",
    "fédérations": "fédération",
    "fédérative": "fédératif",
    "fédératives": "fédératif",
    "fédératrice": "fédérateur",
    "fédératrices": "fédérateur",
    "fédéraux": "fédéral",
    "fédérera": "fédérer",
    "fédérerai": "fédérer",
    "fédéreraient": "fédérer",
    "fédérerais": "fédérer",
    "fédérerait": "fédérer",
    "fédéreras": "fédérer",
    "fédérerez": "fédérer",
    "fédéreriez": "fédérer",
    "fédérerions": "fédérer",
    "fédérerons": "fédérer",
    "fédéreront": "fédérer",
    "fédérez": "fédérer",
    "fédériez": "fédérer",
    "fédérions": "fédérer",
    "fédérons": "fédérer",
    "fédérâmes": "fédérer",
    "fédérât": "fédérer",
    "fédérâtes": "fédérer",
    "fédérèrent": "fédérer",
    "fédéré": "fédérer",
    "fédérée": "fédérer",
    "fédérées": "fédérer",
    "fédérés": "fédérer",
    "féeries": "féerie",
    "féeriques": "féerique",
    "fées": "fée",
    "félibres": "félibre",
    "félicita": "féliciter",
    "félicitai": "féliciter",
    "félicitaient": "féliciter",
    "félicitais": "féliciter",
    "félicitait": "féliciter",
    "félicitant": "féliciter",
    "félicitas": "féliciter",
    "félicitasse": "féliciter",
    "félicitassent": "féliciter",
    "félicitasses": "féliciter",
    "félicitassiez": "féliciter",
    "félicitassions": "féliciter",
    "félicitations": "félicitation",
    "félicite": "féliciter",
    "félicitent": "féliciter",
    "félicitera": "féliciter",
    "féliciterai": "féliciter",
    "féliciteraient": "féliciter",
    "féliciterais": "féliciter",
    "féliciterait": "féliciter",
    "féliciteras": "féliciter",
    "féliciterez": "féliciter",
    "féliciteriez": "féliciter",
    "féliciterions": "féliciter",
    "féliciterons": "féliciter",
    "féliciteront": "féliciter",
    "félicites": "féliciter",
    "félicitez": "féliciter",
    "félicitiez": "féliciter",
    "félicitions": "féliciter",
    "félicitons": "féliciter",
    "félicitâmes": "féliciter",
    "félicitât": "féliciter",
    "félicitâtes": "féliciter",
    "félicitèrent": "féliciter",
    "félicité": "féliciter",
    "félicitée": "féliciter",
    "félicitées": "féliciter",
    "félicités": "féliciter",
    "féline": "félin",
    "félines": "félin",
    "félins": "félin",
    "félonies": "félonie",
    "félonne": "félon",
    "félonnes": "félon",
    "félons": "félon",
    "féminine": "féminin",
    "féminines": "féminin",
    "féminins": "féminin",
    "féminisaient": "féminiser",
    "féminisations": "féminisation",
    "féminismes": "féminisme",
    "féministes": "féministe",
    "féminisé": "féminiser",
    "féminités": "féminité",
    "fémorale": "fémoral",
    "fémorales": "fémoral",
    "fémoraux": "fémoral",
    "fémurs": "fémur",
    "fénelonienne": "fénelonien",
    "féodale": "féodal",
    "féodales": "féodal",
    "féodalismes": "féodalisme",
    "féodalités": "féodalité",
    "féodaux": "féodal",
    "féras": "féra",
    "férias": "féria",
    "fériée": "férié",
    "fériées": "férié",
    "fériés": "férié",
    "féroces": "féroce",
    "férocités": "férocité",
    "féru": "férir",
    "férue": "féru",
    "férues": "féru",
    "férules": "férule",
    "férus": "féru",
    "fétiches": "fétiche",
    "féticheurs": "féticheur",
    "fétichisations": "fétichisation",
    "fétichismes": "fétichisme",
    "fétichistes": "fétichiste",
    "fétides": "fétide",
    "fétidités": "fétidité",
    "fétus": "fétu",
    "féveroles": "féverole",
    "févriers": "février",
    "fêla": "fêler",
    "fêlai": "fêler",
    "fêlaient": "fêler",
    "fêlais": "fêler",
    "fêlait": "fêler",
    "fêlant": "fêler",
    "fêlas": "fêler",
    "fêlasse": "fêler",
    "fêlassent": "fêler",
    "fêlasses": "fêler",
    "fêlassiez": "fêler",
    "fêlassions": "fêler",
    "fêle": "fêler",
    "fêlent": "fêler",
    "fêlera": "fêler",
    "fêlerai": "fêler",
    "fêleraient": "fêler",
    "fêlerais": "fêler",
    "fêlerait": "fêler",
    "fêleras": "fêler",
    "fêlerez": "fêler",
    "fêleriez": "fêler",
    "fêlerions": "fêler",
    "fêlerons": "fêler",
    "fêleront": "fêler",
    "fêles": "fêler",
    "fêlez": "fêler",
    "fêliez": "fêler",
    "fêlions": "fêler",
    "fêlons": "fêler",
    "fêlures": "fêlure",
    "fêlâmes": "fêler",
    "fêlât": "fêler",
    "fêlâtes": "fêler",
    "fêlèrent": "fêler",
    "fêlé": "fêler",
    "fêlée": "fêler",
    "fêlées": "fêler",
    "fêlés": "fêler",
    "fêta": "fêter",
    "fêtai": "fêter",
    "fêtaient": "fêter",
    "fêtais": "fêter",
    "fêtait": "fêter",
    "fêtant": "fêter",
    "fêtarde": "fêtard",
    "fêtardes": "fêtard",
    "fêtards": "fêtard",
    "fêtas": "fêter",
    "fêtasse": "fêter",
    "fêtassent": "fêter",
    "fêtasses": "fêter",
    "fêtassiez": "fêter",
    "fêtassions": "fêter",
    "fête": "fêter",
    "fêtent": "fêter",
    "fêtera": "fêter",
    "fêterai": "fêter",
    "fêteraient": "fêter",
    "fêterais": "fêter",
    "fêterait": "fêter",
    "fêteras": "fêter",
    "fêterez": "fêter",
    "fêteriez": "fêter",
    "fêterions": "fêter",
    "fêterons": "fêter",
    "fêteront": "fêter",
    "fêtes": "fêter",
    "fêtez": "fêter",
    "fêtiez": "fêter",
    "fêtions": "fêter",
    "fêtons": "fêter",
    "fêtâmes": "fêter",
    "fêtât": "fêter",
    "fêtâtes": "fêter",
    "fêtèrent": "fêter",
    "fêté": "fêter",
    "fêtée": "fêter",
    "fêtées": "fêter",
    "fêtés": "fêter",
    "fîmes": "faire",
    "fît": "faire",
    "fîtes": "faire",
    "föhns": "föhn",
    "fûmes": "être",
    "fût": "être",
    "fûtes": "être",
    "fûts": "fût",
    "führers": "führer",
    "gabardines": "gabardine",
    "gabares": "gabare",
    "gabariers": "gabarier",
    "gabarits": "gabarit",
    "gabarres": "gabarre",
    "gabe": "gaber",
    "gabegies": "gabegie",
    "gabelles": "gabelle",
    "gabelous": "gabelou",
    "gabiers": "gabier",
    "gabionnages": "gabionnage",
    "gabions": "gabion",
    "gables": "gable",
    "gabonaise": "gabonais",
    "gabonaises": "gabonais",
    "gadgets": "gadget",
    "gadins": "gadin",
    "gadoues": "gadoue",
    "gaffa": "gaffer",
    "gaffai": "gaffer",
    "gaffaient": "gaffer",
    "gaffais": "gaffer",
    "gaffait": "gaffer",
    "gaffant": "gaffer",
    "gaffas": "gaffer",
    "gaffasse": "gaffer",
    "gaffassent": "gaffer",
    "gaffasses": "gaffer",
    "gaffassiez": "gaffer",
    "gaffassions": "gaffer",
    "gaffe": "gaffer",
    "gaffent": "gaffer",
    "gaffera": "gaffer",
    "gafferai": "gaffer",
    "gafferaient": "gaffer",
    "gafferais": "gaffer",
    "gafferait": "gaffer",
    "gafferas": "gaffer",
    "gafferez": "gaffer",
    "gafferiez": "gaffer",
    "gafferions": "gaffer",
    "gafferons": "gaffer",
    "gafferont": "gaffer",
    "gaffes": "gaffer",
    "gaffeurs": "gaffeur",
    "gaffeuse": "gaffeur",
    "gaffeuses": "gaffeur",
    "gaffez": "gaffer",
    "gaffiez": "gaffer",
    "gaffions": "gaffer",
    "gaffons": "gaffer",
    "gaffâmes": "gaffer",
    "gaffât": "gaffer",
    "gaffâtes": "gaffer",
    "gaffèrent": "gaffer",
    "gaffé": "gaffer",
    "gaffée": "gaffer",
    "gaffées": "gaffer",
    "gaffés": "gaffer",
    "gagas": "gaga",
    "gage": "gager",
    "gagea": "gager",
    "gageai": "gager",
    "gageaient": "gager",
    "gageais": "gager",
    "gageait": "gager",
    "gageant": "gager",
    "gageas": "gager",
    "gageasse": "gager",
    "gageassent": "gager",
    "gageasses": "gager",
    "gageassiez": "gager",
    "gageassions": "gager",
    "gagent": "gager",
    "gageons": "gager",
    "gagera": "gager",
    "gagerai": "gager",
    "gageraient": "gager",
    "gagerais": "gager",
    "gagerait": "gager",
    "gageras": "gager",
    "gagerez": "gager",
    "gageriez": "gager",
    "gagerions": "gager",
    "gagerons": "gager",
    "gageront": "gager",
    "gages": "gager",
    "gageures": "gageure",
    "gagez": "gager",
    "gageâmes": "gager",
    "gageât": "gager",
    "gageâtes": "gager",
    "gagiez": "gager",
    "gagions": "gager",
    "gagmans": "gagman",
    "gagna": "gagner",
    "gagnages": "gagnage",
    "gagnai": "gagner",
    "gagnaient": "gagner",
    "gagnais": "gagner",
    "gagnait": "gagner",
    "gagnant": "gagner",
    "gagnante": "gagnant",
    "gagnantes": "gagnant",
    "gagnants": "gagnant",
    "gagnas": "gagner",
    "gagnasse": "gagner",
    "gagnassent": "gagner",
    "gagnasses": "gagner",
    "gagnassiez": "gagner",
    "gagnassions": "gagner",
    "gagne": "gagner",
    "gagnent": "gagner",
    "gagnera": "gagner",
    "gagnerai": "gagner",
    "gagneraient": "gagner",
    "gagnerais": "gagner",
    "gagnerait": "gagner",
    "gagneras": "gagner",
    "gagnerez": "gagner",
    "gagneriez": "gagner",
    "gagnerions": "gagner",
    "gagnerons": "gagner",
    "gagneront": "gagner",
    "gagnes": "gagner",
    "gagneurs": "gagneur",
    "gagneuse": "gagneur",
    "gagneuses": "gagneur",
    "gagnez": "gagner",
    "gagniez": "gagner",
    "gagnions": "gagner",
    "gagnons": "gagner",
    "gagnâmes": "gagner",
    "gagnât": "gagner",
    "gagnâtes": "gagner",
    "gagnèrent": "gagner",
    "gagné": "gagner",
    "gagnée": "gagner",
    "gagnées": "gagner",
    "gagnés": "gagner",
    "gags": "gag",
    "gagèrent": "gager",
    "gagé": "gager",
    "gagée": "gager",
    "gagées": "gager",
    "gagés": "gager",
    "gaie": "gai",
    "gaies": "gai",
    "gaietés": "gaieté",
    "gaillarde": "gaillard",
    "gaillardes": "gaillard",
    "gaillards": "gaillard",
    "gailletins": "gailletin",
    "gaillettes": "gaillette",
    "gainaient": "gainer",
    "gainait": "gainer",
    "gainent": "gainer",
    "gaines": "gaine",
    "gainiers": "gainier",
    "gains": "gain",
    "gainé": "gainer",
    "gainée": "gainer",
    "gainées": "gainer",
    "gainés": "gainer",
    "gais": "gai",
    "galactiques": "galactique",
    "galante": "galant",
    "galanteries": "galanterie",
    "galantes": "galant",
    "galantines": "galantine",
    "galantins": "galantin",
    "galantisait": "galantiser",
    "galantisé": "galantiser",
    "galants": "galant",
    "galapiats": "galapiat",
    "galas": "gala",
    "galates": "galate",
    "galaxies": "galaxie",
    "galbait": "galber",
    "galbes": "galbe",
    "galbé": "galber",
    "galbée": "galber",
    "galbées": "galber",
    "galbés": "galber",
    "galeries": "galerie",
    "galeries-refuges": "galerie-refuge",
    "galernes": "galerne",
    "gales": "gale",
    "galets": "galet",
    "galettes": "galette",
    "galeuse": "galeux",
    "galeuses": "galeux",
    "galgals": "galgal",
    "galhaubans": "galhauban",
    "galibots": "galibot",
    "galicienne": "galicien",
    "galiciennes": "galicien",
    "galiciens": "galicien",
    "galions": "galion",
    "galiotes": "galiote",
    "galipettes": "galipette",
    "galipots": "galipot",
    "gallant": "galler",
    "galles": "galle",
    "gallicane": "gallican",
    "gallicanes": "gallican",
    "gallicans": "gallican",
    "gallicismes": "gallicisme",
    "gallinacés": "gallinacé",
    "galliques": "gallique",
    "gallo-romaine": "gallo-romain",
    "gallo-romaines": "gallo-romain",
    "gallo-romains": "gallo-romain",
    "galloise": "gallois",
    "galloises": "gallois",
    "gallons": "gallon",
    "gallos": "gallo",
    "galoches": "galoche",
    "galoché": "galocher",
    "galochés": "galocher",
    "galonna": "galonner",
    "galonnai": "galonner",
    "galonnaient": "galonner",
    "galonnais": "galonner",
    "galonnait": "galonner",
    "galonnant": "galonner",
    "galonnas": "galonner",
    "galonnasse": "galonner",
    "galonnassent": "galonner",
    "galonnasses": "galonner",
    "galonnassiez": "galonner",
    "galonnassions": "galonner",
    "galonne": "galonner",
    "galonnent": "galonner",
    "galonnera": "galonner",
    "galonnerai": "galonner",
    "galonneraient": "galonner",
    "galonnerais": "galonner",
    "galonnerait": "galonner",
    "galonneras": "galonner",
    "galonnerez": "galonner",
    "galonneriez": "galonner",
    "galonnerions": "galonner",
    "galonnerons": "galonner",
    "galonneront": "galonner",
    "galonnes": "galonner",
    "galonnez": "galonner",
    "galonniez": "galonner",
    "galonnions": "galonner",
    "galonnons": "galonner",
    "galonnâmes": "galonner",
    "galonnât": "galonner",
    "galonnâtes": "galonner",
    "galonnèrent": "galonner",
    "galonné": "galonner",
    "galonnée": "galonner",
    "galonnées": "galonner",
    "galonnés": "galonner",
    "galons": "galon",
    "galopa": "galoper",
    "galopades": "galopade",
    "galopai": "galoper",
    "galopaient": "galoper",
    "galopais": "galoper",
    "galopait": "galoper",
    "galopant": "galoper",
    "galopante": "galopant",
    "galopantes": "galopant",
    "galopants": "galopant",
    "galopas": "galoper",
    "galopasse": "galoper",
    "galopassent": "galoper",
    "galopasses": "galoper",
    "galopassiez": "galoper",
    "galopassions": "galoper",
    "galope": "galoper",
    "galopent": "galoper",
    "galopera": "galoper",
    "galoperai": "galoper",
    "galoperaient": "galoper",
    "galoperais": "galoper",
    "galoperait": "galoper",
    "galoperas": "galoper",
    "galoperez": "galoper",
    "galoperiez": "galoper",
    "galoperions": "galoper",
    "galoperons": "galoper",
    "galoperont": "galoper",
    "galopes": "galoper",
    "galopez": "galoper",
    "galopiez": "galoper",
    "galopine": "galopin",
    "galopines": "galopin",
    "galopins": "galopin",
    "galopions": "galoper",
    "galopons": "galoper",
    "galops": "galop",
    "galopâmes": "galoper",
    "galopât": "galoper",
    "galopâtes": "galoper",
    "galopèrent": "galoper",
    "galopé": "galoper",
    "galoubets": "galoubet",
    "gals": "gal",
    "galtouses": "galtouse",
    "galures": "galure",
    "galvanisa": "galvaniser",
    "galvanisai": "galvaniser",
    "galvanisaient": "galvaniser",
    "galvanisais": "galvaniser",
    "galvanisait": "galvaniser",
    "galvanisant": "galvaniser",
    "galvanisas": "galvaniser",
    "galvanisasse": "galvaniser",
    "galvanisassent": "galvaniser",
    "galvanisasses": "galvaniser",
    "galvanisassiez": "galvaniser",
    "galvanisassions": "galvaniser",
    "galvanise": "galvaniser",
    "galvanisent": "galvaniser",
    "galvanisera": "galvaniser",
    "galvaniserai": "galvaniser",
    "galvaniseraient": "galvaniser",
    "galvaniserais": "galvaniser",
    "galvaniserait": "galvaniser",
    "galvaniseras": "galvaniser",
    "galvaniserez": "galvaniser",
    "galvaniseriez": "galvaniser",
    "galvaniserions": "galvaniser",
    "galvaniserons": "galvaniser",
    "galvaniseront": "galvaniser",
    "galvanises": "galvaniser",
    "galvanisez": "galvaniser",
    "galvanisiez": "galvaniser",
    "galvanisions": "galvaniser",
    "galvanisons": "galvaniser",
    "galvanisâmes": "galvaniser",
    "galvanisât": "galvaniser",
    "galvanisâtes": "galvaniser",
    "galvanisèrent": "galvaniser",
    "galvanisé": "galvaniser",
    "galvanisée": "galvaniser",
    "galvanisées": "galvaniser",
    "galvanisés": "galvaniser",
    "galvanos": "galvano",
    "galvauda": "galvauder",
    "galvaudai": "galvauder",
    "galvaudaient": "galvauder",
    "galvaudais": "galvauder",
    "galvaudait": "galvauder",
    "galvaudant": "galvauder",
    "galvaudas": "galvauder",
    "galvaudasse": "galvauder",
    "galvaudassent": "galvauder",
    "galvaudasses": "galvauder",
    "galvaudassiez": "galvauder",
    "galvaudassions": "galvauder",
    "galvaude": "galvauder",
    "galvaudent": "galvauder",
    "galvaudera": "galvauder",
    "galvauderai": "galvauder",
    "galvauderaient": "galvauder",
    "galvauderais": "galvauder",
    "galvauderait": "galvauder",
    "galvauderas": "galvauder",
    "galvauderez": "galvauder",
    "galvauderiez": "galvauder",
    "galvauderions": "galvauder",
    "galvauderons": "galvauder",
    "galvauderont": "galvauder",
    "galvaudes": "galvauder",
    "galvaudez": "galvauder",
    "galvaudiez": "galvauder",
    "galvaudions": "galvauder",
    "galvaudons": "galvauder",
    "galvaudâmes": "galvauder",
    "galvaudât": "galvauder",
    "galvaudâtes": "galvauder",
    "galvaudèrent": "galvauder",
    "galvaudé": "galvauder",
    "galvaudée": "galvauder",
    "galvaudées": "galvauder",
    "galvaudés": "galvauder",
    "galèje": "galéjer",
    "galèjent": "galéjer",
    "galèjes": "galéjer",
    "galère": "galérer",
    "galèrent": "galérer",
    "galères": "galérer",
    "galéasses": "galéasse",
    "galées": "galée",
    "galéja": "galéjer",
    "galéjades": "galéjade",
    "galéjai": "galéjer",
    "galéjaient": "galéjer",
    "galéjais": "galéjer",
    "galéjait": "galéjer",
    "galéjant": "galéjer",
    "galéjas": "galéjer",
    "galéjasse": "galéjer",
    "galéjassent": "galéjer",
    "galéjasses": "galéjer",
    "galéjassiez": "galéjer",
    "galéjassions": "galéjer",
    "galéjera": "galéjer",
    "galéjerai": "galéjer",
    "galéjeraient": "galéjer",
    "galéjerais": "galéjer",
    "galéjerait": "galéjer",
    "galéjeras": "galéjer",
    "galéjerez": "galéjer",
    "galéjeriez": "galéjer",
    "galéjerions": "galéjer",
    "galéjerons": "galéjer",
    "galéjeront": "galéjer",
    "galéjez": "galéjer",
    "galéjiez": "galéjer",
    "galéjions": "galéjer",
    "galéjons": "galéjer",
    "galéjâmes": "galéjer",
    "galéjât": "galéjer",
    "galéjâtes": "galéjer",
    "galéjèrent": "galéjer",
    "galéjé": "galéjer",
    "galéjée": "galéjer",
    "galéjées": "galéjer",
    "galéjés": "galéjer",
    "galérais": "galérer",
    "galérait": "galérer",
    "galériens": "galérien",
    "galéré": "galérer",
    "gamahuche": "gamahucher",
    "gambada": "gambader",
    "gambadaient": "gambader",
    "gambadais": "gambader",
    "gambadait": "gambader",
    "gambadant": "gambader",
    "gambadante": "gambadant",
    "gambade": "gambader",
    "gambadent": "gambader",
    "gambades": "gambader",
    "gambadeurs": "gambadeur",
    "gambadez": "gambader",
    "gambadèrent": "gambader",
    "gambas": "gamba",
    "gamberge": "gamberger",
    "gambergea": "gamberger",
    "gambergeaient": "gamberger",
    "gambergeais": "gamberger",
    "gambergeait": "gamberger",
    "gambergeant": "gamberger",
    "gambergent": "gamberger",
    "gambergeons": "gamberger",
    "gamberges": "gamberger",
    "gambergez": "gamberger",
    "gambergé": "gamberger",
    "gambettes": "gambette",
    "gambillait": "gambiller",
    "gambillant": "gambiller",
    "gambille": "gambiller",
    "gambilles": "gambiller",
    "gambilleurs": "gambilleur",
    "gambilleuses": "gambilleur",
    "gambillé": "gambiller",
    "gambits": "gambit",
    "gamelles": "gamelle",
    "gaminas": "gaminer",
    "gamine": "gamin",
    "gamineries": "gaminerie",
    "gamines": "gamin",
    "gamins": "gamin",
    "gammaglobulines": "gammaglobuline",
    "gammares": "gammare",
    "gammas": "gamma",
    "gammes": "gamme",
    "gammées": "gammée",
    "gamètes": "gamète",
    "ganaches": "ganache",
    "ganaderias": "ganaderia",
    "gandins": "gandin",
    "gandouras": "gandoura",
    "ganglionnaires": "ganglionnaire",
    "ganglions": "ganglion",
    "gangrena": "gangrener",
    "gangrenai": "gangrener",
    "gangrenaient": "gangrener",
    "gangrenais": "gangrener",
    "gangrenait": "gangrener",
    "gangrenant": "gangrener",
    "gangrenas": "gangrener",
    "gangrenasse": "gangrener",
    "gangrenassent": "gangrener",
    "gangrenasses": "gangrener",
    "gangrenassiez": "gangrener",
    "gangrenassions": "gangrener",
    "gangrenez": "gangrener",
    "gangreniez": "gangrener",
    "gangrenions": "gangrener",
    "gangrenons": "gangrener",
    "gangrenâmes": "gangrener",
    "gangrenât": "gangrener",
    "gangrenâtes": "gangrener",
    "gangrenèrent": "gangrener",
    "gangrené": "gangrener",
    "gangrenée": "gangrener",
    "gangrenées": "gangrener",
    "gangrenés": "gangrener",
    "gangrène": "gangrener",
    "gangrènent": "gangrener",
    "gangrènera": "gangrener",
    "gangrènerai": "gangrener",
    "gangrèneraient": "gangrener",
    "gangrènerais": "gangrener",
    "gangrènerait": "gangrener",
    "gangrèneras": "gangrener",
    "gangrènerez": "gangrener",
    "gangrèneriez": "gangrener",
    "gangrènerions": "gangrener",
    "gangrènerons": "gangrener",
    "gangrèneront": "gangrener",
    "gangrènes": "gangrener",
    "gangs": "gang",
    "gangsters": "gangster",
    "gangstérismes": "gangstérisme",
    "gangues": "gangue",
    "ganses": "ganse",
    "gansé": "ganser",
    "gansée": "ganser",
    "gantait": "ganter",
    "gantant": "ganter",
    "gante": "ganter",
    "gantelets": "gantelet",
    "ganteries": "ganterie",
    "gantiers": "gantier",
    "gantière": "gantier",
    "gantières": "gantier",
    "gants": "gant",
    "ganté": "ganter",
    "gantée": "ganter",
    "gantées": "ganter",
    "gantés": "ganter",
    "ganymèdes": "ganymède",
    "gapettes": "gapette",
    "gara": "garer",
    "garages": "garage",
    "garagistes": "garagiste",
    "garai": "garer",
    "garaient": "garer",
    "garais": "garer",
    "garait": "garer",
    "garances": "garance",
    "garant": "garer",
    "garante": "garant",
    "garantes": "garant",
    "garanti": "garantir",
    "garantie": "garantir",
    "garanties": "garantir",
    "garantira": "garantir",
    "garantirai": "garantir",
    "garantiraient": "garantir",
    "garantirais": "garantir",
    "garantirait": "garantir",
    "garantiras": "garantir",
    "garantirent": "garantir",
    "garantirez": "garantir",
    "garantiriez": "garantir",
    "garantirions": "garantir",
    "garantirons": "garantir",
    "garantiront": "garantir",
    "garantis": "garantir",
    "garantissaient": "garantir",
    "garantissais": "garantir",
    "garantissait": "garantir",
    "garantissant": "garantir",
    "garantisse": "garantir",
    "garantissent": "garantir",
    "garantisses": "garantir",
    "garantissez": "garantir",
    "garantissiez": "garantir",
    "garantissions": "garantir",
    "garantissons": "garantir",
    "garantit": "garantir",
    "garants": "garant",
    "garantîmes": "garantir",
    "garantît": "garantir",
    "garantîtes": "garantir",
    "garas": "garer",
    "garasse": "garer",
    "garassent": "garer",
    "garasses": "garer",
    "garassiez": "garer",
    "garassions": "garer",
    "garces": "garce",
    "garcettes": "garcette",
    "garda": "garder",
    "gardai": "garder",
    "gardaient": "garder",
    "gardais": "garder",
    "gardait": "garder",
    "gardant": "garder",
    "gardas": "garder",
    "gardasse": "garder",
    "gardassent": "garder",
    "gardasses": "garder",
    "gardassiez": "garder",
    "gardassions": "garder",
    "garde": "garder",
    "garde-côtes": "garde-côte",
    "garde-feux": "garde-feu",
    "garde-fous": "garde-fou",
    "garde-meubles": "garde-meuble",
    "garde-places": "garde-place",
    "garde-robes": "garde-robe",
    "garden-parties": "garden-party",
    "gardent": "garder",
    "gardera": "garder",
    "garderai": "garder",
    "garderaient": "garder",
    "garderais": "garder",
    "garderait": "garder",
    "garderas": "garder",
    "garderez": "garder",
    "garderies": "garderie",
    "garderiez": "garder",
    "garderions": "garder",
    "garderons": "garder",
    "garderont": "garder",
    "gardes": "garder",
    "gardes-barrière": "garde-barrière",
    "gardes-barrières": "garde-barrières",
    "gardes-champêtres": "garde-champêtre",
    "gardes-chasse": "garde-chasse",
    "gardes-chiourme": "garde-chiourme",
    "gardes-chiourmes": "garde-chiourme",
    "gardes-côtes": "garde-côtes",
    "gardes-françaises": "garde-française",
    "gardes-frontières": "garde-frontières",
    "gardes-magasin": "garde-magasin",
    "gardes-malade": "garde-malade",
    "gardes-marine": "garde-marine",
    "gardes-pêche": "garde-pêche",
    "gardes-rivière": "garde-rivière",
    "gardes-voie": "garde-voie",
    "gardes-voies": "garde-voie",
    "gardeurs": "gardeur",
    "gardeuse": "gardeur",
    "gardeuses": "gardeur",
    "gardez": "garder",
    "gardians": "gardian",
    "gardiennages": "gardiennage",
    "gardiennait": "gardienner",
    "gardienne": "gardien",
    "gardiennes": "gardien",
    "gardiens": "gardien",
    "gardiez": "garder",
    "gardions": "garder",
    "gardoise": "gardois",
    "gardoises": "gardois",
    "gardons": "gardon",
    "gardâmes": "garder",
    "gardât": "garder",
    "gardâtes": "garder",
    "gardèrent": "garder",
    "gardé": "garder",
    "gardée": "garder",
    "gardées": "garder",
    "gardénias": "gardénia",
    "gardés": "garder",
    "gare": "garer",
    "garennes": "garenne",
    "garent": "garer",
    "garera": "garer",
    "garerai": "garer",
    "gareraient": "garer",
    "garerais": "garer",
    "garerait": "garer",
    "gareras": "garer",
    "garerez": "garer",
    "gareriez": "garer",
    "garerions": "garer",
    "garerons": "garer",
    "gareront": "garer",
    "gares": "garer",
    "garez": "garer",
    "gargantuas": "gargantua",
    "gargantuesques": "gargantuesque",
    "gargarisa": "gargariser",
    "gargarisai": "gargariser",
    "gargarisaient": "gargariser",
    "gargarisais": "gargariser",
    "gargarisait": "gargariser",
    "gargarisant": "gargariser",
    "gargarisas": "gargariser",
    "gargarisasse": "gargariser",
    "gargarisassent": "gargariser",
    "gargarisasses": "gargariser",
    "gargarisassiez": "gargariser",
    "gargarisassions": "gargariser",
    "gargarise": "gargariser",
    "gargarisent": "gargariser",
    "gargarisera": "gargariser",
    "gargariserai": "gargariser",
    "gargariseraient": "gargariser",
    "gargariserais": "gargariser",
    "gargariserait": "gargariser",
    "gargariseras": "gargariser",
    "gargariserez": "gargariser",
    "gargariseriez": "gargariser",
    "gargariserions": "gargariser",
    "gargariserons": "gargariser",
    "gargariseront": "gargariser",
    "gargarises": "gargariser",
    "gargarisez": "gargariser",
    "gargarisiez": "gargariser",
    "gargarisions": "gargariser",
    "gargarismes": "gargarisme",
    "gargarisons": "gargariser",
    "gargarisâmes": "gargariser",
    "gargarisât": "gargariser",
    "gargarisâtes": "gargariser",
    "gargarisèrent": "gargariser",
    "gargarisé": "gargariser",
    "gargarisée": "gargariser",
    "gargarisées": "gargariser",
    "gargarisés": "gargariser",
    "gargotes": "gargote",
    "gargotiers": "gargotier",
    "gargouilla": "gargouiller",
    "gargouillaient": "gargouiller",
    "gargouillait": "gargouiller",
    "gargouillant": "gargouiller",
    "gargouillante": "gargouillant",
    "gargouille": "gargouiller",
    "gargouillements": "gargouillement",
    "gargouillent": "gargouiller",
    "gargouilles": "gargouille",
    "gargouillé": "gargouiller",
    "gargoulettes": "gargoulette",
    "gargousses": "gargousse",
    "garibaldienne": "garibaldien",
    "garibaldiennes": "garibaldien",
    "garibaldiens": "garibaldien",
    "gariez": "garer",
    "garions": "garer",
    "garnements": "garnement",
    "garni": "garnir",
    "garnie": "garnir",
    "garnies": "garnir",
    "garnira": "garnir",
    "garnirai": "garnir",
    "garniraient": "garnir",
    "garnirais": "garnir",
    "garnirait": "garnir",
    "garniras": "garnir",
    "garnirent": "garnir",
    "garnirez": "garnir",
    "garniriez": "garnir",
    "garnirions": "garnir",
    "garnirons": "garnir",
    "garniront": "garnir",
    "garnis": "garnir",
    "garnisons": "garnison",
    "garnissaient": "garnir",
    "garnissais": "garnir",
    "garnissait": "garnir",
    "garnissant": "garnir",
    "garnisse": "garnir",
    "garnissent": "garnir",
    "garnisses": "garnir",
    "garnissez": "garnir",
    "garnissiez": "garnir",
    "garnissions": "garnir",
    "garnissons": "garnir",
    "garnit": "garnir",
    "garnitures": "garniture",
    "garnîmes": "garnir",
    "garnît": "garnir",
    "garnîtes": "garnir",
    "garons": "garer",
    "garous": "garou",
    "garrigues": "garrigue",
    "garrots": "garrot",
    "garrotta": "garrotter",
    "garrottai": "garrotter",
    "garrottaient": "garrotter",
    "garrottais": "garrotter",
    "garrottait": "garrotter",
    "garrottant": "garrotter",
    "garrottas": "garrotter",
    "garrottasse": "garrotter",
    "garrottassent": "garrotter",
    "garrottasses": "garrotter",
    "garrottassiez": "garrotter",
    "garrottassions": "garrotter",
    "garrotte": "garrotter",
    "garrottent": "garrotter",
    "garrottera": "garrotter",
    "garrotterai": "garrotter",
    "garrotteraient": "garrotter",
    "garrotterais": "garrotter",
    "garrotterait": "garrotter",
    "garrotteras": "garrotter",
    "garrotterez": "garrotter",
    "garrotteriez": "garrotter",
    "garrotterions": "garrotter",
    "garrotterons": "garrotter",
    "garrotteront": "garrotter",
    "garrottes": "garrotter",
    "garrottez": "garrotter",
    "garrottiez": "garrotter",
    "garrottions": "garrotter",
    "garrottons": "garrotter",
    "garrottâmes": "garrotter",
    "garrottât": "garrotter",
    "garrottâtes": "garrotter",
    "garrottèrent": "garrotter",
    "garrotté": "garrotter",
    "garrottée": "garrotter",
    "garrottées": "garrotter",
    "garrottés": "garrotter",
    "garâmes": "garer",
    "garât": "garer",
    "garâtes": "garer",
    "garçonne": "garçon",
    "garçonnes": "garçon",
    "garçonnets": "garçonnet",
    "garçonniers": "garçonnier",
    "garçonnière": "garçonnier",
    "garçonnières": "garçonnière",
    "garçons": "garçon",
    "garèrent": "garer",
    "garé": "garer",
    "garée": "garer",
    "garées": "garer",
    "garés": "garer",
    "gas-oils": "gas-oil",
    "gasconne": "gascon",
    "gasconnes": "gascon",
    "gascons": "gascon",
    "gasifications": "gasification",
    "gasoils": "gasoil",
    "gaspards": "gaspard",
    "gaspilla": "gaspiller",
    "gaspillages": "gaspillage",
    "gaspillai": "gaspiller",
    "gaspillaient": "gaspiller",
    "gaspillais": "gaspiller",
    "gaspillait": "gaspiller",
    "gaspillant": "gaspiller",
    "gaspillas": "gaspiller",
    "gaspillasse": "gaspiller",
    "gaspillassent": "gaspiller",
    "gaspillasses": "gaspiller",
    "gaspillassiez": "gaspiller",
    "gaspillassions": "gaspiller",
    "gaspille": "gaspiller",
    "gaspillent": "gaspiller",
    "gaspillera": "gaspiller",
    "gaspillerai": "gaspiller",
    "gaspilleraient": "gaspiller",
    "gaspillerais": "gaspiller",
    "gaspillerait": "gaspiller",
    "gaspilleras": "gaspiller",
    "gaspillerez": "gaspiller",
    "gaspilleriez": "gaspiller",
    "gaspillerions": "gaspiller",
    "gaspillerons": "gaspiller",
    "gaspilleront": "gaspiller",
    "gaspilles": "gaspiller",
    "gaspilleurs": "gaspilleur",
    "gaspilleuse": "gaspilleur",
    "gaspilleuses": "gaspilleur",
    "gaspillez": "gaspiller",
    "gaspilliez": "gaspiller",
    "gaspillions": "gaspiller",
    "gaspillons": "gaspiller",
    "gaspillâmes": "gaspiller",
    "gaspillât": "gaspiller",
    "gaspillâtes": "gaspiller",
    "gaspillèrent": "gaspiller",
    "gaspillé": "gaspiller",
    "gaspillée": "gaspiller",
    "gaspillées": "gaspiller",
    "gaspillés": "gaspiller",
    "gastralgies": "gastralgie",
    "gastriques": "gastrique",
    "gastrites": "gastrite",
    "gastritiques": "gastritique",
    "gastro-entérologies": "gastro-entérologie",
    "gastro-entérologues": "gastro-entérologue",
    "gastro-intestinale": "gastro-intestinal",
    "gastro-intestinaux": "gastro-intestinal",
    "gastronomes": "gastronome",
    "gastronomies": "gastronomie",
    "gastronomiques": "gastronomique",
    "gastrulas": "gastrula",
    "gastéropodes": "gastéropode",
    "gattiliers": "gattilier",
    "gaucheries": "gaucherie",
    "gauchers": "gaucher",
    "gauches": "gauche",
    "gauchi": "gauchir",
    "gauchie": "gauchir",
    "gauchies": "gauchir",
    "gauchira": "gauchir",
    "gauchirai": "gauchir",
    "gauchiraient": "gauchir",
    "gauchirais": "gauchir",
    "gauchirait": "gauchir",
    "gauchiras": "gauchir",
    "gauchirent": "gauchir",
    "gauchirez": "gauchir",
    "gauchiriez": "gauchir",
    "gauchirions": "gauchir",
    "gauchirons": "gauchir",
    "gauchiront": "gauchir",
    "gauchis": "gauchir",
    "gauchisante": "gauchisant",
    "gauchisantes": "gauchisant",
    "gauchismes": "gauchisme",
    "gauchissaient": "gauchir",
    "gauchissais": "gauchir",
    "gauchissait": "gauchir",
    "gauchissant": "gauchir",
    "gauchisse": "gauchir",
    "gauchissent": "gauchir",
    "gauchisses": "gauchir",
    "gauchissez": "gauchir",
    "gauchissiez": "gauchir",
    "gauchissions": "gauchir",
    "gauchissons": "gauchir",
    "gauchistes": "gauchiste",
    "gauchit": "gauchir",
    "gauchos": "gaucho",
    "gauchère": "gaucher",
    "gauchères": "gaucher",
    "gauchîmes": "gauchir",
    "gauchît": "gauchir",
    "gauchîtes": "gauchir",
    "gaudes": "gaude",
    "gaudi": "gaudir",
    "gaudie": "gaudir",
    "gaudies": "gaudir",
    "gaudira": "gaudir",
    "gaudirai": "gaudir",
    "gaudiraient": "gaudir",
    "gaudirais": "gaudir",
    "gaudirait": "gaudir",
    "gaudiras": "gaudir",
    "gaudirent": "gaudir",
    "gaudirez": "gaudir",
    "gaudiriez": "gaudir",
    "gaudirions": "gaudir",
    "gaudirons": "gaudir",
    "gaudiront": "gaudir",
    "gaudis": "gaudir",
    "gaudissaient": "gaudir",
    "gaudissais": "gaudir",
    "gaudissait": "gaudir",
    "gaudissant": "gaudir",
    "gaudisse": "gaudir",
    "gaudissent": "gaudir",
    "gaudisses": "gaudir",
    "gaudissez": "gaudir",
    "gaudissiez": "gaudir",
    "gaudissions": "gaudir",
    "gaudissons": "gaudir",
    "gaudit": "gaudir",
    "gaudrioles": "gaudriole",
    "gaudîmes": "gaudir",
    "gaudît": "gaudir",
    "gaudîtes": "gaudir",
    "gaufra": "gaufrer",
    "gaufrai": "gaufrer",
    "gaufraient": "gaufrer",
    "gaufrais": "gaufrer",
    "gaufrait": "gaufrer",
    "gaufrant": "gaufrer",
    "gaufras": "gaufrer",
    "gaufrasse": "gaufrer",
    "gaufrassent": "gaufrer",
    "gaufrasses": "gaufrer",
    "gaufrassiez": "gaufrer",
    "gaufrassions": "gaufrer",
    "gaufre": "gaufrer",
    "gaufrent": "gaufrer",
    "gaufrera": "gaufrer",
    "gaufrerai": "gaufrer",
    "gaufreraient": "gaufrer",
    "gaufrerais": "gaufrer",
    "gaufrerait": "gaufrer",
    "gaufreras": "gaufrer",
    "gaufrerez": "gaufrer",
    "gaufreriez": "gaufrer",
    "gaufrerions": "gaufrer",
    "gaufrerons": "gaufrer",
    "gaufreront": "gaufrer",
    "gaufres": "gaufrer",
    "gaufrettes": "gaufrette",
    "gaufrez": "gaufrer",
    "gaufriez": "gaufrer",
    "gaufrions": "gaufrer",
    "gaufrons": "gaufrer",
    "gaufrâmes": "gaufrer",
    "gaufrât": "gaufrer",
    "gaufrâtes": "gaufrer",
    "gaufrèrent": "gaufrer",
    "gaufré": "gaufrer",
    "gaufrée": "gaufrer",
    "gaufrées": "gaufrer",
    "gaufrés": "gaufrer",
    "gaulant": "gauler",
    "gauldos": "gauldo",
    "gaule": "gauler",
    "gaulerais": "gauler",
    "gaulerait": "gauler",
    "gaules": "gaule",
    "gaullienne": "gaullien",
    "gaulliennes": "gaullien",
    "gaulliens": "gaullien",
    "gaullismes": "gaullisme",
    "gaullistes": "gaulliste",
    "gauloise": "gaulois",
    "gauloiseries": "gauloiserie",
    "gauloises": "gaulois",
    "gaulèrent": "gauler",
    "gaulé": "gauler",
    "gaulée": "gauler",
    "gaupes": "gaupe",
    "gaussa": "gausser",
    "gaussai": "gausser",
    "gaussaient": "gausser",
    "gaussais": "gausser",
    "gaussait": "gausser",
    "gaussant": "gausser",
    "gaussas": "gausser",
    "gaussasse": "gausser",
    "gaussassent": "gausser",
    "gaussasses": "gausser",
    "gaussassiez": "gausser",
    "gaussassions": "gausser",
    "gausse": "gausser",
    "gaussent": "gausser",
    "gaussera": "gausser",
    "gausserai": "gausser",
    "gausseraient": "gausser",
    "gausserais": "gausser",
    "gausserait": "gausser",
    "gausseras": "gausser",
    "gausserez": "gausser",
    "gausseriez": "gausser",
    "gausserions": "gausser",
    "gausserons": "gausser",
    "gausseront": "gausser",
    "gausses": "gausser",
    "gaussez": "gausser",
    "gaussiez": "gausser",
    "gaussions": "gausser",
    "gaussons": "gausser",
    "gaussâmes": "gausser",
    "gaussât": "gausser",
    "gaussâtes": "gausser",
    "gaussèrent": "gausser",
    "gaussé": "gausser",
    "gaussée": "gausser",
    "gaussées": "gausser",
    "gaussés": "gausser",
    "gava": "gaver",
    "gavai": "gaver",
    "gavaient": "gaver",
    "gavais": "gaver",
    "gavait": "gaver",
    "gavant": "gaver",
    "gavas": "gaver",
    "gavasse": "gaver",
    "gavassent": "gaver",
    "gavasses": "gaver",
    "gavassiez": "gaver",
    "gavassions": "gaver",
    "gave": "gaver",
    "gavent": "gaver",
    "gavera": "gaver",
    "gaverai": "gaver",
    "gaveraient": "gaver",
    "gaverais": "gaver",
    "gaverait": "gaver",
    "gaveras": "gaver",
    "gaverez": "gaver",
    "gaveriez": "gaver",
    "gaverions": "gaver",
    "gaverons": "gaver",
    "gaveront": "gaver",
    "gaves": "gaver",
    "gavez": "gaver",
    "gavials": "gavial",
    "gaviez": "gaver",
    "gavions": "gaver",
    "gavons": "gaver",
    "gavottes": "gavotte",
    "gavroches": "gavroche",
    "gavâmes": "gaver",
    "gavât": "gaver",
    "gavâtes": "gaver",
    "gavèrent": "gaver",
    "gavé": "gaver",
    "gavée": "gaver",
    "gavées": "gaver",
    "gavés": "gaver",
    "gayals": "gayal",
    "gays": "gay",
    "gaza": "gazer",
    "gazai": "gazer",
    "gazaient": "gazer",
    "gazais": "gazer",
    "gazait": "gazer",
    "gazant": "gazer",
    "gazas": "gazer",
    "gazasse": "gazer",
    "gazassent": "gazer",
    "gazasses": "gazer",
    "gazassiez": "gazer",
    "gazassions": "gazer",
    "gaze": "gazer",
    "gazelles": "gazelle",
    "gazent": "gazer",
    "gazera": "gazer",
    "gazerai": "gazer",
    "gazeraient": "gazer",
    "gazerais": "gazer",
    "gazerait": "gazer",
    "gazeras": "gazer",
    "gazerez": "gazer",
    "gazeriez": "gazer",
    "gazerions": "gazer",
    "gazerons": "gazer",
    "gazeront": "gazer",
    "gazes": "gazer",
    "gazetiers": "gazetier",
    "gazettes": "gazette",
    "gazeuse": "gazeux",
    "gazeuses": "gazeux",
    "gazez": "gazer",
    "gaziers": "gazier",
    "gaziez": "gazer",
    "gazinières": "gazinière",
    "gazions": "gazer",
    "gazoducs": "gazoduc",
    "gazogènes": "gazogène",
    "gazoles": "gazole",
    "gazolines": "gazoline",
    "gazomètres": "gazomètre",
    "gazonna": "gazonner",
    "gazonnai": "gazonner",
    "gazonnaient": "gazonner",
    "gazonnais": "gazonner",
    "gazonnait": "gazonner",
    "gazonnant": "gazonner",
    "gazonnas": "gazonner",
    "gazonnasse": "gazonner",
    "gazonnassent": "gazonner",
    "gazonnasses": "gazonner",
    "gazonnassiez": "gazonner",
    "gazonnassions": "gazonner",
    "gazonne": "gazonner",
    "gazonnent": "gazonner",
    "gazonnera": "gazonner",
    "gazonnerai": "gazonner",
    "gazonneraient": "gazonner",
    "gazonnerais": "gazonner",
    "gazonnerait": "gazonner",
    "gazonneras": "gazonner",
    "gazonnerez": "gazonner",
    "gazonneriez": "gazonner",
    "gazonnerions": "gazonner",
    "gazonnerons": "gazonner",
    "gazonneront": "gazonner",
    "gazonnes": "gazonner",
    "gazonnez": "gazonner",
    "gazonniez": "gazonner",
    "gazonnions": "gazonner",
    "gazonnons": "gazonner",
    "gazonnâmes": "gazonner",
    "gazonnât": "gazonner",
    "gazonnâtes": "gazonner",
    "gazonnèrent": "gazonner",
    "gazonné": "gazonner",
    "gazonnée": "gazonner",
    "gazonnées": "gazonner",
    "gazonnés": "gazonner",
    "gazons": "gazon",
    "gazouilla": "gazouiller",
    "gazouillai": "gazouiller",
    "gazouillaient": "gazouiller",
    "gazouillais": "gazouiller",
    "gazouillait": "gazouiller",
    "gazouillant": "gazouiller",
    "gazouillante": "gazouillant",
    "gazouillants": "gazouillant",
    "gazouillas": "gazouiller",
    "gazouillasse": "gazouiller",
    "gazouillassent": "gazouiller",
    "gazouillasses": "gazouiller",
    "gazouillassiez": "gazouiller",
    "gazouillassions": "gazouiller",
    "gazouille": "gazouiller",
    "gazouillements": "gazouillement",
    "gazouillent": "gazouiller",
    "gazouillera": "gazouiller",
    "gazouillerai": "gazouiller",
    "gazouilleraient": "gazouiller",
    "gazouillerais": "gazouiller",
    "gazouillerait": "gazouiller",
    "gazouilleras": "gazouiller",
    "gazouillerez": "gazouiller",
    "gazouilleriez": "gazouiller",
    "gazouillerions": "gazouiller",
    "gazouillerons": "gazouiller",
    "gazouilleront": "gazouiller",
    "gazouilles": "gazouiller",
    "gazouilleurs": "gazouilleur",
    "gazouillez": "gazouiller",
    "gazouilliez": "gazouiller",
    "gazouillions": "gazouiller",
    "gazouillons": "gazouiller",
    "gazouillâmes": "gazouiller",
    "gazouillât": "gazouiller",
    "gazouillâtes": "gazouiller",
    "gazouillèrent": "gazouiller",
    "gazouillé": "gazouiller",
    "gazouillée": "gazouiller",
    "gazouillées": "gazouiller",
    "gazouillés": "gazouiller",
    "gazâmes": "gazer",
    "gazât": "gazer",
    "gazâtes": "gazer",
    "gazèrent": "gazer",
    "gazé": "gazer",
    "gazée": "gazer",
    "gazées": "gazer",
    "gazéifia": "gazéifier",
    "gazéifiai": "gazéifier",
    "gazéifiaient": "gazéifier",
    "gazéifiais": "gazéifier",
    "gazéifiait": "gazéifier",
    "gazéifiant": "gazéifier",
    "gazéifias": "gazéifier",
    "gazéifiasse": "gazéifier",
    "gazéifiassent": "gazéifier",
    "gazéifiasses": "gazéifier",
    "gazéifiassiez": "gazéifier",
    "gazéifiassions": "gazéifier",
    "gazéifications": "gazéification",
    "gazéifie": "gazéifier",
    "gazéifient": "gazéifier",
    "gazéifiera": "gazéifier",
    "gazéifierai": "gazéifier",
    "gazéifieraient": "gazéifier",
    "gazéifierais": "gazéifier",
    "gazéifierait": "gazéifier",
    "gazéifieras": "gazéifier",
    "gazéifierez": "gazéifier",
    "gazéifieriez": "gazéifier",
    "gazéifierions": "gazéifier",
    "gazéifierons": "gazéifier",
    "gazéifieront": "gazéifier",
    "gazéifies": "gazéifier",
    "gazéifiez": "gazéifier",
    "gazéifiiez": "gazéifier",
    "gazéifiions": "gazéifier",
    "gazéifions": "gazéifier",
    "gazéifiâmes": "gazéifier",
    "gazéifiât": "gazéifier",
    "gazéifiâtes": "gazéifier",
    "gazéifièrent": "gazéifier",
    "gazéifié": "gazéifier",
    "gazéifiée": "gazéifier",
    "gazéifiées": "gazéifier",
    "gazéifiés": "gazéifier",
    "gazés": "gazer",
    "gaéliques": "gaélique",
    "gaîtés": "gaîté",
    "gaïacs": "gaïac",
    "geais": "geai",
    "geckos": "gecko",
    "geignaient": "geindre",
    "geignais": "geindre",
    "geignait": "geindre",
    "geignant": "geindre",
    "geignante": "geignant",
    "geignantes": "geignant",
    "geignarde": "geignard",
    "geignardes": "geignard",
    "geignardises": "geignardise",
    "geignards": "geignard",
    "geigne": "geindre",
    "geignements": "geignement",
    "geignent": "geindre",
    "geignes": "geindre",
    "geignez": "geindre",
    "geigniez": "geindre",
    "geignions": "geindre",
    "geignirent": "geindre",
    "geignis": "geindre",
    "geignisse": "geindre",
    "geignissent": "geindre",
    "geignisses": "geindre",
    "geignissiez": "geindre",
    "geignissions": "geindre",
    "geignit": "geindre",
    "geignons": "geindre",
    "geignîmes": "geindre",
    "geignît": "geindre",
    "geignîtes": "geindre",
    "geindra": "geindre",
    "geindrai": "geindre",
    "geindraient": "geindre",
    "geindrais": "geindre",
    "geindrait": "geindre",
    "geindras": "geindre",
    "geindrez": "geindre",
    "geindriez": "geindre",
    "geindrions": "geindre",
    "geindrons": "geindre",
    "geindront": "geindre",
    "geins": "geindre",
    "geint": "geindre",
    "geishas": "geisha",
    "gela": "geler",
    "gelai": "geler",
    "gelaient": "geler",
    "gelais": "geler",
    "gelait": "geler",
    "gelant": "geler",
    "gelas": "geler",
    "gelasse": "geler",
    "gelassent": "geler",
    "gelasses": "geler",
    "gelassiez": "geler",
    "gelassions": "geler",
    "gelez": "geler",
    "geliez": "geler",
    "gelions": "geler",
    "gelons": "geler",
    "gels": "gel",
    "gelures": "gelure",
    "gelâmes": "geler",
    "gelât": "geler",
    "gelâtes": "geler",
    "gelèrent": "geler",
    "gelé": "geler",
    "gelée": "geler",
    "gelées": "geler",
    "gelés": "geler",
    "gemmaux": "gemmail",
    "gemmes": "gemme",
    "gencives": "gencive",
    "gendarmeries": "gendarmerie",
    "gendarmes": "gendarme",
    "gendelettres": "gendelettre",
    "gendres": "gendre",
    "genets": "genet",
    "genettes": "genette",
    "genevoise": "genevois",
    "genevoises": "genevois",
    "genièvres": "genièvre",
    "genouillères": "genouillère",
    "genoux": "genou",
    "genres": "genre",
    "gente": "gent",
    "gentes": "gent",
    "gentianes": "gentiane",
    "gentilhommière": "gentilhommier",
    "gentilhommières": "gentilhommier",
    "gentille": "gentil",
    "gentilles": "gentil",
    "gentillesses": "gentillesse",
    "gentillets": "gentillet",
    "gentillette": "gentillet",
    "gentils": "gentil",
    "gentilshommes": "gentilhomme",
    "gentlemans": "gentleman",
    "gentlemen": "gentleman",
    "gentlemen-farmers": "gentleman-farmer",
    "gentrys": "gentry",
    "gents": "gent",
    "genèses": "genèse",
    "genépis": "genépi",
    "genévriers": "genévrier",
    "genêts": "genêt",
    "gerba": "gerber",
    "gerbaient": "gerber",
    "gerbais": "gerber",
    "gerbait": "gerber",
    "gerbant": "gerber",
    "gerbe": "gerber",
    "gerbent": "gerber",
    "gerberais": "gerber",
    "gerberas": "gerbera",
    "gerbes": "gerber",
    "gerbeuse": "gerbeur",
    "gerbeuses": "gerbeur",
    "gerbière": "gerbier",
    "gerboises": "gerboise",
    "gerbèrent": "gerber",
    "gerbé": "gerber",
    "gerbée": "gerber",
    "gerbées": "gerber",
    "gerbés": "gerber",
    "gerce": "gercer",
    "gercent": "gercer",
    "gercera": "gercer",
    "gercerai": "gercer",
    "gerceraient": "gercer",
    "gercerais": "gercer",
    "gercerait": "gercer",
    "gerceras": "gercer",
    "gercerez": "gercer",
    "gerceriez": "gercer",
    "gercerions": "gercer",
    "gercerons": "gercer",
    "gerceront": "gercer",
    "gerces": "gercer",
    "gercez": "gercer",
    "gerciez": "gercer",
    "gercions": "gercer",
    "gercèrent": "gercer",
    "gercé": "gercer",
    "gercée": "gercer",
    "gercées": "gercer",
    "gercés": "gercer",
    "gerfauts": "gerfaut",
    "germa": "germer",
    "germai": "germer",
    "germaient": "germer",
    "germaine": "germain",
    "germaines": "germain",
    "germains": "germain",
    "germais": "germer",
    "germait": "germer",
    "germaniques": "germanique",
    "germano-anglaises": "germano-anglais",
    "germant": "germer",
    "germas": "germer",
    "germasse": "germer",
    "germassent": "germer",
    "germasses": "germer",
    "germassiez": "germer",
    "germassions": "germer",
    "germe": "germer",
    "germent": "germer",
    "germera": "germer",
    "germerai": "germer",
    "germeraient": "germer",
    "germerais": "germer",
    "germerait": "germer",
    "germeras": "germer",
    "germerez": "germer",
    "germeriez": "germer",
    "germerions": "germer",
    "germerons": "germer",
    "germeront": "germer",
    "germes": "germer",
    "germez": "germer",
    "germiez": "germer",
    "germinale": "germinal",
    "germinals": "germinal",
    "germinations": "germination",
    "germions": "germer",
    "germons": "germer",
    "germâmes": "germer",
    "germât": "germer",
    "germâtes": "germer",
    "germèrent": "germer",
    "germé": "germer",
    "germée": "germer",
    "germées": "germer",
    "germés": "germer",
    "gerseaux": "gerseau",
    "gerça": "gercer",
    "gerçai": "gercer",
    "gerçaient": "gercer",
    "gerçais": "gercer",
    "gerçait": "gercer",
    "gerçant": "gercer",
    "gerças": "gercer",
    "gerçasse": "gercer",
    "gerçassent": "gercer",
    "gerçasses": "gercer",
    "gerçassiez": "gercer",
    "gerçassions": "gercer",
    "gerçons": "gercer",
    "gerçures": "gerçure",
    "gerçâmes": "gercer",
    "gerçât": "gercer",
    "gerçâtes": "gercer",
    "gesses": "gesse",
    "gestations": "gestation",
    "gestes": "geste",
    "gesticula": "gesticuler",
    "gesticulai": "gesticuler",
    "gesticulaient": "gesticuler",
    "gesticulais": "gesticuler",
    "gesticulait": "gesticuler",
    "gesticulant": "gesticuler",
    "gesticulante": "gesticulant",
    "gesticulantes": "gesticulant",
    "gesticulants": "gesticulant",
    "gesticulas": "gesticuler",
    "gesticulasse": "gesticuler",
    "gesticulassent": "gesticuler",
    "gesticulasses": "gesticuler",
    "gesticulassiez": "gesticuler",
    "gesticulassions": "gesticuler",
    "gesticulateurs": "gesticulateur",
    "gesticulations": "gesticulation",
    "gesticule": "gesticuler",
    "gesticulent": "gesticuler",
    "gesticulera": "gesticuler",
    "gesticulerai": "gesticuler",
    "gesticuleraient": "gesticuler",
    "gesticulerais": "gesticuler",
    "gesticulerait": "gesticuler",
    "gesticuleras": "gesticuler",
    "gesticulerez": "gesticuler",
    "gesticuleriez": "gesticuler",
    "gesticulerions": "gesticuler",
    "gesticulerons": "gesticuler",
    "gesticuleront": "gesticuler",
    "gesticules": "gesticuler",
    "gesticulez": "gesticuler",
    "gesticuliez": "gesticuler",
    "gesticulions": "gesticuler",
    "gesticulons": "gesticuler",
    "gesticulâmes": "gesticuler",
    "gesticulât": "gesticuler",
    "gesticulâtes": "gesticuler",
    "gesticulèrent": "gesticuler",
    "gesticulé": "gesticuler",
    "gesticulée": "gesticuler",
    "gesticulées": "gesticuler",
    "gesticulés": "gesticuler",
    "gestionnaires": "gestionnaire",
    "gestions": "gestion",
    "gestuelle": "gestuel",
    "gestuelles": "gestuelle",
    "gestuels": "gestuel",
    "geysers": "geyser",
    "geôles": "geôle",
    "geôliers": "geôlier",
    "geôlière": "geôlier",
    "geôlières": "geôlier",
    "ghanéens": "ghanéen",
    "ghettos": "ghetto",
    "giaours": "giaour",
    "gibbeuse": "gibbeux",
    "gibbons": "gibbon",
    "gibbosités": "gibbosité",
    "gibecières": "gibecière",
    "gibeline": "gibelin",
    "gibelins": "gibelin",
    "gibelottes": "gibelotte",
    "gibernes": "giberne",
    "gibets": "gibet",
    "gibiers": "gibier",
    "giboulées": "giboulée",
    "giboyeuse": "giboyeux",
    "giboyeuses": "giboyeux",
    "gicla": "gicler",
    "giclai": "gicler",
    "giclaient": "gicler",
    "giclais": "gicler",
    "giclait": "gicler",
    "giclant": "gicler",
    "giclas": "gicler",
    "giclasse": "gicler",
    "giclassent": "gicler",
    "giclasses": "gicler",
    "giclassiez": "gicler",
    "giclassions": "gicler",
    "gicle": "gicler",
    "giclements": "giclement",
    "giclent": "gicler",
    "giclera": "gicler",
    "giclerai": "gicler",
    "gicleraient": "gicler",
    "giclerais": "gicler",
    "giclerait": "gicler",
    "gicleras": "gicler",
    "giclerez": "gicler",
    "gicleriez": "gicler",
    "giclerions": "gicler",
    "giclerons": "gicler",
    "gicleront": "gicler",
    "gicles": "gicler",
    "giclez": "gicler",
    "gicliez": "gicler",
    "giclions": "gicler",
    "giclons": "gicler",
    "giclâmes": "gicler",
    "giclât": "gicler",
    "giclâtes": "gicler",
    "giclèrent": "gicler",
    "giclé": "gicler",
    "giclée": "gicler",
    "giclées": "gicler",
    "giclés": "gicler",
    "gidienne": "gidien",
    "gidiennes": "gidien",
    "gifla": "gifler",
    "giflai": "gifler",
    "giflaient": "gifler",
    "giflais": "gifler",
    "giflait": "gifler",
    "giflant": "gifler",
    "giflas": "gifler",
    "giflasse": "gifler",
    "giflassent": "gifler",
    "giflasses": "gifler",
    "giflassiez": "gifler",
    "giflassions": "gifler",
    "gifle": "gifler",
    "giflent": "gifler",
    "giflera": "gifler",
    "giflerai": "gifler",
    "gifleraient": "gifler",
    "giflerais": "gifler",
    "giflerait": "gifler",
    "gifleras": "gifler",
    "giflerez": "gifler",
    "gifleriez": "gifler",
    "giflerions": "gifler",
    "giflerons": "gifler",
    "gifleront": "gifler",
    "gifles": "gifler",
    "gifleuse": "gifleur",
    "giflez": "gifler",
    "gifliez": "gifler",
    "giflions": "gifler",
    "giflons": "gifler",
    "giflâmes": "gifler",
    "giflât": "gifler",
    "giflâtes": "gifler",
    "giflèrent": "gifler",
    "giflé": "gifler",
    "giflée": "gifler",
    "giflées": "gifler",
    "giflés": "gifler",
    "gifts": "gift",
    "gigabits": "gigabit",
    "gigantesques": "gigantesque",
    "gigantismes": "gigantisme",
    "gigaoctets": "gigaoctet",
    "gigas": "giga",
    "gigognes": "gigogne",
    "gigolos": "gigolo",
    "gigolpinces": "gigolpince",
    "gigota": "gigoter",
    "gigotai": "gigoter",
    "gigotaient": "gigoter",
    "gigotais": "gigoter",
    "gigotait": "gigoter",
    "gigotant": "gigoter",
    "gigotas": "gigoter",
    "gigotasse": "gigoter",
    "gigotassent": "gigoter",
    "gigotasses": "gigoter",
    "gigotassiez": "gigoter",
    "gigotassions": "gigoter",
    "gigote": "gigoter",
    "gigotements": "gigotement",
    "gigotent": "gigoter",
    "gigotera": "gigoter",
    "gigoterai": "gigoter",
    "gigoteraient": "gigoter",
    "gigoterais": "gigoter",
    "gigoterait": "gigoter",
    "gigoteras": "gigoter",
    "gigoterez": "gigoter",
    "gigoteriez": "gigoter",
    "gigoterions": "gigoter",
    "gigoterons": "gigoter",
    "gigoteront": "gigoter",
    "gigotes": "gigoter",
    "gigotez": "gigoter",
    "gigotiez": "gigoter",
    "gigotions": "gigoter",
    "gigotons": "gigoter",
    "gigots": "gigot",
    "gigotâmes": "gigoter",
    "gigotât": "gigoter",
    "gigotâtes": "gigoter",
    "gigotèrent": "gigoter",
    "gigoté": "gigoter",
    "gigues": "gigue",
    "giletières": "giletier",
    "gilets": "gilet",
    "gilles": "gille",
    "gimmicks": "gimmick",
    "gingembres": "gingembre",
    "gingivale": "gingival",
    "gingivales": "gingival",
    "gingivaux": "gingival",
    "ginguets": "ginguet",
    "ginguette": "ginguet",
    "ginguettes": "ginguet",
    "gins": "gin",
    "girafeaux": "girafeau",
    "girafes": "girafe",
    "girandes": "girande",
    "girandoles": "girandole",
    "girations": "giration",
    "giraudistes": "giraudiste",
    "giravions": "giravion",
    "girelles": "girel",
    "gires": "gire",
    "giries": "girie",
    "girls": "girl",
    "girodynes": "girodyne",
    "girofles": "girofle",
    "giroflées": "giroflée",
    "girolles": "girolle",
    "gironde": "girond",
    "girondes": "girond",
    "girondine": "girondin",
    "girondines": "girondin",
    "girondins": "girondin",
    "gironds": "girond",
    "girons": "giron",
    "girouettait": "girouetter",
    "girouettant": "girouetter",
    "girouettes": "girouette",
    "gis": "gésir",
    "gisaient": "gésir",
    "gisais": "gésir",
    "gisait": "gésir",
    "gisant": "gésir",
    "gisante": "gisant",
    "gisantes": "gisant",
    "gisants": "gisant",
    "giscardienne": "giscardien",
    "giscardiennes": "giscardien",
    "giscardiens": "giscardien",
    "gisements": "gisement",
    "gisent": "gésir",
    "gisez": "gésir",
    "gisiez": "gésir",
    "gisions": "gésir",
    "gisons": "gésir",
    "gisquettes": "gisquette",
    "gitane": "gitan",
    "gitanes": "gitan",
    "gitans": "gitan",
    "gitons": "giton",
    "givrait": "givrer",
    "givrante": "givrant",
    "givres": "givre",
    "givré": "givrer",
    "givrée": "givrer",
    "givrées": "givrer",
    "givrés": "givrer",
    "glabres": "glabre",
    "glace": "glacer",
    "glacent": "glacer",
    "glacera": "glacer",
    "glacerai": "glacer",
    "glaceraient": "glacer",
    "glacerais": "glacer",
    "glacerait": "glacer",
    "glaceras": "glacer",
    "glacerez": "glacer",
    "glaceriez": "glacer",
    "glacerions": "glacer",
    "glacerons": "glacer",
    "glaceront": "glacer",
    "glaces": "glacer",
    "glacez": "glacer",
    "glaciaires": "glaciaire",
    "glaciale": "glacial",
    "glaciales": "glacial",
    "glacials": "glacial",
    "glaciations": "glaciation",
    "glaciaux": "glacial",
    "glaciers": "glacier",
    "glaciez": "glacer",
    "glacions": "glacer",
    "glacières": "glacière",
    "glacèrent": "glacer",
    "glacé": "glacer",
    "glacée": "glacer",
    "glacées": "glacer",
    "glacés": "glacer",
    "gladiateurs": "gladiateur",
    "gladiatrices": "gladiatrice",
    "glaglate": "glaglater",
    "glaires": "glaire",
    "glaireuse": "glaireux",
    "glaireuses": "glaireux",
    "glaises": "glaise",
    "glaiseuse": "glaiseux",
    "glaiseuses": "glaiseux",
    "glaives": "glaive",
    "glana": "glaner",
    "glanai": "glaner",
    "glanaient": "glaner",
    "glanais": "glaner",
    "glanait": "glaner",
    "glanant": "glaner",
    "glanas": "glaner",
    "glanasse": "glaner",
    "glanassent": "glaner",
    "glanasses": "glaner",
    "glanassiez": "glaner",
    "glanassions": "glaner",
    "glandais": "glander",
    "glandait": "glander",
    "glande": "glander",
    "glandent": "glander",
    "glandes": "glander",
    "glandeurs": "glandeur",
    "glandez": "glander",
    "glandiez": "glander",
    "glandilleuses": "glandilleuse",
    "glandons": "glander",
    "glandouillant": "glandouiller",
    "glandouille": "glandouiller",
    "glandouillez": "glandouiller",
    "glandouillé": "glandouiller",
    "glands": "gland",
    "glandulaires": "glandulaire",
    "glanduleuse": "glanduleux",
    "glandus": "glandu",
    "glandé": "glander",
    "glane": "glaner",
    "glanent": "glaner",
    "glanera": "glaner",
    "glanerai": "glaner",
    "glaneraient": "glaner",
    "glanerais": "glaner",
    "glanerait": "glaner",
    "glaneras": "glaner",
    "glanerez": "glaner",
    "glaneriez": "glaner",
    "glanerions": "glaner",
    "glanerons": "glaner",
    "glaneront": "glaner",
    "glanes": "glaner",
    "glaneuse": "glaneur",
    "glanez": "glaner",
    "glaniez": "glaner",
    "glanions": "glaner",
    "glanons": "glaner",
    "glanâmes": "glaner",
    "glanât": "glaner",
    "glanâtes": "glaner",
    "glanèrent": "glaner",
    "glané": "glaner",
    "glanée": "glaner",
    "glanées": "glaner",
    "glanés": "glaner",
    "glapi": "glapir",
    "glapie": "glapir",
    "glapies": "glapir",
    "glapira": "glapir",
    "glapirai": "glapir",
    "glapiraient": "glapir",
    "glapirais": "glapir",
    "glapirait": "glapir",
    "glapiras": "glapir",
    "glapirent": "glapir",
    "glapirez": "glapir",
    "glapiriez": "glapir",
    "glapirions": "glapir",
    "glapirons": "glapir",
    "glapiront": "glapir",
    "glapis": "glapir",
    "glapissaient": "glapir",
    "glapissais": "glapir",
    "glapissait": "glapir",
    "glapissant": "glapir",
    "glapissante": "glapissant",
    "glapissantes": "glapissant",
    "glapissants": "glapissant",
    "glapisse": "glapir",
    "glapissements": "glapissement",
    "glapissent": "glapir",
    "glapisses": "glapir",
    "glapisseurs": "glapisseur",
    "glapissez": "glapir",
    "glapissiez": "glapir",
    "glapissions": "glapir",
    "glapissons": "glapir",
    "glapit": "glapir",
    "glapîmes": "glapir",
    "glapît": "glapir",
    "glapîtes": "glapir",
    "glasses": "glass",
    "glati": "glatir",
    "glatie": "glatir",
    "glaties": "glatir",
    "glatira": "glatir",
    "glatirai": "glatir",
    "glatiraient": "glatir",
    "glatirais": "glatir",
    "glatirait": "glatir",
    "glatiras": "glatir",
    "glatirent": "glatir",
    "glatirez": "glatir",
    "glatiriez": "glatir",
    "glatirions": "glatir",
    "glatirons": "glatir",
    "glatiront": "glatir",
    "glatis": "glatir",
    "glatissaient": "glatir",
    "glatissais": "glatir",
    "glatissait": "glatir",
    "glatissant": "glatir",
    "glatisse": "glatir",
    "glatissent": "glatir",
    "glatisses": "glatir",
    "glatissez": "glatir",
    "glatissiez": "glatir",
    "glatissions": "glatir",
    "glatissons": "glatir",
    "glatit": "glatir",
    "glatîmes": "glatir",
    "glatît": "glatir",
    "glatîtes": "glatir",
    "glaucomes": "glaucome",
    "glauques": "glauque",
    "glaviotaient": "glavioter",
    "glaviotait": "glavioter",
    "glaviotant": "glavioter",
    "glaviote": "glavioter",
    "glavioteurs": "glavioteur",
    "glaviots": "glaviot",
    "glaviotte": "glaviotter",
    "glaça": "glacer",
    "glaçages": "glaçage",
    "glaçai": "glacer",
    "glaçaient": "glacer",
    "glaçais": "glacer",
    "glaçait": "glacer",
    "glaçant": "glacer",
    "glaçante": "glaçant",
    "glaças": "glacer",
    "glaçasse": "glacer",
    "glaçassent": "glacer",
    "glaçasses": "glacer",
    "glaçassiez": "glacer",
    "glaçassions": "glacer",
    "glaçons": "glaçon",
    "glaçures": "glaçure",
    "glaçâmes": "glacer",
    "glaçât": "glacer",
    "glaçâtes": "glacer",
    "glaïeuls": "glaïeul",
    "gliale": "glial",
    "gliales": "glial",
    "gliaux": "glial",
    "glissa": "glisser",
    "glissades": "glissade",
    "glissai": "glisser",
    "glissaient": "glisser",
    "glissais": "glisser",
    "glissait": "glisser",
    "glissandi": "glissando",
    "glissandos": "glissando",
    "glissant": "glisser",
    "glissante": "glissant",
    "glissantes": "glissant",
    "glissants": "glissant",
    "glissas": "glisser",
    "glissasse": "glisser",
    "glissassent": "glisser",
    "glissasses": "glisser",
    "glissassiez": "glisser",
    "glissassions": "glisser",
    "glisse": "glisser",
    "glissements": "glissement",
    "glissent": "glisser",
    "glissera": "glisser",
    "glisserai": "glisser",
    "glisseraient": "glisser",
    "glisserais": "glisser",
    "glisserait": "glisser",
    "glisseras": "glisser",
    "glisserez": "glisser",
    "glisseriez": "glisser",
    "glisserions": "glisser",
    "glisserons": "glisser",
    "glisseront": "glisser",
    "glisses": "glisser",
    "glissez": "glisser",
    "glissiez": "glisser",
    "glissions": "glisser",
    "glissières": "glissière",
    "glissons": "glisser",
    "glissâmes": "glisser",
    "glissât": "glisser",
    "glissâtes": "glisser",
    "glissèrent": "glisser",
    "glissé": "glisser",
    "glissée": "glisser",
    "glissées": "glisser",
    "glissés": "glisser",
    "globale": "global",
    "globales": "global",
    "globalisa": "globaliser",
    "globalisai": "globaliser",
    "globalisaient": "globaliser",
    "globalisais": "globaliser",
    "globalisait": "globaliser",
    "globalisant": "globaliser",
    "globalisante": "globalisant",
    "globalisantes": "globalisant",
    "globalisants": "globalisant",
    "globalisas": "globaliser",
    "globalisasse": "globaliser",
    "globalisassent": "globaliser",
    "globalisasses": "globaliser",
    "globalisassiez": "globaliser",
    "globalisassions": "globaliser",
    "globalisations": "globalisation",
    "globalise": "globaliser",
    "globalisent": "globaliser",
    "globalisera": "globaliser",
    "globaliserai": "globaliser",
    "globaliseraient": "globaliser",
    "globaliserais": "globaliser",
    "globaliserait": "globaliser",
    "globaliseras": "globaliser",
    "globaliserez": "globaliser",
    "globaliseriez": "globaliser",
    "globaliserions": "globaliser",
    "globaliserons": "globaliser",
    "globaliseront": "globaliser",
    "globalises": "globaliser",
    "globalisez": "globaliser",
    "globalisiez": "globaliser",
    "globalisions": "globaliser",
    "globalisons": "globaliser",
    "globalisâmes": "globaliser",
    "globalisât": "globaliser",
    "globalisâtes": "globaliser",
    "globalisèrent": "globaliser",
    "globalisé": "globaliser",
    "globalisée": "globaliser",
    "globalisées": "globaliser",
    "globalisés": "globaliser",
    "globalités": "globalité",
    "globaux": "global",
    "globe-trotters": "globe-trotter",
    "globes": "globe",
    "globulaires": "globulaire",
    "globules": "globule",
    "globuleuse": "globuleux",
    "gloires": "gloire",
    "glomérules": "glomérule",
    "glorias": "gloria",
    "gloriettes": "gloriette",
    "glorieuse": "glorieux",
    "glorieuses": "glorieux",
    "glorifia": "glorifier",
    "glorifiai": "glorifier",
    "glorifiaient": "glorifier",
    "glorifiais": "glorifier",
    "glorifiait": "glorifier",
    "glorifiant": "glorifier",
    "glorifias": "glorifier",
    "glorifiasse": "glorifier",
    "glorifiassent": "glorifier",
    "glorifiasses": "glorifier",
    "glorifiassiez": "glorifier",
    "glorifiassions": "glorifier",
    "glorifications": "glorification",
    "glorifie": "glorifier",
    "glorifient": "glorifier",
    "glorifiera": "glorifier",
    "glorifierai": "glorifier",
    "glorifieraient": "glorifier",
    "glorifierais": "glorifier",
    "glorifierait": "glorifier",
    "glorifieras": "glorifier",
    "glorifierez": "glorifier",
    "glorifieriez": "glorifier",
    "glorifierions": "glorifier",
    "glorifierons": "glorifier",
    "glorifieront": "glorifier",
    "glorifies": "glorifier",
    "glorifiez": "glorifier",
    "glorifiiez": "glorifier",
    "glorifiions": "glorifier",
    "glorifions": "glorifier",
    "glorifiâmes": "glorifier",
    "glorifiât": "glorifier",
    "glorifiâtes": "glorifier",
    "glorifièrent": "glorifier",
    "glorifié": "glorifier",
    "glorifiée": "glorifier",
    "glorifiées": "glorifier",
    "glorifiés": "glorifier",
    "glorioles": "gloriole",
    "glosaient": "gloser",
    "glose": "gloser",
    "gloses": "glose",
    "glossaires": "glossaire",
    "glossateurs": "glossateur",
    "glosso-pharyngienne": "glosso-pharyngien",
    "glosso-pharyngiennes": "glosso-pharyngien",
    "glosso-pharyngiens": "glosso-pharyngien",
    "glosé": "gloser",
    "glosées": "gloser",
    "glottale": "glottal",
    "glottales": "glottal",
    "glottaux": "glottal",
    "glottes": "glotte",
    "glouglous": "glouglou",
    "glouglouta": "glouglouter",
    "glougloutai": "glouglouter",
    "glougloutaient": "glouglouter",
    "glougloutais": "glouglouter",
    "glougloutait": "glouglouter",
    "glougloutant": "glouglouter",
    "glougloutas": "glouglouter",
    "glougloutasse": "glouglouter",
    "glougloutassent": "glouglouter",
    "glougloutasses": "glouglouter",
    "glougloutassiez": "glouglouter",
    "glougloutassions": "glouglouter",
    "glougloute": "glouglouter",
    "glougloutent": "glouglouter",
    "glougloutera": "glouglouter",
    "glouglouterai": "glouglouter",
    "glouglouteraient": "glouglouter",
    "glouglouterais": "glouglouter",
    "glouglouterait": "glouglouter",
    "glouglouteras": "glouglouter",
    "glouglouterez": "glouglouter",
    "glouglouteriez": "glouglouter",
    "glouglouterions": "glouglouter",
    "glouglouterons": "glouglouter",
    "glouglouteront": "glouglouter",
    "glougloutes": "glouglouter",
    "glougloutez": "glouglouter",
    "glougloutiez": "glouglouter",
    "glougloutions": "glouglouter",
    "glougloutons": "glouglouter",
    "glougloutâmes": "glouglouter",
    "glougloutât": "glouglouter",
    "glougloutâtes": "glouglouter",
    "glougloutèrent": "glouglouter",
    "glouglouté": "glouglouter",
    "gloussa": "glousser",
    "gloussai": "glousser",
    "gloussaient": "glousser",
    "gloussais": "glousser",
    "gloussait": "glousser",
    "gloussant": "glousser",
    "gloussante": "gloussant",
    "gloussantes": "gloussant",
    "gloussants": "gloussant",
    "gloussas": "glousser",
    "gloussasse": "glousser",
    "gloussassent": "glousser",
    "gloussasses": "glousser",
    "gloussassiez": "glousser",
    "gloussassions": "glousser",
    "glousse": "glousser",
    "gloussements": "gloussement",
    "gloussent": "glousser",
    "gloussera": "glousser",
    "glousserai": "glousser",
    "glousseraient": "glousser",
    "glousserais": "glousser",
    "glousserait": "glousser",
    "glousseras": "glousser",
    "glousserez": "glousser",
    "glousseriez": "glousser",
    "glousserions": "glousser",
    "glousserons": "glousser",
    "glousseront": "glousser",
    "glousses": "glousser",
    "gloussez": "glousser",
    "gloussiez": "glousser",
    "gloussions": "glousser",
    "gloussons": "glousser",
    "gloussâmes": "glousser",
    "gloussât": "glousser",
    "gloussâtes": "glousser",
    "gloussèrent": "glousser",
    "gloussé": "glousser",
    "gloussée": "glousser",
    "gloussées": "glousser",
    "gloussés": "glousser",
    "gloutonnant": "gloutonner",
    "gloutonne": "glouton",
    "gloutonneries": "gloutonnerie",
    "gloutonnes": "glouton",
    "gloutons": "glouton",
    "gloxinias": "gloxinia",
    "gluant": "gluer",
    "gluante": "gluant",
    "gluantes": "gluant",
    "gluants": "gluant",
    "gluaux": "gluau",
    "glucides": "glucide",
    "glucoses": "glucose",
    "glue": "gluer",
    "gluent": "gluer",
    "glumes": "glume",
    "glus": "glu",
    "glutens": "gluten",
    "glycines": "glycine",
    "glycocolles": "glycocolle",
    "glycogènes": "glycogène",
    "glycémies": "glycémie",
    "glycérines": "glycérine",
    "glyphes": "glyphe",
    "glyptiques": "glyptique",
    "glyptothèques": "glyptothèque",
    "glèbes": "glèbe",
    "glénoïdale": "glénoïdal",
    "glénoïdales": "glénoïdal",
    "glénoïdaux": "glénoïdal",
    "glénoïdes": "glénoïde",
    "gnafrons": "gnafron",
    "gnards": "gnard",
    "gniards": "gniard",
    "gnocchis": "gnocchi",
    "gnomes": "gnome",
    "gnomiques": "gnomique",
    "gnomons": "gnomon",
    "gnons": "gnon",
    "gnoses": "gnose",
    "gnosticismes": "gnosticisme",
    "gnostiques": "gnostique",
    "gnous": "gnou",
    "goal-averages": "goal-average",
    "goals": "goal",
    "goba": "gober",
    "gobages": "gobage",
    "gobai": "gober",
    "gobaient": "gober",
    "gobais": "gober",
    "gobait": "gober",
    "gobant": "gober",
    "gobas": "gober",
    "gobasse": "gober",
    "gobassent": "gober",
    "gobasses": "gober",
    "gobassiez": "gober",
    "gobassions": "gober",
    "gobe": "gober",
    "gobe-mouches": "gobe-mouche",
    "gobelets": "gobelet",
    "gobelins": "gobelin",
    "gobelottes": "gobelotter",
    "gobent": "gober",
    "gobera": "gober",
    "goberai": "gober",
    "goberaient": "gober",
    "goberais": "gober",
    "goberait": "gober",
    "goberas": "gober",
    "goberez": "gober",
    "goberge": "goberger",
    "gobergea": "goberger",
    "gobergeai": "goberger",
    "gobergeaient": "goberger",
    "gobergeais": "goberger",
    "gobergeait": "goberger",
    "gobergeant": "goberger",
    "gobergeas": "goberger",
    "gobergeasse": "goberger",
    "gobergeassent": "goberger",
    "gobergeasses": "goberger",
    "gobergeassiez": "goberger",
    "gobergeassions": "goberger",
    "gobergent": "goberger",
    "gobergeons": "goberger",
    "gobergera": "goberger",
    "gobergerai": "goberger",
    "gobergeraient": "goberger",
    "gobergerais": "goberger",
    "gobergerait": "goberger",
    "gobergeras": "goberger",
    "gobergerez": "goberger",
    "gobergeriez": "goberger",
    "gobergerions": "goberger",
    "gobergerons": "goberger",
    "gobergeront": "goberger",
    "goberges": "goberger",
    "gobergez": "goberger",
    "gobergeâmes": "goberger",
    "gobergeât": "goberger",
    "gobergeâtes": "goberger",
    "gobergiez": "goberger",
    "gobergions": "goberger",
    "gobergèrent": "goberger",
    "gobergé": "goberger",
    "gobergée": "goberger",
    "gobergées": "goberger",
    "gobergés": "goberger",
    "goberiez": "gober",
    "goberions": "gober",
    "goberons": "gober",
    "goberont": "gober",
    "gobes": "gober",
    "gobets": "gobet",
    "gobette": "gobeter",
    "gobeurs": "gobeur",
    "gobeuse": "gobeur",
    "gobez": "gober",
    "gobiez": "gober",
    "gobions": "gober",
    "gobons": "gober",
    "gobâmes": "gober",
    "gobât": "gober",
    "gobâtes": "gober",
    "gobèrent": "gober",
    "gobé": "gober",
    "gobée": "gober",
    "gobées": "gober",
    "gobés": "gober",
    "goda": "goder",
    "godailla": "godailler",
    "godaillai": "godailler",
    "godaillaient": "godailler",
    "godaillais": "godailler",
    "godaillait": "godailler",
    "godaillant": "godailler",
    "godaillas": "godailler",
    "godaillasse": "godailler",
    "godaillassent": "godailler",
    "godaillasses": "godailler",
    "godaillassiez": "godailler",
    "godaillassions": "godailler",
    "godaille": "godailler",
    "godaillent": "godailler",
    "godaillera": "godailler",
    "godaillerai": "godailler",
    "godailleraient": "godailler",
    "godaillerais": "godailler",
    "godaillerait": "godailler",
    "godailleras": "godailler",
    "godaillerez": "godailler",
    "godailleriez": "godailler",
    "godaillerions": "godailler",
    "godaillerons": "godailler",
    "godailleront": "godailler",
    "godailles": "godailler",
    "godaillez": "godailler",
    "godailliez": "godailler",
    "godaillions": "godailler",
    "godaillons": "godailler",
    "godaillâmes": "godailler",
    "godaillât": "godailler",
    "godaillâtes": "godailler",
    "godaillèrent": "godailler",
    "godaillé": "godailler",
    "godait": "goder",
    "godant": "goder",
    "godasses": "goder",
    "gode": "goder",
    "godelureaux": "godelureau",
    "godemichés": "godemiché",
    "godent": "goder",
    "goderas": "goder",
    "godes": "goder",
    "godets": "godet",
    "godiches": "godiche",
    "godillais": "godiller",
    "godillait": "godiller",
    "godillant": "godiller",
    "godille": "godiller",
    "godilles": "godille",
    "godillots": "godillot",
    "godillé": "godiller",
    "godiveaux": "godiveau",
    "godronnés": "godronner",
    "godrons": "godron",
    "gogols": "gogol",
    "gogos": "gogo",
    "gogs": "gog",
    "goguenarda": "goguenarder",
    "goguenarde": "goguenarder",
    "goguenardes": "goguenard",
    "goguenards": "goguenard",
    "goguenots": "goguenot",
    "goguettes": "goguette",
    "goinfra": "goinfrer",
    "goinfrai": "goinfrer",
    "goinfraient": "goinfrer",
    "goinfrais": "goinfrer",
    "goinfrait": "goinfrer",
    "goinfrant": "goinfrer",
    "goinfras": "goinfrer",
    "goinfrasse": "goinfrer",
    "goinfrassent": "goinfrer",
    "goinfrasses": "goinfrer",
    "goinfrassiez": "goinfrer",
    "goinfrassions": "goinfrer",
    "goinfre": "goinfrer",
    "goinfrent": "goinfrer",
    "goinfrera": "goinfrer",
    "goinfrerai": "goinfrer",
    "goinfreraient": "goinfrer",
    "goinfrerais": "goinfrer",
    "goinfrerait": "goinfrer",
    "goinfreras": "goinfrer",
    "goinfrerez": "goinfrer",
    "goinfreriez": "goinfrer",
    "goinfrerions": "goinfrer",
    "goinfrerons": "goinfrer",
    "goinfreront": "goinfrer",
    "goinfres": "goinfrer",
    "goinfrez": "goinfrer",
    "goinfriez": "goinfrer",
    "goinfrions": "goinfrer",
    "goinfrons": "goinfrer",
    "goinfrâmes": "goinfrer",
    "goinfrât": "goinfrer",
    "goinfrâtes": "goinfrer",
    "goinfrèrent": "goinfrer",
    "goinfré": "goinfrer",
    "goinfrée": "goinfrer",
    "goinfrées": "goinfrer",
    "goinfrés": "goinfrer",
    "goitres": "goitre",
    "goldens": "golden",
    "goldos": "goldo",
    "golfes": "golfe",
    "golfeurs": "golfeur",
    "golfeuse": "golfeur",
    "golfeuses": "golfeur",
    "golfs": "golf",
    "gombos": "gombo",
    "gominé": "gominer",
    "gominée": "gominer",
    "gominées": "gominer",
    "gominés": "gominer",
    "gomma": "gommer",
    "gommages": "gommage",
    "gommai": "gommer",
    "gommaient": "gommer",
    "gommais": "gommer",
    "gommait": "gommer",
    "gommant": "gommer",
    "gommas": "gommer",
    "gommasse": "gommer",
    "gommassent": "gommer",
    "gommasses": "gommer",
    "gommassiez": "gommer",
    "gommassions": "gommer",
    "gomme": "gommer",
    "gomment": "gommer",
    "gommera": "gommer",
    "gommerai": "gommer",
    "gommeraient": "gommer",
    "gommerais": "gommer",
    "gommerait": "gommer",
    "gommeras": "gommer",
    "gommerez": "gommer",
    "gommeriez": "gommer",
    "gommerions": "gommer",
    "gommerons": "gommer",
    "gommeront": "gommer",
    "gommes": "gommer",
    "gommes-guttes": "gomme-gutte",
    "gommes-résines": "gomme-résine",
    "gommeuse": "gommeux",
    "gommez": "gommer",
    "gommiers": "gommier",
    "gommiez": "gommer",
    "gommions": "gommer",
    "gommons": "gommer",
    "gommâmes": "gommer",
    "gommât": "gommer",
    "gommâtes": "gommer",
    "gommèrent": "gommer",
    "gommé": "gommer",
    "gommée": "gommer",
    "gommées": "gommer",
    "gommés": "gommer",
    "goménolée": "goménolé",
    "gonades": "gonade",
    "gonadotropes": "gonadotrope",
    "gonde": "gonder",
    "gondola": "gondoler",
    "gondolai": "gondoler",
    "gondolaient": "gondoler",
    "gondolais": "gondoler",
    "gondolait": "gondoler",
    "gondolant": "gondoler",
    "gondolas": "gondoler",
    "gondolasse": "gondoler",
    "gondolassent": "gondoler",
    "gondolasses": "gondoler",
    "gondolassiez": "gondoler",
    "gondolassions": "gondoler",
    "gondole": "gondoler",
    "gondolent": "gondoler",
    "gondolera": "gondoler",
    "gondolerai": "gondoler",
    "gondoleraient": "gondoler",
    "gondolerais": "gondoler",
    "gondolerait": "gondoler",
    "gondoleras": "gondoler",
    "gondolerez": "gondoler",
    "gondoleriez": "gondoler",
    "gondolerions": "gondoler",
    "gondolerons": "gondoler",
    "gondoleront": "gondoler",
    "gondoles": "gondoler",
    "gondolez": "gondoler",
    "gondoliers": "gondolier",
    "gondoliez": "gondoler",
    "gondolions": "gondoler",
    "gondolière": "gondolier",
    "gondolons": "gondoler",
    "gondolâmes": "gondoler",
    "gondolât": "gondoler",
    "gondolâtes": "gondoler",
    "gondolèrent": "gondoler",
    "gondolé": "gondoler",
    "gondolée": "gondoler",
    "gondolées": "gondoler",
    "gondolés": "gondoler",
    "gonds": "gond",
    "gonfaloniers": "gonfalonier",
    "gonfalons": "gonfalon",
    "gonfanons": "gonfanon",
    "gonfla": "gonfler",
    "gonflables": "gonflable",
    "gonflai": "gonfler",
    "gonflaient": "gonfler",
    "gonflais": "gonfler",
    "gonflait": "gonfler",
    "gonflant": "gonfler",
    "gonflante": "gonflant",
    "gonflantes": "gonflant",
    "gonflants": "gonflant",
    "gonflas": "gonfler",
    "gonflasse": "gonfler",
    "gonflassent": "gonfler",
    "gonflasses": "gonfler",
    "gonflassiez": "gonfler",
    "gonflassions": "gonfler",
    "gonfle": "gonfler",
    "gonflements": "gonflement",
    "gonflent": "gonfler",
    "gonflera": "gonfler",
    "gonflerai": "gonfler",
    "gonfleraient": "gonfler",
    "gonflerais": "gonfler",
    "gonflerait": "gonfler",
    "gonfleras": "gonfler",
    "gonflerez": "gonfler",
    "gonfleriez": "gonfler",
    "gonflerions": "gonfler",
    "gonflerons": "gonfler",
    "gonfleront": "gonfler",
    "gonfles": "gonfler",
    "gonflez": "gonfler",
    "gonfliez": "gonfler",
    "gonflions": "gonfler",
    "gonflons": "gonfler",
    "gonflâmes": "gonfler",
    "gonflât": "gonfler",
    "gonflâtes": "gonfler",
    "gonflèrent": "gonfler",
    "gonflé": "gonfler",
    "gonflée": "gonfler",
    "gonflées": "gonfler",
    "gonflés": "gonfler",
    "gongs": "gong",
    "goniomètres": "goniomètre",
    "gonocoques": "gonocoque",
    "gonzes": "gonze",
    "gonzesse": "gonze",
    "gonzesses": "gonzesse",
    "gorbatchévienne": "gorbatchévien",
    "gorbatchéviennes": "gorbatchévien",
    "gorbatchéviens": "gorbatchévien",
    "gorbatchévismes": "gorbatchévisme",
    "gordiens": "gordien",
    "gores": "gore",
    "gorets": "goret",
    "gorfous": "gorfou",
    "gorge": "gorger",
    "gorgea": "gorger",
    "gorgeai": "gorger",
    "gorgeaient": "gorger",
    "gorgeais": "gorger",
    "gorgeait": "gorger",
    "gorgeant": "gorger",
    "gorgent": "gorger",
    "gorgeons": "gorger",
    "gorges": "gorger",
    "gorgez": "gorger",
    "gorgonzolas": "gorgonzola",
    "gorgèrent": "gorger",
    "gorgé": "gorger",
    "gorgée": "gorger",
    "gorgées": "gorger",
    "gorgés": "gorger",
    "gorilles": "gorille",
    "gosiers": "gosier",
    "gosselines": "gosseline",
    "gosses": "gosse",
    "gothas": "gotha",
    "gothiques": "gothique",
    "goths": "goth",
    "gotiques": "gotique",
    "gouaches": "gouache",
    "gouachez": "gouacher",
    "gouailla": "gouailler",
    "gouaillai": "gouailler",
    "gouaillaient": "gouailler",
    "gouaillais": "gouailler",
    "gouaillait": "gouailler",
    "gouaillant": "gouailler",
    "gouaillas": "gouailler",
    "gouaillasse": "gouailler",
    "gouaillassent": "gouailler",
    "gouaillasses": "gouailler",
    "gouaillassiez": "gouailler",
    "gouaillassions": "gouailler",
    "gouaille": "gouailler",
    "gouaillent": "gouailler",
    "gouaillera": "gouailler",
    "gouaillerai": "gouailler",
    "gouailleraient": "gouailler",
    "gouaillerais": "gouailler",
    "gouaillerait": "gouailler",
    "gouailleras": "gouailler",
    "gouaillerez": "gouailler",
    "gouailleriez": "gouailler",
    "gouaillerions": "gouailler",
    "gouaillerons": "gouailler",
    "gouailleront": "gouailler",
    "gouailles": "gouailler",
    "gouailleurs": "gouailleur",
    "gouailleuse": "gouailleur",
    "gouailleuses": "gouailleur",
    "gouaillez": "gouailler",
    "gouailliez": "gouailler",
    "gouaillions": "gouailler",
    "gouaillons": "gouailler",
    "gouaillâmes": "gouailler",
    "gouaillât": "gouailler",
    "gouaillâtes": "gouailler",
    "gouaillèrent": "gouailler",
    "gouaillé": "gouailler",
    "goualantes": "goualante",
    "gouapes": "gouape",
    "goudous": "goudou",
    "goudronna": "goudronner",
    "goudronnai": "goudronner",
    "goudronnaient": "goudronner",
    "goudronnais": "goudronner",
    "goudronnait": "goudronner",
    "goudronnant": "goudronner",
    "goudronnas": "goudronner",
    "goudronnasse": "goudronner",
    "goudronnassent": "goudronner",
    "goudronnasses": "goudronner",
    "goudronnassiez": "goudronner",
    "goudronnassions": "goudronner",
    "goudronne": "goudronner",
    "goudronnent": "goudronner",
    "goudronnera": "goudronner",
    "goudronnerai": "goudronner",
    "goudronneraient": "goudronner",
    "goudronnerais": "goudronner",
    "goudronnerait": "goudronner",
    "goudronneras": "goudronner",
    "goudronnerez": "goudronner",
    "goudronneriez": "goudronner",
    "goudronnerions": "goudronner",
    "goudronnerons": "goudronner",
    "goudronneront": "goudronner",
    "goudronnes": "goudronner",
    "goudronnez": "goudronner",
    "goudronniez": "goudronner",
    "goudronnions": "goudronner",
    "goudronnons": "goudronner",
    "goudronnâmes": "goudronner",
    "goudronnât": "goudronner",
    "goudronnâtes": "goudronner",
    "goudronnèrent": "goudronner",
    "goudronné": "goudronner",
    "goudronnée": "goudronner",
    "goudronnées": "goudronner",
    "goudronnés": "goudronner",
    "goudrons": "goudron",
    "gouffres": "gouffre",
    "gouges": "gouge",
    "gougnafiers": "gougnafier",
    "gougnottes": "gougnotter",
    "gougouttes": "gougoutte",
    "gougères": "gougère",
    "gouine": "gouin",
    "gouines": "gouine",
    "goujats": "goujat",
    "goujons": "goujon",
    "goulafres": "goulafre",
    "goulags": "goulag",
    "goules": "goule",
    "goulets": "goulet",
    "gouleyante": "gouleyant",
    "gouleyantes": "gouleyant",
    "gouleyants": "gouleyant",
    "goulots": "goulot",
    "goulue": "goulu",
    "goulues": "goulu",
    "goulus": "goulu",
    "goulées": "goulée",
    "goumiers": "goumier",
    "goums": "goum",
    "goupillait": "goupiller",
    "goupille": "goupiller",
    "goupilles": "goupiller",
    "goupillons": "goupillon",
    "goupillé": "goupiller",
    "goupillée": "goupiller",
    "gouraient": "gourer",
    "gourais": "gourer",
    "gourait": "gourer",
    "gourances": "gourance",
    "gourantes": "gourante",
    "gourbis": "gourbi",
    "gourde": "gourd",
    "gourdes": "gourde",
    "gourdins": "gourdin",
    "gourds": "gourd",
    "goure": "gourer",
    "gourent": "gourer",
    "gourerait": "gourer",
    "goures": "gourer",
    "gourez": "gourer",
    "gourgandines": "gourgandine",
    "gourmanda": "gourmander",
    "gourmandai": "gourmander",
    "gourmandaient": "gourmander",
    "gourmandais": "gourmander",
    "gourmandait": "gourmander",
    "gourmandant": "gourmander",
    "gourmandas": "gourmander",
    "gourmandasse": "gourmander",
    "gourmandassent": "gourmander",
    "gourmandasses": "gourmander",
    "gourmandassiez": "gourmander",
    "gourmandassions": "gourmander",
    "gourmande": "gourmander",
    "gourmandent": "gourmander",
    "gourmandera": "gourmander",
    "gourmanderai": "gourmander",
    "gourmanderaient": "gourmander",
    "gourmanderais": "gourmander",
    "gourmanderait": "gourmander",
    "gourmanderas": "gourmander",
    "gourmanderez": "gourmander",
    "gourmanderiez": "gourmander",
    "gourmanderions": "gourmander",
    "gourmanderons": "gourmander",
    "gourmanderont": "gourmander",
    "gourmandes": "gourmander",
    "gourmandez": "gourmander",
    "gourmandiez": "gourmander",
    "gourmandions": "gourmander",
    "gourmandises": "gourmandise",
    "gourmandons": "gourmander",
    "gourmands": "gourmand",
    "gourmandâmes": "gourmander",
    "gourmandât": "gourmander",
    "gourmandâtes": "gourmander",
    "gourmandèrent": "gourmander",
    "gourmandé": "gourmander",
    "gourmandée": "gourmander",
    "gourmandées": "gourmander",
    "gourmandés": "gourmander",
    "gourmes": "gourme",
    "gourmets": "gourmet",
    "gourmettes": "gourmette",
    "gourmé": "gourmer",
    "gourmée": "gourmé",
    "gourmées": "gourmé",
    "gourmés": "gourmé",
    "gourous": "gourou",
    "gours": "gour",
    "gourvernements": "gourvernement",
    "gouré": "gourer",
    "gourée": "gourer",
    "gourées": "gourer",
    "gourés": "gourer",
    "gousses": "gousse",
    "goussets": "gousset",
    "goutta": "goutter",
    "gouttai": "goutter",
    "gouttaient": "goutter",
    "gouttais": "goutter",
    "gouttait": "goutter",
    "gouttant": "goutter",
    "gouttas": "goutter",
    "gouttasse": "goutter",
    "gouttassent": "goutter",
    "gouttasses": "goutter",
    "gouttassiez": "goutter",
    "gouttassions": "goutter",
    "goutte": "goutter",
    "gouttelaient": "goutteler",
    "gouttelait": "goutteler",
    "gouttelettes": "gouttelette",
    "gouttent": "goutter",
    "gouttera": "goutter",
    "goutterai": "goutter",
    "goutteraient": "goutter",
    "goutterais": "goutter",
    "goutterait": "goutter",
    "goutteras": "goutter",
    "gouttereaux": "gouttereau",
    "goutterez": "goutter",
    "goutteriez": "goutter",
    "goutterions": "goutter",
    "goutterons": "goutter",
    "goutteront": "goutter",
    "gouttes": "goutter",
    "goutteuse": "goutteux",
    "goutteuses": "goutteux",
    "gouttez": "goutter",
    "gouttiez": "goutter",
    "gouttions": "goutter",
    "gouttières": "gouttière",
    "gouttons": "goutter",
    "gouttâmes": "goutter",
    "gouttât": "goutter",
    "gouttâtes": "goutter",
    "gouttèrent": "goutter",
    "goutté": "goutter",
    "gouverna": "gouverner",
    "gouvernai": "gouverner",
    "gouvernaient": "gouverner",
    "gouvernails": "gouvernail",
    "gouvernais": "gouverner",
    "gouvernait": "gouverner",
    "gouvernant": "gouverner",
    "gouvernante": "gouvernant",
    "gouvernantes": "gouvernante",
    "gouvernants": "gouvernant",
    "gouvernas": "gouverner",
    "gouvernasse": "gouverner",
    "gouvernassent": "gouverner",
    "gouvernasses": "gouverner",
    "gouvernassiez": "gouverner",
    "gouvernassions": "gouverner",
    "gouverne": "gouverner",
    "gouvernementale": "gouvernemental",
    "gouvernementales": "gouvernemental",
    "gouvernementaux": "gouvernemental",
    "gouvernements": "gouvernement",
    "gouvernent": "gouverner",
    "gouvernera": "gouverner",
    "gouvernerai": "gouverner",
    "gouverneraient": "gouverner",
    "gouvernerais": "gouverner",
    "gouvernerait": "gouverner",
    "gouverneras": "gouverner",
    "gouvernerez": "gouverner",
    "gouverneriez": "gouverner",
    "gouvernerions": "gouverner",
    "gouvernerons": "gouverner",
    "gouverneront": "gouverner",
    "gouvernes": "gouverner",
    "gouverneurs": "gouverneur",
    "gouvernez": "gouverner",
    "gouverniez": "gouverner",
    "gouvernions": "gouverner",
    "gouvernons": "gouverner",
    "gouvernorats": "gouvernorat",
    "gouvernâmes": "gouverner",
    "gouvernât": "gouverner",
    "gouvernâtes": "gouverner",
    "gouvernèrent": "gouverner",
    "gouverné": "gouverner",
    "gouvernée": "gouverner",
    "gouvernées": "gouverner",
    "gouvernés": "gouverner",
    "goyaves": "goyave",
    "goyesques": "goyesque",
    "goélands": "goéland",
    "goélettes": "goélette",
    "goémons": "goémon",
    "goûta": "goûter",
    "goûtables": "goûtable",
    "goûtai": "goûter",
    "goûtaient": "goûter",
    "goûtais": "goûter",
    "goûtait": "goûter",
    "goûtant": "goûter",
    "goûtas": "goûter",
    "goûtasse": "goûter",
    "goûtassent": "goûter",
    "goûtasses": "goûter",
    "goûtassiez": "goûter",
    "goûtassions": "goûter",
    "goûte": "goûter",
    "goûtent": "goûter",
    "goûtera": "goûter",
    "goûterai": "goûter",
    "goûteraient": "goûter",
    "goûterais": "goûter",
    "goûterait": "goûter",
    "goûteras": "goûter",
    "goûterez": "goûter",
    "goûteriez": "goûter",
    "goûterions": "goûter",
    "goûterons": "goûter",
    "goûteront": "goûter",
    "goûters": "goûter",
    "goûtes": "goûter",
    "goûteuse": "goûteux",
    "goûteuses": "goûteux",
    "goûtez": "goûter",
    "goûtiez": "goûter",
    "goûtions": "goûter",
    "goûtons": "goûter",
    "goûts": "goût",
    "goûtâmes": "goûter",
    "goûtât": "goûter",
    "goûtâtes": "goûter",
    "goûtèrent": "goûter",
    "goûté": "goûter",
    "goûtée": "goûter",
    "goûtées": "goûter",
    "goûtés": "goûter",
    "grabataires": "grabataire",
    "grabats": "grabat",
    "grabuges": "grabuge",
    "gracia": "gracier",
    "graciai": "gracier",
    "graciaient": "gracier",
    "graciais": "gracier",
    "graciait": "gracier",
    "graciant": "gracier",
    "gracias": "gracier",
    "graciasse": "gracier",
    "graciassent": "gracier",
    "graciasses": "gracier",
    "graciassiez": "gracier",
    "graciassions": "gracier",
    "gracie": "gracier",
    "gracient": "gracier",
    "graciera": "gracier",
    "gracierai": "gracier",
    "gracieraient": "gracier",
    "gracierais": "gracier",
    "gracierait": "gracier",
    "gracieras": "gracier",
    "gracierez": "gracier",
    "gracieriez": "gracier",
    "gracierions": "gracier",
    "gracierons": "gracier",
    "gracieront": "gracier",
    "gracies": "gracier",
    "gracieuse": "gracieux",
    "gracieuses": "gracieux",
    "gracieusetés": "gracieuseté",
    "graciez": "gracier",
    "graciiez": "gracier",
    "graciions": "gracier",
    "graciles": "gracile",
    "gracions": "gracier",
    "graciâmes": "gracier",
    "graciât": "gracier",
    "graciâtes": "gracier",
    "gracièrent": "gracier",
    "gracié": "gracier",
    "graciée": "gracier",
    "graciées": "gracier",
    "graciés": "gracier",
    "gradations": "gradation",
    "grades": "grade",
    "gradients": "gradient",
    "gradins": "gradin",
    "gradua": "graduer",
    "graduai": "graduer",
    "graduaient": "graduer",
    "graduais": "graduer",
    "graduait": "graduer",
    "graduant": "graduer",
    "graduas": "graduer",
    "graduasse": "graduer",
    "graduassent": "graduer",
    "graduasses": "graduer",
    "graduassiez": "graduer",
    "graduassions": "graduer",
    "graduations": "graduation",
    "gradue": "graduer",
    "graduelle": "graduel",
    "graduelles": "graduel",
    "graduels": "graduel",
    "graduent": "graduer",
    "graduera": "graduer",
    "graduerai": "graduer",
    "gradueraient": "graduer",
    "graduerais": "graduer",
    "graduerait": "graduer",
    "gradueras": "graduer",
    "graduerez": "graduer",
    "gradueriez": "graduer",
    "graduerions": "graduer",
    "graduerons": "graduer",
    "gradueront": "graduer",
    "gradues": "graduer",
    "graduez": "graduer",
    "graduiez": "graduer",
    "graduions": "graduer",
    "graduons": "graduer",
    "graduâmes": "graduer",
    "graduât": "graduer",
    "graduâtes": "graduer",
    "graduèrent": "graduer",
    "gradué": "graduer",
    "graduée": "graduer",
    "graduées": "graduer",
    "gradués": "graduer",
    "gradée": "gradé",
    "gradées": "gradé",
    "gradés": "gradé",
    "graffita": "graffiter",
    "graffiteurs": "graffiteur",
    "graffitis": "graffiti",
    "graffité": "graffiter",
    "grailla": "grailler",
    "graillai": "grailler",
    "graillaient": "grailler",
    "graillais": "grailler",
    "graillait": "grailler",
    "graillant": "grailler",
    "graillas": "grailler",
    "graillasse": "grailler",
    "graillassent": "grailler",
    "graillasses": "grailler",
    "graillassiez": "grailler",
    "graillassions": "grailler",
    "graille": "grailler",
    "graillent": "grailler",
    "graillera": "grailler",
    "graillerai": "grailler",
    "grailleraient": "grailler",
    "graillerais": "grailler",
    "graillerait": "grailler",
    "grailleras": "grailler",
    "graillerez": "grailler",
    "grailleriez": "grailler",
    "graillerions": "grailler",
    "graillerons": "grailler",
    "grailleront": "grailler",
    "grailles": "grailler",
    "graillez": "grailler",
    "grailliez": "grailler",
    "graillions": "grailler",
    "graillonna": "graillonner",
    "graillonnai": "graillonner",
    "graillonnaient": "graillonner",
    "graillonnais": "graillonner",
    "graillonnait": "graillonner",
    "graillonnant": "graillonner",
    "graillonnas": "graillonner",
    "graillonnasse": "graillonner",
    "graillonnassent": "graillonner",
    "graillonnasses": "graillonner",
    "graillonnassiez": "graillonner",
    "graillonnassions": "graillonner",
    "graillonne": "graillonner",
    "graillonnements": "graillonnement",
    "graillonnent": "graillonner",
    "graillonnera": "graillonner",
    "graillonnerai": "graillonner",
    "graillonneraient": "graillonner",
    "graillonnerais": "graillonner",
    "graillonnerait": "graillonner",
    "graillonneras": "graillonner",
    "graillonnerez": "graillonner",
    "graillonneriez": "graillonner",
    "graillonnerions": "graillonner",
    "graillonnerons": "graillonner",
    "graillonneront": "graillonner",
    "graillonnes": "graillonner",
    "graillonneuse": "graillonneur",
    "graillonneuses": "graillonneur",
    "graillonnez": "graillonner",
    "graillonniez": "graillonner",
    "graillonnions": "graillonner",
    "graillonnons": "graillonner",
    "graillonnâmes": "graillonner",
    "graillonnât": "graillonner",
    "graillonnâtes": "graillonner",
    "graillonnèrent": "graillonner",
    "graillonné": "graillonner",
    "graillons": "graillon",
    "graillâmes": "grailler",
    "graillât": "grailler",
    "graillâtes": "grailler",
    "graillèrent": "grailler",
    "graillé": "grailler",
    "graillée": "grailler",
    "graines": "graine",
    "graineteries": "graineterie",
    "grainetiers": "grainetier",
    "grainetière": "grainetier",
    "grainetières": "grainetier",
    "grains": "grain",
    "grainé": "grainer",
    "graissa": "graisser",
    "graissages": "graissage",
    "graissai": "graisser",
    "graissaient": "graisser",
    "graissais": "graisser",
    "graissait": "graisser",
    "graissant": "graisser",
    "graissas": "graisser",
    "graissasse": "graisser",
    "graissassent": "graisser",
    "graissasses": "graisser",
    "graissassiez": "graisser",
    "graissassions": "graisser",
    "graisse": "graisser",
    "graissent": "graisser",
    "graissera": "graisser",
    "graisserai": "graisser",
    "graisseraient": "graisser",
    "graisserais": "graisser",
    "graisserait": "graisser",
    "graisseras": "graisser",
    "graisserez": "graisser",
    "graisseriez": "graisser",
    "graisserions": "graisser",
    "graisserons": "graisser",
    "graisseront": "graisser",
    "graisses": "graisser",
    "graisseuse": "graisseux",
    "graisseuses": "graisseux",
    "graissez": "graisser",
    "graissiez": "graisser",
    "graissions": "graisser",
    "graissons": "graisser",
    "graissâmes": "graisser",
    "graissât": "graisser",
    "graissâtes": "graisser",
    "graissèrent": "graisser",
    "graissé": "graisser",
    "graissée": "graisser",
    "graissées": "graisser",
    "graissés": "graisser",
    "gramens": "gramen",
    "graminées": "graminée",
    "grammages": "grammage",
    "grammaires": "grammaire",
    "grammairienne": "grammairien",
    "grammairiennes": "grammairien",
    "grammairiens": "grammairien",
    "grammaticale": "grammatical",
    "grammaticales": "grammatical",
    "grammaticaux": "grammatical",
    "grammes": "gramme",
    "gramophones": "gramophone",
    "granas": "grana",
    "grand-ducale": "grand-ducal",
    "grand-ducales": "grand-ducal",
    "grand-ducaux": "grand-ducal",
    "grand-gardes": "grand-garde",
    "grand-guignolesques": "grand-guignolesque",
    "grand-maman": "grand-papa",
    "grand-mamans": "grand-maman",
    "grand-messes": "grand-messe",
    "grand-mères": "grand-mère",
    "grand-routes": "grand-route",
    "grand-tantes": "grand-tante",
    "grande": "grand",
    "grande-duchesse": "grand-duc",
    "grandes": "grand",
    "grandes-duchesses": "grand-duc",
    "grandeurs": "grandeur",
    "grandi": "grandir",
    "grandie": "grandir",
    "grandies": "grandir",
    "grandiloquences": "grandiloquence",
    "grandiloquente": "grandiloquent",
    "grandiloquentes": "grandiloquent",
    "grandiloquents": "grandiloquent",
    "grandioses": "grandiose",
    "grandira": "grandir",
    "grandirai": "grandir",
    "grandiraient": "grandir",
    "grandirais": "grandir",
    "grandirait": "grandir",
    "grandiras": "grandir",
    "grandirent": "grandir",
    "grandirez": "grandir",
    "grandiriez": "grandir",
    "grandirions": "grandir",
    "grandirons": "grandir",
    "grandiront": "grandir",
    "grandis": "grandir",
    "grandissaient": "grandir",
    "grandissais": "grandir",
    "grandissait": "grandir",
    "grandissant": "grandir",
    "grandissante": "grandissant",
    "grandissantes": "grandissant",
    "grandissants": "grandissant",
    "grandisse": "grandir",
    "grandissent": "grandir",
    "grandisses": "grandir",
    "grandissez": "grandir",
    "grandissiez": "grandir",
    "grandissions": "grandir",
    "grandissons": "grandir",
    "grandit": "grandir",
    "grands": "grand",
    "grands-angles": "grand-angle",
    "grands-angulaires": "grand-angulaire",
    "grands-croix": "grand-croix",
    "grands-duchés": "grand-duché",
    "grands-ducs": "grand-duc",
    "grands-mères": "grand-mère",
    "grands-oncles": "grand-oncle",
    "grands-papas": "grand-papa",
    "grands-pères": "grand-père",
    "grands-routes": "grand-route",
    "grands-tantes": "grand-tante",
    "grandîmes": "grandir",
    "grandît": "grandir",
    "grandîtes": "grandir",
    "granges": "grange",
    "granita": "graniter",
    "granites": "granite",
    "granitiques": "granitique",
    "granits": "granit",
    "granitée": "graniter",
    "granités": "granité",
    "granulait": "granuler",
    "granulations": "granulation",
    "granule": "granuler",
    "granules": "granule",
    "granuleuse": "granuleux",
    "granuleuses": "granuleux",
    "granulée": "granuler",
    "granulés": "granulé",
    "grape-fruits": "grape-fruit",
    "graphes": "graphe",
    "graphies": "graphie",
    "graphiques": "graphique",
    "graphismes": "graphisme",
    "graphistes": "graphiste",
    "graphites": "graphite",
    "graphologues": "graphologue",
    "graphomanes": "graphomane",
    "grappes": "grappe",
    "grappilla": "grappiller",
    "grappillai": "grappiller",
    "grappillaient": "grappiller",
    "grappillais": "grappiller",
    "grappillait": "grappiller",
    "grappillant": "grappiller",
    "grappillas": "grappiller",
    "grappillasse": "grappiller",
    "grappillassent": "grappiller",
    "grappillasses": "grappiller",
    "grappillassiez": "grappiller",
    "grappillassions": "grappiller",
    "grappille": "grappiller",
    "grappillent": "grappiller",
    "grappillera": "grappiller",
    "grappillerai": "grappiller",
    "grappilleraient": "grappiller",
    "grappillerais": "grappiller",
    "grappillerait": "grappiller",
    "grappilleras": "grappiller",
    "grappillerez": "grappiller",
    "grappilleriez": "grappiller",
    "grappillerions": "grappiller",
    "grappillerons": "grappiller",
    "grappilleront": "grappiller",
    "grappilles": "grappiller",
    "grappillez": "grappiller",
    "grappilliez": "grappiller",
    "grappillions": "grappiller",
    "grappillons": "grappillon",
    "grappillâmes": "grappiller",
    "grappillât": "grappiller",
    "grappillâtes": "grappiller",
    "grappillèrent": "grappiller",
    "grappillé": "grappiller",
    "grappillée": "grappiller",
    "grappillées": "grappiller",
    "grappillés": "grappiller",
    "grappins": "grappin",
    "gras-doubles": "gras-double",
    "grasse": "gras",
    "grasses": "gras",
    "grasseya": "grasseyer",
    "grasseyai": "grasseyer",
    "grasseyaient": "grasseyer",
    "grasseyais": "grasseyer",
    "grasseyait": "grasseyer",
    "grasseyant": "grasseyer",
    "grasseyante": "grasseyant",
    "grasseyas": "grasseyer",
    "grasseyasse": "grasseyer",
    "grasseyassent": "grasseyer",
    "grasseyasses": "grasseyer",
    "grasseyassiez": "grasseyer",
    "grasseyassions": "grasseyer",
    "grasseye": "grasseyer",
    "grasseyements": "grasseyement",
    "grasseyent": "grasseyer",
    "grasseyera": "grasseyer",
    "grasseyerai": "grasseyer",
    "grasseyeraient": "grasseyer",
    "grasseyerais": "grasseyer",
    "grasseyerait": "grasseyer",
    "grasseyeras": "grasseyer",
    "grasseyerez": "grasseyer",
    "grasseyeriez": "grasseyer",
    "grasseyerions": "grasseyer",
    "grasseyerons": "grasseyer",
    "grasseyeront": "grasseyer",
    "grasseyes": "grasseyer",
    "grasseyez": "grasseyer",
    "grasseyiez": "grasseyer",
    "grasseyions": "grasseyer",
    "grasseyons": "grasseyer",
    "grasseyâmes": "grasseyer",
    "grasseyât": "grasseyer",
    "grasseyâtes": "grasseyer",
    "grasseyèrent": "grasseyer",
    "grasseyé": "grasseyer",
    "grasseyée": "grasseyer",
    "grasseyées": "grasseyer",
    "grasseyés": "grasseyer",
    "grassouillets": "grassouillet",
    "grassouillette": "grassouillet",
    "grassouillettes": "grassouillet",
    "gratifia": "gratifier",
    "gratifiai": "gratifier",
    "gratifiaient": "gratifier",
    "gratifiais": "gratifier",
    "gratifiait": "gratifier",
    "gratifiant": "gratifier",
    "gratifiante": "gratifiant",
    "gratifias": "gratifier",
    "gratifiasse": "gratifier",
    "gratifiassent": "gratifier",
    "gratifiasses": "gratifier",
    "gratifiassiez": "gratifier",
    "gratifiassions": "gratifier",
    "gratifications": "gratification",
    "gratifie": "gratifier",
    "gratifient": "gratifier",
    "gratifiera": "gratifier",
    "gratifierai": "gratifier",
    "gratifieraient": "gratifier",
    "gratifierais": "gratifier",
    "gratifierait": "gratifier",
    "gratifieras": "gratifier",
    "gratifierez": "gratifier",
    "gratifieriez": "gratifier",
    "gratifierions": "gratifier",
    "gratifierons": "gratifier",
    "gratifieront": "gratifier",
    "gratifies": "gratifier",
    "gratifiez": "gratifier",
    "gratifiiez": "gratifier",
    "gratifiions": "gratifier",
    "gratifions": "gratifier",
    "gratifiâmes": "gratifier",
    "gratifiât": "gratifier",
    "gratifiâtes": "gratifier",
    "gratifièrent": "gratifier",
    "gratifié": "gratifier",
    "gratifiée": "gratifier",
    "gratifiées": "gratifier",
    "gratifiés": "gratifier",
    "gratins": "gratin",
    "gratiné": "gratiner",
    "gratinée": "gratiner",
    "gratinées": "gratiner",
    "gratinés": "gratiner",
    "gratitudes": "gratitude",
    "gratouillait": "gratouiller",
    "gratouillant": "gratouiller",
    "gratouille": "gratouiller",
    "gratouillerait": "gratouiller",
    "gratta": "gratter",
    "grattages": "grattage",
    "grattai": "gratter",
    "grattaient": "gratter",
    "grattais": "gratter",
    "grattait": "gratter",
    "grattant": "gratter",
    "grattas": "gratter",
    "grattasse": "gratter",
    "grattassent": "gratter",
    "grattasses": "gratter",
    "grattassiez": "gratter",
    "grattassions": "gratter",
    "gratte": "gratter",
    "gratte-ciels": "gratte-ciel",
    "gratte-papiers": "gratte-papier",
    "grattements": "grattement",
    "grattent": "gratter",
    "grattera": "gratter",
    "gratterai": "gratter",
    "gratteraient": "gratter",
    "gratterais": "gratter",
    "gratterait": "gratter",
    "gratteras": "gratter",
    "gratterez": "gratter",
    "gratteriez": "gratter",
    "gratterions": "gratter",
    "gratterons": "gratteron",
    "gratteront": "gratter",
    "grattes": "gratter",
    "gratteurs": "gratteur",
    "grattez": "gratter",
    "grattiez": "gratter",
    "grattions": "gratter",
    "grattoirs": "grattoir",
    "grattons": "gratton",
    "grattouillant": "grattouiller",
    "grattouillent": "grattouiller",
    "grattouilles": "grattouiller",
    "grattouillé": "grattouiller",
    "grattâmes": "gratter",
    "grattât": "gratter",
    "grattâtes": "gratter",
    "grattèrent": "gratter",
    "gratté": "gratter",
    "grattée": "gratter",
    "grattées": "gratter",
    "grattés": "gratter",
    "gratuite": "gratuit",
    "gratuites": "gratuit",
    "gratuits": "gratuit",
    "gratuités": "gratuité",
    "graux": "grau",
    "grava": "graver",
    "gravai": "graver",
    "gravaient": "graver",
    "gravais": "graver",
    "gravait": "graver",
    "gravant": "graver",
    "gravas": "graver",
    "gravasse": "graver",
    "gravassent": "graver",
    "gravasses": "graver",
    "gravassiez": "graver",
    "gravassions": "graver",
    "grave": "graver",
    "graveleuse": "graveleux",
    "graveleuses": "graveleux",
    "gravelles": "gravelle",
    "gravelé": "graveler",
    "gravelés": "graveler",
    "gravent": "graver",
    "gravera": "graver",
    "graverai": "graver",
    "graveraient": "graver",
    "graverais": "graver",
    "graverait": "graver",
    "graveras": "graver",
    "graverez": "graver",
    "graveriez": "graver",
    "graverions": "graver",
    "graverons": "graver",
    "graveront": "graver",
    "graves": "graver",
    "graveurs": "graveur",
    "graveuse": "graveur",
    "graveuses": "graveur",
    "gravez": "graver",
    "gravi": "gravir",
    "gravie": "gravir",
    "graviers": "gravier",
    "gravies": "gravir",
    "graviez": "graver",
    "gravillonnée": "gravillonner",
    "gravillonnées": "gravillonner",
    "gravillons": "gravillon",
    "gravimétriques": "gravimétrique",
    "gravions": "graver",
    "gravira": "gravir",
    "gravirai": "gravir",
    "graviraient": "gravir",
    "gravirais": "gravir",
    "gravirait": "gravir",
    "graviras": "gravir",
    "gravirent": "gravir",
    "gravirez": "gravir",
    "graviriez": "gravir",
    "gravirions": "gravir",
    "gravirons": "gravir",
    "graviront": "gravir",
    "gravis": "gravir",
    "gravissaient": "gravir",
    "gravissais": "gravir",
    "gravissait": "gravir",
    "gravissant": "gravir",
    "gravisse": "gravir",
    "gravissent": "gravir",
    "gravisses": "gravir",
    "gravissez": "gravir",
    "gravissiez": "gravir",
    "gravissimes": "gravissime",
    "gravissions": "gravir",
    "gravissons": "gravir",
    "gravit": "gravir",
    "gravita": "graviter",
    "gravitai": "graviter",
    "gravitaient": "graviter",
    "gravitais": "graviter",
    "gravitait": "graviter",
    "gravitant": "graviter",
    "gravitas": "graviter",
    "gravitasse": "graviter",
    "gravitassent": "graviter",
    "gravitasses": "graviter",
    "gravitassiez": "graviter",
    "gravitassions": "graviter",
    "gravitationnelle": "gravitationnel",
    "gravitationnelles": "gravitationnel",
    "gravitationnels": "gravitationnel",
    "gravitations": "gravitation",
    "gravite": "graviter",
    "gravitent": "graviter",
    "gravitera": "graviter",
    "graviterai": "graviter",
    "graviteraient": "graviter",
    "graviterais": "graviter",
    "graviterait": "graviter",
    "graviteras": "graviter",
    "graviterez": "graviter",
    "graviteriez": "graviter",
    "graviterions": "graviter",
    "graviterons": "graviter",
    "graviteront": "graviter",
    "gravites": "graviter",
    "gravitez": "graviter",
    "gravitiez": "graviter",
    "gravitions": "graviter",
    "gravitons": "graviton",
    "gravitâmes": "graviter",
    "gravitât": "graviter",
    "gravitâtes": "graviter",
    "gravitèrent": "graviter",
    "gravité": "graviter",
    "gravités": "gravité",
    "gravières": "gravière",
    "gravons": "graver",
    "gravosses": "gravosse",
    "gravures": "gravure",
    "gravâmes": "graver",
    "gravât": "graver",
    "gravâtes": "graver",
    "gravèrent": "graver",
    "gravé": "graver",
    "gravée": "graver",
    "gravées": "graver",
    "gravés": "graver",
    "gravîmes": "gravir",
    "gravît": "gravir",
    "gravîtes": "gravir",
    "grays": "gray",
    "grecque": "grec",
    "grecques": "grec",
    "grecs": "grec",
    "gredine": "gredin",
    "gredineries": "gredinerie",
    "gredines": "gredin",
    "gredins": "gredin",
    "greens": "green",
    "greffa": "greffer",
    "greffai": "greffer",
    "greffaient": "greffer",
    "greffais": "greffer",
    "greffait": "greffer",
    "greffant": "greffer",
    "greffas": "greffer",
    "greffasse": "greffer",
    "greffassent": "greffer",
    "greffasses": "greffer",
    "greffassiez": "greffer",
    "greffassions": "greffer",
    "greffe": "greffer",
    "greffent": "greffer",
    "greffera": "greffer",
    "grefferai": "greffer",
    "grefferaient": "greffer",
    "grefferais": "greffer",
    "grefferait": "greffer",
    "grefferas": "greffer",
    "grefferez": "greffer",
    "grefferiez": "greffer",
    "grefferions": "greffer",
    "grefferons": "greffer",
    "grefferont": "greffer",
    "greffes": "greffer",
    "greffez": "greffer",
    "greffiers": "greffier",
    "greffiez": "greffer",
    "greffions": "greffer",
    "greffière": "greffier",
    "greffières": "greffier",
    "greffons": "greffon",
    "greffâmes": "greffer",
    "greffât": "greffer",
    "greffâtes": "greffer",
    "greffèrent": "greffer",
    "greffé": "greffer",
    "greffée": "greffer",
    "greffées": "greffer",
    "greffés": "greffer",
    "grelins": "grelin",
    "grelots": "grelot",
    "grelotta": "grelotter",
    "grelottai": "grelotter",
    "grelottaient": "grelotter",
    "grelottais": "grelotter",
    "grelottait": "grelotter",
    "grelottant": "grelotter",
    "grelottante": "grelottant",
    "grelottantes": "grelottant",
    "grelottants": "grelottant",
    "grelottas": "grelotter",
    "grelottasse": "grelotter",
    "grelottassent": "grelotter",
    "grelottasses": "grelotter",
    "grelottassiez": "grelotter",
    "grelottassions": "grelotter",
    "grelotte": "grelotter",
    "grelottements": "grelottement",
    "grelottent": "grelotter",
    "grelottera": "grelotter",
    "grelotterai": "grelotter",
    "grelotteraient": "grelotter",
    "grelotterais": "grelotter",
    "grelotterait": "grelotter",
    "grelotteras": "grelotter",
    "grelotterez": "grelotter",
    "grelotteriez": "grelotter",
    "grelotterions": "grelotter",
    "grelotterons": "grelotter",
    "grelotteront": "grelotter",
    "grelottes": "grelotter",
    "grelottez": "grelotter",
    "grelottiez": "grelotter",
    "grelottions": "grelotter",
    "grelottons": "grelotter",
    "grelottâmes": "grelotter",
    "grelottât": "grelotter",
    "grelottâtes": "grelotter",
    "grelottèrent": "grelotter",
    "grelotté": "grelotter",
    "grelottée": "grelotter",
    "greluches": "greluche",
    "grena": "grener",
    "grenaches": "grenache",
    "grenades": "grenade",
    "grenadiers": "grenadier",
    "grenadine": "grenadin",
    "grenadines": "grenadine",
    "grenadins": "grenadin",
    "grenadé": "grenader",
    "grenai": "grener",
    "grenaient": "grener",
    "grenailles": "grenaille",
    "grenais": "grener",
    "grenait": "grener",
    "grenant": "grener",
    "grenas": "grener",
    "grenasse": "grener",
    "grenassent": "grener",
    "grenasses": "grener",
    "grenassiez": "grener",
    "grenassions": "grener",
    "grenats": "grenat",
    "grenelle": "greneler",
    "greneta": "greneter",
    "greneuse": "greneur",
    "grenez": "grener",
    "greniers": "grenier",
    "greniez": "grener",
    "grenions": "grener",
    "grenobloise": "grenoblois",
    "grenobloises": "grenoblois",
    "grenons": "grener",
    "grenouilla": "grenouiller",
    "grenouillai": "grenouiller",
    "grenouillaient": "grenouiller",
    "grenouillais": "grenouiller",
    "grenouillait": "grenouiller",
    "grenouillant": "grenouiller",
    "grenouillas": "grenouiller",
    "grenouillasse": "grenouiller",
    "grenouillassent": "grenouiller",
    "grenouillasses": "grenouiller",
    "grenouillassiez": "grenouiller",
    "grenouillassions": "grenouiller",
    "grenouille": "grenouiller",
    "grenouillent": "grenouiller",
    "grenouillera": "grenouiller",
    "grenouillerai": "grenouiller",
    "grenouilleraient": "grenouiller",
    "grenouillerais": "grenouiller",
    "grenouillerait": "grenouiller",
    "grenouilleras": "grenouiller",
    "grenouillerez": "grenouiller",
    "grenouilleriez": "grenouiller",
    "grenouillerions": "grenouiller",
    "grenouillerons": "grenouiller",
    "grenouilleront": "grenouiller",
    "grenouilles": "grenouiller",
    "grenouillettes": "grenouillette",
    "grenouillez": "grenouiller",
    "grenouilliez": "grenouiller",
    "grenouillions": "grenouiller",
    "grenouillons": "grenouiller",
    "grenouillâmes": "grenouiller",
    "grenouillât": "grenouiller",
    "grenouillâtes": "grenouiller",
    "grenouillèrent": "grenouiller",
    "grenouillères": "grenouillère",
    "grenouillé": "grenouiller",
    "grenue": "grenu",
    "grenues": "grenu",
    "grenures": "grenure",
    "grenus": "grenu",
    "grenâmes": "grener",
    "grenât": "grener",
    "grenâtes": "grener",
    "grenèrent": "grener",
    "grené": "grener",
    "grenée": "grener",
    "grenées": "grener",
    "grenés": "grener",
    "gressins": "gressin",
    "gretchens": "gretchen",
    "greva": "grever",
    "grevai": "grever",
    "grevaient": "grever",
    "grevais": "grever",
    "grevait": "grever",
    "grevant": "grever",
    "grevas": "grever",
    "grevasse": "grever",
    "grevassent": "grever",
    "grevasses": "grever",
    "grevassiez": "grever",
    "grevassions": "grever",
    "grevez": "grever",
    "greviez": "grever",
    "grevions": "grever",
    "grevons": "grever",
    "grevâmes": "grever",
    "grevât": "grever",
    "grevâtes": "grever",
    "grevèrent": "grever",
    "grevé": "grever",
    "grevée": "grever",
    "grevées": "grever",
    "grevés": "grever",
    "gribouilla": "gribouiller",
    "gribouillages": "gribouillage",
    "gribouillai": "gribouiller",
    "gribouillaient": "gribouiller",
    "gribouillais": "gribouiller",
    "gribouillait": "gribouiller",
    "gribouillant": "gribouiller",
    "gribouillas": "gribouiller",
    "gribouillasse": "gribouiller",
    "gribouillassent": "gribouiller",
    "gribouillasses": "gribouiller",
    "gribouillassiez": "gribouiller",
    "gribouillassions": "gribouiller",
    "gribouille": "gribouiller",
    "gribouillent": "gribouiller",
    "gribouillera": "gribouiller",
    "gribouillerai": "gribouiller",
    "gribouilleraient": "gribouiller",
    "gribouillerais": "gribouiller",
    "gribouillerait": "gribouiller",
    "gribouilleras": "gribouiller",
    "gribouillerez": "gribouiller",
    "gribouilleriez": "gribouiller",
    "gribouillerions": "gribouiller",
    "gribouillerons": "gribouiller",
    "gribouilleront": "gribouiller",
    "gribouilles": "gribouiller",
    "gribouillez": "gribouiller",
    "gribouilliez": "gribouiller",
    "gribouillions": "gribouiller",
    "gribouillons": "gribouiller",
    "gribouillâmes": "gribouiller",
    "gribouillât": "gribouiller",
    "gribouillâtes": "gribouiller",
    "gribouillèrent": "gribouiller",
    "gribouillé": "gribouiller",
    "gribouillée": "gribouiller",
    "gribouillées": "gribouiller",
    "gribouillés": "gribouiller",
    "griefs": "grief",
    "griffa": "griffer",
    "griffai": "griffer",
    "griffaient": "griffer",
    "griffais": "griffer",
    "griffait": "griffer",
    "griffant": "griffer",
    "griffas": "griffer",
    "griffasse": "griffer",
    "griffassent": "griffer",
    "griffasses": "griffer",
    "griffassiez": "griffer",
    "griffassions": "griffer",
    "griffe": "griffer",
    "griffent": "griffer",
    "griffera": "griffer",
    "grifferai": "griffer",
    "grifferaient": "griffer",
    "grifferais": "griffer",
    "grifferait": "griffer",
    "grifferas": "griffer",
    "grifferez": "griffer",
    "grifferiez": "griffer",
    "grifferions": "griffer",
    "grifferons": "griffer",
    "grifferont": "griffer",
    "griffes": "griffer",
    "griffez": "griffer",
    "griffiez": "griffer",
    "griffions": "griffer",
    "griffonna": "griffonner",
    "griffonnages": "griffonnage",
    "griffonnai": "griffonner",
    "griffonnaient": "griffonner",
    "griffonnais": "griffonner",
    "griffonnait": "griffonner",
    "griffonnant": "griffonner",
    "griffonnas": "griffonner",
    "griffonnasse": "griffonner",
    "griffonnassent": "griffonner",
    "griffonnasses": "griffonner",
    "griffonnassiez": "griffonner",
    "griffonnassions": "griffonner",
    "griffonne": "griffonner",
    "griffonnent": "griffonner",
    "griffonnera": "griffonner",
    "griffonnerai": "griffonner",
    "griffonneraient": "griffonner",
    "griffonnerais": "griffonner",
    "griffonnerait": "griffonner",
    "griffonneras": "griffonner",
    "griffonnerez": "griffonner",
    "griffonneriez": "griffonner",
    "griffonnerions": "griffonner",
    "griffonnerons": "griffonner",
    "griffonneront": "griffonner",
    "griffonnes": "griffonner",
    "griffonnez": "griffonner",
    "griffonniez": "griffonner",
    "griffonnions": "griffonner",
    "griffonnons": "griffonner",
    "griffonnâmes": "griffonner",
    "griffonnât": "griffonner",
    "griffonnâtes": "griffonner",
    "griffonnèrent": "griffonner",
    "griffonné": "griffonner",
    "griffonnée": "griffonner",
    "griffonnées": "griffonner",
    "griffonnés": "griffonner",
    "griffons": "griffon",
    "grifftons": "griffton",
    "griffue": "griffu",
    "griffues": "griffu",
    "griffures": "griffure",
    "griffus": "griffu",
    "griffâmes": "griffer",
    "griffât": "griffer",
    "griffâtes": "griffer",
    "griffèrent": "griffer",
    "griffé": "griffer",
    "griffée": "griffer",
    "griffées": "griffer",
    "griffés": "griffer",
    "grignota": "grignoter",
    "grignotages": "grignotage",
    "grignotai": "grignoter",
    "grignotaient": "grignoter",
    "grignotais": "grignoter",
    "grignotait": "grignoter",
    "grignotant": "grignoter",
    "grignotas": "grignoter",
    "grignotasse": "grignoter",
    "grignotassent": "grignoter",
    "grignotasses": "grignoter",
    "grignotassiez": "grignoter",
    "grignotassions": "grignoter",
    "grignote": "grignoter",
    "grignotements": "grignotement",
    "grignotent": "grignoter",
    "grignotera": "grignoter",
    "grignoterai": "grignoter",
    "grignoteraient": "grignoter",
    "grignoterais": "grignoter",
    "grignoterait": "grignoter",
    "grignoteras": "grignoter",
    "grignoterez": "grignoter",
    "grignoteriez": "grignoter",
    "grignoterions": "grignoter",
    "grignoterons": "grignoter",
    "grignoteront": "grignoter",
    "grignotes": "grignoter",
    "grignoteurs": "grignoteur",
    "grignoteuses": "grignoteur",
    "grignotez": "grignoter",
    "grignotiez": "grignoter",
    "grignotions": "grignoter",
    "grignotons": "grignoter",
    "grignotâmes": "grignoter",
    "grignotât": "grignoter",
    "grignotâtes": "grignoter",
    "grignotèrent": "grignoter",
    "grignoté": "grignoter",
    "grignotée": "grignoter",
    "grignotées": "grignoter",
    "grignotés": "grignoter",
    "grigous": "grigou",
    "grigris": "grigri",
    "grill-rooms": "grill-room",
    "grilla": "griller",
    "grillades": "grillade",
    "grillage": "grillager",
    "grillagea": "grillager",
    "grillageai": "grillager",
    "grillageaient": "grillager",
    "grillageais": "grillager",
    "grillageait": "grillager",
    "grillageant": "grillager",
    "grillageas": "grillager",
    "grillageasse": "grillager",
    "grillageassent": "grillager",
    "grillageasses": "grillager",
    "grillageassiez": "grillager",
    "grillageassions": "grillager",
    "grillagent": "grillager",
    "grillageons": "grillager",
    "grillagera": "grillager",
    "grillagerai": "grillager",
    "grillageraient": "grillager",
    "grillagerais": "grillager",
    "grillagerait": "grillager",
    "grillageras": "grillager",
    "grillagerez": "grillager",
    "grillageriez": "grillager",
    "grillagerions": "grillager",
    "grillagerons": "grillager",
    "grillageront": "grillager",
    "grillages": "grillager",
    "grillagez": "grillager",
    "grillageâmes": "grillager",
    "grillageât": "grillager",
    "grillageâtes": "grillager",
    "grillagiez": "grillager",
    "grillagions": "grillager",
    "grillagèrent": "grillager",
    "grillagé": "grillager",
    "grillagée": "grillager",
    "grillagées": "grillager",
    "grillagés": "grillager",
    "grillai": "griller",
    "grillaient": "griller",
    "grillais": "griller",
    "grillait": "griller",
    "grillant": "griller",
    "grillas": "griller",
    "grillasse": "griller",
    "grillassent": "griller",
    "grillasses": "griller",
    "grillassiez": "griller",
    "grillassions": "griller",
    "grille": "griller",
    "grillent": "griller",
    "grillera": "griller",
    "grillerai": "griller",
    "grilleraient": "griller",
    "grillerais": "griller",
    "grillerait": "griller",
    "grilleras": "griller",
    "grillerez": "griller",
    "grilleriez": "griller",
    "grillerions": "griller",
    "grillerons": "griller",
    "grilleront": "griller",
    "grilles": "griller",
    "grillez": "griller",
    "grilliez": "griller",
    "grillions": "griller",
    "grilloirs": "grilloir",
    "grillons": "grillon",
    "grillots": "grillot",
    "grillâmes": "griller",
    "grillât": "griller",
    "grillâtes": "griller",
    "grillèrent": "griller",
    "grillé": "griller",
    "grillée": "griller",
    "grillées": "griller",
    "grillés": "griller",
    "grils": "gril",
    "grima": "grimer",
    "grimace": "grimacer",
    "grimacent": "grimacer",
    "grimacera": "grimacer",
    "grimacerai": "grimacer",
    "grimaceraient": "grimacer",
    "grimacerais": "grimacer",
    "grimacerait": "grimacer",
    "grimaceras": "grimacer",
    "grimacerez": "grimacer",
    "grimaceries": "grimacerie",
    "grimaceriez": "grimacer",
    "grimacerions": "grimacer",
    "grimacerons": "grimacer",
    "grimaceront": "grimacer",
    "grimaces": "grimacer",
    "grimacez": "grimacer",
    "grimaciers": "grimacier",
    "grimaciez": "grimacer",
    "grimacions": "grimacer",
    "grimacèrent": "grimacer",
    "grimacé": "grimacer",
    "grimacée": "grimacer",
    "grimacées": "grimacer",
    "grimacés": "grimacer",
    "grimait": "grimer",
    "grimant": "grimer",
    "grimasse": "grimer",
    "grimauds": "grimaud",
    "grimaça": "grimacer",
    "grimaçai": "grimacer",
    "grimaçaient": "grimacer",
    "grimaçais": "grimacer",
    "grimaçait": "grimacer",
    "grimaçant": "grimacer",
    "grimaçante": "grimaçant",
    "grimaçantes": "grimaçant",
    "grimaçants": "grimaçant",
    "grimaças": "grimacer",
    "grimaçasse": "grimacer",
    "grimaçassent": "grimacer",
    "grimaçasses": "grimacer",
    "grimaçassiez": "grimacer",
    "grimaçassions": "grimacer",
    "grimaçons": "grimacer",
    "grimaçâmes": "grimacer",
    "grimaçât": "grimacer",
    "grimaçâtes": "grimacer",
    "griment": "grimer",
    "grimes": "grimer",
    "grimoires": "grimoire",
    "grimpa": "grimper",
    "grimpai": "grimper",
    "grimpaient": "grimper",
    "grimpais": "grimper",
    "grimpait": "grimper",
    "grimpant": "grimper",
    "grimpante": "grimpant",
    "grimpantes": "grimpant",
    "grimpants": "grimpant",
    "grimpas": "grimper",
    "grimpasse": "grimper",
    "grimpassent": "grimper",
    "grimpasses": "grimper",
    "grimpassiez": "grimper",
    "grimpassions": "grimper",
    "grimpe": "grimper",
    "grimpent": "grimper",
    "grimpera": "grimper",
    "grimperai": "grimper",
    "grimperaient": "grimper",
    "grimperais": "grimper",
    "grimperait": "grimper",
    "grimperas": "grimper",
    "grimpereaux": "grimpereau",
    "grimperez": "grimper",
    "grimperiez": "grimper",
    "grimperions": "grimper",
    "grimperons": "grimper",
    "grimperont": "grimper",
    "grimpes": "grimper",
    "grimpettes": "grimpette",
    "grimpeurs": "grimpeur",
    "grimpeuse": "grimpeur",
    "grimpeuses": "grimpeur",
    "grimpez": "grimper",
    "grimpiez": "grimper",
    "grimpions": "grimper",
    "grimpons": "grimper",
    "grimpâmes": "grimper",
    "grimpât": "grimper",
    "grimpâtes": "grimper",
    "grimpèrent": "grimper",
    "grimpé": "grimper",
    "grimpée": "grimper",
    "grimpées": "grimper",
    "grimpés": "grimper",
    "grimé": "grimer",
    "grimée": "grimer",
    "grimées": "grimer",
    "grimés": "grimer",
    "grince": "grincer",
    "grincements": "grincement",
    "grincent": "grincer",
    "grincera": "grincer",
    "grincerai": "grincer",
    "grinceraient": "grincer",
    "grincerais": "grincer",
    "grincerait": "grincer",
    "grinceras": "grincer",
    "grincerez": "grincer",
    "grinceriez": "grincer",
    "grincerions": "grincer",
    "grincerons": "grincer",
    "grinceront": "grincer",
    "grinces": "grincer",
    "grincez": "grincer",
    "grinche": "grincher",
    "grincheuse": "grincheux",
    "grincheuses": "grincheux",
    "grinciez": "grincer",
    "grincions": "grincer",
    "grincèrent": "grincer",
    "grincé": "grincer",
    "gringalets": "gringalet",
    "gringos": "gringo",
    "grinça": "grincer",
    "grinçai": "grincer",
    "grinçaient": "grincer",
    "grinçais": "grincer",
    "grinçait": "grincer",
    "grinçant": "grincer",
    "grinçante": "grinçant",
    "grinçantes": "grinçant",
    "grinçants": "grinçant",
    "grinças": "grincer",
    "grinçasse": "grincer",
    "grinçassent": "grincer",
    "grinçasses": "grincer",
    "grinçassiez": "grincer",
    "grinçassions": "grincer",
    "grinçons": "grincer",
    "grinçâmes": "grincer",
    "grinçât": "grincer",
    "grinçâtes": "grincer",
    "griots": "griot",
    "griottes": "griotte",
    "grippa": "gripper",
    "grippages": "grippage",
    "grippai": "gripper",
    "grippaient": "gripper",
    "grippais": "gripper",
    "grippait": "gripper",
    "grippale": "grippal",
    "grippales": "grippal",
    "grippant": "gripper",
    "grippas": "gripper",
    "grippasse": "gripper",
    "grippassent": "gripper",
    "grippasses": "gripper",
    "grippassiez": "gripper",
    "grippassions": "gripper",
    "grippaux": "grippal",
    "grippe": "gripper",
    "grippe-sous": "grippe-sou",
    "grippements": "grippement",
    "grippent": "gripper",
    "grippera": "gripper",
    "gripperai": "gripper",
    "gripperaient": "gripper",
    "gripperais": "gripper",
    "gripperait": "gripper",
    "gripperas": "gripper",
    "gripperez": "gripper",
    "gripperiez": "gripper",
    "gripperions": "gripper",
    "gripperons": "gripper",
    "gripperont": "gripper",
    "grippes": "gripper",
    "grippez": "gripper",
    "grippiez": "gripper",
    "grippions": "gripper",
    "grippons": "gripper",
    "grippâmes": "gripper",
    "grippât": "gripper",
    "grippâtes": "gripper",
    "grippèrent": "gripper",
    "grippé": "gripper",
    "grippée": "gripper",
    "grippées": "gripper",
    "grippés": "gripper",
    "gris-gris": "gri-gri",
    "grisa": "griser",
    "grisai": "griser",
    "grisaient": "griser",
    "grisailles": "grisaille",
    "grisaillèrent": "grisailler",
    "grisais": "griser",
    "grisait": "griser",
    "grisant": "griser",
    "grisante": "grisant",
    "grisantes": "grisant",
    "grisants": "grisant",
    "grisarde": "grisard",
    "grisardes": "grisard",
    "grisards": "grisard",
    "grisas": "griser",
    "grisasse": "griser",
    "grisassent": "griser",
    "grisasses": "griser",
    "grisassiez": "griser",
    "grisassions": "griser",
    "grise": "griser",
    "grisent": "griser",
    "grisera": "griser",
    "griserai": "griser",
    "griseraient": "griser",
    "griserais": "griser",
    "griserait": "griser",
    "griseras": "griser",
    "griserez": "griser",
    "griseries": "griserie",
    "griseriez": "griser",
    "griserions": "griser",
    "griserons": "griser",
    "griseront": "griser",
    "grises": "griser",
    "grisettes": "grisette",
    "grisez": "griser",
    "grisiez": "griser",
    "grisions": "griser",
    "grisonna": "grisonner",
    "grisonnai": "grisonner",
    "grisonnaient": "grisonner",
    "grisonnais": "grisonner",
    "grisonnait": "grisonner",
    "grisonnant": "grisonner",
    "grisonnante": "grisonnant",
    "grisonnantes": "grisonnant",
    "grisonnants": "grisonnant",
    "grisonnas": "grisonner",
    "grisonnasse": "grisonner",
    "grisonnassent": "grisonner",
    "grisonnasses": "grisonner",
    "grisonnassiez": "grisonner",
    "grisonnassions": "grisonner",
    "grisonne": "grisonner",
    "grisonnent": "grisonner",
    "grisonnera": "grisonner",
    "grisonnerai": "grisonner",
    "grisonneraient": "grisonner",
    "grisonnerais": "grisonner",
    "grisonnerait": "grisonner",
    "grisonneras": "grisonner",
    "grisonnerez": "grisonner",
    "grisonneriez": "grisonner",
    "grisonnerions": "grisonner",
    "grisonnerons": "grisonner",
    "grisonneront": "grisonner",
    "grisonnes": "grisonner",
    "grisonnez": "grisonner",
    "grisonniez": "grisonner",
    "grisonnions": "grisonner",
    "grisonnons": "grisonner",
    "grisonnâmes": "grisonner",
    "grisonnât": "grisonner",
    "grisonnâtes": "grisonner",
    "grisonnèrent": "grisonner",
    "grisonné": "grisonner",
    "grisons": "grison",
    "grisous": "grisou",
    "grisouteuse": "grisouteux",
    "grisouteuses": "grisouteux",
    "grisâmes": "griser",
    "grisât": "griser",
    "grisâtes": "griser",
    "grisâtres": "grisâtre",
    "grisèrent": "griser",
    "grisé": "griser",
    "grisée": "griser",
    "grisées": "griser",
    "grisés": "griser",
    "grivela": "griveler",
    "grivelai": "griveler",
    "grivelaient": "griveler",
    "grivelais": "griveler",
    "grivelait": "griveler",
    "grivelant": "griveler",
    "grivelas": "griveler",
    "grivelasse": "griveler",
    "grivelassent": "griveler",
    "grivelasses": "griveler",
    "grivelassiez": "griveler",
    "grivelassions": "griveler",
    "grivelez": "griveler",
    "griveliez": "griveler",
    "grivelions": "griveler",
    "grivelle": "griveler",
    "grivellent": "griveler",
    "grivellera": "griveler",
    "grivellerai": "griveler",
    "grivelleraient": "griveler",
    "grivellerais": "griveler",
    "grivellerait": "griveler",
    "grivelleras": "griveler",
    "grivellerez": "griveler",
    "grivelleriez": "griveler",
    "grivellerions": "griveler",
    "grivellerons": "griveler",
    "grivelleront": "griveler",
    "grivelles": "griveler",
    "grivelons": "griveler",
    "grivelures": "grivelure",
    "grivelâmes": "griveler",
    "grivelât": "griveler",
    "grivelâtes": "griveler",
    "grivelèrent": "griveler",
    "grivelé": "griveler",
    "grivelée": "griveler",
    "grivelées": "griveler",
    "grivelés": "griveler",
    "grives": "grive",
    "grivetons": "griveton",
    "grivoise": "grivois",
    "grivoiseries": "grivoiserie",
    "grivoises": "grivois",
    "grivèleries": "grivèlerie",
    "grizzlis": "grizzli",
    "grizzlys": "grizzly",
    "grièches": "grièche",
    "groenendaels": "groenendael",
    "grogna": "grogner",
    "grognai": "grogner",
    "grognaient": "grogner",
    "grognais": "grogner",
    "grognait": "grogner",
    "grognant": "grogner",
    "grognards": "grognard",
    "grognas": "grogner",
    "grognassaient": "grognasser",
    "grognasse": "grogner",
    "grognassent": "grogner",
    "grognasses": "grogner",
    "grognassiez": "grogner",
    "grognassions": "grogner",
    "grogne": "grogner",
    "grognements": "grognement",
    "grognent": "grogner",
    "grognera": "grogner",
    "grognerai": "grogner",
    "grogneraient": "grogner",
    "grognerais": "grogner",
    "grognerait": "grogner",
    "grogneras": "grogner",
    "grognerez": "grogner",
    "grogneriez": "grogner",
    "grognerions": "grogner",
    "grognerons": "grogner",
    "grogneront": "grogner",
    "grognes": "grogner",
    "grogneurs": "grogneur",
    "grogneuse": "grogneur",
    "grognez": "grogner",
    "grogniez": "grogner",
    "grognions": "grogner",
    "grognonna": "grognonner",
    "grognonne": "grognonner",
    "grognonnes": "grognon",
    "grognons": "grognon",
    "grognâmes": "grogner",
    "grognât": "grogner",
    "grognâtes": "grogner",
    "grognèrent": "grogner",
    "grogné": "grogner",
    "grognée": "grogner",
    "grognées": "grogner",
    "grognés": "grogner",
    "grogs": "grog",
    "groins": "groin",
    "groles": "grole",
    "grolles": "grolle",
    "grommela": "grommeler",
    "grommelai": "grommeler",
    "grommelaient": "grommeler",
    "grommelais": "grommeler",
    "grommelait": "grommeler",
    "grommelant": "grommeler",
    "grommelas": "grommeler",
    "grommelasse": "grommeler",
    "grommelassent": "grommeler",
    "grommelasses": "grommeler",
    "grommelassiez": "grommeler",
    "grommelassions": "grommeler",
    "grommelez": "grommeler",
    "grommeliez": "grommeler",
    "grommelions": "grommeler",
    "grommelle": "grommeler",
    "grommellements": "grommellement",
    "grommellent": "grommeler",
    "grommellera": "grommeler",
    "grommellerai": "grommeler",
    "grommelleraient": "grommeler",
    "grommellerais": "grommeler",
    "grommellerait": "grommeler",
    "grommelleras": "grommeler",
    "grommellerez": "grommeler",
    "grommelleriez": "grommeler",
    "grommellerions": "grommeler",
    "grommellerons": "grommeler",
    "grommelleront": "grommeler",
    "grommelles": "grommeler",
    "grommelons": "grommeler",
    "grommelâmes": "grommeler",
    "grommelât": "grommeler",
    "grommelâtes": "grommeler",
    "grommelèrent": "grommeler",
    "grommelé": "grommeler",
    "grommelée": "grommeler",
    "grommelées": "grommeler",
    "grommelés": "grommeler",
    "gronda": "gronder",
    "grondai": "gronder",
    "grondaient": "gronder",
    "grondais": "gronder",
    "grondait": "gronder",
    "grondant": "gronder",
    "grondante": "grondant",
    "grondants": "grondant",
    "grondas": "gronder",
    "grondasse": "gronder",
    "grondassent": "gronder",
    "grondasses": "gronder",
    "grondassiez": "gronder",
    "grondassions": "gronder",
    "gronde": "gronder",
    "grondements": "grondement",
    "grondent": "gronder",
    "grondera": "gronder",
    "gronderai": "gronder",
    "gronderaient": "gronder",
    "gronderais": "gronder",
    "gronderait": "gronder",
    "gronderas": "gronder",
    "gronderez": "gronder",
    "gronderies": "gronderie",
    "gronderiez": "gronder",
    "gronderions": "gronder",
    "gronderons": "gronder",
    "gronderont": "gronder",
    "grondes": "gronder",
    "grondeurs": "grondeur",
    "grondeuse": "grondeur",
    "grondeuses": "grondeur",
    "grondez": "gronder",
    "grondiez": "gronder",
    "grondins": "grondin",
    "grondions": "gronder",
    "grondons": "gronder",
    "grondâmes": "gronder",
    "grondât": "gronder",
    "grondâtes": "gronder",
    "grondèrent": "gronder",
    "grondé": "gronder",
    "grondée": "gronder",
    "grondées": "gronder",
    "grondés": "gronder",
    "grooms": "groom",
    "gros-becs": "gros-bec",
    "gros-porteurs": "gros-porteur",
    "groseilles": "groseille",
    "groseilliers": "groseillier",
    "grosse": "gros",
    "grosses": "gros",
    "grossesses": "grossesse",
    "grosseurs": "grosseur",
    "grossi": "grossir",
    "grossie": "grossir",
    "grossiers": "grossier",
    "grossies": "grossir",
    "grossira": "grossir",
    "grossirai": "grossir",
    "grossiraient": "grossir",
    "grossirais": "grossir",
    "grossirait": "grossir",
    "grossiras": "grossir",
    "grossirent": "grossir",
    "grossirez": "grossir",
    "grossiriez": "grossir",
    "grossirions": "grossir",
    "grossirons": "grossir",
    "grossiront": "grossir",
    "grossis": "grossir",
    "grossissaient": "grossir",
    "grossissais": "grossir",
    "grossissait": "grossir",
    "grossissant": "grossir",
    "grossissante": "grossissant",
    "grossissantes": "grossissant",
    "grossissants": "grossissant",
    "grossisse": "grossir",
    "grossissements": "grossissement",
    "grossissent": "grossir",
    "grossisses": "grossir",
    "grossissez": "grossir",
    "grossissiez": "grossir",
    "grossissions": "grossir",
    "grossissons": "grossir",
    "grossistes": "grossiste",
    "grossit": "grossir",
    "grossiums": "grossium",
    "grossière": "grossier",
    "grossières": "grossier",
    "grossièretés": "grossièreté",
    "grossîmes": "grossir",
    "grossît": "grossir",
    "grossîtes": "grossir",
    "grotesques": "grotesque",
    "grottes": "grotte",
    "grouilla": "grouiller",
    "grouillai": "grouiller",
    "grouillaient": "grouiller",
    "grouillais": "grouiller",
    "grouillait": "grouiller",
    "grouillant": "grouiller",
    "grouillante": "grouillant",
    "grouillantes": "grouillant",
    "grouillants": "grouillant",
    "grouillas": "grouiller",
    "grouillasse": "grouiller",
    "grouillassent": "grouiller",
    "grouillasses": "grouiller",
    "grouillassiez": "grouiller",
    "grouillassions": "grouiller",
    "grouille": "grouiller",
    "grouillements": "grouillement",
    "grouillent": "grouiller",
    "grouillera": "grouiller",
    "grouillerai": "grouiller",
    "grouilleraient": "grouiller",
    "grouillerais": "grouiller",
    "grouillerait": "grouiller",
    "grouilleras": "grouiller",
    "grouillerez": "grouiller",
    "grouilleriez": "grouiller",
    "grouillerions": "grouiller",
    "grouillerons": "grouiller",
    "grouilleront": "grouiller",
    "grouilles": "grouiller",
    "grouillez": "grouiller",
    "grouilliez": "grouiller",
    "grouillions": "grouiller",
    "grouillons": "grouiller",
    "grouillots": "grouillot",
    "grouillâmes": "grouiller",
    "grouillât": "grouiller",
    "grouillâtes": "grouiller",
    "grouillèrent": "grouiller",
    "grouillé": "grouiller",
    "grouillée": "grouiller",
    "grouillées": "grouiller",
    "grouillés": "grouiller",
    "groumais": "groumer",
    "groumait": "groumer",
    "groumant": "groumer",
    "groume": "groumer",
    "groupa": "grouper",
    "groupages": "groupage",
    "groupai": "grouper",
    "groupaient": "grouper",
    "groupais": "grouper",
    "groupait": "grouper",
    "groupant": "grouper",
    "groupas": "grouper",
    "groupasse": "grouper",
    "groupassent": "grouper",
    "groupasses": "grouper",
    "groupassiez": "grouper",
    "groupassions": "grouper",
    "groupe": "grouper",
    "groupements": "groupement",
    "groupent": "grouper",
    "groupera": "grouper",
    "grouperai": "grouper",
    "grouperaient": "grouper",
    "grouperais": "grouper",
    "grouperait": "grouper",
    "grouperas": "grouper",
    "grouperez": "grouper",
    "grouperiez": "grouper",
    "grouperions": "grouper",
    "grouperons": "grouper",
    "grouperont": "grouper",
    "groupes": "grouper",
    "groupez": "grouper",
    "groupies": "groupie",
    "groupiez": "grouper",
    "groupions": "grouper",
    "groupons": "grouper",
    "groups": "group",
    "groupuscules": "groupuscule",
    "groupâmes": "grouper",
    "groupât": "grouper",
    "groupâtes": "grouper",
    "groupèrent": "grouper",
    "groupé": "grouper",
    "groupée": "grouper",
    "groupées": "grouper",
    "groupés": "grouper",
    "grouses": "grouse",
    "gruaux": "gruau",
    "grues": "grue",
    "gruge": "gruger",
    "grugea": "gruger",
    "grugeai": "gruger",
    "grugeaient": "gruger",
    "grugeais": "gruger",
    "grugeait": "gruger",
    "grugeant": "gruger",
    "grugeas": "gruger",
    "grugeasse": "gruger",
    "grugeassent": "gruger",
    "grugeasses": "gruger",
    "grugeassiez": "gruger",
    "grugeassions": "gruger",
    "grugent": "gruger",
    "grugeons": "gruger",
    "grugera": "gruger",
    "grugerai": "gruger",
    "grugeraient": "gruger",
    "grugerais": "gruger",
    "grugerait": "gruger",
    "grugeras": "gruger",
    "grugerez": "gruger",
    "grugeriez": "gruger",
    "grugerions": "gruger",
    "grugerons": "gruger",
    "grugeront": "gruger",
    "gruges": "gruger",
    "grugez": "gruger",
    "grugeâmes": "gruger",
    "grugeât": "gruger",
    "grugeâtes": "gruger",
    "grugiez": "gruger",
    "grugions": "gruger",
    "grugèrent": "gruger",
    "grugé": "gruger",
    "grugée": "gruger",
    "grugées": "gruger",
    "grugés": "gruger",
    "grumeaux": "grumeau",
    "grumela": "grumeler",
    "grumelai": "grumeler",
    "grumelaient": "grumeler",
    "grumelais": "grumeler",
    "grumelait": "grumeler",
    "grumelant": "grumeler",
    "grumelas": "grumeler",
    "grumelasse": "grumeler",
    "grumelassent": "grumeler",
    "grumelasses": "grumeler",
    "grumelassiez": "grumeler",
    "grumelassions": "grumeler",
    "grumeleuse": "grumeleux",
    "grumeleuses": "grumeleux",
    "grumelez": "grumeler",
    "grumeliez": "grumeler",
    "grumelions": "grumeler",
    "grumelle": "grumeler",
    "grumellent": "grumeler",
    "grumellera": "grumeler",
    "grumellerai": "grumeler",
    "grumelleraient": "grumeler",
    "grumellerais": "grumeler",
    "grumellerait": "grumeler",
    "grumelleras": "grumeler",
    "grumellerez": "grumeler",
    "grumelleriez": "grumeler",
    "grumellerions": "grumeler",
    "grumellerons": "grumeler",
    "grumelleront": "grumeler",
    "grumelles": "grumeler",
    "grumelons": "grumeler",
    "grumelâmes": "grumeler",
    "grumelât": "grumeler",
    "grumelâtes": "grumeler",
    "grumelèrent": "grumeler",
    "grumelé": "grumeler",
    "grumelée": "grumeler",
    "grumelées": "grumeler",
    "grumelés": "grumeler",
    "grumes": "grume",
    "gruppettos": "gruppetto",
    "gruta": "gruter",
    "grute": "gruter",
    "grutiers": "grutier",
    "grutière": "grutier",
    "gruyères": "gruyère",
    "grâces": "grâce",
    "grèbes": "grèbe",
    "grèges": "grège",
    "grène": "grener",
    "grènent": "grener",
    "grènera": "grener",
    "grènerai": "grener",
    "grèneraient": "grener",
    "grènerais": "grener",
    "grènerait": "grener",
    "grèneras": "grener",
    "grènerez": "grener",
    "grèneriez": "grener",
    "grènerions": "grener",
    "grènerons": "grener",
    "grèneront": "grener",
    "grènes": "grener",
    "grèse": "gréser",
    "grèsent": "gréser",
    "grèses": "gréser",
    "grève": "grever",
    "grèvent": "grever",
    "grèvera": "grever",
    "grèverai": "grever",
    "grèveraient": "grever",
    "grèverais": "grever",
    "grèverait": "grever",
    "grèveras": "grever",
    "grèverez": "grever",
    "grèveriez": "grever",
    "grèverions": "grever",
    "grèverons": "grever",
    "grèveront": "grever",
    "grèves": "grever",
    "gréa": "gréer",
    "gréai": "gréer",
    "gréaient": "gréer",
    "gréais": "gréer",
    "gréait": "gréer",
    "gréant": "gréer",
    "gréas": "gréer",
    "gréasse": "gréer",
    "gréassent": "gréer",
    "gréasses": "gréer",
    "gréassiez": "gréer",
    "gréassions": "gréer",
    "grécisa": "gréciser",
    "grécisai": "gréciser",
    "grécisaient": "gréciser",
    "grécisais": "gréciser",
    "grécisait": "gréciser",
    "grécisant": "gréciser",
    "grécisas": "gréciser",
    "grécisasse": "gréciser",
    "grécisassent": "gréciser",
    "grécisasses": "gréciser",
    "grécisassiez": "gréciser",
    "grécisassions": "gréciser",
    "grécise": "gréciser",
    "grécisent": "gréciser",
    "grécisera": "gréciser",
    "gréciserai": "gréciser",
    "gréciseraient": "gréciser",
    "gréciserais": "gréciser",
    "gréciserait": "gréciser",
    "gréciseras": "gréciser",
    "gréciserez": "gréciser",
    "gréciseriez": "gréciser",
    "gréciserions": "gréciser",
    "gréciserons": "gréciser",
    "gréciseront": "gréciser",
    "grécises": "gréciser",
    "grécisez": "gréciser",
    "grécisiez": "gréciser",
    "grécisions": "gréciser",
    "grécisons": "gréciser",
    "grécisâmes": "gréciser",
    "grécisât": "gréciser",
    "grécisâtes": "gréciser",
    "grécisèrent": "gréciser",
    "grécisé": "gréciser",
    "grécisée": "gréciser",
    "grécisées": "gréciser",
    "grécisés": "gréciser",
    "gréco-latine": "gréco-latin",
    "gréco-latines": "gréco-latin",
    "gréco-latins": "gréco-latin",
    "gréco-romaine": "gréco-romain",
    "gréco-romaines": "gréco-romain",
    "gréco-romains": "gréco-romain",
    "grécophones": "grécophone",
    "grée": "gréer",
    "gréements": "gréement",
    "gréent": "gréer",
    "gréera": "gréer",
    "gréerai": "gréer",
    "gréeraient": "gréer",
    "gréerais": "gréer",
    "gréerait": "gréer",
    "gréeras": "gréer",
    "gréerez": "gréer",
    "gréeriez": "gréer",
    "gréerions": "gréer",
    "gréerons": "gréer",
    "gréeront": "gréer",
    "grées": "gréer",
    "gréez": "gréer",
    "grégaires": "grégaire",
    "grégorienne": "grégorien",
    "grégoriennes": "grégorien",
    "grégoriens": "grégorien",
    "gréiez": "gréer",
    "gréions": "gréer",
    "gréons": "gréer",
    "grés": "gré",
    "grésa": "gréser",
    "grésai": "gréser",
    "grésaient": "gréser",
    "grésais": "gréser",
    "grésait": "gréser",
    "grésant": "gréser",
    "grésas": "gréser",
    "grésasse": "gréser",
    "grésassent": "gréser",
    "grésasses": "gréser",
    "grésassiez": "gréser",
    "grésassions": "gréser",
    "grésera": "gréser",
    "gréserai": "gréser",
    "gréseraient": "gréser",
    "gréserais": "gréser",
    "gréserait": "gréser",
    "gréseras": "gréser",
    "gréserez": "gréser",
    "gréseriez": "gréser",
    "gréserions": "gréser",
    "gréserons": "gréser",
    "gréseront": "gréser",
    "grésez": "gréser",
    "grésiez": "gréser",
    "grésilla": "grésiller",
    "grésillai": "grésiller",
    "grésillaient": "grésiller",
    "grésillais": "grésiller",
    "grésillait": "grésiller",
    "grésillant": "grésiller",
    "grésillante": "grésillant",
    "grésillantes": "grésillant",
    "grésillas": "grésiller",
    "grésillasse": "grésiller",
    "grésillassent": "grésiller",
    "grésillasses": "grésiller",
    "grésillassiez": "grésiller",
    "grésillassions": "grésiller",
    "grésille": "grésiller",
    "grésillements": "grésillement",
    "grésillent": "grésiller",
    "grésillera": "grésiller",
    "grésillerai": "grésiller",
    "grésilleraient": "grésiller",
    "grésillerais": "grésiller",
    "grésillerait": "grésiller",
    "grésilleras": "grésiller",
    "grésillerez": "grésiller",
    "grésilleriez": "grésiller",
    "grésillerions": "grésiller",
    "grésillerons": "grésiller",
    "grésilleront": "grésiller",
    "grésilles": "grésiller",
    "grésillez": "grésiller",
    "grésilliez": "grésiller",
    "grésillions": "grésiller",
    "grésillons": "grésiller",
    "grésillâmes": "grésiller",
    "grésillât": "grésiller",
    "grésillâtes": "grésiller",
    "grésillèrent": "grésiller",
    "grésillé": "grésiller",
    "grésils": "grésil",
    "grésions": "gréser",
    "grésons": "gréser",
    "grésâmes": "gréser",
    "grésât": "gréser",
    "grésâtes": "gréser",
    "grésèrent": "gréser",
    "grésé": "gréser",
    "grésée": "gréser",
    "grésées": "gréser",
    "grésés": "gréser",
    "grévistes": "gréviste",
    "gréâmes": "gréer",
    "gréât": "gréer",
    "gréâtes": "gréer",
    "gréèrent": "gréer",
    "gréé": "gréer",
    "gréée": "gréer",
    "gréées": "gréer",
    "gréés": "gréer",
    "grêla": "grêler",
    "grêlaient": "grêler",
    "grêlait": "grêler",
    "grêlant": "grêler",
    "grêle": "grêler",
    "grêlent": "grêler",
    "grêlera": "grêler",
    "grêleraient": "grêler",
    "grêlerait": "grêler",
    "grêles": "grêle",
    "grêlons": "grêlon",
    "grêlât": "grêler",
    "grêlé": "grêler",
    "grêlée": "grêler",
    "grêlées": "grêler",
    "grêlés": "grêler",
    "guadeloupéenne": "guadeloupéen",
    "guadeloupéennes": "guadeloupéen",
    "guadeloupéens": "guadeloupéen",
    "guanacos": "guanaco",
    "guanos": "guano",
    "guatémaltèques": "guatémaltèque",
    "guelfes": "guelfe",
    "gueltes": "guelte",
    "guenilles": "guenille",
    "guenillons": "guenillon",
    "guenons": "guenon",
    "guerillas": "guerilla",
    "guerres": "guerre",
    "guerriers": "guerrier",
    "guerrière": "guerrier",
    "guerrières": "guerrier",
    "guerroie": "guerroyer",
    "guerroient": "guerroyer",
    "guerroiera": "guerroyer",
    "guerroierai": "guerroyer",
    "guerroieraient": "guerroyer",
    "guerroierais": "guerroyer",
    "guerroierait": "guerroyer",
    "guerroieras": "guerroyer",
    "guerroierez": "guerroyer",
    "guerroieriez": "guerroyer",
    "guerroierions": "guerroyer",
    "guerroierons": "guerroyer",
    "guerroieront": "guerroyer",
    "guerroies": "guerroyer",
    "guerroya": "guerroyer",
    "guerroyai": "guerroyer",
    "guerroyaient": "guerroyer",
    "guerroyais": "guerroyer",
    "guerroyait": "guerroyer",
    "guerroyant": "guerroyer",
    "guerroyas": "guerroyer",
    "guerroyasse": "guerroyer",
    "guerroyassent": "guerroyer",
    "guerroyasses": "guerroyer",
    "guerroyassiez": "guerroyer",
    "guerroyassions": "guerroyer",
    "guerroyez": "guerroyer",
    "guerroyiez": "guerroyer",
    "guerroyions": "guerroyer",
    "guerroyons": "guerroyer",
    "guerroyâmes": "guerroyer",
    "guerroyât": "guerroyer",
    "guerroyâtes": "guerroyer",
    "guerroyèrent": "guerroyer",
    "guerroyé": "guerroyer",
    "guets": "guet",
    "guets-apens": "guet-apens",
    "guetta": "guetter",
    "guettai": "guetter",
    "guettaient": "guetter",
    "guettais": "guetter",
    "guettait": "guetter",
    "guettant": "guetter",
    "guettas": "guetter",
    "guettasse": "guetter",
    "guettassent": "guetter",
    "guettasses": "guetter",
    "guettassiez": "guetter",
    "guettassions": "guetter",
    "guette": "guetter",
    "guettent": "guetter",
    "guettera": "guetter",
    "guetterai": "guetter",
    "guetteraient": "guetter",
    "guetterais": "guetter",
    "guetterait": "guetter",
    "guetteras": "guetter",
    "guetterez": "guetter",
    "guetteriez": "guetter",
    "guetterions": "guetter",
    "guetterons": "guetter",
    "guetteront": "guetter",
    "guettes": "guetter",
    "guetteurs": "guetteur",
    "guetteuse": "guetteur",
    "guetteuses": "guetteur",
    "guettez": "guetter",
    "guettiez": "guetter",
    "guettions": "guetter",
    "guettons": "guetter",
    "guettâmes": "guetter",
    "guettât": "guetter",
    "guettâtes": "guetter",
    "guettèrent": "guetter",
    "guetté": "guetter",
    "guettée": "guetter",
    "guettées": "guetter",
    "guettés": "guetter",
    "gueula": "gueuler",
    "gueulai": "gueuler",
    "gueulaient": "gueuler",
    "gueulais": "gueuler",
    "gueulait": "gueuler",
    "gueulant": "gueuler",
    "gueulantes": "gueulante",
    "gueularde": "gueulard",
    "gueulardes": "gueulard",
    "gueulards": "gueulard",
    "gueule": "gueuler",
    "gueulements": "gueulement",
    "gueulent": "gueuler",
    "gueulera": "gueuler",
    "gueulerai": "gueuler",
    "gueulerais": "gueuler",
    "gueulerait": "gueuler",
    "gueules": "gueuler",
    "gueules-de-loup": "gueule-de-loup",
    "gueuletonna": "gueuletonner",
    "gueuletonnai": "gueuletonner",
    "gueuletonnaient": "gueuletonner",
    "gueuletonnais": "gueuletonner",
    "gueuletonnait": "gueuletonner",
    "gueuletonnant": "gueuletonner",
    "gueuletonnas": "gueuletonner",
    "gueuletonnasse": "gueuletonner",
    "gueuletonnassent": "gueuletonner",
    "gueuletonnasses": "gueuletonner",
    "gueuletonnassiez": "gueuletonner",
    "gueuletonnassions": "gueuletonner",
    "gueuletonne": "gueuletonner",
    "gueuletonnent": "gueuletonner",
    "gueuletonnera": "gueuletonner",
    "gueuletonnerai": "gueuletonner",
    "gueuletonneraient": "gueuletonner",
    "gueuletonnerais": "gueuletonner",
    "gueuletonnerait": "gueuletonner",
    "gueuletonneras": "gueuletonner",
    "gueuletonnerez": "gueuletonner",
    "gueuletonneriez": "gueuletonner",
    "gueuletonnerions": "gueuletonner",
    "gueuletonnerons": "gueuletonner",
    "gueuletonneront": "gueuletonner",
    "gueuletonnes": "gueuletonner",
    "gueuletonnez": "gueuletonner",
    "gueuletonniez": "gueuletonner",
    "gueuletonnions": "gueuletonner",
    "gueuletonnons": "gueuletonner",
    "gueuletonnâmes": "gueuletonner",
    "gueuletonnât": "gueuletonner",
    "gueuletonnâtes": "gueuletonner",
    "gueuletonnèrent": "gueuletonner",
    "gueuletonné": "gueuletonner",
    "gueuletons": "gueuleton",
    "gueulettes": "gueulette",
    "gueulez": "gueuler",
    "gueulé": "gueuler",
    "gueulée": "gueuler",
    "gueulés": "gueuler",
    "gueusant": "gueuser",
    "gueusards": "gueusard",
    "gueuse": "gueux",
    "gueuses": "gueux",
    "gugusses": "gugusse",
    "guiboles": "guibole",
    "guibolles": "guibolle",
    "guiches": "guiche",
    "guichetiers": "guichetier",
    "guichetière": "guichetier",
    "guichetières": "guichetier",
    "guichets": "guichet",
    "guida": "guider",
    "guidages": "guidage",
    "guidai": "guider",
    "guidaient": "guider",
    "guidais": "guider",
    "guidait": "guider",
    "guidant": "guider",
    "guidas": "guider",
    "guidasse": "guider",
    "guidassent": "guider",
    "guidasses": "guider",
    "guidassiez": "guider",
    "guidassions": "guider",
    "guide": "guider",
    "guide-ânes": "guide-âne",
    "guideaux": "guideau",
    "guident": "guider",
    "guidera": "guider",
    "guiderai": "guider",
    "guideraient": "guider",
    "guiderais": "guider",
    "guiderait": "guider",
    "guideras": "guider",
    "guiderez": "guider",
    "guideriez": "guider",
    "guiderions": "guider",
    "guiderons": "guider",
    "guideront": "guider",
    "guideropes": "guiderope",
    "guides": "guider",
    "guidez": "guider",
    "guidiez": "guider",
    "guidions": "guider",
    "guidons": "guidon",
    "guidâmes": "guider",
    "guidât": "guider",
    "guidâtes": "guider",
    "guidèrent": "guider",
    "guidé": "guider",
    "guidée": "guider",
    "guidées": "guider",
    "guidés": "guider",
    "guigna": "guigner",
    "guignai": "guigner",
    "guignaient": "guigner",
    "guignais": "guigner",
    "guignait": "guigner",
    "guignant": "guigner",
    "guignas": "guigner",
    "guignasse": "guigner",
    "guignassent": "guigner",
    "guignasses": "guigner",
    "guignassiez": "guigner",
    "guignassions": "guigner",
    "guigne": "guigner",
    "guignent": "guigner",
    "guignera": "guigner",
    "guignerai": "guigner",
    "guigneraient": "guigner",
    "guignerais": "guigner",
    "guignerait": "guigner",
    "guigneras": "guigner",
    "guignerez": "guigner",
    "guigneriez": "guigner",
    "guignerions": "guigner",
    "guignerons": "guigner",
    "guigneront": "guigner",
    "guignes": "guigner",
    "guignez": "guigner",
    "guigniez": "guigner",
    "guignions": "guigner",
    "guignolades": "guignolade",
    "guignolets": "guignolet",
    "guignols": "guignol",
    "guignons": "guignon",
    "guignâmes": "guigner",
    "guignât": "guigner",
    "guignâtes": "guigner",
    "guignèrent": "guigner",
    "guigné": "guigner",
    "guignée": "guigner",
    "guignées": "guigner",
    "guignés": "guigner",
    "guildes": "guilde",
    "guillaumes": "guillaume",
    "guilledous": "guilledou",
    "guillemets": "guillemet",
    "guillemots": "guillemot",
    "guillerets": "guilleret",
    "guillerette": "guilleret",
    "guillerettes": "guilleret",
    "guillocha": "guillocher",
    "guillochai": "guillocher",
    "guillochaient": "guillocher",
    "guillochais": "guillocher",
    "guillochait": "guillocher",
    "guillochant": "guillocher",
    "guillochas": "guillocher",
    "guillochasse": "guillocher",
    "guillochassent": "guillocher",
    "guillochasses": "guillocher",
    "guillochassiez": "guillocher",
    "guillochassions": "guillocher",
    "guilloche": "guillocher",
    "guillochent": "guillocher",
    "guillochera": "guillocher",
    "guillocherai": "guillocher",
    "guillocheraient": "guillocher",
    "guillocherais": "guillocher",
    "guillocherait": "guillocher",
    "guillocheras": "guillocher",
    "guillocherez": "guillocher",
    "guillocheriez": "guillocher",
    "guillocherions": "guillocher",
    "guillocherons": "guillocher",
    "guillocheront": "guillocher",
    "guilloches": "guillocher",
    "guillochez": "guillocher",
    "guillochiez": "guillocher",
    "guillochions": "guillocher",
    "guillochons": "guillocher",
    "guillochures": "guillochure",
    "guillochâmes": "guillocher",
    "guillochât": "guillocher",
    "guillochâtes": "guillocher",
    "guillochèrent": "guillocher",
    "guilloché": "guillocher",
    "guillochée": "guillocher",
    "guillochées": "guillocher",
    "guillochés": "guillocher",
    "guillotina": "guillotiner",
    "guillotinai": "guillotiner",
    "guillotinaient": "guillotiner",
    "guillotinais": "guillotiner",
    "guillotinait": "guillotiner",
    "guillotinant": "guillotiner",
    "guillotinas": "guillotiner",
    "guillotinasse": "guillotiner",
    "guillotinassent": "guillotiner",
    "guillotinasses": "guillotiner",
    "guillotinassiez": "guillotiner",
    "guillotinassions": "guillotiner",
    "guillotine": "guillotiner",
    "guillotinent": "guillotiner",
    "guillotinera": "guillotiner",
    "guillotinerai": "guillotiner",
    "guillotineraient": "guillotiner",
    "guillotinerais": "guillotiner",
    "guillotinerait": "guillotiner",
    "guillotineras": "guillotiner",
    "guillotinerez": "guillotiner",
    "guillotineriez": "guillotiner",
    "guillotinerions": "guillotiner",
    "guillotinerons": "guillotiner",
    "guillotineront": "guillotiner",
    "guillotines": "guillotiner",
    "guillotineurs": "guillotineur",
    "guillotinez": "guillotiner",
    "guillotiniez": "guillotiner",
    "guillotinions": "guillotiner",
    "guillotinons": "guillotiner",
    "guillotinâmes": "guillotiner",
    "guillotinât": "guillotiner",
    "guillotinâtes": "guillotiner",
    "guillotinèrent": "guillotiner",
    "guillotiné": "guillotiner",
    "guillotinée": "guillotiner",
    "guillotinées": "guillotiner",
    "guillotinés": "guillotiner",
    "guimauves": "guimauve",
    "guimbardes": "guimbarde",
    "guimpes": "guimpe",
    "guinchait": "guincher",
    "guinches": "guincher",
    "guinda": "guinder",
    "guindai": "guinder",
    "guindaient": "guinder",
    "guindais": "guinder",
    "guindait": "guinder",
    "guindals": "guindal",
    "guindant": "guinder",
    "guindas": "guinder",
    "guindasse": "guinder",
    "guindassent": "guinder",
    "guindasses": "guinder",
    "guindassiez": "guinder",
    "guindassions": "guinder",
    "guinde": "guinder",
    "guindent": "guinder",
    "guindera": "guinder",
    "guinderai": "guinder",
    "guinderaient": "guinder",
    "guinderais": "guinder",
    "guinderait": "guinder",
    "guinderas": "guinder",
    "guinderez": "guinder",
    "guinderiez": "guinder",
    "guinderions": "guinder",
    "guinderons": "guinder",
    "guinderont": "guinder",
    "guindes": "guinder",
    "guindez": "guinder",
    "guindiez": "guinder",
    "guindions": "guinder",
    "guindons": "guinder",
    "guindâmes": "guinder",
    "guindât": "guinder",
    "guindâtes": "guinder",
    "guindèrent": "guinder",
    "guindé": "guinder",
    "guindée": "guinder",
    "guindées": "guinder",
    "guindés": "guinder",
    "guinguettes": "guinguette",
    "guinéenne": "guinéen",
    "guinéennes": "guinéen",
    "guinéens": "guinéen",
    "guinées": "guinée",
    "guipa": "guiper",
    "guipai": "guiper",
    "guipaient": "guiper",
    "guipais": "guiper",
    "guipait": "guiper",
    "guipant": "guiper",
    "guipas": "guiper",
    "guipasse": "guiper",
    "guipassent": "guiper",
    "guipasses": "guiper",
    "guipassiez": "guiper",
    "guipassions": "guiper",
    "guipe": "guiper",
    "guipent": "guiper",
    "guipera": "guiper",
    "guiperai": "guiper",
    "guiperaient": "guiper",
    "guiperais": "guiper",
    "guiperait": "guiper",
    "guiperas": "guiper",
    "guiperez": "guiper",
    "guiperiez": "guiper",
    "guiperions": "guiper",
    "guiperons": "guiper",
    "guiperont": "guiper",
    "guipes": "guiper",
    "guipez": "guiper",
    "guipiez": "guiper",
    "guipions": "guiper",
    "guipons": "guiper",
    "guipures": "guipure",
    "guipâmes": "guiper",
    "guipât": "guiper",
    "guipâtes": "guiper",
    "guipèrent": "guiper",
    "guipé": "guiper",
    "guipée": "guiper",
    "guipées": "guiper",
    "guipés": "guiper",
    "guirlandes": "guirlande",
    "guis": "gui",
    "guises": "guise",
    "guitares": "guitare",
    "guitaristes": "guitariste",
    "guitounes": "guitoune",
    "gummifères": "gummifère",
    "guns": "gun",
    "gustations": "gustation",
    "gustative": "gustatif",
    "gustatives": "gustatif",
    "guttas-perchas": "gutta-percha",
    "gutturale": "guttural",
    "gutturales": "guttural",
    "gutturaux": "guttural",
    "guyanaise": "guyanais",
    "guyanaises": "guyanais",
    "guéguerres": "guéguerre",
    "guépards": "guépard",
    "guérets": "guéret",
    "guéri": "guérir",
    "guéridons": "guéridon",
    "guérie": "guérir",
    "guéries": "guérir",
    "guérillas": "guérilla",
    "guérilleros": "guérillero",
    "guérira": "guérir",
    "guérirai": "guérir",
    "guériraient": "guérir",
    "guérirais": "guérir",
    "guérirait": "guérir",
    "guériras": "guérir",
    "guérirent": "guérir",
    "guérirez": "guérir",
    "guéririez": "guérir",
    "guéririons": "guérir",
    "guérirons": "guérir",
    "guériront": "guérir",
    "guéris": "guérir",
    "guérisons": "guérison",
    "guérissables": "guérissable",
    "guérissaient": "guérir",
    "guérissais": "guérir",
    "guérissait": "guérir",
    "guérissant": "guérir",
    "guérisse": "guérir",
    "guérissent": "guérir",
    "guérisses": "guérir",
    "guérisseurs": "guérisseur",
    "guérisseuse": "guérisseur",
    "guérisseuses": "guérisseur",
    "guérissez": "guérir",
    "guérissiez": "guérir",
    "guérissions": "guérir",
    "guérissons": "guérir",
    "guérit": "guérir",
    "guérites": "guérite",
    "guérîmes": "guérir",
    "guérît": "guérir",
    "guérîtes": "guérir",
    "gués": "gué",
    "guêpes": "guêpe",
    "guêpières": "guêpière",
    "guêtres": "guêtre",
    "guêtré": "guêtrer",
    "guêtrés": "guêtrer",
    "gymkhanas": "gymkhana",
    "gymnases": "gymnase",
    "gymnastes": "gymnaste",
    "gymnastiques": "gymnastique",
    "gymniques": "gymnique",
    "gymnosophistes": "gymnosophiste",
    "gymnospermes": "gymnosperme",
    "gymnotes": "gymnote",
    "gynécologies": "gynécologie",
    "gynécologiques": "gynécologique",
    "gynécologues": "gynécologue",
    "gynécées": "gynécée",
    "gypaètes": "gypaète",
    "gypses": "gypse",
    "gypseuse": "gypseux",
    "gypsophiles": "gypsophile",
    "gyrins": "gyrin",
    "gyrophares": "gyrophare",
    "gyroscopes": "gyroscope",
    "gâcha": "gâcher",
    "gâchai": "gâcher",
    "gâchaient": "gâcher",
    "gâchais": "gâcher",
    "gâchait": "gâcher",
    "gâchant": "gâcher",
    "gâchas": "gâcher",
    "gâchasse": "gâcher",
    "gâchassent": "gâcher",
    "gâchasses": "gâcher",
    "gâchassiez": "gâcher",
    "gâchassions": "gâcher",
    "gâche": "gâcher",
    "gâchent": "gâcher",
    "gâchera": "gâcher",
    "gâcherai": "gâcher",
    "gâcheraient": "gâcher",
    "gâcherais": "gâcher",
    "gâcherait": "gâcher",
    "gâcheras": "gâcher",
    "gâcherez": "gâcher",
    "gâcheriez": "gâcher",
    "gâcherions": "gâcher",
    "gâcherons": "gâcher",
    "gâcheront": "gâcher",
    "gâches": "gâcher",
    "gâchettes": "gâchette",
    "gâcheurs": "gâcheur",
    "gâcheuse": "gâcheur",
    "gâchez": "gâcher",
    "gâchiez": "gâcher",
    "gâchions": "gâcher",
    "gâchons": "gâcher",
    "gâchâmes": "gâcher",
    "gâchât": "gâcher",
    "gâchâtes": "gâcher",
    "gâchèrent": "gâcher",
    "gâché": "gâcher",
    "gâchée": "gâcher",
    "gâchées": "gâcher",
    "gâchés": "gâcher",
    "gâta": "gâter",
    "gâtai": "gâter",
    "gâtaient": "gâter",
    "gâtais": "gâter",
    "gâtait": "gâter",
    "gâtant": "gâter",
    "gâtas": "gâter",
    "gâtasse": "gâter",
    "gâtassent": "gâter",
    "gâtasses": "gâter",
    "gâtassiez": "gâter",
    "gâtassions": "gâter",
    "gâte": "gâter",
    "gâte-sauces": "gâte-sauce",
    "gâteaux": "gâteau",
    "gâtent": "gâter",
    "gâtera": "gâter",
    "gâterai": "gâter",
    "gâteraient": "gâter",
    "gâterais": "gâter",
    "gâterait": "gâter",
    "gâteras": "gâter",
    "gâterez": "gâter",
    "gâteries": "gâterie",
    "gâteriez": "gâter",
    "gâterions": "gâter",
    "gâterons": "gâter",
    "gâteront": "gâter",
    "gâtes": "gâter",
    "gâteuse": "gâteux",
    "gâteuses": "gâteux",
    "gâtez": "gâter",
    "gâtiez": "gâter",
    "gâtifie": "gâtifier",
    "gâtines": "gâtine",
    "gâtions": "gâter",
    "gâtismes": "gâtisme",
    "gâtons": "gâter",
    "gâtâmes": "gâter",
    "gâtât": "gâter",
    "gâtâtes": "gâter",
    "gâtèrent": "gâter",
    "gâté": "gâter",
    "gâtée": "gâter",
    "gâtées": "gâter",
    "gâtés": "gâter",
    "gèle": "geler",
    "gèlent": "geler",
    "gèlera": "geler",
    "gèlerai": "geler",
    "gèleraient": "geler",
    "gèlerais": "geler",
    "gèlerait": "geler",
    "gèleras": "geler",
    "gèlerez": "geler",
    "gèleriez": "geler",
    "gèlerions": "geler",
    "gèlerons": "geler",
    "gèleront": "geler",
    "gèles": "geler",
    "gènes": "gène",
    "gère": "gérer",
    "gèrent": "gérer",
    "gères": "gérer",
    "géante": "géant",
    "géantes": "géant",
    "géants": "géant",
    "géhennes": "géhenne",
    "gélatines": "gélatine",
    "gélatineuse": "gélatineux",
    "gélatineuses": "gélatineux",
    "gélifia": "gélifier",
    "gélifiai": "gélifier",
    "gélifiaient": "gélifier",
    "gélifiais": "gélifier",
    "gélifiait": "gélifier",
    "gélifiant": "gélifier",
    "gélifias": "gélifier",
    "gélifiasse": "gélifier",
    "gélifiassent": "gélifier",
    "gélifiasses": "gélifier",
    "gélifiassiez": "gélifier",
    "gélifiassions": "gélifier",
    "gélifie": "gélifier",
    "gélifient": "gélifier",
    "gélifiera": "gélifier",
    "gélifierai": "gélifier",
    "gélifieraient": "gélifier",
    "gélifierais": "gélifier",
    "gélifierait": "gélifier",
    "gélifieras": "gélifier",
    "gélifierez": "gélifier",
    "gélifieriez": "gélifier",
    "gélifierions": "gélifier",
    "gélifierons": "gélifier",
    "gélifieront": "gélifier",
    "gélifies": "gélifier",
    "gélifiez": "gélifier",
    "gélifiiez": "gélifier",
    "gélifiions": "gélifier",
    "gélifions": "gélifier",
    "gélifiâmes": "gélifier",
    "gélifiât": "gélifier",
    "gélifiâtes": "gélifier",
    "gélifièrent": "gélifier",
    "gélifié": "gélifier",
    "gélifiée": "gélifier",
    "gélifiées": "gélifier",
    "gélifiés": "gélifier",
    "gélines": "géline",
    "gélinottes": "gélinotte",
    "gélules": "gélule",
    "gémeaux": "gémeau",
    "gémellaires": "gémellaire",
    "gémi": "gémir",
    "gémie": "gémir",
    "gémina": "géminer",
    "géminai": "géminer",
    "géminaient": "géminer",
    "géminais": "géminer",
    "géminait": "géminer",
    "géminant": "géminer",
    "géminas": "géminer",
    "géminasse": "géminer",
    "géminassent": "géminer",
    "géminasses": "géminer",
    "géminassiez": "géminer",
    "géminassions": "géminer",
    "gémine": "géminer",
    "géminent": "géminer",
    "géminera": "géminer",
    "géminerai": "géminer",
    "gémineraient": "géminer",
    "géminerais": "géminer",
    "géminerait": "géminer",
    "gémineras": "géminer",
    "géminerez": "géminer",
    "gémineriez": "géminer",
    "géminerions": "géminer",
    "géminerons": "géminer",
    "gémineront": "géminer",
    "gémines": "géminer",
    "géminez": "géminer",
    "géminiez": "géminer",
    "géminions": "géminer",
    "géminons": "géminer",
    "géminâmes": "géminer",
    "géminât": "géminer",
    "géminâtes": "géminer",
    "géminèrent": "géminer",
    "géminé": "géminer",
    "géminée": "géminer",
    "géminées": "géminer",
    "géminés": "géminer",
    "gémira": "gémir",
    "gémirai": "gémir",
    "gémiraient": "gémir",
    "gémirais": "gémir",
    "gémirait": "gémir",
    "gémiras": "gémir",
    "gémirent": "gémir",
    "gémirez": "gémir",
    "gémiriez": "gémir",
    "gémirions": "gémir",
    "gémirons": "gémir",
    "gémiront": "gémir",
    "gémis": "gémir",
    "gémissaient": "gémir",
    "gémissais": "gémir",
    "gémissait": "gémir",
    "gémissant": "gémir",
    "gémissante": "gémissant",
    "gémissantes": "gémissant",
    "gémissants": "gémissant",
    "gémisse": "gémir",
    "gémissements": "gémissement",
    "gémissent": "gémir",
    "gémisses": "gémir",
    "gémisseurs": "gémisseur",
    "gémissez": "gémir",
    "gémissiez": "gémir",
    "gémissions": "gémir",
    "gémissons": "gémir",
    "gémit": "gémir",
    "gémîmes": "gémir",
    "gémît": "gémir",
    "gémîtes": "gémir",
    "géniale": "génial",
    "géniales": "génial",
    "géniaux": "génial",
    "génies": "génie",
    "génisses": "génisse",
    "génitale": "génital",
    "génitales": "génital",
    "génitaux": "génital",
    "géniteurs": "géniteur",
    "génitifs": "génitif",
    "génitoires": "génitoire",
    "génitrice": "géniteur",
    "génitrices": "géniteur",
    "génocides": "génocide",
    "génoise": "génois",
    "génoises": "génois",
    "génomes": "génome",
    "génomiques": "génomique",
    "génotypes": "génotype",
    "génovéfains": "génovéfain",
    "génuflexions": "génuflexion",
    "génère": "générer",
    "génèrent": "générer",
    "génères": "générer",
    "généalogies": "généalogie",
    "généalogiques": "généalogique",
    "généalogistes": "généalogiste",
    "génépis": "génépi",
    "généra": "générer",
    "générai": "générer",
    "généraient": "générer",
    "générais": "générer",
    "générait": "générer",
    "générale": "général",
    "générales": "général",
    "généralisa": "généraliser",
    "généralisai": "généraliser",
    "généralisaient": "généraliser",
    "généralisais": "généraliser",
    "généralisait": "généraliser",
    "généralisant": "généraliser",
    "généralisas": "généraliser",
    "généralisasse": "généraliser",
    "généralisassent": "généraliser",
    "généralisasses": "généraliser",
    "généralisassiez": "généraliser",
    "généralisassions": "généraliser",
    "généralisations": "généralisation",
    "généralise": "généraliser",
    "généralisent": "généraliser",
    "généralisera": "généraliser",
    "généraliserai": "généraliser",
    "généraliseraient": "généraliser",
    "généraliserais": "généraliser",
    "généraliserait": "généraliser",
    "généraliseras": "généraliser",
    "généraliserez": "généraliser",
    "généraliseriez": "généraliser",
    "généraliserions": "généraliser",
    "généraliserons": "généraliser",
    "généraliseront": "généraliser",
    "généralises": "généraliser",
    "généralisez": "généraliser",
    "généralisiez": "généraliser",
    "généralisions": "généraliser",
    "généralisons": "généraliser",
    "généralistes": "généraliste",
    "généralisâmes": "généraliser",
    "généralisât": "généraliser",
    "généralisâtes": "généraliser",
    "généralisèrent": "généraliser",
    "généralisé": "généraliser",
    "généralisée": "généraliser",
    "généralisées": "généraliser",
    "généralisés": "généraliser",
    "généralités": "généralité",
    "générals": "général",
    "générant": "générer",
    "généras": "générer",
    "générasse": "générer",
    "générassent": "générer",
    "générasses": "générer",
    "générassiez": "générer",
    "générassions": "générer",
    "générateurs": "générateur",
    "générations": "génération",
    "générative": "génératif",
    "génératrice": "générateur",
    "génératrices": "générateur",
    "généraux": "général",
    "générera": "générer",
    "générerai": "générer",
    "généreraient": "générer",
    "générerais": "générer",
    "générerait": "générer",
    "généreras": "générer",
    "générerez": "générer",
    "généreriez": "générer",
    "générerions": "générer",
    "générerons": "générer",
    "généreront": "générer",
    "généreuse": "généreux",
    "généreuses": "généreux",
    "générez": "générer",
    "génériez": "générer",
    "générions": "générer",
    "génériques": "générique",
    "générons": "générer",
    "générosités": "générosité",
    "générâmes": "générer",
    "générât": "générer",
    "générâtes": "générer",
    "générèrent": "générer",
    "généré": "générer",
    "générée": "générer",
    "générées": "générer",
    "générés": "générer",
    "généticienne": "généticien",
    "généticiennes": "généticien",
    "généticiens": "généticien",
    "génétiques": "génétique",
    "géocorises": "géocorise",
    "géodésiens": "géodésien",
    "géodésies": "géodésie",
    "géodésiques": "géodésique",
    "géographes": "géographe",
    "géographies": "géographie",
    "géographiques": "géographique",
    "géologies": "géologie",
    "géologiques": "géologique",
    "géologues": "géologue",
    "géomagnétiques": "géomagnétique",
    "géomètres": "géomètre",
    "géométries": "géométrie",
    "géométriques": "géométrique",
    "géophysicienne": "géophysicien",
    "géophysiciennes": "géophysicien",
    "géophysiciens": "géophysicien",
    "géopolitiques": "géopolitique",
    "géorgienne": "géorgien",
    "géorgiennes": "géorgien",
    "géorgiens": "géorgien",
    "géorgiques": "géorgique",
    "géosciences": "géoscience",
    "géostationnaires": "géostationnaire",
    "géostratégiques": "géostratégique",
    "géosynclinaux": "géosynclinal",
    "géothermale": "géothermal",
    "géothermies": "géothermie",
    "géothermiques": "géothermique",
    "géotropiques": "géotropique",
    "géra": "gérer",
    "gérables": "gérable",
    "gérai": "gérer",
    "géraient": "gérer",
    "gérais": "gérer",
    "gérait": "gérer",
    "gérances": "gérance",
    "géraniums": "géranium",
    "gérant": "gérer",
    "gérante": "gérant",
    "gérantes": "gérant",
    "gérants": "gérant",
    "géras": "gérer",
    "gérasse": "gérer",
    "gérassent": "gérer",
    "gérasses": "gérer",
    "gérassiez": "gérer",
    "gérassions": "gérer",
    "gérera": "gérer",
    "gérerai": "gérer",
    "géreraient": "gérer",
    "gérerais": "gérer",
    "gérerait": "gérer",
    "géreras": "gérer",
    "gérerez": "gérer",
    "géreriez": "gérer",
    "gérerions": "gérer",
    "gérerons": "gérer",
    "géreront": "gérer",
    "gérez": "gérer",
    "gériatriques": "gériatrique",
    "gériez": "gérer",
    "gérions": "gérer",
    "gérondifs": "gérondif",
    "gérons": "gérer",
    "gérontes": "géronte",
    "gérontocraties": "gérontocratie",
    "gérontologies": "gérontologie",
    "gérontophiles": "gérontophile",
    "gérâmes": "gérer",
    "gérât": "gérer",
    "gérâtes": "gérer",
    "gérèrent": "gérer",
    "géré": "gérer",
    "gérée": "gérer",
    "gérées": "gérer",
    "gérés": "gérer",
    "gésiers": "gésier",
    "gêna": "gêner",
    "gênai": "gêner",
    "gênaient": "gêner",
    "gênais": "gêner",
    "gênait": "gêner",
    "gênant": "gêner",
    "gênante": "gênant",
    "gênantes": "gênant",
    "gênants": "gênant",
    "gênas": "gêner",
    "gênasse": "gêner",
    "gênassent": "gêner",
    "gênasses": "gêner",
    "gênassiez": "gêner",
    "gênassions": "gêner",
    "gêne": "gêner",
    "gênent": "gêner",
    "gênera": "gêner",
    "gênerai": "gêner",
    "gêneraient": "gêner",
    "gênerais": "gêner",
    "gênerait": "gêner",
    "gêneras": "gêner",
    "gênerez": "gêner",
    "gêneriez": "gêner",
    "gênerions": "gêner",
    "gênerons": "gêner",
    "gêneront": "gêner",
    "gênes": "gêner",
    "gêneurs": "gêneur",
    "gêneuse": "gêneur",
    "gêneuses": "gêneur",
    "gênez": "gêner",
    "gêniez": "gêner",
    "gênions": "gêner",
    "gênons": "gêner",
    "gênâmes": "gêner",
    "gênât": "gêner",
    "gênâtes": "gêner",
    "gênèrent": "gêner",
    "gêné": "gêner",
    "gênée": "gêner",
    "gênées": "gêner",
    "gênés": "gêner",
    "gît": "gésir",
    "gîta": "gîter",
    "gîtait": "gîter",
    "gîtent": "gîter",
    "gîtera": "gîter",
    "gîtes": "gîte",
    "gîté": "gîter",
    "habiles": "habile",
    "habiletés": "habileté",
    "habilita": "habiliter",
    "habilitai": "habiliter",
    "habilitaient": "habiliter",
    "habilitais": "habiliter",
    "habilitait": "habiliter",
    "habilitant": "habiliter",
    "habilitas": "habiliter",
    "habilitasse": "habiliter",
    "habilitassent": "habiliter",
    "habilitasses": "habiliter",
    "habilitassiez": "habiliter",
    "habilitassions": "habiliter",
    "habilitations": "habilitation",
    "habilite": "habiliter",
    "habilitent": "habiliter",
    "habilitera": "habiliter",
    "habiliterai": "habiliter",
    "habiliteraient": "habiliter",
    "habiliterais": "habiliter",
    "habiliterait": "habiliter",
    "habiliteras": "habiliter",
    "habiliterez": "habiliter",
    "habiliteriez": "habiliter",
    "habiliterions": "habiliter",
    "habiliterons": "habiliter",
    "habiliteront": "habiliter",
    "habilites": "habiliter",
    "habilitez": "habiliter",
    "habilitiez": "habiliter",
    "habilitions": "habiliter",
    "habilitons": "habiliter",
    "habilitâmes": "habiliter",
    "habilitât": "habiliter",
    "habilitâtes": "habiliter",
    "habilitèrent": "habiliter",
    "habilité": "habiliter",
    "habilitée": "habiliter",
    "habilitées": "habiliter",
    "habilités": "habiliter",
    "habilla": "habiller",
    "habillages": "habillage",
    "habillai": "habiller",
    "habillaient": "habiller",
    "habillais": "habiller",
    "habillait": "habiller",
    "habillant": "habiller",
    "habillas": "habiller",
    "habillasse": "habiller",
    "habillassent": "habiller",
    "habillasses": "habiller",
    "habillassiez": "habiller",
    "habillassions": "habiller",
    "habille": "habiller",
    "habillements": "habillement",
    "habillent": "habiller",
    "habillera": "habiller",
    "habillerai": "habiller",
    "habilleraient": "habiller",
    "habillerais": "habiller",
    "habillerait": "habiller",
    "habilleras": "habiller",
    "habillerez": "habiller",
    "habilleriez": "habiller",
    "habillerions": "habiller",
    "habillerons": "habiller",
    "habilleront": "habiller",
    "habilles": "habiller",
    "habilleurs": "habilleur",
    "habilleuse": "habilleur",
    "habilleuses": "habilleur",
    "habillez": "habiller",
    "habilliez": "habiller",
    "habillions": "habiller",
    "habillons": "habiller",
    "habillâmes": "habiller",
    "habillât": "habiller",
    "habillâtes": "habiller",
    "habillèrent": "habiller",
    "habillé": "habiller",
    "habillée": "habiller",
    "habillées": "habiller",
    "habillés": "habiller",
    "habita": "habiter",
    "habitabilités": "habitabilité",
    "habitables": "habitable",
    "habitacles": "habitacle",
    "habitai": "habiter",
    "habitaient": "habiter",
    "habitais": "habiter",
    "habitait": "habiter",
    "habitant": "habiter",
    "habitante": "habitant",
    "habitantes": "habitant",
    "habitants": "habitant",
    "habitas": "habiter",
    "habitasse": "habiter",
    "habitassent": "habiter",
    "habitasses": "habiter",
    "habitassiez": "habiter",
    "habitassions": "habiter",
    "habitations": "habitation",
    "habitats": "habitat",
    "habite": "habiter",
    "habitent": "habiter",
    "habitera": "habiter",
    "habiterai": "habiter",
    "habiteraient": "habiter",
    "habiterais": "habiter",
    "habiterait": "habiter",
    "habiteras": "habiter",
    "habiterez": "habiter",
    "habiteriez": "habiter",
    "habiterions": "habiter",
    "habiterons": "habiter",
    "habiteront": "habiter",
    "habites": "habiter",
    "habitez": "habiter",
    "habitiez": "habiter",
    "habitions": "habiter",
    "habitons": "habiter",
    "habits": "habit",
    "habitua": "habituer",
    "habituai": "habituer",
    "habituaient": "habituer",
    "habituais": "habituer",
    "habituait": "habituer",
    "habituant": "habituer",
    "habituas": "habituer",
    "habituasse": "habituer",
    "habituassent": "habituer",
    "habituasses": "habituer",
    "habituassiez": "habituer",
    "habituassions": "habituer",
    "habitudes": "habitude",
    "habitue": "habituer",
    "habituelle": "habituel",
    "habituelles": "habituel",
    "habituels": "habituel",
    "habituent": "habituer",
    "habituera": "habituer",
    "habituerai": "habituer",
    "habitueraient": "habituer",
    "habituerais": "habituer",
    "habituerait": "habituer",
    "habitueras": "habituer",
    "habituerez": "habituer",
    "habitueriez": "habituer",
    "habituerions": "habituer",
    "habituerons": "habituer",
    "habitueront": "habituer",
    "habitues": "habituer",
    "habituez": "habituer",
    "habituiez": "habituer",
    "habituions": "habituer",
    "habituons": "habituer",
    "habituâmes": "habituer",
    "habituât": "habituer",
    "habituâtes": "habituer",
    "habituèrent": "habituer",
    "habitué": "habituer",
    "habituée": "habituer",
    "habituées": "habituer",
    "habitués": "habituer",
    "habitâmes": "habiter",
    "habitât": "habiter",
    "habitâtes": "habiter",
    "habitèrent": "habiter",
    "habité": "habiter",
    "habitée": "habiter",
    "habitées": "habiter",
    "habités": "habiter",
    "hacha": "hacher",
    "hachages": "hachage",
    "hachai": "hacher",
    "hachaient": "hacher",
    "hachais": "hacher",
    "hachait": "hacher",
    "hachant": "hacher",
    "hachas": "hacher",
    "hachasse": "hacher",
    "hachassent": "hacher",
    "hachasses": "hacher",
    "hachassiez": "hacher",
    "hachassions": "hacher",
    "hache": "hacher",
    "hache-légumes": "hache-légume",
    "hachent": "hacher",
    "hachera": "hacher",
    "hacherai": "hacher",
    "hacheraient": "hacher",
    "hacherais": "hacher",
    "hacherait": "hacher",
    "hacheras": "hacher",
    "hachereaux": "hachereau",
    "hacherez": "hacher",
    "hacheriez": "hacher",
    "hacherions": "hacher",
    "hacherons": "hacher",
    "hacheront": "hacher",
    "haches": "hacher",
    "hachettes": "hachette",
    "hacheurs": "hacheur",
    "hachez": "hacher",
    "hachiez": "hacher",
    "hachions": "hacher",
    "hachischs": "hachisch",
    "hachoirs": "hachoir",
    "hachons": "hacher",
    "hachuraient": "hachurer",
    "hachurait": "hachurer",
    "hachurant": "hachurer",
    "hachure": "hachurer",
    "hachures": "hachure",
    "hachuré": "hachurer",
    "hachurée": "hachurer",
    "hachurées": "hachurer",
    "hachurés": "hachurer",
    "hachâmes": "hacher",
    "hachât": "hacher",
    "hachâtes": "hacher",
    "hachèrent": "hacher",
    "haché": "hacher",
    "hachée": "hacher",
    "hachées": "hacher",
    "hachés": "hacher",
    "haciendas": "hacienda",
    "hackers": "hacker",
    "hadale": "hadal",
    "hadales": "hadal",
    "hadaux": "hadal",
    "haddocks": "haddock",
    "hadroniques": "hadronique",
    "hafniums": "hafnium",
    "hagarde": "hagard",
    "hagardes": "hagard",
    "hagards": "hagard",
    "hagiographies": "hagiographie",
    "haies": "haie",
    "haillonneuse": "haillonneux",
    "haillonneuses": "haillonneux",
    "haillons": "haillon",
    "haines": "haine",
    "haineuse": "haineux",
    "haineuses": "haineux",
    "haires": "haire",
    "hais": "haïr",
    "hait": "haïr",
    "hala": "haler",
    "halages": "halage",
    "halai": "haler",
    "halaient": "haler",
    "halais": "haler",
    "halait": "haler",
    "halant": "haler",
    "halas": "haler",
    "halasse": "haler",
    "halassent": "haler",
    "halasses": "haler",
    "halassiez": "haler",
    "halassions": "haler",
    "halbrans": "halbran",
    "hale": "haler",
    "haleines": "haleine",
    "halent": "haler",
    "halera": "haler",
    "halerai": "haler",
    "haleraient": "haler",
    "halerais": "haler",
    "halerait": "haler",
    "haleras": "haler",
    "halerez": "haler",
    "haleriez": "haler",
    "halerions": "haler",
    "halerons": "haler",
    "haleront": "haler",
    "hales": "haler",
    "haleta": "haleter",
    "haletai": "haleter",
    "haletaient": "haleter",
    "haletais": "haleter",
    "haletait": "haleter",
    "haletant": "haleter",
    "haletante": "haletant",
    "haletantes": "haletant",
    "haletants": "haletant",
    "haletas": "haleter",
    "haletasse": "haleter",
    "haletassent": "haleter",
    "haletasses": "haleter",
    "haletassiez": "haleter",
    "haletassions": "haleter",
    "haletez": "haleter",
    "haletiez": "haleter",
    "haletions": "haleter",
    "haletons": "haleter",
    "haletâmes": "haleter",
    "haletât": "haleter",
    "haletâtes": "haleter",
    "haletèrent": "haleter",
    "haleté": "haleter",
    "haleurs": "haleur",
    "halez": "haler",
    "half-tracks": "half-track",
    "halieutiques": "halieutique",
    "haliez": "haler",
    "halions": "haler",
    "hallalis": "hallali",
    "hallebardes": "hallebarde",
    "hallebardiers": "hallebardier",
    "halles": "halle",
    "halliers": "hallier",
    "halls": "hall",
    "hallucina": "halluciner",
    "hallucinai": "halluciner",
    "hallucinaient": "halluciner",
    "hallucinais": "halluciner",
    "hallucinait": "halluciner",
    "hallucinant": "halluciner",
    "hallucinante": "hallucinant",
    "hallucinantes": "hallucinant",
    "hallucinants": "hallucinant",
    "hallucinas": "halluciner",
    "hallucinasse": "halluciner",
    "hallucinassent": "halluciner",
    "hallucinasses": "halluciner",
    "hallucinassiez": "halluciner",
    "hallucinassions": "halluciner",
    "hallucinations": "hallucination",
    "hallucinatoires": "hallucinatoire",
    "hallucine": "halluciner",
    "hallucinent": "halluciner",
    "hallucinera": "halluciner",
    "hallucinerai": "halluciner",
    "hallucineraient": "halluciner",
    "hallucinerais": "halluciner",
    "hallucinerait": "halluciner",
    "hallucineras": "halluciner",
    "hallucinerez": "halluciner",
    "hallucineriez": "halluciner",
    "hallucinerions": "halluciner",
    "hallucinerons": "halluciner",
    "hallucineront": "halluciner",
    "hallucines": "halluciner",
    "hallucinez": "halluciner",
    "halluciniez": "halluciner",
    "hallucinions": "halluciner",
    "hallucinogènes": "hallucinogène",
    "hallucinons": "halluciner",
    "hallucinâmes": "halluciner",
    "hallucinât": "halluciner",
    "hallucinâtes": "halluciner",
    "hallucinèrent": "halluciner",
    "halluciné": "halluciner",
    "hallucinée": "halluciner",
    "hallucinées": "halluciner",
    "hallucinés": "halluciner",
    "halogènes": "halogène",
    "halogénée": "halogéné",
    "halogénées": "halogéné",
    "halogénés": "halogéné",
    "halons": "halon",
    "halos": "halo",
    "halte": "halter",
    "haltes": "halte",
    "haltères": "haltère",
    "haltérophiles": "haltérophile",
    "halâmes": "haler",
    "halât": "haler",
    "halâtes": "haler",
    "halèrent": "haler",
    "halète": "haleter",
    "halètements": "halètement",
    "halètent": "haleter",
    "halètera": "haleter",
    "halèterai": "haleter",
    "halèteraient": "haleter",
    "halèterais": "haleter",
    "halèterait": "haleter",
    "halèteras": "haleter",
    "halèterez": "haleter",
    "halèteriez": "haleter",
    "halèterions": "haleter",
    "halèterons": "haleter",
    "halèteront": "haleter",
    "halètes": "haleter",
    "halé": "haler",
    "halée": "haler",
    "halées": "haler",
    "halés": "haler",
    "hamacs": "hamac",
    "hamadas": "hamada",
    "hambourgeoise": "hambourgeois",
    "hambourgeoises": "hambourgeois",
    "hamburgers": "hamburger",
    "hameaux": "hameau",
    "hameçonne": "hameçonner",
    "hameçons": "hameçon",
    "hammams": "hammam",
    "hampes": "hampe",
    "hamsters": "hamster",
    "hanaps": "hanap",
    "hanches": "hanche",
    "hanchée": "hancher",
    "handballs": "handball",
    "handicapait": "handicaper",
    "handicape": "handicaper",
    "handicapera": "handicaper",
    "handicaps": "handicap",
    "handicapé": "handicaper",
    "handicapée": "handicaper",
    "handicapées": "handicaper",
    "handicapés": "handicaper",
    "hangars": "hangar",
    "hannetonna": "hannetonner",
    "hannetonnages": "hannetonnage",
    "hannetonnai": "hannetonner",
    "hannetonnaient": "hannetonner",
    "hannetonnais": "hannetonner",
    "hannetonnait": "hannetonner",
    "hannetonnant": "hannetonner",
    "hannetonnas": "hannetonner",
    "hannetonnasse": "hannetonner",
    "hannetonnassent": "hannetonner",
    "hannetonnasses": "hannetonner",
    "hannetonnassiez": "hannetonner",
    "hannetonnassions": "hannetonner",
    "hannetonne": "hannetonner",
    "hannetonnent": "hannetonner",
    "hannetonnera": "hannetonner",
    "hannetonnerai": "hannetonner",
    "hannetonneraient": "hannetonner",
    "hannetonnerais": "hannetonner",
    "hannetonnerait": "hannetonner",
    "hannetonneras": "hannetonner",
    "hannetonnerez": "hannetonner",
    "hannetonneriez": "hannetonner",
    "hannetonnerions": "hannetonner",
    "hannetonnerons": "hannetonner",
    "hannetonneront": "hannetonner",
    "hannetonnes": "hannetonner",
    "hannetonnez": "hannetonner",
    "hannetonniez": "hannetonner",
    "hannetonnions": "hannetonner",
    "hannetonnons": "hannetonner",
    "hannetonnâmes": "hannetonner",
    "hannetonnât": "hannetonner",
    "hannetonnâtes": "hannetonner",
    "hannetonnèrent": "hannetonner",
    "hannetonné": "hannetonner",
    "hannetonnée": "hannetonner",
    "hannetonnées": "hannetonner",
    "hannetonnés": "hannetonner",
    "hannetons": "hanneton",
    "hanovriens": "hanovrien",
    "hanta": "hanter",
    "hantai": "hanter",
    "hantaient": "hanter",
    "hantais": "hanter",
    "hantait": "hanter",
    "hantant": "hanter",
    "hantas": "hanter",
    "hantasse": "hanter",
    "hantassent": "hanter",
    "hantasses": "hanter",
    "hantassiez": "hanter",
    "hantassions": "hanter",
    "hante": "hanter",
    "hantent": "hanter",
    "hantera": "hanter",
    "hanterai": "hanter",
    "hanteraient": "hanter",
    "hanterais": "hanter",
    "hanterait": "hanter",
    "hanteras": "hanter",
    "hanterez": "hanter",
    "hanteriez": "hanter",
    "hanterions": "hanter",
    "hanterons": "hanter",
    "hanteront": "hanter",
    "hantes": "hanter",
    "hantez": "hanter",
    "hantiez": "hanter",
    "hantions": "hanter",
    "hantises": "hantise",
    "hantons": "hanter",
    "hantâmes": "hanter",
    "hantât": "hanter",
    "hantâtes": "hanter",
    "hantèrent": "hanter",
    "hanté": "hanter",
    "hantée": "hanter",
    "hantées": "hanter",
    "hantés": "hanter",
    "happa": "happer",
    "happai": "happer",
    "happaient": "happer",
    "happais": "happer",
    "happait": "happer",
    "happant": "happer",
    "happas": "happer",
    "happasse": "happer",
    "happassent": "happer",
    "happasses": "happer",
    "happassiez": "happer",
    "happassions": "happer",
    "happe": "happer",
    "happenings": "happening",
    "happent": "happer",
    "happera": "happer",
    "happerai": "happer",
    "happeraient": "happer",
    "happerais": "happer",
    "happerait": "happer",
    "happeras": "happer",
    "happerez": "happer",
    "happeriez": "happer",
    "happerions": "happer",
    "happerons": "happer",
    "happeront": "happer",
    "happes": "happer",
    "happeurs": "happeur",
    "happez": "happer",
    "happiez": "happer",
    "happions": "happer",
    "happons": "happer",
    "happy ends": "happy end",
    "happâmes": "happer",
    "happât": "happer",
    "happâtes": "happer",
    "happèrent": "happer",
    "happé": "happer",
    "happée": "happer",
    "happées": "happer",
    "happés": "happer",
    "haquenées": "haquenée",
    "haquets": "haquet",
    "hara-kiris": "hara-kiri",
    "harangua": "haranguer",
    "haranguai": "haranguer",
    "haranguaient": "haranguer",
    "haranguais": "haranguer",
    "haranguait": "haranguer",
    "haranguant": "haranguer",
    "haranguas": "haranguer",
    "haranguasse": "haranguer",
    "haranguassent": "haranguer",
    "haranguasses": "haranguer",
    "haranguassiez": "haranguer",
    "haranguassions": "haranguer",
    "harangue": "haranguer",
    "haranguent": "haranguer",
    "haranguera": "haranguer",
    "haranguerai": "haranguer",
    "harangueraient": "haranguer",
    "haranguerais": "haranguer",
    "haranguerait": "haranguer",
    "harangueras": "haranguer",
    "haranguerez": "haranguer",
    "harangueriez": "haranguer",
    "haranguerions": "haranguer",
    "haranguerons": "haranguer",
    "harangueront": "haranguer",
    "harangues": "haranguer",
    "haranguez": "haranguer",
    "haranguiez": "haranguer",
    "haranguions": "haranguer",
    "haranguons": "haranguer",
    "haranguâmes": "haranguer",
    "haranguât": "haranguer",
    "haranguâtes": "haranguer",
    "haranguèrent": "haranguer",
    "harangué": "haranguer",
    "haranguée": "haranguer",
    "haranguées": "haranguer",
    "harangués": "haranguer",
    "harassa": "harasser",
    "harassai": "harasser",
    "harassaient": "harasser",
    "harassais": "harasser",
    "harassait": "harasser",
    "harassant": "harasser",
    "harassante": "harassant",
    "harassantes": "harassant",
    "harassants": "harassant",
    "harassas": "harasser",
    "harassasse": "harasser",
    "harassassent": "harasser",
    "harassasses": "harasser",
    "harassassiez": "harasser",
    "harassassions": "harasser",
    "harasse": "harasser",
    "harassent": "harasser",
    "harassera": "harasser",
    "harasserai": "harasser",
    "harasseraient": "harasser",
    "harasserais": "harasser",
    "harasserait": "harasser",
    "harasseras": "harasser",
    "harasserez": "harasser",
    "harasseriez": "harasser",
    "harasserions": "harasser",
    "harasserons": "harasser",
    "harasseront": "harasser",
    "harasses": "harasser",
    "harassez": "harasser",
    "harassiez": "harasser",
    "harassions": "harasser",
    "harassons": "harasser",
    "harassâmes": "harasser",
    "harassât": "harasser",
    "harassâtes": "harasser",
    "harassèrent": "harasser",
    "harassé": "harasser",
    "harassée": "harasser",
    "harassées": "harasser",
    "harassés": "harasser",
    "harcela": "harceler",
    "harcelai": "harceler",
    "harcelaient": "harceler",
    "harcelais": "harceler",
    "harcelait": "harceler",
    "harcelant": "harceler",
    "harcelante": "harcelant",
    "harcelantes": "harcelant",
    "harcelants": "harcelant",
    "harcelas": "harceler",
    "harcelasse": "harceler",
    "harcelassent": "harceler",
    "harcelasses": "harceler",
    "harcelassiez": "harceler",
    "harcelassions": "harceler",
    "harceleuse": "harceleur",
    "harcelez": "harceler",
    "harceliez": "harceler",
    "harcelions": "harceler",
    "harcelle": "harceler",
    "harcellent": "harceler",
    "harcellera": "harceler",
    "harcellerai": "harceler",
    "harcelleraient": "harceler",
    "harcellerais": "harceler",
    "harcellerait": "harceler",
    "harcelleras": "harceler",
    "harcellerez": "harceler",
    "harcelleriez": "harceler",
    "harcellerions": "harceler",
    "harcellerons": "harceler",
    "harcelleront": "harceler",
    "harcelles": "harceler",
    "harcelons": "harceler",
    "harcelâmes": "harceler",
    "harcelât": "harceler",
    "harcelâtes": "harceler",
    "harcelèrent": "harceler",
    "harcelé": "harceler",
    "harcelée": "harceler",
    "harcelées": "harceler",
    "harcelés": "harceler",
    "harcèle": "harceler",
    "harcèlements": "harcèlement",
    "harcèlent": "harceler",
    "harcèlera": "harceler",
    "harcèlerai": "harceler",
    "harcèleraient": "harceler",
    "harcèlerez": "harceler",
    "harcèlerons": "harceler",
    "harcèleront": "harceler",
    "hard-tops": "hard-top",
    "hardent": "harder",
    "hardes": "harde",
    "hardie": "hardi",
    "hardies": "hardi",
    "hardiesses": "hardiesse",
    "hardis": "hardi",
    "harems": "harem",
    "harengs": "hareng",
    "hargnes": "hargne",
    "hargneuse": "hargneux",
    "hargneuses": "hargneux",
    "haricots": "haricot",
    "haridelles": "haridelle",
    "harkis": "harki",
    "harmattans": "harmattan",
    "harmolodies": "harmolodie",
    "harmonicas": "harmonica",
    "harmonies": "harmonie",
    "harmonieuse": "harmonieux",
    "harmonieuses": "harmonieux",
    "harmoniques": "harmonique",
    "harmonisa": "harmoniser",
    "harmonisai": "harmoniser",
    "harmonisaient": "harmoniser",
    "harmonisais": "harmoniser",
    "harmonisait": "harmoniser",
    "harmonisant": "harmoniser",
    "harmonisas": "harmoniser",
    "harmonisasse": "harmoniser",
    "harmonisassent": "harmoniser",
    "harmonisasses": "harmoniser",
    "harmonisassiez": "harmoniser",
    "harmonisassions": "harmoniser",
    "harmonisateurs": "harmonisateur",
    "harmonisations": "harmonisation",
    "harmonisatrices": "harmonisateur",
    "harmonise": "harmoniser",
    "harmonisent": "harmoniser",
    "harmonisera": "harmoniser",
    "harmoniserai": "harmoniser",
    "harmoniseraient": "harmoniser",
    "harmoniserais": "harmoniser",
    "harmoniserait": "harmoniser",
    "harmoniseras": "harmoniser",
    "harmoniserez": "harmoniser",
    "harmoniseriez": "harmoniser",
    "harmoniserions": "harmoniser",
    "harmoniserons": "harmoniser",
    "harmoniseront": "harmoniser",
    "harmonises": "harmoniser",
    "harmonisez": "harmoniser",
    "harmonisiez": "harmoniser",
    "harmonisions": "harmoniser",
    "harmonisons": "harmoniser",
    "harmonisâmes": "harmoniser",
    "harmonisât": "harmoniser",
    "harmonisâtes": "harmoniser",
    "harmonisèrent": "harmoniser",
    "harmonisé": "harmoniser",
    "harmonisée": "harmoniser",
    "harmonisées": "harmoniser",
    "harmonisés": "harmoniser",
    "harmoniums": "harmonium",
    "harnacha": "harnacher",
    "harnachai": "harnacher",
    "harnachaient": "harnacher",
    "harnachais": "harnacher",
    "harnachait": "harnacher",
    "harnachant": "harnacher",
    "harnachas": "harnacher",
    "harnachasse": "harnacher",
    "harnachassent": "harnacher",
    "harnachasses": "harnacher",
    "harnachassiez": "harnacher",
    "harnachassions": "harnacher",
    "harnache": "harnacher",
    "harnachements": "harnachement",
    "harnachent": "harnacher",
    "harnachera": "harnacher",
    "harnacherai": "harnacher",
    "harnacheraient": "harnacher",
    "harnacherais": "harnacher",
    "harnacherait": "harnacher",
    "harnacheras": "harnacher",
    "harnacherez": "harnacher",
    "harnacheriez": "harnacher",
    "harnacherions": "harnacher",
    "harnacherons": "harnacher",
    "harnacheront": "harnacher",
    "harnaches": "harnacher",
    "harnachez": "harnacher",
    "harnachiez": "harnacher",
    "harnachions": "harnacher",
    "harnachons": "harnacher",
    "harnachâmes": "harnacher",
    "harnachât": "harnacher",
    "harnachâtes": "harnacher",
    "harnachèrent": "harnacher",
    "harnaché": "harnacher",
    "harnachée": "harnacher",
    "harnachées": "harnacher",
    "harnachés": "harnacher",
    "haros": "haro",
    "harpes": "harpe",
    "harpies": "harpie",
    "harpions": "harper",
    "harponna": "harponner",
    "harponnai": "harponner",
    "harponnaient": "harponner",
    "harponnais": "harponner",
    "harponnait": "harponner",
    "harponnant": "harponner",
    "harponnas": "harponner",
    "harponnasse": "harponner",
    "harponnassent": "harponner",
    "harponnasses": "harponner",
    "harponnassiez": "harponner",
    "harponnassions": "harponner",
    "harponne": "harponner",
    "harponnent": "harponner",
    "harponnera": "harponner",
    "harponnerai": "harponner",
    "harponneraient": "harponner",
    "harponnerais": "harponner",
    "harponnerait": "harponner",
    "harponneras": "harponner",
    "harponnerez": "harponner",
    "harponneriez": "harponner",
    "harponnerions": "harponner",
    "harponnerons": "harponner",
    "harponneront": "harponner",
    "harponnes": "harponner",
    "harponneurs": "harponneur",
    "harponnez": "harponner",
    "harponniez": "harponner",
    "harponnions": "harponner",
    "harponnons": "harponner",
    "harponnâmes": "harponner",
    "harponnât": "harponner",
    "harponnâtes": "harponner",
    "harponnèrent": "harponner",
    "harponné": "harponner",
    "harponnée": "harponner",
    "harponnées": "harponner",
    "harponnés": "harponner",
    "harpons": "harpon",
    "harpyes": "harpye",
    "harristes": "harriste",
    "harts": "hart",
    "haruspices": "haruspice",
    "hasarda": "hasarder",
    "hasardai": "hasarder",
    "hasardaient": "hasarder",
    "hasardais": "hasarder",
    "hasardait": "hasarder",
    "hasardant": "hasarder",
    "hasardas": "hasarder",
    "hasardasse": "hasarder",
    "hasardassent": "hasarder",
    "hasardasses": "hasarder",
    "hasardassiez": "hasarder",
    "hasardassions": "hasarder",
    "hasarde": "hasarder",
    "hasardent": "hasarder",
    "hasardera": "hasarder",
    "hasarderai": "hasarder",
    "hasarderaient": "hasarder",
    "hasarderais": "hasarder",
    "hasarderait": "hasarder",
    "hasarderas": "hasarder",
    "hasarderez": "hasarder",
    "hasarderiez": "hasarder",
    "hasarderions": "hasarder",
    "hasarderons": "hasarder",
    "hasarderont": "hasarder",
    "hasardes": "hasarder",
    "hasardeuse": "hasardeux",
    "hasardeuses": "hasardeux",
    "hasardez": "hasarder",
    "hasardiez": "hasarder",
    "hasardions": "hasarder",
    "hasardons": "hasarder",
    "hasards": "hasard",
    "hasardâmes": "hasarder",
    "hasardât": "hasarder",
    "hasardâtes": "hasarder",
    "hasardèrent": "hasarder",
    "hasardé": "hasarder",
    "hasardée": "hasarder",
    "hasardées": "hasarder",
    "hasardés": "hasarder",
    "haschischs": "haschisch",
    "haschs": "hasch",
    "hasekis": "haseki",
    "hases": "hase",
    "haubans": "hauban",
    "haubanée": "haubaner",
    "haubanés": "haubaner",
    "hauberts": "haubert",
    "haussa": "hausser",
    "haussai": "hausser",
    "haussaient": "hausser",
    "haussais": "hausser",
    "haussait": "hausser",
    "haussant": "hausser",
    "haussas": "hausser",
    "haussasse": "hausser",
    "haussassent": "hausser",
    "haussasses": "hausser",
    "haussassiez": "hausser",
    "haussassions": "hausser",
    "hausse": "hausser",
    "hausse-cols": "hausse-col",
    "haussements": "haussement",
    "haussent": "hausser",
    "haussera": "hausser",
    "hausserai": "hausser",
    "hausseraient": "hausser",
    "hausserais": "hausser",
    "hausserait": "hausser",
    "hausseras": "hausser",
    "hausserez": "hausser",
    "hausseriez": "hausser",
    "hausserions": "hausser",
    "hausserons": "hausser",
    "hausseront": "hausser",
    "hausses": "hausser",
    "haussez": "hausser",
    "haussiers": "haussier",
    "haussiez": "hausser",
    "haussions": "hausser",
    "haussière": "haussier",
    "haussières": "haussière",
    "haussons": "hausser",
    "haussâmes": "hausser",
    "haussât": "hausser",
    "haussâtes": "hausser",
    "haussèrent": "hausser",
    "haussé": "hausser",
    "haussée": "hausser",
    "haussées": "hausser",
    "haussés": "hausser",
    "haut-parleurs": "haut-parleur",
    "hautaine": "hautain",
    "hautaines": "hautain",
    "hautains": "hautain",
    "hautboïstes": "hautboïste",
    "haute": "haut",
    "hautes": "haut",
    "hautes-contre": "haute-contre",
    "hautes-fidélités": "haute-fidélité",
    "hauteurs": "hauteur",
    "hautins": "hautin",
    "hauts": "haut",
    "hauts-commissaires": "haut-commissaire",
    "hauts-de-chausses": "haut-de-chausses",
    "hauts-de-forme": "haut-de-forme",
    "hauts-fonds": "haut-fond",
    "hauts-fourneaux": "haut-fourneau",
    "hauts-reliefs": "haut-relief",
    "hauturiers": "hauturier",
    "hauturière": "hauturier",
    "hauturières": "hauturier",
    "hava": "haver",
    "havages": "havage",
    "havai": "haver",
    "havaient": "haver",
    "havais": "haver",
    "havait": "haver",
    "havanes": "havane",
    "havant": "haver",
    "havas": "haver",
    "havasse": "haver",
    "havassent": "haver",
    "havasses": "haver",
    "havassiez": "haver",
    "havassions": "haver",
    "have": "haver",
    "haveneaux": "haveneau",
    "havenets": "havenet",
    "havent": "haver",
    "havera": "haver",
    "haverai": "haver",
    "haveraient": "haver",
    "haverais": "haver",
    "haverait": "haver",
    "haveras": "haver",
    "haverez": "haver",
    "haveriez": "haver",
    "haverions": "haver",
    "haverons": "haver",
    "haveront": "haver",
    "haves": "haver",
    "havez": "haver",
    "havi": "havir",
    "havie": "havir",
    "havies": "havir",
    "haviez": "haver",
    "havions": "haver",
    "havira": "havir",
    "havirai": "havir",
    "haviraient": "havir",
    "havirais": "havir",
    "havirait": "havir",
    "haviras": "havir",
    "havirent": "havir",
    "havirez": "havir",
    "haviriez": "havir",
    "havirions": "havir",
    "havirons": "havir",
    "haviront": "havir",
    "havis": "havir",
    "havissaient": "havir",
    "havissais": "havir",
    "havissait": "havir",
    "havissant": "havir",
    "havisse": "havir",
    "havissent": "havir",
    "havisses": "havir",
    "havissez": "havir",
    "havissiez": "havir",
    "havissions": "havir",
    "havissons": "havir",
    "havit": "havir",
    "havons": "haver",
    "havres": "havre",
    "havresacs": "havresac",
    "havâmes": "haver",
    "havât": "haver",
    "havâtes": "haver",
    "havèrent": "haver",
    "havé": "haver",
    "havée": "haver",
    "havées": "haver",
    "havés": "haver",
    "havîmes": "havir",
    "havît": "havir",
    "havîtes": "havir",
    "hawaiienne": "hawaiien",
    "hawaiiennes": "hawaiien",
    "hawaïenne": "hawaïen",
    "hayons": "hayon",
    "haï": "haïr",
    "haïe": "haïr",
    "haïes": "haïr",
    "haïkaïs": "haïkaï",
    "haïks": "haïk",
    "haïkus": "haïku",
    "haïmes": "haïr",
    "haïra": "haïr",
    "haïrai": "haïr",
    "haïraient": "haïr",
    "haïrais": "haïr",
    "haïrait": "haïr",
    "haïras": "haïr",
    "haïrent": "haïr",
    "haïrez": "haïr",
    "haïriez": "haïr",
    "haïrions": "haïr",
    "haïrons": "haïr",
    "haïront": "haïr",
    "haïs": "haïr",
    "haïssables": "haïssable",
    "haïssaient": "haïr",
    "haïssais": "haïr",
    "haïssait": "haïr",
    "haïssant": "haïr",
    "haïsse": "haïr",
    "haïssent": "haïr",
    "haïsses": "haïr",
    "haïssez": "haïr",
    "haïssiez": "haïr",
    "haïssions": "haïr",
    "haïssons": "haïr",
    "haït": "haïr",
    "haïtes": "haïr",
    "haïtienne": "haïtien",
    "haïtiens": "haïtien",
    "heaumes": "heaume",
    "hebdomadaires": "hebdomadaire",
    "hebdos": "hebdo",
    "hectares": "hectare",
    "hectolitres": "hectolitre",
    "hectomètres": "hectomètre",
    "hellènes": "hellène",
    "hellébores": "hellébore",
    "helléniques": "hellénique",
    "hellénistes": "helléniste",
    "hellénistiques": "hellénistique",
    "hellénisé": "helléniser",
    "helminthes": "helminthe",
    "helvelles": "helvelle",
    "helvètes": "helvète",
    "helvétiques": "helvétique",
    "hendécasyllabes": "hendécasyllabe",
    "henni": "hennir",
    "hennins": "hennin",
    "hennira": "hennir",
    "hennirai": "hennir",
    "henniraient": "hennir",
    "hennirais": "hennir",
    "hennirait": "hennir",
    "henniras": "hennir",
    "hennirent": "hennir",
    "hennirez": "hennir",
    "henniriez": "hennir",
    "hennirions": "hennir",
    "hennirons": "hennir",
    "henniront": "hennir",
    "hennis": "hennir",
    "hennissaient": "hennir",
    "hennissais": "hennir",
    "hennissait": "hennir",
    "hennissant": "hennir",
    "hennissantes": "hennissant",
    "hennisse": "hennir",
    "hennissements": "hennissement",
    "hennissent": "hennir",
    "hennisses": "hennir",
    "hennissez": "hennir",
    "hennissiez": "hennir",
    "hennissions": "hennir",
    "hennissons": "hennir",
    "hennit": "hennir",
    "hennés": "henné",
    "hennîmes": "hennir",
    "hennît": "hennir",
    "hennîtes": "hennir",
    "herba": "herber",
    "herbagers": "herbager",
    "herbages": "herbage",
    "herbes": "herbe",
    "herbettes": "herbette",
    "herbeuse": "herbeux",
    "herbeuses": "herbeux",
    "herbicides": "herbicide",
    "herbiers": "herbier",
    "herbivores": "herbivore",
    "herborisa": "herboriser",
    "herborisai": "herboriser",
    "herborisaient": "herboriser",
    "herborisais": "herboriser",
    "herborisait": "herboriser",
    "herborisant": "herboriser",
    "herborisas": "herboriser",
    "herborisasse": "herboriser",
    "herborisassent": "herboriser",
    "herborisasses": "herboriser",
    "herborisassiez": "herboriser",
    "herborisassions": "herboriser",
    "herborise": "herboriser",
    "herborisent": "herboriser",
    "herborisera": "herboriser",
    "herboriserai": "herboriser",
    "herboriseraient": "herboriser",
    "herboriserais": "herboriser",
    "herboriserait": "herboriser",
    "herboriseras": "herboriser",
    "herboriserez": "herboriser",
    "herboriseriez": "herboriser",
    "herboriserions": "herboriser",
    "herboriserons": "herboriser",
    "herboriseront": "herboriser",
    "herborises": "herboriser",
    "herborisez": "herboriser",
    "herborisiez": "herboriser",
    "herborisions": "herboriser",
    "herborisons": "herboriser",
    "herboristeries": "herboristerie",
    "herboristes": "herboriste",
    "herborisâmes": "herboriser",
    "herborisât": "herboriser",
    "herborisâtes": "herboriser",
    "herborisèrent": "herboriser",
    "herborisé": "herboriser",
    "herbue": "herbu",
    "herbues": "herbu",
    "herbus": "herbu",
    "hercha": "hercher",
    "herchai": "hercher",
    "herchaient": "hercher",
    "herchais": "hercher",
    "herchait": "hercher",
    "herchant": "hercher",
    "herchas": "hercher",
    "herchasse": "hercher",
    "herchassent": "hercher",
    "herchasses": "hercher",
    "herchassiez": "hercher",
    "herchassions": "hercher",
    "herche": "hercher",
    "herchent": "hercher",
    "herchera": "hercher",
    "hercherai": "hercher",
    "hercheraient": "hercher",
    "hercherais": "hercher",
    "hercherait": "hercher",
    "hercheras": "hercher",
    "hercherez": "hercher",
    "hercheriez": "hercher",
    "hercherions": "hercher",
    "hercherons": "hercher",
    "hercheront": "hercher",
    "herches": "hercher",
    "herchez": "hercher",
    "herchiez": "hercher",
    "herchions": "hercher",
    "herchons": "hercher",
    "herchâmes": "hercher",
    "herchât": "hercher",
    "herchâtes": "hercher",
    "herchèrent": "hercher",
    "herché": "hercher",
    "hercules": "hercule",
    "herculéenne": "herculéen",
    "herculéennes": "herculéen",
    "herculéens": "herculéen",
    "hercynienne": "hercynien",
    "hercyniennes": "hercynien",
    "hercyniens": "hercynien",
    "herd-books": "herd-book",
    "hermaphrodites": "hermaphrodite",
    "hermines": "hermine",
    "herminettes": "herminette",
    "herméneutiques": "herméneutique",
    "hermétiques": "hermétique",
    "hermétismes": "hermétisme",
    "hermétistes": "hermétiste",
    "herniaires": "herniaire",
    "hernies": "hernie",
    "hernusienne": "hernusien",
    "hernusiennes": "hernusien",
    "hernusiens": "hernusien",
    "hersa": "herser",
    "hersai": "herser",
    "hersaient": "herser",
    "hersais": "herser",
    "hersait": "herser",
    "hersant": "herser",
    "hersas": "herser",
    "hersasse": "herser",
    "hersassent": "herser",
    "hersasses": "herser",
    "hersassiez": "herser",
    "hersassions": "herser",
    "herscha": "herscher",
    "herschai": "herscher",
    "herschaient": "herscher",
    "herschais": "herscher",
    "herschait": "herscher",
    "herschant": "herscher",
    "herschas": "herscher",
    "herschasse": "herscher",
    "herschassent": "herscher",
    "herschasses": "herscher",
    "herschassiez": "herscher",
    "herschassions": "herscher",
    "hersche": "herscher",
    "herschent": "herscher",
    "herschera": "herscher",
    "herscherai": "herscher",
    "herscheraient": "herscher",
    "herscherais": "herscher",
    "herscherait": "herscher",
    "herscheras": "herscher",
    "herscherez": "herscher",
    "herscheriez": "herscher",
    "herscherions": "herscher",
    "herscherons": "herscher",
    "herscheront": "herscher",
    "hersches": "herscher",
    "herschez": "herscher",
    "herschiez": "herscher",
    "herschions": "herscher",
    "herschons": "herscher",
    "herschâmes": "herscher",
    "herschât": "herscher",
    "herschâtes": "herscher",
    "herschèrent": "herscher",
    "hersché": "herscher",
    "herse": "herser",
    "hersent": "herser",
    "hersera": "herser",
    "herserai": "herser",
    "herseraient": "herser",
    "herserais": "herser",
    "herserait": "herser",
    "herseras": "herser",
    "herserez": "herser",
    "herseriez": "herser",
    "herserions": "herser",
    "herserons": "herser",
    "herseront": "herser",
    "herses": "herser",
    "hersez": "herser",
    "hersiez": "herser",
    "hersions": "herser",
    "hersons": "herser",
    "hersâmes": "herser",
    "hersât": "herser",
    "hersâtes": "herser",
    "hersèrent": "herser",
    "hersé": "herser",
    "hersée": "herser",
    "hersées": "herser",
    "hersés": "herser",
    "hertzienne": "hertzien",
    "hertziennes": "hertzien",
    "hertziens": "hertzien",
    "hessoise": "hessois",
    "hetmans": "hetman",
    "heures": "heure",
    "heureuse": "heureux",
    "heureuses": "heureux",
    "heuristiques": "heuristique",
    "heurs": "heur",
    "heurta": "heurter",
    "heurtai": "heurter",
    "heurtaient": "heurter",
    "heurtais": "heurter",
    "heurtait": "heurter",
    "heurtant": "heurter",
    "heurtas": "heurter",
    "heurtasse": "heurter",
    "heurtassent": "heurter",
    "heurtasses": "heurter",
    "heurtassiez": "heurter",
    "heurtassions": "heurter",
    "heurte": "heurter",
    "heurtent": "heurter",
    "heurtera": "heurter",
    "heurterai": "heurter",
    "heurteraient": "heurter",
    "heurterais": "heurter",
    "heurterait": "heurter",
    "heurteras": "heurter",
    "heurterez": "heurter",
    "heurteriez": "heurter",
    "heurterions": "heurter",
    "heurterons": "heurter",
    "heurteront": "heurter",
    "heurtes": "heurter",
    "heurtez": "heurter",
    "heurtiez": "heurter",
    "heurtions": "heurter",
    "heurtoirs": "heurtoir",
    "heurtons": "heurter",
    "heurts": "heurt",
    "heurtâmes": "heurter",
    "heurtât": "heurter",
    "heurtâtes": "heurter",
    "heurtèrent": "heurter",
    "heurté": "heurter",
    "heurtée": "heurter",
    "heurtées": "heurter",
    "heurtés": "heurter",
    "hexafluorures": "hexafluorure",
    "hexagonale": "hexagonal",
    "hexagonales": "hexagonal",
    "hexagonaux": "hexagonal",
    "hexagones": "hexagone",
    "hexamètres": "hexamètre",
    "hexaèdres": "hexaèdre",
    "hiatale": "hiatal",
    "hiberna": "hiberner",
    "hibernai": "hiberner",
    "hibernaient": "hiberner",
    "hibernais": "hiberner",
    "hibernait": "hiberner",
    "hibernale": "hibernal",
    "hibernales": "hibernal",
    "hibernant": "hiberner",
    "hibernas": "hiberner",
    "hibernasse": "hiberner",
    "hibernassent": "hiberner",
    "hibernasses": "hiberner",
    "hibernassiez": "hiberner",
    "hibernassions": "hiberner",
    "hibernations": "hibernation",
    "hibernaux": "hibernal",
    "hiberne": "hiberner",
    "hibernent": "hiberner",
    "hibernera": "hiberner",
    "hibernerai": "hiberner",
    "hiberneraient": "hiberner",
    "hibernerais": "hiberner",
    "hibernerait": "hiberner",
    "hiberneras": "hiberner",
    "hibernerez": "hiberner",
    "hiberneriez": "hiberner",
    "hibernerions": "hiberner",
    "hibernerons": "hiberner",
    "hiberneront": "hiberner",
    "hibernes": "hiberner",
    "hibernez": "hiberner",
    "hiberniez": "hiberner",
    "hibernions": "hiberner",
    "hibernons": "hiberner",
    "hibernâmes": "hiberner",
    "hibernât": "hiberner",
    "hibernâtes": "hiberner",
    "hibernèrent": "hiberner",
    "hiberné": "hiberner",
    "hiboux": "hibou",
    "hickorys": "hickory",
    "hidalgos": "hidalgo",
    "hideurs": "hideur",
    "hideuse": "hideux",
    "hideuses": "hideux",
    "high tech": "high-tech",
    "highlanders": "highlander",
    "hilarante": "hilarant",
    "hilarantes": "hilarant",
    "hilarants": "hilarant",
    "hilares": "hilare",
    "hilarités": "hilarité",
    "hiles": "hile",
    "hiloires": "hiloire",
    "hilotes": "hilote",
    "himalayenne": "himalayen",
    "himalayens": "himalayen",
    "himalayistes": "himalayiste",
    "hindoue": "hindou",
    "hindoues": "hindou",
    "hindouismes": "hindouisme",
    "hindouistes": "hindouiste",
    "hindous": "hindou",
    "hinterlands": "hinterland",
    "hippies": "hippie",
    "hippiques": "hippique",
    "hippocampes": "hippocampe",
    "hippodromes": "hippodrome",
    "hippogriffes": "hippogriffe",
    "hippologies": "hippologie",
    "hippomobiles": "hippomobile",
    "hippophagiques": "hippophagique",
    "hippopotames": "hippopotame",
    "hircine": "hircin",
    "hircines": "hircin",
    "hircins": "hircin",
    "hirondeaux": "hirondeau",
    "hirondelle": "hirondeau",
    "hirondelles": "hirondelle",
    "hirsutes": "hirsute",
    "hispaniques": "hispanique",
    "hispanisante": "hispanisant",
    "hispanisants": "hispanisant",
    "hispanités": "hispanité",
    "hispano-américaine": "hispano-américain",
    "hissa": "hisser",
    "hissai": "hisser",
    "hissaient": "hisser",
    "hissais": "hisser",
    "hissait": "hisser",
    "hissant": "hisser",
    "hissas": "hisser",
    "hissasse": "hisser",
    "hissassent": "hisser",
    "hissasses": "hisser",
    "hissassiez": "hisser",
    "hissassions": "hisser",
    "hisse": "hisser",
    "hissent": "hisser",
    "hissera": "hisser",
    "hisserai": "hisser",
    "hisseraient": "hisser",
    "hisserais": "hisser",
    "hisserait": "hisser",
    "hisseras": "hisser",
    "hisserez": "hisser",
    "hisseriez": "hisser",
    "hisserions": "hisser",
    "hisserons": "hisser",
    "hisseront": "hisser",
    "hisses": "hisser",
    "hissez": "hisser",
    "hissiez": "hisser",
    "hissions": "hisser",
    "hissons": "hisser",
    "hissâmes": "hisser",
    "hissât": "hisser",
    "hissâtes": "hisser",
    "hissèrent": "hisser",
    "hissé": "hisser",
    "hissée": "hisser",
    "hissées": "hisser",
    "hissés": "hisser",
    "histocompatibles": "histocompatible",
    "histoires": "histoire",
    "histologies": "histologie",
    "historia": "historier",
    "historico-culturelle": "historico-culturel",
    "historienne": "historien",
    "historiennes": "historien",
    "historiens": "historien",
    "historiettes": "historiette",
    "historiographies": "historiographie",
    "historiographiques": "historiographique",
    "historiques": "historique",
    "historiée": "historier",
    "historiés": "historier",
    "histrions": "histrion",
    "hit-parades": "hit-parade",
    "hitchcockienne": "hitchcockien",
    "hitchcockiennes": "hitchcockien",
    "hitchcockiens": "hitchcockien",
    "hitlérienne": "hitlérien",
    "hitlériennes": "hitlérien",
    "hitlériens": "hitlérien",
    "hitlérismes": "hitlérisme",
    "hits": "hit",
    "hittites": "hittite",
    "hiverna": "hiverner",
    "hivernai": "hiverner",
    "hivernaient": "hiverner",
    "hivernais": "hiverner",
    "hivernait": "hiverner",
    "hivernale": "hivernal",
    "hivernales": "hivernal",
    "hivernant": "hiverner",
    "hivernante": "hivernant",
    "hivernantes": "hivernant",
    "hivernants": "hivernant",
    "hivernas": "hiverner",
    "hivernasse": "hiverner",
    "hivernassent": "hiverner",
    "hivernasses": "hiverner",
    "hivernassiez": "hiverner",
    "hivernassions": "hiverner",
    "hivernaux": "hivernal",
    "hiverne": "hiverner",
    "hivernent": "hiverner",
    "hivernera": "hiverner",
    "hivernerai": "hiverner",
    "hiverneraient": "hiverner",
    "hivernerais": "hiverner",
    "hivernerait": "hiverner",
    "hiverneras": "hiverner",
    "hivernerez": "hiverner",
    "hiverneriez": "hiverner",
    "hivernerions": "hiverner",
    "hivernerons": "hiverner",
    "hiverneront": "hiverner",
    "hivernes": "hiverner",
    "hivernez": "hiverner",
    "hiverniez": "hiverner",
    "hivernions": "hiverner",
    "hivernons": "hiverner",
    "hivernâmes": "hiverner",
    "hivernât": "hiverner",
    "hivernâtes": "hiverner",
    "hivernèrent": "hiverner",
    "hiverné": "hiverner",
    "hivers": "hiver",
    "hièbles": "hièble",
    "hiémale": "hiémal",
    "hiémales": "hiémal",
    "hiémaux": "hiémal",
    "hiérarchies": "hiérarchie",
    "hiérarchiques": "hiérarchique",
    "hiérarchisait": "hiérarchiser",
    "hiérarchise": "hiérarchiser",
    "hiérarchisée": "hiérarchisé",
    "hiérarchisés": "hiérarchiser",
    "hiératiques": "hiératique",
    "hiéroglyphes": "hiéroglyphe",
    "hiéroglyphiques": "hiéroglyphique",
    "hiéronymites": "hiéronymite",
    "hobbies": "hobby",
    "hobereaux": "hobereau",
    "hoccos": "hocco",
    "hocha": "hocher",
    "hochai": "hocher",
    "hochaient": "hocher",
    "hochais": "hocher",
    "hochait": "hocher",
    "hochant": "hocher",
    "hochas": "hocher",
    "hochasse": "hocher",
    "hochassent": "hocher",
    "hochasses": "hocher",
    "hochassiez": "hocher",
    "hochassions": "hocher",
    "hoche": "hocher",
    "hochements": "hochement",
    "hochent": "hocher",
    "hochepots": "hochepot",
    "hochequeues": "hochequeue",
    "hochera": "hocher",
    "hocherai": "hocher",
    "hocheraient": "hocher",
    "hocherais": "hocher",
    "hocherait": "hocher",
    "hocheras": "hocher",
    "hocherez": "hocher",
    "hocheriez": "hocher",
    "hocherions": "hocher",
    "hocherons": "hocher",
    "hocheront": "hocher",
    "hoches": "hocher",
    "hochets": "hochet",
    "hocheurs": "hocheur",
    "hochez": "hocher",
    "hochiez": "hocher",
    "hochions": "hocher",
    "hochons": "hocher",
    "hochâmes": "hocher",
    "hochât": "hocher",
    "hochâtes": "hocher",
    "hochèrent": "hocher",
    "hoché": "hocher",
    "hochée": "hocher",
    "hochées": "hocher",
    "hochés": "hocher",
    "hockeyeurs": "hockeyeur",
    "hockeyeuse": "hockeyeur",
    "hockeyeuses": "hockeyeur",
    "hockeys": "hockey",
    "hoiries": "hoirie",
    "hoirs": "hoir",
    "hold up": "hold-up",
    "holdings": "holding",
    "holistiques": "holistique",
    "hollandaise": "hollandais",
    "hollandaises": "hollandais",
    "hollywoodienne": "hollywoodien",
    "hollywoodiennes": "hollywoodien",
    "hollywoodiens": "hollywoodien",
    "holmiums": "holmium",
    "holocaustes": "holocauste",
    "hologrammes": "hologramme",
    "holographes": "holographe",
    "holographiques": "holographique",
    "holothuries": "holothurie",
    "holoèdres": "holoèdre",
    "homardiers": "homardier",
    "homards": "homard",
    "home-trainers": "home-trainer",
    "homes": "home",
    "homicides": "homicide",
    "hominiens": "hominien",
    "hommages": "hommage",
    "hommasses": "hommasse",
    "hommes": "homme",
    "hommes-grenouilles": "homme-grenouille",
    "hommes-orchestres": "homme-orchestre",
    "hommes-sandwichs": "homme-sandwich",
    "homogènes": "homogène",
    "homogénéisations": "homogénéisation",
    "homogénéisé": "homogénéiser",
    "homogénéisée": "homogénéisé",
    "homogénéités": "homogénéité",
    "homologations": "homologation",
    "homologua": "homologuer",
    "homologuai": "homologuer",
    "homologuaient": "homologuer",
    "homologuais": "homologuer",
    "homologuait": "homologuer",
    "homologuant": "homologuer",
    "homologuas": "homologuer",
    "homologuasse": "homologuer",
    "homologuassent": "homologuer",
    "homologuasses": "homologuer",
    "homologuassiez": "homologuer",
    "homologuassions": "homologuer",
    "homologue": "homologuer",
    "homologuent": "homologuer",
    "homologuera": "homologuer",
    "homologuerai": "homologuer",
    "homologueraient": "homologuer",
    "homologuerais": "homologuer",
    "homologuerait": "homologuer",
    "homologueras": "homologuer",
    "homologuerez": "homologuer",
    "homologueriez": "homologuer",
    "homologuerions": "homologuer",
    "homologuerons": "homologuer",
    "homologueront": "homologuer",
    "homologues": "homologuer",
    "homologuez": "homologuer",
    "homologuiez": "homologuer",
    "homologuions": "homologuer",
    "homologuons": "homologuer",
    "homologuâmes": "homologuer",
    "homologuât": "homologuer",
    "homologuâtes": "homologuer",
    "homologuèrent": "homologuer",
    "homologué": "homologuer",
    "homologuée": "homologuer",
    "homologuées": "homologuer",
    "homologués": "homologuer",
    "homoncules": "homoncule",
    "homonymes": "homonyme",
    "homonymies": "homonymie",
    "homophobes": "homophobe",
    "homophones": "homophone",
    "homorozygotes": "homorozygote",
    "homos": "homo",
    "homosexualités": "homosexualité",
    "homosexuelle": "homosexuel",
    "homosexuelles": "homosexuelle",
    "homosexuels": "homosexuel",
    "homuncules": "homuncule",
    "homélies": "homélie",
    "homéopathes": "homéopathe",
    "homéopathies": "homéopathie",
    "homéopathiques": "homéopathique",
    "homériques": "homérique",
    "hondurienne": "hondurien",
    "honduriens": "hondurien",
    "hongres": "hongre",
    "hongroie": "hongroyer",
    "hongroient": "hongroyer",
    "hongroiera": "hongroyer",
    "hongroierai": "hongroyer",
    "hongroieraient": "hongroyer",
    "hongroierais": "hongroyer",
    "hongroierait": "hongroyer",
    "hongroieras": "hongroyer",
    "hongroierez": "hongroyer",
    "hongroieriez": "hongroyer",
    "hongroierions": "hongroyer",
    "hongroierons": "hongroyer",
    "hongroieront": "hongroyer",
    "hongroies": "hongroyer",
    "hongroise": "hongrois",
    "hongroises": "hongroise",
    "hongroya": "hongroyer",
    "hongroyai": "hongroyer",
    "hongroyaient": "hongroyer",
    "hongroyais": "hongroyer",
    "hongroyait": "hongroyer",
    "hongroyant": "hongroyer",
    "hongroyas": "hongroyer",
    "hongroyasse": "hongroyer",
    "hongroyassent": "hongroyer",
    "hongroyasses": "hongroyer",
    "hongroyassiez": "hongroyer",
    "hongroyassions": "hongroyer",
    "hongroyez": "hongroyer",
    "hongroyiez": "hongroyer",
    "hongroyions": "hongroyer",
    "hongroyons": "hongroyer",
    "hongroyâmes": "hongroyer",
    "hongroyât": "hongroyer",
    "hongroyâtes": "hongroyer",
    "hongroyèrent": "hongroyer",
    "hongroyé": "hongroyer",
    "hongroyée": "hongroyer",
    "hongroyées": "hongroyer",
    "hongroyés": "hongroyer",
    "honneurs": "honneur",
    "honni": "honnir",
    "honnie": "honnir",
    "honnies": "honnir",
    "honnira": "honnir",
    "honnirai": "honnir",
    "honniraient": "honnir",
    "honnirais": "honnir",
    "honnirait": "honnir",
    "honniras": "honnir",
    "honnirent": "honnir",
    "honnirez": "honnir",
    "honniriez": "honnir",
    "honnirions": "honnir",
    "honnirons": "honnir",
    "honniront": "honnir",
    "honnis": "honnir",
    "honnissaient": "honnir",
    "honnissais": "honnir",
    "honnissait": "honnir",
    "honnissant": "honnir",
    "honnisse": "honnir",
    "honnissent": "honnir",
    "honnisses": "honnir",
    "honnissez": "honnir",
    "honnissiez": "honnir",
    "honnissions": "honnir",
    "honnissons": "honnir",
    "honnit": "honnir",
    "honnêtes": "honnête",
    "honnêtetés": "honnêteté",
    "honnîmes": "honnir",
    "honnît": "honnir",
    "honnîtes": "honnir",
    "honora": "honorer",
    "honorabilités": "honorabilité",
    "honorables": "honorable",
    "honorai": "honorer",
    "honoraient": "honorer",
    "honoraires": "honoraire",
    "honorais": "honorer",
    "honorait": "honorer",
    "honorant": "honorer",
    "honoras": "honorer",
    "honorasse": "honorer",
    "honorassent": "honorer",
    "honorasses": "honorer",
    "honorassiez": "honorer",
    "honorassions": "honorer",
    "honore": "honorer",
    "honorent": "honorer",
    "honorera": "honorer",
    "honorerai": "honorer",
    "honoreraient": "honorer",
    "honorerais": "honorer",
    "honorerait": "honorer",
    "honoreras": "honorer",
    "honorerez": "honorer",
    "honoreriez": "honorer",
    "honorerions": "honorer",
    "honorerons": "honorer",
    "honoreront": "honorer",
    "honores": "honorer",
    "honorez": "honorer",
    "honoriez": "honorer",
    "honorifiques": "honorifique",
    "honorions": "honorer",
    "honorons": "honorer",
    "honorâmes": "honorer",
    "honorât": "honorer",
    "honorâtes": "honorer",
    "honorèrent": "honorer",
    "honoré": "honorer",
    "honorée": "honorer",
    "honorées": "honorer",
    "honorés": "honorer",
    "hontes": "honte",
    "honteuse": "honteux",
    "honteuses": "honteux",
    "hooliganismes": "hooliganisme",
    "hooligans": "hooligan",
    "hopis": "hopi",
    "hoplites": "hoplite",
    "hoqueta": "hoqueter",
    "hoquetai": "hoqueter",
    "hoquetaient": "hoqueter",
    "hoquetais": "hoqueter",
    "hoquetait": "hoqueter",
    "hoquetant": "hoqueter",
    "hoquetas": "hoqueter",
    "hoquetasse": "hoqueter",
    "hoquetassent": "hoqueter",
    "hoquetasses": "hoqueter",
    "hoquetassiez": "hoqueter",
    "hoquetassions": "hoqueter",
    "hoquetez": "hoqueter",
    "hoquetiez": "hoqueter",
    "hoquetions": "hoqueter",
    "hoquetons": "hoqueter",
    "hoquets": "hoquet",
    "hoquette": "hoqueter",
    "hoquettent": "hoqueter",
    "hoquettera": "hoqueter",
    "hoquetterai": "hoqueter",
    "hoquetteraient": "hoqueter",
    "hoquetterais": "hoqueter",
    "hoquetterait": "hoqueter",
    "hoquetteras": "hoqueter",
    "hoquetterez": "hoqueter",
    "hoquetteriez": "hoqueter",
    "hoquetterions": "hoqueter",
    "hoquetterons": "hoqueter",
    "hoquetteront": "hoqueter",
    "hoquettes": "hoqueter",
    "hoquetâmes": "hoqueter",
    "hoquetât": "hoqueter",
    "hoquetâtes": "hoqueter",
    "hoquetèrent": "hoqueter",
    "hoqueté": "hoqueter",
    "hoquetée": "hoqueter",
    "hoquetées": "hoqueter",
    "hoquetés": "hoqueter",
    "horaires": "horaire",
    "hordes": "horde",
    "horions": "horion",
    "horizons": "horizon",
    "horizontale": "horizontal",
    "horizontales": "horizontale",
    "horizontaux": "horizontal",
    "horlogeries": "horlogerie",
    "horlogers": "horloger",
    "horloges": "horloge",
    "horlogère": "horloger",
    "horlogères": "horloger",
    "hormonale": "hormonal",
    "hormonales": "hormonal",
    "hormonaux": "hormonal",
    "hormones": "hormone",
    "hormonés": "hormoner",
    "horodateurs": "horodateur",
    "horoscopes": "horoscope",
    "horreurs": "horreur",
    "horribles": "horrible",
    "horrifia": "horrifier",
    "horrifiai": "horrifier",
    "horrifiaient": "horrifier",
    "horrifiais": "horrifier",
    "horrifiait": "horrifier",
    "horrifiant": "horrifier",
    "horrifiante": "horrifiant",
    "horrifiants": "horrifiant",
    "horrifias": "horrifier",
    "horrifiasse": "horrifier",
    "horrifiassent": "horrifier",
    "horrifiasses": "horrifier",
    "horrifiassiez": "horrifier",
    "horrifiassions": "horrifier",
    "horrifie": "horrifier",
    "horrifient": "horrifier",
    "horrifiera": "horrifier",
    "horrifierai": "horrifier",
    "horrifieraient": "horrifier",
    "horrifierais": "horrifier",
    "horrifierait": "horrifier",
    "horrifieras": "horrifier",
    "horrifierez": "horrifier",
    "horrifieriez": "horrifier",
    "horrifierions": "horrifier",
    "horrifierons": "horrifier",
    "horrifieront": "horrifier",
    "horrifies": "horrifier",
    "horrifiez": "horrifier",
    "horrifiiez": "horrifier",
    "horrifiions": "horrifier",
    "horrifions": "horrifier",
    "horrifiques": "horrifique",
    "horrifiâmes": "horrifier",
    "horrifiât": "horrifier",
    "horrifiâtes": "horrifier",
    "horrifièrent": "horrifier",
    "horrifié": "horrifier",
    "horrifiée": "horrifier",
    "horrifiées": "horrifier",
    "horrifiés": "horrifier",
    "horripila": "horripiler",
    "horripilai": "horripiler",
    "horripilaient": "horripiler",
    "horripilais": "horripiler",
    "horripilait": "horripiler",
    "horripilant": "horripiler",
    "horripilante": "horripilant",
    "horripilantes": "horripilant",
    "horripilants": "horripilant",
    "horripilas": "horripiler",
    "horripilasse": "horripiler",
    "horripilassent": "horripiler",
    "horripilasses": "horripiler",
    "horripilassiez": "horripiler",
    "horripilassions": "horripiler",
    "horripilations": "horripilation",
    "horripile": "horripiler",
    "horripilent": "horripiler",
    "horripilera": "horripiler",
    "horripilerai": "horripiler",
    "horripileraient": "horripiler",
    "horripilerais": "horripiler",
    "horripilerait": "horripiler",
    "horripileras": "horripiler",
    "horripilerez": "horripiler",
    "horripileriez": "horripiler",
    "horripilerions": "horripiler",
    "horripilerons": "horripiler",
    "horripileront": "horripiler",
    "horripiles": "horripiler",
    "horripilez": "horripiler",
    "horripiliez": "horripiler",
    "horripilions": "horripiler",
    "horripilons": "horripiler",
    "horripilâmes": "horripiler",
    "horripilât": "horripiler",
    "horripilâtes": "horripiler",
    "horripilèrent": "horripiler",
    "horripilé": "horripiler",
    "horripilée": "horripiler",
    "horripilées": "horripiler",
    "horripilés": "horripiler",
    "horse-guards": "horse-guard",
    "hortensias": "hortensia",
    "horticoles": "horticole",
    "horticulteurs": "horticulteur",
    "horticultures": "horticulture",
    "hortillonnages": "hortillonnage",
    "hosannas": "hosanna",
    "hospices": "hospice",
    "hospitaliers": "hospitalier",
    "hospitalisa": "hospitaliser",
    "hospitalisai": "hospitaliser",
    "hospitalisaient": "hospitaliser",
    "hospitalisais": "hospitaliser",
    "hospitalisait": "hospitaliser",
    "hospitalisant": "hospitaliser",
    "hospitalisas": "hospitaliser",
    "hospitalisasse": "hospitaliser",
    "hospitalisassent": "hospitaliser",
    "hospitalisasses": "hospitaliser",
    "hospitalisassiez": "hospitaliser",
    "hospitalisassions": "hospitaliser",
    "hospitalisations": "hospitalisation",
    "hospitalise": "hospitaliser",
    "hospitalisent": "hospitaliser",
    "hospitalisera": "hospitaliser",
    "hospitaliserai": "hospitaliser",
    "hospitaliseraient": "hospitaliser",
    "hospitaliserais": "hospitaliser",
    "hospitaliserait": "hospitaliser",
    "hospitaliseras": "hospitaliser",
    "hospitaliserez": "hospitaliser",
    "hospitaliseriez": "hospitaliser",
    "hospitaliserions": "hospitaliser",
    "hospitaliserons": "hospitaliser",
    "hospitaliseront": "hospitaliser",
    "hospitalises": "hospitaliser",
    "hospitalisez": "hospitaliser",
    "hospitalisiez": "hospitaliser",
    "hospitalisions": "hospitaliser",
    "hospitalisons": "hospitaliser",
    "hospitalisâmes": "hospitaliser",
    "hospitalisât": "hospitaliser",
    "hospitalisâtes": "hospitaliser",
    "hospitalisèrent": "hospitaliser",
    "hospitalisé": "hospitaliser",
    "hospitalisée": "hospitaliser",
    "hospitalisées": "hospitaliser",
    "hospitalisés": "hospitaliser",
    "hospitalités": "hospitalité",
    "hospitalière": "hospitalier",
    "hospitalières": "hospitalier",
    "hospodars": "hospodar",
    "hostelleries": "hostellerie",
    "hosties": "hostie",
    "hostiles": "hostile",
    "hostilités": "hostilité",
    "hostos": "hosto",
    "hot dogs": "hot dog",
    "hot-dogs": "hot-dog",
    "hottes": "hotte",
    "hotus": "hotu",
    "houa": "houer",
    "houblonna": "houblonner",
    "houblonnai": "houblonner",
    "houblonnaient": "houblonner",
    "houblonnais": "houblonner",
    "houblonnait": "houblonner",
    "houblonnant": "houblonner",
    "houblonnas": "houblonner",
    "houblonnasse": "houblonner",
    "houblonnassent": "houblonner",
    "houblonnasses": "houblonner",
    "houblonnassiez": "houblonner",
    "houblonnassions": "houblonner",
    "houblonne": "houblonner",
    "houblonnent": "houblonner",
    "houblonnera": "houblonner",
    "houblonnerai": "houblonner",
    "houblonneraient": "houblonner",
    "houblonnerais": "houblonner",
    "houblonnerait": "houblonner",
    "houblonneras": "houblonner",
    "houblonnerez": "houblonner",
    "houblonneriez": "houblonner",
    "houblonnerions": "houblonner",
    "houblonnerons": "houblonner",
    "houblonneront": "houblonner",
    "houblonnes": "houblonner",
    "houblonnez": "houblonner",
    "houblonniez": "houblonner",
    "houblonnions": "houblonner",
    "houblonnons": "houblonner",
    "houblonnâmes": "houblonner",
    "houblonnât": "houblonner",
    "houblonnâtes": "houblonner",
    "houblonnèrent": "houblonner",
    "houblonné": "houblonner",
    "houblonnée": "houblonner",
    "houblonnées": "houblonner",
    "houblonnés": "houblonner",
    "houblons": "houblon",
    "houes": "houe",
    "houillers": "houiller",
    "houilles": "houille",
    "houillère": "houiller",
    "houillères": "houillère",
    "houles": "houle",
    "houlettes": "houlette",
    "houleuse": "houleux",
    "houleuses": "houleux",
    "houppelandes": "houppelande",
    "houppes": "houppe",
    "houppettes": "houppette",
    "hourds": "hourd",
    "houris": "houri",
    "hourrahs": "hourrah",
    "hourras": "hourra",
    "hourvaris": "hourvari",
    "housards": "housard",
    "house-boats": "house-boat",
    "houseaux": "houseau",
    "houspilla": "houspiller",
    "houspillai": "houspiller",
    "houspillaient": "houspiller",
    "houspillais": "houspiller",
    "houspillait": "houspiller",
    "houspillant": "houspiller",
    "houspillas": "houspiller",
    "houspillasse": "houspiller",
    "houspillassent": "houspiller",
    "houspillasses": "houspiller",
    "houspillassiez": "houspiller",
    "houspillassions": "houspiller",
    "houspille": "houspiller",
    "houspillent": "houspiller",
    "houspillera": "houspiller",
    "houspillerai": "houspiller",
    "houspilleraient": "houspiller",
    "houspillerais": "houspiller",
    "houspillerait": "houspiller",
    "houspilleras": "houspiller",
    "houspillerez": "houspiller",
    "houspilleriez": "houspiller",
    "houspillerions": "houspiller",
    "houspillerons": "houspiller",
    "houspilleront": "houspiller",
    "houspilles": "houspiller",
    "houspillez": "houspiller",
    "houspilliez": "houspiller",
    "houspillions": "houspiller",
    "houspillons": "houspiller",
    "houspillâmes": "houspiller",
    "houspillât": "houspiller",
    "houspillâtes": "houspiller",
    "houspillèrent": "houspiller",
    "houspillé": "houspiller",
    "houspillée": "houspiller",
    "houspillées": "houspiller",
    "houspillés": "houspiller",
    "houssaies": "houssaie",
    "housses": "housse",
    "houssés": "housser",
    "hovercrafts": "hovercraft",
    "hoyaux": "hoyau",
    "hua": "huer",
    "huai": "huer",
    "huaient": "huer",
    "huais": "huer",
    "huait": "huer",
    "huant": "huer",
    "huards": "huard",
    "huas": "huer",
    "huasse": "huer",
    "huassent": "huer",
    "huasses": "huer",
    "huassiez": "huer",
    "huassions": "huer",
    "hublots": "hublot",
    "hucha": "hucher",
    "huchai": "hucher",
    "huchaient": "hucher",
    "huchais": "hucher",
    "huchait": "hucher",
    "huchant": "hucher",
    "huchas": "hucher",
    "huchasse": "hucher",
    "huchassent": "hucher",
    "huchasses": "hucher",
    "huchassiez": "hucher",
    "huchassions": "hucher",
    "huche": "hucher",
    "huchent": "hucher",
    "huchera": "hucher",
    "hucherai": "hucher",
    "hucheraient": "hucher",
    "hucherais": "hucher",
    "hucherait": "hucher",
    "hucheras": "hucher",
    "hucherez": "hucher",
    "hucheriez": "hucher",
    "hucherions": "hucher",
    "hucherons": "hucher",
    "hucheront": "hucher",
    "huches": "hucher",
    "huchez": "hucher",
    "huchiez": "hucher",
    "huchions": "hucher",
    "huchons": "hucher",
    "huchâmes": "hucher",
    "huchât": "hucher",
    "huchâtes": "hucher",
    "huchèrent": "hucher",
    "huché": "hucher",
    "huchée": "hucher",
    "huchées": "hucher",
    "huchés": "hucher",
    "hue": "huer",
    "huent": "huer",
    "huera": "huer",
    "huerai": "huer",
    "hueraient": "huer",
    "huerais": "huer",
    "huerait": "huer",
    "hueras": "huer",
    "huerez": "huer",
    "hueriez": "huer",
    "huerions": "huer",
    "huerons": "huer",
    "hueront": "huer",
    "hues": "huer",
    "huez": "huer",
    "hugoliens": "hugolien",
    "huguenote": "huguenot",
    "huguenotes": "huguenot",
    "huguenots": "huguenot",
    "huiez": "huer",
    "huilai": "huiler",
    "huilait": "huiler",
    "huile": "huiler",
    "huilent": "huiler",
    "huilerai": "huiler",
    "huileries": "huilerie",
    "huiles": "huile",
    "huileuse": "huileux",
    "huileuses": "huileux",
    "huilez": "huiler",
    "huiliers": "huilier",
    "huilière": "huilier",
    "huilières": "huilier",
    "huilé": "huiler",
    "huilée": "huiler",
    "huilées": "huiler",
    "huilés": "huiler",
    "huions": "huer",
    "huipils": "huipil",
    "huisseries": "huisserie",
    "huissiers": "huissier",
    "huitaines": "huitaine",
    "huitièmes": "huitième",
    "hulottes": "hulotte",
    "hulula": "hululer",
    "hululai": "hululer",
    "hululaient": "hululer",
    "hululais": "hululer",
    "hululait": "hululer",
    "hululant": "hululer",
    "hululas": "hululer",
    "hululasse": "hululer",
    "hululassent": "hululer",
    "hululasses": "hululer",
    "hululassiez": "hululer",
    "hululassions": "hululer",
    "hulule": "hululer",
    "hululements": "hululement",
    "hululent": "hululer",
    "hululera": "hululer",
    "hululerai": "hululer",
    "hululeraient": "hululer",
    "hululerais": "hululer",
    "hululerait": "hululer",
    "hululeras": "hululer",
    "hululerez": "hululer",
    "hululeriez": "hululer",
    "hululerions": "hululer",
    "hululerons": "hululer",
    "hululeront": "hululer",
    "hulules": "hululer",
    "hululez": "hululer",
    "hululiez": "hululer",
    "hululions": "hululer",
    "hululons": "hululer",
    "hululâmes": "hululer",
    "hululât": "hululer",
    "hululâtes": "hululer",
    "hululèrent": "hululer",
    "hululé": "hululer",
    "hululée": "hululer",
    "huma": "humer",
    "humages": "humage",
    "humai": "humer",
    "humaient": "humer",
    "humaine": "humain",
    "humaines": "humain",
    "humains": "humain",
    "humais": "humer",
    "humait": "humer",
    "humanisait": "humaniser",
    "humanisant": "humaniser",
    "humanisations": "humanisation",
    "humanise": "humaniser",
    "humanisent": "humaniser",
    "humanismes": "humanisme",
    "humanistes": "humaniste",
    "humanisé": "humaniser",
    "humanisée": "humaniser",
    "humanisées": "humaniser",
    "humanisés": "humaniser",
    "humanitaires": "humanitaire",
    "humanités": "humanité",
    "humanoïdes": "humanoïde",
    "humant": "humer",
    "humas": "humer",
    "humasse": "humer",
    "humassent": "humer",
    "humasses": "humer",
    "humassiez": "humer",
    "humassions": "humer",
    "humbles": "humble",
    "hume": "humer",
    "humecta": "humecter",
    "humectai": "humecter",
    "humectaient": "humecter",
    "humectais": "humecter",
    "humectait": "humecter",
    "humectant": "humecter",
    "humectas": "humecter",
    "humectasse": "humecter",
    "humectassent": "humecter",
    "humectasses": "humecter",
    "humectassiez": "humecter",
    "humectassions": "humecter",
    "humecte": "humecter",
    "humectent": "humecter",
    "humectera": "humecter",
    "humecterai": "humecter",
    "humecteraient": "humecter",
    "humecterais": "humecter",
    "humecterait": "humecter",
    "humecteras": "humecter",
    "humecterez": "humecter",
    "humecteriez": "humecter",
    "humecterions": "humecter",
    "humecterons": "humecter",
    "humecteront": "humecter",
    "humectes": "humecter",
    "humectez": "humecter",
    "humectiez": "humecter",
    "humections": "humecter",
    "humectons": "humecter",
    "humectâmes": "humecter",
    "humectât": "humecter",
    "humectâtes": "humecter",
    "humectèrent": "humecter",
    "humecté": "humecter",
    "humectée": "humecter",
    "humectées": "humecter",
    "humectés": "humecter",
    "hument": "humer",
    "humera": "humer",
    "humerai": "humer",
    "humeraient": "humer",
    "humerais": "humer",
    "humerait": "humer",
    "humeras": "humer",
    "humerez": "humer",
    "humeriez": "humer",
    "humerions": "humer",
    "humerons": "humer",
    "humeront": "humer",
    "humes": "humer",
    "humeurs": "humeur",
    "humez": "humer",
    "humides": "humide",
    "humidifia": "humidifier",
    "humidifiant": "humidifier",
    "humidifient": "humidifier",
    "humidifié": "humidifier",
    "humidifiés": "humidifier",
    "humidités": "humidité",
    "humiez": "humer",
    "humilia": "humilier",
    "humiliai": "humilier",
    "humiliaient": "humilier",
    "humiliais": "humilier",
    "humiliait": "humilier",
    "humiliant": "humilier",
    "humiliante": "humiliant",
    "humiliantes": "humiliant",
    "humiliants": "humiliant",
    "humilias": "humilier",
    "humiliasse": "humilier",
    "humiliassent": "humilier",
    "humiliasses": "humilier",
    "humiliassiez": "humilier",
    "humiliassions": "humilier",
    "humiliations": "humiliation",
    "humilie": "humilier",
    "humilient": "humilier",
    "humiliera": "humilier",
    "humilierai": "humilier",
    "humilieraient": "humilier",
    "humilierais": "humilier",
    "humilierait": "humilier",
    "humilieras": "humilier",
    "humilierez": "humilier",
    "humilieriez": "humilier",
    "humilierions": "humilier",
    "humilierons": "humilier",
    "humilieront": "humilier",
    "humilies": "humilier",
    "humiliez": "humilier",
    "humiliiez": "humilier",
    "humiliions": "humilier",
    "humilions": "humilier",
    "humilités": "humilité",
    "humiliâmes": "humilier",
    "humiliât": "humilier",
    "humiliâtes": "humilier",
    "humilièrent": "humilier",
    "humilié": "humilier",
    "humiliée": "humilier",
    "humiliées": "humilier",
    "humiliés": "humilier",
    "humions": "humer",
    "humons": "humer",
    "humorale": "humoral",
    "humorales": "humoral",
    "humoraux": "humoral",
    "humoristes": "humoriste",
    "humoristiques": "humoristique",
    "humours": "humour",
    "humâmes": "humer",
    "humât": "humer",
    "humâtes": "humer",
    "humèrent": "humer",
    "humé": "humer",
    "humée": "humer",
    "humées": "humer",
    "humérale": "huméral",
    "humérales": "huméral",
    "huméraux": "huméral",
    "humés": "humer",
    "hunes": "hune",
    "huniers": "hunier",
    "huns": "hun",
    "huons": "huer",
    "huppes": "huppe",
    "huppée": "huppé",
    "huppées": "huppé",
    "huppés": "huppé",
    "hures": "hure",
    "hurla": "hurler",
    "hurlai": "hurler",
    "hurlaient": "hurler",
    "hurlais": "hurler",
    "hurlait": "hurler",
    "hurlant": "hurler",
    "hurlante": "hurlant",
    "hurlantes": "hurlant",
    "hurlants": "hurlant",
    "hurlas": "hurler",
    "hurlasse": "hurler",
    "hurlassent": "hurler",
    "hurlasses": "hurler",
    "hurlassiez": "hurler",
    "hurlassions": "hurler",
    "hurle": "hurler",
    "hurlements": "hurlement",
    "hurlent": "hurler",
    "hurlera": "hurler",
    "hurlerai": "hurler",
    "hurleraient": "hurler",
    "hurlerais": "hurler",
    "hurlerait": "hurler",
    "hurleras": "hurler",
    "hurlerez": "hurler",
    "hurleriez": "hurler",
    "hurlerions": "hurler",
    "hurlerons": "hurler",
    "hurleront": "hurler",
    "hurles": "hurler",
    "hurleurs": "hurleur",
    "hurlez": "hurler",
    "hurliez": "hurler",
    "hurlions": "hurler",
    "hurlons": "hurler",
    "hurluberlue": "hurluberlu",
    "hurluberlues": "hurluberlu",
    "hurluberlus": "hurluberlu",
    "hurlâmes": "hurler",
    "hurlât": "hurler",
    "hurlâtes": "hurler",
    "hurlèrent": "hurler",
    "hurlé": "hurler",
    "hurlée": "hurler",
    "hurlées": "hurler",
    "hurlés": "hurler",
    "huronne": "huron",
    "hurrahs": "hurrah",
    "hurricanes": "hurricane",
    "hussarde": "hussard",
    "hussardes": "hussard",
    "hussards": "hussard",
    "husseinites": "husseinite",
    "hussites": "hussite",
    "huttes": "hutte",
    "huâmes": "huer",
    "huât": "huer",
    "huâtes": "huer",
    "huèrent": "huer",
    "hué": "huer",
    "huée": "huer",
    "huées": "huer",
    "hués": "huer",
    "huîtres": "huître",
    "huîtriers": "huîtrier",
    "hyacinthes": "hyacinthe",
    "hyades": "hyade",
    "hyaline": "hyalin",
    "hyalines": "hyalin",
    "hyalins": "hyalin",
    "hybridations": "hybridation",
    "hybrides": "hybride",
    "hybridé": "hybrider",
    "hydrata": "hydrater",
    "hydratai": "hydrater",
    "hydrataient": "hydrater",
    "hydratais": "hydrater",
    "hydratait": "hydrater",
    "hydratant": "hydrater",
    "hydratante": "hydratant",
    "hydratantes": "hydratant",
    "hydratants": "hydratant",
    "hydratas": "hydrater",
    "hydratasse": "hydrater",
    "hydratassent": "hydrater",
    "hydratasses": "hydrater",
    "hydratassiez": "hydrater",
    "hydratassions": "hydrater",
    "hydratations": "hydratation",
    "hydrate": "hydrater",
    "hydratent": "hydrater",
    "hydratera": "hydrater",
    "hydraterai": "hydrater",
    "hydrateraient": "hydrater",
    "hydraterais": "hydrater",
    "hydraterait": "hydrater",
    "hydrateras": "hydrater",
    "hydraterez": "hydrater",
    "hydrateriez": "hydrater",
    "hydraterions": "hydrater",
    "hydraterons": "hydrater",
    "hydrateront": "hydrater",
    "hydrates": "hydrater",
    "hydratez": "hydrater",
    "hydratiez": "hydrater",
    "hydrations": "hydrater",
    "hydratons": "hydrater",
    "hydratâmes": "hydrater",
    "hydratât": "hydrater",
    "hydratâtes": "hydrater",
    "hydratèrent": "hydrater",
    "hydraté": "hydrater",
    "hydratée": "hydrater",
    "hydratées": "hydrater",
    "hydratés": "hydrater",
    "hydraulicienne": "hydraulicien",
    "hydrauliciennes": "hydraulicien",
    "hydrauliciens": "hydraulicien",
    "hydrauliques": "hydraulique",
    "hydravions": "hydravion",
    "hydres": "hydre",
    "hydriques": "hydrique",
    "hydro-électriques": "hydro-électrique",
    "hydrocarbures": "hydrocarbure",
    "hydrocéphales": "hydrocéphale",
    "hydroglisseurs": "hydroglisseur",
    "hydrographes": "hydrographe",
    "hydrographiques": "hydrographique",
    "hydrogènes": "hydrogène",
    "hydrogénée": "hydrogéné",
    "hydrogéologiques": "hydrogéologique",
    "hydrologies": "hydrologie",
    "hydrologiques": "hydrologique",
    "hydrolyses": "hydrolyse",
    "hydromels": "hydromel",
    "hydromètres": "hydromètre",
    "hydrométriques": "hydrométrique",
    "hydrophiles": "hydrophile",
    "hydropisies": "hydropisie",
    "hydroponiques": "hydroponique",
    "hydrothérapies": "hydrothérapie",
    "hydroélectriques": "hydroélectrique",
    "hygiènes": "hygiène",
    "hygiéniques": "hygiénique",
    "hygiénistes": "hygiéniste",
    "hygromètres": "hygromètre",
    "hygrométriques": "hygrométrique",
    "hymens": "hymen",
    "hymnes": "hymne",
    "hyménoptères": "hyménoptère",
    "hyménées": "hyménée",
    "hypallages": "hypallage",
    "hyperactive": "hyperactif",
    "hyperboles": "hyperbole",
    "hyperboréenne": "hyperboréen",
    "hyperboréens": "hyperboréen",
    "hypercorrecte": "hypercorrect",
    "hypercorrectes": "hypercorrect",
    "hypercorrects": "hypercorrect",
    "hyperglycémies": "hyperglycémie",
    "hyperinflations": "hyperinflation",
    "hypermarchés": "hypermarché",
    "hypermétropes": "hypermétrope",
    "hypernerveuse": "hypernerveux",
    "hypernerveuses": "hypernerveux",
    "hyperréalismes": "hyperréalisme",
    "hyperréalistes": "hyperréaliste",
    "hypersensibilités": "hypersensibilité",
    "hypersensibles": "hypersensible",
    "hypertendue": "hypertendu",
    "hypertendus": "hypertendu",
    "hypertensions": "hypertension",
    "hypertrophie": "hypertrophier",
    "hypertrophies": "hypertrophie",
    "hypertrophié": "hypertrophier",
    "hypertrophiée": "hypertrophier",
    "hypertrophiées": "hypertrophié",
    "hypertrophiés": "hypertrophier",
    "hyperémotive": "hyperémotif",
    "hyperémotivités": "hyperémotivité",
    "hyphes": "hyphe",
    "hypholomes": "hypholome",
    "hypnagogiques": "hypnagogique",
    "hypnogènes": "hypnogène",
    "hypnoses": "hypnose",
    "hypnotiques": "hypnotique",
    "hypnotisa": "hypnotiser",
    "hypnotisai": "hypnotiser",
    "hypnotisaient": "hypnotiser",
    "hypnotisais": "hypnotiser",
    "hypnotisait": "hypnotiser",
    "hypnotisant": "hypnotiser",
    "hypnotisas": "hypnotiser",
    "hypnotisasse": "hypnotiser",
    "hypnotisassent": "hypnotiser",
    "hypnotisasses": "hypnotiser",
    "hypnotisassiez": "hypnotiser",
    "hypnotisassions": "hypnotiser",
    "hypnotise": "hypnotiser",
    "hypnotisent": "hypnotiser",
    "hypnotisera": "hypnotiser",
    "hypnotiserai": "hypnotiser",
    "hypnotiseraient": "hypnotiser",
    "hypnotiserais": "hypnotiser",
    "hypnotiserait": "hypnotiser",
    "hypnotiseras": "hypnotiser",
    "hypnotiserez": "hypnotiser",
    "hypnotiseriez": "hypnotiser",
    "hypnotiserions": "hypnotiser",
    "hypnotiserons": "hypnotiser",
    "hypnotiseront": "hypnotiser",
    "hypnotises": "hypnotiser",
    "hypnotiseurs": "hypnotiseur",
    "hypnotiseuse": "hypnotiseur",
    "hypnotisez": "hypnotiser",
    "hypnotisiez": "hypnotiser",
    "hypnotisions": "hypnotiser",
    "hypnotisons": "hypnotiser",
    "hypnotisâmes": "hypnotiser",
    "hypnotisât": "hypnotiser",
    "hypnotisâtes": "hypnotiser",
    "hypnotisèrent": "hypnotiser",
    "hypnotisé": "hypnotiser",
    "hypnotisée": "hypnotiser",
    "hypnotisées": "hypnotiser",
    "hypnotisés": "hypnotiser",
    "hypoallergéniques": "hypoallergénique",
    "hypocaustes": "hypocauste",
    "hypochondriaques": "hypochondriaque",
    "hypocondriaques": "hypocondriaque",
    "hypocrisies": "hypocrisie",
    "hypocrites": "hypocrite",
    "hypodermiques": "hypodermique",
    "hypoglycémiques": "hypoglycémique",
    "hypogées": "hypogée",
    "hypokhâgnes": "hypokhâgne",
    "hypomaniaques": "hypomaniaque",
    "hyponomeutes": "hyponomeute",
    "hypophysaires": "hypophysaire",
    "hypophyses": "hypophyse",
    "hypostases": "hypostase",
    "hypostyles": "hypostyle",
    "hypotendue": "hypotendu",
    "hypotensions": "hypotension",
    "hypotensive": "hypotensif",
    "hypothermies": "hypothermie",
    "hypothèque": "hypothéquer",
    "hypothèquent": "hypothéquer",
    "hypothèques": "hypothéquer",
    "hypothèses": "hypothèse",
    "hypothécaires": "hypothécaire",
    "hypothéqua": "hypothéquer",
    "hypothéquai": "hypothéquer",
    "hypothéquaient": "hypothéquer",
    "hypothéquais": "hypothéquer",
    "hypothéquait": "hypothéquer",
    "hypothéquant": "hypothéquer",
    "hypothéquas": "hypothéquer",
    "hypothéquasse": "hypothéquer",
    "hypothéquassent": "hypothéquer",
    "hypothéquasses": "hypothéquer",
    "hypothéquassiez": "hypothéquer",
    "hypothéquassions": "hypothéquer",
    "hypothéquera": "hypothéquer",
    "hypothéquerai": "hypothéquer",
    "hypothéqueraient": "hypothéquer",
    "hypothéquerais": "hypothéquer",
    "hypothéquerait": "hypothéquer",
    "hypothéqueras": "hypothéquer",
    "hypothéquerez": "hypothéquer",
    "hypothéqueriez": "hypothéquer",
    "hypothéquerions": "hypothéquer",
    "hypothéquerons": "hypothéquer",
    "hypothéqueront": "hypothéquer",
    "hypothéquez": "hypothéquer",
    "hypothéquiez": "hypothéquer",
    "hypothéquions": "hypothéquer",
    "hypothéquons": "hypothéquer",
    "hypothéquâmes": "hypothéquer",
    "hypothéquât": "hypothéquer",
    "hypothéquâtes": "hypothéquer",
    "hypothéquèrent": "hypothéquer",
    "hypothéqué": "hypothéquer",
    "hypothéquée": "hypothéquer",
    "hypothéquées": "hypothéquer",
    "hypothéqués": "hypothéquer",
    "hypothétiques": "hypothétique",
    "hypotrophies": "hypotrophie",
    "hypoténuses": "hypoténuse",
    "hypoïdes": "hypoïde",
    "hysopes": "hysope",
    "hystéries": "hystérie",
    "hystériques": "hystérique",
    "hyènes": "hyène",
    "hâbleries": "hâblerie",
    "hâbleurs": "hâbleur",
    "hâbleuse": "hâbleur",
    "hâbleuses": "hâbleur",
    "hâla": "hâler",
    "hâlai": "hâler",
    "hâlaient": "hâler",
    "hâlais": "hâler",
    "hâlait": "hâler",
    "hâlant": "hâler",
    "hâlas": "hâler",
    "hâlasse": "hâler",
    "hâlassent": "hâler",
    "hâlasses": "hâler",
    "hâlassiez": "hâler",
    "hâlassions": "hâler",
    "hâle": "hâler",
    "hâlent": "hâler",
    "hâlera": "hâler",
    "hâlerai": "hâler",
    "hâleraient": "hâler",
    "hâlerais": "hâler",
    "hâlerait": "hâler",
    "hâleras": "hâler",
    "hâlerez": "hâler",
    "hâleriez": "hâler",
    "hâlerions": "hâler",
    "hâlerons": "hâler",
    "hâleront": "hâler",
    "hâles": "hâler",
    "hâlez": "hâler",
    "hâliez": "hâler",
    "hâlions": "hâler",
    "hâlons": "hâler",
    "hâlâmes": "hâler",
    "hâlât": "hâler",
    "hâlâtes": "hâler",
    "hâlèrent": "hâler",
    "hâlé": "hâler",
    "hâlée": "hâler",
    "hâlées": "hâler",
    "hâlés": "hâler",
    "hâta": "hâter",
    "hâtai": "hâter",
    "hâtaient": "hâter",
    "hâtais": "hâter",
    "hâtait": "hâter",
    "hâtant": "hâter",
    "hâtas": "hâter",
    "hâtasse": "hâter",
    "hâtassent": "hâter",
    "hâtasses": "hâter",
    "hâtassiez": "hâter",
    "hâtassions": "hâter",
    "hâte": "hâter",
    "hâtent": "hâter",
    "hâtera": "hâter",
    "hâterai": "hâter",
    "hâteraient": "hâter",
    "hâterais": "hâter",
    "hâterait": "hâter",
    "hâteras": "hâter",
    "hâterez": "hâter",
    "hâteriez": "hâter",
    "hâterions": "hâter",
    "hâterons": "hâter",
    "hâteront": "hâter",
    "hâtes": "hâter",
    "hâtez": "hâter",
    "hâtiez": "hâter",
    "hâtifs": "hâtif",
    "hâtions": "hâter",
    "hâtive": "hâtif",
    "hâtives": "hâtif",
    "hâtons": "hâter",
    "hâtâmes": "hâter",
    "hâtât": "hâter",
    "hâtâtes": "hâter",
    "hâtèrent": "hâter",
    "hâté": "hâter",
    "hâtée": "hâter",
    "hâtées": "hâter",
    "hâtés": "hâter",
    "hâves": "hâve",
    "hèle": "héler",
    "hèlent": "héler",
    "hèles": "héler",
    "hères": "hère",
    "héberge": "héberger",
    "hébergea": "héberger",
    "hébergeai": "héberger",
    "hébergeaient": "héberger",
    "hébergeais": "héberger",
    "hébergeait": "héberger",
    "hébergeant": "héberger",
    "hébergeas": "héberger",
    "hébergeasse": "héberger",
    "hébergeassent": "héberger",
    "hébergeasses": "héberger",
    "hébergeassiez": "héberger",
    "hébergeassions": "héberger",
    "hébergements": "hébergement",
    "hébergent": "héberger",
    "hébergeons": "héberger",
    "hébergera": "héberger",
    "hébergerai": "héberger",
    "hébergeraient": "héberger",
    "hébergerais": "héberger",
    "hébergerait": "héberger",
    "hébergeras": "héberger",
    "hébergerez": "héberger",
    "hébergeriez": "héberger",
    "hébergerions": "héberger",
    "hébergerons": "héberger",
    "hébergeront": "héberger",
    "héberges": "héberger",
    "hébergez": "héberger",
    "hébergeâmes": "héberger",
    "hébergeât": "héberger",
    "hébergeâtes": "héberger",
    "hébergiez": "héberger",
    "hébergions": "héberger",
    "hébergèrent": "héberger",
    "hébergé": "héberger",
    "hébergée": "héberger",
    "hébergées": "héberger",
    "hébergés": "héberger",
    "hébraïques": "hébraïque",
    "hébreux": "hébreu",
    "hébète": "hébéter",
    "hébètent": "hébéter",
    "hébètes": "hébéter",
    "hébéphrènes": "hébéphrène",
    "hébéphrénies": "hébéphrénie",
    "hébéta": "hébéter",
    "hébétai": "hébéter",
    "hébétaient": "hébéter",
    "hébétais": "hébéter",
    "hébétait": "hébéter",
    "hébétant": "hébéter",
    "hébétas": "hébéter",
    "hébétasse": "hébéter",
    "hébétassent": "hébéter",
    "hébétasses": "hébéter",
    "hébétassiez": "hébéter",
    "hébétassions": "hébéter",
    "hébétements": "hébétement",
    "hébétera": "hébéter",
    "hébéterai": "hébéter",
    "hébéteraient": "hébéter",
    "hébéterais": "hébéter",
    "hébéterait": "hébéter",
    "hébéteras": "hébéter",
    "hébéterez": "hébéter",
    "hébéteriez": "hébéter",
    "hébéterions": "hébéter",
    "hébéterons": "hébéter",
    "hébéteront": "hébéter",
    "hébétez": "hébéter",
    "hébétiez": "hébéter",
    "hébétions": "hébéter",
    "hébétons": "hébéter",
    "hébétudes": "hébétude",
    "hébétâmes": "hébéter",
    "hébétât": "hébéter",
    "hébétâtes": "hébéter",
    "hébétèrent": "hébéter",
    "hébété": "hébéter",
    "hébétée": "hébéter",
    "hébétées": "hébéter",
    "hébétés": "hébéter",
    "hécatombes": "hécatombe",
    "hédonismes": "hédonisme",
    "hédonistes": "hédoniste",
    "hégélienne": "hégélien",
    "hégéliens": "hégélien",
    "hégémonies": "hégémonie",
    "hégémoniques": "hégémonique",
    "héla": "héler",
    "hélai": "héler",
    "hélaient": "héler",
    "hélais": "héler",
    "hélait": "héler",
    "hélant": "héler",
    "hélas": "héler",
    "hélasse": "héler",
    "hélassent": "héler",
    "hélasses": "héler",
    "hélassiez": "héler",
    "hélassions": "héler",
    "hélera": "héler",
    "hélerai": "héler",
    "héleraient": "héler",
    "hélerais": "héler",
    "hélerait": "héler",
    "héleras": "héler",
    "hélerez": "héler",
    "héleriez": "héler",
    "hélerions": "héler",
    "hélerons": "héler",
    "héleront": "héler",
    "hélez": "héler",
    "hélianthes": "hélianthe",
    "hélices": "hélice",
    "hélicons": "hélicon",
    "hélicoptères": "hélicoptère",
    "hélicoïdale": "hélicoïdal",
    "hélicoïdales": "hélicoïdal",
    "hélicoïdaux": "hélicoïdal",
    "héliez": "héler",
    "héliographiques": "héliographique",
    "héliogravures": "héliogravure",
    "héliomarine": "héliomarin",
    "héliomarines": "héliomarin",
    "héliomarins": "héliomarin",
    "hélions": "héler",
    "héliothérapies": "héliothérapie",
    "héliotropes": "héliotrope",
    "héliports": "héliport",
    "héliporté": "héliporter",
    "héliportée": "héliporter",
    "héliportés": "héliporter",
    "héliums": "hélium",
    "hélons": "héler",
    "hélâmes": "héler",
    "hélât": "héler",
    "hélâtes": "héler",
    "hélèrent": "héler",
    "hélé": "héler",
    "hélée": "héler",
    "hélées": "héler",
    "hélés": "héler",
    "hématies": "hématie",
    "hématologies": "hématologie",
    "hématomes": "hématome",
    "hématuries": "hématurie",
    "hémicycles": "hémicycle",
    "hémicyles": "hémicyle",
    "hémiplégies": "hémiplégie",
    "hémisphères": "hémisphère",
    "hémisphériques": "hémisphérique",
    "hémistiches": "hémistiche",
    "hémièdres": "hémièdre",
    "hémocultures": "hémoculture",
    "hémodialyses": "hémodialyse",
    "hémoglobines": "hémoglobine",
    "hémolyses": "hémolyse",
    "hémolytiques": "hémolytique",
    "hémophiles": "hémophile",
    "hémophilies": "hémophilie",
    "hémoptysies": "hémoptysie",
    "hémorragies": "hémorragie",
    "hémorroïdale": "hémorroïdal",
    "hémorroïdes": "hémorroïde",
    "hémostases": "hémostase",
    "hémostatiques": "hémostatique",
    "hépatiques": "hépatique",
    "hépatites": "hépatite",
    "héraclitienne": "héraclitien",
    "héraclitéenne": "héraclitéen",
    "héraldiques": "héraldique",
    "hérauts": "héraut",
    "hérissa": "hérisser",
    "hérissai": "hérisser",
    "hérissaient": "hérisser",
    "hérissais": "hérisser",
    "hérissait": "hérisser",
    "hérissant": "hérisser",
    "hérissas": "hérisser",
    "hérissasse": "hérisser",
    "hérissassent": "hérisser",
    "hérissasses": "hérisser",
    "hérissassiez": "hérisser",
    "hérissassions": "hérisser",
    "hérisse": "hérisser",
    "hérissements": "hérissement",
    "hérissent": "hérisser",
    "hérissera": "hérisser",
    "hérisserai": "hérisser",
    "hérisseraient": "hérisser",
    "hérisserais": "hérisser",
    "hérisserait": "hérisser",
    "hérisseras": "hérisser",
    "hérisserez": "hérisser",
    "hérisseriez": "hérisser",
    "hérisserions": "hérisser",
    "hérisserons": "hérisser",
    "hérisseront": "hérisser",
    "hérisses": "hérisser",
    "hérissez": "hérisser",
    "hérissiez": "hérisser",
    "hérissions": "hérisser",
    "hérissons": "hérisson",
    "hérissâmes": "hérisser",
    "hérissât": "hérisser",
    "hérissâtes": "hérisser",
    "hérissèrent": "hérisser",
    "hérissé": "hérisser",
    "hérissée": "hérisser",
    "hérissées": "hérisser",
    "hérissés": "hérisser",
    "hérita": "hériter",
    "héritages": "héritage",
    "héritai": "hériter",
    "héritaient": "hériter",
    "héritais": "hériter",
    "héritait": "hériter",
    "héritant": "hériter",
    "héritas": "hériter",
    "héritasse": "hériter",
    "héritassent": "hériter",
    "héritasses": "hériter",
    "héritassiez": "hériter",
    "héritassions": "hériter",
    "hérite": "hériter",
    "héritent": "hériter",
    "héritera": "hériter",
    "hériterai": "hériter",
    "hériteraient": "hériter",
    "hériterais": "hériter",
    "hériterait": "hériter",
    "hériteras": "hériter",
    "hériterez": "hériter",
    "hériteriez": "hériter",
    "hériterions": "hériter",
    "hériterons": "hériter",
    "hériteront": "hériter",
    "hérites": "hériter",
    "héritez": "hériter",
    "héritiers": "héritier",
    "héritiez": "hériter",
    "héritions": "hériter",
    "héritière": "héritier",
    "héritières": "héritier",
    "héritons": "hériter",
    "héritâmes": "hériter",
    "héritât": "hériter",
    "héritâtes": "hériter",
    "héritèrent": "hériter",
    "hérité": "hériter",
    "héritée": "hériter",
    "héritées": "hériter",
    "hérités": "hériter",
    "héronneaux": "héronneau",
    "hérons": "héron",
    "héroï-comiques": "héroï-comique",
    "héroïne": "héros",
    "héroïnes": "héros",
    "héroïques": "héroïque",
    "héroïsmes": "héroïsme",
    "héréditaires": "héréditaire",
    "hérédités": "hérédité",
    "hérésiarques": "hérésiarque",
    "hérésies": "hérésie",
    "hérétiques": "hérétique",
    "hésita": "hésiter",
    "hésitai": "hésiter",
    "hésitaient": "hésiter",
    "hésitais": "hésiter",
    "hésitait": "hésiter",
    "hésitant": "hésiter",
    "hésitante": "hésitant",
    "hésitantes": "hésitant",
    "hésitants": "hésitant",
    "hésitas": "hésiter",
    "hésitasse": "hésiter",
    "hésitassent": "hésiter",
    "hésitasses": "hésiter",
    "hésitassiez": "hésiter",
    "hésitassions": "hésiter",
    "hésitations": "hésitation",
    "hésite": "hésiter",
    "hésitent": "hésiter",
    "hésitera": "hésiter",
    "hésiterai": "hésiter",
    "hésiteraient": "hésiter",
    "hésiterais": "hésiter",
    "hésiterait": "hésiter",
    "hésiteras": "hésiter",
    "hésiterez": "hésiter",
    "hésiteriez": "hésiter",
    "hésiterions": "hésiter",
    "hésiterons": "hésiter",
    "hésiteront": "hésiter",
    "hésites": "hésiter",
    "hésitez": "hésiter",
    "hésitiez": "hésiter",
    "hésitions": "hésiter",
    "hésitons": "hésiter",
    "hésitâmes": "hésiter",
    "hésitât": "hésiter",
    "hésitâtes": "hésiter",
    "hésitèrent": "hésiter",
    "hésité": "hésiter",
    "hétaïres": "hétaïre",
    "hétéroclites": "hétéroclite",
    "hétérodoxes": "hétérodoxe",
    "hétérogènes": "hétérogène",
    "hétérogénéités": "hétérogénéité",
    "hétéros": "hétéro",
    "hétérosexuelle": "hétérosexuel",
    "hétérosexuelles": "hétérosexuel",
    "hétérosexuels": "hétérosexuel",
    "hétérozygotes": "hétérozygote",
    "hévéas": "hévéa",
    "hêtraies": "hêtraie",
    "hêtres": "hêtre",
    "hôpitaux": "hôpital",
    "hôteliers": "hôtelier",
    "hôtelière": "hôtelier",
    "hôtelières": "hôtelier",
    "hôtelleries": "hôtellerie",
    "hôtels": "hôtel",
    "hôtels-Dieu": "hôtel-Dieu",
    "hôtes": "hôte",
    "hôtesse": "hôte",
    "hôtesses": "hôtesse",
    "i": "ie",
    "iambiques": "iambique",
    "ibères": "ibère",
    "ibériques": "ibérique",
    "ice cream": "ice-cream",
    "ice-creams": "ice-cream",
    "icebergs": "iceberg",
    "ichneumons": "ichneumon",
    "ichtyologies": "ichtyologie",
    "ichtyosaures": "ichtyosaure",
    "icoglans": "icoglan",
    "iconiques": "iconique",
    "iconoclastes": "iconoclaste",
    "iconographies": "iconographie",
    "iconostases": "iconostase",
    "ictères": "ictère",
    "icônes": "icône",
    "identifia": "identifier",
    "identifiables": "identifiable",
    "identifiai": "identifier",
    "identifiaient": "identifier",
    "identifiais": "identifier",
    "identifiait": "identifier",
    "identifiant": "identifier",
    "identifias": "identifier",
    "identifiasse": "identifier",
    "identifiassent": "identifier",
    "identifiasses": "identifier",
    "identifiassiez": "identifier",
    "identifiassions": "identifier",
    "identifications": "identification",
    "identifie": "identifier",
    "identifient": "identifier",
    "identifiera": "identifier",
    "identifierai": "identifier",
    "identifieraient": "identifier",
    "identifierais": "identifier",
    "identifierait": "identifier",
    "identifieras": "identifier",
    "identifierez": "identifier",
    "identifieriez": "identifier",
    "identifierions": "identifier",
    "identifierons": "identifier",
    "identifieront": "identifier",
    "identifies": "identifier",
    "identifiez": "identifier",
    "identifiiez": "identifier",
    "identifiions": "identifier",
    "identifions": "identifier",
    "identifiâmes": "identifier",
    "identifiât": "identifier",
    "identifiâtes": "identifier",
    "identifièrent": "identifier",
    "identifié": "identifier",
    "identifiée": "identifier",
    "identifiées": "identifier",
    "identifiés": "identifier",
    "identiques": "identique",
    "identitaires": "identitaire",
    "identités": "identité",
    "idiolectes": "idiolecte",
    "idiomatiques": "idiomatique",
    "idiomes": "idiome",
    "idiosyncrasies": "idiosyncrasie",
    "idiote": "idiot",
    "idiotes": "idiot",
    "idioties": "idiotie",
    "idiotismes": "idiotisme",
    "idiots": "idiot",
    "idoines": "idoine",
    "idoles": "idole",
    "idolâtraient": "idolâtrer",
    "idolâtrait": "idolâtrer",
    "idolâtrant": "idolâtrer",
    "idolâtre": "idolâtrer",
    "idolâtrent": "idolâtrer",
    "idolâtres": "idolâtrer",
    "idolâtries": "idolâtrie",
    "idolâtré": "idolâtrer",
    "idolâtrée": "idolâtrer",
    "idylles": "idylle",
    "idylliques": "idyllique",
    "idéale": "idéal",
    "idéales": "idéal",
    "idéalisa": "idéaliser",
    "idéalisai": "idéaliser",
    "idéalisaient": "idéaliser",
    "idéalisais": "idéaliser",
    "idéalisait": "idéaliser",
    "idéalisant": "idéaliser",
    "idéalisas": "idéaliser",
    "idéalisasse": "idéaliser",
    "idéalisassent": "idéaliser",
    "idéalisasses": "idéaliser",
    "idéalisassiez": "idéaliser",
    "idéalisassions": "idéaliser",
    "idéalise": "idéaliser",
    "idéalisent": "idéaliser",
    "idéalisera": "idéaliser",
    "idéaliserai": "idéaliser",
    "idéaliseraient": "idéaliser",
    "idéaliserais": "idéaliser",
    "idéaliserait": "idéaliser",
    "idéaliseras": "idéaliser",
    "idéaliserez": "idéaliser",
    "idéaliseriez": "idéaliser",
    "idéaliserions": "idéaliser",
    "idéaliserons": "idéaliser",
    "idéaliseront": "idéaliser",
    "idéalises": "idéaliser",
    "idéalisez": "idéaliser",
    "idéalisiez": "idéaliser",
    "idéalisions": "idéaliser",
    "idéalismes": "idéalisme",
    "idéalisons": "idéaliser",
    "idéalistes": "idéaliste",
    "idéalisâmes": "idéaliser",
    "idéalisât": "idéaliser",
    "idéalisâtes": "idéaliser",
    "idéalisèrent": "idéaliser",
    "idéalisé": "idéaliser",
    "idéalisée": "idéaliser",
    "idéalisées": "idéaliser",
    "idéalisés": "idéaliser",
    "idéals": "idéal",
    "idéaux": "idéal",
    "idées": "idée",
    "idées-forces": "idée-force",
    "idéogrammes": "idéogramme",
    "idéologies": "idéologie",
    "idéologiques": "idéologique",
    "idéologisa": "idéologiser",
    "idéologisai": "idéologiser",
    "idéologisaient": "idéologiser",
    "idéologisais": "idéologiser",
    "idéologisait": "idéologiser",
    "idéologisant": "idéologiser",
    "idéologisas": "idéologiser",
    "idéologisasse": "idéologiser",
    "idéologisassent": "idéologiser",
    "idéologisasses": "idéologiser",
    "idéologisassiez": "idéologiser",
    "idéologisassions": "idéologiser",
    "idéologise": "idéologiser",
    "idéologisent": "idéologiser",
    "idéologisera": "idéologiser",
    "idéologiserai": "idéologiser",
    "idéologiseraient": "idéologiser",
    "idéologiserais": "idéologiser",
    "idéologiserait": "idéologiser",
    "idéologiseras": "idéologiser",
    "idéologiserez": "idéologiser",
    "idéologiseriez": "idéologiser",
    "idéologiserions": "idéologiser",
    "idéologiserons": "idéologiser",
    "idéologiseront": "idéologiser",
    "idéologises": "idéologiser",
    "idéologisez": "idéologiser",
    "idéologisiez": "idéologiser",
    "idéologisions": "idéologiser",
    "idéologisons": "idéologiser",
    "idéologisâmes": "idéologiser",
    "idéologisât": "idéologiser",
    "idéologisâtes": "idéologiser",
    "idéologisèrent": "idéologiser",
    "idéologisé": "idéologiser",
    "idéologisée": "idéologiser",
    "idéologisées": "idéologiser",
    "idéologisés": "idéologiser",
    "idéologues": "idéologue",
    "ifs": "if",
    "igloos": "igloo",
    "ignames": "igname",
    "ignares": "ignare",
    "ignifugeant": "ignifuger",
    "ignifugé": "ignifuger",
    "ignifugée": "ignifugé",
    "ignifugées": "ignifuger",
    "ignifugés": "ignifugé",
    "ignitions": "ignition",
    "ignobles": "ignoble",
    "ignominies": "ignominie",
    "ignominieuse": "ignominieux",
    "ignominieuses": "ignominieux",
    "ignora": "ignorer",
    "ignorai": "ignorer",
    "ignoraient": "ignorer",
    "ignorais": "ignorer",
    "ignorait": "ignorer",
    "ignorances": "ignorance",
    "ignorant": "ignorer",
    "ignorante": "ignorant",
    "ignorantes": "ignorant",
    "ignorantins": "ignorantin",
    "ignorants": "ignorant",
    "ignoras": "ignorer",
    "ignorasse": "ignorer",
    "ignorassent": "ignorer",
    "ignorasses": "ignorer",
    "ignorassiez": "ignorer",
    "ignorassions": "ignorer",
    "ignore": "ignorer",
    "ignorent": "ignorer",
    "ignorera": "ignorer",
    "ignorerai": "ignorer",
    "ignoreraient": "ignorer",
    "ignorerais": "ignorer",
    "ignorerait": "ignorer",
    "ignoreras": "ignorer",
    "ignorerez": "ignorer",
    "ignoreriez": "ignorer",
    "ignorerions": "ignorer",
    "ignorerons": "ignorer",
    "ignoreront": "ignorer",
    "ignores": "ignorer",
    "ignorez": "ignorer",
    "ignoriez": "ignorer",
    "ignorions": "ignorer",
    "ignorons": "ignorer",
    "ignorâmes": "ignorer",
    "ignorât": "ignorer",
    "ignorâtes": "ignorer",
    "ignorèrent": "ignorer",
    "ignoré": "ignorer",
    "ignorée": "ignorer",
    "ignorées": "ignorer",
    "ignorés": "ignorer",
    "ignée": "igné",
    "ignées": "igné",
    "ignés": "igné",
    "iguanes": "iguane",
    "iguanodons": "iguanodon",
    "igues": "igue",
    "ilangs-ilangs": "ilang-ilang",
    "iles": "ile",
    "iliaques": "iliaque",
    "illettrismes": "illettrisme",
    "illettrée": "illettré",
    "illettrées": "illettré",
    "illettrés": "illettré",
    "illicites": "illicite",
    "illimitée": "illimité",
    "illimitées": "illimité",
    "illimités": "illimité",
    "illisibles": "illisible",
    "illogiques": "illogique",
    "illogismes": "illogisme",
    "illumina": "illuminer",
    "illuminai": "illuminer",
    "illuminaient": "illuminer",
    "illuminais": "illuminer",
    "illuminait": "illuminer",
    "illuminant": "illuminer",
    "illuminas": "illuminer",
    "illuminasse": "illuminer",
    "illuminassent": "illuminer",
    "illuminasses": "illuminer",
    "illuminassiez": "illuminer",
    "illuminassions": "illuminer",
    "illuminateurs": "illuminateur",
    "illuminations": "illumination",
    "illumine": "illuminer",
    "illuminent": "illuminer",
    "illuminera": "illuminer",
    "illuminerai": "illuminer",
    "illumineraient": "illuminer",
    "illuminerais": "illuminer",
    "illuminerait": "illuminer",
    "illumineras": "illuminer",
    "illuminerez": "illuminer",
    "illumineriez": "illuminer",
    "illuminerions": "illuminer",
    "illuminerons": "illuminer",
    "illumineront": "illuminer",
    "illumines": "illuminer",
    "illuminez": "illuminer",
    "illuminiez": "illuminer",
    "illuminions": "illuminer",
    "illuministes": "illuministe",
    "illuminons": "illuminer",
    "illuminâmes": "illuminer",
    "illuminât": "illuminer",
    "illuminâtes": "illuminer",
    "illuminèrent": "illuminer",
    "illuminé": "illuminer",
    "illuminée": "illuminer",
    "illuminées": "illuminer",
    "illuminés": "illuminer",
    "illusionna": "illusionner",
    "illusionnai": "illusionner",
    "illusionnaient": "illusionner",
    "illusionnais": "illusionner",
    "illusionnait": "illusionner",
    "illusionnant": "illusionner",
    "illusionnas": "illusionner",
    "illusionnasse": "illusionner",
    "illusionnassent": "illusionner",
    "illusionnasses": "illusionner",
    "illusionnassiez": "illusionner",
    "illusionnassions": "illusionner",
    "illusionne": "illusionner",
    "illusionnent": "illusionner",
    "illusionnera": "illusionner",
    "illusionnerai": "illusionner",
    "illusionneraient": "illusionner",
    "illusionnerais": "illusionner",
    "illusionnerait": "illusionner",
    "illusionneras": "illusionner",
    "illusionnerez": "illusionner",
    "illusionneriez": "illusionner",
    "illusionnerions": "illusionner",
    "illusionnerons": "illusionner",
    "illusionneront": "illusionner",
    "illusionnes": "illusionner",
    "illusionnez": "illusionner",
    "illusionniez": "illusionner",
    "illusionnions": "illusionner",
    "illusionnistes": "illusionniste",
    "illusionnons": "illusionner",
    "illusionnâmes": "illusionner",
    "illusionnât": "illusionner",
    "illusionnâtes": "illusionner",
    "illusionnèrent": "illusionner",
    "illusionné": "illusionner",
    "illusionnée": "illusionner",
    "illusionnées": "illusionner",
    "illusionnés": "illusionner",
    "illusions": "illusion",
    "illusoires": "illusoire",
    "illustra": "illustrer",
    "illustrai": "illustrer",
    "illustraient": "illustrer",
    "illustrais": "illustrer",
    "illustrait": "illustrer",
    "illustrant": "illustrer",
    "illustras": "illustrer",
    "illustrasse": "illustrer",
    "illustrassent": "illustrer",
    "illustrasses": "illustrer",
    "illustrassiez": "illustrer",
    "illustrassions": "illustrer",
    "illustrations": "illustration",
    "illustratrice": "illustrateur",
    "illustre": "illustrer",
    "illustrent": "illustrer",
    "illustrera": "illustrer",
    "illustrerai": "illustrer",
    "illustreraient": "illustrer",
    "illustrerais": "illustrer",
    "illustrerait": "illustrer",
    "illustreras": "illustrer",
    "illustrerez": "illustrer",
    "illustreriez": "illustrer",
    "illustrerions": "illustrer",
    "illustrerons": "illustrer",
    "illustreront": "illustrer",
    "illustres": "illustrer",
    "illustrez": "illustrer",
    "illustriez": "illustrer",
    "illustrions": "illustrer",
    "illustrissimes": "illustrissime",
    "illustrons": "illustrer",
    "illustrâmes": "illustrer",
    "illustrât": "illustrer",
    "illustrâtes": "illustrer",
    "illustrèrent": "illustrer",
    "illustré": "illustrer",
    "illustrée": "illustrer",
    "illustrées": "illustrer",
    "illustrés": "illustrer",
    "illégale": "illégal",
    "illégales": "illégal",
    "illégalistes": "illégaliste",
    "illégalités": "illégalité",
    "illégaux": "illégal",
    "illégitimes": "illégitime",
    "ilotes": "ilote",
    "ilotismes": "ilotisme",
    "ils": "il",
    "iléaux": "iléal",
    "image": "imager",
    "imageant": "imager",
    "imageries": "imagerie",
    "images": "image",
    "imageurs": "imageur",
    "imageuse": "imageux",
    "imageuses": "imageux",
    "imagiers": "imagier",
    "imagina": "imaginer",
    "imaginables": "imaginable",
    "imaginai": "imaginer",
    "imaginaient": "imaginer",
    "imaginaires": "imaginaire",
    "imaginais": "imaginer",
    "imaginait": "imaginer",
    "imaginant": "imaginer",
    "imaginas": "imaginer",
    "imaginasse": "imaginer",
    "imaginassent": "imaginer",
    "imaginasses": "imaginer",
    "imaginassiez": "imaginer",
    "imaginassions": "imaginer",
    "imaginatifs": "imaginatif",
    "imaginations": "imagination",
    "imaginative": "imaginatif",
    "imaginatives": "imaginatif",
    "imagine": "imaginer",
    "imaginent": "imaginer",
    "imaginera": "imaginer",
    "imaginerai": "imaginer",
    "imagineraient": "imaginer",
    "imaginerais": "imaginer",
    "imaginerait": "imaginer",
    "imagineras": "imaginer",
    "imaginerez": "imaginer",
    "imagineriez": "imaginer",
    "imaginerions": "imaginer",
    "imaginerons": "imaginer",
    "imagineront": "imaginer",
    "imagines": "imaginer",
    "imaginez": "imaginer",
    "imaginiez": "imaginer",
    "imaginions": "imaginer",
    "imaginons": "imaginer",
    "imaginâmes": "imaginer",
    "imaginât": "imaginer",
    "imaginâtes": "imaginer",
    "imaginèrent": "imaginer",
    "imaginé": "imaginer",
    "imaginée": "imaginer",
    "imaginées": "imaginer",
    "imaginés": "imaginer",
    "imagos": "imago",
    "imagé": "imager",
    "imagée": "imager",
    "imagées": "imager",
    "imagés": "imager",
    "imams": "imam",
    "imans": "iman",
    "imbattables": "imbattable",
    "imberbes": "imberbe",
    "imbiba": "imbiber",
    "imbibai": "imbiber",
    "imbibaient": "imbiber",
    "imbibais": "imbiber",
    "imbibait": "imbiber",
    "imbibant": "imbiber",
    "imbibas": "imbiber",
    "imbibasse": "imbiber",
    "imbibassent": "imbiber",
    "imbibasses": "imbiber",
    "imbibassiez": "imbiber",
    "imbibassions": "imbiber",
    "imbibe": "imbiber",
    "imbibent": "imbiber",
    "imbibera": "imbiber",
    "imbiberai": "imbiber",
    "imbiberaient": "imbiber",
    "imbiberais": "imbiber",
    "imbiberait": "imbiber",
    "imbiberas": "imbiber",
    "imbiberez": "imbiber",
    "imbiberiez": "imbiber",
    "imbiberions": "imbiber",
    "imbiberons": "imbiber",
    "imbiberont": "imbiber",
    "imbibes": "imbiber",
    "imbibez": "imbiber",
    "imbibiez": "imbiber",
    "imbibions": "imbiber",
    "imbibons": "imbiber",
    "imbibâmes": "imbiber",
    "imbibât": "imbiber",
    "imbibâtes": "imbiber",
    "imbibèrent": "imbiber",
    "imbibé": "imbiber",
    "imbibée": "imbiber",
    "imbibées": "imbiber",
    "imbibés": "imbiber",
    "imbitables": "imbitable",
    "imbrications": "imbrication",
    "imbriqua": "imbriquer",
    "imbriquai": "imbriquer",
    "imbriquaient": "imbriquer",
    "imbriquais": "imbriquer",
    "imbriquait": "imbriquer",
    "imbriquant": "imbriquer",
    "imbriquas": "imbriquer",
    "imbriquasse": "imbriquer",
    "imbriquassent": "imbriquer",
    "imbriquasses": "imbriquer",
    "imbriquassiez": "imbriquer",
    "imbriquassions": "imbriquer",
    "imbrique": "imbriquer",
    "imbriquent": "imbriquer",
    "imbriquera": "imbriquer",
    "imbriquerai": "imbriquer",
    "imbriqueraient": "imbriquer",
    "imbriquerais": "imbriquer",
    "imbriquerait": "imbriquer",
    "imbriqueras": "imbriquer",
    "imbriquerez": "imbriquer",
    "imbriqueriez": "imbriquer",
    "imbriquerions": "imbriquer",
    "imbriquerons": "imbriquer",
    "imbriqueront": "imbriquer",
    "imbriques": "imbriquer",
    "imbriquez": "imbriquer",
    "imbriquiez": "imbriquer",
    "imbriquions": "imbriquer",
    "imbriquons": "imbriquer",
    "imbriquâmes": "imbriquer",
    "imbriquât": "imbriquer",
    "imbriquâtes": "imbriquer",
    "imbriquèrent": "imbriquer",
    "imbriqué": "imbriquer",
    "imbriquée": "imbriquer",
    "imbriquées": "imbriquer",
    "imbriqués": "imbriquer",
    "imbroglios": "imbroglio",
    "imbue": "imbu",
    "imbues": "imbu",
    "imbus": "imbu",
    "imbuvables": "imbuvable",
    "imbéciles": "imbécile",
    "imbécillités": "imbécillité",
    "imita": "imiter",
    "imitables": "imitable",
    "imitai": "imiter",
    "imitaient": "imiter",
    "imitais": "imiter",
    "imitait": "imiter",
    "imitant": "imiter",
    "imitas": "imiter",
    "imitasse": "imiter",
    "imitassent": "imiter",
    "imitasses": "imiter",
    "imitassiez": "imiter",
    "imitassions": "imiter",
    "imitateurs": "imitateur",
    "imitations": "imitation",
    "imitative": "imitatif",
    "imitatives": "imitatif",
    "imitatrice": "imitateur",
    "imite": "imiter",
    "imitent": "imiter",
    "imitera": "imiter",
    "imiterai": "imiter",
    "imiteraient": "imiter",
    "imiterais": "imiter",
    "imiterait": "imiter",
    "imiteras": "imiter",
    "imiterez": "imiter",
    "imiteriez": "imiter",
    "imiterions": "imiter",
    "imiterons": "imiter",
    "imiteront": "imiter",
    "imites": "imiter",
    "imitez": "imiter",
    "imitiez": "imiter",
    "imitions": "imiter",
    "imitons": "imiter",
    "imitâmes": "imiter",
    "imitât": "imiter",
    "imitâtes": "imiter",
    "imitèrent": "imiter",
    "imité": "imiter",
    "imitée": "imiter",
    "imitées": "imiter",
    "imités": "imiter",
    "immaculée": "immaculé",
    "immaculées": "immaculé",
    "immaculés": "immaculé",
    "immanences": "immanence",
    "immanente": "immanent",
    "immanentes": "immanent",
    "immanents": "immanent",
    "immangeables": "immangeable",
    "immanquables": "immanquable",
    "immatricula": "immatriculer",
    "immatriculai": "immatriculer",
    "immatriculaient": "immatriculer",
    "immatriculais": "immatriculer",
    "immatriculait": "immatriculer",
    "immatriculant": "immatriculer",
    "immatriculas": "immatriculer",
    "immatriculasse": "immatriculer",
    "immatriculassent": "immatriculer",
    "immatriculasses": "immatriculer",
    "immatriculassiez": "immatriculer",
    "immatriculassions": "immatriculer",
    "immatriculations": "immatriculation",
    "immatricule": "immatriculer",
    "immatriculent": "immatriculer",
    "immatriculera": "immatriculer",
    "immatriculerai": "immatriculer",
    "immatriculeraient": "immatriculer",
    "immatriculerais": "immatriculer",
    "immatriculerait": "immatriculer",
    "immatriculeras": "immatriculer",
    "immatriculerez": "immatriculer",
    "immatriculeriez": "immatriculer",
    "immatriculerions": "immatriculer",
    "immatriculerons": "immatriculer",
    "immatriculeront": "immatriculer",
    "immatricules": "immatriculer",
    "immatriculez": "immatriculer",
    "immatriculiez": "immatriculer",
    "immatriculions": "immatriculer",
    "immatriculons": "immatriculer",
    "immatriculâmes": "immatriculer",
    "immatriculât": "immatriculer",
    "immatriculâtes": "immatriculer",
    "immatriculèrent": "immatriculer",
    "immatriculé": "immatriculer",
    "immatriculée": "immatriculer",
    "immatriculées": "immatriculer",
    "immatriculés": "immatriculer",
    "immatures": "immature",
    "immatérielle": "immatériel",
    "immatérielles": "immatériel",
    "immatériels": "immatériel",
    "immenses": "immense",
    "immensités": "immensité",
    "immerge": "immerger",
    "immergea": "immerger",
    "immergeai": "immerger",
    "immergeaient": "immerger",
    "immergeais": "immerger",
    "immergeait": "immerger",
    "immergeant": "immerger",
    "immergeas": "immerger",
    "immergeasse": "immerger",
    "immergeassent": "immerger",
    "immergeasses": "immerger",
    "immergeassiez": "immerger",
    "immergeassions": "immerger",
    "immergent": "immerger",
    "immergeons": "immerger",
    "immergera": "immerger",
    "immergerai": "immerger",
    "immergeraient": "immerger",
    "immergerais": "immerger",
    "immergerait": "immerger",
    "immergeras": "immerger",
    "immergerez": "immerger",
    "immergeriez": "immerger",
    "immergerions": "immerger",
    "immergerons": "immerger",
    "immergeront": "immerger",
    "immerges": "immerger",
    "immergez": "immerger",
    "immergeâmes": "immerger",
    "immergeât": "immerger",
    "immergeâtes": "immerger",
    "immergiez": "immerger",
    "immergions": "immerger",
    "immergèrent": "immerger",
    "immergé": "immerger",
    "immergée": "immerger",
    "immergées": "immerger",
    "immergés": "immerger",
    "immersions": "immersion",
    "immettables": "immettable",
    "immeubles": "immeuble",
    "immigra": "immigrer",
    "immigrai": "immigrer",
    "immigraient": "immigrer",
    "immigrais": "immigrer",
    "immigrait": "immigrer",
    "immigrant": "immigrer",
    "immigrante": "immigrant",
    "immigrantes": "immigrant",
    "immigrants": "immigrant",
    "immigras": "immigrer",
    "immigrasse": "immigrer",
    "immigrassent": "immigrer",
    "immigrasses": "immigrer",
    "immigrassiez": "immigrer",
    "immigrassions": "immigrer",
    "immigrations": "immigration",
    "immigre": "immigrer",
    "immigrent": "immigrer",
    "immigrera": "immigrer",
    "immigrerai": "immigrer",
    "immigreraient": "immigrer",
    "immigrerais": "immigrer",
    "immigrerait": "immigrer",
    "immigreras": "immigrer",
    "immigrerez": "immigrer",
    "immigreriez": "immigrer",
    "immigrerions": "immigrer",
    "immigrerons": "immigrer",
    "immigreront": "immigrer",
    "immigres": "immigrer",
    "immigrez": "immigrer",
    "immigriez": "immigrer",
    "immigrions": "immigrer",
    "immigrons": "immigrer",
    "immigrâmes": "immigrer",
    "immigrât": "immigrer",
    "immigrâtes": "immigrer",
    "immigrèrent": "immigrer",
    "immigré": "immigrer",
    "immigrée": "immigrer",
    "immigrées": "immigrer",
    "immigrés": "immigrer",
    "imminences": "imminence",
    "imminente": "imminent",
    "imminentes": "imminent",
    "imminents": "imminent",
    "immisce": "immiscer",
    "immiscent": "immiscer",
    "immiscera": "immiscer",
    "immiscerai": "immiscer",
    "immisceraient": "immiscer",
    "immiscerais": "immiscer",
    "immiscerait": "immiscer",
    "immisceras": "immiscer",
    "immiscerez": "immiscer",
    "immisceriez": "immiscer",
    "immiscerions": "immiscer",
    "immiscerons": "immiscer",
    "immisceront": "immiscer",
    "immisces": "immiscer",
    "immiscez": "immiscer",
    "immiscibles": "immiscible",
    "immisciez": "immiscer",
    "immiscions": "immiscer",
    "immiscèrent": "immiscer",
    "immiscé": "immiscer",
    "immiscée": "immiscer",
    "immiscées": "immiscer",
    "immiscés": "immiscer",
    "immisça": "immiscer",
    "immisçai": "immiscer",
    "immisçaient": "immiscer",
    "immisçais": "immiscer",
    "immisçait": "immiscer",
    "immisçant": "immiscer",
    "immisças": "immiscer",
    "immisçasse": "immiscer",
    "immisçassent": "immiscer",
    "immisçasses": "immiscer",
    "immisçassiez": "immiscer",
    "immisçassions": "immiscer",
    "immisçons": "immiscer",
    "immisçâmes": "immiscer",
    "immisçât": "immiscer",
    "immisçâtes": "immiscer",
    "immixtions": "immixtion",
    "immobiles": "immobile",
    "immobiliers": "immobilier",
    "immobilisa": "immobiliser",
    "immobilisai": "immobiliser",
    "immobilisaient": "immobiliser",
    "immobilisais": "immobiliser",
    "immobilisait": "immobiliser",
    "immobilisant": "immobiliser",
    "immobilisas": "immobiliser",
    "immobilisasse": "immobiliser",
    "immobilisassent": "immobiliser",
    "immobilisasses": "immobiliser",
    "immobilisassiez": "immobiliser",
    "immobilisassions": "immobiliser",
    "immobilisations": "immobilisation",
    "immobilise": "immobiliser",
    "immobilisent": "immobiliser",
    "immobilisera": "immobiliser",
    "immobiliserai": "immobiliser",
    "immobiliseraient": "immobiliser",
    "immobiliserais": "immobiliser",
    "immobiliserait": "immobiliser",
    "immobiliseras": "immobiliser",
    "immobiliserez": "immobiliser",
    "immobiliseriez": "immobiliser",
    "immobiliserions": "immobiliser",
    "immobiliserons": "immobiliser",
    "immobiliseront": "immobiliser",
    "immobilises": "immobiliser",
    "immobilisez": "immobiliser",
    "immobilisiez": "immobiliser",
    "immobilisions": "immobiliser",
    "immobilismes": "immobilisme",
    "immobilisons": "immobiliser",
    "immobilisâmes": "immobiliser",
    "immobilisât": "immobiliser",
    "immobilisâtes": "immobiliser",
    "immobilisèrent": "immobiliser",
    "immobilisé": "immobiliser",
    "immobilisée": "immobiliser",
    "immobilisées": "immobiliser",
    "immobilisés": "immobiliser",
    "immobilités": "immobilité",
    "immobilière": "immobilier",
    "immobilières": "immobilier",
    "immodestes": "immodeste",
    "immodérée": "immodéré",
    "immodérées": "immodéré",
    "immodérés": "immodéré",
    "immola": "immoler",
    "immolai": "immoler",
    "immolaient": "immoler",
    "immolais": "immoler",
    "immolait": "immoler",
    "immolant": "immoler",
    "immolas": "immoler",
    "immolasse": "immoler",
    "immolassent": "immoler",
    "immolasses": "immoler",
    "immolassiez": "immoler",
    "immolassions": "immoler",
    "immolations": "immolation",
    "immole": "immoler",
    "immolent": "immoler",
    "immolera": "immoler",
    "immolerai": "immoler",
    "immoleraient": "immoler",
    "immolerais": "immoler",
    "immolerait": "immoler",
    "immoleras": "immoler",
    "immolerez": "immoler",
    "immoleriez": "immoler",
    "immolerions": "immoler",
    "immolerons": "immoler",
    "immoleront": "immoler",
    "immoles": "immoler",
    "immolez": "immoler",
    "immoliez": "immoler",
    "immolions": "immoler",
    "immolons": "immoler",
    "immolâmes": "immoler",
    "immolât": "immoler",
    "immolâtes": "immoler",
    "immolèrent": "immoler",
    "immolé": "immoler",
    "immolée": "immoler",
    "immolées": "immoler",
    "immolés": "immoler",
    "immondes": "immonde",
    "immondices": "immondice",
    "immorale": "immoral",
    "immorales": "immoral",
    "immoraux": "immoral",
    "immortalisa": "immortaliser",
    "immortalisai": "immortaliser",
    "immortalisaient": "immortaliser",
    "immortalisais": "immortaliser",
    "immortalisait": "immortaliser",
    "immortalisant": "immortaliser",
    "immortalisas": "immortaliser",
    "immortalisasse": "immortaliser",
    "immortalisassent": "immortaliser",
    "immortalisasses": "immortaliser",
    "immortalisassiez": "immortaliser",
    "immortalisassions": "immortaliser",
    "immortalise": "immortaliser",
    "immortalisent": "immortaliser",
    "immortalisera": "immortaliser",
    "immortaliserai": "immortaliser",
    "immortaliseraient": "immortaliser",
    "immortaliserais": "immortaliser",
    "immortaliserait": "immortaliser",
    "immortaliseras": "immortaliser",
    "immortaliserez": "immortaliser",
    "immortaliseriez": "immortaliser",
    "immortaliserions": "immortaliser",
    "immortaliserons": "immortaliser",
    "immortaliseront": "immortaliser",
    "immortalises": "immortaliser",
    "immortalisez": "immortaliser",
    "immortalisiez": "immortaliser",
    "immortalisions": "immortaliser",
    "immortalisons": "immortaliser",
    "immortalisâmes": "immortaliser",
    "immortalisât": "immortaliser",
    "immortalisâtes": "immortaliser",
    "immortalisèrent": "immortaliser",
    "immortalisé": "immortaliser",
    "immortalisée": "immortaliser",
    "immortalisées": "immortaliser",
    "immortalisés": "immortaliser",
    "immortalités": "immortalité",
    "immortelle": "immortel",
    "immortelles": "immortel",
    "immortels": "immortel",
    "immortifiées": "immortifié",
    "immotivée": "immotivé",
    "immotivés": "immotivé",
    "immuables": "immuable",
    "immune": "immun",
    "immunisa": "immuniser",
    "immunisai": "immuniser",
    "immunisaient": "immuniser",
    "immunisais": "immuniser",
    "immunisait": "immuniser",
    "immunisant": "immuniser",
    "immunisas": "immuniser",
    "immunisasse": "immuniser",
    "immunisassent": "immuniser",
    "immunisasses": "immuniser",
    "immunisassiez": "immuniser",
    "immunisassions": "immuniser",
    "immunisations": "immunisation",
    "immunise": "immuniser",
    "immunisent": "immuniser",
    "immunisera": "immuniser",
    "immuniserai": "immuniser",
    "immuniseraient": "immuniser",
    "immuniserais": "immuniser",
    "immuniserait": "immuniser",
    "immuniseras": "immuniser",
    "immuniserez": "immuniser",
    "immuniseriez": "immuniser",
    "immuniserions": "immuniser",
    "immuniserons": "immuniser",
    "immuniseront": "immuniser",
    "immunises": "immuniser",
    "immunisez": "immuniser",
    "immunisiez": "immuniser",
    "immunisions": "immuniser",
    "immunisons": "immuniser",
    "immunisâmes": "immuniser",
    "immunisât": "immuniser",
    "immunisâtes": "immuniser",
    "immunisèrent": "immuniser",
    "immunisé": "immuniser",
    "immunisée": "immuniser",
    "immunisées": "immuniser",
    "immunisés": "immuniser",
    "immunitaires": "immunitaire",
    "immunités": "immunité",
    "immunobiologies": "immunobiologie",
    "immunologiques": "immunologique",
    "immédiate": "immédiat",
    "immédiates": "immédiat",
    "immédiatetés": "immédiateté",
    "immédiats": "immédiat",
    "immémoriale": "immémorial",
    "immémoriales": "immémorial",
    "immémoriaux": "immémorial",
    "imméritée": "immérité",
    "imméritées": "immérité",
    "immérités": "immérité",
    "impacts": "impact",
    "impaire": "impair",
    "impaires": "impair",
    "impairs": "impair",
    "impalas": "impala",
    "impalpables": "impalpable",
    "imparables": "imparable",
    "impardonnables": "impardonnable",
    "imparfaite": "imparfait",
    "imparfaites": "imparfait",
    "imparfaits": "imparfait",
    "impartageables": "impartageable",
    "imparti": "impartir",
    "impartiale": "impartial",
    "impartiales": "impartial",
    "impartialités": "impartialité",
    "impartiaux": "impartial",
    "impartie": "impartir",
    "imparties": "impartir",
    "impartira": "impartir",
    "impartirai": "impartir",
    "impartiraient": "impartir",
    "impartirais": "impartir",
    "impartirait": "impartir",
    "impartiras": "impartir",
    "impartirent": "impartir",
    "impartirez": "impartir",
    "impartiriez": "impartir",
    "impartirions": "impartir",
    "impartirons": "impartir",
    "impartiront": "impartir",
    "impartis": "impartir",
    "impartissaient": "impartir",
    "impartissais": "impartir",
    "impartissait": "impartir",
    "impartissant": "impartir",
    "impartisse": "impartir",
    "impartissent": "impartir",
    "impartisses": "impartir",
    "impartissez": "impartir",
    "impartissiez": "impartir",
    "impartissions": "impartir",
    "impartissons": "impartir",
    "impartit": "impartir",
    "impartîmes": "impartir",
    "impartît": "impartir",
    "impartîtes": "impartir",
    "impasses": "impasse",
    "impassibilités": "impassibilité",
    "impassibles": "impassible",
    "impatiences": "impatience",
    "impatienta": "impatienter",
    "impatientai": "impatienter",
    "impatientaient": "impatienter",
    "impatientais": "impatienter",
    "impatientait": "impatienter",
    "impatientant": "impatienter",
    "impatiente": "impatienter",
    "impatientent": "impatienter",
    "impatienterait": "impatienter",
    "impatientes": "impatienter",
    "impatientez": "impatienter",
    "impatients": "impatient",
    "impatientèrent": "impatienter",
    "impatienté": "impatienter",
    "impatientée": "impatienter",
    "impatientées": "impatienté",
    "impatientés": "impatienter",
    "impatronisa": "impatroniser",
    "impatronisai": "impatroniser",
    "impatronisaient": "impatroniser",
    "impatronisais": "impatroniser",
    "impatronisait": "impatroniser",
    "impatronisant": "impatroniser",
    "impatronisas": "impatroniser",
    "impatronisasse": "impatroniser",
    "impatronisassent": "impatroniser",
    "impatronisasses": "impatroniser",
    "impatronisassiez": "impatroniser",
    "impatronisassions": "impatroniser",
    "impatronise": "impatroniser",
    "impatronisent": "impatroniser",
    "impatronisera": "impatroniser",
    "impatroniserai": "impatroniser",
    "impatroniseraient": "impatroniser",
    "impatroniserais": "impatroniser",
    "impatroniserait": "impatroniser",
    "impatroniseras": "impatroniser",
    "impatroniserez": "impatroniser",
    "impatroniseriez": "impatroniser",
    "impatroniserions": "impatroniser",
    "impatroniserons": "impatroniser",
    "impatroniseront": "impatroniser",
    "impatronises": "impatroniser",
    "impatronisez": "impatroniser",
    "impatronisiez": "impatroniser",
    "impatronisions": "impatroniser",
    "impatronisons": "impatroniser",
    "impatronisâmes": "impatroniser",
    "impatronisât": "impatroniser",
    "impatronisâtes": "impatroniser",
    "impatronisèrent": "impatroniser",
    "impatronisé": "impatroniser",
    "impatronisée": "impatroniser",
    "impatronisées": "impatroniser",
    "impatronisés": "impatroniser",
    "impavides": "impavide",
    "impayables": "impayable",
    "impayée": "impayé",
    "impayées": "impayé",
    "impayés": "impayé",
    "impeccables": "impeccable",
    "impensables": "impensable",
    "imperceptibles": "imperceptible",
    "imperdables": "imperdable",
    "imperfectibles": "imperfectible",
    "imperfections": "imperfection",
    "imperméabilisé": "imperméabiliser",
    "imperméabilités": "imperméabilité",
    "imperméables": "imperméable",
    "impers": "imper",
    "impersonnalités": "impersonnalité",
    "impersonnelle": "impersonnel",
    "impersonnelles": "impersonnel",
    "impersonnels": "impersonnel",
    "impertinences": "impertinence",
    "impertinente": "impertinent",
    "impertinentes": "impertinent",
    "impertinents": "impertinent",
    "imperturbables": "imperturbable",
    "impies": "impie",
    "impitoyables": "impitoyable",
    "impiétés": "impiété",
    "implacables": "implacable",
    "implanta": "implanter",
    "implantables": "implantable",
    "implantai": "implanter",
    "implantaient": "implanter",
    "implantais": "implanter",
    "implantait": "implanter",
    "implantant": "implanter",
    "implantas": "implanter",
    "implantasse": "implanter",
    "implantassent": "implanter",
    "implantasses": "implanter",
    "implantassiez": "implanter",
    "implantassions": "implanter",
    "implantations": "implantation",
    "implante": "implanter",
    "implantent": "implanter",
    "implantera": "implanter",
    "implanterai": "implanter",
    "implanteraient": "implanter",
    "implanterais": "implanter",
    "implanterait": "implanter",
    "implanteras": "implanter",
    "implanterez": "implanter",
    "implanteriez": "implanter",
    "implanterions": "implanter",
    "implanterons": "implanter",
    "implanteront": "implanter",
    "implantes": "implanter",
    "implantez": "implanter",
    "implantiez": "implanter",
    "implantions": "implanter",
    "implantons": "implanter",
    "implants": "implant",
    "implantâmes": "implanter",
    "implantât": "implanter",
    "implantâtes": "implanter",
    "implantèrent": "implanter",
    "implanté": "implanter",
    "implantée": "implanter",
    "implantées": "implanter",
    "implantés": "implanter",
    "implications": "implication",
    "implicites": "implicite",
    "impliqua": "impliquer",
    "impliquai": "impliquer",
    "impliquaient": "impliquer",
    "impliquais": "impliquer",
    "impliquait": "impliquer",
    "impliquant": "impliquer",
    "impliquas": "impliquer",
    "impliquasse": "impliquer",
    "impliquassent": "impliquer",
    "impliquasses": "impliquer",
    "impliquassiez": "impliquer",
    "impliquassions": "impliquer",
    "implique": "impliquer",
    "impliquent": "impliquer",
    "impliquera": "impliquer",
    "impliquerai": "impliquer",
    "impliqueraient": "impliquer",
    "impliquerais": "impliquer",
    "impliquerait": "impliquer",
    "impliqueras": "impliquer",
    "impliquerez": "impliquer",
    "impliqueriez": "impliquer",
    "impliquerions": "impliquer",
    "impliquerons": "impliquer",
    "impliqueront": "impliquer",
    "impliques": "impliquer",
    "impliquez": "impliquer",
    "impliquiez": "impliquer",
    "impliquions": "impliquer",
    "impliquons": "impliquer",
    "impliquâmes": "impliquer",
    "impliquât": "impliquer",
    "impliquâtes": "impliquer",
    "impliquèrent": "impliquer",
    "impliqué": "impliquer",
    "impliquée": "impliquer",
    "impliquées": "impliquer",
    "impliqués": "impliquer",
    "implora": "implorer",
    "implorai": "implorer",
    "imploraient": "implorer",
    "implorais": "implorer",
    "implorait": "implorer",
    "implorant": "implorer",
    "implorante": "implorant",
    "implorantes": "implorant",
    "implorants": "implorant",
    "imploras": "implorer",
    "implorasse": "implorer",
    "implorassent": "implorer",
    "implorasses": "implorer",
    "implorassiez": "implorer",
    "implorassions": "implorer",
    "implorations": "imploration",
    "implore": "implorer",
    "implorent": "implorer",
    "implorera": "implorer",
    "implorerai": "implorer",
    "imploreraient": "implorer",
    "implorerais": "implorer",
    "implorerait": "implorer",
    "imploreras": "implorer",
    "implorerez": "implorer",
    "imploreriez": "implorer",
    "implorerions": "implorer",
    "implorerons": "implorer",
    "imploreront": "implorer",
    "implores": "implorer",
    "implorez": "implorer",
    "imploriez": "implorer",
    "implorions": "implorer",
    "implorons": "implorer",
    "implorâmes": "implorer",
    "implorât": "implorer",
    "implorâtes": "implorer",
    "implorèrent": "implorer",
    "imploré": "implorer",
    "implorée": "implorer",
    "implorées": "implorer",
    "implorés": "implorer",
    "implosa": "imploser",
    "implosai": "imploser",
    "implosaient": "imploser",
    "implosais": "imploser",
    "implosait": "imploser",
    "implosant": "imploser",
    "implosas": "imploser",
    "implosasse": "imploser",
    "implosassent": "imploser",
    "implosasses": "imploser",
    "implosassiez": "imploser",
    "implosassions": "imploser",
    "implose": "imploser",
    "implosent": "imploser",
    "implosera": "imploser",
    "imploserai": "imploser",
    "imploseraient": "imploser",
    "imploserais": "imploser",
    "imploserait": "imploser",
    "imploseras": "imploser",
    "imploserez": "imploser",
    "imploseriez": "imploser",
    "imploserions": "imploser",
    "imploserons": "imploser",
    "imploseront": "imploser",
    "imploses": "imploser",
    "implosez": "imploser",
    "implosiez": "imploser",
    "implosifs": "implosif",
    "implosions": "implosion",
    "implosives": "implosif",
    "implosons": "imploser",
    "implosâmes": "imploser",
    "implosât": "imploser",
    "implosâtes": "imploser",
    "implosèrent": "imploser",
    "implosé": "imploser",
    "impluviosités": "impluviosité",
    "impolie": "impoli",
    "impolies": "impoli",
    "impolis": "impoli",
    "impolitesses": "impolitesse",
    "impolitiques": "impolitique",
    "impolluée": "impollué",
    "impolluées": "impollué",
    "impollués": "impollué",
    "impondérables": "impondérable",
    "impopulaires": "impopulaire",
    "impopularités": "impopularité",
    "importa": "importer",
    "importables": "importable",
    "importai": "importer",
    "importaient": "importer",
    "importais": "importer",
    "importait": "importer",
    "importances": "importance",
    "important": "importer",
    "importante": "important",
    "importantes": "important",
    "importants": "important",
    "importas": "importer",
    "importasse": "importer",
    "importassent": "importer",
    "importasses": "importer",
    "importassiez": "importer",
    "importassions": "importer",
    "importateurs": "importateur",
    "importations": "importation",
    "importatrice": "importateur",
    "importatrices": "importateur",
    "importe": "importer",
    "importent": "importer",
    "importera": "importer",
    "importerai": "importer",
    "importeraient": "importer",
    "importerais": "importer",
    "importerait": "importer",
    "importeras": "importer",
    "importerez": "importer",
    "importeriez": "importer",
    "importerions": "importer",
    "importerons": "importer",
    "importeront": "importer",
    "importes": "importer",
    "importez": "importer",
    "importiez": "importer",
    "importions": "importer",
    "importons": "importer",
    "imports": "import",
    "importuna": "importuner",
    "importunaient": "importuner",
    "importunais": "importuner",
    "importunait": "importuner",
    "importune": "importuner",
    "importunent": "importuner",
    "importunerai": "importuner",
    "importunerait": "importuner",
    "importunerez": "importuner",
    "importunerons": "importuner",
    "importunes": "importuner",
    "importunez": "importuner",
    "importunités": "importunité",
    "importuns": "importun",
    "importunât": "importuner",
    "importuné": "importuner",
    "importunée": "importuner",
    "importunés": "importuner",
    "importâmes": "importer",
    "importât": "importer",
    "importâtes": "importer",
    "importèrent": "importer",
    "importé": "importer",
    "importée": "importer",
    "importées": "importer",
    "importés": "importer",
    "imposa": "imposer",
    "imposables": "imposable",
    "imposai": "imposer",
    "imposaient": "imposer",
    "imposais": "imposer",
    "imposait": "imposer",
    "imposant": "imposer",
    "imposante": "imposant",
    "imposantes": "imposant",
    "imposants": "imposant",
    "imposas": "imposer",
    "imposasse": "imposer",
    "imposassent": "imposer",
    "imposasses": "imposer",
    "imposassiez": "imposer",
    "imposassions": "imposer",
    "impose": "imposer",
    "imposent": "imposer",
    "imposera": "imposer",
    "imposerai": "imposer",
    "imposeraient": "imposer",
    "imposerais": "imposer",
    "imposerait": "imposer",
    "imposeras": "imposer",
    "imposerez": "imposer",
    "imposeriez": "imposer",
    "imposerions": "imposer",
    "imposerons": "imposer",
    "imposeront": "imposer",
    "imposes": "imposer",
    "imposez": "imposer",
    "imposiez": "imposer",
    "imposions": "imposer",
    "impositions": "imposition",
    "imposons": "imposer",
    "impossibilités": "impossibilité",
    "impossibles": "impossible",
    "impostes": "imposte",
    "imposteurs": "imposteur",
    "impostures": "imposture",
    "imposâmes": "imposer",
    "imposât": "imposer",
    "imposâtes": "imposer",
    "imposèrent": "imposer",
    "imposé": "imposer",
    "imposée": "imposer",
    "imposées": "imposer",
    "imposés": "imposer",
    "impotences": "impotence",
    "impotente": "impotent",
    "impotentes": "impotent",
    "impotents": "impotent",
    "impraticables": "impraticable",
    "imprenables": "imprenable",
    "impresarii": "impresario",
    "impresarios": "impresario",
    "imprescriptibles": "imprescriptible",
    "impressionna": "impressionner",
    "impressionnables": "impressionnable",
    "impressionnai": "impressionner",
    "impressionnaient": "impressionner",
    "impressionnais": "impressionner",
    "impressionnait": "impressionner",
    "impressionnant": "impressionner",
    "impressionnante": "impressionnant",
    "impressionnantes": "impressionnant",
    "impressionnants": "impressionnant",
    "impressionnas": "impressionner",
    "impressionnasse": "impressionner",
    "impressionnassent": "impressionner",
    "impressionnasses": "impressionner",
    "impressionnassiez": "impressionner",
    "impressionnassions": "impressionner",
    "impressionne": "impressionner",
    "impressionnent": "impressionner",
    "impressionnera": "impressionner",
    "impressionnerai": "impressionner",
    "impressionneraient": "impressionner",
    "impressionnerais": "impressionner",
    "impressionnerait": "impressionner",
    "impressionneras": "impressionner",
    "impressionnerez": "impressionner",
    "impressionneriez": "impressionner",
    "impressionnerions": "impressionner",
    "impressionnerons": "impressionner",
    "impressionneront": "impressionner",
    "impressionnes": "impressionner",
    "impressionnez": "impressionner",
    "impressionniez": "impressionner",
    "impressionnions": "impressionner",
    "impressionnistes": "impressionniste",
    "impressionnons": "impressionner",
    "impressionnâmes": "impressionner",
    "impressionnât": "impressionner",
    "impressionnâtes": "impressionner",
    "impressionnèrent": "impressionner",
    "impressionné": "impressionner",
    "impressionnée": "impressionner",
    "impressionnées": "impressionner",
    "impressionnés": "impressionner",
    "impressions": "impression",
    "impressive": "impressif",
    "imprima": "imprimer",
    "imprimai": "imprimer",
    "imprimaient": "imprimer",
    "imprimais": "imprimer",
    "imprimait": "imprimer",
    "imprimant": "imprimer",
    "imprimantes": "imprimante",
    "imprimas": "imprimer",
    "imprimasse": "imprimer",
    "imprimassent": "imprimer",
    "imprimasses": "imprimer",
    "imprimassiez": "imprimer",
    "imprimassions": "imprimer",
    "imprimaturs": "imprimatur",
    "imprime": "imprimer",
    "impriment": "imprimer",
    "imprimera": "imprimer",
    "imprimerai": "imprimer",
    "imprimeraient": "imprimer",
    "imprimerais": "imprimer",
    "imprimerait": "imprimer",
    "imprimeras": "imprimer",
    "imprimerez": "imprimer",
    "imprimeries": "imprimerie",
    "imprimeriez": "imprimer",
    "imprimerions": "imprimer",
    "imprimerons": "imprimer",
    "imprimeront": "imprimer",
    "imprimes": "imprimer",
    "imprimeurs": "imprimeur",
    "imprimez": "imprimer",
    "imprimiez": "imprimer",
    "imprimions": "imprimer",
    "imprimons": "imprimer",
    "imprimâmes": "imprimer",
    "imprimât": "imprimer",
    "imprimâtes": "imprimer",
    "imprimèrent": "imprimer",
    "imprimé": "imprimer",
    "imprimée": "imprimer",
    "imprimées": "imprimer",
    "imprimés": "imprimer",
    "improbables": "improbable",
    "improbités": "improbité",
    "improductifs": "improductif",
    "improductive": "improductif",
    "improductives": "improductif",
    "impromptue": "impromptu",
    "impromptues": "impromptu",
    "impromptus": "impromptu",
    "imprononçables": "imprononçable",
    "impropres": "impropre",
    "impropriétés": "impropriété",
    "improuva": "improuver",
    "improuvables": "improuvable",
    "improuvai": "improuver",
    "improuvaient": "improuver",
    "improuvais": "improuver",
    "improuvait": "improuver",
    "improuvant": "improuver",
    "improuvas": "improuver",
    "improuvasse": "improuver",
    "improuvassent": "improuver",
    "improuvasses": "improuver",
    "improuvassiez": "improuver",
    "improuvassions": "improuver",
    "improuve": "improuver",
    "improuvent": "improuver",
    "improuvera": "improuver",
    "improuverai": "improuver",
    "improuveraient": "improuver",
    "improuverais": "improuver",
    "improuverait": "improuver",
    "improuveras": "improuver",
    "improuverez": "improuver",
    "improuveriez": "improuver",
    "improuverions": "improuver",
    "improuverons": "improuver",
    "improuveront": "improuver",
    "improuves": "improuver",
    "improuvez": "improuver",
    "improuviez": "improuver",
    "improuvions": "improuver",
    "improuvons": "improuver",
    "improuvâmes": "improuver",
    "improuvât": "improuver",
    "improuvâtes": "improuver",
    "improuvèrent": "improuver",
    "improuvé": "improuver",
    "improuvée": "improuver",
    "improuvées": "improuver",
    "improuvés": "improuver",
    "improvisa": "improviser",
    "improvisai": "improviser",
    "improvisaient": "improviser",
    "improvisais": "improviser",
    "improvisait": "improviser",
    "improvisant": "improviser",
    "improvisas": "improviser",
    "improvisasse": "improviser",
    "improvisassent": "improviser",
    "improvisasses": "improviser",
    "improvisassiez": "improviser",
    "improvisassions": "improviser",
    "improvisateurs": "improvisateur",
    "improvisations": "improvisation",
    "improvise": "improviser",
    "improvisent": "improviser",
    "improvisera": "improviser",
    "improviserai": "improviser",
    "improviseraient": "improviser",
    "improviserais": "improviser",
    "improviserait": "improviser",
    "improviseras": "improviser",
    "improviserez": "improviser",
    "improviseriez": "improviser",
    "improviserions": "improviser",
    "improviserons": "improviser",
    "improviseront": "improviser",
    "improvises": "improviser",
    "improvisez": "improviser",
    "improvisiez": "improviser",
    "improvisions": "improviser",
    "improvisons": "improviser",
    "improvisâmes": "improviser",
    "improvisât": "improviser",
    "improvisâtes": "improviser",
    "improvisèrent": "improviser",
    "improvisé": "improviser",
    "improvisée": "improviser",
    "improvisées": "improviser",
    "improvisés": "improviser",
    "imprudences": "imprudence",
    "imprudente": "imprudent",
    "imprudentes": "imprudent",
    "imprudents": "imprudent",
    "imprègne": "imprégner",
    "imprègnent": "imprégner",
    "imprègnes": "imprégner",
    "imprécations": "imprécation",
    "imprécisables": "imprécisable",
    "imprécise": "imprécis",
    "imprécises": "imprécis",
    "imprécisions": "imprécision",
    "imprégna": "imprégner",
    "imprégnai": "imprégner",
    "imprégnaient": "imprégner",
    "imprégnais": "imprégner",
    "imprégnait": "imprégner",
    "imprégnant": "imprégner",
    "imprégnas": "imprégner",
    "imprégnasse": "imprégner",
    "imprégnassent": "imprégner",
    "imprégnasses": "imprégner",
    "imprégnassiez": "imprégner",
    "imprégnassions": "imprégner",
    "imprégnations": "imprégnation",
    "imprégnera": "imprégner",
    "imprégnerai": "imprégner",
    "imprégneraient": "imprégner",
    "imprégnerais": "imprégner",
    "imprégnerait": "imprégner",
    "imprégneras": "imprégner",
    "imprégnerez": "imprégner",
    "imprégneriez": "imprégner",
    "imprégnerions": "imprégner",
    "imprégnerons": "imprégner",
    "imprégneront": "imprégner",
    "imprégnez": "imprégner",
    "imprégniez": "imprégner",
    "imprégnions": "imprégner",
    "imprégnons": "imprégner",
    "imprégnâmes": "imprégner",
    "imprégnât": "imprégner",
    "imprégnâtes": "imprégner",
    "imprégnèrent": "imprégner",
    "imprégné": "imprégner",
    "imprégnée": "imprégner",
    "imprégnées": "imprégner",
    "imprégnés": "imprégner",
    "impréparations": "impréparation",
    "imprésarios": "imprésario",
    "imprésentables": "imprésentable",
    "imprévisibilités": "imprévisibilité",
    "imprévisibles": "imprévisible",
    "imprévoyances": "imprévoyance",
    "imprévoyante": "imprévoyant",
    "imprévoyantes": "imprévoyant",
    "imprévoyants": "imprévoyant",
    "imprévue": "imprévu",
    "imprévues": "imprévu",
    "imprévus": "imprévu",
    "impubliables": "impubliable",
    "impubères": "impubère",
    "impudences": "impudence",
    "impudente": "impudent",
    "impudentes": "impudent",
    "impudents": "impudent",
    "impudeurs": "impudeur",
    "impudiques": "impudique",
    "impuissances": "impuissance",
    "impuissante": "impuissant",
    "impuissantes": "impuissant",
    "impuissants": "impuissant",
    "impulsa": "impulser",
    "impulsai": "impulser",
    "impulsaient": "impulser",
    "impulsais": "impulser",
    "impulsait": "impulser",
    "impulsant": "impulser",
    "impulsas": "impulser",
    "impulsasse": "impulser",
    "impulsassent": "impulser",
    "impulsasses": "impulser",
    "impulsassiez": "impulser",
    "impulsassions": "impulser",
    "impulse": "impulser",
    "impulsent": "impulser",
    "impulsera": "impulser",
    "impulserai": "impulser",
    "impulseraient": "impulser",
    "impulserais": "impulser",
    "impulserait": "impulser",
    "impulseras": "impulser",
    "impulserez": "impulser",
    "impulseriez": "impulser",
    "impulserions": "impulser",
    "impulserons": "impulser",
    "impulseront": "impulser",
    "impulses": "impulser",
    "impulsez": "impulser",
    "impulsiez": "impulser",
    "impulsifs": "impulsif",
    "impulsions": "impulsion",
    "impulsive": "impulsif",
    "impulsives": "impulsif",
    "impulsons": "impulser",
    "impulsâmes": "impulser",
    "impulsât": "impulser",
    "impulsâtes": "impulser",
    "impulsèrent": "impulser",
    "impulsé": "impulser",
    "impulsée": "impulser",
    "impulsées": "impulser",
    "impulsés": "impulser",
    "impunie": "impuni",
    "impunies": "impuni",
    "impunis": "impuni",
    "impunités": "impunité",
    "impure": "impur",
    "impures": "impur",
    "impuretés": "impureté",
    "impurs": "impur",
    "imputa": "imputer",
    "imputables": "imputable",
    "imputai": "imputer",
    "imputaient": "imputer",
    "imputais": "imputer",
    "imputait": "imputer",
    "imputant": "imputer",
    "imputas": "imputer",
    "imputasse": "imputer",
    "imputassent": "imputer",
    "imputasses": "imputer",
    "imputassiez": "imputer",
    "imputassions": "imputer",
    "imputations": "imputation",
    "impute": "imputer",
    "imputent": "imputer",
    "imputera": "imputer",
    "imputerai": "imputer",
    "imputeraient": "imputer",
    "imputerais": "imputer",
    "imputerait": "imputer",
    "imputeras": "imputer",
    "imputerez": "imputer",
    "imputeriez": "imputer",
    "imputerions": "imputer",
    "imputerons": "imputer",
    "imputeront": "imputer",
    "imputes": "imputer",
    "imputez": "imputer",
    "imputiez": "imputer",
    "imputions": "imputer",
    "imputons": "imputer",
    "imputrescibles": "imputrescible",
    "imputâmes": "imputer",
    "imputât": "imputer",
    "imputâtes": "imputer",
    "imputèrent": "imputer",
    "imputé": "imputer",
    "imputée": "imputer",
    "imputées": "imputer",
    "imputés": "imputer",
    "impécunieuse": "impécunieux",
    "impécunieuses": "impécunieux",
    "impénitente": "impénitent",
    "impénitentes": "impénitent",
    "impénitents": "impénitent",
    "impénétrables": "impénétrable",
    "impératifs": "impératif",
    "impérative": "impératif",
    "impératives": "impératif",
    "impératrices": "impératrice",
    "impériale": "impérial",
    "impériales": "impériale",
    "impérialismes": "impérialisme",
    "impérialistes": "impérialiste",
    "impériaux": "impérial",
    "impérieuse": "impérieux",
    "impérieuses": "impérieux",
    "impérissables": "impérissable",
    "impérities": "impéritie",
    "impétigos": "impétigo",
    "impétrante": "impétrant",
    "impétrantes": "impétrant",
    "impétrants": "impétrant",
    "impétueuse": "impétueux",
    "impétueuses": "impétueux",
    "impétuosités": "impétuosité",
    "impôts": "impôt",
    "in-folios": "in-folio",
    "in-octavos": "in-octavo",
    "in-quartos": "in-quarto",
    "inabordables": "inabordable",
    "inaboutie": "inabouti",
    "inacceptables": "inacceptable",
    "inaccessibilités": "inaccessibilité",
    "inaccessibles": "inaccessible",
    "inaccomplis": "inaccompli",
    "inaccomplissements": "inaccomplissement",
    "inaccoutumée": "inaccoutumé",
    "inaccoutumées": "inaccoutumé",
    "inaccoutumés": "inaccoutumé",
    "inachevée": "inachevé",
    "inachevées": "inachevé",
    "inachevés": "inachevé",
    "inactifs": "inactif",
    "inactions": "inaction",
    "inactive": "inactif",
    "inactives": "inactif",
    "inactivités": "inactivité",
    "inadaptations": "inadaptation",
    "inadaptée": "inadapté",
    "inadaptées": "inadapté",
    "inadaptés": "inadapté",
    "inadmissibilités": "inadmissibilité",
    "inadmissibles": "inadmissible",
    "inadvertances": "inadvertance",
    "inadéquate": "inadéquat",
    "inadéquates": "inadéquat",
    "inadéquations": "inadéquation",
    "inadéquats": "inadéquat",
    "inaliénables": "inaliénable",
    "inaltérables": "inaltérable",
    "inaltérée": "inaltéré",
    "inaltérées": "inaltéré",
    "inaltérés": "inaltéré",
    "inamicale": "inamical",
    "inamicales": "inamical",
    "inamicaux": "inamical",
    "inamovibles": "inamovible",
    "inanalysables": "inanalysable",
    "inanimée": "inanimé",
    "inanimées": "inanimé",
    "inanimés": "inanimé",
    "inanitions": "inanition",
    "inanités": "inanité",
    "inapaisables": "inapaisable",
    "inapaisée": "inapaisé",
    "inapaisées": "inapaisé",
    "inapaisés": "inapaisé",
    "inaperçue": "inaperçu",
    "inaperçues": "inaperçu",
    "inaperçus": "inaperçu",
    "inapparente": "inapparent",
    "inapparentes": "inapparent",
    "inapparents": "inapparent",
    "inapplicables": "inapplicable",
    "inappliquée": "inappliqué",
    "inappliquées": "inappliqué",
    "inappliqués": "inappliqué",
    "inapprivoisables": "inapprivoisable",
    "inappropriée": "inapproprié",
    "inappropriées": "inapproprié",
    "inappropriés": "inapproprié",
    "inappréciables": "inappréciable",
    "inappréciée": "inapprécié",
    "inappréciées": "inapprécié",
    "inappréciés": "inapprécié",
    "inappétences": "inappétence",
    "inaptes": "inapte",
    "inaptitudes": "inaptitude",
    "inarticulée": "inarticulé",
    "inarticulées": "inarticulé",
    "inarticulés": "inarticulé",
    "inassimilables": "inassimilable",
    "inassouvie": "inassouvi",
    "inassouvies": "inassouvi",
    "inassouvis": "inassouvi",
    "inassouvissables": "inassouvissable",
    "inattaquables": "inattaquable",
    "inatteignables": "inatteignable",
    "inattendue": "inattendu",
    "inattendues": "inattendu",
    "inattendus": "inattendu",
    "inattentifs": "inattentif",
    "inattentions": "inattention",
    "inattentive": "inattentif",
    "inattentives": "inattentif",
    "inaudibles": "inaudible",
    "inaugura": "inaugurer",
    "inaugurai": "inaugurer",
    "inauguraient": "inaugurer",
    "inaugurais": "inaugurer",
    "inaugurait": "inaugurer",
    "inaugurale": "inaugural",
    "inaugurales": "inaugural",
    "inaugurant": "inaugurer",
    "inauguras": "inaugurer",
    "inaugurasse": "inaugurer",
    "inaugurassent": "inaugurer",
    "inaugurasses": "inaugurer",
    "inaugurassiez": "inaugurer",
    "inaugurassions": "inaugurer",
    "inaugurations": "inauguration",
    "inauguraux": "inaugural",
    "inaugure": "inaugurer",
    "inaugurent": "inaugurer",
    "inaugurera": "inaugurer",
    "inaugurerai": "inaugurer",
    "inaugureraient": "inaugurer",
    "inaugurerais": "inaugurer",
    "inaugurerait": "inaugurer",
    "inaugureras": "inaugurer",
    "inaugurerez": "inaugurer",
    "inaugureriez": "inaugurer",
    "inaugurerions": "inaugurer",
    "inaugurerons": "inaugurer",
    "inaugureront": "inaugurer",
    "inaugures": "inaugurer",
    "inaugurez": "inaugurer",
    "inauguriez": "inaugurer",
    "inaugurions": "inaugurer",
    "inaugurons": "inaugurer",
    "inaugurâmes": "inaugurer",
    "inaugurât": "inaugurer",
    "inaugurâtes": "inaugurer",
    "inaugurèrent": "inaugurer",
    "inauguré": "inaugurer",
    "inaugurée": "inaugurer",
    "inaugurées": "inaugurer",
    "inaugurés": "inaugurer",
    "inavouables": "inavouable",
    "inavouée": "inavoué",
    "inavouées": "inavoué",
    "inavoués": "inavoué",
    "incalculables": "incalculable",
    "incandescences": "incandescence",
    "incandescente": "incandescent",
    "incandescentes": "incandescent",
    "incandescents": "incandescent",
    "incantations": "incantation",
    "incantatoires": "incantatoire",
    "incantatrice": "incantateur",
    "incapables": "incapable",
    "incapacitante": "incapacitant",
    "incapacitants": "incapacitant",
    "incapacités": "incapacité",
    "incarcère": "incarcérer",
    "incarcèrent": "incarcérer",
    "incarcères": "incarcérer",
    "incarcéra": "incarcérer",
    "incarcérai": "incarcérer",
    "incarcéraient": "incarcérer",
    "incarcérais": "incarcérer",
    "incarcérait": "incarcérer",
    "incarcérant": "incarcérer",
    "incarcéras": "incarcérer",
    "incarcérasse": "incarcérer",
    "incarcérassent": "incarcérer",
    "incarcérasses": "incarcérer",
    "incarcérassiez": "incarcérer",
    "incarcérassions": "incarcérer",
    "incarcérations": "incarcération",
    "incarcérera": "incarcérer",
    "incarcérerai": "incarcérer",
    "incarcéreraient": "incarcérer",
    "incarcérerais": "incarcérer",
    "incarcérerait": "incarcérer",
    "incarcéreras": "incarcérer",
    "incarcérerez": "incarcérer",
    "incarcéreriez": "incarcérer",
    "incarcérerions": "incarcérer",
    "incarcérerons": "incarcérer",
    "incarcéreront": "incarcérer",
    "incarcérez": "incarcérer",
    "incarcériez": "incarcérer",
    "incarcérions": "incarcérer",
    "incarcérons": "incarcérer",
    "incarcérâmes": "incarcérer",
    "incarcérât": "incarcérer",
    "incarcérâtes": "incarcérer",
    "incarcérèrent": "incarcérer",
    "incarcéré": "incarcérer",
    "incarcérée": "incarcérer",
    "incarcérées": "incarcérer",
    "incarcérés": "incarcérer",
    "incarna": "incarner",
    "incarnadines": "incarnadin",
    "incarnai": "incarner",
    "incarnaient": "incarner",
    "incarnais": "incarner",
    "incarnait": "incarner",
    "incarnant": "incarner",
    "incarnas": "incarner",
    "incarnasse": "incarner",
    "incarnassent": "incarner",
    "incarnasses": "incarner",
    "incarnassiez": "incarner",
    "incarnassions": "incarner",
    "incarnate": "incarnat",
    "incarnates": "incarnat",
    "incarnations": "incarnation",
    "incarnats": "incarnat",
    "incarne": "incarner",
    "incarnent": "incarner",
    "incarnera": "incarner",
    "incarnerai": "incarner",
    "incarneraient": "incarner",
    "incarnerais": "incarner",
    "incarnerait": "incarner",
    "incarneras": "incarner",
    "incarnerez": "incarner",
    "incarneriez": "incarner",
    "incarnerions": "incarner",
    "incarnerons": "incarner",
    "incarneront": "incarner",
    "incarnes": "incarner",
    "incarnez": "incarner",
    "incarniez": "incarner",
    "incarnions": "incarner",
    "incarnons": "incarner",
    "incarnâmes": "incarner",
    "incarnât": "incarner",
    "incarnâtes": "incarner",
    "incarnèrent": "incarner",
    "incarné": "incarner",
    "incarnée": "incarner",
    "incarnées": "incarner",
    "incarnés": "incarner",
    "incartades": "incartade",
    "incas": "inca",
    "incassables": "incassable",
    "incendia": "incendier",
    "incendiai": "incendier",
    "incendiaient": "incendier",
    "incendiaires": "incendiaire",
    "incendiais": "incendier",
    "incendiait": "incendier",
    "incendiant": "incendier",
    "incendias": "incendier",
    "incendiasse": "incendier",
    "incendiassent": "incendier",
    "incendiasses": "incendier",
    "incendiassiez": "incendier",
    "incendiassions": "incendier",
    "incendie": "incendier",
    "incendient": "incendier",
    "incendiera": "incendier",
    "incendierai": "incendier",
    "incendieraient": "incendier",
    "incendierais": "incendier",
    "incendierait": "incendier",
    "incendieras": "incendier",
    "incendierez": "incendier",
    "incendieriez": "incendier",
    "incendierions": "incendier",
    "incendierons": "incendier",
    "incendieront": "incendier",
    "incendies": "incendier",
    "incendiez": "incendier",
    "incendiiez": "incendier",
    "incendiions": "incendier",
    "incendions": "incendier",
    "incendiâmes": "incendier",
    "incendiât": "incendier",
    "incendiâtes": "incendier",
    "incendièrent": "incendier",
    "incendié": "incendier",
    "incendiée": "incendier",
    "incendiées": "incendier",
    "incendiés": "incendier",
    "incertaine": "incertain",
    "incertaines": "incertain",
    "incertains": "incertain",
    "incertitudes": "incertitude",
    "incessante": "incessant",
    "incessantes": "incessant",
    "incessants": "incessant",
    "incessibles": "incessible",
    "incestes": "inceste",
    "incestueuse": "incestueux",
    "incestueuses": "incestueux",
    "inchangée": "inchangé",
    "inchangées": "inchangé",
    "inchangés": "inchangé",
    "inchoatifs": "inchoatif",
    "inchoative": "inchoatif",
    "inchoatives": "inchoatif",
    "incidences": "incidence",
    "incidente": "incident",
    "incidentes": "incident",
    "incidents": "incident",
    "incinère": "incinérer",
    "incinèrent": "incinérer",
    "incinères": "incinérer",
    "incinéra": "incinérer",
    "incinérai": "incinérer",
    "incinéraient": "incinérer",
    "incinérais": "incinérer",
    "incinérait": "incinérer",
    "incinérant": "incinérer",
    "incinéras": "incinérer",
    "incinérasse": "incinérer",
    "incinérassent": "incinérer",
    "incinérasses": "incinérer",
    "incinérassiez": "incinérer",
    "incinérassions": "incinérer",
    "incinérateurs": "incinérateur",
    "incinérations": "incinération",
    "incinérera": "incinérer",
    "incinérerai": "incinérer",
    "incinéreraient": "incinérer",
    "incinérerais": "incinérer",
    "incinérerait": "incinérer",
    "incinéreras": "incinérer",
    "incinérerez": "incinérer",
    "incinéreriez": "incinérer",
    "incinérerions": "incinérer",
    "incinérerons": "incinérer",
    "incinéreront": "incinérer",
    "incinérez": "incinérer",
    "incinériez": "incinérer",
    "incinérions": "incinérer",
    "incinérons": "incinérer",
    "incinérâmes": "incinérer",
    "incinérât": "incinérer",
    "incinérâtes": "incinérer",
    "incinérèrent": "incinérer",
    "incinéré": "incinérer",
    "incinérée": "incinérer",
    "incinérées": "incinérer",
    "incinérés": "incinérer",
    "incisa": "inciser",
    "incisai": "inciser",
    "incisaient": "inciser",
    "incisais": "inciser",
    "incisait": "inciser",
    "incisant": "inciser",
    "incisas": "inciser",
    "incisasse": "inciser",
    "incisassent": "inciser",
    "incisasses": "inciser",
    "incisassiez": "inciser",
    "incisassions": "inciser",
    "incise": "inciser",
    "incisent": "inciser",
    "incisera": "inciser",
    "inciserai": "inciser",
    "inciseraient": "inciser",
    "inciserais": "inciser",
    "inciserait": "inciser",
    "inciseras": "inciser",
    "inciserez": "inciser",
    "inciseriez": "inciser",
    "inciserions": "inciser",
    "inciserons": "inciser",
    "inciseront": "inciser",
    "incises": "inciser",
    "incisez": "inciser",
    "incisiez": "inciser",
    "incisifs": "incisif",
    "incisions": "incision",
    "incisive": "incisif",
    "incisives": "incisive",
    "incisons": "inciser",
    "incisâmes": "inciser",
    "incisât": "inciser",
    "incisâtes": "inciser",
    "incisèrent": "inciser",
    "incisé": "inciser",
    "incisée": "inciser",
    "incisées": "inciser",
    "incisés": "inciser",
    "incita": "inciter",
    "incitai": "inciter",
    "incitaient": "inciter",
    "incitais": "inciter",
    "incitait": "inciter",
    "incitant": "inciter",
    "incitants": "incitant",
    "incitas": "inciter",
    "incitasse": "inciter",
    "incitassent": "inciter",
    "incitasses": "inciter",
    "incitassiez": "inciter",
    "incitassions": "inciter",
    "incitatifs": "incitatif",
    "incitations": "incitation",
    "incitative": "incitatif",
    "incitatives": "incitatif",
    "incitatrice": "incitateur",
    "incite": "inciter",
    "incitent": "inciter",
    "incitera": "inciter",
    "inciterai": "inciter",
    "inciteraient": "inciter",
    "inciterais": "inciter",
    "inciterait": "inciter",
    "inciteras": "inciter",
    "inciterez": "inciter",
    "inciteriez": "inciter",
    "inciterions": "inciter",
    "inciterons": "inciter",
    "inciteront": "inciter",
    "incites": "inciter",
    "incitez": "inciter",
    "incitiez": "inciter",
    "incitions": "inciter",
    "incitons": "inciter",
    "incitâmes": "inciter",
    "incitât": "inciter",
    "incitâtes": "inciter",
    "incitèrent": "inciter",
    "incité": "inciter",
    "incitée": "inciter",
    "incitées": "inciter",
    "incités": "inciter",
    "incivile": "incivil",
    "inciviles": "incivil",
    "incivils": "incivil",
    "inclassables": "inclassable",
    "inclina": "incliner",
    "inclinables": "inclinable",
    "inclinai": "incliner",
    "inclinaient": "incliner",
    "inclinais": "incliner",
    "inclinaisons": "inclinaison",
    "inclinait": "incliner",
    "inclinant": "incliner",
    "inclinante": "inclinant",
    "inclinas": "incliner",
    "inclinasse": "incliner",
    "inclinassent": "incliner",
    "inclinasses": "incliner",
    "inclinassiez": "incliner",
    "inclinassions": "incliner",
    "inclinations": "inclination",
    "incline": "incliner",
    "inclinent": "incliner",
    "inclinera": "incliner",
    "inclinerai": "incliner",
    "inclineraient": "incliner",
    "inclinerais": "incliner",
    "inclinerait": "incliner",
    "inclineras": "incliner",
    "inclinerez": "incliner",
    "inclineriez": "incliner",
    "inclinerions": "incliner",
    "inclinerons": "incliner",
    "inclineront": "incliner",
    "inclines": "incliner",
    "inclinez": "incliner",
    "incliniez": "incliner",
    "inclinions": "incliner",
    "inclinons": "incliner",
    "inclinâmes": "incliner",
    "inclinât": "incliner",
    "inclinâtes": "incliner",
    "inclinèrent": "incliner",
    "incliné": "incliner",
    "inclinée": "incliner",
    "inclinées": "incliner",
    "inclinés": "incliner",
    "incluaient": "inclure",
    "incluais": "inclure",
    "incluait": "inclure",
    "incluant": "inclure",
    "inclue": "inclure",
    "incluent": "inclure",
    "inclues": "inclure",
    "incluez": "inclure",
    "incluiez": "inclure",
    "incluions": "inclure",
    "incluons": "inclure",
    "inclura": "inclure",
    "inclurai": "inclure",
    "incluraient": "inclure",
    "inclurais": "inclure",
    "inclurait": "inclure",
    "incluras": "inclure",
    "inclurent": "inclure",
    "inclurez": "inclure",
    "incluriez": "inclure",
    "inclurions": "inclure",
    "inclurons": "inclure",
    "incluront": "inclure",
    "inclus": "inclure",
    "incluse": "inclus",
    "incluses": "inclus",
    "inclusions": "inclusion",
    "inclusive": "inclusif",
    "inclusse": "inclure",
    "inclussent": "inclure",
    "inclusses": "inclure",
    "inclussiez": "inclure",
    "inclussions": "inclure",
    "inclut": "inclure",
    "inclémences": "inclémence",
    "inclémente": "inclément",
    "inclémentes": "inclément",
    "incléments": "inclément",
    "inclûmes": "inclure",
    "inclût": "inclure",
    "inclûtes": "inclure",
    "incoercibles": "incoercible",
    "incognitos": "incognito",
    "incohérences": "incohérence",
    "incohérente": "incohérent",
    "incohérentes": "incohérent",
    "incohérents": "incohérent",
    "incoiffables": "incoiffable",
    "incolores": "incolore",
    "incomba": "incomber",
    "incombai": "incomber",
    "incombaient": "incomber",
    "incombais": "incomber",
    "incombait": "incomber",
    "incombant": "incomber",
    "incombas": "incomber",
    "incombasse": "incomber",
    "incombassent": "incomber",
    "incombasses": "incomber",
    "incombassiez": "incomber",
    "incombassions": "incomber",
    "incombe": "incomber",
    "incombent": "incomber",
    "incombera": "incomber",
    "incomberai": "incomber",
    "incomberaient": "incomber",
    "incomberais": "incomber",
    "incomberait": "incomber",
    "incomberas": "incomber",
    "incomberez": "incomber",
    "incomberiez": "incomber",
    "incomberions": "incomber",
    "incomberons": "incomber",
    "incomberont": "incomber",
    "incombes": "incomber",
    "incombez": "incomber",
    "incombiez": "incomber",
    "incombions": "incomber",
    "incombons": "incomber",
    "incombustibles": "incombustible",
    "incombâmes": "incomber",
    "incombât": "incomber",
    "incombâtes": "incomber",
    "incombèrent": "incomber",
    "incombé": "incomber",
    "incommensurables": "incommensurable",
    "incommoda": "incommoder",
    "incommodai": "incommoder",
    "incommodaient": "incommoder",
    "incommodais": "incommoder",
    "incommodait": "incommoder",
    "incommodant": "incommoder",
    "incommodante": "incommodant",
    "incommodantes": "incommodant",
    "incommodas": "incommoder",
    "incommodasse": "incommoder",
    "incommodassent": "incommoder",
    "incommodasses": "incommoder",
    "incommodassiez": "incommoder",
    "incommodassions": "incommoder",
    "incommode": "incommoder",
    "incommodent": "incommoder",
    "incommodera": "incommoder",
    "incommoderai": "incommoder",
    "incommoderaient": "incommoder",
    "incommoderais": "incommoder",
    "incommoderait": "incommoder",
    "incommoderas": "incommoder",
    "incommoderez": "incommoder",
    "incommoderiez": "incommoder",
    "incommoderions": "incommoder",
    "incommoderons": "incommoder",
    "incommoderont": "incommoder",
    "incommodes": "incommoder",
    "incommodez": "incommoder",
    "incommodiez": "incommoder",
    "incommodions": "incommoder",
    "incommodités": "incommodité",
    "incommodons": "incommoder",
    "incommodâmes": "incommoder",
    "incommodât": "incommoder",
    "incommodâtes": "incommoder",
    "incommodèrent": "incommoder",
    "incommodé": "incommoder",
    "incommodée": "incommoder",
    "incommodées": "incommoder",
    "incommodés": "incommoder",
    "incommunicabilités": "incommunicabilité",
    "incommunicables": "incommunicable",
    "incomparables": "incomparable",
    "incompatibilités": "incompatibilité",
    "incompatibles": "incompatible",
    "incomplets": "incomplet",
    "incomplète": "incomplet",
    "incomplètes": "incomplet",
    "incomplétudes": "incomplétude",
    "incompressibles": "incompressible",
    "incomprise": "incompris",
    "incomprises": "incompris",
    "incompréhensibles": "incompréhensible",
    "incompréhensifs": "incompréhensif",
    "incompréhensions": "incompréhension",
    "incomptables": "incomptable",
    "incompétences": "incompétence",
    "incompétente": "incompétent",
    "incompétentes": "incompétent",
    "incompétents": "incompétent",
    "inconcevables": "inconcevable",
    "inconciliables": "inconciliable",
    "inconditionnelle": "inconditionnel",
    "inconditionnelles": "inconditionnel",
    "inconditionnels": "inconditionnel",
    "inconditionnée": "inconditionné",
    "inconditionnées": "inconditionné",
    "inconditionnés": "inconditionné",
    "inconduites": "inconduite",
    "inconfortables": "inconfortable",
    "inconforts": "inconfort",
    "incongelables": "incongelable",
    "incongrue": "incongru",
    "incongrues": "incongru",
    "incongruités": "incongruité",
    "incongrus": "incongru",
    "inconnue": "inconnu",
    "inconnues": "inconnu",
    "inconnus": "inconnu",
    "inconsciences": "inconscience",
    "inconsciente": "inconscient",
    "inconscientes": "inconscient",
    "inconscients": "inconscient",
    "inconsidérée": "inconsidéré",
    "inconsidérées": "inconsidéré",
    "inconsidérés": "inconsidéré",
    "inconsistances": "inconsistance",
    "inconsistante": "inconsistant",
    "inconsistantes": "inconsistant",
    "inconsistants": "inconsistant",
    "inconsolables": "inconsolable",
    "inconsolée": "inconsolé",
    "inconsolées": "inconsolé",
    "inconsolés": "inconsolé",
    "inconstances": "inconstance",
    "inconstante": "inconstant",
    "inconstantes": "inconstant",
    "inconstants": "inconstant",
    "inconstitutionnalités": "inconstitutionnalité",
    "inconstitutionnelle": "inconstitutionnel",
    "inconstitutionnelles": "inconstitutionnel",
    "inconstitutionnels": "inconstitutionnel",
    "inconstructibles": "inconstructible",
    "inconséquences": "inconséquence",
    "inconséquente": "inconséquent",
    "inconséquentes": "inconséquent",
    "inconséquents": "inconséquent",
    "incontestables": "incontestable",
    "incontestée": "incontesté",
    "incontestées": "incontesté",
    "incontestés": "incontesté",
    "incontinences": "incontinence",
    "incontinente": "incontinent",
    "incontinentes": "incontinent",
    "incontinents": "incontinent",
    "incontournables": "incontournable",
    "incontrôlables": "incontrôlable",
    "incontrôlée": "incontrôlé",
    "incontrôlées": "incontrôlé",
    "incontrôlés": "incontrôlé",
    "inconvenances": "inconvenance",
    "inconvenante": "inconvenant",
    "inconvenantes": "inconvenant",
    "inconvenants": "inconvenant",
    "inconvertibles": "inconvertible",
    "inconvénients": "inconvénient",
    "incoordinations": "incoordination",
    "incorpora": "incorporer",
    "incorporai": "incorporer",
    "incorporaient": "incorporer",
    "incorporais": "incorporer",
    "incorporait": "incorporer",
    "incorporant": "incorporer",
    "incorporas": "incorporer",
    "incorporasse": "incorporer",
    "incorporassent": "incorporer",
    "incorporasses": "incorporer",
    "incorporassiez": "incorporer",
    "incorporassions": "incorporer",
    "incorporations": "incorporation",
    "incorpore": "incorporer",
    "incorporelle": "incorporel",
    "incorporelles": "incorporel",
    "incorporels": "incorporel",
    "incorporent": "incorporer",
    "incorporera": "incorporer",
    "incorporerai": "incorporer",
    "incorporeraient": "incorporer",
    "incorporerais": "incorporer",
    "incorporerait": "incorporer",
    "incorporeras": "incorporer",
    "incorporerez": "incorporer",
    "incorporeriez": "incorporer",
    "incorporerions": "incorporer",
    "incorporerons": "incorporer",
    "incorporeront": "incorporer",
    "incorpores": "incorporer",
    "incorporez": "incorporer",
    "incorporiez": "incorporer",
    "incorporions": "incorporer",
    "incorporons": "incorporer",
    "incorporâmes": "incorporer",
    "incorporât": "incorporer",
    "incorporâtes": "incorporer",
    "incorporèrent": "incorporer",
    "incorporé": "incorporer",
    "incorporée": "incorporer",
    "incorporées": "incorporer",
    "incorporés": "incorporer",
    "incorrecte": "incorrect",
    "incorrectes": "incorrect",
    "incorrects": "incorrect",
    "incorrigibles": "incorrigible",
    "incorruptibles": "incorruptible",
    "increvables": "increvable",
    "incrimina": "incriminer",
    "incriminai": "incriminer",
    "incriminaient": "incriminer",
    "incriminais": "incriminer",
    "incriminait": "incriminer",
    "incriminant": "incriminer",
    "incriminas": "incriminer",
    "incriminasse": "incriminer",
    "incriminassent": "incriminer",
    "incriminasses": "incriminer",
    "incriminassiez": "incriminer",
    "incriminassions": "incriminer",
    "incriminations": "incrimination",
    "incrimine": "incriminer",
    "incriminent": "incriminer",
    "incriminera": "incriminer",
    "incriminerai": "incriminer",
    "incrimineraient": "incriminer",
    "incriminerais": "incriminer",
    "incriminerait": "incriminer",
    "incrimineras": "incriminer",
    "incriminerez": "incriminer",
    "incrimineriez": "incriminer",
    "incriminerions": "incriminer",
    "incriminerons": "incriminer",
    "incrimineront": "incriminer",
    "incrimines": "incriminer",
    "incriminez": "incriminer",
    "incriminiez": "incriminer",
    "incriminions": "incriminer",
    "incriminons": "incriminer",
    "incriminâmes": "incriminer",
    "incriminât": "incriminer",
    "incriminâtes": "incriminer",
    "incriminèrent": "incriminer",
    "incriminé": "incriminer",
    "incriminée": "incriminer",
    "incriminées": "incriminer",
    "incriminés": "incriminer",
    "incrochetables": "incrochetable",
    "incroyables": "incroyable",
    "incroyante": "incroyant",
    "incroyantes": "incroyant",
    "incroyants": "incroyant",
    "incrusta": "incruster",
    "incrustai": "incruster",
    "incrustaient": "incruster",
    "incrustais": "incruster",
    "incrustait": "incruster",
    "incrustant": "incruster",
    "incrustas": "incruster",
    "incrustasse": "incruster",
    "incrustassent": "incruster",
    "incrustasses": "incruster",
    "incrustassiez": "incruster",
    "incrustassions": "incruster",
    "incrustations": "incrustation",
    "incruste": "incruster",
    "incrustent": "incruster",
    "incrustera": "incruster",
    "incrusterai": "incruster",
    "incrusteraient": "incruster",
    "incrusterais": "incruster",
    "incrusterait": "incruster",
    "incrusteras": "incruster",
    "incrusterez": "incruster",
    "incrusteriez": "incruster",
    "incrusterions": "incruster",
    "incrusterons": "incruster",
    "incrusteront": "incruster",
    "incrustes": "incruster",
    "incrustez": "incruster",
    "incrustiez": "incruster",
    "incrustions": "incruster",
    "incrustons": "incruster",
    "incrustâmes": "incruster",
    "incrustât": "incruster",
    "incrustâtes": "incruster",
    "incrustèrent": "incruster",
    "incrusté": "incruster",
    "incrustée": "incruster",
    "incrustées": "incruster",
    "incrustés": "incruster",
    "incrédules": "incrédule",
    "incrédulités": "incrédulité",
    "incréée": "incréé",
    "incuba": "incuber",
    "incubai": "incuber",
    "incubaient": "incuber",
    "incubais": "incuber",
    "incubait": "incuber",
    "incubant": "incuber",
    "incubas": "incuber",
    "incubasse": "incuber",
    "incubassent": "incuber",
    "incubasses": "incuber",
    "incubassiez": "incuber",
    "incubassions": "incuber",
    "incubateurs": "incubateur",
    "incubations": "incubation",
    "incube": "incuber",
    "incubent": "incuber",
    "incubera": "incuber",
    "incuberai": "incuber",
    "incuberaient": "incuber",
    "incuberais": "incuber",
    "incuberait": "incuber",
    "incuberas": "incuber",
    "incuberez": "incuber",
    "incuberiez": "incuber",
    "incuberions": "incuber",
    "incuberons": "incuber",
    "incuberont": "incuber",
    "incubes": "incuber",
    "incubez": "incuber",
    "incubiez": "incuber",
    "incubions": "incuber",
    "incubons": "incuber",
    "incubâmes": "incuber",
    "incubât": "incuber",
    "incubâtes": "incuber",
    "incubèrent": "incuber",
    "incubé": "incuber",
    "incubée": "incuber",
    "incubées": "incuber",
    "incubés": "incuber",
    "inculcations": "inculcation",
    "inculpa": "inculper",
    "inculpai": "inculper",
    "inculpaient": "inculper",
    "inculpais": "inculper",
    "inculpait": "inculper",
    "inculpant": "inculper",
    "inculpas": "inculper",
    "inculpasse": "inculper",
    "inculpassent": "inculper",
    "inculpasses": "inculper",
    "inculpassiez": "inculper",
    "inculpassions": "inculper",
    "inculpations": "inculpation",
    "inculpe": "inculper",
    "inculpent": "inculper",
    "inculpera": "inculper",
    "inculperai": "inculper",
    "inculperaient": "inculper",
    "inculperais": "inculper",
    "inculperait": "inculper",
    "inculperas": "inculper",
    "inculperez": "inculper",
    "inculperiez": "inculper",
    "inculperions": "inculper",
    "inculperons": "inculper",
    "inculperont": "inculper",
    "inculpes": "inculper",
    "inculpez": "inculper",
    "inculpiez": "inculper",
    "inculpions": "inculper",
    "inculpons": "inculper",
    "inculpâmes": "inculper",
    "inculpât": "inculper",
    "inculpâtes": "inculper",
    "inculpèrent": "inculper",
    "inculpé": "inculper",
    "inculpée": "inculper",
    "inculpées": "inculper",
    "inculpés": "inculper",
    "inculqua": "inculquer",
    "inculquai": "inculquer",
    "inculquaient": "inculquer",
    "inculquais": "inculquer",
    "inculquait": "inculquer",
    "inculquant": "inculquer",
    "inculquas": "inculquer",
    "inculquasse": "inculquer",
    "inculquassent": "inculquer",
    "inculquasses": "inculquer",
    "inculquassiez": "inculquer",
    "inculquassions": "inculquer",
    "inculque": "inculquer",
    "inculquent": "inculquer",
    "inculquera": "inculquer",
    "inculquerai": "inculquer",
    "inculqueraient": "inculquer",
    "inculquerais": "inculquer",
    "inculquerait": "inculquer",
    "inculqueras": "inculquer",
    "inculquerez": "inculquer",
    "inculqueriez": "inculquer",
    "inculquerions": "inculquer",
    "inculquerons": "inculquer",
    "inculqueront": "inculquer",
    "inculques": "inculquer",
    "inculquez": "inculquer",
    "inculquiez": "inculquer",
    "inculquions": "inculquer",
    "inculquons": "inculquer",
    "inculquâmes": "inculquer",
    "inculquât": "inculquer",
    "inculquâtes": "inculquer",
    "inculquèrent": "inculquer",
    "inculqué": "inculquer",
    "inculquée": "inculquer",
    "inculquées": "inculquer",
    "inculqués": "inculquer",
    "incultes": "inculte",
    "incultivables": "incultivable",
    "incunables": "incunable",
    "incurables": "incurable",
    "incuries": "incurie",
    "incursions": "incursion",
    "incurva": "incurver",
    "incurvai": "incurver",
    "incurvaient": "incurver",
    "incurvais": "incurver",
    "incurvait": "incurver",
    "incurvant": "incurver",
    "incurvas": "incurver",
    "incurvasse": "incurver",
    "incurvassent": "incurver",
    "incurvasses": "incurver",
    "incurvassiez": "incurver",
    "incurvassions": "incurver",
    "incurvations": "incurvation",
    "incurve": "incurver",
    "incurvent": "incurver",
    "incurvera": "incurver",
    "incurverai": "incurver",
    "incurveraient": "incurver",
    "incurverais": "incurver",
    "incurverait": "incurver",
    "incurveras": "incurver",
    "incurverez": "incurver",
    "incurveriez": "incurver",
    "incurverions": "incurver",
    "incurverons": "incurver",
    "incurveront": "incurver",
    "incurves": "incurver",
    "incurvez": "incurver",
    "incurviez": "incurver",
    "incurvions": "incurver",
    "incurvons": "incurver",
    "incurvâmes": "incurver",
    "incurvât": "incurver",
    "incurvâtes": "incurver",
    "incurvèrent": "incurver",
    "incurvé": "incurver",
    "incurvée": "incurver",
    "incurvées": "incurver",
    "incurvés": "incurver",
    "indemnes": "indemne",
    "indemnisa": "indemniser",
    "indemnisai": "indemniser",
    "indemnisaient": "indemniser",
    "indemnisais": "indemniser",
    "indemnisait": "indemniser",
    "indemnisant": "indemniser",
    "indemnisas": "indemniser",
    "indemnisasse": "indemniser",
    "indemnisassent": "indemniser",
    "indemnisasses": "indemniser",
    "indemnisassiez": "indemniser",
    "indemnisassions": "indemniser",
    "indemnisations": "indemnisation",
    "indemnise": "indemniser",
    "indemnisent": "indemniser",
    "indemnisera": "indemniser",
    "indemniserai": "indemniser",
    "indemniseraient": "indemniser",
    "indemniserais": "indemniser",
    "indemniserait": "indemniser",
    "indemniseras": "indemniser",
    "indemniserez": "indemniser",
    "indemniseriez": "indemniser",
    "indemniserions": "indemniser",
    "indemniserons": "indemniser",
    "indemniseront": "indemniser",
    "indemnises": "indemniser",
    "indemnisez": "indemniser",
    "indemnisiez": "indemniser",
    "indemnisions": "indemniser",
    "indemnisons": "indemniser",
    "indemnisâmes": "indemniser",
    "indemnisât": "indemniser",
    "indemnisâtes": "indemniser",
    "indemnisèrent": "indemniser",
    "indemnisé": "indemniser",
    "indemnisée": "indemniser",
    "indemnisées": "indemniser",
    "indemnisés": "indemniser",
    "indemnitaires": "indemnitaire",
    "indemnités": "indemnité",
    "indemnités-repas": "indemnités-repa",
    "indenté": "indenter",
    "indes": "inde",
    "indescriptibles": "indescriptible",
    "indestructibles": "indestructible",
    "indexa": "indexer",
    "indexai": "indexer",
    "indexaient": "indexer",
    "indexais": "indexer",
    "indexait": "indexer",
    "indexant": "indexer",
    "indexas": "indexer",
    "indexasse": "indexer",
    "indexassent": "indexer",
    "indexasses": "indexer",
    "indexassiez": "indexer",
    "indexassions": "indexer",
    "indexations": "indexation",
    "indexe": "indexer",
    "indexent": "indexer",
    "indexera": "indexer",
    "indexerai": "indexer",
    "indexeraient": "indexer",
    "indexerais": "indexer",
    "indexerait": "indexer",
    "indexeras": "indexer",
    "indexerez": "indexer",
    "indexeriez": "indexer",
    "indexerions": "indexer",
    "indexerons": "indexer",
    "indexeront": "indexer",
    "indexes": "indexer",
    "indexez": "indexer",
    "indexiez": "indexer",
    "indexions": "indexer",
    "indexons": "indexer",
    "indexâmes": "indexer",
    "indexât": "indexer",
    "indexâtes": "indexer",
    "indexèrent": "indexer",
    "indexé": "indexer",
    "indexée": "indexer",
    "indexées": "indexer",
    "indexés": "indexer",
    "indianisée": "indianisé",
    "indianisées": "indianisé",
    "indianisés": "indianiser",
    "indicateurs": "indicateur",
    "indicatifs": "indicatif",
    "indications": "indication",
    "indicative": "indicatif",
    "indicatives": "indicatif",
    "indicatrice": "indicateur",
    "indicatrices": "indicateur",
    "indices": "indice",
    "indiciaires": "indiciaire",
    "indicibles": "indicible",
    "indics": "indic",
    "indienne": "indien",
    "indienneries": "indiennerie",
    "indiennes": "indienne",
    "indiens": "indien",
    "indiffère": "indifférer",
    "indiffèrent": "indifférer",
    "indiffères": "indifférer",
    "indifféra": "indifférer",
    "indifférai": "indifférer",
    "indifféraient": "indifférer",
    "indifférais": "indifférer",
    "indifférait": "indifférer",
    "indifférant": "indifférer",
    "indifféras": "indifférer",
    "indifférasse": "indifférer",
    "indifférassent": "indifférer",
    "indifférasses": "indifférer",
    "indifférassiez": "indifférer",
    "indifférassions": "indifférer",
    "indifférences": "indifférence",
    "indifférenciée": "indifférencier",
    "indifférenciés": "indifférencié",
    "indifférente": "indifférent",
    "indifférentes": "indifférent",
    "indifférents": "indifférent",
    "indifférera": "indifférer",
    "indifférerai": "indifférer",
    "indifféreraient": "indifférer",
    "indifférerais": "indifférer",
    "indifférerait": "indifférer",
    "indifféreras": "indifférer",
    "indifférerez": "indifférer",
    "indifféreriez": "indifférer",
    "indifférerions": "indifférer",
    "indifférerons": "indifférer",
    "indifféreront": "indifférer",
    "indifférez": "indifférer",
    "indiffériez": "indifférer",
    "indifférions": "indifférer",
    "indifférons": "indifférer",
    "indifférâmes": "indifférer",
    "indifférât": "indifférer",
    "indifférâtes": "indifférer",
    "indifférèrent": "indifférer",
    "indifféré": "indifférer",
    "indifférée": "indifférer",
    "indifférées": "indifférer",
    "indifférés": "indifférer",
    "indigences": "indigence",
    "indigente": "indigent",
    "indigentes": "indigent",
    "indigents": "indigent",
    "indigestes": "indigeste",
    "indigestions": "indigestion",
    "indigna": "indigner",
    "indignai": "indigner",
    "indignaient": "indigner",
    "indignais": "indigner",
    "indignait": "indigner",
    "indignant": "indigner",
    "indignas": "indigner",
    "indignasse": "indigner",
    "indignassent": "indigner",
    "indignasses": "indigner",
    "indignassiez": "indigner",
    "indignassions": "indigner",
    "indignations": "indignation",
    "indigne": "indigner",
    "indignent": "indigner",
    "indignera": "indigner",
    "indignerai": "indigner",
    "indigneraient": "indigner",
    "indignerais": "indigner",
    "indignerait": "indigner",
    "indigneras": "indigner",
    "indignerez": "indigner",
    "indigneriez": "indigner",
    "indignerions": "indigner",
    "indignerons": "indigner",
    "indigneront": "indigner",
    "indignes": "indigner",
    "indignez": "indigner",
    "indigniez": "indigner",
    "indignions": "indigner",
    "indignités": "indignité",
    "indignons": "indigner",
    "indignâmes": "indigner",
    "indignât": "indigner",
    "indignâtes": "indigner",
    "indignèrent": "indigner",
    "indigné": "indigner",
    "indignée": "indigner",
    "indignées": "indigner",
    "indignés": "indigner",
    "indigos": "indigo",
    "indigènes": "indigène",
    "indiqua": "indiquer",
    "indiquai": "indiquer",
    "indiquaient": "indiquer",
    "indiquais": "indiquer",
    "indiquait": "indiquer",
    "indiquant": "indiquer",
    "indiquas": "indiquer",
    "indiquasse": "indiquer",
    "indiquassent": "indiquer",
    "indiquasses": "indiquer",
    "indiquassiez": "indiquer",
    "indiquassions": "indiquer",
    "indique": "indiquer",
    "indiquent": "indiquer",
    "indiquera": "indiquer",
    "indiquerai": "indiquer",
    "indiqueraient": "indiquer",
    "indiquerais": "indiquer",
    "indiquerait": "indiquer",
    "indiqueras": "indiquer",
    "indiquerez": "indiquer",
    "indiqueriez": "indiquer",
    "indiquerions": "indiquer",
    "indiquerons": "indiquer",
    "indiqueront": "indiquer",
    "indiques": "indiquer",
    "indiquez": "indiquer",
    "indiquiez": "indiquer",
    "indiquions": "indiquer",
    "indiquons": "indiquer",
    "indiquâmes": "indiquer",
    "indiquât": "indiquer",
    "indiquâtes": "indiquer",
    "indiquèrent": "indiquer",
    "indiqué": "indiquer",
    "indiquée": "indiquer",
    "indiquées": "indiquer",
    "indiqués": "indiquer",
    "indirecte": "indirect",
    "indirectes": "indirect",
    "indirects": "indirect",
    "indiscernables": "indiscernable",
    "indisciplines": "indiscipline",
    "indisciplinée": "indiscipliné",
    "indisciplinées": "indiscipliné",
    "indisciplinés": "indiscipliné",
    "indiscrets": "indiscret",
    "indiscrète": "indiscret",
    "indiscrètes": "indiscret",
    "indiscrétions": "indiscrétion",
    "indiscutables": "indiscutable",
    "indiscutée": "indiscuté",
    "indiscutées": "indiscuté",
    "indiscutés": "indiscuté",
    "indispensables": "indispensable",
    "indisponibles": "indisponible",
    "indisposa": "indisposer",
    "indisposai": "indisposer",
    "indisposaient": "indisposer",
    "indisposais": "indisposer",
    "indisposait": "indisposer",
    "indisposant": "indisposer",
    "indisposas": "indisposer",
    "indisposasse": "indisposer",
    "indisposassent": "indisposer",
    "indisposasses": "indisposer",
    "indisposassiez": "indisposer",
    "indisposassions": "indisposer",
    "indispose": "indisposer",
    "indisposent": "indisposer",
    "indisposera": "indisposer",
    "indisposerai": "indisposer",
    "indisposeraient": "indisposer",
    "indisposerais": "indisposer",
    "indisposerait": "indisposer",
    "indisposeras": "indisposer",
    "indisposerez": "indisposer",
    "indisposeriez": "indisposer",
    "indisposerions": "indisposer",
    "indisposerons": "indisposer",
    "indisposeront": "indisposer",
    "indisposes": "indisposer",
    "indisposez": "indisposer",
    "indisposiez": "indisposer",
    "indisposions": "indisposer",
    "indisposons": "indisposer",
    "indisposâmes": "indisposer",
    "indisposât": "indisposer",
    "indisposâtes": "indisposer",
    "indisposèrent": "indisposer",
    "indisposé": "indisposer",
    "indisposée": "indisposer",
    "indisposées": "indisposer",
    "indisposés": "indisposer",
    "indissociables": "indissociable",
    "indissociés": "indissocié",
    "indissolubles": "indissoluble",
    "indistincte": "indistinct",
    "indistinctes": "indistinct",
    "indistincts": "indistinct",
    "individualisa": "individualiser",
    "individualisai": "individualiser",
    "individualisaient": "individualiser",
    "individualisais": "individualiser",
    "individualisait": "individualiser",
    "individualisant": "individualiser",
    "individualisas": "individualiser",
    "individualisasse": "individualiser",
    "individualisassent": "individualiser",
    "individualisasses": "individualiser",
    "individualisassiez": "individualiser",
    "individualisassions": "individualiser",
    "individualisations": "individualisation",
    "individualise": "individualiser",
    "individualisent": "individualiser",
    "individualisera": "individualiser",
    "individualiserai": "individualiser",
    "individualiseraient": "individualiser",
    "individualiserais": "individualiser",
    "individualiserait": "individualiser",
    "individualiseras": "individualiser",
    "individualiserez": "individualiser",
    "individualiseriez": "individualiser",
    "individualiserions": "individualiser",
    "individualiserons": "individualiser",
    "individualiseront": "individualiser",
    "individualises": "individualiser",
    "individualisez": "individualiser",
    "individualisiez": "individualiser",
    "individualisions": "individualiser",
    "individualismes": "individualisme",
    "individualisons": "individualiser",
    "individualistes": "individualiste",
    "individualisâmes": "individualiser",
    "individualisât": "individualiser",
    "individualisâtes": "individualiser",
    "individualisèrent": "individualiser",
    "individualisé": "individualiser",
    "individualisée": "individualiser",
    "individualisées": "individualiser",
    "individualisés": "individualiser",
    "individualités": "individualité",
    "individuelle": "individuel",
    "individuelles": "individuel",
    "individuels": "individuel",
    "individus": "individu",
    "individuée": "individué",
    "indivise": "indivis",
    "indivises": "indivis",
    "indivisibles": "indivisible",
    "indo-européenne": "indo-européen",
    "indo-européennes": "indo-européen",
    "indo-européens": "indo-européen",
    "indochinoise": "indochinois",
    "indochinoises": "indochinois",
    "indociles": "indocile",
    "indolences": "indolence",
    "indolente": "indolent",
    "indolentes": "indolent",
    "indolents": "indolent",
    "indolores": "indolore",
    "indomptables": "indomptable",
    "indomptée": "indompté",
    "indomptées": "indompté",
    "indomptés": "indompté",
    "indonésienne": "indonésien",
    "indonésiens": "indonésien",
    "indous": "indou",
    "indubitables": "indubitable",
    "inductions": "induction",
    "inductive": "inductif",
    "inductrice": "inducteur",
    "indue": "indu",
    "indues": "indu",
    "induira": "induire",
    "induirai": "induire",
    "induiraient": "induire",
    "induirais": "induire",
    "induirait": "induire",
    "induiras": "induire",
    "induirez": "induire",
    "induiriez": "induire",
    "induirions": "induire",
    "induirons": "induire",
    "induiront": "induire",
    "induis": "induire",
    "induisaient": "induire",
    "induisais": "induire",
    "induisait": "induire",
    "induisant": "induire",
    "induise": "induire",
    "induisent": "induire",
    "induises": "induire",
    "induisez": "induire",
    "induisiez": "induire",
    "induisions": "induire",
    "induisirent": "induire",
    "induisis": "induire",
    "induisisse": "induire",
    "induisissent": "induire",
    "induisisses": "induire",
    "induisissiez": "induire",
    "induisissions": "induire",
    "induisit": "induire",
    "induisons": "induire",
    "induisîmes": "induire",
    "induisît": "induire",
    "induisîtes": "induire",
    "induit": "induire",
    "induite": "induit",
    "induites": "induire",
    "induits": "induire",
    "indulgences": "indulgence",
    "indulgente": "indulgent",
    "indulgentes": "indulgent",
    "indulgents": "indulgent",
    "indura": "indurer",
    "indurai": "indurer",
    "induraient": "indurer",
    "indurais": "indurer",
    "indurait": "indurer",
    "indurant": "indurer",
    "induras": "indurer",
    "indurasse": "indurer",
    "indurassent": "indurer",
    "indurasses": "indurer",
    "indurassiez": "indurer",
    "indurassions": "indurer",
    "indure": "indurer",
    "indurent": "indurer",
    "indurera": "indurer",
    "indurerai": "indurer",
    "indureraient": "indurer",
    "indurerais": "indurer",
    "indurerait": "indurer",
    "indureras": "indurer",
    "indurerez": "indurer",
    "indureriez": "indurer",
    "indurerions": "indurer",
    "indurerons": "indurer",
    "indureront": "indurer",
    "indures": "indurer",
    "indurez": "indurer",
    "induriez": "indurer",
    "indurions": "indurer",
    "indurons": "indurer",
    "indurâmes": "indurer",
    "indurât": "indurer",
    "indurâtes": "indurer",
    "indurèrent": "indurer",
    "induré": "indurer",
    "indurée": "indurer",
    "indurées": "indurer",
    "indurés": "indurer",
    "indus": "indu",
    "industrialisa": "industrialiser",
    "industrialisai": "industrialiser",
    "industrialisaient": "industrialiser",
    "industrialisais": "industrialiser",
    "industrialisait": "industrialiser",
    "industrialisant": "industrialiser",
    "industrialisas": "industrialiser",
    "industrialisasse": "industrialiser",
    "industrialisassent": "industrialiser",
    "industrialisasses": "industrialiser",
    "industrialisassiez": "industrialiser",
    "industrialisassions": "industrialiser",
    "industrialisations": "industrialisation",
    "industrialise": "industrialiser",
    "industrialisent": "industrialiser",
    "industrialisera": "industrialiser",
    "industrialiserai": "industrialiser",
    "industrialiseraient": "industrialiser",
    "industrialiserais": "industrialiser",
    "industrialiserait": "industrialiser",
    "industrialiseras": "industrialiser",
    "industrialiserez": "industrialiser",
    "industrialiseriez": "industrialiser",
    "industrialiserions": "industrialiser",
    "industrialiserons": "industrialiser",
    "industrialiseront": "industrialiser",
    "industrialises": "industrialiser",
    "industrialisez": "industrialiser",
    "industrialisiez": "industrialiser",
    "industrialisions": "industrialiser",
    "industrialisons": "industrialiser",
    "industrialisâmes": "industrialiser",
    "industrialisât": "industrialiser",
    "industrialisâtes": "industrialiser",
    "industrialisèrent": "industrialiser",
    "industrialisé": "industrialiser",
    "industrialisée": "industrialiser",
    "industrialisées": "industrialiser",
    "industrialisés": "industrialiser",
    "industrielle": "industriel",
    "industrielles": "industriel",
    "industriels": "industriel",
    "industries": "industrie",
    "industrieuse": "industrieux",
    "industrieuses": "industrieux",
    "indécelables": "indécelable",
    "indécences": "indécence",
    "indécente": "indécent",
    "indécentes": "indécent",
    "indécents": "indécent",
    "indéchiffrables": "indéchiffrable",
    "indéchirables": "indéchirable",
    "indécidables": "indécidable",
    "indécise": "indécis",
    "indécises": "indécis",
    "indécisions": "indécision",
    "indéclinables": "indéclinable",
    "indécollables": "indécollable",
    "indécomposables": "indécomposable",
    "indécrassables": "indécrassable",
    "indécrottables": "indécrottable",
    "indéfectibles": "indéfectible",
    "indéfendables": "indéfendable",
    "indéfinie": "indéfini",
    "indéfinies": "indéfini",
    "indéfinis": "indéfini",
    "indéfinissables": "indéfinissable",
    "indéformables": "indéformable",
    "indéfrisables": "indéfrisable",
    "indélicate": "indélicat",
    "indélicates": "indélicat",
    "indélicatesses": "indélicatesse",
    "indélicats": "indélicat",
    "indélogeables": "indélogeable",
    "indélébiles": "indélébile",
    "indémaillables": "indémaillable",
    "indémodables": "indémodable",
    "indémontrables": "indémontrable",
    "indémêlables": "indémêlable",
    "indéniables": "indéniable",
    "indénombrables": "indénombrable",
    "indépassables": "indépassable",
    "indépendances": "indépendance",
    "indépendante": "indépendant",
    "indépendantes": "indépendant",
    "indépendantistes": "indépendantiste",
    "indépendants": "indépendant",
    "indéracinables": "indéracinable",
    "indéréglables": "indéréglable",
    "indésirables": "indésirable",
    "indétectables": "indétectable",
    "indéterminations": "indétermination",
    "indéterminée": "indéterminé",
    "indéterminées": "indéterminé",
    "indéterminés": "indéterminé",
    "ineffables": "ineffable",
    "ineffaçables": "ineffaçable",
    "inefficaces": "inefficace",
    "inefficacités": "inefficacité",
    "inemployables": "inemployable",
    "inemployée": "inemployé",
    "inemployées": "inemployé",
    "inemployés": "inemployé",
    "inentamables": "inentamable",
    "inentamée": "inentamé",
    "inentamées": "inentamé",
    "ineptes": "inepte",
    "inepties": "ineptie",
    "inertes": "inerte",
    "inertielle": "inertiel",
    "inertielles": "inertiel",
    "inertiels": "inertiel",
    "inerties": "inertie",
    "inespérée": "inespéré",
    "inespérées": "inespéré",
    "inespérés": "inespéré",
    "inesthétiques": "inesthétique",
    "inestimables": "inestimable",
    "inexacte": "inexact",
    "inexactes": "inexact",
    "inexactitudes": "inexactitude",
    "inexacts": "inexact",
    "inexcusables": "inexcusable",
    "inexercée": "inexercé",
    "inexercées": "inexercé",
    "inexercés": "inexercé",
    "inexigibles": "inexigible",
    "inexistante": "inexistant",
    "inexistantes": "inexistant",
    "inexistants": "inexistant",
    "inexistences": "inexistence",
    "inexorables": "inexorable",
    "inexperte": "inexpert",
    "inexpiée": "inexpié",
    "inexpiées": "inexpié",
    "inexpiés": "inexpié",
    "inexplicables": "inexplicable",
    "inexpliquée": "inexpliqué",
    "inexpliquées": "inexpliqué",
    "inexpliqués": "inexpliqué",
    "inexploitée": "inexploité",
    "inexploitées": "inexploité",
    "inexploités": "inexploité",
    "inexplorée": "inexploré",
    "inexplorées": "inexploré",
    "inexplorés": "inexploré",
    "inexplosibles": "inexplosible",
    "inexpressifs": "inexpressif",
    "inexpressive": "inexpressif",
    "inexpressives": "inexpressif",
    "inexprimables": "inexprimable",
    "inexprimée": "inexprimé",
    "inexprimées": "inexprimé",
    "inexprimés": "inexprimé",
    "inexpugnables": "inexpugnable",
    "inexpériences": "inexpérience",
    "inexpérimentée": "inexpérimenté",
    "inexpérimentées": "inexpérimenté",
    "inexpérimentés": "inexpérimenté",
    "inextensibles": "inextensible",
    "inextinguibles": "inextinguible",
    "inextricables": "inextricable",
    "inexécutions": "inexécution",
    "infaillibilités": "infaillibilité",
    "infaillibles": "infaillible",
    "infaisables": "infaisable",
    "infamante": "infamant",
    "infamantes": "infamant",
    "infamants": "infamant",
    "infamies": "infamie",
    "infante": "infant",
    "infanteries": "infanterie",
    "infantes": "infant",
    "infanticides": "infanticide",
    "infantiles": "infantile",
    "infantilismes": "infantilisme",
    "infantilisé": "infantiliser",
    "infants": "infant",
    "infatigables": "infatigable",
    "infatua": "infatuer",
    "infatuai": "infatuer",
    "infatuaient": "infatuer",
    "infatuais": "infatuer",
    "infatuait": "infatuer",
    "infatuant": "infatuer",
    "infatuas": "infatuer",
    "infatuasse": "infatuer",
    "infatuassent": "infatuer",
    "infatuasses": "infatuer",
    "infatuassiez": "infatuer",
    "infatuassions": "infatuer",
    "infatuations": "infatuation",
    "infatue": "infatuer",
    "infatuent": "infatuer",
    "infatuera": "infatuer",
    "infatuerai": "infatuer",
    "infatueraient": "infatuer",
    "infatuerais": "infatuer",
    "infatuerait": "infatuer",
    "infatueras": "infatuer",
    "infatuerez": "infatuer",
    "infatueriez": "infatuer",
    "infatuerions": "infatuer",
    "infatuerons": "infatuer",
    "infatueront": "infatuer",
    "infatues": "infatuer",
    "infatuez": "infatuer",
    "infatuiez": "infatuer",
    "infatuions": "infatuer",
    "infatuons": "infatuer",
    "infatuâmes": "infatuer",
    "infatuât": "infatuer",
    "infatuâtes": "infatuer",
    "infatuèrent": "infatuer",
    "infatué": "infatuer",
    "infatuée": "infatuer",
    "infatuées": "infatuer",
    "infatués": "infatuer",
    "infecta": "infecter",
    "infectai": "infecter",
    "infectaient": "infecter",
    "infectais": "infecter",
    "infectait": "infecter",
    "infectant": "infecter",
    "infectas": "infecter",
    "infectasse": "infecter",
    "infectassent": "infecter",
    "infectasses": "infecter",
    "infectassiez": "infecter",
    "infectassions": "infecter",
    "infecte": "infecter",
    "infectent": "infecter",
    "infectera": "infecter",
    "infecterai": "infecter",
    "infecteraient": "infecter",
    "infecterais": "infecter",
    "infecterait": "infecter",
    "infecteras": "infecter",
    "infecterez": "infecter",
    "infecteriez": "infecter",
    "infecterions": "infecter",
    "infecterons": "infecter",
    "infecteront": "infecter",
    "infectes": "infecter",
    "infectez": "infecter",
    "infectieuse": "infectieux",
    "infectieuses": "infectieux",
    "infectiez": "infecter",
    "infections": "infection",
    "infectons": "infecter",
    "infects": "infect",
    "infectâmes": "infecter",
    "infectât": "infecter",
    "infectâtes": "infecter",
    "infectèrent": "infecter",
    "infecté": "infecter",
    "infectée": "infecter",
    "infectées": "infecter",
    "infectés": "infecter",
    "infernale": "infernal",
    "infernales": "infernal",
    "infernaux": "infernal",
    "infertiles": "infertile",
    "infesta": "infester",
    "infestai": "infester",
    "infestaient": "infester",
    "infestais": "infester",
    "infestait": "infester",
    "infestant": "infester",
    "infestas": "infester",
    "infestasse": "infester",
    "infestassent": "infester",
    "infestasses": "infester",
    "infestassiez": "infester",
    "infestassions": "infester",
    "infeste": "infester",
    "infestent": "infester",
    "infestera": "infester",
    "infesterai": "infester",
    "infesteraient": "infester",
    "infesterais": "infester",
    "infesterait": "infester",
    "infesteras": "infester",
    "infesterez": "infester",
    "infesteriez": "infester",
    "infesterions": "infester",
    "infesterons": "infester",
    "infesteront": "infester",
    "infestes": "infester",
    "infestez": "infester",
    "infestiez": "infester",
    "infestions": "infester",
    "infestons": "infester",
    "infestâmes": "infester",
    "infestât": "infester",
    "infestâtes": "infester",
    "infestèrent": "infester",
    "infesté": "infester",
    "infestée": "infester",
    "infestées": "infester",
    "infestés": "infester",
    "infibulations": "infibulation",
    "infidèles": "infidèle",
    "infidélités": "infidélité",
    "infiltra": "infiltrer",
    "infiltrai": "infiltrer",
    "infiltraient": "infiltrer",
    "infiltrais": "infiltrer",
    "infiltrait": "infiltrer",
    "infiltrant": "infiltrer",
    "infiltras": "infiltrer",
    "infiltrasse": "infiltrer",
    "infiltrassent": "infiltrer",
    "infiltrasses": "infiltrer",
    "infiltrassiez": "infiltrer",
    "infiltrassions": "infiltrer",
    "infiltrations": "infiltration",
    "infiltre": "infiltrer",
    "infiltrent": "infiltrer",
    "infiltrera": "infiltrer",
    "infiltrerai": "infiltrer",
    "infiltreraient": "infiltrer",
    "infiltrerais": "infiltrer",
    "infiltrerait": "infiltrer",
    "infiltreras": "infiltrer",
    "infiltrerez": "infiltrer",
    "infiltreriez": "infiltrer",
    "infiltrerions": "infiltrer",
    "infiltrerons": "infiltrer",
    "infiltreront": "infiltrer",
    "infiltres": "infiltrer",
    "infiltrez": "infiltrer",
    "infiltriez": "infiltrer",
    "infiltrions": "infiltrer",
    "infiltrons": "infiltrer",
    "infiltrâmes": "infiltrer",
    "infiltrât": "infiltrer",
    "infiltrâtes": "infiltrer",
    "infiltrèrent": "infiltrer",
    "infiltré": "infiltrer",
    "infiltrée": "infiltrer",
    "infiltrées": "infiltrer",
    "infiltrés": "infiltrer",
    "infimes": "infime",
    "infinie": "infini",
    "infinies": "infini",
    "infinis": "infini",
    "infinitifs": "infinitif",
    "infinitive": "infinitif",
    "infinitives": "infinitif",
    "infinités": "infinité",
    "infinitésimale": "infinitésimal",
    "infinitésimales": "infinitésimal",
    "infinitésimaux": "infinitésimal",
    "infirma": "infirmer",
    "infirmai": "infirmer",
    "infirmaient": "infirmer",
    "infirmais": "infirmer",
    "infirmait": "infirmer",
    "infirmant": "infirmer",
    "infirmas": "infirmer",
    "infirmasse": "infirmer",
    "infirmassent": "infirmer",
    "infirmasses": "infirmer",
    "infirmassiez": "infirmer",
    "infirmassions": "infirmer",
    "infirme": "infirmer",
    "infirment": "infirmer",
    "infirmera": "infirmer",
    "infirmerai": "infirmer",
    "infirmeraient": "infirmer",
    "infirmerais": "infirmer",
    "infirmerait": "infirmer",
    "infirmeras": "infirmer",
    "infirmerez": "infirmer",
    "infirmeries": "infirmerie",
    "infirmeriez": "infirmer",
    "infirmerions": "infirmer",
    "infirmerons": "infirmer",
    "infirmeront": "infirmer",
    "infirmes": "infirmer",
    "infirmez": "infirmer",
    "infirmiers": "infirmier",
    "infirmiez": "infirmer",
    "infirmions": "infirmer",
    "infirmités": "infirmité",
    "infirmière": "infirmier",
    "infirmières": "infirmier",
    "infirmons": "infirmer",
    "infirmâmes": "infirmer",
    "infirmât": "infirmer",
    "infirmâtes": "infirmer",
    "infirmèrent": "infirmer",
    "infirmé": "infirmer",
    "infirmée": "infirmer",
    "infirmées": "infirmer",
    "infirmés": "infirmer",
    "inflammables": "inflammable",
    "inflammations": "inflammation",
    "inflammatoires": "inflammatoire",
    "inflationnistes": "inflationniste",
    "inflations": "inflation",
    "inflexibles": "inflexible",
    "inflexions": "inflexion",
    "inflige": "infliger",
    "infligea": "infliger",
    "infligeai": "infliger",
    "infligeaient": "infliger",
    "infligeais": "infliger",
    "infligeait": "infliger",
    "infligeant": "infliger",
    "infligeas": "infliger",
    "infligeasse": "infliger",
    "infligeassent": "infliger",
    "infligeasses": "infliger",
    "infligeassiez": "infliger",
    "infligeassions": "infliger",
    "infligent": "infliger",
    "infligeons": "infliger",
    "infligera": "infliger",
    "infligerai": "infliger",
    "infligeraient": "infliger",
    "infligerais": "infliger",
    "infligerait": "infliger",
    "infligeras": "infliger",
    "infligerez": "infliger",
    "infligeriez": "infliger",
    "infligerions": "infliger",
    "infligerons": "infliger",
    "infligeront": "infliger",
    "infliges": "infliger",
    "infligez": "infliger",
    "infligeâmes": "infliger",
    "infligeât": "infliger",
    "infligeâtes": "infliger",
    "infligiez": "infliger",
    "infligions": "infliger",
    "infligèrent": "infliger",
    "infligé": "infliger",
    "infligée": "infliger",
    "infligées": "infliger",
    "infligés": "infliger",
    "inflorescences": "inflorescence",
    "influa": "influer",
    "influai": "influer",
    "influaient": "influer",
    "influais": "influer",
    "influait": "influer",
    "influant": "influer",
    "influas": "influer",
    "influasse": "influer",
    "influassent": "influer",
    "influasses": "influer",
    "influassiez": "influer",
    "influassions": "influer",
    "influe": "influer",
    "influence": "influencer",
    "influencent": "influencer",
    "influencera": "influencer",
    "influencerai": "influencer",
    "influenceraient": "influencer",
    "influencerais": "influencer",
    "influencerait": "influencer",
    "influenceras": "influencer",
    "influencerez": "influencer",
    "influenceriez": "influencer",
    "influencerions": "influencer",
    "influencerons": "influencer",
    "influenceront": "influencer",
    "influences": "influencer",
    "influencez": "influencer",
    "influenciez": "influencer",
    "influencions": "influencer",
    "influencèrent": "influencer",
    "influencé": "influencer",
    "influencée": "influencer",
    "influencées": "influencer",
    "influencés": "influencer",
    "influent": "influer",
    "influente": "influent",
    "influentes": "influent",
    "influents": "influent",
    "influenzas": "influenza",
    "influença": "influencer",
    "influençables": "influençable",
    "influençai": "influencer",
    "influençaient": "influencer",
    "influençais": "influencer",
    "influençait": "influencer",
    "influençant": "influencer",
    "influenças": "influencer",
    "influençasse": "influencer",
    "influençassent": "influencer",
    "influençasses": "influencer",
    "influençassiez": "influencer",
    "influençassions": "influencer",
    "influençons": "influencer",
    "influençâmes": "influencer",
    "influençât": "influencer",
    "influençâtes": "influencer",
    "influera": "influer",
    "influerai": "influer",
    "influeraient": "influer",
    "influerais": "influer",
    "influerait": "influer",
    "influeras": "influer",
    "influerez": "influer",
    "influeriez": "influer",
    "influerions": "influer",
    "influerons": "influer",
    "influeront": "influer",
    "influes": "influer",
    "influez": "influer",
    "influiez": "influer",
    "influions": "influer",
    "influons": "influer",
    "influâmes": "influer",
    "influât": "influer",
    "influâtes": "influer",
    "influèrent": "influer",
    "influé": "influer",
    "infléchi": "infléchir",
    "infléchie": "infléchir",
    "infléchies": "infléchir",
    "infléchira": "infléchir",
    "infléchirai": "infléchir",
    "infléchiraient": "infléchir",
    "infléchirais": "infléchir",
    "infléchirait": "infléchir",
    "infléchiras": "infléchir",
    "infléchirent": "infléchir",
    "infléchirez": "infléchir",
    "infléchiriez": "infléchir",
    "infléchirions": "infléchir",
    "infléchirons": "infléchir",
    "infléchiront": "infléchir",
    "infléchis": "infléchir",
    "infléchissaient": "infléchir",
    "infléchissais": "infléchir",
    "infléchissait": "infléchir",
    "infléchissant": "infléchir",
    "infléchisse": "infléchir",
    "infléchissements": "infléchissement",
    "infléchissent": "infléchir",
    "infléchisses": "infléchir",
    "infléchissez": "infléchir",
    "infléchissiez": "infléchir",
    "infléchissions": "infléchir",
    "infléchissons": "infléchir",
    "infléchit": "infléchir",
    "infléchîmes": "infléchir",
    "infléchît": "infléchir",
    "infléchîtes": "infléchir",
    "infondée": "infondé",
    "infondées": "infondé",
    "infondés": "infondé",
    "informa": "informer",
    "informai": "informer",
    "informaient": "informer",
    "informais": "informer",
    "informait": "informer",
    "informant": "informer",
    "informas": "informer",
    "informasse": "informer",
    "informassent": "informer",
    "informasses": "informer",
    "informassiez": "informer",
    "informassions": "informer",
    "informateurs": "informateur",
    "informaticienne": "informaticien",
    "informaticiennes": "informaticien",
    "informaticiens": "informaticien",
    "informatifs": "informatif",
    "informations": "information",
    "informatiques": "informatique",
    "informatisations": "informatisation",
    "informatisé": "informatiser",
    "informatisée": "informatiser",
    "informatisées": "informatiser",
    "informatisés": "informatiser",
    "informative": "informatif",
    "informatives": "informatif",
    "informatrice": "informateur",
    "informatrices": "informateur",
    "informe": "informer",
    "informelle": "informel",
    "informelles": "informel",
    "informels": "informel",
    "informent": "informer",
    "informera": "informer",
    "informerai": "informer",
    "informeraient": "informer",
    "informerais": "informer",
    "informerait": "informer",
    "informeras": "informer",
    "informerez": "informer",
    "informeriez": "informer",
    "informerions": "informer",
    "informerons": "informer",
    "informeront": "informer",
    "informes": "informer",
    "informez": "informer",
    "informiez": "informer",
    "informions": "informer",
    "informons": "informer",
    "informulables": "informulable",
    "informulée": "informulé",
    "informulées": "informulé",
    "informulés": "informulé",
    "informâmes": "informer",
    "informât": "informer",
    "informâtes": "informer",
    "informèrent": "informer",
    "informé": "informer",
    "informée": "informer",
    "informées": "informer",
    "informés": "informer",
    "infortunes": "infortune",
    "infortunée": "infortuné",
    "infortunées": "infortuné",
    "infortunés": "infortuné",
    "infos": "info",
    "infoutue": "infoutu",
    "infoutus": "infoutu",
    "infractionnelle": "infractionnel",
    "infractionnelles": "infractionnel",
    "infractionnels": "infractionnel",
    "infractions": "infraction",
    "infranchissables": "infranchissable",
    "infrarouges": "infrarouge",
    "infrarégionale": "infrarégional",
    "infrarégionales": "infrarégional",
    "infrarégionaux": "infrarégional",
    "infrasons": "infrason",
    "infrastructurelle": "infrastructurel",
    "infrastructurelles": "infrastructurel",
    "infrastructurels": "infrastructurel",
    "infrastructures": "infrastructure",
    "infroissables": "infroissable",
    "infructueuse": "infructueux",
    "infructueuses": "infructueux",
    "infréquentables": "infréquentable",
    "infréquentée": "infréquenté",
    "infréquentés": "infréquenté",
    "infumables": "infumable",
    "infusa": "infuser",
    "infusai": "infuser",
    "infusaient": "infuser",
    "infusais": "infuser",
    "infusait": "infuser",
    "infusant": "infuser",
    "infusas": "infuser",
    "infusasse": "infuser",
    "infusassent": "infuser",
    "infusasses": "infuser",
    "infusassiez": "infuser",
    "infusassions": "infuser",
    "infuse": "infuser",
    "infusent": "infuser",
    "infusera": "infuser",
    "infuserai": "infuser",
    "infuseraient": "infuser",
    "infuserais": "infuser",
    "infuserait": "infuser",
    "infuseras": "infuser",
    "infuserez": "infuser",
    "infuseriez": "infuser",
    "infuserions": "infuser",
    "infuserons": "infuser",
    "infuseront": "infuser",
    "infuses": "infuser",
    "infusez": "infuser",
    "infusibles": "infusible",
    "infusiez": "infuser",
    "infusions": "infusion",
    "infusoires": "infusoire",
    "infusons": "infuser",
    "infusâmes": "infuser",
    "infusât": "infuser",
    "infusâtes": "infuser",
    "infusèrent": "infuser",
    "infusé": "infuser",
    "infusée": "infuser",
    "infusées": "infuser",
    "infusés": "infuser",
    "infâmes": "infâme",
    "infère": "inférer",
    "infèrent": "inférer",
    "infères": "inférer",
    "inféconde": "infécond",
    "infécondes": "infécond",
    "inféconds": "infécond",
    "inféoda": "inféoder",
    "inféodai": "inféoder",
    "inféodaient": "inféoder",
    "inféodais": "inféoder",
    "inféodait": "inféoder",
    "inféodant": "inféoder",
    "inféodas": "inféoder",
    "inféodasse": "inféoder",
    "inféodassent": "inféoder",
    "inféodasses": "inféoder",
    "inféodassiez": "inféoder",
    "inféodassions": "inféoder",
    "inféode": "inféoder",
    "inféodent": "inféoder",
    "inféodera": "inféoder",
    "inféoderai": "inféoder",
    "inféoderaient": "inféoder",
    "inféoderais": "inféoder",
    "inféoderait": "inféoder",
    "inféoderas": "inféoder",
    "inféoderez": "inféoder",
    "inféoderiez": "inféoder",
    "inféoderions": "inféoder",
    "inféoderons": "inféoder",
    "inféoderont": "inféoder",
    "inféodes": "inféoder",
    "inféodez": "inféoder",
    "inféodiez": "inféoder",
    "inféodions": "inféoder",
    "inféodons": "inféoder",
    "inféodâmes": "inféoder",
    "inféodât": "inféoder",
    "inféodâtes": "inféoder",
    "inféodèrent": "inféoder",
    "inféodé": "inféoder",
    "inféodée": "inféoder",
    "inféodées": "inféoder",
    "inféodés": "inféoder",
    "inféra": "inférer",
    "inférai": "inférer",
    "inféraient": "inférer",
    "inférais": "inférer",
    "inférait": "inférer",
    "inférant": "inférer",
    "inféras": "inférer",
    "inférasse": "inférer",
    "inférassent": "inférer",
    "inférasses": "inférer",
    "inférassiez": "inférer",
    "inférassions": "inférer",
    "inférera": "inférer",
    "inférerai": "inférer",
    "inféreraient": "inférer",
    "inférerais": "inférer",
    "inférerait": "inférer",
    "inféreras": "inférer",
    "inférerez": "inférer",
    "inféreriez": "inférer",
    "inférerions": "inférer",
    "inférerons": "inférer",
    "inféreront": "inférer",
    "inférez": "inférer",
    "inférieure": "inférieur",
    "inférieures": "inférieur",
    "inférieurs": "inférieur",
    "infériez": "inférer",
    "inférions": "inférer",
    "infériorités": "infériorité",
    "inférons": "inférer",
    "inférâmes": "inférer",
    "inférât": "inférer",
    "inférâtes": "inférer",
    "inférèrent": "inférer",
    "inféré": "inférer",
    "inférée": "inférer",
    "inférées": "inférer",
    "inférés": "inférer",
    "ingagnables": "ingagnable",
    "ingambes": "ingambe",
    "ingestions": "ingestion",
    "ingouvernables": "ingouvernable",
    "ingrate": "ingrat",
    "ingrates": "ingrat",
    "ingratitudes": "ingratitude",
    "ingrats": "ingrat",
    "ingrédients": "ingrédient",
    "inguinale": "inguinal",
    "inguinales": "inguinal",
    "inguinaux": "inguinal",
    "ingurgita": "ingurgiter",
    "ingurgitai": "ingurgiter",
    "ingurgitaient": "ingurgiter",
    "ingurgitais": "ingurgiter",
    "ingurgitait": "ingurgiter",
    "ingurgitant": "ingurgiter",
    "ingurgitas": "ingurgiter",
    "ingurgitasse": "ingurgiter",
    "ingurgitassent": "ingurgiter",
    "ingurgitasses": "ingurgiter",
    "ingurgitassiez": "ingurgiter",
    "ingurgitassions": "ingurgiter",
    "ingurgite": "ingurgiter",
    "ingurgitent": "ingurgiter",
    "ingurgitera": "ingurgiter",
    "ingurgiterai": "ingurgiter",
    "ingurgiteraient": "ingurgiter",
    "ingurgiterais": "ingurgiter",
    "ingurgiterait": "ingurgiter",
    "ingurgiteras": "ingurgiter",
    "ingurgiterez": "ingurgiter",
    "ingurgiteriez": "ingurgiter",
    "ingurgiterions": "ingurgiter",
    "ingurgiterons": "ingurgiter",
    "ingurgiteront": "ingurgiter",
    "ingurgites": "ingurgiter",
    "ingurgitez": "ingurgiter",
    "ingurgitiez": "ingurgiter",
    "ingurgitions": "ingurgiter",
    "ingurgitons": "ingurgiter",
    "ingurgitâmes": "ingurgiter",
    "ingurgitât": "ingurgiter",
    "ingurgitâtes": "ingurgiter",
    "ingurgitèrent": "ingurgiter",
    "ingurgité": "ingurgiter",
    "ingurgitée": "ingurgiter",
    "ingurgitées": "ingurgiter",
    "ingurgités": "ingurgiter",
    "inguérissables": "inguérissable",
    "ingère": "ingérer",
    "ingèrent": "ingérer",
    "ingères": "ingérer",
    "ingénia": "ingénier",
    "ingéniai": "ingénier",
    "ingéniaient": "ingénier",
    "ingéniais": "ingénier",
    "ingéniait": "ingénier",
    "ingéniant": "ingénier",
    "ingénias": "ingénier",
    "ingéniasse": "ingénier",
    "ingéniassent": "ingénier",
    "ingéniasses": "ingénier",
    "ingéniassiez": "ingénier",
    "ingéniassions": "ingénier",
    "ingénie": "ingénier",
    "ingénient": "ingénier",
    "ingéniera": "ingénier",
    "ingénierai": "ingénier",
    "ingénieraient": "ingénier",
    "ingénierais": "ingénier",
    "ingénierait": "ingénier",
    "ingénieras": "ingénier",
    "ingénierez": "ingénier",
    "ingénieries": "ingénierie",
    "ingénieriez": "ingénier",
    "ingénierions": "ingénier",
    "ingénierons": "ingénier",
    "ingénieront": "ingénier",
    "ingénies": "ingénier",
    "ingénieurs": "ingénieur",
    "ingénieuse": "ingénieux",
    "ingénieuses": "ingénieux",
    "ingéniez": "ingénier",
    "ingéniiez": "ingénier",
    "ingéniions": "ingénier",
    "ingénions": "ingénier",
    "ingéniosités": "ingéniosité",
    "ingéniâmes": "ingénier",
    "ingéniât": "ingénier",
    "ingéniâtes": "ingénier",
    "ingénièrent": "ingénier",
    "ingénié": "ingénier",
    "ingéniée": "ingénier",
    "ingéniées": "ingénier",
    "ingéniés": "ingénier",
    "ingénue": "ingénu",
    "ingénues": "ingénu",
    "ingénuités": "ingénuité",
    "ingénus": "ingénu",
    "ingéra": "ingérer",
    "ingérables": "ingérable",
    "ingérai": "ingérer",
    "ingéraient": "ingérer",
    "ingérais": "ingérer",
    "ingérait": "ingérer",
    "ingérant": "ingérer",
    "ingéras": "ingérer",
    "ingérasse": "ingérer",
    "ingérassent": "ingérer",
    "ingérasses": "ingérer",
    "ingérassiez": "ingérer",
    "ingérassions": "ingérer",
    "ingérences": "ingérence",
    "ingérera": "ingérer",
    "ingérerai": "ingérer",
    "ingéreraient": "ingérer",
    "ingérerais": "ingérer",
    "ingérerait": "ingérer",
    "ingéreras": "ingérer",
    "ingérerez": "ingérer",
    "ingéreriez": "ingérer",
    "ingérerions": "ingérer",
    "ingérerons": "ingérer",
    "ingéreront": "ingérer",
    "ingérez": "ingérer",
    "ingériez": "ingérer",
    "ingérions": "ingérer",
    "ingérons": "ingérer",
    "ingérâmes": "ingérer",
    "ingérât": "ingérer",
    "ingérâtes": "ingérer",
    "ingérèrent": "ingérer",
    "ingéré": "ingérer",
    "ingérée": "ingérer",
    "ingérées": "ingérer",
    "ingérés": "ingérer",
    "inhabiles": "inhabile",
    "inhabitables": "inhabitable",
    "inhabituelle": "inhabituel",
    "inhabituelles": "inhabituel",
    "inhabituels": "inhabituel",
    "inhabitée": "inhabité",
    "inhabitées": "inhabité",
    "inhabités": "inhabité",
    "inhala": "inhaler",
    "inhalai": "inhaler",
    "inhalaient": "inhaler",
    "inhalais": "inhaler",
    "inhalait": "inhaler",
    "inhalant": "inhaler",
    "inhalas": "inhaler",
    "inhalasse": "inhaler",
    "inhalassent": "inhaler",
    "inhalasses": "inhaler",
    "inhalassiez": "inhaler",
    "inhalassions": "inhaler",
    "inhalateurs": "inhalateur",
    "inhalations": "inhalation",
    "inhale": "inhaler",
    "inhalent": "inhaler",
    "inhalera": "inhaler",
    "inhalerai": "inhaler",
    "inhaleraient": "inhaler",
    "inhalerais": "inhaler",
    "inhalerait": "inhaler",
    "inhaleras": "inhaler",
    "inhalerez": "inhaler",
    "inhaleriez": "inhaler",
    "inhalerions": "inhaler",
    "inhalerons": "inhaler",
    "inhaleront": "inhaler",
    "inhales": "inhaler",
    "inhalez": "inhaler",
    "inhaliez": "inhaler",
    "inhalions": "inhaler",
    "inhalons": "inhaler",
    "inhalâmes": "inhaler",
    "inhalât": "inhaler",
    "inhalâtes": "inhaler",
    "inhalèrent": "inhaler",
    "inhalé": "inhaler",
    "inhalée": "inhaler",
    "inhalées": "inhaler",
    "inhalés": "inhaler",
    "inharmonieuse": "inharmonieux",
    "inharmonieuses": "inharmonieux",
    "inhiba": "inhiber",
    "inhibai": "inhiber",
    "inhibaient": "inhiber",
    "inhibais": "inhiber",
    "inhibait": "inhiber",
    "inhibant": "inhiber",
    "inhibas": "inhiber",
    "inhibasse": "inhiber",
    "inhibassent": "inhiber",
    "inhibasses": "inhiber",
    "inhibassiez": "inhiber",
    "inhibassions": "inhiber",
    "inhibe": "inhiber",
    "inhibent": "inhiber",
    "inhibera": "inhiber",
    "inhiberai": "inhiber",
    "inhiberaient": "inhiber",
    "inhiberais": "inhiber",
    "inhiberait": "inhiber",
    "inhiberas": "inhiber",
    "inhiberez": "inhiber",
    "inhiberiez": "inhiber",
    "inhiberions": "inhiber",
    "inhiberons": "inhiber",
    "inhiberont": "inhiber",
    "inhibes": "inhiber",
    "inhibez": "inhiber",
    "inhibiez": "inhiber",
    "inhibions": "inhiber",
    "inhibiteurs": "inhibiteur",
    "inhibitions": "inhibition",
    "inhibitrice": "inhibiteur",
    "inhibons": "inhiber",
    "inhibâmes": "inhiber",
    "inhibât": "inhiber",
    "inhibâtes": "inhiber",
    "inhibèrent": "inhiber",
    "inhibé": "inhiber",
    "inhibée": "inhiber",
    "inhibées": "inhiber",
    "inhibés": "inhiber",
    "inhospitaliers": "inhospitalier",
    "inhospitalière": "inhospitalier",
    "inhospitalières": "inhospitalier",
    "inhuma": "inhumer",
    "inhumai": "inhumer",
    "inhumaient": "inhumer",
    "inhumaine": "inhumain",
    "inhumaines": "inhumain",
    "inhumains": "inhumain",
    "inhumais": "inhumer",
    "inhumait": "inhumer",
    "inhumanités": "inhumanité",
    "inhumant": "inhumer",
    "inhumas": "inhumer",
    "inhumasse": "inhumer",
    "inhumassent": "inhumer",
    "inhumasses": "inhumer",
    "inhumassiez": "inhumer",
    "inhumassions": "inhumer",
    "inhumations": "inhumation",
    "inhume": "inhumer",
    "inhument": "inhumer",
    "inhumera": "inhumer",
    "inhumerai": "inhumer",
    "inhumeraient": "inhumer",
    "inhumerais": "inhumer",
    "inhumerait": "inhumer",
    "inhumeras": "inhumer",
    "inhumerez": "inhumer",
    "inhumeriez": "inhumer",
    "inhumerions": "inhumer",
    "inhumerons": "inhumer",
    "inhumeront": "inhumer",
    "inhumes": "inhumer",
    "inhumez": "inhumer",
    "inhumiez": "inhumer",
    "inhumions": "inhumer",
    "inhumons": "inhumer",
    "inhumâmes": "inhumer",
    "inhumât": "inhumer",
    "inhumâtes": "inhumer",
    "inhumèrent": "inhumer",
    "inhumé": "inhumer",
    "inhumée": "inhumer",
    "inhumées": "inhumer",
    "inhumés": "inhumer",
    "inhérente": "inhérent",
    "inhérentes": "inhérent",
    "inhérents": "inhérent",
    "inidentifiables": "inidentifiable",
    "inimaginables": "inimaginable",
    "inimitables": "inimitable",
    "inimitiés": "inimitié",
    "inimitée": "inimité",
    "inimitées": "inimité",
    "inimités": "inimité",
    "ininflammables": "ininflammable",
    "inintelligences": "inintelligence",
    "inintelligente": "inintelligent",
    "inintelligentes": "inintelligent",
    "inintelligents": "inintelligent",
    "inintelligibles": "inintelligible",
    "ininterprétables": "ininterprétable",
    "ininterrompue": "ininterrompu",
    "ininterrompues": "ininterrompu",
    "ininterrompus": "ininterrompu",
    "inintéressante": "inintéressant",
    "inintéressantes": "inintéressant",
    "inintéressants": "inintéressant",
    "iniques": "inique",
    "iniquités": "iniquité",
    "initia": "initier",
    "initiai": "initier",
    "initiaient": "initier",
    "initiais": "initier",
    "initiait": "initier",
    "initiale": "initial",
    "initiales": "initiale",
    "initialise": "initialiser",
    "initialisez": "initialiser",
    "initialisé": "initialiser",
    "initialisée": "initialisé",
    "initialisés": "initialisé",
    "initiant": "initier",
    "initias": "initier",
    "initiasse": "initier",
    "initiassent": "initier",
    "initiasses": "initier",
    "initiassiez": "initier",
    "initiassions": "initier",
    "initiateurs": "initiateur",
    "initiations": "initiation",
    "initiatiques": "initiatique",
    "initiatives": "initiative",
    "initiatrice": "initiateur",
    "initiatrices": "initiateur",
    "initiaux": "initial",
    "initie": "initier",
    "initient": "initier",
    "initiera": "initier",
    "initierai": "initier",
    "initieraient": "initier",
    "initierais": "initier",
    "initierait": "initier",
    "initieras": "initier",
    "initierez": "initier",
    "initieriez": "initier",
    "initierions": "initier",
    "initierons": "initier",
    "initieront": "initier",
    "inities": "initier",
    "initiez": "initier",
    "initiiez": "initier",
    "initiions": "initier",
    "initions": "initier",
    "initiâmes": "initier",
    "initiât": "initier",
    "initiâtes": "initier",
    "initièrent": "initier",
    "initié": "initier",
    "initiée": "initier",
    "initiées": "initier",
    "initiés": "initier",
    "injecta": "injecter",
    "injectai": "injecter",
    "injectaient": "injecter",
    "injectais": "injecter",
    "injectait": "injecter",
    "injectant": "injecter",
    "injectas": "injecter",
    "injectasse": "injecter",
    "injectassent": "injecter",
    "injectasses": "injecter",
    "injectassiez": "injecter",
    "injectassions": "injecter",
    "injecte": "injecter",
    "injectent": "injecter",
    "injectera": "injecter",
    "injecterai": "injecter",
    "injecteraient": "injecter",
    "injecterais": "injecter",
    "injecterait": "injecter",
    "injecteras": "injecter",
    "injecterez": "injecter",
    "injecteriez": "injecter",
    "injecterions": "injecter",
    "injecterons": "injecter",
    "injecteront": "injecter",
    "injectes": "injecter",
    "injecteurs": "injecteur",
    "injectez": "injecter",
    "injectiez": "injecter",
    "injections": "injection",
    "injectons": "injecter",
    "injectâmes": "injecter",
    "injectât": "injecter",
    "injectâtes": "injecter",
    "injectèrent": "injecter",
    "injecté": "injecter",
    "injectée": "injecter",
    "injectées": "injecter",
    "injectés": "injecter",
    "injoignables": "injoignable",
    "injonctions": "injonction",
    "injouables": "injouable",
    "injures": "injure",
    "injuria": "injurier",
    "injuriai": "injurier",
    "injuriaient": "injurier",
    "injuriais": "injurier",
    "injuriait": "injurier",
    "injuriant": "injurier",
    "injurie": "injurier",
    "injurient": "injurier",
    "injuries": "injurier",
    "injurieuse": "injurieux",
    "injurié": "injurier",
    "injuriée": "injurier",
    "injuriés": "injurier",
    "injustes": "injuste",
    "injustices": "injustice",
    "injustifiables": "injustifiable",
    "injustifiée": "injustifié",
    "injustifiées": "injustifié",
    "injustifiés": "injustifié",
    "inlassables": "inlassable",
    "inlays": "inlay",
    "innerva": "innerver",
    "innervai": "innerver",
    "innervaient": "innerver",
    "innervais": "innerver",
    "innervait": "innerver",
    "innervant": "innerver",
    "innervas": "innerver",
    "innervasse": "innerver",
    "innervassent": "innerver",
    "innervasses": "innerver",
    "innervassiez": "innerver",
    "innervassions": "innerver",
    "innerve": "innerver",
    "innervent": "innerver",
    "innervera": "innerver",
    "innerverai": "innerver",
    "innerveraient": "innerver",
    "innerverais": "innerver",
    "innerverait": "innerver",
    "innerveras": "innerver",
    "innerverez": "innerver",
    "innerveriez": "innerver",
    "innerverions": "innerver",
    "innerverons": "innerver",
    "innerveront": "innerver",
    "innerves": "innerver",
    "innervez": "innerver",
    "innerviez": "innerver",
    "innervions": "innerver",
    "innervons": "innerver",
    "innervâmes": "innerver",
    "innervât": "innerver",
    "innervâtes": "innerver",
    "innervèrent": "innerver",
    "innervé": "innerver",
    "innervée": "innerver",
    "innervées": "innerver",
    "innervés": "innerver",
    "innocences": "innocence",
    "innocentait": "innocenter",
    "innocentant": "innocenter",
    "innocente": "innocenter",
    "innocentera": "innocenter",
    "innocenterai": "innocenter",
    "innocenterait": "innocenter",
    "innocentes": "innocenter",
    "innocents": "innocent",
    "innocenté": "innocenter",
    "innocentée": "innocenter",
    "innocuités": "innocuité",
    "innombrables": "innombrable",
    "innominés": "innominé",
    "innommables": "innommable",
    "innommée": "innommé",
    "innommées": "innommé",
    "innommés": "innommé",
    "innomée": "innomé",
    "innomées": "innomé",
    "innomés": "innomé",
    "innova": "innover",
    "innovai": "innover",
    "innovaient": "innover",
    "innovais": "innover",
    "innovait": "innover",
    "innovant": "innover",
    "innovante": "innovant",
    "innovantes": "innovant",
    "innovants": "innovant",
    "innovas": "innover",
    "innovasse": "innover",
    "innovassent": "innover",
    "innovasses": "innover",
    "innovassiez": "innover",
    "innovassions": "innover",
    "innovateurs": "innovateur",
    "innovations": "innovation",
    "innovatrice": "innovateur",
    "innovatrices": "innovateur",
    "innove": "innover",
    "innovent": "innover",
    "innovera": "innover",
    "innoverai": "innover",
    "innoveraient": "innover",
    "innoverais": "innover",
    "innoverait": "innover",
    "innoveras": "innover",
    "innoverez": "innover",
    "innoveriez": "innover",
    "innoverions": "innover",
    "innoverons": "innover",
    "innoveront": "innover",
    "innoves": "innover",
    "innovez": "innover",
    "innoviez": "innover",
    "innovions": "innover",
    "innovons": "innover",
    "innovâmes": "innover",
    "innovât": "innover",
    "innovâtes": "innover",
    "innovèrent": "innover",
    "innové": "innover",
    "innovée": "innover",
    "innovées": "innover",
    "innovés": "innover",
    "innée": "inné",
    "innées": "inné",
    "innés": "inné",
    "inobservances": "inobservance",
    "inobservations": "inobservation",
    "inobservée": "inobservé",
    "inobservées": "inobservé",
    "inobservés": "inobservé",
    "inoccupations": "inoccupation",
    "inoccupée": "inoccupé",
    "inoccupées": "inoccupé",
    "inoccupés": "inoccupé",
    "inocula": "inoculer",
    "inoculai": "inoculer",
    "inoculaient": "inoculer",
    "inoculais": "inoculer",
    "inoculait": "inoculer",
    "inoculant": "inoculer",
    "inoculas": "inoculer",
    "inoculasse": "inoculer",
    "inoculassent": "inoculer",
    "inoculasses": "inoculer",
    "inoculassiez": "inoculer",
    "inoculassions": "inoculer",
    "inocule": "inoculer",
    "inoculent": "inoculer",
    "inoculera": "inoculer",
    "inoculerai": "inoculer",
    "inoculeraient": "inoculer",
    "inoculerais": "inoculer",
    "inoculerait": "inoculer",
    "inoculeras": "inoculer",
    "inoculerez": "inoculer",
    "inoculeriez": "inoculer",
    "inoculerions": "inoculer",
    "inoculerons": "inoculer",
    "inoculeront": "inoculer",
    "inocules": "inoculer",
    "inoculez": "inoculer",
    "inoculiez": "inoculer",
    "inoculions": "inoculer",
    "inoculons": "inoculer",
    "inoculâmes": "inoculer",
    "inoculât": "inoculer",
    "inoculâtes": "inoculer",
    "inoculèrent": "inoculer",
    "inoculé": "inoculer",
    "inoculée": "inoculer",
    "inoculées": "inoculer",
    "inoculés": "inoculer",
    "inodores": "inodore",
    "inoffensifs": "inoffensif",
    "inoffensive": "inoffensif",
    "inoffensives": "inoffensif",
    "inonda": "inonder",
    "inondables": "inondable",
    "inondai": "inonder",
    "inondaient": "inonder",
    "inondais": "inonder",
    "inondait": "inonder",
    "inondant": "inonder",
    "inondas": "inonder",
    "inondasse": "inonder",
    "inondassent": "inonder",
    "inondasses": "inonder",
    "inondassiez": "inonder",
    "inondassions": "inonder",
    "inondations": "inondation",
    "inonde": "inonder",
    "inondent": "inonder",
    "inondera": "inonder",
    "inonderai": "inonder",
    "inonderaient": "inonder",
    "inonderais": "inonder",
    "inonderait": "inonder",
    "inonderas": "inonder",
    "inonderez": "inonder",
    "inonderiez": "inonder",
    "inonderions": "inonder",
    "inonderons": "inonder",
    "inonderont": "inonder",
    "inondes": "inonder",
    "inondez": "inonder",
    "inondiez": "inonder",
    "inondions": "inonder",
    "inondons": "inonder",
    "inondâmes": "inonder",
    "inondât": "inonder",
    "inondâtes": "inonder",
    "inondèrent": "inonder",
    "inondé": "inonder",
    "inondée": "inonder",
    "inondées": "inonder",
    "inondés": "inonder",
    "inopinée": "inopiné",
    "inopinées": "inopiné",
    "inopinés": "inopiné",
    "inopportune": "inopportun",
    "inopportunes": "inopportun",
    "inopportunités": "inopportunité",
    "inopportuns": "inopportun",
    "inopposables": "inopposable",
    "inopérables": "inopérable",
    "inopérante": "inopérant",
    "inopérantes": "inopérant",
    "inopérants": "inopérant",
    "inorganisations": "inorganisation",
    "inorganisée": "inorganisé",
    "inorganisées": "inorganisé",
    "inorganisés": "inorganisé",
    "inoubliables": "inoubliable",
    "inoubliées": "inoublié",
    "inouïe": "inouï",
    "inouïes": "inouï",
    "inouïs": "inouï",
    "inoxydables": "inoxydable",
    "inqualifiables": "inqualifiable",
    "inquiets": "inquiet",
    "inquisiteurs": "inquisiteur",
    "inquisitions": "inquisition",
    "inquisitive": "inquisitif",
    "inquisitoriale": "inquisitorial",
    "inquisitoriales": "inquisitorial",
    "inquisitoriaux": "inquisitorial",
    "inquisitrice": "inquisiteur",
    "inquisitrices": "inquisiteur",
    "inquiète": "inquiéter",
    "inquiètent": "inquiéter",
    "inquiètes": "inquiéter",
    "inquiéta": "inquiéter",
    "inquiétai": "inquiéter",
    "inquiétaient": "inquiéter",
    "inquiétais": "inquiéter",
    "inquiétait": "inquiéter",
    "inquiétant": "inquiéter",
    "inquiétante": "inquiétant",
    "inquiétantes": "inquiétant",
    "inquiétants": "inquiétant",
    "inquiétas": "inquiéter",
    "inquiétasse": "inquiéter",
    "inquiétassent": "inquiéter",
    "inquiétasses": "inquiéter",
    "inquiétassiez": "inquiéter",
    "inquiétassions": "inquiéter",
    "inquiétera": "inquiéter",
    "inquiéterai": "inquiéter",
    "inquiéteraient": "inquiéter",
    "inquiéterais": "inquiéter",
    "inquiéterait": "inquiéter",
    "inquiéteras": "inquiéter",
    "inquiéterez": "inquiéter",
    "inquiéteriez": "inquiéter",
    "inquiéterions": "inquiéter",
    "inquiéterons": "inquiéter",
    "inquiéteront": "inquiéter",
    "inquiétez": "inquiéter",
    "inquiétiez": "inquiéter",
    "inquiétions": "inquiéter",
    "inquiétons": "inquiéter",
    "inquiétudes": "inquiétude",
    "inquiétâmes": "inquiéter",
    "inquiétât": "inquiéter",
    "inquiétâtes": "inquiéter",
    "inquiétèrent": "inquiéter",
    "inquiété": "inquiéter",
    "inquiétée": "inquiéter",
    "inquiétées": "inquiéter",
    "inquiétés": "inquiéter",
    "inracontables": "inracontable",
    "insaisissables": "insaisissable",
    "insalissables": "insalissable",
    "insalubres": "insalubre",
    "insanes": "insane",
    "insanités": "insanité",
    "insatiables": "insatiable",
    "insatisfactions": "insatisfaction",
    "insatisfaisante": "insatisfaisant",
    "insatisfaisantes": "insatisfaisant",
    "insatisfaisants": "insatisfaisant",
    "insatisfaite": "insatisfait",
    "insatisfaites": "insatisfait",
    "insatisfaits": "insatisfait",
    "inscriptions": "inscription",
    "inscrira": "inscrire",
    "inscrirai": "inscrire",
    "inscriraient": "inscrire",
    "inscrirais": "inscrire",
    "inscrirait": "inscrire",
    "inscriras": "inscrire",
    "inscrirez": "inscrire",
    "inscririez": "inscrire",
    "inscririons": "inscrire",
    "inscrirons": "inscrire",
    "inscriront": "inscrire",
    "inscris": "inscrire",
    "inscrit": "inscrire",
    "inscrite": "inscrit",
    "inscrites": "inscrit",
    "inscrits": "inscrit",
    "inscrivaient": "inscrire",
    "inscrivais": "inscrire",
    "inscrivait": "inscrire",
    "inscrivant": "inscrire",
    "inscrive": "inscrire",
    "inscrivent": "inscrire",
    "inscrives": "inscrire",
    "inscrivez": "inscrire",
    "inscriviez": "inscrire",
    "inscrivions": "inscrire",
    "inscrivirent": "inscrire",
    "inscrivis": "inscrire",
    "inscrivisse": "inscrire",
    "inscrivissent": "inscrire",
    "inscrivisses": "inscrire",
    "inscrivissiez": "inscrire",
    "inscrivissions": "inscrire",
    "inscrivit": "inscrire",
    "inscrivons": "inscrire",
    "inscrivîmes": "inscrire",
    "inscrivît": "inscrire",
    "inscrivîtes": "inscrire",
    "insectariums": "insectarium",
    "insectes": "insecte",
    "insecticides": "insecticide",
    "insensibilisait": "insensibiliser",
    "insensibilisé": "insensibiliser",
    "insensibilisée": "insensibiliser",
    "insensibilités": "insensibilité",
    "insensibles": "insensible",
    "insensée": "insensé",
    "insensées": "insensé",
    "insensés": "insensé",
    "insertions": "insertion",
    "inserts": "insert",
    "insidieuse": "insidieux",
    "insidieuses": "insidieux",
    "insights": "insight",
    "insignes": "insigne",
    "insignifiances": "insignifiance",
    "insignifiante": "insignifiant",
    "insignifiantes": "insignifiant",
    "insignifiants": "insignifiant",
    "insinua": "insinuer",
    "insinuai": "insinuer",
    "insinuaient": "insinuer",
    "insinuais": "insinuer",
    "insinuait": "insinuer",
    "insinuant": "insinuer",
    "insinuante": "insinuant",
    "insinuantes": "insinuant",
    "insinuants": "insinuant",
    "insinuas": "insinuer",
    "insinuasse": "insinuer",
    "insinuassent": "insinuer",
    "insinuasses": "insinuer",
    "insinuassiez": "insinuer",
    "insinuassions": "insinuer",
    "insinuations": "insinuation",
    "insinue": "insinuer",
    "insinuent": "insinuer",
    "insinuera": "insinuer",
    "insinuerai": "insinuer",
    "insinueraient": "insinuer",
    "insinuerais": "insinuer",
    "insinuerait": "insinuer",
    "insinueras": "insinuer",
    "insinuerez": "insinuer",
    "insinueriez": "insinuer",
    "insinuerions": "insinuer",
    "insinuerons": "insinuer",
    "insinueront": "insinuer",
    "insinues": "insinuer",
    "insinuez": "insinuer",
    "insinuiez": "insinuer",
    "insinuions": "insinuer",
    "insinuons": "insinuer",
    "insinuâmes": "insinuer",
    "insinuât": "insinuer",
    "insinuâtes": "insinuer",
    "insinuèrent": "insinuer",
    "insinué": "insinuer",
    "insinuée": "insinuer",
    "insinuées": "insinuer",
    "insinués": "insinuer",
    "insipides": "insipide",
    "insista": "insister",
    "insistai": "insister",
    "insistaient": "insister",
    "insistais": "insister",
    "insistait": "insister",
    "insistances": "insistance",
    "insistant": "insister",
    "insistante": "insistant",
    "insistantes": "insistant",
    "insistants": "insistant",
    "insistas": "insister",
    "insistasse": "insister",
    "insistassent": "insister",
    "insistasses": "insister",
    "insistassiez": "insister",
    "insistassions": "insister",
    "insiste": "insister",
    "insistent": "insister",
    "insistera": "insister",
    "insisterai": "insister",
    "insisteraient": "insister",
    "insisterais": "insister",
    "insisterait": "insister",
    "insisteras": "insister",
    "insisterez": "insister",
    "insisteriez": "insister",
    "insisterions": "insister",
    "insisterons": "insister",
    "insisteront": "insister",
    "insistes": "insister",
    "insistez": "insister",
    "insistiez": "insister",
    "insistions": "insister",
    "insistons": "insister",
    "insistâmes": "insister",
    "insistât": "insister",
    "insistâtes": "insister",
    "insistèrent": "insister",
    "insisté": "insister",
    "insolant": "insoler",
    "insolations": "insolation",
    "insolences": "insolence",
    "insolent": "insoler",
    "insolente": "insolent",
    "insolentes": "insolent",
    "insolents": "insolent",
    "insolites": "insolite",
    "insolubles": "insoluble",
    "insolvabilités": "insolvabilité",
    "insolvables": "insolvable",
    "insolé": "insoler",
    "insomniaques": "insomniaque",
    "insomnies": "insomnie",
    "insomnieuse": "insomnieux",
    "insondables": "insondable",
    "insonores": "insonore",
    "insonorisa": "insonoriser",
    "insonorisai": "insonoriser",
    "insonorisaient": "insonoriser",
    "insonorisais": "insonoriser",
    "insonorisait": "insonoriser",
    "insonorisant": "insonoriser",
    "insonorisas": "insonoriser",
    "insonorisasse": "insonoriser",
    "insonorisassent": "insonoriser",
    "insonorisasses": "insonoriser",
    "insonorisassiez": "insonoriser",
    "insonorisassions": "insonoriser",
    "insonorisations": "insonorisation",
    "insonorise": "insonoriser",
    "insonorisent": "insonoriser",
    "insonorisera": "insonoriser",
    "insonoriserai": "insonoriser",
    "insonoriseraient": "insonoriser",
    "insonoriserais": "insonoriser",
    "insonoriserait": "insonoriser",
    "insonoriseras": "insonoriser",
    "insonoriserez": "insonoriser",
    "insonoriseriez": "insonoriser",
    "insonoriserions": "insonoriser",
    "insonoriserons": "insonoriser",
    "insonoriseront": "insonoriser",
    "insonorises": "insonoriser",
    "insonorisez": "insonoriser",
    "insonorisiez": "insonoriser",
    "insonorisions": "insonoriser",
    "insonorisons": "insonoriser",
    "insonorisâmes": "insonoriser",
    "insonorisât": "insonoriser",
    "insonorisâtes": "insonoriser",
    "insonorisèrent": "insonoriser",
    "insonorisé": "insonoriser",
    "insonorisée": "insonoriser",
    "insonorisées": "insonoriser",
    "insonorisés": "insonoriser",
    "insortables": "insortable",
    "insouciances": "insouciance",
    "insouciante": "insouciant",
    "insouciantes": "insouciant",
    "insouciants": "insouciant",
    "insoucieuse": "insoucieux",
    "insoulevables": "insoulevable",
    "insoumise": "insoumis",
    "insoumises": "insoumis",
    "insoumissions": "insoumission",
    "insoupçonnables": "insoupçonnable",
    "insoupçonnée": "insoupçonné",
    "insoupçonnées": "insoupçonné",
    "insoupçonnés": "insoupçonné",
    "insoutenables": "insoutenable",
    "inspecta": "inspecter",
    "inspectai": "inspecter",
    "inspectaient": "inspecter",
    "inspectais": "inspecter",
    "inspectait": "inspecter",
    "inspectant": "inspecter",
    "inspectas": "inspecter",
    "inspectasse": "inspecter",
    "inspectassent": "inspecter",
    "inspectasses": "inspecter",
    "inspectassiez": "inspecter",
    "inspectassions": "inspecter",
    "inspecte": "inspecter",
    "inspectent": "inspecter",
    "inspectera": "inspecter",
    "inspecterai": "inspecter",
    "inspecteraient": "inspecter",
    "inspecterais": "inspecter",
    "inspecterait": "inspecter",
    "inspecteras": "inspecter",
    "inspecterez": "inspecter",
    "inspecteriez": "inspecter",
    "inspecterions": "inspecter",
    "inspecterons": "inspecter",
    "inspecteront": "inspecter",
    "inspectes": "inspecter",
    "inspecteurs": "inspecteur",
    "inspectez": "inspecter",
    "inspectiez": "inspecter",
    "inspections": "inspection",
    "inspectons": "inspecter",
    "inspectrice": "inspecteur",
    "inspectrices": "inspecteur",
    "inspectâmes": "inspecter",
    "inspectât": "inspecter",
    "inspectâtes": "inspecter",
    "inspectèrent": "inspecter",
    "inspecté": "inspecter",
    "inspectée": "inspecter",
    "inspectées": "inspecter",
    "inspectés": "inspecter",
    "inspira": "inspirer",
    "inspirai": "inspirer",
    "inspiraient": "inspirer",
    "inspirais": "inspirer",
    "inspirait": "inspirer",
    "inspirant": "inspirer",
    "inspirante": "inspirant",
    "inspirantes": "inspirant",
    "inspirants": "inspirant",
    "inspiras": "inspirer",
    "inspirasse": "inspirer",
    "inspirassent": "inspirer",
    "inspirasses": "inspirer",
    "inspirassiez": "inspirer",
    "inspirassions": "inspirer",
    "inspirateurs": "inspirateur",
    "inspirations": "inspiration",
    "inspiratrice": "inspirateur",
    "inspiratrices": "inspirateur",
    "inspire": "inspirer",
    "inspirent": "inspirer",
    "inspirera": "inspirer",
    "inspirerai": "inspirer",
    "inspireraient": "inspirer",
    "inspirerais": "inspirer",
    "inspirerait": "inspirer",
    "inspireras": "inspirer",
    "inspirerez": "inspirer",
    "inspireriez": "inspirer",
    "inspirerions": "inspirer",
    "inspirerons": "inspirer",
    "inspireront": "inspirer",
    "inspires": "inspirer",
    "inspirez": "inspirer",
    "inspiriez": "inspirer",
    "inspirions": "inspirer",
    "inspirons": "inspirer",
    "inspirâmes": "inspirer",
    "inspirât": "inspirer",
    "inspirâtes": "inspirer",
    "inspirèrent": "inspirer",
    "inspiré": "inspirer",
    "inspirée": "inspirer",
    "inspirées": "inspirer",
    "inspirés": "inspirer",
    "instabilités": "instabilité",
    "instables": "instable",
    "installa": "installer",
    "installai": "installer",
    "installaient": "installer",
    "installais": "installer",
    "installait": "installer",
    "installant": "installer",
    "installas": "installer",
    "installasse": "installer",
    "installassent": "installer",
    "installasses": "installer",
    "installassiez": "installer",
    "installassions": "installer",
    "installateurs": "installateur",
    "installations": "installation",
    "installe": "installer",
    "installent": "installer",
    "installera": "installer",
    "installerai": "installer",
    "installeraient": "installer",
    "installerais": "installer",
    "installerait": "installer",
    "installeras": "installer",
    "installerez": "installer",
    "installeriez": "installer",
    "installerions": "installer",
    "installerons": "installer",
    "installeront": "installer",
    "installes": "installer",
    "installez": "installer",
    "installiez": "installer",
    "installions": "installer",
    "installons": "installer",
    "installâmes": "installer",
    "installât": "installer",
    "installâtes": "installer",
    "installèrent": "installer",
    "installé": "installer",
    "installée": "installer",
    "installées": "installer",
    "installés": "installer",
    "instances": "instance",
    "instantanée": "instantané",
    "instantanées": "instantané",
    "instantanés": "instantané",
    "instante": "instant",
    "instantes": "instant",
    "instants": "instant",
    "instaura": "instaurer",
    "instaurai": "instaurer",
    "instauraient": "instaurer",
    "instaurais": "instaurer",
    "instaurait": "instaurer",
    "instaurant": "instaurer",
    "instauras": "instaurer",
    "instaurasse": "instaurer",
    "instaurassent": "instaurer",
    "instaurasses": "instaurer",
    "instaurassiez": "instaurer",
    "instaurassions": "instaurer",
    "instaurations": "instauration",
    "instauratrice": "instaurateur",
    "instaure": "instaurer",
    "instaurent": "instaurer",
    "instaurera": "instaurer",
    "instaurerai": "instaurer",
    "instaureraient": "instaurer",
    "instaurerais": "instaurer",
    "instaurerait": "instaurer",
    "instaureras": "instaurer",
    "instaurerez": "instaurer",
    "instaureriez": "instaurer",
    "instaurerions": "instaurer",
    "instaurerons": "instaurer",
    "instaureront": "instaurer",
    "instaures": "instaurer",
    "instaurez": "instaurer",
    "instauriez": "instaurer",
    "instaurions": "instaurer",
    "instaurons": "instaurer",
    "instaurâmes": "instaurer",
    "instaurât": "instaurer",
    "instaurâtes": "instaurer",
    "instaurèrent": "instaurer",
    "instauré": "instaurer",
    "instaurée": "instaurer",
    "instaurées": "instaurer",
    "instaurés": "instaurer",
    "instigateurs": "instigateur",
    "instigations": "instigation",
    "instigatrice": "instigateur",
    "instigatrices": "instigateur",
    "instilla": "instiller",
    "instillai": "instiller",
    "instillaient": "instiller",
    "instillais": "instiller",
    "instillait": "instiller",
    "instillant": "instiller",
    "instillas": "instiller",
    "instillasse": "instiller",
    "instillassent": "instiller",
    "instillasses": "instiller",
    "instillassiez": "instiller",
    "instillassions": "instiller",
    "instille": "instiller",
    "instillent": "instiller",
    "instillera": "instiller",
    "instillerai": "instiller",
    "instilleraient": "instiller",
    "instillerais": "instiller",
    "instillerait": "instiller",
    "instilleras": "instiller",
    "instillerez": "instiller",
    "instilleriez": "instiller",
    "instillerions": "instiller",
    "instillerons": "instiller",
    "instilleront": "instiller",
    "instilles": "instiller",
    "instillez": "instiller",
    "instilliez": "instiller",
    "instillions": "instiller",
    "instillons": "instiller",
    "instillâmes": "instiller",
    "instillât": "instiller",
    "instillâtes": "instiller",
    "instillèrent": "instiller",
    "instillé": "instiller",
    "instillée": "instiller",
    "instillées": "instiller",
    "instillés": "instiller",
    "instinctifs": "instinctif",
    "instinctive": "instinctif",
    "instinctives": "instinctif",
    "instincts": "instinct",
    "instits": "instit",
    "institua": "instituer",
    "instituai": "instituer",
    "instituaient": "instituer",
    "instituais": "instituer",
    "instituait": "instituer",
    "instituant": "instituer",
    "instituas": "instituer",
    "instituasse": "instituer",
    "instituassent": "instituer",
    "instituasses": "instituer",
    "instituassiez": "instituer",
    "instituassions": "instituer",
    "institue": "instituer",
    "instituent": "instituer",
    "instituera": "instituer",
    "instituerai": "instituer",
    "institueraient": "instituer",
    "instituerais": "instituer",
    "instituerait": "instituer",
    "institueras": "instituer",
    "instituerez": "instituer",
    "institueriez": "instituer",
    "instituerions": "instituer",
    "instituerons": "instituer",
    "institueront": "instituer",
    "institues": "instituer",
    "instituez": "instituer",
    "instituiez": "instituer",
    "instituions": "instituer",
    "instituons": "instituer",
    "instituteurs": "instituteur",
    "institutionnalisa": "institutionnaliser",
    "institutionnalisai": "institutionnaliser",
    "institutionnalisaient": "institutionnaliser",
    "institutionnalisais": "institutionnaliser",
    "institutionnalisait": "institutionnaliser",
    "institutionnalisant": "institutionnaliser",
    "institutionnalisas": "institutionnaliser",
    "institutionnalisasse": "institutionnaliser",
    "institutionnalisassent": "institutionnaliser",
    "institutionnalisasses": "institutionnaliser",
    "institutionnalisassiez": "institutionnaliser",
    "institutionnalisassions": "institutionnaliser",
    "institutionnalisations": "institutionnalisation",
    "institutionnalise": "institutionnaliser",
    "institutionnalisent": "institutionnaliser",
    "institutionnalisera": "institutionnaliser",
    "institutionnaliserai": "institutionnaliser",
    "institutionnaliseraient": "institutionnaliser",
    "institutionnaliserais": "institutionnaliser",
    "institutionnaliserait": "institutionnaliser",
    "institutionnaliseras": "institutionnaliser",
    "institutionnaliserez": "institutionnaliser",
    "institutionnaliseriez": "institutionnaliser",
    "institutionnaliserions": "institutionnaliser",
    "institutionnaliserons": "institutionnaliser",
    "institutionnaliseront": "institutionnaliser",
    "institutionnalises": "institutionnaliser",
    "institutionnalisez": "institutionnaliser",
    "institutionnalisiez": "institutionnaliser",
    "institutionnalisions": "institutionnaliser",
    "institutionnalisons": "institutionnaliser",
    "institutionnalisâmes": "institutionnaliser",
    "institutionnalisât": "institutionnaliser",
    "institutionnalisâtes": "institutionnaliser",
    "institutionnalisèrent": "institutionnaliser",
    "institutionnalisé": "institutionnaliser",
    "institutionnalisée": "institutionnaliser",
    "institutionnalisées": "institutionnaliser",
    "institutionnalisés": "institutionnaliser",
    "institutionnelle": "institutionnel",
    "institutionnelles": "institutionnel",
    "institutionnels": "institutionnel",
    "institutions": "institution",
    "institutrice": "instituteur",
    "institutrices": "instituteur",
    "instituts": "institut",
    "instituâmes": "instituer",
    "instituât": "instituer",
    "instituâtes": "instituer",
    "instituèrent": "instituer",
    "institué": "instituer",
    "instituée": "instituer",
    "instituées": "instituer",
    "institués": "instituer",
    "instructeurs": "instructeur",
    "instructifs": "instructif",
    "instructions": "instruction",
    "instructive": "instructif",
    "instructives": "instructif",
    "instructrice": "instructeur",
    "instructrices": "instructeur",
    "instruira": "instruire",
    "instruirai": "instruire",
    "instruiraient": "instruire",
    "instruirais": "instruire",
    "instruirait": "instruire",
    "instruiras": "instruire",
    "instruirez": "instruire",
    "instruiriez": "instruire",
    "instruirions": "instruire",
    "instruirons": "instruire",
    "instruiront": "instruire",
    "instruis": "instruire",
    "instruisaient": "instruire",
    "instruisais": "instruire",
    "instruisait": "instruire",
    "instruisant": "instruire",
    "instruise": "instruire",
    "instruisent": "instruire",
    "instruises": "instruire",
    "instruisez": "instruire",
    "instruisiez": "instruire",
    "instruisions": "instruire",
    "instruisirent": "instruire",
    "instruisis": "instruire",
    "instruisisse": "instruire",
    "instruisissent": "instruire",
    "instruisisses": "instruire",
    "instruisissiez": "instruire",
    "instruisissions": "instruire",
    "instruisit": "instruire",
    "instruisons": "instruire",
    "instruisîmes": "instruire",
    "instruisît": "instruire",
    "instruisîtes": "instruire",
    "instruit": "instruire",
    "instruite": "instruit",
    "instruites": "instruit",
    "instruits": "instruit",
    "instrumentais": "instrumenter",
    "instrumentale": "instrumental",
    "instrumentales": "instrumental",
    "instrumentations": "instrumentation",
    "instrumentaux": "instrumental",
    "instrumentistes": "instrumentiste",
    "instruments": "instrument",
    "insubmersibles": "insubmersible",
    "insubordinations": "insubordination",
    "insubordonnée": "insubordonné",
    "insubordonnées": "insubordonné",
    "insubordonnés": "insubordonné",
    "insuccès": "insuccè",
    "insuffisances": "insuffisance",
    "insuffisante": "insuffisant",
    "insuffisantes": "insuffisant",
    "insuffisants": "insuffisant",
    "insuffla": "insuffler",
    "insufflai": "insuffler",
    "insufflaient": "insuffler",
    "insufflais": "insuffler",
    "insufflait": "insuffler",
    "insufflant": "insuffler",
    "insufflas": "insuffler",
    "insufflasse": "insuffler",
    "insufflassent": "insuffler",
    "insufflasses": "insuffler",
    "insufflassiez": "insuffler",
    "insufflassions": "insuffler",
    "insuffle": "insuffler",
    "insufflent": "insuffler",
    "insufflera": "insuffler",
    "insufflerai": "insuffler",
    "insuffleraient": "insuffler",
    "insufflerais": "insuffler",
    "insufflerait": "insuffler",
    "insuffleras": "insuffler",
    "insufflerez": "insuffler",
    "insuffleriez": "insuffler",
    "insufflerions": "insuffler",
    "insufflerons": "insuffler",
    "insuffleront": "insuffler",
    "insuffles": "insuffler",
    "insufflez": "insuffler",
    "insuffliez": "insuffler",
    "insufflions": "insuffler",
    "insufflons": "insuffler",
    "insufflâmes": "insuffler",
    "insufflât": "insuffler",
    "insufflâtes": "insuffler",
    "insufflèrent": "insuffler",
    "insufflé": "insuffler",
    "insufflée": "insuffler",
    "insufflées": "insuffler",
    "insufflés": "insuffler",
    "insulaires": "insulaire",
    "insularités": "insularité",
    "insulines": "insuline",
    "insulta": "insulter",
    "insultai": "insulter",
    "insultaient": "insulter",
    "insultais": "insulter",
    "insultait": "insulter",
    "insultant": "insulter",
    "insultante": "insultant",
    "insultantes": "insultant",
    "insultants": "insultant",
    "insultas": "insulter",
    "insultasse": "insulter",
    "insultassent": "insulter",
    "insultasses": "insulter",
    "insultassiez": "insulter",
    "insultassions": "insulter",
    "insulte": "insulter",
    "insultent": "insulter",
    "insultera": "insulter",
    "insulterai": "insulter",
    "insulteraient": "insulter",
    "insulterais": "insulter",
    "insulterait": "insulter",
    "insulteras": "insulter",
    "insulterez": "insulter",
    "insulteriez": "insulter",
    "insulterions": "insulter",
    "insulterons": "insulter",
    "insulteront": "insulter",
    "insultes": "insulter",
    "insulteurs": "insulteur",
    "insultez": "insulter",
    "insultiez": "insulter",
    "insultions": "insulter",
    "insultons": "insulter",
    "insultâmes": "insulter",
    "insultât": "insulter",
    "insultâtes": "insulter",
    "insultèrent": "insulter",
    "insulté": "insulter",
    "insultée": "insulter",
    "insultées": "insulter",
    "insultés": "insulter",
    "insupportables": "insupportable",
    "insupportaient": "insupporter",
    "insupporte": "insupporter",
    "insupportent": "insupporter",
    "insurge": "insurger",
    "insurgea": "insurger",
    "insurgeai": "insurger",
    "insurgeaient": "insurger",
    "insurgeais": "insurger",
    "insurgeait": "insurger",
    "insurgeant": "insurger",
    "insurgeas": "insurger",
    "insurgeasse": "insurger",
    "insurgeassent": "insurger",
    "insurgeasses": "insurger",
    "insurgeassiez": "insurger",
    "insurgeassions": "insurger",
    "insurgent": "insurger",
    "insurgeons": "insurger",
    "insurgera": "insurger",
    "insurgerai": "insurger",
    "insurgeraient": "insurger",
    "insurgerais": "insurger",
    "insurgerait": "insurger",
    "insurgeras": "insurger",
    "insurgerez": "insurger",
    "insurgeriez": "insurger",
    "insurgerions": "insurger",
    "insurgerons": "insurger",
    "insurgeront": "insurger",
    "insurges": "insurger",
    "insurgez": "insurger",
    "insurgeâmes": "insurger",
    "insurgeât": "insurger",
    "insurgeâtes": "insurger",
    "insurgiez": "insurger",
    "insurgions": "insurger",
    "insurgèrent": "insurger",
    "insurgé": "insurger",
    "insurgée": "insurger",
    "insurgées": "insurger",
    "insurgés": "insurger",
    "insurmontables": "insurmontable",
    "insurrectionnelle": "insurrectionnel",
    "insurrectionnelles": "insurrectionnel",
    "insurrectionnels": "insurrectionnel",
    "insurrections": "insurrection",
    "insère": "insérer",
    "insèrent": "insérer",
    "insères": "insérer",
    "insécurités": "insécurité",
    "insémina": "inséminer",
    "inséminai": "inséminer",
    "inséminaient": "inséminer",
    "inséminais": "inséminer",
    "inséminait": "inséminer",
    "inséminant": "inséminer",
    "inséminas": "inséminer",
    "inséminasse": "inséminer",
    "inséminassent": "inséminer",
    "inséminasses": "inséminer",
    "inséminassiez": "inséminer",
    "inséminassions": "inséminer",
    "inséminations": "insémination",
    "insémine": "inséminer",
    "inséminent": "inséminer",
    "inséminera": "inséminer",
    "inséminerai": "inséminer",
    "insémineraient": "inséminer",
    "inséminerais": "inséminer",
    "inséminerait": "inséminer",
    "insémineras": "inséminer",
    "inséminerez": "inséminer",
    "insémineriez": "inséminer",
    "inséminerions": "inséminer",
    "inséminerons": "inséminer",
    "insémineront": "inséminer",
    "insémines": "inséminer",
    "inséminez": "inséminer",
    "inséminiez": "inséminer",
    "inséminions": "inséminer",
    "inséminons": "inséminer",
    "inséminâmes": "inséminer",
    "inséminât": "inséminer",
    "inséminâtes": "inséminer",
    "inséminèrent": "inséminer",
    "inséminé": "inséminer",
    "inséminée": "inséminer",
    "inséminées": "inséminer",
    "inséminés": "inséminer",
    "inséparables": "inséparable",
    "inséra": "insérer",
    "insérai": "insérer",
    "inséraient": "insérer",
    "insérais": "insérer",
    "insérait": "insérer",
    "insérant": "insérer",
    "inséras": "insérer",
    "insérasse": "insérer",
    "insérassent": "insérer",
    "insérasses": "insérer",
    "insérassiez": "insérer",
    "insérassions": "insérer",
    "insérera": "insérer",
    "insérerai": "insérer",
    "inséreraient": "insérer",
    "insérerais": "insérer",
    "insérerait": "insérer",
    "inséreras": "insérer",
    "insérerez": "insérer",
    "inséreriez": "insérer",
    "insérerions": "insérer",
    "insérerons": "insérer",
    "inséreront": "insérer",
    "inséreurs": "inséreur",
    "insérez": "insérer",
    "insériez": "insérer",
    "insérions": "insérer",
    "insérons": "insérer",
    "insérâmes": "insérer",
    "insérât": "insérer",
    "insérâtes": "insérer",
    "insérèrent": "insérer",
    "inséré": "insérer",
    "insérée": "insérer",
    "insérées": "insérer",
    "insérés": "insérer",
    "intacte": "intact",
    "intactes": "intact",
    "intacts": "intact",
    "intailla": "intailler",
    "intaillai": "intailler",
    "intaillaient": "intailler",
    "intaillais": "intailler",
    "intaillait": "intailler",
    "intaillant": "intailler",
    "intaillas": "intailler",
    "intaillasse": "intailler",
    "intaillassent": "intailler",
    "intaillasses": "intailler",
    "intaillassiez": "intailler",
    "intaillassions": "intailler",
    "intaille": "intailler",
    "intaillent": "intailler",
    "intaillera": "intailler",
    "intaillerai": "intailler",
    "intailleraient": "intailler",
    "intaillerais": "intailler",
    "intaillerait": "intailler",
    "intailleras": "intailler",
    "intaillerez": "intailler",
    "intailleriez": "intailler",
    "intaillerions": "intailler",
    "intaillerons": "intailler",
    "intailleront": "intailler",
    "intailles": "intailler",
    "intaillez": "intailler",
    "intailliez": "intailler",
    "intaillions": "intailler",
    "intaillons": "intailler",
    "intaillâmes": "intailler",
    "intaillât": "intailler",
    "intaillâtes": "intailler",
    "intaillèrent": "intailler",
    "intaillé": "intailler",
    "intaillée": "intailler",
    "intaillées": "intailler",
    "intaillés": "intailler",
    "intangibilités": "intangibilité",
    "intangibles": "intangible",
    "intarissables": "intarissable",
    "intellects": "intellect",
    "intellectualise": "intellectualiser",
    "intellectualismes": "intellectualisme",
    "intellectualisées": "intellectualiser",
    "intellectualités": "intellectualité",
    "intellectuelle": "intellectuel",
    "intellectuelles": "intellectuel",
    "intellectuels": "intellectuel",
    "intellige": "intelliger",
    "intelligences": "intelligence",
    "intelligente": "intelligent",
    "intelligentes": "intelligent",
    "intelligents": "intelligent",
    "intelligentsias": "intelligentsia",
    "intelligibles": "intelligible",
    "intellos": "intello",
    "intempestifs": "intempestif",
    "intempestive": "intempestif",
    "intempestives": "intempestif",
    "intemporelle": "intemporel",
    "intemporelles": "intemporel",
    "intemporels": "intemporel",
    "intempérances": "intempérance",
    "intempérante": "intempérant",
    "intempérantes": "intempérant",
    "intempérants": "intempérant",
    "intempéries": "intempérie",
    "intenables": "intenable",
    "intendances": "intendance",
    "intendante": "intendant",
    "intendantes": "intendant",
    "intendants": "intendant",
    "intenses": "intense",
    "intensifia": "intensifier",
    "intensifiai": "intensifier",
    "intensifiaient": "intensifier",
    "intensifiais": "intensifier",
    "intensifiait": "intensifier",
    "intensifiant": "intensifier",
    "intensifias": "intensifier",
    "intensifiasse": "intensifier",
    "intensifiassent": "intensifier",
    "intensifiasses": "intensifier",
    "intensifiassiez": "intensifier",
    "intensifiassions": "intensifier",
    "intensifications": "intensification",
    "intensifie": "intensifier",
    "intensifient": "intensifier",
    "intensifiera": "intensifier",
    "intensifierai": "intensifier",
    "intensifieraient": "intensifier",
    "intensifierais": "intensifier",
    "intensifierait": "intensifier",
    "intensifieras": "intensifier",
    "intensifierez": "intensifier",
    "intensifieriez": "intensifier",
    "intensifierions": "intensifier",
    "intensifierons": "intensifier",
    "intensifieront": "intensifier",
    "intensifies": "intensifier",
    "intensifiez": "intensifier",
    "intensifiiez": "intensifier",
    "intensifiions": "intensifier",
    "intensifions": "intensifier",
    "intensifiâmes": "intensifier",
    "intensifiât": "intensifier",
    "intensifiâtes": "intensifier",
    "intensifièrent": "intensifier",
    "intensifié": "intensifier",
    "intensifiée": "intensifier",
    "intensifiées": "intensifier",
    "intensifiés": "intensifier",
    "intensifs": "intensif",
    "intensités": "intensité",
    "intensive": "intensif",
    "intensives": "intensif",
    "intenta": "intenter",
    "intentai": "intenter",
    "intentaient": "intenter",
    "intentais": "intenter",
    "intentait": "intenter",
    "intentant": "intenter",
    "intentas": "intenter",
    "intentasse": "intenter",
    "intentassent": "intenter",
    "intentasses": "intenter",
    "intentassiez": "intenter",
    "intentassions": "intenter",
    "intente": "intenter",
    "intentent": "intenter",
    "intentera": "intenter",
    "intenterai": "intenter",
    "intenteraient": "intenter",
    "intenterais": "intenter",
    "intenterait": "intenter",
    "intenteras": "intenter",
    "intenterez": "intenter",
    "intenteriez": "intenter",
    "intenterions": "intenter",
    "intenterons": "intenter",
    "intenteront": "intenter",
    "intentes": "intenter",
    "intentez": "intenter",
    "intentiez": "intenter",
    "intentionnelle": "intentionnel",
    "intentionnelles": "intentionnel",
    "intentionnels": "intentionnel",
    "intentionnée": "intentionné",
    "intentionnées": "intentionné",
    "intentionnés": "intentionné",
    "intentions": "intention",
    "intentons": "intenter",
    "intentâmes": "intenter",
    "intentât": "intenter",
    "intentâtes": "intenter",
    "intentèrent": "intenter",
    "intenté": "intenter",
    "intentée": "intenter",
    "intentées": "intenter",
    "intentés": "intenter",
    "inter-écoles": "inter-école",
    "interactifs": "interactif",
    "interactions": "interaction",
    "interactive": "interactif",
    "interactives": "interactif",
    "interagis": "interagir",
    "interagissais": "interagir",
    "interagissant": "interagir",
    "interagit": "interagir",
    "interalliée": "interallié",
    "interalliées": "interallié",
    "interalliés": "interallié",
    "interaméricaine": "interaméricain",
    "interaméricaines": "interaméricain",
    "interaméricains": "interaméricain",
    "interbancaires": "interbancaire",
    "intercala": "intercaler",
    "intercalai": "intercaler",
    "intercalaient": "intercaler",
    "intercalaires": "intercalaire",
    "intercalais": "intercaler",
    "intercalait": "intercaler",
    "intercalant": "intercaler",
    "intercalas": "intercaler",
    "intercalasse": "intercaler",
    "intercalassent": "intercaler",
    "intercalasses": "intercaler",
    "intercalassiez": "intercaler",
    "intercalassions": "intercaler",
    "intercale": "intercaler",
    "intercalent": "intercaler",
    "intercalera": "intercaler",
    "intercalerai": "intercaler",
    "intercaleraient": "intercaler",
    "intercalerais": "intercaler",
    "intercalerait": "intercaler",
    "intercaleras": "intercaler",
    "intercalerez": "intercaler",
    "intercaleriez": "intercaler",
    "intercalerions": "intercaler",
    "intercalerons": "intercaler",
    "intercaleront": "intercaler",
    "intercales": "intercaler",
    "intercalez": "intercaler",
    "intercaliez": "intercaler",
    "intercalions": "intercaler",
    "intercalons": "intercaler",
    "intercalâmes": "intercaler",
    "intercalât": "intercaler",
    "intercalâtes": "intercaler",
    "intercalèrent": "intercaler",
    "intercalé": "intercaler",
    "intercalée": "intercaler",
    "intercalées": "intercaler",
    "intercalés": "intercaler",
    "intercepta": "intercepter",
    "interceptai": "intercepter",
    "interceptaient": "intercepter",
    "interceptais": "intercepter",
    "interceptait": "intercepter",
    "interceptant": "intercepter",
    "interceptas": "intercepter",
    "interceptasse": "intercepter",
    "interceptassent": "intercepter",
    "interceptasses": "intercepter",
    "interceptassiez": "intercepter",
    "interceptassions": "intercepter",
    "intercepte": "intercepter",
    "interceptent": "intercepter",
    "interceptera": "intercepter",
    "intercepterai": "intercepter",
    "intercepteraient": "intercepter",
    "intercepterais": "intercepter",
    "intercepterait": "intercepter",
    "intercepteras": "intercepter",
    "intercepterez": "intercepter",
    "intercepteriez": "intercepter",
    "intercepterions": "intercepter",
    "intercepterons": "intercepter",
    "intercepteront": "intercepter",
    "interceptes": "intercepter",
    "intercepteurs": "intercepteur",
    "interceptez": "intercepter",
    "interceptiez": "intercepter",
    "interceptions": "interception",
    "interceptons": "intercepter",
    "interceptâmes": "intercepter",
    "interceptât": "intercepter",
    "interceptâtes": "intercepter",
    "interceptèrent": "intercepter",
    "intercepté": "intercepter",
    "interceptée": "intercepter",
    "interceptées": "intercepter",
    "interceptés": "intercepter",
    "intercesseurs": "intercesseur",
    "intercessions": "intercession",
    "interchangeables": "interchangeable",
    "interchangé": "interchanger",
    "interclasses": "interclasse",
    "intercommunale": "intercommunal",
    "intercommunales": "intercommunal",
    "intercommunalités": "intercommunalité",
    "intercommunautaires": "intercommunautaire",
    "intercommunaux": "intercommunal",
    "interconnecta": "interconnecter",
    "interconnectai": "interconnecter",
    "interconnectaient": "interconnecter",
    "interconnectais": "interconnecter",
    "interconnectait": "interconnecter",
    "interconnectant": "interconnecter",
    "interconnectas": "interconnecter",
    "interconnectasse": "interconnecter",
    "interconnectassent": "interconnecter",
    "interconnectasses": "interconnecter",
    "interconnectassiez": "interconnecter",
    "interconnectassions": "interconnecter",
    "interconnecte": "interconnecter",
    "interconnectent": "interconnecter",
    "interconnectera": "interconnecter",
    "interconnecterai": "interconnecter",
    "interconnecteraient": "interconnecter",
    "interconnecterais": "interconnecter",
    "interconnecterait": "interconnecter",
    "interconnecteras": "interconnecter",
    "interconnecterez": "interconnecter",
    "interconnecteriez": "interconnecter",
    "interconnecterions": "interconnecter",
    "interconnecterons": "interconnecter",
    "interconnecteront": "interconnecter",
    "interconnectes": "interconnecter",
    "interconnectez": "interconnecter",
    "interconnectiez": "interconnecter",
    "interconnections": "interconnecter",
    "interconnectons": "interconnecter",
    "interconnectâmes": "interconnecter",
    "interconnectât": "interconnecter",
    "interconnectâtes": "interconnecter",
    "interconnectèrent": "interconnecter",
    "interconnecté": "interconnecter",
    "interconnectée": "interconnecter",
    "interconnectées": "interconnecter",
    "interconnectés": "interconnecter",
    "interconnexions": "interconnexion",
    "intercontinentale": "intercontinental",
    "intercontinentales": "intercontinental",
    "intercontinentaux": "intercontinental",
    "intercostale": "intercostal",
    "intercostales": "intercostal",
    "intercostaux": "intercostal",
    "interculturels": "interculturel",
    "intercède": "intercéder",
    "intercèdent": "intercéder",
    "intercèdes": "intercéder",
    "intercéda": "intercéder",
    "intercédai": "intercéder",
    "intercédaient": "intercéder",
    "intercédais": "intercéder",
    "intercédait": "intercéder",
    "intercédant": "intercéder",
    "intercédas": "intercéder",
    "intercédasse": "intercéder",
    "intercédassent": "intercéder",
    "intercédasses": "intercéder",
    "intercédassiez": "intercéder",
    "intercédassions": "intercéder",
    "intercédera": "intercéder",
    "intercéderai": "intercéder",
    "intercéderaient": "intercéder",
    "intercéderais": "intercéder",
    "intercéderait": "intercéder",
    "intercéderas": "intercéder",
    "intercéderez": "intercéder",
    "intercéderiez": "intercéder",
    "intercéderions": "intercéder",
    "intercéderons": "intercéder",
    "intercéderont": "intercéder",
    "intercédez": "intercéder",
    "intercédiez": "intercéder",
    "intercédions": "intercéder",
    "intercédons": "intercéder",
    "intercédâmes": "intercéder",
    "intercédât": "intercéder",
    "intercédâtes": "intercéder",
    "intercédèrent": "intercéder",
    "intercédé": "intercéder",
    "interdictions": "interdiction",
    "interdira": "interdire",
    "interdirai": "interdire",
    "interdiraient": "interdire",
    "interdirais": "interdire",
    "interdirait": "interdire",
    "interdiras": "interdire",
    "interdirent": "interdire",
    "interdirez": "interdire",
    "interdiriez": "interdire",
    "interdirions": "interdire",
    "interdirons": "interdire",
    "interdiront": "interdire",
    "interdis": "interdire",
    "interdisaient": "interdire",
    "interdisais": "interdire",
    "interdisait": "interdire",
    "interdisant": "interdire",
    "interdisciplinaires": "interdisciplinaire",
    "interdise": "interdire",
    "interdisent": "interdire",
    "interdises": "interdire",
    "interdisez": "interdire",
    "interdisiez": "interdire",
    "interdisions": "interdire",
    "interdisons": "interdire",
    "interdisse": "interdire",
    "interdissent": "interdire",
    "interdisses": "interdire",
    "interdissiez": "interdire",
    "interdissions": "interdire",
    "interdit": "interdire",
    "interdite": "interdit",
    "interdites": "interdit",
    "interdits": "interdit",
    "interdépartementaux": "interdépartemental",
    "interdépendances": "interdépendance",
    "interdépendante": "interdépendant",
    "interdépendantes": "interdépendant",
    "interdépendants": "interdépendant",
    "interdîmes": "interdire",
    "interdît": "interdire",
    "interdîtes": "interdire",
    "interethniques": "interethnique",
    "interfaces": "interface",
    "interfère": "interférer",
    "interfèrent": "interférer",
    "interfèrera": "interférer",
    "interfèrerai": "interférer",
    "interfèreraient": "interférer",
    "interfèrerais": "interférer",
    "interfèrerait": "interférer",
    "interfèreras": "interférer",
    "interfèrerez": "interférer",
    "interfèreriez": "interférer",
    "interfèrerions": "interférer",
    "interfèrerons": "interférer",
    "interfèreront": "interférer",
    "interfères": "interférer",
    "interfédérale": "interfédéral",
    "interfédérales": "interfédéral",
    "interfédérauxs": "interfédéral",
    "interféra": "interférer",
    "interférai": "interférer",
    "interféraient": "interférer",
    "interférais": "interférer",
    "interférait": "interférer",
    "interférant": "interférer",
    "interféras": "interférer",
    "interférasse": "interférer",
    "interférassent": "interférer",
    "interférasses": "interférer",
    "interférassiez": "interférer",
    "interférassions": "interférer",
    "interférences": "interférence",
    "interférez": "interférer",
    "interfériez": "interférer",
    "interférions": "interférer",
    "interférons": "interféron",
    "interférâmes": "interférer",
    "interférât": "interférer",
    "interférâtes": "interférer",
    "interférèrent": "interférer",
    "interféré": "interférer",
    "interférée": "interférer",
    "interférées": "interférer",
    "interférés": "interférer",
    "intergalactiques": "intergalactique",
    "intergouvernementale": "intergouvernemental",
    "intergouvernementales": "intergouvernemental",
    "intergouvernementaux": "intergouvernemental",
    "interims": "interim",
    "interinstitutionnelle": "interinstitutionnel",
    "interinstitutionnelles": "interinstitutionnel",
    "interinstitutionnels": "interinstitutionnel",
    "interjections": "interjection",
    "interjeta": "interjeter",
    "interjetai": "interjeter",
    "interjetaient": "interjeter",
    "interjetais": "interjeter",
    "interjetait": "interjeter",
    "interjetant": "interjeter",
    "interjetas": "interjeter",
    "interjetasse": "interjeter",
    "interjetassent": "interjeter",
    "interjetasses": "interjeter",
    "interjetassiez": "interjeter",
    "interjetassions": "interjeter",
    "interjetez": "interjeter",
    "interjetiez": "interjeter",
    "interjetions": "interjeter",
    "interjetons": "interjeter",
    "interjette": "interjeter",
    "interjettent": "interjeter",
    "interjettera": "interjeter",
    "interjetterai": "interjeter",
    "interjetteraient": "interjeter",
    "interjetterais": "interjeter",
    "interjetterait": "interjeter",
    "interjetteras": "interjeter",
    "interjetterez": "interjeter",
    "interjetteriez": "interjeter",
    "interjetterions": "interjeter",
    "interjetterons": "interjeter",
    "interjetteront": "interjeter",
    "interjettes": "interjeter",
    "interjetâmes": "interjeter",
    "interjetât": "interjeter",
    "interjetâtes": "interjeter",
    "interjetèrent": "interjeter",
    "interjeté": "interjeter",
    "interjetée": "interjeter",
    "interjetées": "interjeter",
    "interjetés": "interjeter",
    "interlibanaise": "interlibanais",
    "interlibanaises": "interlibanais",
    "interlignes": "interligne",
    "interlignés": "interligner",
    "interlocuteurs": "interlocuteur",
    "interlocutoires": "interlocutoire",
    "interlocutrice": "interlocuteur",
    "interlocutrices": "interlocuteur",
    "interlopes": "interlope",
    "interloqua": "interloquer",
    "interloquai": "interloquer",
    "interloquaient": "interloquer",
    "interloquais": "interloquer",
    "interloquait": "interloquer",
    "interloquant": "interloquer",
    "interloquas": "interloquer",
    "interloquasse": "interloquer",
    "interloquassent": "interloquer",
    "interloquasses": "interloquer",
    "interloquassiez": "interloquer",
    "interloquassions": "interloquer",
    "interloque": "interloquer",
    "interloquent": "interloquer",
    "interloquera": "interloquer",
    "interloquerai": "interloquer",
    "interloqueraient": "interloquer",
    "interloquerais": "interloquer",
    "interloquerait": "interloquer",
    "interloqueras": "interloquer",
    "interloquerez": "interloquer",
    "interloqueriez": "interloquer",
    "interloquerions": "interloquer",
    "interloquerons": "interloquer",
    "interloqueront": "interloquer",
    "interloques": "interloquer",
    "interloquez": "interloquer",
    "interloquiez": "interloquer",
    "interloquions": "interloquer",
    "interloquons": "interloquer",
    "interloquâmes": "interloquer",
    "interloquât": "interloquer",
    "interloquâtes": "interloquer",
    "interloquèrent": "interloquer",
    "interloqué": "interloquer",
    "interloquée": "interloquer",
    "interloquées": "interloquer",
    "interloqués": "interloquer",
    "interludes": "interlude",
    "intermezzos": "intermezzo",
    "interminables": "interminable",
    "interministérielle": "interministériel",
    "interministérielles": "interministériel",
    "interministériels": "interministériel",
    "intermittences": "intermittence",
    "intermittente": "intermittent",
    "intermittentes": "intermittent",
    "intermittents": "intermittent",
    "intermèdes": "intermède",
    "intermédiaires": "intermédiaire",
    "internationale": "international",
    "internationales": "international",
    "internationalisa": "internationaliser",
    "internationalisai": "internationaliser",
    "internationalisaient": "internationaliser",
    "internationalisais": "internationaliser",
    "internationalisait": "internationaliser",
    "internationalisant": "internationaliser",
    "internationalisas": "internationaliser",
    "internationalisasse": "internationaliser",
    "internationalisassent": "internationaliser",
    "internationalisasses": "internationaliser",
    "internationalisassiez": "internationaliser",
    "internationalisassions": "internationaliser",
    "internationalisations": "internationalisation",
    "internationalise": "internationaliser",
    "internationalisent": "internationaliser",
    "internationalisera": "internationaliser",
    "internationaliserai": "internationaliser",
    "internationaliseraient": "internationaliser",
    "internationaliserais": "internationaliser",
    "internationaliserait": "internationaliser",
    "internationaliseras": "internationaliser",
    "internationaliserez": "internationaliser",
    "internationaliseriez": "internationaliser",
    "internationaliserions": "internationaliser",
    "internationaliserons": "internationaliser",
    "internationaliseront": "internationaliser",
    "internationalises": "internationaliser",
    "internationalisez": "internationaliser",
    "internationalisiez": "internationaliser",
    "internationalisions": "internationaliser",
    "internationalismes": "internationalisme",
    "internationalisons": "internationaliser",
    "internationalistes": "internationaliste",
    "internationalisâmes": "internationaliser",
    "internationalisât": "internationaliser",
    "internationalisâtes": "internationaliser",
    "internationalisèrent": "internationaliser",
    "internationalisé": "internationaliser",
    "internationalisée": "internationaliser",
    "internationalisées": "internationaliser",
    "internationalisés": "internationaliser",
    "internationaux": "international",
    "internats": "internat",
    "internautes": "internaute",
    "interne": "interner",
    "internements": "internement",
    "internes": "interne",
    "internez": "interner",
    "interné": "interner",
    "internée": "interner",
    "internées": "interner",
    "internés": "interner",
    "interocéaniques": "interocéanique",
    "interopérabilités": "interopérabilité",
    "interparlementaires": "interparlementaire",
    "interpella": "interpeller",
    "interpellai": "interpeller",
    "interpellaient": "interpeller",
    "interpellais": "interpeller",
    "interpellait": "interpeller",
    "interpellant": "interpeller",
    "interpellas": "interpeller",
    "interpellasse": "interpeller",
    "interpellassent": "interpeller",
    "interpellasses": "interpeller",
    "interpellassiez": "interpeller",
    "interpellassions": "interpeller",
    "interpellateurs": "interpellateur",
    "interpellations": "interpellation",
    "interpelle": "interpeller",
    "interpellent": "interpeller",
    "interpellera": "interpeller",
    "interpellerai": "interpeller",
    "interpelleraient": "interpeller",
    "interpellerais": "interpeller",
    "interpellerait": "interpeller",
    "interpelleras": "interpeller",
    "interpellerez": "interpeller",
    "interpelleriez": "interpeller",
    "interpellerions": "interpeller",
    "interpellerons": "interpeller",
    "interpelleront": "interpeller",
    "interpelles": "interpeller",
    "interpellez": "interpeller",
    "interpelliez": "interpeller",
    "interpellions": "interpeller",
    "interpellons": "interpeller",
    "interpellâmes": "interpeller",
    "interpellât": "interpeller",
    "interpellâtes": "interpeller",
    "interpellèrent": "interpeller",
    "interpellé": "interpeller",
    "interpellée": "interpeller",
    "interpellées": "interpeller",
    "interpellés": "interpeller",
    "interphones": "interphone",
    "interplanétaires": "interplanétaire",
    "interpola": "interpoler",
    "interpolai": "interpoler",
    "interpolaient": "interpoler",
    "interpolais": "interpoler",
    "interpolait": "interpoler",
    "interpolant": "interpoler",
    "interpolas": "interpoler",
    "interpolasse": "interpoler",
    "interpolassent": "interpoler",
    "interpolasses": "interpoler",
    "interpolassiez": "interpoler",
    "interpolassions": "interpoler",
    "interpolations": "interpolation",
    "interpole": "interpoler",
    "interpolent": "interpoler",
    "interpolera": "interpoler",
    "interpolerai": "interpoler",
    "interpoleraient": "interpoler",
    "interpolerais": "interpoler",
    "interpolerait": "interpoler",
    "interpoleras": "interpoler",
    "interpolerez": "interpoler",
    "interpoleriez": "interpoler",
    "interpolerions": "interpoler",
    "interpolerons": "interpoler",
    "interpoleront": "interpoler",
    "interpoles": "interpoler",
    "interpolez": "interpoler",
    "interpoliez": "interpoler",
    "interpolions": "interpoler",
    "interpolons": "interpoler",
    "interpolâmes": "interpoler",
    "interpolât": "interpoler",
    "interpolâtes": "interpoler",
    "interpolèrent": "interpoler",
    "interpolé": "interpoler",
    "interpolée": "interpoler",
    "interpolées": "interpoler",
    "interpolés": "interpoler",
    "interportuaires": "interportuaire",
    "interposa": "interposer",
    "interposai": "interposer",
    "interposaient": "interposer",
    "interposais": "interposer",
    "interposait": "interposer",
    "interposant": "interposer",
    "interposas": "interposer",
    "interposasse": "interposer",
    "interposassent": "interposer",
    "interposasses": "interposer",
    "interposassiez": "interposer",
    "interposassions": "interposer",
    "interpose": "interposer",
    "interposent": "interposer",
    "interposera": "interposer",
    "interposerai": "interposer",
    "interposeraient": "interposer",
    "interposerais": "interposer",
    "interposerait": "interposer",
    "interposeras": "interposer",
    "interposerez": "interposer",
    "interposeriez": "interposer",
    "interposerions": "interposer",
    "interposerons": "interposer",
    "interposeront": "interposer",
    "interposes": "interposer",
    "interposez": "interposer",
    "interposiez": "interposer",
    "interposions": "interposer",
    "interpositions": "interposition",
    "interposons": "interposer",
    "interposâmes": "interposer",
    "interposât": "interposer",
    "interposâtes": "interposer",
    "interposèrent": "interposer",
    "interposé": "interposer",
    "interposée": "interposer",
    "interposées": "interposer",
    "interposés": "interposer",
    "interprofessionnelle": "interprofessionnel",
    "interprofessionnelles": "interprofessionnel",
    "interprofessionnels": "interprofessionnel",
    "interprète": "interpréter",
    "interprètent": "interpréter",
    "interprètes": "interpréter",
    "interpréta": "interpréter",
    "interprétai": "interpréter",
    "interprétaient": "interpréter",
    "interprétais": "interpréter",
    "interprétait": "interpréter",
    "interprétant": "interpréter",
    "interprétante": "interprétant",
    "interprétas": "interpréter",
    "interprétasse": "interpréter",
    "interprétassent": "interpréter",
    "interprétasses": "interpréter",
    "interprétassiez": "interpréter",
    "interprétassions": "interpréter",
    "interprétatifs": "interprétatif",
    "interprétations": "interprétation",
    "interprétative": "interprétatif",
    "interprétatives": "interprétatif",
    "interprétera": "interpréter",
    "interpréterai": "interpréter",
    "interpréteraient": "interpréter",
    "interpréterais": "interpréter",
    "interpréterait": "interpréter",
    "interpréteras": "interpréter",
    "interpréterez": "interpréter",
    "interpréteriez": "interpréter",
    "interpréterions": "interpréter",
    "interpréterons": "interpréter",
    "interpréteront": "interpréter",
    "interprétez": "interpréter",
    "interprétiez": "interpréter",
    "interprétions": "interpréter",
    "interprétons": "interpréter",
    "interprétâmes": "interpréter",
    "interprétât": "interpréter",
    "interprétâtes": "interpréter",
    "interprétèrent": "interpréter",
    "interprété": "interpréter",
    "interprétée": "interpréter",
    "interprétées": "interpréter",
    "interprétés": "interpréter",
    "interpénètre": "interpénétrer",
    "interpénètrent": "interpénétrer",
    "interpénètres": "interpénétrer",
    "interpénétra": "interpénétrer",
    "interpénétrai": "interpénétrer",
    "interpénétraient": "interpénétrer",
    "interpénétrais": "interpénétrer",
    "interpénétrait": "interpénétrer",
    "interpénétrant": "interpénétrer",
    "interpénétras": "interpénétrer",
    "interpénétrasse": "interpénétrer",
    "interpénétrassent": "interpénétrer",
    "interpénétrasses": "interpénétrer",
    "interpénétrassiez": "interpénétrer",
    "interpénétrassions": "interpénétrer",
    "interpénétrations": "interpénétration",
    "interpénétrera": "interpénétrer",
    "interpénétrerai": "interpénétrer",
    "interpénétreraient": "interpénétrer",
    "interpénétrerais": "interpénétrer",
    "interpénétrerait": "interpénétrer",
    "interpénétreras": "interpénétrer",
    "interpénétrerez": "interpénétrer",
    "interpénétreriez": "interpénétrer",
    "interpénétrerions": "interpénétrer",
    "interpénétrerons": "interpénétrer",
    "interpénétreront": "interpénétrer",
    "interpénétrez": "interpénétrer",
    "interpénétriez": "interpénétrer",
    "interpénétrions": "interpénétrer",
    "interpénétrons": "interpénétrer",
    "interpénétrâmes": "interpénétrer",
    "interpénétrât": "interpénétrer",
    "interpénétrâtes": "interpénétrer",
    "interpénétrèrent": "interpénétrer",
    "interpénétré": "interpénétrer",
    "interpénétrée": "interpénétrer",
    "interpénétrées": "interpénétrer",
    "interpénétrés": "interpénétrer",
    "interraciale": "interracial",
    "interraciaux": "interracial",
    "interrelations": "interrelation",
    "interreligieuse": "interreligieux",
    "interreligieuses": "interreligieux",
    "interrogateurs": "interrogateur",
    "interrogatifs": "interrogatif",
    "interrogations": "interrogation",
    "interrogative": "interrogatif",
    "interrogatives": "interrogative",
    "interrogatoires": "interrogatoire",
    "interrogatrice": "interrogateur",
    "interroge": "interroger",
    "interrogea": "interroger",
    "interrogeai": "interroger",
    "interrogeaient": "interroger",
    "interrogeais": "interroger",
    "interrogeait": "interroger",
    "interrogeant": "interroger",
    "interrogeas": "interroger",
    "interrogeasse": "interroger",
    "interrogeassent": "interroger",
    "interrogeasses": "interroger",
    "interrogeassiez": "interroger",
    "interrogeassions": "interroger",
    "interrogent": "interroger",
    "interrogeons": "interroger",
    "interrogera": "interroger",
    "interrogerai": "interroger",
    "interrogeraient": "interroger",
    "interrogerais": "interroger",
    "interrogerait": "interroger",
    "interrogeras": "interroger",
    "interrogerez": "interroger",
    "interrogeriez": "interroger",
    "interrogerions": "interroger",
    "interrogerons": "interroger",
    "interrogeront": "interroger",
    "interroges": "interroger",
    "interrogez": "interroger",
    "interrogeâmes": "interroger",
    "interrogeât": "interroger",
    "interrogeâtes": "interroger",
    "interrogiez": "interroger",
    "interrogions": "interroger",
    "interrogèrent": "interroger",
    "interrogé": "interroger",
    "interrogée": "interroger",
    "interrogées": "interroger",
    "interrogés": "interroger",
    "interrompaient": "interrompre",
    "interrompais": "interrompre",
    "interrompait": "interrompre",
    "interrompant": "interrompre",
    "interrompe": "interrompre",
    "interrompent": "interrompre",
    "interrompes": "interrompre",
    "interrompez": "interrompre",
    "interrompiez": "interrompre",
    "interrompions": "interrompre",
    "interrompirent": "interrompre",
    "interrompis": "interrompre",
    "interrompisse": "interrompre",
    "interrompissent": "interrompre",
    "interrompisses": "interrompre",
    "interrompissiez": "interrompre",
    "interrompissions": "interrompre",
    "interrompit": "interrompre",
    "interrompons": "interrompre",
    "interrompra": "interrompre",
    "interromprai": "interrompre",
    "interrompraient": "interrompre",
    "interromprais": "interrompre",
    "interromprait": "interrompre",
    "interrompras": "interrompre",
    "interromprez": "interrompre",
    "interrompriez": "interrompre",
    "interromprions": "interrompre",
    "interromprons": "interrompre",
    "interrompront": "interrompre",
    "interromps": "interrompre",
    "interrompt": "interrompre",
    "interrompu": "interrompre",
    "interrompue": "interrompu",
    "interrompues": "interrompu",
    "interrompus": "interrompu",
    "interrompîmes": "interrompre",
    "interrompît": "interrompre",
    "interrompîtes": "interrompre",
    "interrupteurs": "interrupteur",
    "interruptions": "interruption",
    "interrègnes": "interrègne",
    "interrégionale": "interrégional",
    "interrégionales": "interrégional",
    "interrégionaux": "interrégional",
    "inters": "inter",
    "intersectant": "intersecter",
    "intersections": "intersection",
    "intersessions": "intersession",
    "intersidérale": "intersidéral",
    "intersidérales": "intersidéral",
    "intersidéraux": "intersidéral",
    "interstellaires": "interstellaire",
    "interstices": "interstice",
    "interstitielle": "interstitiel",
    "interstitielles": "interstitiel",
    "interstitiels": "interstitiel",
    "intersyndicale": "intersyndical",
    "intersyndicales": "intersyndical",
    "intersyndicaux": "intersyndical",
    "interuniversitaires": "interuniversitaire",
    "interurbaine": "interurbain",
    "interurbaines": "interurbain",
    "interurbains": "interurbain",
    "intervalles": "intervalle",
    "intervenaient": "intervenir",
    "intervenais": "intervenir",
    "intervenait": "intervenir",
    "intervenant": "intervenir",
    "intervenante": "intervenant",
    "intervenantes": "intervenant",
    "intervenants": "intervenant",
    "intervenez": "intervenir",
    "interveniez": "intervenir",
    "intervenions": "intervenir",
    "intervenons": "intervenir",
    "interventionnismes": "interventionnisme",
    "interventionnistes": "interventionniste",
    "interventions": "intervention",
    "intervenu": "intervenir",
    "intervenue": "intervenir",
    "intervenues": "intervenir",
    "intervenus": "intervenir",
    "interversions": "interversion",
    "interverti": "intervertir",
    "intervertie": "intervertir",
    "interverties": "intervertir",
    "intervertira": "intervertir",
    "intervertirai": "intervertir",
    "intervertiraient": "intervertir",
    "intervertirais": "intervertir",
    "intervertirait": "intervertir",
    "intervertiras": "intervertir",
    "intervertirent": "intervertir",
    "intervertirez": "intervertir",
    "intervertiriez": "intervertir",
    "intervertirions": "intervertir",
    "intervertirons": "intervertir",
    "intervertiront": "intervertir",
    "intervertis": "intervertir",
    "intervertissaient": "intervertir",
    "intervertissais": "intervertir",
    "intervertissait": "intervertir",
    "intervertissant": "intervertir",
    "intervertisse": "intervertir",
    "intervertissent": "intervertir",
    "intervertisses": "intervertir",
    "intervertissez": "intervertir",
    "intervertissiez": "intervertir",
    "intervertissions": "intervertir",
    "intervertissons": "intervertir",
    "intervertit": "intervertir",
    "intervertébraux": "intervertébral",
    "intervertîmes": "intervertir",
    "intervertît": "intervertir",
    "intervertîtes": "intervertir",
    "interviendra": "intervenir",
    "interviendrai": "intervenir",
    "interviendraient": "intervenir",
    "interviendrais": "intervenir",
    "interviendrait": "intervenir",
    "interviendras": "intervenir",
    "interviendrez": "intervenir",
    "interviendriez": "intervenir",
    "interviendrions": "intervenir",
    "interviendrons": "intervenir",
    "interviendront": "intervenir",
    "intervienne": "intervenir",
    "interviennent": "intervenir",
    "interviennes": "intervenir",
    "interviens": "intervenir",
    "intervient": "intervenir",
    "interviewa": "interviewer",
    "interviewai": "interviewer",
    "interviewaient": "interviewer",
    "interviewais": "interviewer",
    "interviewait": "interviewer",
    "interviewant": "interviewer",
    "interviewas": "interviewer",
    "interviewasse": "interviewer",
    "interviewassent": "interviewer",
    "interviewasses": "interviewer",
    "interviewassiez": "interviewer",
    "interviewassions": "interviewer",
    "interviewe": "interviewer",
    "interviewent": "interviewer",
    "interviewera": "interviewer",
    "interviewerai": "interviewer",
    "intervieweraient": "interviewer",
    "interviewerais": "interviewer",
    "interviewerait": "interviewer",
    "intervieweras": "interviewer",
    "interviewerez": "interviewer",
    "intervieweriez": "interviewer",
    "interviewerions": "interviewer",
    "interviewerons": "interviewer",
    "intervieweront": "interviewer",
    "interviewers": "interviewer",
    "interviewes": "interviewer",
    "interviewez": "interviewer",
    "interviewiez": "interviewer",
    "interviewions": "interviewer",
    "interviewons": "interviewer",
    "interviews": "interview",
    "interviewâmes": "interviewer",
    "interviewât": "interviewer",
    "interviewâtes": "interviewer",
    "interviewèrent": "interviewer",
    "interviewé": "interviewer",
    "interviewée": "interviewer",
    "interviewées": "interviewer",
    "interviewés": "interviewer",
    "intervinrent": "intervenir",
    "intervins": "intervenir",
    "intervinsse": "intervenir",
    "intervinssent": "intervenir",
    "intervinsses": "intervenir",
    "intervinssiez": "intervenir",
    "intervinssions": "intervenir",
    "intervint": "intervenir",
    "intervînmes": "intervenir",
    "intervînt": "intervenir",
    "intervîntes": "intervenir",
    "interzones": "interzone",
    "interétatiques": "interétatique",
    "intestats": "intestat",
    "intestinale": "intestinal",
    "intestinales": "intestinal",
    "intestinaux": "intestinal",
    "intestine": "intestin",
    "intestines": "intestin",
    "intestins": "intestin",
    "intima": "intimer",
    "intimai": "intimer",
    "intimaient": "intimer",
    "intimais": "intimer",
    "intimait": "intimer",
    "intimant": "intimer",
    "intimas": "intimer",
    "intimasse": "intimer",
    "intimassent": "intimer",
    "intimasses": "intimer",
    "intimassiez": "intimer",
    "intimassions": "intimer",
    "intime": "intimer",
    "intiment": "intimer",
    "intimera": "intimer",
    "intimerai": "intimer",
    "intimeraient": "intimer",
    "intimerais": "intimer",
    "intimerait": "intimer",
    "intimeras": "intimer",
    "intimerez": "intimer",
    "intimeriez": "intimer",
    "intimerions": "intimer",
    "intimerons": "intimer",
    "intimeront": "intimer",
    "intimes": "intimer",
    "intimez": "intimer",
    "intimida": "intimider",
    "intimidai": "intimider",
    "intimidaient": "intimider",
    "intimidais": "intimider",
    "intimidait": "intimider",
    "intimidant": "intimider",
    "intimidante": "intimidant",
    "intimidantes": "intimidant",
    "intimidants": "intimidant",
    "intimidas": "intimider",
    "intimidasse": "intimider",
    "intimidassent": "intimider",
    "intimidasses": "intimider",
    "intimidassiez": "intimider",
    "intimidassions": "intimider",
    "intimidations": "intimidation",
    "intimide": "intimider",
    "intimident": "intimider",
    "intimidera": "intimider",
    "intimiderai": "intimider",
    "intimideraient": "intimider",
    "intimiderais": "intimider",
    "intimiderait": "intimider",
    "intimideras": "intimider",
    "intimiderez": "intimider",
    "intimideriez": "intimider",
    "intimiderions": "intimider",
    "intimiderons": "intimider",
    "intimideront": "intimider",
    "intimides": "intimider",
    "intimidez": "intimider",
    "intimidiez": "intimider",
    "intimidions": "intimider",
    "intimidons": "intimider",
    "intimidâmes": "intimider",
    "intimidât": "intimider",
    "intimidâtes": "intimider",
    "intimidèrent": "intimider",
    "intimidé": "intimider",
    "intimidée": "intimider",
    "intimidées": "intimider",
    "intimidés": "intimider",
    "intimiez": "intimer",
    "intimions": "intimer",
    "intimistes": "intimiste",
    "intimités": "intimité",
    "intimons": "intimer",
    "intimâmes": "intimer",
    "intimât": "intimer",
    "intimâtes": "intimer",
    "intimèrent": "intimer",
    "intimé": "intimer",
    "intimée": "intimer",
    "intimées": "intimer",
    "intimés": "intimer",
    "intitula": "intituler",
    "intitulai": "intituler",
    "intitulaient": "intituler",
    "intitulais": "intituler",
    "intitulait": "intituler",
    "intitulant": "intituler",
    "intitulas": "intituler",
    "intitulasse": "intituler",
    "intitulassent": "intituler",
    "intitulasses": "intituler",
    "intitulassiez": "intituler",
    "intitulassions": "intituler",
    "intitule": "intituler",
    "intitulent": "intituler",
    "intitulera": "intituler",
    "intitulerai": "intituler",
    "intituleraient": "intituler",
    "intitulerais": "intituler",
    "intitulerait": "intituler",
    "intituleras": "intituler",
    "intitulerez": "intituler",
    "intituleriez": "intituler",
    "intitulerions": "intituler",
    "intitulerons": "intituler",
    "intituleront": "intituler",
    "intitules": "intituler",
    "intitulez": "intituler",
    "intituliez": "intituler",
    "intitulions": "intituler",
    "intitulons": "intituler",
    "intitulâmes": "intituler",
    "intitulât": "intituler",
    "intitulâtes": "intituler",
    "intitulèrent": "intituler",
    "intitulé": "intituler",
    "intitulée": "intituler",
    "intitulées": "intituler",
    "intitulés": "intituler",
    "intolérables": "intolérable",
    "intolérances": "intolérance",
    "intolérante": "intolérant",
    "intolérantes": "intolérant",
    "intolérants": "intolérant",
    "intonations": "intonation",
    "intouchables": "intouchable",
    "intouchée": "intouché",
    "intouchées": "intouché",
    "intouchés": "intouché",
    "intoxe": "intox",
    "intoxicante": "intoxicant",
    "intoxicantes": "intoxicant",
    "intoxicants": "intoxicant",
    "intoxications": "intoxication",
    "intoxiqua": "intoxiquer",
    "intoxiquai": "intoxiquer",
    "intoxiquaient": "intoxiquer",
    "intoxiquais": "intoxiquer",
    "intoxiquait": "intoxiquer",
    "intoxiquant": "intoxiquer",
    "intoxiquas": "intoxiquer",
    "intoxiquasse": "intoxiquer",
    "intoxiquassent": "intoxiquer",
    "intoxiquasses": "intoxiquer",
    "intoxiquassiez": "intoxiquer",
    "intoxiquassions": "intoxiquer",
    "intoxique": "intoxiquer",
    "intoxiquent": "intoxiquer",
    "intoxiquera": "intoxiquer",
    "intoxiquerai": "intoxiquer",
    "intoxiqueraient": "intoxiquer",
    "intoxiquerais": "intoxiquer",
    "intoxiquerait": "intoxiquer",
    "intoxiqueras": "intoxiquer",
    "intoxiquerez": "intoxiquer",
    "intoxiqueriez": "intoxiquer",
    "intoxiquerions": "intoxiquer",
    "intoxiquerons": "intoxiquer",
    "intoxiqueront": "intoxiquer",
    "intoxiques": "intoxiquer",
    "intoxiquez": "intoxiquer",
    "intoxiquiez": "intoxiquer",
    "intoxiquions": "intoxiquer",
    "intoxiquons": "intoxiquer",
    "intoxiquâmes": "intoxiquer",
    "intoxiquât": "intoxiquer",
    "intoxiquâtes": "intoxiquer",
    "intoxiquèrent": "intoxiquer",
    "intoxiqué": "intoxiquer",
    "intoxiquée": "intoxiquer",
    "intoxiquées": "intoxiquer",
    "intoxiqués": "intoxiquer",
    "intra-rachidienne": "rachidien",
    "intra-utérine": "intra-utérin",
    "intra-utérines": "intra-utérin",
    "intracommunautaires": "intracommunautaire",
    "intracrânienne": "intracrânien",
    "intracérébrale": "intracérébral",
    "intraduisibles": "intraduisible",
    "intraitables": "intraitable",
    "intramusculaires": "intramusculaire",
    "intransigeances": "intransigeance",
    "intransigeante": "intransigeant",
    "intransigeantes": "intransigeant",
    "intransigeants": "intransigeant",
    "intransitifs": "intransitif",
    "intransitive": "intransitif",
    "intransitives": "intransitif",
    "intransportables": "intransportable",
    "intrants": "intrant",
    "intraveineuse": "intraveineux",
    "intraveineuses": "intraveineux",
    "intrigante": "intrigant",
    "intrigantes": "intrigant",
    "intrigants": "intrigant",
    "intrigua": "intriguer",
    "intriguai": "intriguer",
    "intriguaient": "intriguer",
    "intriguais": "intriguer",
    "intriguait": "intriguer",
    "intriguant": "intriguer",
    "intriguas": "intriguer",
    "intriguasse": "intriguer",
    "intriguassent": "intriguer",
    "intriguasses": "intriguer",
    "intriguassiez": "intriguer",
    "intriguassions": "intriguer",
    "intrigue": "intriguer",
    "intriguent": "intriguer",
    "intriguera": "intriguer",
    "intriguerai": "intriguer",
    "intrigueraient": "intriguer",
    "intriguerais": "intriguer",
    "intriguerait": "intriguer",
    "intrigueras": "intriguer",
    "intriguerez": "intriguer",
    "intrigueriez": "intriguer",
    "intriguerions": "intriguer",
    "intriguerons": "intriguer",
    "intrigueront": "intriguer",
    "intrigues": "intriguer",
    "intriguez": "intriguer",
    "intriguiez": "intriguer",
    "intriguions": "intriguer",
    "intriguons": "intriguer",
    "intriguâmes": "intriguer",
    "intriguât": "intriguer",
    "intriguâtes": "intriguer",
    "intriguèrent": "intriguer",
    "intrigué": "intriguer",
    "intriguée": "intriguer",
    "intriguées": "intriguer",
    "intrigués": "intriguer",
    "intrinsèques": "intrinsèque",
    "introductifs": "introductif",
    "introductions": "introduction",
    "introductives": "introductif",
    "introductrice": "introducteur",
    "introduira": "introduire",
    "introduirai": "introduire",
    "introduiraient": "introduire",
    "introduirais": "introduire",
    "introduirait": "introduire",
    "introduiras": "introduire",
    "introduirez": "introduire",
    "introduiriez": "introduire",
    "introduirions": "introduire",
    "introduirons": "introduire",
    "introduiront": "introduire",
    "introduis": "introduire",
    "introduisaient": "introduire",
    "introduisais": "introduire",
    "introduisait": "introduire",
    "introduisant": "introduire",
    "introduise": "introduire",
    "introduisent": "introduire",
    "introduises": "introduire",
    "introduisez": "introduire",
    "introduisiez": "introduire",
    "introduisions": "introduire",
    "introduisirent": "introduire",
    "introduisis": "introduire",
    "introduisisse": "introduire",
    "introduisissent": "introduire",
    "introduisisses": "introduire",
    "introduisissiez": "introduire",
    "introduisissions": "introduire",
    "introduisit": "introduire",
    "introduisons": "introduire",
    "introduisîmes": "introduire",
    "introduisît": "introduire",
    "introduisîtes": "introduire",
    "introduit": "introduire",
    "introduite": "introduire",
    "introduites": "introduire",
    "introduits": "introduire",
    "intromissions": "intromission",
    "intronisa": "introniser",
    "intronisai": "introniser",
    "intronisaient": "introniser",
    "intronisais": "introniser",
    "intronisait": "introniser",
    "intronisant": "introniser",
    "intronisas": "introniser",
    "intronisasse": "introniser",
    "intronisassent": "introniser",
    "intronisasses": "introniser",
    "intronisassiez": "introniser",
    "intronisassions": "introniser",
    "intronise": "introniser",
    "intronisent": "introniser",
    "intronisera": "introniser",
    "introniserai": "introniser",
    "introniseraient": "introniser",
    "introniserais": "introniser",
    "introniserait": "introniser",
    "introniseras": "introniser",
    "introniserez": "introniser",
    "introniseriez": "introniser",
    "introniserions": "introniser",
    "introniserons": "introniser",
    "introniseront": "introniser",
    "intronises": "introniser",
    "intronisez": "introniser",
    "intronisiez": "introniser",
    "intronisions": "introniser",
    "intronisons": "introniser",
    "intronisâmes": "introniser",
    "intronisât": "introniser",
    "intronisâtes": "introniser",
    "intronisèrent": "introniser",
    "intronisé": "introniser",
    "intronisée": "introniser",
    "intronisées": "introniser",
    "intronisés": "introniser",
    "introspections": "introspection",
    "introspective": "introspectif",
    "introspectives": "introspectif",
    "introuvables": "introuvable",
    "introversions": "introversion",
    "introvertie": "introverti",
    "introverties": "introverti",
    "introvertis": "introverti",
    "intruse": "intrus",
    "intruses": "intrus",
    "intrusions": "intrusion",
    "intrépides": "intrépide",
    "intube": "intuber",
    "intubez": "intuber",
    "intubé": "intuber",
    "intubée": "intuber",
    "intuitifs": "intuitif",
    "intuitionnismes": "intuitionnisme",
    "intuitions": "intuition",
    "intuitive": "intuitif",
    "intuitives": "intuitif",
    "intègre": "intégrer",
    "intègrent": "intégrer",
    "intègres": "intégrer",
    "intégra": "intégrer",
    "intégrai": "intégrer",
    "intégraient": "intégrer",
    "intégrais": "intégrer",
    "intégrait": "intégrer",
    "intégrale": "intégral",
    "intégrales": "intégrale",
    "intégralités": "intégralité",
    "intégrant": "intégrer",
    "intégrante": "intégrant",
    "intégrantes": "intégrant",
    "intégrants": "intégrant",
    "intégras": "intégrer",
    "intégrasse": "intégrer",
    "intégrassent": "intégrer",
    "intégrasses": "intégrer",
    "intégrassiez": "intégrer",
    "intégrassions": "intégrer",
    "intégrateurs": "intégrateur",
    "intégrationnistes": "intégrationniste",
    "intégrations": "intégration",
    "intégraux": "intégral",
    "intégrera": "intégrer",
    "intégrerai": "intégrer",
    "intégreraient": "intégrer",
    "intégrerais": "intégrer",
    "intégrerait": "intégrer",
    "intégreras": "intégrer",
    "intégrerez": "intégrer",
    "intégreriez": "intégrer",
    "intégrerions": "intégrer",
    "intégrerons": "intégrer",
    "intégreront": "intégrer",
    "intégrez": "intégrer",
    "intégriez": "intégrer",
    "intégrions": "intégrer",
    "intégrismes": "intégrisme",
    "intégristes": "intégriste",
    "intégrités": "intégrité",
    "intégrons": "intégrer",
    "intégrâmes": "intégrer",
    "intégrât": "intégrer",
    "intégrâtes": "intégrer",
    "intégrèrent": "intégrer",
    "intégré": "intégrer",
    "intégrée": "intégrer",
    "intégrées": "intégrer",
    "intégrés": "intégrer",
    "intéressa": "intéresser",
    "intéressai": "intéresser",
    "intéressaient": "intéresser",
    "intéressais": "intéresser",
    "intéressait": "intéresser",
    "intéressant": "intéresser",
    "intéressante": "intéressant",
    "intéressantes": "intéressant",
    "intéressants": "intéressant",
    "intéressas": "intéresser",
    "intéressasse": "intéresser",
    "intéressassent": "intéresser",
    "intéressasses": "intéresser",
    "intéressassiez": "intéresser",
    "intéressassions": "intéresser",
    "intéresse": "intéresser",
    "intéressements": "intéressement",
    "intéressent": "intéresser",
    "intéressera": "intéresser",
    "intéresserai": "intéresser",
    "intéresseraient": "intéresser",
    "intéresserais": "intéresser",
    "intéresserait": "intéresser",
    "intéresseras": "intéresser",
    "intéresserez": "intéresser",
    "intéresseriez": "intéresser",
    "intéresserions": "intéresser",
    "intéresserons": "intéresser",
    "intéresseront": "intéresser",
    "intéresses": "intéresser",
    "intéressez": "intéresser",
    "intéressiez": "intéresser",
    "intéressions": "intéresser",
    "intéressons": "intéresser",
    "intéressâmes": "intéresser",
    "intéressât": "intéresser",
    "intéressâtes": "intéresser",
    "intéressèrent": "intéresser",
    "intéressé": "intéresser",
    "intéressée": "intéresser",
    "intéressées": "intéresser",
    "intéressés": "intéresser",
    "intérieure": "intérieur",
    "intérieures": "intérieur",
    "intérieurs": "intérrieur",
    "intérimaires": "intérimaire",
    "intérims": "intérim",
    "intériorisa": "intérioriser",
    "intériorisait": "intérioriser",
    "intériorise": "intérioriser",
    "intériorisent": "intérioriser",
    "intériorisée": "intérioriser",
    "intériorisées": "intérioriser",
    "intériorisés": "intérioriser",
    "intériorités": "intériorité",
    "intérêts": "intérêt",
    "inusables": "inusable",
    "inusitée": "inusité",
    "inusitées": "inusité",
    "inusités": "inusité",
    "inusuelle": "inusuel",
    "inutiles": "inutile",
    "inutilisables": "inutilisable",
    "inutilisée": "inutilisé",
    "inutilisées": "inutilisé",
    "inutilisés": "inutilisé",
    "inutilités": "inutilité",
    "invaincue": "invaincu",
    "invaincues": "invaincu",
    "invaincus": "invaincu",
    "invalida": "invalider",
    "invalidai": "invalider",
    "invalidaient": "invalider",
    "invalidais": "invalider",
    "invalidait": "invalider",
    "invalidant": "invalider",
    "invalidante": "invalidant",
    "invalidas": "invalider",
    "invalidasse": "invalider",
    "invalidassent": "invalider",
    "invalidasses": "invalider",
    "invalidassiez": "invalider",
    "invalidassions": "invalider",
    "invalide": "invalider",
    "invalident": "invalider",
    "invalidera": "invalider",
    "invaliderai": "invalider",
    "invalideraient": "invalider",
    "invaliderais": "invalider",
    "invaliderait": "invalider",
    "invalideras": "invalider",
    "invaliderez": "invalider",
    "invalideriez": "invalider",
    "invaliderions": "invalider",
    "invaliderons": "invalider",
    "invalideront": "invalider",
    "invalides": "invalider",
    "invalidez": "invalider",
    "invalidiez": "invalider",
    "invalidions": "invalider",
    "invalidités": "invalidité",
    "invalidons": "invalider",
    "invalidâmes": "invalider",
    "invalidât": "invalider",
    "invalidâtes": "invalider",
    "invalidèrent": "invalider",
    "invalidé": "invalider",
    "invalidée": "invalider",
    "invalidées": "invalider",
    "invalidés": "invalider",
    "invariables": "invariable",
    "invasions": "invasion",
    "invasive": "invasif",
    "invasives": "invasif",
    "invectiva": "invectiver",
    "invectivai": "invectiver",
    "invectivaient": "invectiver",
    "invectivais": "invectiver",
    "invectivait": "invectiver",
    "invectivant": "invectiver",
    "invectivas": "invectiver",
    "invectivasse": "invectiver",
    "invectivassent": "invectiver",
    "invectivasses": "invectiver",
    "invectivassiez": "invectiver",
    "invectivassions": "invectiver",
    "invective": "invectiver",
    "invectivent": "invectiver",
    "invectivera": "invectiver",
    "invectiverai": "invectiver",
    "invectiveraient": "invectiver",
    "invectiverais": "invectiver",
    "invectiverait": "invectiver",
    "invectiveras": "invectiver",
    "invectiverez": "invectiver",
    "invectiveriez": "invectiver",
    "invectiverions": "invectiver",
    "invectiverons": "invectiver",
    "invectiveront": "invectiver",
    "invectives": "invectiver",
    "invectivez": "invectiver",
    "invectiviez": "invectiver",
    "invectivions": "invectiver",
    "invectivons": "invectiver",
    "invectivâmes": "invectiver",
    "invectivât": "invectiver",
    "invectivâtes": "invectiver",
    "invectivèrent": "invectiver",
    "invectivé": "invectiver",
    "invectivée": "invectiver",
    "invectivées": "invectiver",
    "invectivés": "invectiver",
    "invendables": "invendable",
    "invendue": "invendu",
    "invendues": "invendu",
    "invendus": "invendu",
    "inventa": "inventer",
    "inventai": "inventer",
    "inventaient": "inventer",
    "inventaires": "inventaire",
    "inventais": "inventer",
    "inventait": "inventer",
    "inventant": "inventer",
    "inventas": "inventer",
    "inventasse": "inventer",
    "inventassent": "inventer",
    "inventasses": "inventer",
    "inventassiez": "inventer",
    "inventassions": "inventer",
    "invente": "inventer",
    "inventent": "inventer",
    "inventera": "inventer",
    "inventerai": "inventer",
    "inventeraient": "inventer",
    "inventerais": "inventer",
    "inventerait": "inventer",
    "inventeras": "inventer",
    "inventerez": "inventer",
    "inventeriez": "inventer",
    "inventerions": "inventer",
    "inventerons": "inventer",
    "inventeront": "inventer",
    "inventes": "inventer",
    "inventeurs": "inventeur",
    "inventez": "inventer",
    "inventiez": "inventer",
    "inventifs": "inventif",
    "inventions": "invention",
    "inventive": "inventif",
    "inventives": "inventif",
    "inventivités": "inventivité",
    "inventons": "inventer",
    "inventoria": "inventorier",
    "inventoriai": "inventorier",
    "inventoriaient": "inventorier",
    "inventoriais": "inventorier",
    "inventoriait": "inventorier",
    "inventoriant": "inventorier",
    "inventorias": "inventorier",
    "inventoriasse": "inventorier",
    "inventoriassent": "inventorier",
    "inventoriasses": "inventorier",
    "inventoriassiez": "inventorier",
    "inventoriassions": "inventorier",
    "inventorie": "inventorier",
    "inventorient": "inventorier",
    "inventoriera": "inventorier",
    "inventorierai": "inventorier",
    "inventorieraient": "inventorier",
    "inventorierais": "inventorier",
    "inventorierait": "inventorier",
    "inventorieras": "inventorier",
    "inventorierez": "inventorier",
    "inventorieriez": "inventorier",
    "inventorierions": "inventorier",
    "inventorierons": "inventorier",
    "inventorieront": "inventorier",
    "inventories": "inventorier",
    "inventoriez": "inventorier",
    "inventoriiez": "inventorier",
    "inventoriions": "inventorier",
    "inventorions": "inventorier",
    "inventoriâmes": "inventorier",
    "inventoriât": "inventorier",
    "inventoriâtes": "inventorier",
    "inventorièrent": "inventorier",
    "inventorié": "inventorier",
    "inventoriée": "inventorier",
    "inventoriées": "inventorier",
    "inventoriés": "inventorier",
    "inventrice": "inventeur",
    "inventrices": "inventeur",
    "inventâmes": "inventer",
    "inventât": "inventer",
    "inventâtes": "inventer",
    "inventèrent": "inventer",
    "inventé": "inventer",
    "inventée": "inventer",
    "inventées": "inventer",
    "inventés": "inventer",
    "inversa": "inverser",
    "inversai": "inverser",
    "inversaient": "inverser",
    "inversais": "inverser",
    "inversait": "inverser",
    "inversant": "inverser",
    "inversas": "inverser",
    "inversasse": "inverser",
    "inversassent": "inverser",
    "inversasses": "inverser",
    "inversassiez": "inverser",
    "inversassions": "inverser",
    "inverse": "inverser",
    "inversent": "inverser",
    "inversera": "inverser",
    "inverserai": "inverser",
    "inverseraient": "inverser",
    "inverserais": "inverser",
    "inverserait": "inverser",
    "inverseras": "inverser",
    "inverserez": "inverser",
    "inverseriez": "inverser",
    "inverserions": "inverser",
    "inverserons": "inverser",
    "inverseront": "inverser",
    "inverses": "inverser",
    "inversez": "inverser",
    "inversiez": "inverser",
    "inversions": "inversion",
    "inversons": "inverser",
    "inversâmes": "inverser",
    "inversât": "inverser",
    "inversâtes": "inverser",
    "inversèrent": "inverser",
    "inversé": "inverser",
    "inversée": "inverser",
    "inversées": "inverser",
    "inversés": "inverser",
    "inverti": "invertir",
    "invertie": "invertir",
    "inverties": "invertir",
    "invertira": "invertir",
    "invertirai": "invertir",
    "invertiraient": "invertir",
    "invertirais": "invertir",
    "invertirait": "invertir",
    "invertiras": "invertir",
    "invertirent": "invertir",
    "invertirez": "invertir",
    "invertiriez": "invertir",
    "invertirions": "invertir",
    "invertirons": "invertir",
    "invertiront": "invertir",
    "invertis": "invertir",
    "invertissaient": "invertir",
    "invertissais": "invertir",
    "invertissait": "invertir",
    "invertissant": "invertir",
    "invertisse": "invertir",
    "invertissent": "invertir",
    "invertisses": "invertir",
    "invertissez": "invertir",
    "invertissiez": "invertir",
    "invertissions": "invertir",
    "invertissons": "invertir",
    "invertit": "invertir",
    "invertébrée": "invertébré",
    "invertébrés": "invertébré",
    "invertîmes": "invertir",
    "invertît": "invertir",
    "invertîtes": "invertir",
    "investi": "investir",
    "investie": "investir",
    "investies": "investir",
    "investigateurs": "investigateur",
    "investigations": "investigation",
    "investigatrice": "investigateur",
    "investigatrices": "investigateur",
    "investiguant": "investiguer",
    "investira": "investir",
    "investirai": "investir",
    "investiraient": "investir",
    "investirais": "investir",
    "investirait": "investir",
    "investiras": "investir",
    "investirent": "investir",
    "investirez": "investir",
    "investiriez": "investir",
    "investirions": "investir",
    "investirons": "investir",
    "investiront": "investir",
    "investis": "investir",
    "investissaient": "investir",
    "investissais": "investir",
    "investissait": "investir",
    "investissant": "investir",
    "investisse": "investir",
    "investissements": "investissement",
    "investissent": "investir",
    "investisses": "investir",
    "investisseurs": "investisseur",
    "investissez": "investir",
    "investissiez": "investir",
    "investissions": "investir",
    "investissons": "investir",
    "investit": "investir",
    "investitures": "investiture",
    "investîmes": "investir",
    "investît": "investir",
    "investîtes": "investir",
    "invincibles": "invincible",
    "inviolabilités": "inviolabilité",
    "inviolables": "inviolable",
    "inviolée": "inviolé",
    "inviolées": "inviolé",
    "inviolés": "inviolé",
    "invisible piston": "invisible-piston",
    "invisibles": "invisible",
    "invita": "inviter",
    "invitai": "inviter",
    "invitaient": "inviter",
    "invitais": "inviter",
    "invitait": "inviter",
    "invitant": "inviter",
    "invitante": "invitant",
    "invitantes": "invitant",
    "invitants": "invitant",
    "invitas": "inviter",
    "invitasse": "inviter",
    "invitassent": "inviter",
    "invitasses": "inviter",
    "invitassiez": "inviter",
    "invitassions": "inviter",
    "invitations": "invitation",
    "invite": "inviter",
    "invitent": "inviter",
    "invitera": "inviter",
    "inviterai": "inviter",
    "inviteraient": "inviter",
    "inviterais": "inviter",
    "inviterait": "inviter",
    "inviteras": "inviter",
    "inviterez": "inviter",
    "inviteriez": "inviter",
    "inviterions": "inviter",
    "inviterons": "inviter",
    "inviteront": "inviter",
    "invites": "inviter",
    "inviteurs": "inviteur",
    "invitez": "inviter",
    "invitiez": "inviter",
    "invitions": "inviter",
    "invitons": "inviter",
    "invitâmes": "inviter",
    "invitât": "inviter",
    "invitâtes": "inviter",
    "invitèrent": "inviter",
    "invité": "inviter",
    "invitée": "inviter",
    "invitées": "inviter",
    "invités": "inviter",
    "invivables": "invivable",
    "invocations": "invocation",
    "involontaires": "involontaire",
    "involucres": "involucre",
    "involutifs": "involutif",
    "involutions": "involution",
    "invoqua": "invoquer",
    "invoquai": "invoquer",
    "invoquaient": "invoquer",
    "invoquais": "invoquer",
    "invoquait": "invoquer",
    "invoquant": "invoquer",
    "invoquas": "invoquer",
    "invoquasse": "invoquer",
    "invoquassent": "invoquer",
    "invoquasses": "invoquer",
    "invoquassiez": "invoquer",
    "invoquassions": "invoquer",
    "invoque": "invoquer",
    "invoquent": "invoquer",
    "invoquera": "invoquer",
    "invoquerai": "invoquer",
    "invoqueraient": "invoquer",
    "invoquerais": "invoquer",
    "invoquerait": "invoquer",
    "invoqueras": "invoquer",
    "invoquerez": "invoquer",
    "invoqueriez": "invoquer",
    "invoquerions": "invoquer",
    "invoquerons": "invoquer",
    "invoqueront": "invoquer",
    "invoques": "invoquer",
    "invoquez": "invoquer",
    "invoquiez": "invoquer",
    "invoquions": "invoquer",
    "invoquons": "invoquer",
    "invoquâmes": "invoquer",
    "invoquât": "invoquer",
    "invoquâtes": "invoquer",
    "invoquèrent": "invoquer",
    "invoqué": "invoquer",
    "invoquée": "invoquer",
    "invoquées": "invoquer",
    "invoqués": "invoquer",
    "invraisemblables": "invraisemblable",
    "invraisemblances": "invraisemblance",
    "invulnérables": "invulnérable",
    "invérifiables": "invérifiable",
    "invétéré": "invétérer",
    "invétérée": "invétérer",
    "invétérées": "invétéré",
    "invétérés": "invétéré",
    "inébranlables": "inébranlable",
    "inécoutée": "inécouté",
    "inédite": "inédit",
    "inédites": "inédit",
    "inédits": "inédit",
    "inégala": "inégaler",
    "inégalables": "inégalable",
    "inégalai": "inégaler",
    "inégalaient": "inégaler",
    "inégalais": "inégaler",
    "inégalait": "inégaler",
    "inégalant": "inégaler",
    "inégalas": "inégaler",
    "inégalasse": "inégaler",
    "inégalassent": "inégaler",
    "inégalasses": "inégaler",
    "inégalassiez": "inégaler",
    "inégalassions": "inégaler",
    "inégale": "inégaler",
    "inégalent": "inégaler",
    "inégalera": "inégaler",
    "inégalerai": "inégaler",
    "inégaleraient": "inégaler",
    "inégalerais": "inégaler",
    "inégalerait": "inégaler",
    "inégaleras": "inégaler",
    "inégalerez": "inégaler",
    "inégaleriez": "inégaler",
    "inégalerions": "inégaler",
    "inégalerons": "inégaler",
    "inégaleront": "inégaler",
    "inégales": "inégaler",
    "inégalez": "inégaler",
    "inégaliez": "inégaler",
    "inégalions": "inégaler",
    "inégalitaires": "inégalitaire",
    "inégalités": "inégalité",
    "inégalons": "inégaler",
    "inégalâmes": "inégaler",
    "inégalât": "inégaler",
    "inégalâtes": "inégaler",
    "inégalèrent": "inégaler",
    "inégalé": "inégaler",
    "inégalée": "inégaler",
    "inégalées": "inégaler",
    "inégalés": "inégaler",
    "inégaux": "inégal",
    "inéligibilités": "inéligibilité",
    "inéligibles": "inéligible",
    "inéluctables": "inéluctable",
    "inélégances": "inélégance",
    "inélégante": "inélégant",
    "inélégantes": "inélégant",
    "inélégants": "inélégant",
    "inénarrables": "inénarrable",
    "inépuisables": "inépuisable",
    "inépuisée": "inépuisé",
    "inépuisées": "inépuisé",
    "inépuisés": "inépuisé",
    "inéquitables": "inéquitable",
    "inévitables": "inévitable",
    "iodes": "iode",
    "iodle": "iodler",
    "iodée": "ioder",
    "ionienne": "ionien",
    "ioniennes": "ionien",
    "ioniens": "ionien",
    "ioniques": "ionique",
    "ionisa": "ioniser",
    "ionisai": "ioniser",
    "ionisaient": "ioniser",
    "ionisais": "ioniser",
    "ionisait": "ioniser",
    "ionisant": "ioniser",
    "ionisante": "ionisant",
    "ionisantes": "ionisant",
    "ionisants": "ionisant",
    "ionisas": "ioniser",
    "ionisasse": "ioniser",
    "ionisassent": "ioniser",
    "ionisasses": "ioniser",
    "ionisassiez": "ioniser",
    "ionisassions": "ioniser",
    "ionise": "ioniser",
    "ionisent": "ioniser",
    "ionisera": "ioniser",
    "ioniserai": "ioniser",
    "ioniseraient": "ioniser",
    "ioniserais": "ioniser",
    "ioniserait": "ioniser",
    "ioniseras": "ioniser",
    "ioniserez": "ioniser",
    "ioniseriez": "ioniser",
    "ioniserions": "ioniser",
    "ioniserons": "ioniser",
    "ioniseront": "ioniser",
    "ionises": "ioniser",
    "ionisez": "ioniser",
    "ionisiez": "ioniser",
    "ionisions": "ioniser",
    "ionisons": "ioniser",
    "ionisâmes": "ioniser",
    "ionisât": "ioniser",
    "ionisâtes": "ioniser",
    "ionisèrent": "ioniser",
    "ionisé": "ioniser",
    "ionisée": "ioniser",
    "ionisées": "ioniser",
    "ionisés": "ioniser",
    "ions": "ion",
    "iotas": "iota",
    "ipécas": "ipéca",
    "ira": "aller",
    "irai": "aller",
    "iraient": "aller",
    "irais": "aller",
    "irait": "aller",
    "irakienne": "irakien",
    "irakiennes": "irakien",
    "irakiens": "irakien",
    "iranienne": "iranien",
    "iraniennes": "iranien",
    "iraniens": "iranien",
    "iraquienne": "iraquien",
    "iraquiens": "iraquien",
    "iras": "aller",
    "irascibles": "irascible",
    "ires": "ire",
    "irez": "aller",
    "iridescentes": "iridescent",
    "iridiums": "iridium",
    "iriez": "aller",
    "irions": "aller",
    "irisaient": "iriser",
    "irisait": "iriser",
    "irisant": "iriser",
    "irisations": "irisation",
    "irise": "iriser",
    "irisent": "iriser",
    "iriserait": "iriser",
    "irisé": "iriser",
    "irisée": "iriser",
    "irisées": "iriser",
    "irisés": "iriser",
    "irlandaise": "irlandais",
    "irlandaises": "irlandais",
    "ironies": "ironie",
    "ironiques": "ironique",
    "ironisa": "ironiser",
    "ironisai": "ironiser",
    "ironisaient": "ironiser",
    "ironisais": "ironiser",
    "ironisait": "ironiser",
    "ironisant": "ironiser",
    "ironisas": "ironiser",
    "ironisasse": "ironiser",
    "ironisassent": "ironiser",
    "ironisasses": "ironiser",
    "ironisassiez": "ironiser",
    "ironisassions": "ironiser",
    "ironise": "ironiser",
    "ironisent": "ironiser",
    "ironisera": "ironiser",
    "ironiserai": "ironiser",
    "ironiseraient": "ironiser",
    "ironiserais": "ironiser",
    "ironiserait": "ironiser",
    "ironiseras": "ironiser",
    "ironiserez": "ironiser",
    "ironiseriez": "ironiser",
    "ironiserions": "ironiser",
    "ironiserons": "ironiser",
    "ironiseront": "ironiser",
    "ironises": "ironiser",
    "ironisez": "ironiser",
    "ironisiez": "ironiser",
    "ironisions": "ironiser",
    "ironisons": "ironiser",
    "ironisâmes": "ironiser",
    "ironisât": "ironiser",
    "ironisâtes": "ironiser",
    "ironisèrent": "ironiser",
    "ironisé": "ironiser",
    "ironisée": "ironiser",
    "ironisées": "ironiser",
    "ironisés": "ironiser",
    "irons": "aller",
    "iront": "aller",
    "iroquoise": "iroquois",
    "iroquoises": "iroquois",
    "irradia": "irradier",
    "irradiai": "irradier",
    "irradiaient": "irradier",
    "irradiais": "irradier",
    "irradiait": "irradier",
    "irradiant": "irradier",
    "irradiante": "irradiant",
    "irradiantes": "irradiant",
    "irradias": "irradier",
    "irradiasse": "irradier",
    "irradiassent": "irradier",
    "irradiasses": "irradier",
    "irradiassiez": "irradier",
    "irradiassions": "irradier",
    "irradiations": "irradiation",
    "irradie": "irradier",
    "irradient": "irradier",
    "irradiera": "irradier",
    "irradierai": "irradier",
    "irradieraient": "irradier",
    "irradierais": "irradier",
    "irradierait": "irradier",
    "irradieras": "irradier",
    "irradierez": "irradier",
    "irradieriez": "irradier",
    "irradierions": "irradier",
    "irradierons": "irradier",
    "irradieront": "irradier",
    "irradies": "irradier",
    "irradiez": "irradier",
    "irradiiez": "irradier",
    "irradiions": "irradier",
    "irradions": "irradier",
    "irradiâmes": "irradier",
    "irradiât": "irradier",
    "irradiâtes": "irradier",
    "irradièrent": "irradier",
    "irradié": "irradier",
    "irradiée": "irradier",
    "irradiées": "irradier",
    "irradiés": "irradier",
    "irraisonnée": "irraisonné",
    "irraisonnées": "irraisonné",
    "irraisonnés": "irraisonné",
    "irrationalismes": "irrationalisme",
    "irrationalités": "irrationalité",
    "irrationnelle": "irrationnel",
    "irrationnelles": "irrationnel",
    "irrationnels": "irrationnel",
    "irrattrapables": "irrattrapable",
    "irrecevables": "irrecevable",
    "irreligions": "irreligion",
    "irremplaçables": "irremplaçable",
    "irrespects": "irrespect",
    "irrespectueuse": "irrespectueux",
    "irrespectueuses": "irrespectueux",
    "irrespirables": "irrespirable",
    "irresponsabilités": "irresponsabilité",
    "irresponsables": "irresponsable",
    "irrigables": "irrigable",
    "irrigateurs": "irrigateur",
    "irrigations": "irrigation",
    "irrigua": "irriguer",
    "irriguai": "irriguer",
    "irriguaient": "irriguer",
    "irriguais": "irriguer",
    "irriguait": "irriguer",
    "irriguant": "irriguer",
    "irriguas": "irriguer",
    "irriguasse": "irriguer",
    "irriguassent": "irriguer",
    "irriguasses": "irriguer",
    "irriguassiez": "irriguer",
    "irriguassions": "irriguer",
    "irrigue": "irriguer",
    "irriguent": "irriguer",
    "irriguera": "irriguer",
    "irriguerai": "irriguer",
    "irrigueraient": "irriguer",
    "irriguerais": "irriguer",
    "irriguerait": "irriguer",
    "irrigueras": "irriguer",
    "irriguerez": "irriguer",
    "irrigueriez": "irriguer",
    "irriguerions": "irriguer",
    "irriguerons": "irriguer",
    "irrigueront": "irriguer",
    "irrigues": "irriguer",
    "irriguez": "irriguer",
    "irriguiez": "irriguer",
    "irriguions": "irriguer",
    "irriguons": "irriguer",
    "irriguâmes": "irriguer",
    "irriguât": "irriguer",
    "irriguâtes": "irriguer",
    "irriguèrent": "irriguer",
    "irrigué": "irriguer",
    "irriguée": "irriguer",
    "irriguées": "irriguer",
    "irrigués": "irriguer",
    "irrita": "irriter",
    "irritables": "irritable",
    "irritai": "irriter",
    "irritaient": "irriter",
    "irritais": "irriter",
    "irritait": "irriter",
    "irritant": "irriter",
    "irritante": "irritant",
    "irritantes": "irritant",
    "irritants": "irritant",
    "irritas": "irriter",
    "irritasse": "irriter",
    "irritassent": "irriter",
    "irritasses": "irriter",
    "irritassiez": "irriter",
    "irritassions": "irriter",
    "irritations": "irritation",
    "irrite": "irriter",
    "irritent": "irriter",
    "irritera": "irriter",
    "irriterai": "irriter",
    "irriteraient": "irriter",
    "irriterais": "irriter",
    "irriterait": "irriter",
    "irriteras": "irriter",
    "irriterez": "irriter",
    "irriteriez": "irriter",
    "irriterions": "irriter",
    "irriterons": "irriter",
    "irriteront": "irriter",
    "irrites": "irriter",
    "irritez": "irriter",
    "irritiez": "irriter",
    "irritions": "irriter",
    "irritons": "irriter",
    "irritâmes": "irriter",
    "irritât": "irriter",
    "irritâtes": "irriter",
    "irritèrent": "irriter",
    "irrité": "irriter",
    "irritée": "irriter",
    "irritées": "irriter",
    "irrités": "irriter",
    "irruptions": "irruption",
    "irréalisables": "irréalisable",
    "irréalisait": "irréaliser",
    "irréalise": "irréaliser",
    "irréalistes": "irréaliste",
    "irréalisés": "irréalisé",
    "irréalités": "irréalité",
    "irréconciliables": "irréconciliable",
    "irrécupérables": "irrécupérable",
    "irrécusables": "irrécusable",
    "irréductibles": "irréductible",
    "irréelle": "irréel",
    "irréelles": "irréel",
    "irréels": "irréel",
    "irréflexions": "irréflexion",
    "irréfléchie": "irréfléchi",
    "irréfléchies": "irréfléchi",
    "irréfléchis": "irréfléchi",
    "irréfutables": "irréfutable",
    "irréfutée": "irréfuté",
    "irréfutées": "irréfuté",
    "irréfutés": "irréfuté",
    "irrégularités": "irrégularité",
    "irréguliers": "irrégulier",
    "irrégulière": "irrégulier",
    "irrégulières": "irrégulier",
    "irréligieuse": "irréligieux",
    "irréligions": "irréligion",
    "irrémissibles": "irrémissible",
    "irrémédiables": "irrémédiable",
    "irréparables": "irréparable",
    "irrépressibles": "irrépressible",
    "irréprochables": "irréprochable",
    "irrépréhensibles": "irrépréhensible",
    "irrésistibles": "irrésistible",
    "irrésolue": "irrésolu",
    "irrésolues": "irrésolu",
    "irrésolus": "irrésolu",
    "irrétrécissables": "irrétrécissable",
    "irréversibilités": "irréversibilité",
    "irréversibles": "irréversible",
    "irrévocables": "irrévocable",
    "irrévérences": "irrévérence",
    "irrévérencieuse": "irrévérencieux",
    "irrévérencieuses": "irrévérencieux",
    "irtigations": "irtigation",
    "isards": "isard",
    "isbas": "isba",
    "ischémies": "ischémie",
    "islamiques": "islamique",
    "islamisants": "islamisant",
    "islamisations": "islamisation",
    "islamismes": "islamisme",
    "islamistes": "islamiste",
    "islamisée": "islamisé",
    "islamisées": "islamiser",
    "islamologues": "islamologue",
    "islams": "islam",
    "islandaise": "islandais",
    "ismaélienne": "ismaélien",
    "ismaéliennes": "ismaélien",
    "ismaéliens": "ismaélien",
    "ismaïliens": "ismaïlien",
    "isobares": "isobare",
    "isoclinale": "isoclinal",
    "isoclinales": "isoclinal",
    "isoclinaux": "isoclinal",
    "isocèles": "isocèle",
    "isoglosses": "isoglosse",
    "isoglucoses": "isoglucose",
    "isola": "isoler",
    "isolables": "isolable",
    "isolai": "isoler",
    "isolaient": "isoler",
    "isolais": "isoler",
    "isolait": "isoler",
    "isolant": "isoler",
    "isolante": "isolant",
    "isolas": "isoler",
    "isolasse": "isoler",
    "isolassent": "isoler",
    "isolasses": "isoler",
    "isolassiez": "isoler",
    "isolassions": "isoler",
    "isolateurs": "isolateur",
    "isolations": "isolation",
    "isole": "isoler",
    "isolements": "isolement",
    "isolent": "isoler",
    "isolera": "isoler",
    "isolerai": "isoler",
    "isoleraient": "isoler",
    "isolerais": "isoler",
    "isolerait": "isoler",
    "isoleras": "isoler",
    "isolerez": "isoler",
    "isoleriez": "isoler",
    "isolerions": "isoler",
    "isolerons": "isoler",
    "isoleront": "isoler",
    "isoles": "isoler",
    "isolez": "isoler",
    "isoliez": "isoler",
    "isolions": "isoler",
    "isoloirs": "isoloir",
    "isolons": "isoler",
    "isolâmes": "isoler",
    "isolât": "isoler",
    "isolâtes": "isoler",
    "isolèrent": "isoler",
    "isolé": "isoler",
    "isolée": "isoler",
    "isolées": "isoler",
    "isolés": "isoler",
    "isomorphes": "isomorphe",
    "isomères": "isomère",
    "isotopes": "isotope",
    "isotopiques": "isotopique",
    "israélienne": "israélien",
    "israéliennes": "israélien",
    "israéliens": "israélien",
    "israélites": "israélite",
    "israélo-syrienne": "israélo-syrien",
    "issue": "issu",
    "issues": "issue",
    "issus": "issu",
    "isthmes": "isthme",
    "istrienne": "istrien",
    "istriennes": "istrien",
    "istriens": "istrien",
    "italienne": "italien",
    "italiennes": "italien",
    "italiens": "italien",
    "italiques": "italique",
    "italo-allemande": "italo-allemand",
    "italo-allemandes": "italo-allemand",
    "italo-américaine": "italo-américain",
    "italo-françaises": "italo-français",
    "items": "item",
    "itinéraires": "itinéraire",
    "itinérante": "itinérant",
    "itinérantes": "itinérant",
    "itinérants": "itinérant",
    "itérations": "itération",
    "iules": "iule",
    "ives": "ive",
    "ivoires": "ivoire",
    "ivoirienne": "ivoirien",
    "ivoiriennes": "ivoirien",
    "ivoiriens": "ivoirien",
    "ivoirine": "ivoirin",
    "ivoirines": "ivoirin",
    "ivoirins": "ivoirin",
    "ivraies": "ivraie",
    "ivres": "ivre",
    "ivresses": "ivresse",
    "ivrognait": "ivrogner",
    "ivrognasse": "ivrogner",
    "ivrognes": "ivrogne",
    "ixe": "ixer",
    "j'": "il",
    "jabots": "jabot",
    "jacarandas": "jacaranda",
    "jacassa": "jacasser",
    "jacassages": "jacassage",
    "jacassai": "jacasser",
    "jacassaient": "jacasser",
    "jacassais": "jacasser",
    "jacassait": "jacasser",
    "jacassant": "jacasser",
    "jacassante": "jacassant",
    "jacassantes": "jacassant",
    "jacassants": "jacassant",
    "jacassas": "jacasser",
    "jacassasse": "jacasser",
    "jacassassent": "jacasser",
    "jacassasses": "jacasser",
    "jacassassiez": "jacasser",
    "jacassassions": "jacasser",
    "jacasse": "jacasser",
    "jacassements": "jacassement",
    "jacassent": "jacasser",
    "jacassera": "jacasser",
    "jacasserai": "jacasser",
    "jacasseraient": "jacasser",
    "jacasserais": "jacasser",
    "jacasserait": "jacasser",
    "jacasseras": "jacasser",
    "jacasserez": "jacasser",
    "jacasseries": "jacasserie",
    "jacasseriez": "jacasser",
    "jacasserions": "jacasser",
    "jacasserons": "jacasser",
    "jacasseront": "jacasser",
    "jacasses": "jacasser",
    "jacasseurs": "jacasseur",
    "jacasseuse": "jacasseur",
    "jacassez": "jacasser",
    "jacassiers": "jacassier",
    "jacassiez": "jacasser",
    "jacassions": "jacasser",
    "jacassière": "jacassier",
    "jacassons": "jacasser",
    "jacassâmes": "jacasser",
    "jacassât": "jacasser",
    "jacassâtes": "jacasser",
    "jacassèrent": "jacasser",
    "jacassé": "jacasser",
    "jachères": "jachère",
    "jacinthes": "jacinthe",
    "jackets": "jacket",
    "jackpots": "jackpot",
    "jacks": "jack",
    "jacobine": "jacobin",
    "jacobines": "jacobin",
    "jacobinismes": "jacobinisme",
    "jacobins": "jacobin",
    "jacobites": "jacobite",
    "jacobées": "jacobée",
    "jacquards": "jacquard",
    "jacquemarts": "jacquemart",
    "jacqueries": "jacquerie",
    "jactais": "jacter",
    "jactait": "jacter",
    "jactances": "jactance",
    "jactant": "jacter",
    "jacte": "jacter",
    "jactent": "jacter",
    "jacteraient": "jacter",
    "jacterais": "jacter",
    "jactes": "jacter",
    "jactez": "jacter",
    "jactions": "jacter",
    "jacté": "jacter",
    "jacuzzis": "jacuzzi",
    "jades": "jade",
    "jaffa": "jaffer",
    "jaffas": "jaffer",
    "jaguars": "jaguar",
    "jailli": "jaillir",
    "jaillie": "jaillir",
    "jaillies": "jaillir",
    "jaillira": "jaillir",
    "jaillirai": "jaillir",
    "jailliraient": "jaillir",
    "jaillirais": "jaillir",
    "jaillirait": "jaillir",
    "jailliras": "jaillir",
    "jaillirent": "jaillir",
    "jaillirez": "jaillir",
    "jailliriez": "jaillir",
    "jaillirions": "jaillir",
    "jaillirons": "jaillir",
    "jailliront": "jaillir",
    "jaillis": "jaillir",
    "jaillissaient": "jaillir",
    "jaillissais": "jaillir",
    "jaillissait": "jaillir",
    "jaillissant": "jaillir",
    "jaillissante": "jaillissant",
    "jaillissantes": "jaillissant",
    "jaillissants": "jaillissant",
    "jaillisse": "jaillir",
    "jaillissements": "jaillissement",
    "jaillissent": "jaillir",
    "jaillisses": "jaillir",
    "jaillissez": "jaillir",
    "jaillissiez": "jaillir",
    "jaillissions": "jaillir",
    "jaillissons": "jaillir",
    "jaillit": "jaillir",
    "jaillîmes": "jaillir",
    "jaillît": "jaillir",
    "jaillîtes": "jaillir",
    "jalminces": "jalmince",
    "jalonna": "jalonner",
    "jalonnai": "jalonner",
    "jalonnaient": "jalonner",
    "jalonnais": "jalonner",
    "jalonnait": "jalonner",
    "jalonnant": "jalonner",
    "jalonnas": "jalonner",
    "jalonnasse": "jalonner",
    "jalonnassent": "jalonner",
    "jalonnasses": "jalonner",
    "jalonnassiez": "jalonner",
    "jalonnassions": "jalonner",
    "jalonne": "jalonner",
    "jalonnent": "jalonner",
    "jalonnera": "jalonner",
    "jalonnerai": "jalonner",
    "jalonneraient": "jalonner",
    "jalonnerais": "jalonner",
    "jalonnerait": "jalonner",
    "jalonneras": "jalonner",
    "jalonnerez": "jalonner",
    "jalonneriez": "jalonner",
    "jalonnerions": "jalonner",
    "jalonnerons": "jalonner",
    "jalonneront": "jalonner",
    "jalonnes": "jalonner",
    "jalonnez": "jalonner",
    "jalonniez": "jalonner",
    "jalonnions": "jalonner",
    "jalonnons": "jalonner",
    "jalonnâmes": "jalonner",
    "jalonnât": "jalonner",
    "jalonnâtes": "jalonner",
    "jalonnèrent": "jalonner",
    "jalonné": "jalonner",
    "jalonnée": "jalonner",
    "jalonnées": "jalonner",
    "jalonnés": "jalonner",
    "jalons": "jalon",
    "jalousaient": "jalouser",
    "jalousais": "jalouser",
    "jalousait": "jalouser",
    "jalousant": "jalouser",
    "jalouse": "jaloux",
    "jalousent": "jalouser",
    "jalouserais": "jalouser",
    "jalouses": "jaloux",
    "jalousies": "jalousie",
    "jalousé": "jalouser",
    "jalousée": "jalouser",
    "jam-sessions": "jam-session",
    "jamaïcaine": "jamaïcain",
    "jamaïcains": "jamaïcain",
    "jamaïquains": "jamaïquain",
    "jambages": "jambage",
    "jambes": "jambe",
    "jambières": "jambière",
    "jambonneaux": "jambonneau",
    "jambons": "jambon",
    "jamborees": "jamboree",
    "janissaires": "janissaire",
    "jans": "jan",
    "jansénistes": "janséniste",
    "jantes": "jante",
    "janviers": "janvier",
    "japonaise": "japonais",
    "japonaises": "japonais",
    "japoneries": "japonerie",
    "japonisants": "japonisant",
    "japons": "japon",
    "jappa": "japper",
    "jappai": "japper",
    "jappaient": "japper",
    "jappais": "japper",
    "jappait": "japper",
    "jappant": "japper",
    "jappas": "japper",
    "jappasse": "japper",
    "jappassent": "japper",
    "jappasses": "japper",
    "jappassiez": "japper",
    "jappassions": "japper",
    "jappe": "japper",
    "jappements": "jappement",
    "jappent": "japper",
    "jappera": "japper",
    "japperai": "japper",
    "japperaient": "japper",
    "japperais": "japper",
    "japperait": "japper",
    "japperas": "japper",
    "japperez": "japper",
    "japperiez": "japper",
    "japperions": "japper",
    "japperons": "japper",
    "japperont": "japper",
    "jappes": "japper",
    "jappez": "japper",
    "jappiez": "japper",
    "jappions": "japper",
    "jappons": "japper",
    "jappâmes": "japper",
    "jappât": "japper",
    "jappâtes": "japper",
    "jappèrent": "japper",
    "jappé": "japper",
    "japs": "jap",
    "jaquemarts": "jaquemart",
    "jaques": "jaque",
    "jaquettes": "jaquette",
    "jardina": "jardiner",
    "jardinai": "jardiner",
    "jardinaient": "jardiner",
    "jardinais": "jardiner",
    "jardinait": "jardiner",
    "jardinant": "jardiner",
    "jardinas": "jardiner",
    "jardinasse": "jardiner",
    "jardinassent": "jardiner",
    "jardinasses": "jardiner",
    "jardinassiez": "jardiner",
    "jardinassions": "jardiner",
    "jardine": "jardiner",
    "jardinent": "jardiner",
    "jardinera": "jardiner",
    "jardinerai": "jardiner",
    "jardineraient": "jardiner",
    "jardinerais": "jardiner",
    "jardinerait": "jardiner",
    "jardineras": "jardiner",
    "jardinerez": "jardiner",
    "jardineriez": "jardiner",
    "jardinerions": "jardiner",
    "jardinerons": "jardiner",
    "jardineront": "jardiner",
    "jardines": "jardiner",
    "jardinets": "jardinet",
    "jardinez": "jardiner",
    "jardiniers": "jardinier",
    "jardiniez": "jardiner",
    "jardinions": "jardiner",
    "jardinière": "jardinier",
    "jardinières": "jardinière",
    "jardinons": "jardiner",
    "jardins": "jardin",
    "jardinâmes": "jardiner",
    "jardinât": "jardiner",
    "jardinâtes": "jardiner",
    "jardinèrent": "jardiner",
    "jardiné": "jardiner",
    "jardinée": "jardiner",
    "jardinées": "jardiner",
    "jardinés": "jardiner",
    "jargonnant": "jargonner",
    "jargonne": "jargonner",
    "jargonnent": "jargonner",
    "jargonné": "jargonner",
    "jargons": "jargon",
    "jarres": "jarre",
    "jarretelles": "jarretelle",
    "jarretières": "jarretière",
    "jarrets": "jarret",
    "jasa": "jaser",
    "jasai": "jaser",
    "jasaient": "jaser",
    "jasais": "jaser",
    "jasait": "jaser",
    "jasant": "jaser",
    "jasas": "jaser",
    "jasasse": "jaser",
    "jasassent": "jaser",
    "jasasses": "jaser",
    "jasassiez": "jaser",
    "jasassions": "jaser",
    "jase": "jaser",
    "jasent": "jaser",
    "jasera": "jaser",
    "jaserai": "jaser",
    "jaseraient": "jaser",
    "jaserais": "jaser",
    "jaserait": "jaser",
    "jaseras": "jaser",
    "jaserez": "jaser",
    "jaseriez": "jaser",
    "jaserions": "jaser",
    "jaserons": "jaser",
    "jaseront": "jaser",
    "jases": "jaser",
    "jasez": "jaser",
    "jasiez": "jaser",
    "jasions": "jaser",
    "jasmins": "jasmin",
    "jasons": "jaser",
    "jaspaient": "jasper",
    "jaspes": "jaspe",
    "jaspinaient": "jaspiner",
    "jaspinais": "jaspiner",
    "jaspinait": "jaspiner",
    "jaspine": "jaspiner",
    "jaspinent": "jaspiner",
    "jaspiné": "jaspiner",
    "jaspé": "jasper",
    "jaspées": "jasper",
    "jaspés": "jasper",
    "jasâmes": "jaser",
    "jasât": "jaser",
    "jasâtes": "jaser",
    "jasèrent": "jaser",
    "jasé": "jaser",
    "jattes": "jatte",
    "jauge": "jauger",
    "jaugea": "jauger",
    "jaugeages": "jaugeage",
    "jaugeai": "jauger",
    "jaugeaient": "jauger",
    "jaugeais": "jauger",
    "jaugeait": "jauger",
    "jaugeant": "jauger",
    "jaugeas": "jauger",
    "jaugeasse": "jauger",
    "jaugeassent": "jauger",
    "jaugeasses": "jauger",
    "jaugeassiez": "jauger",
    "jaugeassions": "jauger",
    "jaugent": "jauger",
    "jaugeons": "jauger",
    "jaugera": "jauger",
    "jaugerai": "jauger",
    "jaugeraient": "jauger",
    "jaugerais": "jauger",
    "jaugerait": "jauger",
    "jaugeras": "jauger",
    "jaugerez": "jauger",
    "jaugeriez": "jauger",
    "jaugerions": "jauger",
    "jaugerons": "jauger",
    "jaugeront": "jauger",
    "jauges": "jauger",
    "jaugez": "jauger",
    "jaugeâmes": "jauger",
    "jaugeât": "jauger",
    "jaugeâtes": "jauger",
    "jaugiez": "jauger",
    "jaugions": "jauger",
    "jaugèrent": "jauger",
    "jaugé": "jauger",
    "jaugée": "jauger",
    "jaugées": "jauger",
    "jaugés": "jauger",
    "jaunasses": "jaunasse",
    "jaunes": "jaune",
    "jaunets": "jaunet",
    "jauni": "jaunir",
    "jaunie": "jaunir",
    "jaunies": "jaunir",
    "jaunira": "jaunir",
    "jaunirai": "jaunir",
    "jauniraient": "jaunir",
    "jaunirais": "jaunir",
    "jaunirait": "jaunir",
    "jauniras": "jaunir",
    "jaunirent": "jaunir",
    "jaunirez": "jaunir",
    "jauniriez": "jaunir",
    "jaunirions": "jaunir",
    "jaunirons": "jaunir",
    "jauniront": "jaunir",
    "jaunis": "jaunir",
    "jaunissaient": "jaunir",
    "jaunissais": "jaunir",
    "jaunissait": "jaunir",
    "jaunissant": "jaunir",
    "jaunissante": "jaunissant",
    "jaunissantes": "jaunissant",
    "jaunissants": "jaunissant",
    "jaunisse": "jaunir",
    "jaunissements": "jaunissement",
    "jaunissent": "jaunir",
    "jaunisses": "jaunisse",
    "jaunissez": "jaunir",
    "jaunissiez": "jaunir",
    "jaunissions": "jaunir",
    "jaunissons": "jaunir",
    "jaunit": "jaunir",
    "jaunâtres": "jaunâtre",
    "jaunîmes": "jaunir",
    "jaunît": "jaunir",
    "jaunîtes": "jaunir",
    "javanaise": "javanais",
    "javanaises": "javanais",
    "javas": "java",
    "javelles": "javelle",
    "javellisa": "javelliser",
    "javellisai": "javelliser",
    "javellisaient": "javelliser",
    "javellisais": "javelliser",
    "javellisait": "javelliser",
    "javellisant": "javelliser",
    "javellisas": "javelliser",
    "javellisasse": "javelliser",
    "javellisassent": "javelliser",
    "javellisasses": "javelliser",
    "javellisassiez": "javelliser",
    "javellisassions": "javelliser",
    "javellise": "javelliser",
    "javellisent": "javelliser",
    "javellisera": "javelliser",
    "javelliserai": "javelliser",
    "javelliseraient": "javelliser",
    "javelliserais": "javelliser",
    "javelliserait": "javelliser",
    "javelliseras": "javelliser",
    "javelliserez": "javelliser",
    "javelliseriez": "javelliser",
    "javelliserions": "javelliser",
    "javelliserons": "javelliser",
    "javelliseront": "javelliser",
    "javellises": "javelliser",
    "javellisez": "javelliser",
    "javellisiez": "javelliser",
    "javellisions": "javelliser",
    "javellisons": "javelliser",
    "javellisâmes": "javelliser",
    "javellisât": "javelliser",
    "javellisâtes": "javelliser",
    "javellisèrent": "javelliser",
    "javellisé": "javelliser",
    "javellisée": "javelliser",
    "javellisées": "javelliser",
    "javellisés": "javelliser",
    "javelots": "javelot",
    "jazz-bands": "jazz-band",
    "jazzmans": "jazzman",
    "jazzmen": "jazzman",
    "jaïnistes": "jaïniste",
    "je": "il",
    "je-m'en-foutistes": "je-m'en-foutiste",
    "jeannettes": "jeannette",
    "jeans": "jean",
    "jeeps": "jeep",
    "jerricanes": "jerricane",
    "jerricans": "jerrican",
    "jerrycans": "jerrycan",
    "jerseys": "jersey",
    "jet-streams": "jet-stream",
    "jeta": "jeter",
    "jetables": "jetable",
    "jetai": "jeter",
    "jetaient": "jeter",
    "jetais": "jeter",
    "jetait": "jeter",
    "jetant": "jeter",
    "jetas": "jeter",
    "jetasse": "jeter",
    "jetassent": "jeter",
    "jetasses": "jeter",
    "jetassiez": "jeter",
    "jetassions": "jeter",
    "jeteurs": "jeteur",
    "jeteuse": "jeteur",
    "jeteuses": "jeteur",
    "jetez": "jeter",
    "jetiez": "jeter",
    "jetions": "jeter",
    "jetons": "jeton",
    "jets": "jet",
    "jette": "jeter",
    "jettent": "jeter",
    "jettera": "jeter",
    "jetterai": "jeter",
    "jetteraient": "jeter",
    "jetterais": "jeter",
    "jetterait": "jeter",
    "jetteras": "jeter",
    "jetterez": "jeter",
    "jetteriez": "jeter",
    "jetterions": "jeter",
    "jetterons": "jeter",
    "jetteront": "jeter",
    "jettes": "jeter",
    "jetâmes": "jeter",
    "jetât": "jeter",
    "jetâtes": "jeter",
    "jetèrent": "jeter",
    "jeté": "jeter",
    "jetée": "jeter",
    "jetées": "jeter",
    "jetés": "jeter",
    "jeudis": "jeudi",
    "jeunes": "jeune",
    "jeunesses": "jeunesse",
    "jeunets": "jeunet",
    "jeunette": "jeunet",
    "jeunettes": "jeunette",
    "jeunots": "jeunot",
    "jeunotte": "jeunot",
    "jeunottes": "jeunot",
    "jeux": "jeu",
    "jeûna": "jeûner",
    "jeûnai": "jeûner",
    "jeûnaient": "jeûner",
    "jeûnais": "jeûner",
    "jeûnait": "jeûner",
    "jeûnant": "jeûner",
    "jeûnas": "jeûner",
    "jeûnasse": "jeûner",
    "jeûnassent": "jeûner",
    "jeûnasses": "jeûner",
    "jeûnassiez": "jeûner",
    "jeûnassions": "jeûner",
    "jeûne": "jeûner",
    "jeûnent": "jeûner",
    "jeûnera": "jeûner",
    "jeûnerai": "jeûner",
    "jeûneraient": "jeûner",
    "jeûnerais": "jeûner",
    "jeûnerait": "jeûner",
    "jeûneras": "jeûner",
    "jeûnerez": "jeûner",
    "jeûneriez": "jeûner",
    "jeûnerions": "jeûner",
    "jeûnerons": "jeûner",
    "jeûneront": "jeûner",
    "jeûnes": "jeûner",
    "jeûneurs": "jeûneur",
    "jeûnez": "jeûner",
    "jeûniez": "jeûner",
    "jeûnions": "jeûner",
    "jeûnons": "jeûner",
    "jeûnâmes": "jeûner",
    "jeûnât": "jeûner",
    "jeûnâtes": "jeûner",
    "jeûnèrent": "jeûner",
    "jeûné": "jeûner",
    "jingles": "jingle",
    "joailleries": "joaillerie",
    "joailliers": "joaillier",
    "joaillière": "joaillier",
    "joaillières": "joaillier",
    "jobarde": "jobard",
    "jobardes": "jobard",
    "jobards": "jobard",
    "jobs": "job",
    "jocistes": "jociste",
    "jockeys": "jockey",
    "jocrisses": "jocrisse",
    "jodhpurs": "jodhpur",
    "joggers": "jogger",
    "joggeurs": "joggeur",
    "joggeuse": "joggeur",
    "joggings": "jogging",
    "joices": "joice",
    "joies": "joie",
    "joignaient": "joindre",
    "joignais": "joindre",
    "joignait": "joindre",
    "joignant": "joindre",
    "joigne": "joindre",
    "joignent": "joindre",
    "joignes": "joindre",
    "joignez": "joindre",
    "joigniez": "joindre",
    "joignions": "joindre",
    "joignirent": "joindre",
    "joignis": "joindre",
    "joignisse": "joindre",
    "joignissent": "joindre",
    "joignisses": "joindre",
    "joignissiez": "joindre",
    "joignissions": "joindre",
    "joignit": "joindre",
    "joignons": "joindre",
    "joignîmes": "joindre",
    "joignît": "joindre",
    "joignîtes": "joindre",
    "joindra": "joindre",
    "joindrai": "joindre",
    "joindraient": "joindre",
    "joindrais": "joindre",
    "joindrait": "joindre",
    "joindras": "joindre",
    "joindrez": "joindre",
    "joindriez": "joindre",
    "joindrions": "joindre",
    "joindrons": "joindre",
    "joindront": "joindre",
    "joins": "joindre",
    "joint": "joindre",
    "joint-ventures": "joint-venture",
    "jointe": "jointer",
    "jointes": "joint",
    "jointifs": "jointif",
    "jointives": "jointif",
    "jointoie": "jointoyer",
    "jointoiements": "jointoiement",
    "jointoient": "jointoyer",
    "jointoiera": "jointoyer",
    "jointoierai": "jointoyer",
    "jointoieraient": "jointoyer",
    "jointoierais": "jointoyer",
    "jointoierait": "jointoyer",
    "jointoieras": "jointoyer",
    "jointoierez": "jointoyer",
    "jointoieriez": "jointoyer",
    "jointoierions": "jointoyer",
    "jointoierons": "jointoyer",
    "jointoieront": "jointoyer",
    "jointoies": "jointoyer",
    "jointoya": "jointoyer",
    "jointoyai": "jointoyer",
    "jointoyaient": "jointoyer",
    "jointoyais": "jointoyer",
    "jointoyait": "jointoyer",
    "jointoyant": "jointoyer",
    "jointoyas": "jointoyer",
    "jointoyasse": "jointoyer",
    "jointoyassent": "jointoyer",
    "jointoyasses": "jointoyer",
    "jointoyassiez": "jointoyer",
    "jointoyassions": "jointoyer",
    "jointoyez": "jointoyer",
    "jointoyiez": "jointoyer",
    "jointoyions": "jointoyer",
    "jointoyons": "jointoyer",
    "jointoyâmes": "jointoyer",
    "jointoyât": "jointoyer",
    "jointoyâtes": "jointoyer",
    "jointoyèrent": "jointoyer",
    "jointoyé": "jointoyer",
    "jointoyée": "jointoyer",
    "jointoyées": "jointoyer",
    "jointoyés": "jointoyer",
    "joints": "joint",
    "jointures": "jointure",
    "jointée": "jointé",
    "jointés": "jointer",
    "jojos": "jojo",
    "jokers": "joker",
    "jolie": "joli",
    "jolies": "joli",
    "joliesses": "joliesse",
    "joliette": "joliet",
    "jolis": "joli",
    "jonchaient": "joncher",
    "jonchaies": "jonchaie",
    "jonchait": "joncher",
    "jonchant": "joncher",
    "jonchent": "joncher",
    "joncheraies": "joncheraie",
    "jonchets": "jonchet",
    "jonché": "joncher",
    "jonchée": "joncher",
    "jonchées": "joncher",
    "jonchés": "joncher",
    "joncs": "jonc",
    "jonctions": "jonction",
    "jongla": "jongler",
    "jonglai": "jongler",
    "jonglaient": "jongler",
    "jonglais": "jongler",
    "jonglait": "jongler",
    "jonglant": "jongler",
    "jonglas": "jongler",
    "jonglasse": "jongler",
    "jonglassent": "jongler",
    "jonglasses": "jongler",
    "jonglassiez": "jongler",
    "jonglassions": "jongler",
    "jongle": "jongler",
    "jonglent": "jongler",
    "jonglera": "jongler",
    "jonglerai": "jongler",
    "jongleraient": "jongler",
    "jonglerais": "jongler",
    "jonglerait": "jongler",
    "jongleras": "jongler",
    "jonglerez": "jongler",
    "jongleries": "jonglerie",
    "jongleriez": "jongler",
    "jonglerions": "jongler",
    "jonglerons": "jongler",
    "jongleront": "jongler",
    "jongles": "jongler",
    "jongleurs": "jongleur",
    "jongleuse": "jongleur",
    "jongleuses": "jongleur",
    "jonglez": "jongler",
    "jongliez": "jongler",
    "jonglions": "jongler",
    "jonglons": "jongler",
    "jonglâmes": "jongler",
    "jonglât": "jongler",
    "jonglâtes": "jongler",
    "jonglèrent": "jongler",
    "jonglé": "jongler",
    "jonques": "jonque",
    "jonquilles": "jonquille",
    "jordanienne": "jordanien",
    "jordaniens": "jordanien",
    "jospinistes": "jospiniste",
    "jotas": "jota",
    "joua": "jouer",
    "jouables": "jouable",
    "jouai": "jouer",
    "jouaient": "jouer",
    "jouais": "jouer",
    "jouait": "jouer",
    "jouant": "jouer",
    "jouas": "jouer",
    "jouasse": "jouer",
    "jouassent": "jouer",
    "jouasses": "jouer",
    "jouassiez": "jouer",
    "jouassions": "jouer",
    "joue": "jouer",
    "jouent": "jouer",
    "jouera": "jouer",
    "jouerai": "jouer",
    "joueraient": "jouer",
    "jouerais": "jouer",
    "jouerait": "jouer",
    "joueras": "jouer",
    "jouerez": "jouer",
    "joueriez": "jouer",
    "jouerions": "jouer",
    "jouerons": "jouer",
    "joueront": "jouer",
    "joues": "jouer",
    "jouets": "jouet",
    "joueurs": "joueur",
    "joueuse": "joueur",
    "joueuses": "joueur",
    "jouez": "jouer",
    "joufflue": "joufflu",
    "joufflues": "joufflu",
    "joufflus": "joufflu",
    "jougs": "joug",
    "joui": "jouir",
    "jouiez": "jouer",
    "jouions": "jouer",
    "jouira": "jouir",
    "jouirai": "jouir",
    "jouiraient": "jouir",
    "jouirais": "jouir",
    "jouirait": "jouir",
    "jouiras": "jouir",
    "jouirent": "jouir",
    "jouirez": "jouir",
    "jouiriez": "jouir",
    "jouirions": "jouir",
    "jouirons": "jouir",
    "jouiront": "jouir",
    "jouis": "jouir",
    "jouissaient": "jouir",
    "jouissais": "jouir",
    "jouissait": "jouir",
    "jouissances": "jouissance",
    "jouissant": "jouir",
    "jouissants": "jouissant",
    "jouisse": "jouir",
    "jouissent": "jouir",
    "jouisses": "jouir",
    "jouisseurs": "jouisseur",
    "jouisseuse": "jouisseur",
    "jouissez": "jouir",
    "jouissiez": "jouir",
    "jouissifs": "jouissif",
    "jouissions": "jouir",
    "jouissive": "jouissif",
    "jouissives": "jouissif",
    "jouissons": "jouir",
    "jouit": "jouir",
    "joujoux": "joujou",
    "joules": "joule",
    "jouons": "jouer",
    "journaleuse": "journaleux",
    "journaliers": "journalier",
    "journalismes": "journalisme",
    "journalistes": "journaliste",
    "journalistiques": "journalistique",
    "journalière": "journalier",
    "journalières": "journalière",
    "journaux": "journal",
    "journées": "journée",
    "jours": "jour",
    "jouta": "jouter",
    "joutai": "jouter",
    "joutaient": "jouter",
    "joutais": "jouter",
    "joutait": "jouter",
    "joutant": "jouter",
    "joutas": "jouter",
    "joutasse": "jouter",
    "joutassent": "jouter",
    "joutasses": "jouter",
    "joutassiez": "jouter",
    "joutassions": "jouter",
    "joute": "jouter",
    "joutent": "jouter",
    "joutera": "jouter",
    "jouterai": "jouter",
    "jouteraient": "jouter",
    "jouterais": "jouter",
    "jouterait": "jouter",
    "jouteras": "jouter",
    "jouterez": "jouter",
    "jouteriez": "jouter",
    "jouterions": "jouter",
    "jouterons": "jouter",
    "jouteront": "jouter",
    "joutes": "jouter",
    "jouteurs": "jouteur",
    "jouteuse": "jouteur",
    "joutez": "jouter",
    "joutiez": "jouter",
    "joutions": "jouter",
    "joutons": "jouter",
    "joutâmes": "jouter",
    "joutât": "jouter",
    "joutâtes": "jouter",
    "joutèrent": "jouter",
    "jouté": "jouter",
    "jouvenceaux": "jouvenceau",
    "jouvencelle": "jouvenceau",
    "jouvencelles": "jouvenceau",
    "jouvences": "jouvence",
    "jouxta": "jouxter",
    "jouxtai": "jouxter",
    "jouxtaient": "jouxter",
    "jouxtais": "jouxter",
    "jouxtait": "jouxter",
    "jouxtant": "jouxter",
    "jouxtas": "jouxter",
    "jouxtasse": "jouxter",
    "jouxtassent": "jouxter",
    "jouxtasses": "jouxter",
    "jouxtassiez": "jouxter",
    "jouxtassions": "jouxter",
    "jouxte": "jouxter",
    "jouxtent": "jouxter",
    "jouxtera": "jouxter",
    "jouxterai": "jouxter",
    "jouxteraient": "jouxter",
    "jouxterais": "jouxter",
    "jouxterait": "jouxter",
    "jouxteras": "jouxter",
    "jouxterez": "jouxter",
    "jouxteriez": "jouxter",
    "jouxterions": "jouxter",
    "jouxterons": "jouxter",
    "jouxteront": "jouxter",
    "jouxtes": "jouxter",
    "jouxtez": "jouxter",
    "jouxtiez": "jouxter",
    "jouxtions": "jouxter",
    "jouxtons": "jouxter",
    "jouxtâmes": "jouxter",
    "jouxtât": "jouxter",
    "jouxtâtes": "jouxter",
    "jouxtèrent": "jouxter",
    "jouxté": "jouxter",
    "jouxtée": "jouxter",
    "jouxtées": "jouxter",
    "jouxtés": "jouxter",
    "jouâmes": "jouer",
    "jouât": "jouer",
    "jouâtes": "jouer",
    "jouèrent": "jouer",
    "joué": "jouer",
    "jouée": "jouer",
    "jouées": "jouer",
    "joués": "jouer",
    "jouîmes": "jouir",
    "jouît": "jouir",
    "jouîtes": "jouir",
    "joviale": "jovial",
    "joviales": "jovial",
    "jovialités": "jovialité",
    "jovials": "jovial",
    "joviaux": "jovial",
    "joyaux": "joyau",
    "joyciennes": "joycien",
    "joyeuse": "joyeux",
    "joyeuses": "joyeux",
    "joyeusetés": "joyeuseté",
    "jubila": "jubiler",
    "jubilai": "jubiler",
    "jubilaient": "jubiler",
    "jubilais": "jubiler",
    "jubilait": "jubiler",
    "jubilant": "jubiler",
    "jubilante": "jubilant",
    "jubilantes": "jubilant",
    "jubilants": "jubilant",
    "jubilas": "jubiler",
    "jubilasse": "jubiler",
    "jubilassent": "jubiler",
    "jubilasses": "jubiler",
    "jubilassiez": "jubiler",
    "jubilassions": "jubiler",
    "jubilations": "jubilation",
    "jubilatoires": "jubilatoire",
    "jubile": "jubiler",
    "jubilent": "jubiler",
    "jubilera": "jubiler",
    "jubilerai": "jubiler",
    "jubileraient": "jubiler",
    "jubilerais": "jubiler",
    "jubilerait": "jubiler",
    "jubileras": "jubiler",
    "jubilerez": "jubiler",
    "jubileriez": "jubiler",
    "jubilerions": "jubiler",
    "jubilerons": "jubiler",
    "jubileront": "jubiler",
    "jubiles": "jubiler",
    "jubilez": "jubiler",
    "jubiliez": "jubiler",
    "jubilions": "jubiler",
    "jubilons": "jubiler",
    "jubilâmes": "jubiler",
    "jubilât": "jubiler",
    "jubilâtes": "jubiler",
    "jubilèrent": "jubiler",
    "jubilé": "jubiler",
    "jubilée": "jubiler",
    "jubilés": "jubilé",
    "jubés": "jubé",
    "jucha": "jucher",
    "juchai": "jucher",
    "juchaient": "jucher",
    "juchais": "jucher",
    "juchait": "jucher",
    "juchant": "jucher",
    "juchas": "jucher",
    "juchasse": "jucher",
    "juchassent": "jucher",
    "juchasses": "jucher",
    "juchassiez": "jucher",
    "juchassions": "jucher",
    "juche": "jucher",
    "juchent": "jucher",
    "juchera": "jucher",
    "jucherai": "jucher",
    "jucheraient": "jucher",
    "jucherais": "jucher",
    "jucherait": "jucher",
    "jucheras": "jucher",
    "jucherez": "jucher",
    "jucheriez": "jucher",
    "jucherions": "jucher",
    "jucherons": "jucher",
    "jucheront": "jucher",
    "juches": "jucher",
    "juchez": "jucher",
    "juchiez": "jucher",
    "juchions": "jucher",
    "juchons": "jucher",
    "juchâmes": "jucher",
    "juchât": "jucher",
    "juchâtes": "jucher",
    "juchèrent": "jucher",
    "juché": "jucher",
    "juchée": "jucher",
    "juchées": "jucher",
    "juchés": "jucher",
    "judaïques": "judaïque",
    "judaïsa": "judaïser",
    "judaïsai": "judaïser",
    "judaïsaient": "judaïser",
    "judaïsais": "judaïser",
    "judaïsait": "judaïser",
    "judaïsant": "judaïser",
    "judaïsas": "judaïser",
    "judaïsasse": "judaïser",
    "judaïsassent": "judaïser",
    "judaïsasses": "judaïser",
    "judaïsassiez": "judaïser",
    "judaïsassions": "judaïser",
    "judaïse": "judaïser",
    "judaïsent": "judaïser",
    "judaïsera": "judaïser",
    "judaïserai": "judaïser",
    "judaïseraient": "judaïser",
    "judaïserais": "judaïser",
    "judaïserait": "judaïser",
    "judaïseras": "judaïser",
    "judaïserez": "judaïser",
    "judaïseriez": "judaïser",
    "judaïserions": "judaïser",
    "judaïserons": "judaïser",
    "judaïseront": "judaïser",
    "judaïses": "judaïser",
    "judaïsez": "judaïser",
    "judaïsiez": "judaïser",
    "judaïsions": "judaïser",
    "judaïsmes": "judaïsme",
    "judaïsons": "judaïser",
    "judaïsâmes": "judaïser",
    "judaïsât": "judaïser",
    "judaïsâtes": "judaïser",
    "judaïsèrent": "judaïser",
    "judaïsé": "judaïser",
    "judaïsée": "judaïser",
    "judaïsées": "judaïser",
    "judaïsés": "judaïser",
    "judiciaires": "judiciaire",
    "judicieuse": "judicieux",
    "judicieuses": "judicieux",
    "judokas": "judoka",
    "judos": "judo",
    "judéo-chrétienne": "judéo-chrétien",
    "judéo-chrétiennes": "judéo-chrétien",
    "judéo-chrétiens": "judéo-chrétien",
    "juge": "juger",
    "jugea": "juger",
    "jugeai": "juger",
    "jugeaient": "juger",
    "jugeais": "juger",
    "jugeait": "juger",
    "jugeant": "juger",
    "jugeas": "juger",
    "jugeasse": "juger",
    "jugeassent": "juger",
    "jugeasses": "juger",
    "jugeassiez": "juger",
    "jugeassions": "juger",
    "jugements": "jugement",
    "jugent": "juger",
    "jugeons": "juger",
    "jugeotes": "jugeote",
    "jugera": "juger",
    "jugerai": "juger",
    "jugeraient": "juger",
    "jugerais": "juger",
    "jugerait": "juger",
    "jugeras": "juger",
    "jugerez": "juger",
    "jugeriez": "juger",
    "jugerions": "juger",
    "jugerons": "juger",
    "jugeront": "juger",
    "juges": "juger",
    "jugez": "juger",
    "jugeâmes": "juger",
    "jugeât": "juger",
    "jugeâtes": "juger",
    "jugiez": "juger",
    "jugions": "juger",
    "jugula": "juguler",
    "jugulai": "juguler",
    "jugulaient": "juguler",
    "jugulaires": "jugulaire",
    "jugulais": "juguler",
    "jugulait": "juguler",
    "jugulant": "juguler",
    "jugulas": "juguler",
    "jugulasse": "juguler",
    "jugulassent": "juguler",
    "jugulasses": "juguler",
    "jugulassiez": "juguler",
    "jugulassions": "juguler",
    "jugule": "juguler",
    "jugulent": "juguler",
    "jugulera": "juguler",
    "jugulerai": "juguler",
    "juguleraient": "juguler",
    "jugulerais": "juguler",
    "jugulerait": "juguler",
    "juguleras": "juguler",
    "jugulerez": "juguler",
    "juguleriez": "juguler",
    "jugulerions": "juguler",
    "jugulerons": "juguler",
    "juguleront": "juguler",
    "jugules": "juguler",
    "jugulez": "juguler",
    "juguliez": "juguler",
    "jugulions": "juguler",
    "jugulons": "juguler",
    "jugulâmes": "juguler",
    "jugulât": "juguler",
    "jugulâtes": "juguler",
    "jugulèrent": "juguler",
    "jugulé": "juguler",
    "jugulée": "juguler",
    "jugulées": "juguler",
    "jugulés": "juguler",
    "jugèrent": "juger",
    "jugé": "juger",
    "jugée": "juger",
    "jugées": "juger",
    "jugés": "juger",
    "juifs": "juif",
    "juillets": "juillet",
    "juins": "juin",
    "juive": "juif",
    "juiveries": "juiverie",
    "juives": "juif",
    "jujubes": "jujube",
    "jujubiers": "jujubier",
    "juke-boxes": "juke-box",
    "juleps": "julep",
    "juliennes": "julienne",
    "julots": "julot",
    "jumbo-jets": "jumbo-jet",
    "jumeaux": "jumeau",
    "jumela": "jumeler",
    "jumelages": "jumelage",
    "jumelai": "jumeler",
    "jumelaient": "jumeler",
    "jumelais": "jumeler",
    "jumelait": "jumeler",
    "jumelant": "jumeler",
    "jumelas": "jumeler",
    "jumelasse": "jumeler",
    "jumelassent": "jumeler",
    "jumelasses": "jumeler",
    "jumelassiez": "jumeler",
    "jumelassions": "jumeler",
    "jumelez": "jumeler",
    "jumeliez": "jumeler",
    "jumelions": "jumeler",
    "jumelle": "jumeler",
    "jumellent": "jumeler",
    "jumellera": "jumeler",
    "jumellerai": "jumeler",
    "jumelleraient": "jumeler",
    "jumellerais": "jumeler",
    "jumellerait": "jumeler",
    "jumelleras": "jumeler",
    "jumellerez": "jumeler",
    "jumelleriez": "jumeler",
    "jumellerions": "jumeler",
    "jumellerons": "jumeler",
    "jumelleront": "jumeler",
    "jumelles": "jumelle",
    "jumelons": "jumeler",
    "jumelâmes": "jumeler",
    "jumelât": "jumeler",
    "jumelâtes": "jumeler",
    "jumelèrent": "jumeler",
    "jumelé": "jumeler",
    "jumelée": "jumeler",
    "jumelées": "jumeler",
    "jumelés": "jumeler",
    "juments": "jument",
    "jumpings": "jumping",
    "jungiens": "jungien",
    "jungles": "jungle",
    "juniors": "junior",
    "junkers": "junker",
    "junkies": "junkie",
    "juntes": "junte",
    "jupes": "jupe",
    "jupes-culottes": "jupe-culotte",
    "jupettes": "jupette",
    "jupiers": "jupier",
    "jupitérienne": "jupitérien",
    "jupitériens": "jupitérien",
    "juponnée": "juponner",
    "juponnés": "juponner",
    "jupons": "jupon",
    "jupée": "jupé",
    "jupées": "jupé",
    "jura": "jurer",
    "jurai": "jurer",
    "juraient": "jurer",
    "jurais": "jurer",
    "jurait": "jurer",
    "jurandes": "jurande",
    "jurant": "jurer",
    "juras": "jurer",
    "jurasse": "jurer",
    "jurassent": "jurer",
    "jurasses": "jurer",
    "jurassiens": "jurassien",
    "jurassiez": "jurer",
    "jurassions": "jurer",
    "jurassiques": "jurassique",
    "jure": "jurer",
    "jurent": "jurer",
    "jurera": "jurer",
    "jurerai": "jurer",
    "jureraient": "jurer",
    "jurerais": "jurer",
    "jurerait": "jurer",
    "jureras": "jurer",
    "jurerez": "jurer",
    "jureriez": "jurer",
    "jurerions": "jurer",
    "jurerons": "jurer",
    "jureront": "jurer",
    "jures": "jurer",
    "jurez": "jurer",
    "juridictionnelle": "juridictionnel",
    "juridictionnelles": "juridictionnel",
    "juridictionnels": "juridictionnel",
    "juridictions": "juridiction",
    "juridiques": "juridique",
    "juriez": "jurer",
    "jurions": "jurer",
    "jurisconsultes": "jurisconsulte",
    "jurisprudences": "jurisprudence",
    "juristes": "juriste",
    "jurons": "juron",
    "jurys": "jury",
    "jurâmes": "jurer",
    "jurât": "jurer",
    "jurâtes": "jurer",
    "jurèrent": "jurer",
    "juré": "jurer",
    "jurée": "jurer",
    "jurées": "jurer",
    "jurés": "jurer",
    "jusants": "jusant",
    "jusqu'": "jusque",
    "jusqu'au-boutismes": "jusqu'au-boutisme",
    "jusqu'au-boutistes": "jusqu'au-boutiste",
    "jusquiames": "jusquiame",
    "justes": "juste",
    "justes-milieux": "juste-milieu",
    "justesses": "justesse",
    "justices": "justice",
    "justiciables": "justiciable",
    "justicialistes": "justicialiste",
    "justiciers": "justicier",
    "justicière": "justicier",
    "justicières": "justicier",
    "justifia": "justifier",
    "justifiables": "justifiable",
    "justifiai": "justifier",
    "justifiaient": "justifier",
    "justifiais": "justifier",
    "justifiait": "justifier",
    "justifiant": "justifier",
    "justifias": "justifier",
    "justifiasse": "justifier",
    "justifiassent": "justifier",
    "justifiasses": "justifier",
    "justifiassiez": "justifier",
    "justifiassions": "justifier",
    "justificatifs": "justificatif",
    "justifications": "justification",
    "justificative": "justificatif",
    "justificatives": "justificatif",
    "justifie": "justifier",
    "justifient": "justifier",
    "justifiera": "justifier",
    "justifierai": "justifier",
    "justifieraient": "justifier",
    "justifierais": "justifier",
    "justifierait": "justifier",
    "justifieras": "justifier",
    "justifierez": "justifier",
    "justifieriez": "justifier",
    "justifierions": "justifier",
    "justifierons": "justifier",
    "justifieront": "justifier",
    "justifies": "justifier",
    "justifiez": "justifier",
    "justifiiez": "justifier",
    "justifiions": "justifier",
    "justifions": "justifier",
    "justifiâmes": "justifier",
    "justifiât": "justifier",
    "justifiâtes": "justifier",
    "justifièrent": "justifier",
    "justifié": "justifier",
    "justifiée": "justifier",
    "justifiées": "justifier",
    "justifiés": "justifier",
    "juta": "juter",
    "jutai": "juter",
    "jutaient": "juter",
    "jutais": "juter",
    "jutait": "juter",
    "jutant": "juter",
    "jutas": "juter",
    "jutasse": "juter",
    "jutassent": "juter",
    "jutasses": "juter",
    "jutassiez": "juter",
    "jutassions": "juter",
    "jute": "juter",
    "jutent": "juter",
    "jutera": "juter",
    "juterai": "juter",
    "juteraient": "juter",
    "juterais": "juter",
    "juterait": "juter",
    "juteras": "juter",
    "juterez": "juter",
    "juteriez": "juter",
    "juterions": "juter",
    "juterons": "juter",
    "juteront": "juter",
    "jutes": "juter",
    "juteuse": "juteux",
    "juteuses": "juteux",
    "jutez": "juter",
    "jutiez": "juter",
    "jutions": "juter",
    "jutons": "juter",
    "jutâmes": "juter",
    "jutât": "juter",
    "jutâtes": "juter",
    "jutèrent": "juter",
    "juté": "juter",
    "jutée": "juter",
    "jutées": "juter",
    "jutés": "juter",
    "juvéniles": "juvénile",
    "juxtalinéaires": "juxtalinéaire",
    "juxtaposa": "juxtaposer",
    "juxtaposai": "juxtaposer",
    "juxtaposaient": "juxtaposer",
    "juxtaposais": "juxtaposer",
    "juxtaposait": "juxtaposer",
    "juxtaposant": "juxtaposer",
    "juxtaposas": "juxtaposer",
    "juxtaposasse": "juxtaposer",
    "juxtaposassent": "juxtaposer",
    "juxtaposasses": "juxtaposer",
    "juxtaposassiez": "juxtaposer",
    "juxtaposassions": "juxtaposer",
    "juxtapose": "juxtaposer",
    "juxtaposent": "juxtaposer",
    "juxtaposera": "juxtaposer",
    "juxtaposerai": "juxtaposer",
    "juxtaposeraient": "juxtaposer",
    "juxtaposerais": "juxtaposer",
    "juxtaposerait": "juxtaposer",
    "juxtaposeras": "juxtaposer",
    "juxtaposerez": "juxtaposer",
    "juxtaposeriez": "juxtaposer",
    "juxtaposerions": "juxtaposer",
    "juxtaposerons": "juxtaposer",
    "juxtaposeront": "juxtaposer",
    "juxtaposes": "juxtaposer",
    "juxtaposez": "juxtaposer",
    "juxtaposiez": "juxtaposer",
    "juxtaposions": "juxtaposer",
    "juxtapositions": "juxtaposition",
    "juxtaposons": "juxtaposer",
    "juxtaposâmes": "juxtaposer",
    "juxtaposât": "juxtaposer",
    "juxtaposâtes": "juxtaposer",
    "juxtaposèrent": "juxtaposer",
    "juxtaposé": "juxtaposer",
    "juxtaposée": "juxtaposer",
    "juxtaposées": "juxtaposer",
    "juxtaposés": "juxtaposer",
    "jèzes": "jèze",
    "jéjunale": "jéjunal",
    "jéjunums": "jéjunum",
    "jéroboams": "jéroboam",
    "jérémiades": "jérémiade",
    "jésuites": "jésuite",
    "jésuitiques": "jésuitique",
    "kabbales": "kabbale",
    "kabyles": "kabyle",
    "kaftans": "kaftan",
    "kakemonos": "kakemono",
    "kakis": "kaki",
    "kalachnikovs": "kalachnikov",
    "kalmouks": "kalmouk",
    "kaléidoscopes": "kaléidoscope",
    "kamikazes": "kamikaze",
    "kanake": "kanak",
    "kanakes": "kanak",
    "kanaks": "kanak",
    "kandjars": "kandjar",
    "kangourous": "kangourou",
    "kaolins": "kaolin",
    "kapoks": "kapok",
    "kapos": "kapo",
    "kappas": "kappa",
    "karakuls": "karakul",
    "karaokés": "karaoké",
    "karatékas": "karatéka",
    "karatés": "karaté",
    "karstiques": "karstique",
    "kartings": "karting",
    "kastros": "kastro",
    "katas": "kata",
    "katchinas": "katchina",
    "kayaks": "kayak",
    "kazakhs": "kazakh",
    "kebabs": "kebab",
    "keblas": "kebla",
    "keepsakes": "keepsake",
    "kelvins": "kelvin",
    "kermesses": "kermesse",
    "ketchs": "ketch",
    "keufs": "keuf",
    "keums": "keum",
    "keynésienne": "keynésien",
    "keynésiennes": "keynésien",
    "keynésiens": "keynésien",
    "khamsins": "khamsin",
    "khans": "khan",
    "khmers": "khmer",
    "khmère": "khmer",
    "khâgnes": "khâgne",
    "khédivale": "khédival",
    "khédivales": "khédival",
    "khédivaux": "khédival",
    "khédives": "khédive",
    "khédiviale": "khédivial",
    "khédiviales": "khédivial",
    "khédiviaux": "khédivial",
    "khôls": "khôl",
    "kibboutzim": "kibboutz",
    "kicks": "kick",
    "kidnappa": "kidnapper",
    "kidnappai": "kidnapper",
    "kidnappaient": "kidnapper",
    "kidnappais": "kidnapper",
    "kidnappait": "kidnapper",
    "kidnappant": "kidnapper",
    "kidnappas": "kidnapper",
    "kidnappasse": "kidnapper",
    "kidnappassent": "kidnapper",
    "kidnappasses": "kidnapper",
    "kidnappassiez": "kidnapper",
    "kidnappassions": "kidnapper",
    "kidnappe": "kidnapper",
    "kidnappent": "kidnapper",
    "kidnappera": "kidnapper",
    "kidnapperai": "kidnapper",
    "kidnapperaient": "kidnapper",
    "kidnapperais": "kidnapper",
    "kidnapperait": "kidnapper",
    "kidnapperas": "kidnapper",
    "kidnapperez": "kidnapper",
    "kidnapperiez": "kidnapper",
    "kidnapperions": "kidnapper",
    "kidnapperons": "kidnapper",
    "kidnapperont": "kidnapper",
    "kidnappes": "kidnapper",
    "kidnappeurs": "kidnappeur",
    "kidnappez": "kidnapper",
    "kidnappiez": "kidnapper",
    "kidnappings": "kidnapping",
    "kidnappions": "kidnapper",
    "kidnappons": "kidnapper",
    "kidnappâmes": "kidnapper",
    "kidnappât": "kidnapper",
    "kidnappâtes": "kidnapper",
    "kidnappèrent": "kidnapper",
    "kidnappé": "kidnapper",
    "kidnappée": "kidnapper",
    "kidnappées": "kidnapper",
    "kidnappés": "kidnapper",
    "kids": "kid",
    "kierkegaardienne": "kierkegaardien",
    "kifs": "kif",
    "kilogrammes": "kilogramme",
    "kilomètre": "kilométrer",
    "kilomètrent": "kilométrer",
    "kilomètres": "kilométrer",
    "kilomètres-heure": "kilomètre-heure",
    "kilométra": "kilométrer",
    "kilométrages": "kilométrage",
    "kilométrai": "kilométrer",
    "kilométraient": "kilométrer",
    "kilométrais": "kilométrer",
    "kilométrait": "kilométrer",
    "kilométrant": "kilométrer",
    "kilométras": "kilométrer",
    "kilométrasse": "kilométrer",
    "kilométrassent": "kilométrer",
    "kilométrasses": "kilométrer",
    "kilométrassiez": "kilométrer",
    "kilométrassions": "kilométrer",
    "kilométrera": "kilométrer",
    "kilométrerai": "kilométrer",
    "kilométreraient": "kilométrer",
    "kilométrerais": "kilométrer",
    "kilométrerait": "kilométrer",
    "kilométreras": "kilométrer",
    "kilométrerez": "kilométrer",
    "kilométreriez": "kilométrer",
    "kilométrerions": "kilométrer",
    "kilométrerons": "kilométrer",
    "kilométreront": "kilométrer",
    "kilométrez": "kilométrer",
    "kilométriez": "kilométrer",
    "kilométrions": "kilométrer",
    "kilométriques": "kilométrique",
    "kilométrons": "kilométrer",
    "kilométrâmes": "kilométrer",
    "kilométrât": "kilométrer",
    "kilométrâtes": "kilométrer",
    "kilométrèrent": "kilométrer",
    "kilométré": "kilométrer",
    "kilométrée": "kilométrer",
    "kilométrées": "kilométrer",
    "kilométrés": "kilométrer",
    "kilos": "kilo",
    "kilotonnes": "kilotonne",
    "kilowattheures": "kilowattheure",
    "kilowatts": "kilowatt",
    "kils": "kil",
    "kilts": "kilt",
    "kimonos": "kimono",
    "kinesthésies": "kinesthésie",
    "kinkajous": "kinkajou",
    "kinésiques": "kinésique",
    "kinésithérapeutes": "kinésithérapeute",
    "kinésithérapies": "kinésithérapie",
    "kiosks": "kiosk",
    "kiosques": "kiosque",
    "kippers": "kipper",
    "kips": "kip",
    "kirghizes": "kirghize",
    "kirs": "kir",
    "kirschs": "kirsch",
    "kits": "kit",
    "kiwis": "kiwi",
    "klaxonna": "klaxonner",
    "klaxonnai": "klaxonner",
    "klaxonnaient": "klaxonner",
    "klaxonnais": "klaxonner",
    "klaxonnait": "klaxonner",
    "klaxonnant": "klaxonner",
    "klaxonnas": "klaxonner",
    "klaxonnasse": "klaxonner",
    "klaxonnassent": "klaxonner",
    "klaxonnasses": "klaxonner",
    "klaxonnassiez": "klaxonner",
    "klaxonnassions": "klaxonner",
    "klaxonne": "klaxonner",
    "klaxonnent": "klaxonner",
    "klaxonnera": "klaxonner",
    "klaxonnerai": "klaxonner",
    "klaxonneraient": "klaxonner",
    "klaxonnerais": "klaxonner",
    "klaxonnerait": "klaxonner",
    "klaxonneras": "klaxonner",
    "klaxonnerez": "klaxonner",
    "klaxonneriez": "klaxonner",
    "klaxonnerions": "klaxonner",
    "klaxonnerons": "klaxonner",
    "klaxonneront": "klaxonner",
    "klaxonnes": "klaxonner",
    "klaxonnez": "klaxonner",
    "klaxonniez": "klaxonner",
    "klaxonnions": "klaxonner",
    "klaxonnons": "klaxonner",
    "klaxonnâmes": "klaxonner",
    "klaxonnât": "klaxonner",
    "klaxonnâtes": "klaxonner",
    "klaxonnèrent": "klaxonner",
    "klaxonné": "klaxonner",
    "klaxonnée": "klaxonner",
    "klaxonnées": "klaxonner",
    "klaxonnés": "klaxonner",
    "klaxons": "klaxon",
    "kleptomanes": "kleptomane",
    "kleptomanies": "kleptomanie",
    "knickerbockers": "knickerbocker",
    "knickers": "knicker",
    "knouts": "knout",
    "koalas": "koala",
    "kobolds": "kobold",
    "kohols": "kohol",
    "kolas": "kola",
    "kolatiers": "kolatier",
    "kolkhozes": "kolkhoze",
    "kolkhozienne": "kolkhozien",
    "kolkhoziennes": "kolkhozien",
    "kolkhoziens": "kolkhozien",
    "komsomols": "komsomol",
    "konzerns": "konzern",
    "kopecks": "kopeck",
    "kopeks": "kopek",
    "korrigane": "korrigan",
    "korriganes": "korrigan",
    "korrigans": "korrigan",
    "kouglofs": "kouglof",
    "koulaks": "koulak",
    "koweïtienne": "koweïtien",
    "koweïtiennes": "koweïtien",
    "koweïtiens": "koweïtien",
    "kraals": "kraal",
    "krachs": "krach",
    "krafts": "kraft",
    "kroumirs": "kroumir",
    "kryptons": "krypton",
    "ksars": "ksar",
    "ksour": "ksar",
    "kummels": "kummel",
    "kumquats": "kumquat",
    "kung fu": "kung-fu",
    "kurdes": "kurde",
    "kurus": "kuru",
    "kymriques": "kymrique",
    "kyrielles": "kyrielle",
    "kystes": "kyste",
    "kébours": "kébour",
    "kéfirs": "kéfir",
    "képis": "képi",
    "kératinisée": "kératinisé",
    "kérosènes": "kérosène",
    "l'": "le",
    "l'on": "on",
    "l'une": "l'un",
    "la": "le",
    "la_leur": "leur",
    "la_mienne": "mien",
    "la_nôtre": "nôtre",
    "la_sienne": "sien",
    "la_tienne": "tien",
    "la_vôtre": "vôtre",
    "labbes": "labbe",
    "labelles": "labelle",
    "labellisations": "labellisation",
    "labels": "label",
    "labeurs": "labeur",
    "labiale": "labial",
    "labiales": "labial",
    "labialisant": "labialiser",
    "labiaux": "labial",
    "labiles": "labile",
    "laborantine": "laborantin",
    "laborantins": "laborantin",
    "laboratoires": "laboratoire",
    "laborieuse": "laborieux",
    "laborieuses": "laborieux",
    "labos": "labo",
    "laboura": "labourer",
    "labourages": "labourage",
    "labourai": "labourer",
    "labouraient": "labourer",
    "labourais": "labourer",
    "labourait": "labourer",
    "labourant": "labourer",
    "labouras": "labourer",
    "labourasse": "labourer",
    "labourassent": "labourer",
    "labourasses": "labourer",
    "labourassiez": "labourer",
    "labourassions": "labourer",
    "laboure": "labourer",
    "labourent": "labourer",
    "labourera": "labourer",
    "labourerai": "labourer",
    "laboureraient": "labourer",
    "labourerais": "labourer",
    "labourerait": "labourer",
    "laboureras": "labourer",
    "labourerez": "labourer",
    "laboureriez": "labourer",
    "labourerions": "labourer",
    "labourerons": "labourer",
    "laboureront": "labourer",
    "laboures": "labourer",
    "laboureurs": "laboureur",
    "labourez": "labourer",
    "labouriez": "labourer",
    "labourions": "labourer",
    "labourons": "labourer",
    "labours": "labour",
    "labourâmes": "labourer",
    "labourât": "labourer",
    "labourâtes": "labourer",
    "labourèrent": "labourer",
    "labouré": "labourer",
    "labourée": "labourer",
    "labourées": "labourer",
    "labourés": "labourer",
    "labradors": "labrador",
    "labres": "labre",
    "labris": "labri",
    "labyrinthes": "labyrinthe",
    "labyrinthiques": "labyrinthique",
    "lacanienne": "lacanien",
    "lacaniennes": "lacanien",
    "lacaniens": "lacanien",
    "lace": "lacer",
    "lacent": "lacer",
    "lacera": "lacer",
    "lacerai": "lacer",
    "laceraient": "lacer",
    "lacerais": "lacer",
    "lacerait": "lacer",
    "laceras": "lacer",
    "lacerez": "lacer",
    "laceriez": "lacer",
    "lacerions": "lacer",
    "lacerons": "lacer",
    "laceront": "lacer",
    "laces": "lacer",
    "lacets": "lacet",
    "lacez": "lacer",
    "laciez": "lacer",
    "lacions": "lacer",
    "laconiques": "laconique",
    "laconismes": "laconisme",
    "lacryma christi": "lacryma-christi",
    "lacrymale": "lacrymal",
    "lacrymales": "lacrymal",
    "lacrymaux": "lacrymal",
    "lacrymogènes": "lacrymogène",
    "lacs": "lac",
    "lactaires": "lactaire",
    "lactescente": "lactescent",
    "lactoses": "lactose",
    "lactuloses": "lactulose",
    "lactée": "lacté",
    "lactées": "lacté",
    "lactés": "lacté",
    "lacunaires": "lacunaire",
    "lacunes": "lacune",
    "lacustres": "lacustre",
    "lacère": "lacérer",
    "lacèrent": "lacérer",
    "lacères": "lacérer",
    "lacé": "lacer",
    "lacédémoniens": "lacédémonien",
    "lacée": "lacer",
    "lacées": "lacer",
    "lacéra": "lacérer",
    "lacérai": "lacérer",
    "lacéraient": "lacérer",
    "lacérais": "lacérer",
    "lacérait": "lacérer",
    "lacérant": "lacérer",
    "lacéras": "lacérer",
    "lacérasse": "lacérer",
    "lacérassent": "lacérer",
    "lacérasses": "lacérer",
    "lacérassiez": "lacérer",
    "lacérassions": "lacérer",
    "lacérations": "lacération",
    "lacérera": "lacérer",
    "lacérerai": "lacérer",
    "lacéreraient": "lacérer",
    "lacérerais": "lacérer",
    "lacérerait": "lacérer",
    "lacéreras": "lacérer",
    "lacérerez": "lacérer",
    "lacéreriez": "lacérer",
    "lacérerions": "lacérer",
    "lacérerons": "lacérer",
    "lacéreront": "lacérer",
    "lacérez": "lacérer",
    "lacériez": "lacérer",
    "lacérions": "lacérer",
    "lacérons": "lacérer",
    "lacérâmes": "lacérer",
    "lacérât": "lacérer",
    "lacérâtes": "lacérer",
    "lacérèrent": "lacérer",
    "lacéré": "lacérer",
    "lacérée": "lacérer",
    "lacérées": "lacérer",
    "lacérés": "lacérer",
    "lacés": "lacer",
    "ladite": "ledit",
    "ladreries": "ladrerie",
    "ladres": "ladre",
    "lads": "lad",
    "ladys": "lady",
    "lagons": "lagon",
    "lagunaires": "lagunaire",
    "lagunes": "lagune",
    "laide": "laid",
    "laiderons": "laideron",
    "laides": "laid",
    "laideurs": "laideur",
    "laids": "laid",
    "laie": "lai",
    "laies": "laie",
    "laina": "lainer",
    "lainages": "lainage",
    "lainai": "lainer",
    "lainaient": "lainer",
    "lainais": "lainer",
    "lainait": "lainer",
    "lainant": "lainer",
    "lainas": "lainer",
    "lainasse": "lainer",
    "lainassent": "lainer",
    "lainasses": "lainer",
    "lainassiez": "lainer",
    "lainassions": "lainer",
    "laine": "lainer",
    "lainent": "lainer",
    "lainera": "lainer",
    "lainerai": "lainer",
    "laineraient": "lainer",
    "lainerais": "lainer",
    "lainerait": "lainer",
    "laineras": "lainer",
    "lainerez": "lainer",
    "laineriez": "lainer",
    "lainerions": "lainer",
    "lainerons": "lainer",
    "laineront": "lainer",
    "laines": "lainer",
    "laineurs": "laineur",
    "laineuse": "laineux",
    "laineuses": "laineux",
    "lainez": "lainer",
    "lainiez": "lainer",
    "lainions": "lainer",
    "lainière": "lainier",
    "lainons": "lainer",
    "lainâmes": "lainer",
    "lainât": "lainer",
    "lainâtes": "lainer",
    "lainèrent": "lainer",
    "lainé": "lainer",
    "lainée": "lainer",
    "lainées": "lainer",
    "lainés": "lainer",
    "lais": "lai",
    "laissa": "laisser",
    "laissai": "laisser",
    "laissaient": "laisser",
    "laissais": "laisser",
    "laissait": "laisser",
    "laissant": "laisser",
    "laissas": "laisser",
    "laissasse": "laisser",
    "laissassent": "laisser",
    "laissasses": "laisser",
    "laissassiez": "laisser",
    "laissassions": "laisser",
    "laisse": "laisser",
    "laissent": "laisser",
    "laissera": "laisser",
    "laisserai": "laisser",
    "laisseraient": "laisser",
    "laisserais": "laisser",
    "laisserait": "laisser",
    "laisseras": "laisser",
    "laisserez": "laisser",
    "laisseriez": "laisser",
    "laisserions": "laisser",
    "laisserons": "laisser",
    "laisseront": "laisser",
    "laisses": "laisser",
    "laissez": "laisser",
    "laissiez": "laisser",
    "laissions": "laisser",
    "laissons": "laisser",
    "laissâmes": "laisser",
    "laissât": "laisser",
    "laissâtes": "laisser",
    "laissèrent": "laisser",
    "laissé": "laisser",
    "laissée": "laisser",
    "laissées": "laisser",
    "laissés": "laisser",
    "laissés-pour-compte": "laissé-pour-compte",
    "laitages": "laitage",
    "laitances": "laitance",
    "laiteries": "laiterie",
    "laiterons": "laiteron",
    "laites": "laite",
    "laiteuse": "laiteux",
    "laiteuses": "laiteux",
    "laitiers": "laitier",
    "laitière": "laitier",
    "laitières": "laitier",
    "laitonna": "laitonner",
    "laitonnai": "laitonner",
    "laitonnaient": "laitonner",
    "laitonnais": "laitonner",
    "laitonnait": "laitonner",
    "laitonnant": "laitonner",
    "laitonnas": "laitonner",
    "laitonnasse": "laitonner",
    "laitonnassent": "laitonner",
    "laitonnasses": "laitonner",
    "laitonnassiez": "laitonner",
    "laitonnassions": "laitonner",
    "laitonne": "laitonner",
    "laitonnent": "laitonner",
    "laitonnera": "laitonner",
    "laitonnerai": "laitonner",
    "laitonneraient": "laitonner",
    "laitonnerais": "laitonner",
    "laitonnerait": "laitonner",
    "laitonneras": "laitonner",
    "laitonnerez": "laitonner",
    "laitonneriez": "laitonner",
    "laitonnerions": "laitonner",
    "laitonnerons": "laitonner",
    "laitonneront": "laitonner",
    "laitonnes": "laitonner",
    "laitonnez": "laitonner",
    "laitonniez": "laitonner",
    "laitonnions": "laitonner",
    "laitonnons": "laitonner",
    "laitonnâmes": "laitonner",
    "laitonnât": "laitonner",
    "laitonnâtes": "laitonner",
    "laitonnèrent": "laitonner",
    "laitonné": "laitonner",
    "laitonnée": "laitonner",
    "laitonnées": "laitonner",
    "laitonnés": "laitonner",
    "laitons": "laiton",
    "laits": "lait",
    "laitues": "laitue",
    "laizes": "laize",
    "lallations": "lallation",
    "lamais": "lamer",
    "lamaneurs": "lamaneur",
    "lamantins": "lamantin",
    "lamartiniennes": "lamartinien",
    "lamas": "lamer",
    "lamaïsmes": "lamaïsme",
    "lambdas": "lambda",
    "lambeaux": "lambeau",
    "lambina": "lambiner",
    "lambinai": "lambiner",
    "lambinaient": "lambiner",
    "lambinais": "lambiner",
    "lambinait": "lambiner",
    "lambinant": "lambiner",
    "lambinas": "lambiner",
    "lambinasse": "lambiner",
    "lambinassent": "lambiner",
    "lambinasses": "lambiner",
    "lambinassiez": "lambiner",
    "lambinassions": "lambiner",
    "lambine": "lambiner",
    "lambinent": "lambiner",
    "lambinera": "lambiner",
    "lambinerai": "lambiner",
    "lambineraient": "lambiner",
    "lambinerais": "lambiner",
    "lambinerait": "lambiner",
    "lambineras": "lambiner",
    "lambinerez": "lambiner",
    "lambineriez": "lambiner",
    "lambinerions": "lambiner",
    "lambinerons": "lambiner",
    "lambineront": "lambiner",
    "lambines": "lambiner",
    "lambinez": "lambiner",
    "lambiniez": "lambiner",
    "lambinions": "lambiner",
    "lambinons": "lambiner",
    "lambins": "lambin",
    "lambinâmes": "lambiner",
    "lambinât": "lambiner",
    "lambinâtes": "lambiner",
    "lambinèrent": "lambiner",
    "lambiné": "lambiner",
    "lambourdes": "lambourde",
    "lambrequins": "lambrequin",
    "lambrissa": "lambrisser",
    "lambrissai": "lambrisser",
    "lambrissaient": "lambrisser",
    "lambrissais": "lambrisser",
    "lambrissait": "lambrisser",
    "lambrissant": "lambrisser",
    "lambrissas": "lambrisser",
    "lambrissasse": "lambrisser",
    "lambrissassent": "lambrisser",
    "lambrissasses": "lambrisser",
    "lambrissassiez": "lambrisser",
    "lambrissassions": "lambrisser",
    "lambrisse": "lambrisser",
    "lambrissent": "lambrisser",
    "lambrissera": "lambrisser",
    "lambrisserai": "lambrisser",
    "lambrisseraient": "lambrisser",
    "lambrisserais": "lambrisser",
    "lambrisserait": "lambrisser",
    "lambrisseras": "lambrisser",
    "lambrisserez": "lambrisser",
    "lambrisseriez": "lambrisser",
    "lambrisserions": "lambrisser",
    "lambrisserons": "lambrisser",
    "lambrisseront": "lambrisser",
    "lambrisses": "lambrisser",
    "lambrissez": "lambrisser",
    "lambrissiez": "lambrisser",
    "lambrissions": "lambrisser",
    "lambrissons": "lambrisser",
    "lambrissâmes": "lambrisser",
    "lambrissât": "lambrisser",
    "lambrissâtes": "lambrisser",
    "lambrissèrent": "lambrisser",
    "lambrissé": "lambrisser",
    "lambrissée": "lambrisser",
    "lambrissées": "lambrisser",
    "lambrissés": "lambrisser",
    "lambruches": "lambruche",
    "lambrusques": "lambrusque",
    "lamedés": "lamedé",
    "lamelles": "lamelle",
    "lamellibranches": "lamellibranche",
    "lamenta": "lamenter",
    "lamentables": "lamentable",
    "lamentai": "lamenter",
    "lamentaient": "lamenter",
    "lamentais": "lamenter",
    "lamentait": "lamenter",
    "lamentant": "lamenter",
    "lamentas": "lamenter",
    "lamentasse": "lamenter",
    "lamentassent": "lamenter",
    "lamentasses": "lamenter",
    "lamentassiez": "lamenter",
    "lamentassions": "lamenter",
    "lamentations": "lamentation",
    "lamente": "lamenter",
    "lamentent": "lamenter",
    "lamentera": "lamenter",
    "lamenterai": "lamenter",
    "lamenteraient": "lamenter",
    "lamenterais": "lamenter",
    "lamenterait": "lamenter",
    "lamenteras": "lamenter",
    "lamenterez": "lamenter",
    "lamenteriez": "lamenter",
    "lamenterions": "lamenter",
    "lamenterons": "lamenter",
    "lamenteront": "lamenter",
    "lamentes": "lamenter",
    "lamentez": "lamenter",
    "lamentiez": "lamenter",
    "lamentions": "lamenter",
    "lamentons": "lamenter",
    "lamentos": "lamento",
    "lamentâmes": "lamenter",
    "lamentât": "lamenter",
    "lamentâtes": "lamenter",
    "lamentèrent": "lamenter",
    "lamenté": "lamenter",
    "lamentée": "lamenter",
    "lamentées": "lamenter",
    "lamentés": "lamenter",
    "lames": "lame",
    "lamifiés": "lamifié",
    "lamina": "laminer",
    "laminages": "laminage",
    "laminai": "laminer",
    "laminaient": "laminer",
    "laminaires": "laminaire",
    "laminais": "laminer",
    "laminait": "laminer",
    "laminant": "laminer",
    "laminas": "laminer",
    "laminasse": "laminer",
    "laminassent": "laminer",
    "laminasses": "laminer",
    "laminassiez": "laminer",
    "laminassions": "laminer",
    "lamine": "laminer",
    "laminent": "laminer",
    "laminera": "laminer",
    "laminerai": "laminer",
    "lamineraient": "laminer",
    "laminerais": "laminer",
    "laminerait": "laminer",
    "lamineras": "laminer",
    "laminerez": "laminer",
    "lamineriez": "laminer",
    "laminerions": "laminer",
    "laminerons": "laminer",
    "lamineront": "laminer",
    "lamines": "laminer",
    "laminez": "laminer",
    "laminiez": "laminer",
    "laminions": "laminer",
    "laminoirs": "laminoir",
    "laminons": "laminer",
    "laminâmes": "laminer",
    "laminât": "laminer",
    "laminâtes": "laminer",
    "laminèrent": "laminer",
    "laminé": "laminer",
    "laminée": "laminer",
    "laminées": "laminer",
    "laminés": "laminer",
    "lampa": "lamper",
    "lampadaires": "lampadaire",
    "lampais": "lamper",
    "lampait": "lamper",
    "lampant": "lamper",
    "lampante": "lampant",
    "lampantes": "lampant",
    "lampants": "lampant",
    "lamparos": "lamparo",
    "lampe": "lamper",
    "lampent": "lamper",
    "lampes": "lampe",
    "lampes-tempête": "lampe-tempête",
    "lampez": "lamper",
    "lampions": "lampion",
    "lampisteries": "lampisterie",
    "lampistes": "lampiste",
    "lampons": "lampon",
    "lamproies": "lamproie",
    "lampyres": "lampyre",
    "lampé": "lamper",
    "lampée": "lamper",
    "lampées": "lampée",
    "lamée": "lamé",
    "lamées": "lamer",
    "lamés": "lamer",
    "lance": "lancer",
    "lance-pierres": "lance-pierre",
    "lancements": "lancement",
    "lancent": "lancer",
    "lancequine": "lancequiner",
    "lancera": "lancer",
    "lancerai": "lancer",
    "lanceraient": "lancer",
    "lancerais": "lancer",
    "lancerait": "lancer",
    "lanceras": "lancer",
    "lancerez": "lancer",
    "lanceriez": "lancer",
    "lancerions": "lancer",
    "lancerons": "lanceron",
    "lanceront": "lancer",
    "lancers": "lancer",
    "lances": "lancer",
    "lancettes": "lancette",
    "lanceurs": "lanceur",
    "lanceuse": "lanceur",
    "lanceuses": "lanceur",
    "lancez": "lancer",
    "lanciers": "lancier",
    "lanciez": "lancer",
    "lancina": "lanciner",
    "lancinai": "lanciner",
    "lancinaient": "lanciner",
    "lancinais": "lanciner",
    "lancinait": "lanciner",
    "lancinant": "lanciner",
    "lancinante": "lancinant",
    "lancinantes": "lancinant",
    "lancinants": "lancinant",
    "lancinas": "lanciner",
    "lancinasse": "lanciner",
    "lancinassent": "lanciner",
    "lancinasses": "lanciner",
    "lancinassiez": "lanciner",
    "lancinassions": "lanciner",
    "lancine": "lanciner",
    "lancinent": "lanciner",
    "lancinera": "lanciner",
    "lancinerai": "lanciner",
    "lancineraient": "lanciner",
    "lancinerais": "lanciner",
    "lancinerait": "lanciner",
    "lancineras": "lanciner",
    "lancinerez": "lanciner",
    "lancineriez": "lanciner",
    "lancinerions": "lanciner",
    "lancinerons": "lanciner",
    "lancineront": "lanciner",
    "lancines": "lanciner",
    "lancinez": "lanciner",
    "lanciniez": "lanciner",
    "lancinions": "lanciner",
    "lancinons": "lanciner",
    "lancinâmes": "lanciner",
    "lancinât": "lanciner",
    "lancinâtes": "lanciner",
    "lancinèrent": "lanciner",
    "lanciné": "lanciner",
    "lancinée": "lanciner",
    "lancinées": "lanciner",
    "lancinés": "lanciner",
    "lancions": "lancer",
    "lancèrent": "lancer",
    "lancé": "lancer",
    "lancée": "lancer",
    "lancées": "lancer",
    "lancéolés": "lancéolé",
    "lancés": "lancer",
    "landaise": "landais",
    "landaises": "landais",
    "landaus": "landau",
    "landes": "lande",
    "landiers": "landier",
    "landings": "landing",
    "lands": "land",
    "langages": "langage",
    "langagiers": "langagier",
    "lange": "langer",
    "langeait": "langer",
    "langeant": "langer",
    "langes": "lange",
    "langoureuse": "langoureux",
    "langoureuses": "langoureux",
    "langoustes": "langouste",
    "langoustiers": "langoustier",
    "langoustines": "langoustine",
    "languedociens": "languedocien",
    "langues": "langue",
    "langues-de-boeuf": "langue-de-boeuf",
    "langues-de-chat": "langue-de-chat",
    "langues-de-serpent": "langue-de-serpent",
    "languettes": "languette",
    "langueurs": "langueur",
    "langueya": "langueyer",
    "langueyai": "langueyer",
    "langueyaient": "langueyer",
    "langueyais": "langueyer",
    "langueyait": "langueyer",
    "langueyant": "langueyer",
    "langueyas": "langueyer",
    "langueyasse": "langueyer",
    "langueyassent": "langueyer",
    "langueyasses": "langueyer",
    "langueyassiez": "langueyer",
    "langueyassions": "langueyer",
    "langueye": "langueyer",
    "langueyent": "langueyer",
    "langueyera": "langueyer",
    "langueyerai": "langueyer",
    "langueyeraient": "langueyer",
    "langueyerais": "langueyer",
    "langueyerait": "langueyer",
    "langueyeras": "langueyer",
    "langueyerez": "langueyer",
    "langueyeriez": "langueyer",
    "langueyerions": "langueyer",
    "langueyerons": "langueyer",
    "langueyeront": "langueyer",
    "langueyes": "langueyer",
    "langueyez": "langueyer",
    "langueyiez": "langueyer",
    "langueyions": "langueyer",
    "langueyons": "langueyer",
    "langueyâmes": "langueyer",
    "langueyât": "langueyer",
    "langueyâtes": "langueyer",
    "langueyèrent": "langueyer",
    "langueyé": "langueyer",
    "langueyée": "langueyer",
    "langueyées": "langueyer",
    "langueyés": "langueyer",
    "langui": "languir",
    "languides": "languide",
    "languie": "languir",
    "languies": "languir",
    "languira": "languir",
    "languirai": "languir",
    "languiraient": "languir",
    "languirais": "languir",
    "languirait": "languir",
    "languiras": "languir",
    "languirent": "languir",
    "languirez": "languir",
    "languiriez": "languir",
    "languirions": "languir",
    "languirons": "languir",
    "languiront": "languir",
    "languis": "languir",
    "languissaient": "languir",
    "languissais": "languir",
    "languissait": "languir",
    "languissant": "languir",
    "languissante": "languissant",
    "languissantes": "languissant",
    "languissants": "languissant",
    "languisse": "languir",
    "languissent": "languir",
    "languisses": "languir",
    "languissez": "languir",
    "languissiez": "languir",
    "languissions": "languir",
    "languissons": "languir",
    "languit": "languir",
    "languîmes": "languir",
    "languît": "languir",
    "languîtes": "languir",
    "langé": "langer",
    "langée": "langer",
    "lanifères": "lanifère",
    "lanigères": "lanigère",
    "lanières": "lanière",
    "lanolines": "lanoline",
    "lansquenets": "lansquenet",
    "lanterna": "lanterner",
    "lanternai": "lanterner",
    "lanternaient": "lanterner",
    "lanternais": "lanterner",
    "lanternait": "lanterner",
    "lanternant": "lanterner",
    "lanternas": "lanterner",
    "lanternasse": "lanterner",
    "lanternassent": "lanterner",
    "lanternasses": "lanterner",
    "lanternassiez": "lanterner",
    "lanternassions": "lanterner",
    "lanterne": "lanterner",
    "lanterneaux": "lanterneau",
    "lanternent": "lanterner",
    "lanternera": "lanterner",
    "lanternerai": "lanterner",
    "lanterneraient": "lanterner",
    "lanternerais": "lanterner",
    "lanternerait": "lanterner",
    "lanterneras": "lanterner",
    "lanternerez": "lanterner",
    "lanterneriez": "lanterner",
    "lanternerions": "lanterner",
    "lanternerons": "lanterner",
    "lanterneront": "lanterner",
    "lanternes": "lanterner",
    "lanternez": "lanterner",
    "lanterniez": "lanterner",
    "lanternions": "lanterner",
    "lanternons": "lanterner",
    "lanternâmes": "lanterner",
    "lanternât": "lanterner",
    "lanternâtes": "lanterner",
    "lanternèrent": "lanterner",
    "lanterné": "lanterner",
    "lanternée": "lanterner",
    "lanternées": "lanterner",
    "lanternés": "lanterner",
    "lança": "lancer",
    "lançai": "lancer",
    "lançaient": "lancer",
    "lançais": "lancer",
    "lançait": "lancer",
    "lançant": "lancer",
    "lanças": "lancer",
    "lançasse": "lancer",
    "lançassent": "lancer",
    "lançasses": "lancer",
    "lançassiez": "lancer",
    "lançassions": "lancer",
    "lançons": "lançon",
    "lançâmes": "lancer",
    "lançât": "lancer",
    "lançâtes": "lancer",
    "laos": "lao",
    "laotienne": "laotien",
    "laotiens": "laotien",
    "lapa": "laper",
    "lapai": "laper",
    "lapaient": "laper",
    "lapais": "laper",
    "lapait": "laper",
    "lapalissades": "lapalissade",
    "lapant": "laper",
    "lapas": "laper",
    "lapasse": "laper",
    "lapassent": "laper",
    "lapasses": "laper",
    "lapassiez": "laper",
    "lapassions": "laper",
    "lape": "laper",
    "lapements": "lapement",
    "lapent": "laper",
    "lapera": "laper",
    "laperai": "laper",
    "laperaient": "laper",
    "laperais": "laper",
    "laperait": "laper",
    "laperas": "laper",
    "lapereaux": "lapereau",
    "laperez": "laper",
    "laperiez": "laper",
    "laperions": "laper",
    "laperons": "laper",
    "laperont": "laper",
    "lapes": "laper",
    "lapez": "laper",
    "lapida": "lapider",
    "lapidai": "lapider",
    "lapidaient": "lapider",
    "lapidaires": "lapidaire",
    "lapidais": "lapider",
    "lapidait": "lapider",
    "lapidant": "lapider",
    "lapidas": "lapider",
    "lapidasse": "lapider",
    "lapidassent": "lapider",
    "lapidasses": "lapider",
    "lapidassiez": "lapider",
    "lapidassions": "lapider",
    "lapidations": "lapidation",
    "lapide": "lapider",
    "lapident": "lapider",
    "lapidera": "lapider",
    "lapiderai": "lapider",
    "lapideraient": "lapider",
    "lapiderais": "lapider",
    "lapiderait": "lapider",
    "lapideras": "lapider",
    "lapiderez": "lapider",
    "lapideriez": "lapider",
    "lapiderions": "lapider",
    "lapiderons": "lapider",
    "lapideront": "lapider",
    "lapides": "lapider",
    "lapidez": "lapider",
    "lapidiez": "lapider",
    "lapidifiés": "lapidifier",
    "lapidions": "lapider",
    "lapidons": "lapider",
    "lapidâmes": "lapider",
    "lapidât": "lapider",
    "lapidâtes": "lapider",
    "lapidèrent": "lapider",
    "lapidé": "lapider",
    "lapidée": "lapider",
    "lapidées": "lapider",
    "lapidés": "lapider",
    "lapiez": "laper",
    "lapine": "lapin",
    "lapines": "lapin",
    "lapins": "lapin",
    "lapions": "laper",
    "lapis-lazulis": "lapis-lazuli",
    "lapone": "lapon",
    "lapones": "lapon",
    "laponne": "lapon",
    "laponnes": "lapon",
    "lapons": "lapon",
    "lappant": "lapper",
    "lappé": "lapper",
    "lapâmes": "laper",
    "lapât": "laper",
    "lapâtes": "laper",
    "lapèrent": "laper",
    "lapé": "laper",
    "lapée": "laper",
    "lapées": "laper",
    "lapés": "laper",
    "laqua": "laquer",
    "laquai": "laquer",
    "laquaient": "laquer",
    "laquais": "laquer",
    "laquait": "laquer",
    "laquant": "laquer",
    "laquas": "laquer",
    "laquasse": "laquer",
    "laquassent": "laquer",
    "laquasses": "laquer",
    "laquassiez": "laquer",
    "laquassions": "laquer",
    "laque": "laquer",
    "laquelle": "lequel",
    "laquent": "laquer",
    "laquera": "laquer",
    "laquerai": "laquer",
    "laqueraient": "laquer",
    "laquerais": "laquer",
    "laquerait": "laquer",
    "laqueras": "laquer",
    "laquerez": "laquer",
    "laqueriez": "laquer",
    "laquerions": "laquer",
    "laquerons": "laquer",
    "laqueront": "laquer",
    "laques": "laquer",
    "laquez": "laquer",
    "laquiez": "laquer",
    "laquions": "laquer",
    "laquons": "laquer",
    "laquâmes": "laquer",
    "laquât": "laquer",
    "laquâtes": "laquer",
    "laquèrent": "laquer",
    "laqué": "laquer",
    "laquée": "laquer",
    "laquées": "laquer",
    "laqués": "laquer",
    "larbineries": "larbinerie",
    "larbins": "larbin",
    "larcins": "larcin",
    "larda": "larder",
    "lardai": "larder",
    "lardaient": "larder",
    "lardais": "larder",
    "lardait": "larder",
    "lardant": "larder",
    "lardas": "larder",
    "lardasse": "larder",
    "lardassent": "larder",
    "lardasses": "larder",
    "lardassiez": "larder",
    "lardassions": "larder",
    "larde": "larder",
    "lardent": "larder",
    "lardera": "larder",
    "larderai": "larder",
    "larderaient": "larder",
    "larderais": "larder",
    "larderait": "larder",
    "larderas": "larder",
    "larderez": "larder",
    "larderiez": "larder",
    "larderions": "larder",
    "larderons": "larder",
    "larderont": "larder",
    "lardes": "larder",
    "lardez": "larder",
    "lardiez": "larder",
    "lardions": "larder",
    "lardons": "lardon",
    "lards": "lard",
    "lardus": "lardu",
    "lardâmes": "larder",
    "lardât": "larder",
    "lardâtes": "larder",
    "lardèrent": "larder",
    "lardé": "larder",
    "lardée": "larder",
    "lardées": "larder",
    "lardés": "larder",
    "lares": "lare",
    "larfeuilles": "larfeuille",
    "larfeuils": "larfeuil",
    "largages": "largage",
    "larges": "large",
    "largesses": "largesse",
    "largeurs": "largeur",
    "larghettos": "larghetto",
    "largos": "largo",
    "largua": "larguer",
    "larguai": "larguer",
    "larguaient": "larguer",
    "larguais": "larguer",
    "larguait": "larguer",
    "larguant": "larguer",
    "larguas": "larguer",
    "larguasse": "larguer",
    "larguassent": "larguer",
    "larguasses": "larguer",
    "larguassiez": "larguer",
    "larguassions": "larguer",
    "largue": "larguer",
    "larguent": "larguer",
    "larguera": "larguer",
    "larguerai": "larguer",
    "largueraient": "larguer",
    "larguerais": "larguer",
    "larguerait": "larguer",
    "largueras": "larguer",
    "larguerez": "larguer",
    "largueriez": "larguer",
    "larguerions": "larguer",
    "larguerons": "larguer",
    "largueront": "larguer",
    "largues": "larguer",
    "larguez": "larguer",
    "larguiez": "larguer",
    "larguions": "larguer",
    "larguons": "larguer",
    "larguâmes": "larguer",
    "larguât": "larguer",
    "larguâtes": "larguer",
    "larguèrent": "larguer",
    "largué": "larguer",
    "larguée": "larguer",
    "larguées": "larguer",
    "largués": "larguer",
    "larigots": "larigot",
    "larmes": "larme",
    "larmes-de-Job": "larme-de-Job",
    "larmichettes": "larmichette",
    "larmiers": "larmier",
    "larmoie": "larmoyer",
    "larmoiements": "larmoiement",
    "larmoient": "larmoyer",
    "larmoiera": "larmoyer",
    "larmoierai": "larmoyer",
    "larmoieraient": "larmoyer",
    "larmoierais": "larmoyer",
    "larmoierait": "larmoyer",
    "larmoieras": "larmoyer",
    "larmoierez": "larmoyer",
    "larmoieriez": "larmoyer",
    "larmoierions": "larmoyer",
    "larmoierons": "larmoyer",
    "larmoieront": "larmoyer",
    "larmoies": "larmoyer",
    "larmoya": "larmoyer",
    "larmoyai": "larmoyer",
    "larmoyaient": "larmoyer",
    "larmoyais": "larmoyer",
    "larmoyait": "larmoyer",
    "larmoyant": "larmoyer",
    "larmoyante": "larmoyant",
    "larmoyantes": "larmoyant",
    "larmoyants": "larmoyant",
    "larmoyas": "larmoyer",
    "larmoyasse": "larmoyer",
    "larmoyassent": "larmoyer",
    "larmoyasses": "larmoyer",
    "larmoyassiez": "larmoyer",
    "larmoyassions": "larmoyer",
    "larmoyez": "larmoyer",
    "larmoyiez": "larmoyer",
    "larmoyions": "larmoyer",
    "larmoyons": "larmoyer",
    "larmoyâmes": "larmoyer",
    "larmoyât": "larmoyer",
    "larmoyâtes": "larmoyer",
    "larmoyèrent": "larmoyer",
    "larmoyé": "larmoyer",
    "larronne": "larronner",
    "larrons": "larron",
    "larvaires": "larvaire",
    "larves": "larve",
    "larvée": "larvé",
    "larvées": "larvé",
    "larvés": "larvé",
    "laryngoscopes": "laryngoscope",
    "laryngée": "laryngé",
    "laryngées": "laryngé",
    "laryngés": "laryngé",
    "lasagnes": "lasagne",
    "lascars": "lascar",
    "lascifs": "lascif",
    "lascive": "lascif",
    "lascives": "lascif",
    "lascivités": "lascivité",
    "lasers": "laser",
    "lassa": "lasser",
    "lassai": "lasser",
    "lassaient": "lasser",
    "lassais": "lasser",
    "lassait": "lasser",
    "lassant": "lasser",
    "lassante": "lassant",
    "lassantes": "lassant",
    "lassants": "lassant",
    "lassas": "lasser",
    "lassasse": "lasser",
    "lassassent": "lasser",
    "lassasses": "lasser",
    "lassassiez": "lasser",
    "lassassions": "lasser",
    "lasse": "lasser",
    "lassent": "lasser",
    "lassera": "lasser",
    "lasserai": "lasser",
    "lasseraient": "lasser",
    "lasserais": "lasser",
    "lasserait": "lasser",
    "lasseras": "lasser",
    "lasserez": "lasser",
    "lasseriez": "lasser",
    "lasserions": "lasser",
    "lasserons": "lasser",
    "lasseront": "lasser",
    "lasses": "lasser",
    "lassez": "lasser",
    "lassiez": "lasser",
    "lassions": "lasser",
    "lassitudes": "lassitude",
    "lassons": "lasser",
    "lassos": "lasso",
    "lassâmes": "lasser",
    "lassât": "lasser",
    "lassâtes": "lasser",
    "lassèrent": "lasser",
    "lassé": "lasser",
    "lassée": "lasser",
    "lassées": "lasser",
    "lassés": "lasser",
    "lataniers": "latanier",
    "latences": "latence",
    "latente": "latent",
    "latentes": "latent",
    "latents": "latent",
    "laticlaves": "laticlave",
    "latifundistes": "latifundiste",
    "latifundiums": "latifundium",
    "latine": "latin",
    "latines": "latin",
    "latinisa": "latiniser",
    "latinisai": "latiniser",
    "latinisaient": "latiniser",
    "latinisais": "latiniser",
    "latinisait": "latiniser",
    "latinisant": "latiniser",
    "latinisas": "latiniser",
    "latinisasse": "latiniser",
    "latinisassent": "latiniser",
    "latinisasses": "latiniser",
    "latinisassiez": "latiniser",
    "latinisassions": "latiniser",
    "latinise": "latiniser",
    "latinisent": "latiniser",
    "latinisera": "latiniser",
    "latiniserai": "latiniser",
    "latiniseraient": "latiniser",
    "latiniserais": "latiniser",
    "latiniserait": "latiniser",
    "latiniseras": "latiniser",
    "latiniserez": "latiniser",
    "latiniseriez": "latiniser",
    "latiniserions": "latiniser",
    "latiniserons": "latiniser",
    "latiniseront": "latiniser",
    "latinises": "latiniser",
    "latinisez": "latiniser",
    "latinisiez": "latiniser",
    "latinisions": "latiniser",
    "latinismes": "latinisme",
    "latinisons": "latiniser",
    "latinistes": "latiniste",
    "latinisâmes": "latiniser",
    "latinisât": "latiniser",
    "latinisâtes": "latiniser",
    "latinisèrent": "latiniser",
    "latinisé": "latiniser",
    "latinisée": "latiniser",
    "latinisées": "latiniser",
    "latinisés": "latiniser",
    "latinités": "latinité",
    "latino-américaine": "latino-américain",
    "latino-américains": "latino-américain",
    "latinos": "latino",
    "latins": "latin",
    "latitudes": "latitude",
    "latrines": "latrine",
    "latte": "latter",
    "lattes": "latter",
    "latté": "latter",
    "lattés": "latter",
    "latviens": "latvien",
    "latérale": "latéral",
    "latérales": "latéral",
    "latéralisée": "latéralisé",
    "latéraux": "latéral",
    "latérites": "latérite",
    "laudanums": "laudanum",
    "laudateurs": "laudateur",
    "laudatifs": "laudatif",
    "laudative": "laudatif",
    "laudatives": "laudatif",
    "laudatrice": "laudateur",
    "laudatrices": "laudateur",
    "laudes": "laude",
    "lauriers": "laurier",
    "lauriers-cerises": "laurier-cerise",
    "lauriers-roses": "laurier-rose",
    "lauréate": "lauréat",
    "lauréates": "lauréat",
    "lauréats": "lauréat",
    "laurée": "lauré",
    "laurées": "lauré",
    "laurés": "lauré",
    "lausannoises": "lausannois",
    "lauzes": "lauze",
    "lava": "laver",
    "lavables": "lavable",
    "lavabos": "lavabo",
    "lavages": "lavage",
    "lavai": "laver",
    "lavaient": "laver",
    "lavais": "laver",
    "lavait": "laver",
    "lavallières": "lavallière",
    "lavandes": "lavande",
    "lavandières": "lavandière",
    "lavant": "laver",
    "lavarets": "lavaret",
    "lavas": "laver",
    "lavasse": "laver",
    "lavassent": "laver",
    "lavasses": "laver",
    "lavassiez": "laver",
    "lavassions": "laver",
    "lavatorys": "lavatory",
    "lave": "laver",
    "lave-glaces": "lave-glace",
    "lave-ponts": "lave-pont",
    "lavements": "lavement",
    "lavent": "laver",
    "lavera": "laver",
    "laverai": "laver",
    "laveraient": "laver",
    "laverais": "laver",
    "laverait": "laver",
    "laveras": "laver",
    "laverez": "laver",
    "laveries": "laverie",
    "laveriez": "laver",
    "laverions": "laver",
    "laverons": "laver",
    "laveront": "laver",
    "laves": "laver",
    "lavettes": "lavette",
    "laveurs": "laveur",
    "laveuse": "laveur",
    "laveuses": "laveur",
    "lavez": "laver",
    "laviez": "laver",
    "lavions": "laver",
    "lavoirs": "lavoir",
    "lavons": "laver",
    "lavures": "lavure",
    "lavâmes": "laver",
    "lavât": "laver",
    "lavâtes": "laver",
    "lavèrent": "laver",
    "lavé": "laver",
    "lavée": "laver",
    "lavées": "laver",
    "lavés": "laver",
    "laxatifs": "laxatif",
    "laxative": "laxatif",
    "laxatives": "laxatif",
    "laxismes": "laxisme",
    "laxistes": "laxiste",
    "laxités": "laxité",
    "laya": "layer",
    "layettes": "layette",
    "layons": "layon",
    "lazarets": "lazaret",
    "lazzarones": "lazzarone",
    "lazzis": "lazzi",
    "laça": "lacer",
    "laçai": "lacer",
    "laçaient": "lacer",
    "laçais": "lacer",
    "laçait": "lacer",
    "laçant": "lacer",
    "laças": "lacer",
    "laçasse": "lacer",
    "laçassent": "lacer",
    "laçasses": "lacer",
    "laçassiez": "lacer",
    "laçassions": "lacer",
    "laçons": "lacer",
    "laçâmes": "lacer",
    "laçât": "lacer",
    "laçâtes": "lacer",
    "laîches": "laîche",
    "laïcités": "laïcité",
    "laïcs": "laïc",
    "laïque": "laïc",
    "laïques": "laïque",
    "laïussa": "laïusser",
    "laïussai": "laïusser",
    "laïussaient": "laïusser",
    "laïussais": "laïusser",
    "laïussait": "laïusser",
    "laïussant": "laïusser",
    "laïussas": "laïusser",
    "laïussasse": "laïusser",
    "laïussassent": "laïusser",
    "laïussasses": "laïusser",
    "laïussassiez": "laïusser",
    "laïussassions": "laïusser",
    "laïusse": "laïusser",
    "laïussent": "laïusser",
    "laïussera": "laïusser",
    "laïusserai": "laïusser",
    "laïusseraient": "laïusser",
    "laïusserais": "laïusser",
    "laïusserait": "laïusser",
    "laïusseras": "laïusser",
    "laïusserez": "laïusser",
    "laïusseriez": "laïusser",
    "laïusserions": "laïusser",
    "laïusserons": "laïusser",
    "laïusseront": "laïusser",
    "laïusses": "laïusser",
    "laïussez": "laïusser",
    "laïussiez": "laïusser",
    "laïussions": "laïusser",
    "laïussons": "laïusser",
    "laïussâmes": "laïusser",
    "laïussât": "laïusser",
    "laïussâtes": "laïusser",
    "laïussèrent": "laïusser",
    "laïussé": "laïusser",
    "leaders": "leader",
    "leaderships": "leadership",
    "leasings": "leasing",
    "lebels": "lebel",
    "lecteurs": "lecteur",
    "lectorats": "lectorat",
    "lectrice": "lecteur",
    "lectrices": "lecteur",
    "lectures": "lecture",
    "leghorns": "leghorn",
    "legos": "lego",
    "lei": "leu",
    "leishmanias": "leishmania",
    "leitmotive": "leitmotiv",
    "leitmotivs": "leitmotiv",
    "lemmes": "lemme",
    "lemmings": "lemming",
    "lendemains": "lendemain",
    "lente": "lent",
    "lentes": "lente",
    "lenteurs": "lenteur",
    "lenticulaires": "lenticulaire",
    "lenticules": "lenticule",
    "lentilles": "lentille",
    "lentisques": "lentisque",
    "lents": "lent",
    "leptons": "lepton",
    "les": "le",
    "les_autres": "l'un",
    "les_leurs": "leur",
    "les_miennes": "mien",
    "les_miens": "mien",
    "les_nôtres": "nôtre",
    "les_siennes": "sien",
    "les_siens": "sien",
    "les_tiennes": "tien",
    "les_tiens": "tien",
    "les_vôtres": "vôtre",
    "lesbienne": "lesbien",
    "lesbiennes": "lesbien",
    "lesbiens": "lesbien",
    "lesdites": "ledit",
    "lesdits": "ledit",
    "lesquelles": "lequel",
    "lesquels": "lequel",
    "lessiva": "lessiver",
    "lessivages": "lessivage",
    "lessivai": "lessiver",
    "lessivaient": "lessiver",
    "lessivais": "lessiver",
    "lessivait": "lessiver",
    "lessivant": "lessiver",
    "lessivas": "lessiver",
    "lessivasse": "lessiver",
    "lessivassent": "lessiver",
    "lessivasses": "lessiver",
    "lessivassiez": "lessiver",
    "lessivassions": "lessiver",
    "lessive": "lessiver",
    "lessivent": "lessiver",
    "lessivera": "lessiver",
    "lessiverai": "lessiver",
    "lessiveraient": "lessiver",
    "lessiverais": "lessiver",
    "lessiverait": "lessiver",
    "lessiveras": "lessiver",
    "lessiverez": "lessiver",
    "lessiveriez": "lessiver",
    "lessiverions": "lessiver",
    "lessiverons": "lessiver",
    "lessiveront": "lessiver",
    "lessives": "lessiver",
    "lessiveuse": "lessiveur",
    "lessiveuses": "lessiveur",
    "lessivez": "lessiver",
    "lessiviez": "lessiver",
    "lessivions": "lessiver",
    "lessivons": "lessiver",
    "lessivâmes": "lessiver",
    "lessivât": "lessiver",
    "lessivâtes": "lessiver",
    "lessivèrent": "lessiver",
    "lessivé": "lessiver",
    "lessivée": "lessiver",
    "lessivées": "lessiver",
    "lessivés": "lessiver",
    "lesta": "lester",
    "lestai": "lester",
    "lestaient": "lester",
    "lestais": "lester",
    "lestait": "lester",
    "lestant": "lester",
    "lestas": "lester",
    "lestasse": "lester",
    "lestassent": "lester",
    "lestasses": "lester",
    "lestassiez": "lester",
    "lestassions": "lester",
    "leste": "lester",
    "lestent": "lester",
    "lestera": "lester",
    "lesterai": "lester",
    "lesteraient": "lester",
    "lesterais": "lester",
    "lesterait": "lester",
    "lesteras": "lester",
    "lesterez": "lester",
    "lesteriez": "lester",
    "lesterions": "lester",
    "lesterons": "lester",
    "lesteront": "lester",
    "lestes": "lester",
    "lestez": "lester",
    "lestiez": "lester",
    "lestions": "lester",
    "lestons": "lester",
    "lests": "lest",
    "lestâmes": "lester",
    "lestât": "lester",
    "lestâtes": "lester",
    "lestèrent": "lester",
    "lesté": "lester",
    "lestée": "lester",
    "lestées": "lester",
    "lestés": "lester",
    "letchis": "letchi",
    "lettes": "lette",
    "lettone": "letton",
    "lettones": "letton",
    "lettonne": "letton",
    "lettonnes": "letton",
    "lettons": "letton",
    "lettres": "lettre",
    "lettrines": "lettrine",
    "lettriques": "lettrique",
    "lettristes": "lettriste",
    "lettrée": "lettré",
    "lettrées": "lettré",
    "lettrés": "lettré",
    "leucocytes": "leucocyte",
    "leucémies": "leucémie",
    "leur": "lui",
    "leurra": "leurrer",
    "leurrai": "leurrer",
    "leurraient": "leurrer",
    "leurrais": "leurrer",
    "leurrait": "leurrer",
    "leurrant": "leurrer",
    "leurras": "leurrer",
    "leurrasse": "leurrer",
    "leurrassent": "leurrer",
    "leurrasses": "leurrer",
    "leurrassiez": "leurrer",
    "leurrassions": "leurrer",
    "leurre": "leurrer",
    "leurrent": "leurrer",
    "leurrera": "leurrer",
    "leurrerai": "leurrer",
    "leurreraient": "leurrer",
    "leurrerais": "leurrer",
    "leurrerait": "leurrer",
    "leurreras": "leurrer",
    "leurrerez": "leurrer",
    "leurreriez": "leurrer",
    "leurrerions": "leurrer",
    "leurrerons": "leurrer",
    "leurreront": "leurrer",
    "leurres": "leurrer",
    "leurrez": "leurrer",
    "leurriez": "leurrer",
    "leurrions": "leurrer",
    "leurrons": "leurrer",
    "leurrâmes": "leurrer",
    "leurrât": "leurrer",
    "leurrâtes": "leurrer",
    "leurrèrent": "leurrer",
    "leurré": "leurrer",
    "leurrée": "leurrer",
    "leurrées": "leurrer",
    "leurrés": "leurrer",
    "leurs": "leur",
    "leva": "lever",
    "levai": "lever",
    "levaient": "lever",
    "levains": "levain",
    "levais": "lever",
    "levait": "lever",
    "levant": "lever",
    "levante": "levant",
    "levantes": "levant",
    "levantine": "levantin",
    "levantines": "levantin",
    "levantins": "levantin",
    "levants": "levant",
    "levas": "lever",
    "levasse": "lever",
    "levassent": "lever",
    "levasses": "lever",
    "levassiez": "lever",
    "levassions": "lever",
    "levers": "lever",
    "leveurs": "leveur",
    "leveuse": "leveur",
    "levez": "lever",
    "leviers": "levier",
    "leviez": "lever",
    "levions": "lever",
    "levoirs": "levoir",
    "levons": "lever",
    "levrauts": "levraut",
    "levreaux": "levreau",
    "levrette": "lévrier",
    "levrettes": "lévrier",
    "levs": "lev",
    "levures": "levure",
    "levâmes": "lever",
    "levât": "lever",
    "levâtes": "lever",
    "levèrent": "lever",
    "levé": "lever",
    "levée": "lever",
    "levées": "lever",
    "levés": "lever",
    "lexicale": "lexical",
    "lexicales": "lexical",
    "lexicaux": "lexical",
    "lexicographes": "lexicographe",
    "lexiques": "lexique",
    "leçons": "leçon",
    "lia": "lier",
    "liai": "lier",
    "liaient": "lier",
    "liais": "lier",
    "liaisons": "liaison",
    "liait": "lier",
    "lianes": "liane",
    "liant": "lier",
    "liante": "liant",
    "liants": "liant",
    "liardais": "liarder",
    "liards": "liard",
    "lias": "lier",
    "liasse": "lier",
    "liassent": "lier",
    "liasses": "lier",
    "liassiez": "lier",
    "liassions": "lier",
    "libanaise": "libanais",
    "libanaises": "libanais",
    "libanisations": "libanisation",
    "libations": "libation",
    "libella": "libeller",
    "libellai": "libeller",
    "libellaient": "libeller",
    "libellais": "libeller",
    "libellait": "libeller",
    "libellant": "libeller",
    "libellas": "libeller",
    "libellasse": "libeller",
    "libellassent": "libeller",
    "libellasses": "libeller",
    "libellassiez": "libeller",
    "libellassions": "libeller",
    "libelle": "libeller",
    "libellent": "libeller",
    "libellera": "libeller",
    "libellerai": "libeller",
    "libelleraient": "libeller",
    "libellerais": "libeller",
    "libellerait": "libeller",
    "libelleras": "libeller",
    "libellerez": "libeller",
    "libelleriez": "libeller",
    "libellerions": "libeller",
    "libellerons": "libeller",
    "libelleront": "libeller",
    "libelles": "libeller",
    "libellez": "libeller",
    "libelliez": "libeller",
    "libellions": "libeller",
    "libellons": "libeller",
    "libellules": "libellule",
    "libellâmes": "libeller",
    "libellât": "libeller",
    "libellâtes": "libeller",
    "libellèrent": "libeller",
    "libellé": "libeller",
    "libellée": "libeller",
    "libellées": "libeller",
    "libellés": "libeller",
    "libers": "liber",
    "libertaires": "libertaire",
    "libertinages": "libertinage",
    "libertine": "libertin",
    "libertines": "libertin",
    "libertins": "libertin",
    "libertés": "liberté",
    "libidinale": "libidinal",
    "libidinales": "libidinal",
    "libidinaux": "libidinal",
    "libidineuse": "libidineux",
    "libidineuses": "libidineux",
    "libidos": "libido",
    "libraires": "libraire",
    "librairies": "librairie",
    "librations": "libration",
    "libre-penseuse": "libre-penseur",
    "libre-échanges": "libre-échange",
    "libre-échangistes": "libre-échangiste",
    "libres": "libre",
    "libres-services": "libre-service",
    "libretti": "libretto",
    "librettistes": "librettiste",
    "librettos": "libretto",
    "libyenne": "libyen",
    "libyens": "libyen",
    "libère": "libérer",
    "libèrent": "libérer",
    "libères": "libérer",
    "libéra": "libérer",
    "libérables": "libérable",
    "libérai": "libérer",
    "libéraient": "libérer",
    "libérais": "libérer",
    "libérait": "libérer",
    "libérale": "libéral",
    "libérales": "libéral",
    "libéralisa": "libéraliser",
    "libéralisai": "libéraliser",
    "libéralisaient": "libéraliser",
    "libéralisais": "libéraliser",
    "libéralisait": "libéraliser",
    "libéralisant": "libéraliser",
    "libéralisas": "libéraliser",
    "libéralisasse": "libéraliser",
    "libéralisassent": "libéraliser",
    "libéralisasses": "libéraliser",
    "libéralisassiez": "libéraliser",
    "libéralisassions": "libéraliser",
    "libéralisations": "libéralisation",
    "libéralise": "libéraliser",
    "libéralisent": "libéraliser",
    "libéralisera": "libéraliser",
    "libéraliserai": "libéraliser",
    "libéraliseraient": "libéraliser",
    "libéraliserais": "libéraliser",
    "libéraliserait": "libéraliser",
    "libéraliseras": "libéraliser",
    "libéraliserez": "libéraliser",
    "libéraliseriez": "libéraliser",
    "libéraliserions": "libéraliser",
    "libéraliserons": "libéraliser",
    "libéraliseront": "libéraliser",
    "libéralises": "libéraliser",
    "libéralisez": "libéraliser",
    "libéralisiez": "libéraliser",
    "libéralisions": "libéraliser",
    "libéralismes": "libéralisme",
    "libéralisons": "libéraliser",
    "libéralisâmes": "libéraliser",
    "libéralisât": "libéraliser",
    "libéralisâtes": "libéraliser",
    "libéralisèrent": "libéraliser",
    "libéralisé": "libéraliser",
    "libéralisée": "libéraliser",
    "libéralisées": "libéraliser",
    "libéralisés": "libéraliser",
    "libéralités": "libéralité",
    "libérant": "libérer",
    "libéras": "libérer",
    "libérasse": "libérer",
    "libérassent": "libérer",
    "libérasses": "libérer",
    "libérassiez": "libérer",
    "libérassions": "libérer",
    "libérateurs": "libérateur",
    "libérations": "libération",
    "libératoires": "libératoire",
    "libératrice": "libérateur",
    "libératrices": "libérateur",
    "libéraux": "libéral",
    "libérera": "libérer",
    "libérerai": "libérer",
    "libéreraient": "libérer",
    "libérerais": "libérer",
    "libérerait": "libérer",
    "libéreras": "libérer",
    "libérerez": "libérer",
    "libéreriez": "libérer",
    "libérerions": "libérer",
    "libérerons": "libérer",
    "libéreront": "libérer",
    "libérez": "libérer",
    "libérienne": "libérien",
    "libériens": "libérien",
    "libériez": "libérer",
    "libérions": "libérer",
    "libérons": "libérer",
    "libérâmes": "libérer",
    "libérât": "libérer",
    "libérâtes": "libérer",
    "libérèrent": "libérer",
    "libéré": "libérer",
    "libérée": "libérer",
    "libérées": "libérer",
    "libérés": "libérer",
    "licences": "licence",
    "licencia": "licencier",
    "licenciables": "licenciable",
    "licenciai": "licencier",
    "licenciaient": "licencier",
    "licenciais": "licencier",
    "licenciait": "licencier",
    "licenciant": "licencier",
    "licencias": "licencier",
    "licenciasse": "licencier",
    "licenciassent": "licencier",
    "licenciasses": "licencier",
    "licenciassiez": "licencier",
    "licenciassions": "licencier",
    "licencie": "licencier",
    "licenciements": "licenciement",
    "licencient": "licencier",
    "licenciera": "licencier",
    "licencierai": "licencier",
    "licencieraient": "licencier",
    "licencierais": "licencier",
    "licencierait": "licencier",
    "licencieras": "licencier",
    "licencierez": "licencier",
    "licencieriez": "licencier",
    "licencierions": "licencier",
    "licencierons": "licencier",
    "licencieront": "licencier",
    "licencies": "licencier",
    "licencieuse": "licencieux",
    "licencieuses": "licencieux",
    "licenciez": "licencier",
    "licenciiez": "licencier",
    "licenciions": "licencier",
    "licencions": "licencier",
    "licenciâmes": "licencier",
    "licenciât": "licencier",
    "licenciâtes": "licencier",
    "licencièrent": "licencier",
    "licencié": "licencier",
    "licenciée": "licencier",
    "licenciées": "licencier",
    "licenciés": "licencier",
    "lices": "lice",
    "lichant": "licher",
    "lichas": "licher",
    "lichens": "lichen",
    "lichettes": "lichette",
    "liché": "licher",
    "lichée": "licher",
    "lichées": "licher",
    "liciers": "licier",
    "licita": "liciter",
    "licitai": "liciter",
    "licitaient": "liciter",
    "licitais": "liciter",
    "licitait": "liciter",
    "licitant": "liciter",
    "licitas": "liciter",
    "licitasse": "liciter",
    "licitassent": "liciter",
    "licitasses": "liciter",
    "licitassiez": "liciter",
    "licitassions": "liciter",
    "licite": "liciter",
    "licitent": "liciter",
    "licitera": "liciter",
    "liciterai": "liciter",
    "liciteraient": "liciter",
    "liciterais": "liciter",
    "liciterait": "liciter",
    "liciteras": "liciter",
    "liciterez": "liciter",
    "liciteriez": "liciter",
    "liciterions": "liciter",
    "liciterons": "liciter",
    "liciteront": "liciter",
    "licites": "liciter",
    "licitez": "liciter",
    "licitiez": "liciter",
    "licitions": "liciter",
    "licitons": "liciter",
    "licitâmes": "liciter",
    "licitât": "liciter",
    "licitâtes": "liciter",
    "licitèrent": "liciter",
    "licité": "liciter",
    "licitée": "liciter",
    "licitées": "liciter",
    "licités": "liciter",
    "licols": "licol",
    "licornes": "licorne",
    "licous": "licou",
    "licteurs": "licteur",
    "lie": "lier",
    "lieder": "lied",
    "liens": "lien",
    "lient": "lier",
    "liera": "lier",
    "lierai": "lier",
    "lieraient": "lier",
    "lierais": "lier",
    "lierait": "lier",
    "lieras": "lier",
    "lierez": "lier",
    "lieriez": "lier",
    "lierions": "lier",
    "lierons": "lier",
    "lieront": "lier",
    "lierres": "lierre",
    "lies": "lier",
    "liesses": "liesse",
    "lieudits": "lieudit",
    "lieues": "lieue",
    "lieus": "lieu",
    "lieuse": "lieur",
    "lieutenante": "lieutenant",
    "lieutenantes": "lieutenant",
    "lieutenants": "lieutenant",
    "lieutenants-colonels": "lieutenant-colonel",
    "lieux": "lieu",
    "lieux-dits": "lieu-dit",
    "liez": "lier",
    "lifta": "lifter",
    "liftai": "lifter",
    "liftaient": "lifter",
    "liftais": "lifter",
    "liftait": "lifter",
    "liftant": "lifter",
    "liftas": "lifter",
    "liftasse": "lifter",
    "liftassent": "lifter",
    "liftasses": "lifter",
    "liftassiez": "lifter",
    "liftassions": "lifter",
    "lifte": "lifter",
    "liftent": "lifter",
    "liftera": "lifter",
    "lifterai": "lifter",
    "lifteraient": "lifter",
    "lifterais": "lifter",
    "lifterait": "lifter",
    "lifteras": "lifter",
    "lifterez": "lifter",
    "lifteriez": "lifter",
    "lifterions": "lifter",
    "lifterons": "lifter",
    "lifteront": "lifter",
    "liftes": "lifter",
    "liftez": "lifter",
    "liftiers": "liftier",
    "liftiez": "lifter",
    "liftings": "lifting",
    "liftions": "lifter",
    "liftière": "liftier",
    "liftons": "lifter",
    "lifts": "lift",
    "liftâmes": "lifter",
    "liftât": "lifter",
    "liftâtes": "lifter",
    "liftèrent": "lifter",
    "lifté": "lifter",
    "liftée": "lifter",
    "liftées": "lifter",
    "liftés": "lifter",
    "ligaments": "ligament",
    "ligatures": "ligature",
    "ligaturez": "ligaturer",
    "ligaturé": "ligaturer",
    "ligaturée": "ligaturer",
    "liges": "lige",
    "ligna": "ligner",
    "lignages": "lignage",
    "lignards": "lignard",
    "lignes": "ligne",
    "ligneuse": "ligneux",
    "ligneuses": "ligneux",
    "lignifia": "lignifier",
    "lignifiai": "lignifier",
    "lignifiaient": "lignifier",
    "lignifiais": "lignifier",
    "lignifiait": "lignifier",
    "lignifiant": "lignifier",
    "lignifias": "lignifier",
    "lignifiasse": "lignifier",
    "lignifiassent": "lignifier",
    "lignifiasses": "lignifier",
    "lignifiassiez": "lignifier",
    "lignifiassions": "lignifier",
    "lignifie": "lignifier",
    "lignifient": "lignifier",
    "lignifiera": "lignifier",
    "lignifierai": "lignifier",
    "lignifieraient": "lignifier",
    "lignifierais": "lignifier",
    "lignifierait": "lignifier",
    "lignifieras": "lignifier",
    "lignifierez": "lignifier",
    "lignifieriez": "lignifier",
    "lignifierions": "lignifier",
    "lignifierons": "lignifier",
    "lignifieront": "lignifier",
    "lignifies": "lignifier",
    "lignifiez": "lignifier",
    "lignifiiez": "lignifier",
    "lignifiions": "lignifier",
    "lignifions": "lignifier",
    "lignifiâmes": "lignifier",
    "lignifiât": "lignifier",
    "lignifiâtes": "lignifier",
    "lignifièrent": "lignifier",
    "lignifié": "lignifier",
    "lignifiée": "lignifier",
    "lignifiées": "lignifier",
    "lignifiés": "lignifier",
    "lignites": "lignite",
    "ligné": "ligner",
    "lignée": "ligner",
    "lignées": "ligner",
    "ligota": "ligoter",
    "ligotai": "ligoter",
    "ligotaient": "ligoter",
    "ligotais": "ligoter",
    "ligotait": "ligoter",
    "ligotant": "ligoter",
    "ligotas": "ligoter",
    "ligotasse": "ligoter",
    "ligotassent": "ligoter",
    "ligotasses": "ligoter",
    "ligotassiez": "ligoter",
    "ligotassions": "ligoter",
    "ligote": "ligoter",
    "ligotent": "ligoter",
    "ligotera": "ligoter",
    "ligoterai": "ligoter",
    "ligoteraient": "ligoter",
    "ligoterais": "ligoter",
    "ligoterait": "ligoter",
    "ligoteras": "ligoter",
    "ligoterez": "ligoter",
    "ligoteriez": "ligoter",
    "ligoterions": "ligoter",
    "ligoterons": "ligoter",
    "ligoteront": "ligoter",
    "ligotes": "ligoter",
    "ligotez": "ligoter",
    "ligotiez": "ligoter",
    "ligotions": "ligoter",
    "ligotons": "ligoter",
    "ligots": "ligot",
    "ligotâmes": "ligoter",
    "ligotât": "ligoter",
    "ligotâtes": "ligoter",
    "ligotèrent": "ligoter",
    "ligoté": "ligoter",
    "ligotée": "ligoter",
    "ligotées": "ligoter",
    "ligotés": "ligoter",
    "ligua": "liguer",
    "liguai": "liguer",
    "liguaient": "liguer",
    "liguais": "liguer",
    "liguait": "liguer",
    "liguant": "liguer",
    "liguas": "liguer",
    "liguasse": "liguer",
    "liguassent": "liguer",
    "liguasses": "liguer",
    "liguassiez": "liguer",
    "liguassions": "liguer",
    "ligue": "liguer",
    "liguent": "liguer",
    "liguera": "liguer",
    "liguerai": "liguer",
    "ligueraient": "liguer",
    "liguerais": "liguer",
    "liguerait": "liguer",
    "ligueras": "liguer",
    "liguerez": "liguer",
    "ligueriez": "liguer",
    "liguerions": "liguer",
    "liguerons": "liguer",
    "ligueront": "liguer",
    "ligues": "liguer",
    "ligueurs": "ligueur",
    "liguez": "liguer",
    "liguiez": "liguer",
    "liguions": "liguer",
    "liguons": "liguer",
    "ligures": "ligure",
    "liguâmes": "liguer",
    "liguât": "liguer",
    "liguâtes": "liguer",
    "liguèrent": "liguer",
    "ligué": "liguer",
    "liguée": "liguer",
    "liguées": "liguer",
    "ligués": "liguer",
    "liiez": "lier",
    "liions": "lier",
    "liliacées": "liliacée",
    "liliale": "lilial",
    "liliales": "lilial",
    "liliaux": "lilial",
    "lilliputienne": "lilliputien",
    "lilliputiennes": "lilliputien",
    "lilliputiens": "lilliputien",
    "lilloise": "lillois",
    "lilloises": "lillois",
    "lima": "limer",
    "limaces": "limace",
    "limai": "limer",
    "limaient": "limer",
    "limailles": "limaille",
    "limais": "limer",
    "limait": "limer",
    "limandes": "limande",
    "limant": "limer",
    "limas": "limer",
    "limasse": "limer",
    "limassent": "limer",
    "limasses": "limer",
    "limassiez": "limer",
    "limassions": "limer",
    "limaçons": "limaçon",
    "limbes": "limbe",
    "lime": "limer",
    "liment": "limer",
    "limera": "limer",
    "limerai": "limer",
    "limeraient": "limer",
    "limerais": "limer",
    "limerait": "limer",
    "limeras": "limer",
    "limerez": "limer",
    "limericks": "limerick",
    "limeriez": "limer",
    "limerions": "limer",
    "limerons": "limer",
    "limeront": "limer",
    "limes": "limer",
    "limez": "limer",
    "limiers": "limier",
    "limiez": "limer",
    "liminaires": "liminaire",
    "liminale": "liminal",
    "liminales": "liminal",
    "liminaux": "liminal",
    "limions": "limer",
    "limita": "limiter",
    "limitai": "limiter",
    "limitaient": "limiter",
    "limitais": "limiter",
    "limitait": "limiter",
    "limitant": "limiter",
    "limitas": "limiter",
    "limitasse": "limiter",
    "limitassent": "limiter",
    "limitasses": "limiter",
    "limitassiez": "limiter",
    "limitassions": "limiter",
    "limitatifs": "limitatif",
    "limitations": "limitation",
    "limitative": "limitatif",
    "limitatives": "limitatif",
    "limite": "limiter",
    "limitent": "limiter",
    "limitera": "limiter",
    "limiterai": "limiter",
    "limiteraient": "limiter",
    "limiterais": "limiter",
    "limiterait": "limiter",
    "limiteras": "limiter",
    "limiterez": "limiter",
    "limiteriez": "limiter",
    "limiterions": "limiter",
    "limiterons": "limiter",
    "limiteront": "limiter",
    "limites": "limiter",
    "limitez": "limiter",
    "limitiez": "limiter",
    "limitions": "limiter",
    "limitons": "limiter",
    "limitrophes": "limitrophe",
    "limitâmes": "limiter",
    "limitât": "limiter",
    "limitâtes": "limiter",
    "limitèrent": "limiter",
    "limité": "limiter",
    "limitée": "limiter",
    "limitées": "limiter",
    "limités": "limiter",
    "limoge": "limoger",
    "limogea": "limoger",
    "limogeages": "limogeage",
    "limogeai": "limoger",
    "limogeaient": "limoger",
    "limogeais": "limoger",
    "limogeait": "limoger",
    "limogeant": "limoger",
    "limogeas": "limoger",
    "limogeasse": "limoger",
    "limogeassent": "limoger",
    "limogeasses": "limoger",
    "limogeassiez": "limoger",
    "limogeassions": "limoger",
    "limogent": "limoger",
    "limogeons": "limoger",
    "limogera": "limoger",
    "limogerai": "limoger",
    "limogeraient": "limoger",
    "limogerais": "limoger",
    "limogerait": "limoger",
    "limogeras": "limoger",
    "limogerez": "limoger",
    "limogeriez": "limoger",
    "limogerions": "limoger",
    "limogerons": "limoger",
    "limogeront": "limoger",
    "limoges": "limoger",
    "limogez": "limoger",
    "limogeâmes": "limoger",
    "limogeât": "limoger",
    "limogeâtes": "limoger",
    "limogiez": "limoger",
    "limogions": "limoger",
    "limogèrent": "limoger",
    "limogé": "limoger",
    "limogée": "limoger",
    "limogées": "limoger",
    "limogés": "limoger",
    "limonades": "limonade",
    "limonadiers": "limonadier",
    "limonadière": "limonadier",
    "limoneuse": "limoneux",
    "limoneuses": "limoneux",
    "limonière": "limonier",
    "limons": "limon",
    "limousine": "limousin",
    "limousines": "limousine",
    "limousins": "limousin",
    "limpides": "limpide",
    "limpidités": "limpidité",
    "limâmes": "limer",
    "limât": "limer",
    "limâtes": "limer",
    "limèrent": "limer",
    "limé": "limer",
    "limée": "limer",
    "limées": "limer",
    "limés": "limer",
    "linceuls": "linceul",
    "lingeries": "lingerie",
    "linges": "linge",
    "lingettes": "lingette",
    "lingotière": "lingotier",
    "lingots": "lingot",
    "linguale": "lingual",
    "linguales": "lingual",
    "linguaux": "lingual",
    "linguistes": "linguiste",
    "linguistiques": "linguistique",
    "lingère": "linger",
    "lingères": "lingère",
    "liniments": "liniment",
    "linoléums": "linoléum",
    "linons": "linon",
    "linos": "lino",
    "linottes": "linotte",
    "linotypes": "linotype",
    "linotypistes": "linotypiste",
    "lins": "lin",
    "linteaux": "linteau",
    "linéaires": "linéaire",
    "linéaments": "linéament",
    "lionceaux": "lionceau",
    "lionne": "lion",
    "lionnes": "lion",
    "lions": "lion",
    "lipides": "lipide",
    "lipomes": "lipome",
    "liposuccions": "liposuccion",
    "lippes": "lippe",
    "lippue": "lippu",
    "lippues": "lippu",
    "lippus": "lippu",
    "lippées": "lippée",
    "liquettes": "liquette",
    "liqueurs": "liqueur",
    "liquida": "liquider",
    "liquidai": "liquider",
    "liquidaient": "liquider",
    "liquidais": "liquider",
    "liquidait": "liquider",
    "liquidambars": "liquidambar",
    "liquidant": "liquider",
    "liquidas": "liquider",
    "liquidasse": "liquider",
    "liquidassent": "liquider",
    "liquidasses": "liquider",
    "liquidassiez": "liquider",
    "liquidassions": "liquider",
    "liquidateurs": "liquidateur",
    "liquidatifs": "liquidatif",
    "liquidations": "liquidation",
    "liquidative": "liquidatif",
    "liquidatives": "liquidatif",
    "liquide": "liquider",
    "liquident": "liquider",
    "liquidera": "liquider",
    "liquiderai": "liquider",
    "liquideraient": "liquider",
    "liquiderais": "liquider",
    "liquiderait": "liquider",
    "liquideras": "liquider",
    "liquiderez": "liquider",
    "liquideriez": "liquider",
    "liquiderions": "liquider",
    "liquiderons": "liquider",
    "liquideront": "liquider",
    "liquides": "liquider",
    "liquidez": "liquider",
    "liquidiez": "liquider",
    "liquidions": "liquider",
    "liquidités": "liquidité",
    "liquidons": "liquider",
    "liquidâmes": "liquider",
    "liquidât": "liquider",
    "liquidâtes": "liquider",
    "liquidèrent": "liquider",
    "liquidé": "liquider",
    "liquidée": "liquider",
    "liquidées": "liquider",
    "liquidés": "liquider",
    "liquoreuse": "liquoreux",
    "liquoreuses": "liquoreux",
    "liquéfactions": "liquéfaction",
    "liquéfia": "liquéfier",
    "liquéfiai": "liquéfier",
    "liquéfiaient": "liquéfier",
    "liquéfiais": "liquéfier",
    "liquéfiait": "liquéfier",
    "liquéfiant": "liquéfier",
    "liquéfiante": "liquéfiant",
    "liquéfias": "liquéfier",
    "liquéfiasse": "liquéfier",
    "liquéfiassent": "liquéfier",
    "liquéfiasses": "liquéfier",
    "liquéfiassiez": "liquéfier",
    "liquéfiassions": "liquéfier",
    "liquéfie": "liquéfier",
    "liquéfient": "liquéfier",
    "liquéfiera": "liquéfier",
    "liquéfierai": "liquéfier",
    "liquéfieraient": "liquéfier",
    "liquéfierais": "liquéfier",
    "liquéfierait": "liquéfier",
    "liquéfieras": "liquéfier",
    "liquéfierez": "liquéfier",
    "liquéfieriez": "liquéfier",
    "liquéfierions": "liquéfier",
    "liquéfierons": "liquéfier",
    "liquéfieront": "liquéfier",
    "liquéfies": "liquéfier",
    "liquéfiez": "liquéfier",
    "liquéfiiez": "liquéfier",
    "liquéfiions": "liquéfier",
    "liquéfions": "liquéfier",
    "liquéfiâmes": "liquéfier",
    "liquéfiât": "liquéfier",
    "liquéfiâtes": "liquéfier",
    "liquéfièrent": "liquéfier",
    "liquéfié": "liquéfier",
    "liquéfiée": "liquéfier",
    "liquéfiées": "liquéfier",
    "liquéfiés": "liquéfier",
    "lira": "lire",
    "lirai": "lire",
    "liraient": "lire",
    "lirais": "lire",
    "lirait": "lire",
    "liras": "lire",
    "lires": "lire",
    "lirez": "lire",
    "liriez": "lire",
    "lirions": "lire",
    "lirons": "liron",
    "liront": "lire",
    "lis": "lire",
    "lisaient": "lire",
    "lisais": "lire",
    "lisait": "lire",
    "lisant": "lire",
    "lise": "lire",
    "lisent": "lire",
    "lisera": "liserer",
    "liserai": "liserer",
    "liseraient": "liserer",
    "liserais": "liserer",
    "liserait": "liserer",
    "liserant": "liserer",
    "liseras": "liserer",
    "liserasse": "liserer",
    "liserassent": "liserer",
    "liserasses": "liserer",
    "liserassiez": "liserer",
    "liserassions": "liserer",
    "liserez": "liserer",
    "liseriez": "liserer",
    "liserions": "liserer",
    "liserons": "liseron",
    "liserâmes": "liserer",
    "liserât": "liserer",
    "liserâtes": "liserer",
    "liserèrent": "liserer",
    "liseré": "liserer",
    "liserée": "liserer",
    "liserées": "liserer",
    "liserés": "liserer",
    "lises": "lise",
    "liseuse": "liseur",
    "liseuses": "liseur",
    "lisez": "lire",
    "lisibilités": "lisibilité",
    "lisibles": "lisible",
    "lisiers": "lisier",
    "lisiez": "lire",
    "lisions": "lire",
    "lisières": "lisière",
    "lisons": "lire",
    "lissa": "lisser",
    "lissages": "lissage",
    "lissai": "lisser",
    "lissaient": "lisser",
    "lissais": "lisser",
    "lissait": "lisser",
    "lissant": "lisser",
    "lissas": "lisser",
    "lissasse": "lisser",
    "lissassent": "lisser",
    "lissasses": "lisser",
    "lissassiez": "lisser",
    "lissassions": "lisser",
    "lisse": "lisser",
    "lissent": "lisser",
    "lissera": "lisser",
    "lisserai": "lisser",
    "lisseraient": "lisser",
    "lisserais": "lisser",
    "lisserait": "lisser",
    "lisseras": "lisser",
    "lisserez": "lisser",
    "lisseriez": "lisser",
    "lisserions": "lisser",
    "lisserons": "lisser",
    "lisseront": "lisser",
    "lisses": "lisser",
    "lisseurs": "lisseur",
    "lissez": "lisser",
    "lissiez": "lisser",
    "lissions": "lisser",
    "lissons": "lisser",
    "lissâmes": "lisser",
    "lissât": "lisser",
    "lissâtes": "lisser",
    "lissèrent": "lisser",
    "lissé": "lisser",
    "lissée": "lisser",
    "lissées": "lisser",
    "lissés": "lisser",
    "listeaux": "listeau",
    "listes": "liste",
    "listez": "lister",
    "listings": "listing",
    "listé": "lister",
    "listée": "lister",
    "listées": "lister",
    "listés": "lister",
    "lisère": "lisérer",
    "lisèrent": "lisérer",
    "lisèrera": "liserer",
    "lisèrerai": "liserer",
    "lisèreraient": "liserer",
    "lisèrerais": "liserer",
    "lisèrerait": "liserer",
    "lisèreras": "liserer",
    "lisèrerez": "liserer",
    "lisèreriez": "liserer",
    "lisèrerions": "liserer",
    "lisèrerons": "liserer",
    "lisèreront": "liserer",
    "lisères": "lisérer",
    "liséra": "lisérer",
    "lisérai": "lisérer",
    "liséraient": "lisérer",
    "lisérais": "lisérer",
    "lisérait": "lisérer",
    "lisérant": "lisérer",
    "liséras": "lisérer",
    "lisérasse": "lisérer",
    "lisérassent": "lisérer",
    "lisérasses": "lisérer",
    "lisérassiez": "lisérer",
    "lisérassions": "lisérer",
    "lisérera": "lisérer",
    "lisérerai": "lisérer",
    "liséreraient": "lisérer",
    "lisérerais": "lisérer",
    "lisérerait": "lisérer",
    "liséreras": "lisérer",
    "lisérerez": "lisérer",
    "liséreriez": "lisérer",
    "lisérerions": "lisérer",
    "lisérerons": "lisérer",
    "liséreront": "lisérer",
    "lisérez": "lisérer",
    "lisériez": "lisérer",
    "lisérions": "lisérer",
    "lisérons": "lisérer",
    "lisérâmes": "lisérer",
    "lisérât": "lisérer",
    "lisérâtes": "lisérer",
    "lisérèrent": "lisérer",
    "liséré": "lisérer",
    "lisérée": "lisérer",
    "lisérées": "lisérer",
    "lisérés": "lisérer",
    "lit": "lire",
    "lit-divan": "lire",
    "lita": "liter",
    "litanies": "litanie",
    "litchis": "litchi",
    "lite": "liter",
    "liteaux": "liteau",
    "literies": "literie",
    "lithinés": "lithiné",
    "lithiums": "lithium",
    "lithographies": "lithographie",
    "lithographié": "lithographier",
    "lithophages": "lithophage",
    "lithos": "litho",
    "lithosphères": "lithosphère",
    "lithuanienne": "lithuanien",
    "lithuaniennes": "lithuanien",
    "litiges": "litige",
    "litigieuse": "litigieux",
    "litigieuses": "litigieux",
    "litières": "litière",
    "litotes": "litote",
    "litres": "litre",
    "litronaient": "litroner",
    "litrons": "litron",
    "litroné": "litroner",
    "lits": "lit",
    "lits-cages": "lit-cage",
    "littorale": "littoral",
    "littorales": "littoral",
    "littoraux": "littoral",
    "littéraires": "littéraire",
    "littérale": "littéral",
    "littérales": "littéral",
    "littérateurs": "littérateur",
    "littératures": "littérature",
    "littéraux": "littéral",
    "lituanienne": "lituanien",
    "lituaniennes": "lituanien",
    "lituaniens": "lituanien",
    "liturgies": "liturgie",
    "liturgiques": "liturgique",
    "lité": "liter",
    "livarots": "livarot",
    "livides": "livide",
    "living-rooms": "living-room",
    "livings": "living",
    "livoniennes": "livonienne",
    "livra": "livrer",
    "livrables": "livrable",
    "livrai": "livrer",
    "livraient": "livrer",
    "livrais": "livrer",
    "livraisons": "livraison",
    "livrait": "livrer",
    "livrant": "livrer",
    "livras": "livrer",
    "livrasse": "livrer",
    "livrassent": "livrer",
    "livrasses": "livrer",
    "livrassiez": "livrer",
    "livrassions": "livrer",
    "livre": "livrer",
    "livrent": "livrer",
    "livrera": "livrer",
    "livrerai": "livrer",
    "livreraient": "livrer",
    "livrerais": "livrer",
    "livrerait": "livrer",
    "livreras": "livrer",
    "livrerez": "livrer",
    "livreriez": "livrer",
    "livrerions": "livrer",
    "livrerons": "livrer",
    "livreront": "livrer",
    "livres": "livrer",
    "livresques": "livresque",
    "livrets": "livret",
    "livreurs": "livreur",
    "livreuse": "livreur",
    "livrez": "livrer",
    "livriez": "livrer",
    "livrions": "livrer",
    "livrons": "livrer",
    "livrâmes": "livrer",
    "livrât": "livrer",
    "livrâtes": "livrer",
    "livrèrent": "livrer",
    "livré": "livrer",
    "livrée": "livrer",
    "livrées": "livrer",
    "livrés": "livrer",
    "liâmes": "lier",
    "liât": "lier",
    "liâtes": "lier",
    "lièges": "liège",
    "lièrent": "lier",
    "lièvres": "lièvre",
    "lié": "lier",
    "liée": "lier",
    "liées": "lier",
    "liés": "lier",
    "llanos": "llano",
    "lobbys": "lobby",
    "lobes": "lobe",
    "lobotomisé": "lobotomiser",
    "lobotomisée": "lobotomiser",
    "lobs": "lob",
    "lobules": "lobule",
    "lobé": "lober",
    "lobée": "lobé",
    "locale": "local",
    "locales": "local",
    "localisa": "localiser",
    "localisai": "localiser",
    "localisaient": "localiser",
    "localisais": "localiser",
    "localisait": "localiser",
    "localisant": "localiser",
    "localisas": "localiser",
    "localisasse": "localiser",
    "localisassent": "localiser",
    "localisasses": "localiser",
    "localisassiez": "localiser",
    "localisassions": "localiser",
    "localisations": "localisation",
    "localise": "localiser",
    "localisent": "localiser",
    "localisera": "localiser",
    "localiserai": "localiser",
    "localiseraient": "localiser",
    "localiserais": "localiser",
    "localiserait": "localiser",
    "localiseras": "localiser",
    "localiserez": "localiser",
    "localiseriez": "localiser",
    "localiserions": "localiser",
    "localiserons": "localiser",
    "localiseront": "localiser",
    "localises": "localiser",
    "localisez": "localiser",
    "localisiez": "localiser",
    "localisions": "localiser",
    "localisons": "localiser",
    "localisâmes": "localiser",
    "localisât": "localiser",
    "localisâtes": "localiser",
    "localisèrent": "localiser",
    "localisé": "localiser",
    "localisée": "localiser",
    "localisées": "localiser",
    "localisés": "localiser",
    "localités": "localité",
    "locataires": "locataire",
    "locateurs": "locateur",
    "locatifs": "locatif",
    "locations": "location",
    "locative": "locatif",
    "locatives": "locatif",
    "locaux": "local",
    "loches": "loche",
    "lochs": "loch",
    "lock-outa": "lock-outer",
    "lock-outai": "lock-outer",
    "lock-outaient": "lock-outer",
    "lock-outais": "lock-outer",
    "lock-outait": "lock-outer",
    "lock-outant": "lock-outer",
    "lock-outas": "lock-outer",
    "lock-outasse": "lock-outer",
    "lock-outassent": "lock-outer",
    "lock-outasses": "lock-outer",
    "lock-outassiez": "lock-outer",
    "lock-outassions": "lock-outer",
    "lock-oute": "lock-outer",
    "lock-outent": "lock-outer",
    "lock-outera": "lock-outer",
    "lock-outerai": "lock-outer",
    "lock-outeraient": "lock-outer",
    "lock-outerais": "lock-outer",
    "lock-outerait": "lock-outer",
    "lock-outeras": "lock-outer",
    "lock-outerez": "lock-outer",
    "lock-outeriez": "lock-outer",
    "lock-outerions": "lock-outer",
    "lock-outerons": "lock-outer",
    "lock-outeront": "lock-outer",
    "lock-outes": "lock-outer",
    "lock-outez": "lock-outer",
    "lock-outiez": "lock-outer",
    "lock-outions": "lock-outer",
    "lock-outons": "lock-outer",
    "lock-outâmes": "lock-outer",
    "lock-outât": "lock-outer",
    "lock-outâtes": "lock-outer",
    "lock-outèrent": "lock-outer",
    "lock-outé": "lock-outer",
    "lock-outée": "lock-outer",
    "lock-outées": "lock-outer",
    "lock-outés": "lock-outer",
    "locomoteurs": "locomoteur",
    "locomotions": "locomotion",
    "locomotive": "locomotif",
    "locomotives": "locomotive",
    "locomotrice": "locomoteur",
    "locos": "loco",
    "locustes": "locuste",
    "locutions": "locution",
    "locutrice": "locuteur",
    "lodens": "loden",
    "lofe": "lofer",
    "lofez": "lofer",
    "lofing-matches": "lofing-match",
    "lofs": "lof",
    "lofts": "loft",
    "logarithmes": "logarithme",
    "logarithmiques": "logarithmique",
    "loge": "loger",
    "logea": "loger",
    "logeables": "logeable",
    "logeai": "loger",
    "logeaient": "loger",
    "logeais": "loger",
    "logeait": "loger",
    "logeant": "loger",
    "logeas": "loger",
    "logeasse": "loger",
    "logeassent": "loger",
    "logeasses": "loger",
    "logeassiez": "loger",
    "logeassions": "loger",
    "logements": "logement",
    "logent": "loger",
    "logeons": "loger",
    "logera": "loger",
    "logerai": "loger",
    "logeraient": "loger",
    "logerais": "loger",
    "logerait": "loger",
    "logeras": "loger",
    "logerez": "loger",
    "logeriez": "loger",
    "logerions": "loger",
    "logerons": "loger",
    "logeront": "loger",
    "loges": "loger",
    "logettes": "logette",
    "logeurs": "logeur",
    "logeuse": "logeur",
    "logeuses": "logeur",
    "logez": "loger",
    "logeâmes": "loger",
    "logeât": "loger",
    "logeâtes": "loger",
    "loggias": "loggia",
    "logiciels": "logiciel",
    "logicienne": "logicien",
    "logiciennes": "logicien",
    "logiciens": "logicien",
    "logiez": "loger",
    "logions": "loger",
    "logiques": "logique",
    "logistiques": "logistique",
    "logogriphes": "logogriphe",
    "logomachies": "logomachie",
    "logopédies": "logopédie",
    "logorrhées": "logorrhée",
    "logos": "logo",
    "logothètes": "logothète",
    "logotypes": "logotype",
    "logue": "loguer",
    "logèrent": "loger",
    "logé": "loger",
    "logée": "loger",
    "logées": "loger",
    "logés": "loger",
    "lointaine": "lointain",
    "lointaines": "lointain",
    "lointains": "lointain",
    "loirs": "loir",
    "lois": "loi",
    "lois-cadres": "loi-cadre",
    "lois-programmes": "loi-programme",
    "loisibles": "loisible",
    "loisirs": "loisir",
    "lokoums": "lokoum",
    "lolitas": "lolita",
    "lolos": "lolo",
    "lombagos": "lombago",
    "lombaires": "lombaire",
    "lombarde": "lombard",
    "lombardes": "lombard",
    "lombards": "lombard",
    "lombostats": "lombostat",
    "lombrics": "lombric",
    "londonienne": "londonien",
    "londoniennes": "londonien",
    "londoniens": "londonien",
    "long-courriers": "long-courrier",
    "long-jointée": "long-jointé",
    "long-jointées": "long-jointé",
    "long-jointés": "long-jointé",
    "longe": "longer",
    "longea": "longer",
    "longeai": "longer",
    "longeaient": "longer",
    "longeais": "longer",
    "longeait": "longer",
    "longeant": "longer",
    "longeas": "longer",
    "longeasse": "longer",
    "longeassent": "longer",
    "longeasses": "longer",
    "longeassiez": "longer",
    "longeassions": "longer",
    "longent": "longer",
    "longeons": "longer",
    "longera": "longer",
    "longerai": "longer",
    "longeraient": "longer",
    "longerais": "longer",
    "longerait": "longer",
    "longeras": "longer",
    "longerez": "longer",
    "longeriez": "longer",
    "longerions": "longer",
    "longerons": "longeron",
    "longeront": "longer",
    "longes": "longer",
    "longez": "longer",
    "longeâmes": "longer",
    "longeât": "longer",
    "longeâtes": "longer",
    "longicornes": "longicorne",
    "longiez": "longer",
    "longilignes": "longiligne",
    "longions": "longer",
    "longitudes": "longitude",
    "longitudinale": "longitudinal",
    "longitudinales": "longitudinal",
    "longitudinaux": "longitudinal",
    "longrines": "longrine",
    "longs": "long",
    "longue": "long",
    "longues": "longue",
    "longues-vues": "longue-vue",
    "longuette": "longuet",
    "longuettes": "longuet",
    "longueurs": "longueur",
    "longèrent": "longer",
    "longé": "longer",
    "longée": "longer",
    "longées": "longer",
    "longés": "longer",
    "longévités": "longévité",
    "looks": "look",
    "loopings": "looping",
    "loosers": "looser",
    "lopes": "lope",
    "lopettes": "lopette",
    "lopins": "lopin",
    "loquaces": "loquace",
    "loquacités": "loquacité",
    "loquait": "loquer",
    "loquedus": "loquedu",
    "loques": "loque",
    "loqueteaux": "loqueteau",
    "loqueteuse": "loqueteux",
    "loqueteuses": "loqueteux",
    "loquets": "loquet",
    "loquette": "loqueter",
    "loqué": "loquer",
    "loqués": "loquer",
    "lords": "lord",
    "lords-maires": "lord-maire",
    "lorettes": "lorette",
    "lorgna": "lorgner",
    "lorgnai": "lorgner",
    "lorgnaient": "lorgner",
    "lorgnais": "lorgner",
    "lorgnait": "lorgner",
    "lorgnant": "lorgner",
    "lorgnas": "lorgner",
    "lorgnasse": "lorgner",
    "lorgnassent": "lorgner",
    "lorgnasses": "lorgner",
    "lorgnassiez": "lorgner",
    "lorgnassions": "lorgner",
    "lorgne": "lorgner",
    "lorgnent": "lorgner",
    "lorgnera": "lorgner",
    "lorgnerai": "lorgner",
    "lorgneraient": "lorgner",
    "lorgnerais": "lorgner",
    "lorgnerait": "lorgner",
    "lorgneras": "lorgner",
    "lorgnerez": "lorgner",
    "lorgneriez": "lorgner",
    "lorgnerions": "lorgner",
    "lorgnerons": "lorgner",
    "lorgneront": "lorgner",
    "lorgnes": "lorgner",
    "lorgnettes": "lorgnette",
    "lorgnez": "lorgner",
    "lorgniez": "lorgner",
    "lorgnions": "lorgner",
    "lorgnons": "lorgnon",
    "lorgnâmes": "lorgner",
    "lorgnât": "lorgner",
    "lorgnâtes": "lorgner",
    "lorgnèrent": "lorgner",
    "lorgné": "lorgner",
    "lorgnée": "lorgner",
    "lorgnées": "lorgner",
    "lorgnés": "lorgner",
    "loriots": "loriot",
    "lorraine": "lorrain",
    "lorraines": "lorrain",
    "lorrains": "lorrain",
    "lorrys": "lorry",
    "lorsqu'": "lorsque",
    "losanges": "losange",
    "losangée": "losangé",
    "losangés": "losangé",
    "losers": "loser",
    "loteries": "loterie",
    "lotes": "lote",
    "loti": "lotir",
    "lotie": "lotir",
    "loties": "lotir",
    "lotionna": "lotionner",
    "lotionnai": "lotionner",
    "lotionnaient": "lotionner",
    "lotionnais": "lotionner",
    "lotionnait": "lotionner",
    "lotionnant": "lotionner",
    "lotionnas": "lotionner",
    "lotionnasse": "lotionner",
    "lotionnassent": "lotionner",
    "lotionnasses": "lotionner",
    "lotionnassiez": "lotionner",
    "lotionnassions": "lotionner",
    "lotionne": "lotionner",
    "lotionnent": "lotionner",
    "lotionnera": "lotionner",
    "lotionnerai": "lotionner",
    "lotionneraient": "lotionner",
    "lotionnerais": "lotionner",
    "lotionnerait": "lotionner",
    "lotionneras": "lotionner",
    "lotionnerez": "lotionner",
    "lotionneriez": "lotionner",
    "lotionnerions": "lotionner",
    "lotionnerons": "lotionner",
    "lotionneront": "lotionner",
    "lotionnes": "lotionner",
    "lotionnez": "lotionner",
    "lotionniez": "lotionner",
    "lotionnions": "lotionner",
    "lotionnons": "lotionner",
    "lotionnâmes": "lotionner",
    "lotionnât": "lotionner",
    "lotionnâtes": "lotionner",
    "lotionnèrent": "lotionner",
    "lotionné": "lotionner",
    "lotionnée": "lotionner",
    "lotionnées": "lotionner",
    "lotionnés": "lotionner",
    "lotions": "lotion",
    "lotira": "lotir",
    "lotirai": "lotir",
    "lotiraient": "lotir",
    "lotirais": "lotir",
    "lotirait": "lotir",
    "lotiras": "lotir",
    "lotirent": "lotir",
    "lotirez": "lotir",
    "lotiriez": "lotir",
    "lotirions": "lotir",
    "lotirons": "lotir",
    "lotiront": "lotir",
    "lotis": "lotir",
    "lotissaient": "lotir",
    "lotissais": "lotir",
    "lotissait": "lotir",
    "lotissant": "lotir",
    "lotisse": "lotir",
    "lotissements": "lotissement",
    "lotissent": "lotir",
    "lotisses": "lotir",
    "lotissez": "lotir",
    "lotissiez": "lotir",
    "lotissions": "lotir",
    "lotissons": "lotir",
    "lotit": "lotir",
    "lotos": "loto",
    "lots": "lot",
    "lottes": "lotte",
    "lotîmes": "lotir",
    "lotît": "lotir",
    "lotîtes": "lotir",
    "loua": "louer",
    "louables": "louable",
    "louages": "louage",
    "louai": "louer",
    "louaient": "louer",
    "louais": "louer",
    "louait": "louer",
    "louange": "louanger",
    "louangea": "louanger",
    "louangeaient": "louanger",
    "louangeant": "louanger",
    "louanges": "louange",
    "louangeuses": "louangeur",
    "louangé": "louanger",
    "louangée": "louanger",
    "louangés": "louanger",
    "louant": "louer",
    "louas": "louer",
    "louasse": "louer",
    "louassent": "louer",
    "louasses": "louer",
    "louassiez": "louer",
    "louassions": "louer",
    "loubarde": "loubard",
    "loubards": "loubard",
    "loucha": "loucher",
    "louchai": "loucher",
    "louchaient": "loucher",
    "louchais": "loucher",
    "louchait": "loucher",
    "louchant": "loucher",
    "louchas": "loucher",
    "louchasse": "loucher",
    "louchassent": "loucher",
    "louchasses": "loucher",
    "louchassiez": "loucher",
    "louchassions": "loucher",
    "louche": "loucher",
    "louchent": "loucher",
    "louchera": "loucher",
    "loucherai": "loucher",
    "loucheraient": "loucher",
    "loucherais": "loucher",
    "loucherait": "loucher",
    "loucheras": "loucher",
    "loucherez": "loucher",
    "loucheriez": "loucher",
    "loucherions": "loucher",
    "loucherons": "loucher",
    "loucheront": "loucher",
    "louches": "loucher",
    "loucheuse": "loucheur",
    "louchez": "loucher",
    "louchiez": "loucher",
    "louchions": "loucher",
    "louchons": "louchon",
    "louchâmes": "loucher",
    "louchât": "loucher",
    "louchâtes": "loucher",
    "louchèrent": "loucher",
    "louché": "loucher",
    "louchée": "loucher",
    "louchées": "loucher",
    "louchés": "loucher",
    "loue": "louer",
    "louent": "louer",
    "louera": "louer",
    "louerai": "louer",
    "loueraient": "louer",
    "louerais": "louer",
    "louerait": "louer",
    "loueras": "louer",
    "louerez": "louer",
    "loueriez": "louer",
    "louerions": "louer",
    "louerons": "louer",
    "loueront": "louer",
    "loues": "louer",
    "loueurs": "loueur",
    "loueuse": "loueur",
    "louez": "louer",
    "loufes": "loufer",
    "loufiats": "loufiat",
    "loufoqueries": "loufoquerie",
    "loufoques": "loufoque",
    "louiez": "louer",
    "louions": "louer",
    "louis-philipparde": "louis-philippard",
    "louis-philippards": "louis-philippard",
    "louises-bonnes": "louise-bonne",
    "loukoums": "loukoum",
    "loulous": "loulou",
    "louloutes": "louloute",
    "louons": "louer",
    "loupa": "louper",
    "loupai": "louper",
    "loupaient": "louper",
    "loupais": "louper",
    "loupait": "louper",
    "loupant": "louper",
    "loupas": "louper",
    "loupasse": "louper",
    "loupassent": "louper",
    "loupasses": "louper",
    "loupassiez": "louper",
    "loupassions": "louper",
    "loupe": "louper",
    "loupent": "louper",
    "loupera": "louper",
    "louperai": "louper",
    "louperaient": "louper",
    "louperais": "louper",
    "louperait": "louper",
    "louperas": "louper",
    "louperez": "louper",
    "louperiez": "louper",
    "louperions": "louper",
    "louperons": "louper",
    "louperont": "louper",
    "loupes": "louper",
    "loupez": "louper",
    "loupiez": "louper",
    "loupions": "louper",
    "loupiote": "loupiot",
    "loupiotes": "loupiote",
    "loupiots": "loupiot",
    "loupiottes": "loupiotte",
    "loupons": "louper",
    "loups": "loup",
    "loups-cerviers": "loup-cervier",
    "loups-garous": "loup-garou",
    "loupâmes": "louper",
    "loupât": "louper",
    "loupâtes": "louper",
    "loupèrent": "louper",
    "loupé": "louper",
    "loupée": "louper",
    "loupées": "louper",
    "loupés": "louper",
    "loura": "lourer",
    "lourai": "lourer",
    "louraient": "lourer",
    "lourais": "lourer",
    "lourait": "lourer",
    "lourant": "lourer",
    "louras": "lourer",
    "lourasse": "lourer",
    "lourassent": "lourer",
    "lourasses": "lourer",
    "lourassiez": "lourer",
    "lourassions": "lourer",
    "lourdaise": "lourdais",
    "lourdaises": "lourdais",
    "lourdait": "lourder",
    "lourdant": "lourder",
    "lourdaude": "lourdaud",
    "lourdaudes": "lourdaud",
    "lourdauds": "lourdaud",
    "lourde": "lourd",
    "lourdes": "lourde",
    "lourdeurs": "lourdeur",
    "lourdingues": "lourdingue",
    "lourds": "lourd",
    "lourdé": "lourder",
    "lourdée": "lourder",
    "lourdées": "lourder",
    "lourdés": "lourder",
    "loure": "lourer",
    "lourent": "lourer",
    "lourera": "lourer",
    "lourerai": "lourer",
    "loureraient": "lourer",
    "lourerais": "lourer",
    "lourerait": "lourer",
    "loureras": "lourer",
    "lourerez": "lourer",
    "loureriez": "lourer",
    "lourerions": "lourer",
    "lourerons": "lourer",
    "loureront": "lourer",
    "loures": "lourer",
    "lourez": "lourer",
    "louriez": "lourer",
    "lourions": "lourer",
    "lourons": "lourer",
    "lourâmes": "lourer",
    "lourât": "lourer",
    "lourâtes": "lourer",
    "lourèrent": "lourer",
    "louré": "lourer",
    "lourée": "lourer",
    "lourées": "lourer",
    "lourés": "lourer",
    "loustics": "loustic",
    "loutres": "loutre",
    "louve": "loup",
    "louves": "loup",
    "louveta": "louveter",
    "louvetai": "louveter",
    "louvetaient": "louveter",
    "louvetais": "louveter",
    "louvetait": "louveter",
    "louvetant": "louveter",
    "louvetas": "louveter",
    "louvetasse": "louveter",
    "louvetassent": "louveter",
    "louvetasses": "louveter",
    "louvetassiez": "louveter",
    "louvetassions": "louveter",
    "louveteaux": "louveteau",
    "louvetez": "louveter",
    "louvetiers": "louvetier",
    "louvetiez": "louveter",
    "louvetions": "louveter",
    "louvetons": "louveter",
    "louvette": "louveter",
    "louvettent": "louveter",
    "louvettera": "louveter",
    "louvetterai": "louveter",
    "louvetteraient": "louveter",
    "louvetterais": "louveter",
    "louvetterait": "louveter",
    "louvetteras": "louveter",
    "louvetterez": "louveter",
    "louvetteriez": "louveter",
    "louvetterions": "louveter",
    "louvetterons": "louveter",
    "louvetteront": "louveter",
    "louvettes": "louveter",
    "louvetâmes": "louveter",
    "louvetât": "louveter",
    "louvetâtes": "louveter",
    "louvetèrent": "louveter",
    "louveté": "louveter",
    "louvetée": "louveter",
    "louvetées": "louveter",
    "louvetés": "louveter",
    "louvoie": "louvoyer",
    "louvoiements": "louvoiement",
    "louvoient": "louvoyer",
    "louvoiera": "louvoyer",
    "louvoierai": "louvoyer",
    "louvoieraient": "louvoyer",
    "louvoierais": "louvoyer",
    "louvoierait": "louvoyer",
    "louvoieras": "louvoyer",
    "louvoierez": "louvoyer",
    "louvoieriez": "louvoyer",
    "louvoierions": "louvoyer",
    "louvoierons": "louvoyer",
    "louvoieront": "louvoyer",
    "louvoies": "louvoyer",
    "louvoya": "louvoyer",
    "louvoyai": "louvoyer",
    "louvoyaient": "louvoyer",
    "louvoyais": "louvoyer",
    "louvoyait": "louvoyer",
    "louvoyant": "louvoyer",
    "louvoyants": "louvoyant",
    "louvoyas": "louvoyer",
    "louvoyasse": "louvoyer",
    "louvoyassent": "louvoyer",
    "louvoyasses": "louvoyer",
    "louvoyassiez": "louvoyer",
    "louvoyassions": "louvoyer",
    "louvoyez": "louvoyer",
    "louvoyiez": "louvoyer",
    "louvoyions": "louvoyer",
    "louvoyons": "louvoyer",
    "louvoyâmes": "louvoyer",
    "louvoyât": "louvoyer",
    "louvoyâtes": "louvoyer",
    "louvoyèrent": "louvoyer",
    "louvoyé": "louvoyer",
    "louâmes": "louer",
    "louât": "louer",
    "louâtes": "louer",
    "louèrent": "louer",
    "loué": "louer",
    "louée": "louer",
    "louées": "louer",
    "loués": "louer",
    "lova": "lover",
    "lovai": "lover",
    "lovaient": "lover",
    "lovais": "lover",
    "lovait": "lover",
    "lovant": "lover",
    "lovas": "lover",
    "lovasse": "lover",
    "lovassent": "lover",
    "lovasses": "lover",
    "lovassiez": "lover",
    "lovassions": "lover",
    "love": "lover",
    "lovent": "lover",
    "lovera": "lover",
    "loverai": "lover",
    "loveraient": "lover",
    "loverais": "lover",
    "loverait": "lover",
    "loveras": "lover",
    "loverez": "lover",
    "loveriez": "lover",
    "loverions": "lover",
    "loverons": "lover",
    "loveront": "lover",
    "loves": "lover",
    "lovez": "lover",
    "loviez": "lover",
    "lovions": "lover",
    "lovons": "lover",
    "lovâmes": "lover",
    "lovât": "lover",
    "lovâtes": "lover",
    "lovèrent": "lover",
    "lové": "lover",
    "lovée": "lover",
    "lovées": "lover",
    "lovés": "lover",
    "loyale": "loyal",
    "loyales": "loyal",
    "loyalismes": "loyalisme",
    "loyalistes": "loyaliste",
    "loyautés": "loyauté",
    "loyaux": "loyal",
    "loyers": "loyer",
    "lozérienne": "lozérien",
    "lozériennes": "lozérien",
    "lozériens": "lozérien",
    "lu": "lire",
    "lubies": "lubie",
    "lubrifia": "lubrifier",
    "lubrifiai": "lubrifier",
    "lubrifiaient": "lubrifier",
    "lubrifiais": "lubrifier",
    "lubrifiait": "lubrifier",
    "lubrifiant": "lubrifier",
    "lubrifiante": "lubrifiant",
    "lubrifiantes": "lubrifiant",
    "lubrifiants": "lubrifiant",
    "lubrifias": "lubrifier",
    "lubrifiasse": "lubrifier",
    "lubrifiassent": "lubrifier",
    "lubrifiasses": "lubrifier",
    "lubrifiassiez": "lubrifier",
    "lubrifiassions": "lubrifier",
    "lubrifications": "lubrification",
    "lubrifie": "lubrifier",
    "lubrifient": "lubrifier",
    "lubrifiera": "lubrifier",
    "lubrifierai": "lubrifier",
    "lubrifieraient": "lubrifier",
    "lubrifierais": "lubrifier",
    "lubrifierait": "lubrifier",
    "lubrifieras": "lubrifier",
    "lubrifierez": "lubrifier",
    "lubrifieriez": "lubrifier",
    "lubrifierions": "lubrifier",
    "lubrifierons": "lubrifier",
    "lubrifieront": "lubrifier",
    "lubrifies": "lubrifier",
    "lubrifiez": "lubrifier",
    "lubrifiiez": "lubrifier",
    "lubrifiions": "lubrifier",
    "lubrifions": "lubrifier",
    "lubrifiâmes": "lubrifier",
    "lubrifiât": "lubrifier",
    "lubrifiâtes": "lubrifier",
    "lubrifièrent": "lubrifier",
    "lubrifié": "lubrifier",
    "lubrifiée": "lubrifier",
    "lubrifiées": "lubrifier",
    "lubrifiés": "lubrifier",
    "lubriques": "lubrique",
    "lucanes": "lucane",
    "lucarnes": "lucarne",
    "luce": "luc",
    "lucides": "lucide",
    "lucidités": "lucidité",
    "luciférienne": "luciférien",
    "lucifériens": "luciférien",
    "lucioles": "luciole",
    "lucratifs": "lucratif",
    "lucrative": "lucratif",
    "lucratives": "lucratif",
    "lucres": "lucre",
    "ludions": "ludion",
    "ludiques": "ludique",
    "ludopathies": "ludopathie",
    "lue": "lu",
    "lues": "lu",
    "luettes": "luette",
    "lueurs": "lueur",
    "lugers": "luger",
    "luges": "luge",
    "lugubres": "lugubre",
    "lui": "luire",
    "luira": "luire",
    "luirai": "luire",
    "luiraient": "luire",
    "luirais": "luire",
    "luirait": "luire",
    "luiras": "luire",
    "luirent": "luire",
    "luirez": "luire",
    "luiriez": "luire",
    "luirions": "luire",
    "luirons": "luire",
    "luiront": "luire",
    "luis": "luire",
    "luisaient": "luire",
    "luisais": "luire",
    "luisait": "luire",
    "luisances": "luisance",
    "luisant": "luire",
    "luisante": "luisant",
    "luisantes": "luisant",
    "luisants": "luisant",
    "luise": "luire",
    "luisent": "luire",
    "luises": "luire",
    "luisez": "luire",
    "luisiez": "luire",
    "luisions": "luire",
    "luisisse": "luire",
    "luisissent": "luire",
    "luisisses": "luire",
    "luisissiez": "luire",
    "luisissions": "luire",
    "luisons": "luire",
    "luisît": "luire",
    "luit": "luire",
    "lulus": "lulu",
    "lumbagos": "lumbago",
    "lumens": "lumen",
    "lumignons": "lumignon",
    "luminaires": "luminaire",
    "luminescente": "luminescent",
    "luminescentes": "luminescent",
    "luminescents": "luminescent",
    "lumineuse": "lumineux",
    "lumineuses": "lumineux",
    "luminosités": "luminosité",
    "lumières": "lumière",
    "lunaires": "lunaire",
    "lunaisons": "lunaison",
    "lunatiques": "lunatique",
    "lunches": "lunche",
    "lunchs": "lunch",
    "lundis": "lundi",
    "lunes": "lune",
    "lunetiers": "lunetier",
    "lunetteries": "lunetterie",
    "lunettes": "lunette",
    "luni-solaires": "luni-solaire",
    "lunules": "lunule",
    "lunée": "luné",
    "lunées": "luné",
    "lunés": "luné",
    "lupanars": "lupanar",
    "lupins": "lupin",
    "lurent": "lire",
    "lurettes": "lurette",
    "luronne": "luron",
    "luronnes": "luron",
    "lurons": "luron",
    "lus": "lu",
    "lusitanienne": "lusitanien",
    "lusitaniennes": "lusitanien",
    "lusitaniens": "lusitanien",
    "lusophones": "lusophone",
    "lusse": "lire",
    "lussent": "lire",
    "lusses": "lire",
    "lussiez": "lire",
    "lussions": "lire",
    "lustra": "lustrer",
    "lustraient": "lustrer",
    "lustrait": "lustrer",
    "lustrale": "lustral",
    "lustrales": "lustral",
    "lustrant": "lustrer",
    "lustraux": "lustral",
    "lustre": "lustrer",
    "lustres": "lustrer",
    "lustreuse": "lustreur",
    "lustrines": "lustrine",
    "lustré": "lustrer",
    "lustrée": "lustrer",
    "lustrées": "lustrer",
    "lustrés": "lustrer",
    "lut": "lire",
    "luthiers": "luthier",
    "luths": "luth",
    "luthérienne": "luthérien",
    "luthériennes": "luthérien",
    "luthériens": "luthérien",
    "lutinaient": "lutiner",
    "lutinait": "lutiner",
    "lutinant": "lutiner",
    "lutine": "lutiner",
    "lutinent": "lutiner",
    "lutinerais": "lutiner",
    "lutines": "lutin",
    "lutins": "lutin",
    "lutinèrent": "lutiner",
    "lutiné": "lutiner",
    "lutinée": "lutiner",
    "lutrins": "lutrin",
    "luts": "lut",
    "lutta": "lutter",
    "luttai": "lutter",
    "luttaient": "lutter",
    "luttais": "lutter",
    "luttait": "lutter",
    "luttant": "lutter",
    "luttas": "lutter",
    "luttasse": "lutter",
    "luttassent": "lutter",
    "luttasses": "lutter",
    "luttassiez": "lutter",
    "luttassions": "lutter",
    "lutte": "lutter",
    "luttent": "lutter",
    "luttera": "lutter",
    "lutterai": "lutter",
    "lutteraient": "lutter",
    "lutterais": "lutter",
    "lutterait": "lutter",
    "lutteras": "lutter",
    "lutterez": "lutter",
    "lutteriez": "lutter",
    "lutterions": "lutter",
    "lutterons": "lutter",
    "lutteront": "lutter",
    "luttes": "lutter",
    "lutteurs": "lutteur",
    "lutteuse": "lutteur",
    "lutteuses": "lutteur",
    "luttez": "lutter",
    "luttiez": "lutter",
    "luttions": "lutter",
    "luttons": "lutter",
    "luttâmes": "lutter",
    "luttât": "lutter",
    "luttâtes": "lutter",
    "luttèrent": "lutter",
    "lutté": "lutter",
    "luté": "luter",
    "luxa": "luxer",
    "luxations": "luxation",
    "luxe": "luxer",
    "luxembourgeoise": "luxembourgeois",
    "luxembourgeoises": "luxembourgeois",
    "luxes": "luxe",
    "luxueuse": "luxueux",
    "luxueuses": "luxueux",
    "luxures": "luxure",
    "luxuriante": "luxuriant",
    "luxuriantes": "luxuriant",
    "luxuriants": "luxuriant",
    "luxurieuse": "luxurieux",
    "luxé": "luxer",
    "luzernes": "luzerne",
    "luzernières": "luzernière",
    "luîmes": "luire",
    "luîtes": "luire",
    "lycanthropes": "lycanthrope",
    "lycaons": "lycaon",
    "lychees": "lychee",
    "lyciennes": "lycien",
    "lycoperdons": "lycoperdon",
    "lycopodes": "lycopode",
    "lycéenne": "lycéen",
    "lycéennes": "lycéen",
    "lycéens": "lycéen",
    "lycées": "lycée",
    "lymphatiques": "lymphatique",
    "lymphes": "lymphe",
    "lymphocytaires": "lymphocytaire",
    "lymphocytes": "lymphocyte",
    "lymphomes": "lymphome",
    "lyncha": "lyncher",
    "lynchages": "lynchage",
    "lynchai": "lyncher",
    "lynchaient": "lyncher",
    "lynchais": "lyncher",
    "lynchait": "lyncher",
    "lynchant": "lyncher",
    "lynchas": "lyncher",
    "lynchasse": "lyncher",
    "lynchassent": "lyncher",
    "lynchasses": "lyncher",
    "lynchassiez": "lyncher",
    "lynchassions": "lyncher",
    "lynche": "lyncher",
    "lynchent": "lyncher",
    "lynchera": "lyncher",
    "lyncherai": "lyncher",
    "lyncheraient": "lyncher",
    "lyncherais": "lyncher",
    "lyncherait": "lyncher",
    "lyncheras": "lyncher",
    "lyncherez": "lyncher",
    "lyncheriez": "lyncher",
    "lyncherions": "lyncher",
    "lyncherons": "lyncher",
    "lyncheront": "lyncher",
    "lynches": "lyncher",
    "lyncheurs": "lyncheur",
    "lynchez": "lyncher",
    "lynchiez": "lyncher",
    "lynchions": "lyncher",
    "lynchons": "lyncher",
    "lynchâmes": "lyncher",
    "lynchât": "lyncher",
    "lynchâtes": "lyncher",
    "lynchèrent": "lyncher",
    "lynché": "lyncher",
    "lynchée": "lyncher",
    "lynchées": "lyncher",
    "lynchés": "lyncher",
    "lyonnaise": "lyonnais",
    "lyonnaises": "lyonnais",
    "lyophilisa": "lyophiliser",
    "lyophilisai": "lyophiliser",
    "lyophilisaient": "lyophiliser",
    "lyophilisais": "lyophiliser",
    "lyophilisait": "lyophiliser",
    "lyophilisant": "lyophiliser",
    "lyophilisas": "lyophiliser",
    "lyophilisasse": "lyophiliser",
    "lyophilisassent": "lyophiliser",
    "lyophilisasses": "lyophiliser",
    "lyophilisassiez": "lyophiliser",
    "lyophilisassions": "lyophiliser",
    "lyophilise": "lyophiliser",
    "lyophilisent": "lyophiliser",
    "lyophilisera": "lyophiliser",
    "lyophiliserai": "lyophiliser",
    "lyophiliseraient": "lyophiliser",
    "lyophiliserais": "lyophiliser",
    "lyophiliserait": "lyophiliser",
    "lyophiliseras": "lyophiliser",
    "lyophiliserez": "lyophiliser",
    "lyophiliseriez": "lyophiliser",
    "lyophiliserions": "lyophiliser",
    "lyophiliserons": "lyophiliser",
    "lyophiliseront": "lyophiliser",
    "lyophilises": "lyophiliser",
    "lyophilisez": "lyophiliser",
    "lyophilisiez": "lyophiliser",
    "lyophilisions": "lyophiliser",
    "lyophilisons": "lyophiliser",
    "lyophilisâmes": "lyophiliser",
    "lyophilisât": "lyophiliser",
    "lyophilisâtes": "lyophiliser",
    "lyophilisèrent": "lyophiliser",
    "lyophilisé": "lyophiliser",
    "lyophilisée": "lyophiliser",
    "lyophilisées": "lyophiliser",
    "lyophilisés": "lyophiliser",
    "lyres": "lyre",
    "lyriques": "lyrique",
    "lyrismes": "lyrisme",
    "lysosomes": "lysosome",
    "lâcha": "lâcher",
    "lâchages": "lâchage",
    "lâchai": "lâcher",
    "lâchaient": "lâcher",
    "lâchais": "lâcher",
    "lâchait": "lâcher",
    "lâchant": "lâcher",
    "lâchas": "lâcher",
    "lâchasse": "lâcher",
    "lâchassent": "lâcher",
    "lâchasses": "lâcher",
    "lâchassiez": "lâcher",
    "lâchassions": "lâcher",
    "lâche": "lâcher",
    "lâchent": "lâcher",
    "lâchera": "lâcher",
    "lâcherai": "lâcher",
    "lâcheraient": "lâcher",
    "lâcherais": "lâcher",
    "lâcherait": "lâcher",
    "lâcheras": "lâcher",
    "lâcherez": "lâcher",
    "lâcheriez": "lâcher",
    "lâcherions": "lâcher",
    "lâcherons": "lâcher",
    "lâcheront": "lâcher",
    "lâchers": "lâcher",
    "lâches": "lâcher",
    "lâchetés": "lâcheté",
    "lâcheurs": "lâcheur",
    "lâcheuse": "lâcheur",
    "lâchez": "lâcher",
    "lâchiez": "lâcher",
    "lâchions": "lâcher",
    "lâchons": "lâcher",
    "lâchâmes": "lâcher",
    "lâchât": "lâcher",
    "lâchâtes": "lâcher",
    "lâchèrent": "lâcher",
    "lâché": "lâcher",
    "lâchée": "lâcher",
    "lâchées": "lâcher",
    "lâchés": "lâcher",
    "lèche": "lécher",
    "lèchefrites": "lèchefrite",
    "lèchent": "lécher",
    "lècheries": "lècherie",
    "lèches": "lécher",
    "lègue": "léguer",
    "lèguent": "léguer",
    "lègues": "léguer",
    "lèpres": "lèpre",
    "lèse": "léser",
    "lèse-majestés": "lèse-majesté",
    "lèsent": "léser",
    "lèses": "léser",
    "lève": "lever",
    "lèvent": "lever",
    "lèvera": "lever",
    "lèverai": "lever",
    "lèveraient": "lever",
    "lèverais": "lever",
    "lèverait": "lever",
    "lèveras": "lever",
    "lèverez": "lever",
    "lèveriez": "lever",
    "lèverions": "lever",
    "lèverons": "lever",
    "lèveront": "lever",
    "lèves": "lever",
    "lèvres": "lèvre",
    "lécha": "lécher",
    "léchages": "léchage",
    "léchai": "lécher",
    "léchaient": "lécher",
    "léchais": "lécher",
    "léchait": "lécher",
    "léchant": "lécher",
    "léchas": "lécher",
    "léchasse": "lécher",
    "léchassent": "lécher",
    "léchasses": "lécher",
    "léchassiez": "lécher",
    "léchassions": "lécher",
    "léchera": "lécher",
    "lécherai": "lécher",
    "lécheraient": "lécher",
    "lécherais": "lécher",
    "lécherait": "lécher",
    "lécheras": "lécher",
    "lécherez": "lécher",
    "lécheriez": "lécher",
    "lécherions": "lécher",
    "lécherons": "lécher",
    "lécheront": "lécher",
    "lécheurs": "lécheur",
    "lécheuse": "lécheur",
    "lécheuses": "lécheur",
    "léchez": "lécher",
    "léchiez": "lécher",
    "léchions": "lécher",
    "léchons": "lécher",
    "léchouillait": "léchouiller",
    "léchouillent": "léchouiller",
    "léchouilles": "léchouiller",
    "léchâmes": "lécher",
    "léchât": "lécher",
    "léchâtes": "lécher",
    "léchèrent": "lécher",
    "léché": "lécher",
    "léchée": "lécher",
    "léchées": "lécher",
    "léchés": "lécher",
    "légale": "légal",
    "légales": "légal",
    "légalisa": "légaliser",
    "légalisai": "légaliser",
    "légalisaient": "légaliser",
    "légalisais": "légaliser",
    "légalisait": "légaliser",
    "légalisant": "légaliser",
    "légalisas": "légaliser",
    "légalisasse": "légaliser",
    "légalisassent": "légaliser",
    "légalisasses": "légaliser",
    "légalisassiez": "légaliser",
    "légalisassions": "légaliser",
    "légalisations": "légalisation",
    "légalise": "légaliser",
    "légalisent": "légaliser",
    "légalisera": "légaliser",
    "légaliserai": "légaliser",
    "légaliseraient": "légaliser",
    "légaliserais": "légaliser",
    "légaliserait": "légaliser",
    "légaliseras": "légaliser",
    "légaliserez": "légaliser",
    "légaliseriez": "légaliser",
    "légaliserions": "légaliser",
    "légaliserons": "légaliser",
    "légaliseront": "légaliser",
    "légalises": "légaliser",
    "légalisez": "légaliser",
    "légalisiez": "légaliser",
    "légalisions": "légaliser",
    "légalisons": "légaliser",
    "légalistes": "légaliste",
    "légalisâmes": "légaliser",
    "légalisât": "légaliser",
    "légalisâtes": "légaliser",
    "légalisèrent": "légaliser",
    "légalisé": "légaliser",
    "légalisée": "légaliser",
    "légalisées": "légaliser",
    "légalisés": "légaliser",
    "légalités": "légalité",
    "légataires": "légataire",
    "légations": "légation",
    "légats": "légat",
    "légaux": "légal",
    "légendaires": "légendaire",
    "légendes": "légende",
    "légendée": "légender",
    "légere": "léger",
    "légeres": "léger",
    "légers": "léger",
    "légifère": "légiférer",
    "légifèrent": "légiférer",
    "légifères": "légiférer",
    "légiféra": "légiférer",
    "légiférai": "légiférer",
    "légiféraient": "légiférer",
    "légiférais": "légiférer",
    "légiférait": "légiférer",
    "légiférant": "légiférer",
    "légiféras": "légiférer",
    "légiférasse": "légiférer",
    "légiférassent": "légiférer",
    "légiférasses": "légiférer",
    "légiférassiez": "légiférer",
    "légiférassions": "légiférer",
    "légiférera": "légiférer",
    "légiférerai": "légiférer",
    "légiféreraient": "légiférer",
    "légiférerais": "légiférer",
    "légiférerait": "légiférer",
    "légiféreras": "légiférer",
    "légiférerez": "légiférer",
    "légiféreriez": "légiférer",
    "légiférerions": "légiférer",
    "légiférerons": "légiférer",
    "légiféreront": "légiférer",
    "légiférez": "légiférer",
    "légifériez": "légiférer",
    "légiférions": "légiférer",
    "légiférons": "légiférer",
    "légiférâmes": "légiférer",
    "légiférât": "légiférer",
    "légiférâtes": "légiférer",
    "légiférèrent": "légiférer",
    "légiféré": "légiférer",
    "légionnaires": "légionnaire",
    "légions": "légion",
    "législateurs": "législateur",
    "législatifs": "législatif",
    "législations": "législation",
    "législative": "législatif",
    "législatives": "législatif",
    "législatrice": "législateur",
    "législatrices": "législateur",
    "législatures": "législature",
    "légistes": "légiste",
    "légitima": "légitimer",
    "légitimai": "légitimer",
    "légitimaient": "légitimer",
    "légitimais": "légitimer",
    "légitimait": "légitimer",
    "légitimant": "légitimer",
    "légitimas": "légitimer",
    "légitimasse": "légitimer",
    "légitimassent": "légitimer",
    "légitimasses": "légitimer",
    "légitimassiez": "légitimer",
    "légitimassions": "légitimer",
    "légitimations": "légitimation",
    "légitime": "légitimer",
    "légitiment": "légitimer",
    "légitimera": "légitimer",
    "légitimerai": "légitimer",
    "légitimeraient": "légitimer",
    "légitimerais": "légitimer",
    "légitimerait": "légitimer",
    "légitimeras": "légitimer",
    "légitimerez": "légitimer",
    "légitimeriez": "légitimer",
    "légitimerions": "légitimer",
    "légitimerons": "légitimer",
    "légitimeront": "légitimer",
    "légitimes": "légitimer",
    "légitimez": "légitimer",
    "légitimiez": "légitimer",
    "légitimions": "légitimer",
    "légitimismes": "légitimisme",
    "légitimistes": "légitimiste",
    "légitimités": "légitimité",
    "légitimons": "légitimer",
    "légitimâmes": "légitimer",
    "légitimât": "légitimer",
    "légitimâtes": "légitimer",
    "légitimèrent": "légitimer",
    "légitimé": "légitimer",
    "légitimée": "légitimer",
    "légitimées": "légitimer",
    "légitimés": "légitimer",
    "légua": "léguer",
    "léguai": "léguer",
    "léguaient": "léguer",
    "léguais": "léguer",
    "léguait": "léguer",
    "léguant": "léguer",
    "léguas": "léguer",
    "léguasse": "léguer",
    "léguassent": "léguer",
    "léguasses": "léguer",
    "léguassiez": "léguer",
    "léguassions": "léguer",
    "léguera": "léguer",
    "léguerai": "léguer",
    "légueraient": "léguer",
    "léguerais": "léguer",
    "léguerait": "léguer",
    "légueras": "léguer",
    "léguerez": "léguer",
    "légueriez": "léguer",
    "léguerions": "léguer",
    "léguerons": "léguer",
    "légueront": "léguer",
    "léguez": "léguer",
    "léguiez": "léguer",
    "léguions": "léguer",
    "légumes": "légume",
    "légumiers": "légumier",
    "légumineuse": "légumineux",
    "légumineuses": "légumineuse",
    "légumière": "légumier",
    "légumières": "légumier",
    "léguons": "léguer",
    "léguâmes": "léguer",
    "léguât": "léguer",
    "léguâtes": "léguer",
    "léguèrent": "léguer",
    "légué": "léguer",
    "léguée": "léguer",
    "léguées": "léguer",
    "légués": "léguer",
    "légère": "léger",
    "légères": "léger",
    "légèretés": "légèreté",
    "lémures": "lémure",
    "lémuriens": "lémurien",
    "lénifia": "lénifier",
    "lénifiai": "lénifier",
    "lénifiaient": "lénifier",
    "lénifiais": "lénifier",
    "lénifiait": "lénifier",
    "lénifiant": "lénifier",
    "lénifiante": "lénifiant",
    "lénifiantes": "lénifiant",
    "lénifiants": "lénifiant",
    "lénifias": "lénifier",
    "lénifiasse": "lénifier",
    "lénifiassent": "lénifier",
    "lénifiasses": "lénifier",
    "lénifiassiez": "lénifier",
    "lénifiassions": "lénifier",
    "lénifie": "lénifier",
    "lénifient": "lénifier",
    "lénifiera": "lénifier",
    "lénifierai": "lénifier",
    "lénifieraient": "lénifier",
    "lénifierais": "lénifier",
    "lénifierait": "lénifier",
    "lénifieras": "lénifier",
    "lénifierez": "lénifier",
    "lénifieriez": "lénifier",
    "lénifierions": "lénifier",
    "lénifierons": "lénifier",
    "lénifieront": "lénifier",
    "lénifies": "lénifier",
    "lénifiez": "lénifier",
    "lénifiiez": "lénifier",
    "lénifiions": "lénifier",
    "lénifions": "lénifier",
    "lénifiâmes": "lénifier",
    "lénifiât": "lénifier",
    "lénifiâtes": "lénifier",
    "lénifièrent": "lénifier",
    "lénifié": "lénifier",
    "lénifiée": "lénifier",
    "lénifiées": "lénifier",
    "lénifiés": "lénifier",
    "léninismes": "léninisme",
    "léninistes": "léniniste",
    "lénitive": "lénitif",
    "lénitives": "lénitif",
    "léonine": "léonin",
    "léonines": "léonin",
    "léonins": "léonin",
    "léopards": "léopard",
    "lépidodendrons": "lépidodendron",
    "lépidoptères": "lépidoptère",
    "lépiotes": "lépiote",
    "lépreuse": "lépreux",
    "lépreuses": "lépreux",
    "léproseries": "léproserie",
    "lérots": "lérot",
    "lés": "lé",
    "lésa": "léser",
    "lésai": "léser",
    "lésaient": "léser",
    "lésais": "léser",
    "lésait": "léser",
    "lésant": "léser",
    "lésas": "léser",
    "lésasse": "léser",
    "lésassent": "léser",
    "lésasses": "léser",
    "lésassiez": "léser",
    "lésassions": "léser",
    "lésera": "léser",
    "léserai": "léser",
    "léseraient": "léser",
    "léserais": "léser",
    "léserait": "léser",
    "léseras": "léser",
    "léserez": "léser",
    "léseriez": "léser",
    "léserions": "léser",
    "léserons": "léser",
    "léseront": "léser",
    "lésez": "léser",
    "lésiez": "léser",
    "lésina": "lésiner",
    "lésinai": "lésiner",
    "lésinaient": "lésiner",
    "lésinais": "lésiner",
    "lésinait": "lésiner",
    "lésinant": "lésiner",
    "lésinas": "lésiner",
    "lésinasse": "lésiner",
    "lésinassent": "lésiner",
    "lésinasses": "lésiner",
    "lésinassiez": "lésiner",
    "lésinassions": "lésiner",
    "lésine": "lésiner",
    "lésinent": "lésiner",
    "lésinera": "lésiner",
    "lésinerai": "lésiner",
    "lésineraient": "lésiner",
    "lésinerais": "lésiner",
    "lésinerait": "lésiner",
    "lésineras": "lésiner",
    "lésinerez": "lésiner",
    "lésineries": "lésinerie",
    "lésineriez": "lésiner",
    "lésinerions": "lésiner",
    "lésinerons": "lésiner",
    "lésineront": "lésiner",
    "lésines": "lésiner",
    "lésinez": "lésiner",
    "lésiniez": "lésiner",
    "lésinions": "lésiner",
    "lésinons": "lésiner",
    "lésinâmes": "lésiner",
    "lésinât": "lésiner",
    "lésinâtes": "lésiner",
    "lésinèrent": "lésiner",
    "lésiné": "lésiner",
    "lésionnelle": "lésionnel",
    "lésionnelles": "lésionnel",
    "lésionnels": "lésionnel",
    "lésions": "lésion",
    "lésons": "léser",
    "lésâmes": "léser",
    "lésât": "léser",
    "lésâtes": "léser",
    "lésèrent": "léser",
    "lésé": "léser",
    "lésée": "léser",
    "lésées": "léser",
    "lésés": "léser",
    "létale": "létal",
    "létales": "létal",
    "létaux": "létal",
    "léthargies": "léthargie",
    "léthargiques": "léthargique",
    "lévige": "léviger",
    "lévigea": "léviger",
    "lévigeai": "léviger",
    "lévigeaient": "léviger",
    "lévigeais": "léviger",
    "lévigeait": "léviger",
    "lévigeant": "léviger",
    "lévigeas": "léviger",
    "lévigeasse": "léviger",
    "lévigeassent": "léviger",
    "lévigeasses": "léviger",
    "lévigeassiez": "léviger",
    "lévigeassions": "léviger",
    "lévigent": "léviger",
    "lévigeons": "léviger",
    "lévigera": "léviger",
    "lévigerai": "léviger",
    "lévigeraient": "léviger",
    "lévigerais": "léviger",
    "lévigerait": "léviger",
    "lévigeras": "léviger",
    "lévigerez": "léviger",
    "lévigeriez": "léviger",
    "lévigerions": "léviger",
    "lévigerons": "léviger",
    "lévigeront": "léviger",
    "léviges": "léviger",
    "lévigez": "léviger",
    "lévigeâmes": "léviger",
    "lévigeât": "léviger",
    "lévigeâtes": "léviger",
    "lévigiez": "léviger",
    "lévigions": "léviger",
    "lévigèrent": "léviger",
    "lévigé": "léviger",
    "lévigée": "léviger",
    "lévigées": "léviger",
    "lévigés": "léviger",
    "lévitations": "lévitation",
    "lévitent": "léviter",
    "lévites": "lévite",
    "lévriers": "lévrier",
    "lézardaient": "lézarder",
    "lézardait": "lézarder",
    "lézarde": "lézarder",
    "lézardent": "lézarder",
    "lézardes": "lézarde",
    "lézards": "lézard",
    "lézardé": "lézarder",
    "lézardée": "lézardé",
    "lézardées": "lézarder",
    "lézardés": "lézarder",
    "lûmes": "lire",
    "lût": "lire",
    "lûtes": "lire",
    "m'": "se",
    "ma": "mon",
    "maboule": "maboul",
    "maboules": "maboul",
    "mabouls": "maboul",
    "macabres": "macabre",
    "macadams": "macadam",
    "macaques": "macaque",
    "macaronis": "macaroni",
    "macarons": "macaron",
    "macchabs": "macchab",
    "macchabées": "macchabée",
    "machaons": "machaon",
    "machettes": "machette",
    "machiavéliques": "machiavélique",
    "machiavélismes": "machiavélisme",
    "machina": "machiner",
    "machinai": "machiner",
    "machinaient": "machiner",
    "machinais": "machiner",
    "machinait": "machiner",
    "machinale": "machinal",
    "machinales": "machinal",
    "machinant": "machiner",
    "machinas": "machiner",
    "machinasse": "machiner",
    "machinassent": "machiner",
    "machinasses": "machiner",
    "machinassiez": "machiner",
    "machinassions": "machiner",
    "machinations": "machination",
    "machinaux": "machinal",
    "machine": "machiner",
    "machinent": "machiner",
    "machinera": "machiner",
    "machinerai": "machiner",
    "machineraient": "machiner",
    "machinerais": "machiner",
    "machinerait": "machiner",
    "machineras": "machiner",
    "machinerez": "machiner",
    "machineries": "machinerie",
    "machineriez": "machiner",
    "machinerions": "machiner",
    "machinerons": "machiner",
    "machineront": "machiner",
    "machines": "machiner",
    "machines-outils": "machine-outil",
    "machinez": "machiner",
    "machiniez": "machiner",
    "machinions": "machiner",
    "machinismes": "machinisme",
    "machinistes": "machiniste",
    "machinons": "machiner",
    "machinos": "machino",
    "machins": "machin",
    "machinâmes": "machiner",
    "machinât": "machiner",
    "machinâtes": "machiner",
    "machinèrent": "machiner",
    "machiné": "machiner",
    "machinée": "machiner",
    "machinées": "machiner",
    "machinés": "machiner",
    "machismes": "machisme",
    "machistes": "machiste",
    "machos": "macho",
    "macles": "macle",
    "macoutes": "macoute",
    "macres": "macre",
    "macreuses": "macreuse",
    "macrocosmes": "macrocosme",
    "macropodes": "macropode",
    "macroéconomiques": "macroéconomique",
    "macs": "mac",
    "macula": "maculer",
    "maculai": "maculer",
    "maculaient": "maculer",
    "maculais": "maculer",
    "maculait": "maculer",
    "maculant": "maculer",
    "maculas": "maculer",
    "maculasse": "maculer",
    "maculassent": "maculer",
    "maculasses": "maculer",
    "maculassiez": "maculer",
    "maculassions": "maculer",
    "macule": "maculer",
    "maculent": "maculer",
    "maculera": "maculer",
    "maculerai": "maculer",
    "maculeraient": "maculer",
    "maculerais": "maculer",
    "maculerait": "maculer",
    "maculeras": "maculer",
    "maculerez": "maculer",
    "maculeriez": "maculer",
    "maculerions": "maculer",
    "maculerons": "maculer",
    "maculeront": "maculer",
    "macules": "maculer",
    "maculez": "maculer",
    "maculiez": "maculer",
    "maculions": "maculer",
    "maculons": "maculer",
    "maculâmes": "maculer",
    "maculât": "maculer",
    "maculâtes": "maculer",
    "maculèrent": "maculer",
    "maculé": "maculer",
    "maculée": "maculer",
    "maculées": "maculer",
    "maculés": "maculer",
    "macère": "macérer",
    "macèrent": "macérer",
    "macères": "macérer",
    "macédoines": "macédoine",
    "macédonienne": "macédonien",
    "macédoniennes": "macédonien",
    "macédoniens": "macédonien",
    "macéra": "macérer",
    "macérai": "macérer",
    "macéraient": "macérer",
    "macérais": "macérer",
    "macérait": "macérer",
    "macérant": "macérer",
    "macéras": "macérer",
    "macérasse": "macérer",
    "macérassent": "macérer",
    "macérasses": "macérer",
    "macérassiez": "macérer",
    "macérassions": "macérer",
    "macérations": "macération",
    "macérera": "macérer",
    "macérerai": "macérer",
    "macéreraient": "macérer",
    "macérerais": "macérer",
    "macérerait": "macérer",
    "macéreras": "macérer",
    "macérerez": "macérer",
    "macéreriez": "macérer",
    "macérerions": "macérer",
    "macérerons": "macérer",
    "macéreront": "macérer",
    "macérez": "macérer",
    "macériez": "macérer",
    "macérions": "macérer",
    "macérons": "macérer",
    "macérâmes": "macérer",
    "macérât": "macérer",
    "macérâtes": "macérer",
    "macérèrent": "macérer",
    "macéré": "macérer",
    "macérée": "macérer",
    "macérées": "macérer",
    "macérés": "macérer",
    "madapolams": "madapolam",
    "madeleines": "madeleine",
    "mademoiselles": "mademoiselle",
    "madones": "madone",
    "madriers": "madrier",
    "madrigaux": "madrigal",
    "madrilènes": "madrilène",
    "madrée": "madré",
    "madrées": "madré",
    "madrépores": "madrépore",
    "madrés": "madré",
    "madères": "madère",
    "madérisa": "madériser",
    "madérisai": "madériser",
    "madérisaient": "madériser",
    "madérisais": "madériser",
    "madérisait": "madériser",
    "madérisant": "madériser",
    "madérisas": "madériser",
    "madérisasse": "madériser",
    "madérisassent": "madériser",
    "madérisasses": "madériser",
    "madérisassiez": "madériser",
    "madérisassions": "madériser",
    "madérise": "madériser",
    "madérisent": "madériser",
    "madérisera": "madériser",
    "madériserai": "madériser",
    "madériseraient": "madériser",
    "madériserais": "madériser",
    "madériserait": "madériser",
    "madériseras": "madériser",
    "madériserez": "madériser",
    "madériseriez": "madériser",
    "madériserions": "madériser",
    "madériserons": "madériser",
    "madériseront": "madériser",
    "madérises": "madériser",
    "madérisez": "madériser",
    "madérisiez": "madériser",
    "madérisions": "madériser",
    "madérisons": "madériser",
    "madérisâmes": "madériser",
    "madérisât": "madériser",
    "madérisâtes": "madériser",
    "madérisèrent": "madériser",
    "madérisé": "madériser",
    "madérisée": "madériser",
    "madérisées": "madériser",
    "madérisés": "madériser",
    "maelströms": "maelström",
    "maestrias": "maestria",
    "maestros": "maestro",
    "maffias": "maffia",
    "maffiosi": "maffioso",
    "maffiosos": "maffioso",
    "mafflue": "mafflu",
    "mafflus": "mafflu",
    "mafias": "mafia",
    "mafieuse": "mafieux",
    "mafieuses": "mafieux",
    "mafiosi": "mafioso",
    "mafiosos": "mafioso",
    "magasina": "magasiner",
    "magasinages": "magasinage",
    "magasinai": "magasiner",
    "magasinaient": "magasiner",
    "magasinais": "magasiner",
    "magasinait": "magasiner",
    "magasinant": "magasiner",
    "magasinas": "magasiner",
    "magasinasse": "magasiner",
    "magasinassent": "magasiner",
    "magasinasses": "magasiner",
    "magasinassiez": "magasiner",
    "magasinassions": "magasiner",
    "magasine": "magasiner",
    "magasinent": "magasiner",
    "magasinera": "magasiner",
    "magasinerai": "magasiner",
    "magasineraient": "magasiner",
    "magasinerais": "magasiner",
    "magasinerait": "magasiner",
    "magasineras": "magasiner",
    "magasinerez": "magasiner",
    "magasineriez": "magasiner",
    "magasinerions": "magasiner",
    "magasinerons": "magasiner",
    "magasineront": "magasiner",
    "magasines": "magasiner",
    "magasinez": "magasiner",
    "magasiniers": "magasinier",
    "magasiniez": "magasiner",
    "magasinions": "magasiner",
    "magasinière": "magasinier",
    "magasinons": "magasiner",
    "magasins": "magasin",
    "magasinâmes": "magasiner",
    "magasinât": "magasiner",
    "magasinâtes": "magasiner",
    "magasinèrent": "magasiner",
    "magasiné": "magasiner",
    "magasinée": "magasiner",
    "magasinées": "magasiner",
    "magasinés": "magasiner",
    "magazines": "magazine",
    "magdaléniennes": "magdalénien",
    "magentas": "magenta",
    "mages": "mage",
    "maghrébine": "maghrébin",
    "maghrébines": "maghrébin",
    "maghrébins": "maghrébin",
    "magicienne": "magicien",
    "magiciennes": "magicien",
    "magiciens": "magicien",
    "magies": "magie",
    "magiques": "magique",
    "magisters": "magister",
    "magistrale": "magistral",
    "magistrales": "magistral",
    "magistrate": "magistrat",
    "magistrats": "magistrat",
    "magistratures": "magistrature",
    "magistraux": "magistral",
    "magistères": "magistère",
    "magmas": "magma",
    "magmatiques": "magmatique",
    "magna": "magner",
    "magnai": "magner",
    "magnaient": "magner",
    "magnais": "magner",
    "magnait": "magner",
    "magnaneries": "magnanerie",
    "magnanimes": "magnanime",
    "magnanimités": "magnanimité",
    "magnans": "magnan",
    "magnant": "magner",
    "magnas": "magner",
    "magnasse": "magner",
    "magnassent": "magner",
    "magnasses": "magner",
    "magnassiez": "magner",
    "magnassions": "magner",
    "magnats": "magnat",
    "magne": "magner",
    "magnent": "magner",
    "magnera": "magner",
    "magnerai": "magner",
    "magneraient": "magner",
    "magnerais": "magner",
    "magnerait": "magner",
    "magneras": "magner",
    "magnerez": "magner",
    "magneriez": "magner",
    "magnerions": "magner",
    "magnerons": "magner",
    "magneront": "magner",
    "magnes": "magner",
    "magnez": "magner",
    "magniez": "magner",
    "magnifia": "magnifier",
    "magnifiai": "magnifier",
    "magnifiaient": "magnifier",
    "magnifiais": "magnifier",
    "magnifiait": "magnifier",
    "magnifiant": "magnifier",
    "magnifias": "magnifier",
    "magnifiasse": "magnifier",
    "magnifiassent": "magnifier",
    "magnifiasses": "magnifier",
    "magnifiassiez": "magnifier",
    "magnifiassions": "magnifier",
    "magnificences": "magnificence",
    "magnifie": "magnifier",
    "magnifient": "magnifier",
    "magnifiera": "magnifier",
    "magnifierai": "magnifier",
    "magnifieraient": "magnifier",
    "magnifierais": "magnifier",
    "magnifierait": "magnifier",
    "magnifieras": "magnifier",
    "magnifierez": "magnifier",
    "magnifieriez": "magnifier",
    "magnifierions": "magnifier",
    "magnifierons": "magnifier",
    "magnifieront": "magnifier",
    "magnifies": "magnifier",
    "magnifiez": "magnifier",
    "magnifiiez": "magnifier",
    "magnifiions": "magnifier",
    "magnifions": "magnifier",
    "magnifiques": "magnifique",
    "magnifiâmes": "magnifier",
    "magnifiât": "magnifier",
    "magnifiâtes": "magnifier",
    "magnifièrent": "magnifier",
    "magnifié": "magnifier",
    "magnifiée": "magnifier",
    "magnifiées": "magnifier",
    "magnifiés": "magnifier",
    "magnions": "magner",
    "magnitudes": "magnitude",
    "magnolias": "magnolia",
    "magnons": "magner",
    "magnums": "magnum",
    "magnâmes": "magner",
    "magnât": "magner",
    "magnâtes": "magner",
    "magnèrent": "magner",
    "magné": "magner",
    "magnée": "magner",
    "magnées": "magner",
    "magnés": "magner",
    "magnésiums": "magnésium",
    "magnétiques": "magnétique",
    "magnétisa": "magnétiser",
    "magnétisai": "magnétiser",
    "magnétisaient": "magnétiser",
    "magnétisais": "magnétiser",
    "magnétisait": "magnétiser",
    "magnétisant": "magnétiser",
    "magnétisas": "magnétiser",
    "magnétisasse": "magnétiser",
    "magnétisassent": "magnétiser",
    "magnétisasses": "magnétiser",
    "magnétisassiez": "magnétiser",
    "magnétisassions": "magnétiser",
    "magnétise": "magnétiser",
    "magnétisent": "magnétiser",
    "magnétisera": "magnétiser",
    "magnétiserai": "magnétiser",
    "magnétiseraient": "magnétiser",
    "magnétiserais": "magnétiser",
    "magnétiserait": "magnétiser",
    "magnétiseras": "magnétiser",
    "magnétiserez": "magnétiser",
    "magnétiseriez": "magnétiser",
    "magnétiserions": "magnétiser",
    "magnétiserons": "magnétiser",
    "magnétiseront": "magnétiser",
    "magnétises": "magnétiser",
    "magnétiseuses": "magnétiseur",
    "magnétisez": "magnétiser",
    "magnétisiez": "magnétiser",
    "magnétisions": "magnétiser",
    "magnétismes": "magnétisme",
    "magnétisons": "magnétiser",
    "magnétisâmes": "magnétiser",
    "magnétisât": "magnétiser",
    "magnétisâtes": "magnétiser",
    "magnétisèrent": "magnétiser",
    "magnétisé": "magnétiser",
    "magnétisée": "magnétiser",
    "magnétisées": "magnétiser",
    "magnétisés": "magnétiser",
    "magnétons": "magnéton",
    "magnétophones": "magnétophone",
    "magnétos": "magnéto",
    "magnétoscopes": "magnétoscope",
    "magnétrons": "magnétron",
    "magots": "magot",
    "magouillais": "magouiller",
    "magouillait": "magouiller",
    "magouillant": "magouiller",
    "magouilles": "magouille",
    "magouilleurs": "magouilleur",
    "magouillez": "magouiller",
    "magouillé": "magouiller",
    "magrets": "magret",
    "magyare": "magyar",
    "magyares": "magyar",
    "magyars": "magyar",
    "mah-jongs": "mah-jong",
    "maharadjahs": "maharadjah",
    "maharadjas": "maharadja",
    "maharajahs": "maharajah",
    "maharajas": "maharaja",
    "maharanis": "maharani",
    "mahatmas": "mahatma",
    "mahdis": "mahdi",
    "mahométane": "mahométan",
    "mahométanes": "mahométan",
    "mahométans": "mahométan",
    "mahonias": "mahonia",
    "mahousses": "mahousse",
    "maies": "maie",
    "maigrelets": "maigrelet",
    "maigrelette": "maigrelet",
    "maigrelettes": "maigrelette",
    "maigres": "maigre",
    "maigreurs": "maigreur",
    "maigri": "maigrir",
    "maigrichonne": "maigrichon",
    "maigrichonnes": "maigrichon",
    "maigrichons": "maigrichon",
    "maigrie": "maigrir",
    "maigries": "maigrir",
    "maigriots": "maigriot",
    "maigriotte": "maigriot",
    "maigriottes": "maigriot",
    "maigrira": "maigrir",
    "maigrirai": "maigrir",
    "maigriraient": "maigrir",
    "maigrirais": "maigrir",
    "maigrirait": "maigrir",
    "maigriras": "maigrir",
    "maigrirent": "maigrir",
    "maigrirez": "maigrir",
    "maigririez": "maigrir",
    "maigririons": "maigrir",
    "maigrirons": "maigrir",
    "maigriront": "maigrir",
    "maigris": "maigrir",
    "maigrissaient": "maigrir",
    "maigrissais": "maigrir",
    "maigrissait": "maigrir",
    "maigrissant": "maigrir",
    "maigrisse": "maigrir",
    "maigrissent": "maigrir",
    "maigrisses": "maigrir",
    "maigrissez": "maigrir",
    "maigrissiez": "maigrir",
    "maigrissions": "maigrir",
    "maigrissons": "maigrir",
    "maigrit": "maigrir",
    "maigrîmes": "maigrir",
    "maigrît": "maigrir",
    "maigrîtes": "maigrir",
    "mail-coaches": "mail-coach",
    "maillages": "maillage",
    "maillait": "mailler",
    "maillante": "maillant",
    "maillantes": "maillant",
    "maillants": "maillant",
    "maille": "mailler",
    "maillechorts": "maillechort",
    "mailles": "maille",
    "maillets": "maillet",
    "mailloches": "mailloche",
    "maillons": "maillon",
    "maillotins": "maillotin",
    "maillots": "maillot",
    "maillés": "maillé",
    "mails": "mail",
    "mailé": "mailer",
    "mainlevées": "mainlevée",
    "mainmet": "mainmettre",
    "mainmets": "mainmettre",
    "mainmettaient": "mainmettre",
    "mainmettais": "mainmettre",
    "mainmettait": "mainmettre",
    "mainmettant": "mainmettre",
    "mainmette": "mainmettre",
    "mainmettent": "mainmettre",
    "mainmettes": "mainmettre",
    "mainmettez": "mainmettre",
    "mainmettiez": "mainmettre",
    "mainmettions": "mainmettre",
    "mainmettons": "mainmettre",
    "mainmettra": "mainmettre",
    "mainmettrai": "mainmettre",
    "mainmettraient": "mainmettre",
    "mainmettrais": "mainmettre",
    "mainmettrait": "mainmettre",
    "mainmettras": "mainmettre",
    "mainmettrez": "mainmettre",
    "mainmettriez": "mainmettre",
    "mainmettrions": "mainmettre",
    "mainmettrons": "mainmettre",
    "mainmettront": "mainmettre",
    "mainmirent": "mainmettre",
    "mainmis": "mainmettre",
    "mainmise": "mainmettre",
    "mainmises": "mainmise",
    "mainmiss": "mainmettre",
    "mainmisse": "mainmettre",
    "mainmissent": "mainmettre",
    "mainmisses": "mainmettre",
    "mainmissiez": "mainmettre",
    "mainmissions": "mainmettre",
    "mainmit": "mainmettre",
    "mainmortes": "mainmorte",
    "mainmîmes": "mainmettre",
    "mainmît": "mainmettre",
    "mainmîtes": "mainmettre",
    "mains": "main",
    "mains-d'oeuvre": "main-d'oeuvre",
    "mainte": "maint",
    "maintenaient": "maintenir",
    "maintenais": "maintenir",
    "maintenait": "maintenir",
    "maintenances": "maintenance",
    "maintenant": "maintenir",
    "mainteneurs": "mainteneur",
    "maintenez": "maintenir",
    "mainteniez": "maintenir",
    "maintenions": "maintenir",
    "maintenons": "maintenir",
    "maintenu": "maintenir",
    "maintenue": "maintenir",
    "maintenues": "maintenir",
    "maintenus": "maintenir",
    "maintes": "maint",
    "maintiendra": "maintenir",
    "maintiendrai": "maintenir",
    "maintiendraient": "maintenir",
    "maintiendrais": "maintenir",
    "maintiendrait": "maintenir",
    "maintiendras": "maintenir",
    "maintiendrez": "maintenir",
    "maintiendriez": "maintenir",
    "maintiendrions": "maintenir",
    "maintiendrons": "maintenir",
    "maintiendront": "maintenir",
    "maintienne": "maintenir",
    "maintiennent": "maintenir",
    "maintiennes": "maintenir",
    "maintiens": "maintien",
    "maintient": "maintenir",
    "maintinrent": "maintenir",
    "maintins": "maintenir",
    "maintinsse": "maintenir",
    "maintinssent": "maintenir",
    "maintinsses": "maintenir",
    "maintinssiez": "maintenir",
    "maintinssions": "maintenir",
    "maintint": "maintenir",
    "maints": "maint",
    "maintînmes": "maintenir",
    "maintînt": "maintenir",
    "maintîntes": "maintenir",
    "maires": "maire",
    "mairesse": "maire",
    "mairies": "mairie",
    "mais": "mai",
    "maisonnettes": "maisonnette",
    "maisonnées": "maisonnée",
    "maisons": "maison",
    "maistrances": "maistrance",
    "majestueuse": "majestueux",
    "majestueuses": "majestueux",
    "majestés": "majesté",
    "majeure": "majeur",
    "majeures": "majeur",
    "majeurs": "majeur",
    "majora": "majorer",
    "majorai": "majorer",
    "majoraient": "majorer",
    "majorais": "majorer",
    "majorait": "majorer",
    "majorant": "majorer",
    "majoras": "majorer",
    "majorasse": "majorer",
    "majorassent": "majorer",
    "majorasses": "majorer",
    "majorassiez": "majorer",
    "majorassions": "majorer",
    "majorations": "majoration",
    "majorats": "majorat",
    "majordomes": "majordome",
    "majore": "majorer",
    "majorent": "majorer",
    "majorera": "majorer",
    "majorerai": "majorer",
    "majoreraient": "majorer",
    "majorerais": "majorer",
    "majorerait": "majorer",
    "majoreras": "majorer",
    "majorerez": "majorer",
    "majoreriez": "majorer",
    "majorerions": "majorer",
    "majorerons": "majorer",
    "majoreront": "majorer",
    "majores": "majorer",
    "majorettes": "majorette",
    "majorez": "majorer",
    "majoriez": "majorer",
    "majorions": "majorer",
    "majoritaires": "majoritaire",
    "majorités": "majorité",
    "majorons": "majorer",
    "majors": "major",
    "majorâmes": "majorer",
    "majorât": "majorer",
    "majorâtes": "majorer",
    "majorèrent": "majorer",
    "majoré": "majorer",
    "majorée": "majorer",
    "majorées": "majorer",
    "majorés": "majorer",
    "majuscules": "majuscule",
    "mal-aimée": "mal-aimé",
    "mal-aimés": "mal-aimé",
    "mal-baisée": "mal-baisé",
    "mal-logée": "mal-logé",
    "mal-logées": "mal-logé",
    "mal-logés": "mal-logé",
    "mal-pensante": "mal-pensant",
    "mal-pensants": "mal-pensant",
    "malabars": "malabar",
    "malachites": "malachite",
    "malades": "malade",
    "maladies": "maladie",
    "maladifs": "maladif",
    "maladive": "maladif",
    "maladives": "maladif",
    "maladreries": "maladrerie",
    "maladresses": "maladresse",
    "maladroite": "maladroit",
    "maladroites": "maladroit",
    "maladroits": "maladroit",
    "malagas": "malaga",
    "malaires": "malaire",
    "malaise": "malais",
    "malaises": "malaise",
    "malaisienne": "malaisien",
    "malaisiennes": "malaisien",
    "malaisiens": "malaisien",
    "malaisée": "malaisé",
    "malaisées": "malaisé",
    "malaisés": "malaisé",
    "malandrins": "malandrin",
    "malapprise": "malappris",
    "malapprises": "malappris",
    "malards": "malard",
    "malarias": "malaria",
    "malaventures": "malaventure",
    "malavisée": "malavisé",
    "malavisées": "malavisé",
    "malavisés": "malavisé",
    "malawienne": "malawien",
    "malawiennes": "malawien",
    "malawiens": "malawien",
    "malaxa": "malaxer",
    "malaxai": "malaxer",
    "malaxaient": "malaxer",
    "malaxais": "malaxer",
    "malaxait": "malaxer",
    "malaxant": "malaxer",
    "malaxas": "malaxer",
    "malaxasse": "malaxer",
    "malaxassent": "malaxer",
    "malaxasses": "malaxer",
    "malaxassiez": "malaxer",
    "malaxassions": "malaxer",
    "malaxe": "malaxer",
    "malaxent": "malaxer",
    "malaxera": "malaxer",
    "malaxerai": "malaxer",
    "malaxeraient": "malaxer",
    "malaxerais": "malaxer",
    "malaxerait": "malaxer",
    "malaxeras": "malaxer",
    "malaxerez": "malaxer",
    "malaxeriez": "malaxer",
    "malaxerions": "malaxer",
    "malaxerons": "malaxer",
    "malaxeront": "malaxer",
    "malaxes": "malaxer",
    "malaxez": "malaxer",
    "malaxiez": "malaxer",
    "malaxions": "malaxer",
    "malaxons": "malaxer",
    "malaxâmes": "malaxer",
    "malaxât": "malaxer",
    "malaxâtes": "malaxer",
    "malaxèrent": "malaxer",
    "malaxé": "malaxer",
    "malaxée": "malaxer",
    "malaxées": "malaxer",
    "malaxés": "malaxer",
    "malbâtie": "malbâti",
    "malbâties": "malbâti",
    "malbâtis": "malbâti",
    "malchances": "malchance",
    "malchanceuse": "malchanceux",
    "malchanceuses": "malchanceux",
    "malcommodes": "malcommode",
    "malcontents": "malcontent",
    "maldonnes": "maldonne",
    "male": "mal",
    "malencontres": "malencontre",
    "malencontreuse": "malencontreux",
    "malencontreuses": "malencontreux",
    "malentendante": "malentendant",
    "malentendantes": "malentendant",
    "malentendants": "malentendant",
    "malentendus": "malentendu",
    "males": "mal",
    "malfaisances": "malfaisance",
    "malfaisante": "malfaisant",
    "malfaisantes": "malfaisant",
    "malfaisants": "malfaisant",
    "malfaiteurs": "malfaiteur",
    "malfamée": "malfamé",
    "malfamées": "malfamé",
    "malfamés": "malfamé",
    "malfaçons": "malfaçon",
    "malformations": "malformation",
    "malfrats": "malfrat",
    "malgaches": "malgache",
    "malgracieuse": "malgracieux",
    "malhabiles": "malhabile",
    "malheureuse": "malheureux",
    "malheureuses": "malheureux",
    "malheurs": "malheur",
    "malhonnêtes": "malhonnête",
    "malhonnêtetés": "malhonnêteté",
    "malices": "malice",
    "malicieuse": "malicieux",
    "malicieuses": "malicieux",
    "malienne": "malien",
    "maliennes": "malien",
    "maliens": "malien",
    "maligne": "malin",
    "malignes": "malin",
    "malignités": "malignité",
    "maline": "malin",
    "malines": "malin",
    "malingres": "malingre",
    "malins": "malin",
    "malintentionnée": "malintentionné",
    "malintentionnées": "malintentionné",
    "malintentionnés": "malintentionné",
    "maliques": "malique",
    "mallarméenne": "mallarméen",
    "mallarméennes": "mallarméen",
    "mallarméens": "mallarméen",
    "malles": "malle",
    "malles-poste": "malle-poste",
    "malletiers": "malletier",
    "mallettes": "mallette",
    "mallophages": "mallophage",
    "malléables": "malléable",
    "malléoles": "malléole",
    "malmena": "malmener",
    "malmenai": "malmener",
    "malmenaient": "malmener",
    "malmenais": "malmener",
    "malmenait": "malmener",
    "malmenant": "malmener",
    "malmenas": "malmener",
    "malmenasse": "malmener",
    "malmenassent": "malmener",
    "malmenasses": "malmener",
    "malmenassiez": "malmener",
    "malmenassions": "malmener",
    "malmenez": "malmener",
    "malmeniez": "malmener",
    "malmenions": "malmener",
    "malmenons": "malmener",
    "malmenâmes": "malmener",
    "malmenât": "malmener",
    "malmenâtes": "malmener",
    "malmenèrent": "malmener",
    "malmené": "malmener",
    "malmenée": "malmener",
    "malmenées": "malmener",
    "malmenés": "malmener",
    "malmène": "malmener",
    "malmènent": "malmener",
    "malmènera": "malmener",
    "malmènerai": "malmener",
    "malmèneraient": "malmener",
    "malmènerais": "malmener",
    "malmènerait": "malmener",
    "malmèneras": "malmener",
    "malmènerez": "malmener",
    "malmèneriez": "malmener",
    "malmènerions": "malmener",
    "malmènerons": "malmener",
    "malmèneront": "malmener",
    "malmènes": "malmener",
    "malnutritions": "malnutrition",
    "malodorante": "malodorant",
    "malodorantes": "malodorant",
    "malodorants": "malodorant",
    "malotrue": "malotru",
    "malotrues": "malotru",
    "malotrus": "malotru",
    "malouine": "malouin",
    "malouines": "malouin",
    "malouins": "malouin",
    "malpolie": "malpoli",
    "malpolis": "malpoli",
    "malpropres": "malpropre",
    "malsaine": "malsain",
    "malsaines": "malsain",
    "malsains": "malsain",
    "malsonnante": "malsonnant",
    "malsonnantes": "malsonnant",
    "malsonnants": "malsonnant",
    "malstroms": "malstrom",
    "malséante": "malséant",
    "malséantes": "malséant",
    "malséants": "malséant",
    "malta": "malter",
    "maltaise": "maltais",
    "maltaises": "maltais",
    "malthusianismes": "malthusianisme",
    "malthusienne": "malthusien",
    "malthusiennes": "malthusien",
    "malthusiens": "malthusien",
    "maltoses": "maltose",
    "maltraita": "maltraiter",
    "maltraitai": "maltraiter",
    "maltraitaient": "maltraiter",
    "maltraitais": "maltraiter",
    "maltraitait": "maltraiter",
    "maltraitances": "maltraitance",
    "maltraitant": "maltraiter",
    "maltraitas": "maltraiter",
    "maltraitasse": "maltraiter",
    "maltraitassent": "maltraiter",
    "maltraitasses": "maltraiter",
    "maltraitassiez": "maltraiter",
    "maltraitassions": "maltraiter",
    "maltraite": "maltraiter",
    "maltraitent": "maltraiter",
    "maltraitera": "maltraiter",
    "maltraiterai": "maltraiter",
    "maltraiteraient": "maltraiter",
    "maltraiterais": "maltraiter",
    "maltraiterait": "maltraiter",
    "maltraiteras": "maltraiter",
    "maltraiterez": "maltraiter",
    "maltraiteriez": "maltraiter",
    "maltraiterions": "maltraiter",
    "maltraiterons": "maltraiter",
    "maltraiteront": "maltraiter",
    "maltraites": "maltraiter",
    "maltraitez": "maltraiter",
    "maltraitiez": "maltraiter",
    "maltraitions": "maltraiter",
    "maltraitons": "maltraiter",
    "maltraitâmes": "maltraiter",
    "maltraitât": "maltraiter",
    "maltraitâtes": "maltraiter",
    "maltraitèrent": "maltraiter",
    "maltraité": "maltraiter",
    "maltraitée": "maltraiter",
    "maltraitées": "maltraiter",
    "maltraités": "maltraiter",
    "malts": "malt",
    "malté": "malter",
    "maltée": "malter",
    "malvacées": "malvacée",
    "malveillances": "malveillance",
    "malveillante": "malveillant",
    "malveillantes": "malveillant",
    "malveillants": "malveillant",
    "malvenue": "malvenu",
    "malvenues": "malvenu",
    "malvenus": "malvenu",
    "malversations": "malversation",
    "malvoisies": "malvoisie",
    "malédictions": "malédiction",
    "maléfices": "maléfice",
    "maléfiques": "maléfique",
    "mamans": "maman",
    "mambos": "mambo",
    "mamelles": "mamelle",
    "mamelonnée": "mamelonné",
    "mamelonnées": "mamelonné",
    "mamelonnés": "mamelonné",
    "mamelons": "mamelon",
    "mamelouks": "mamelouk",
    "mamelue": "mamelu",
    "mamelues": "mamelu",
    "mameluks": "mameluk",
    "mamelus": "mamelu",
    "mamies": "mamie",
    "mammaires": "mammaire",
    "mammifères": "mammifère",
    "mammouths": "mammouth",
    "mamys": "mamy",
    "manades": "manade",
    "manage": "manager",
    "manageait": "manager",
    "managements": "management",
    "managerais": "manager",
    "managers": "manager",
    "managériale": "managérial",
    "managériales": "managérial",
    "managériaux": "managérial",
    "manants": "manant",
    "mancherons": "mancheron",
    "manches": "manche",
    "manchettes": "manchette",
    "manchons": "manchon",
    "manchote": "manchot",
    "manchotes": "manchot",
    "manchots": "manchot",
    "manda": "mander",
    "mandai": "mander",
    "mandaient": "mander",
    "mandais": "mander",
    "mandait": "mander",
    "mandalas": "mandala",
    "mandales": "mandale",
    "mandant": "mander",
    "mandante": "mandant",
    "mandantes": "mandant",
    "mandants": "mandant",
    "mandarinats": "mandarinat",
    "mandarines": "mandarine",
    "mandariniers": "mandarinier",
    "mandarins": "mandarin",
    "mandas": "mander",
    "mandasse": "mander",
    "mandassent": "mander",
    "mandasses": "mander",
    "mandassiez": "mander",
    "mandassions": "mander",
    "mandata": "mandater",
    "mandatai": "mandater",
    "mandataient": "mandater",
    "mandataires": "mandataire",
    "mandatais": "mandater",
    "mandatait": "mandater",
    "mandatant": "mandater",
    "mandatas": "mandater",
    "mandatasse": "mandater",
    "mandatassent": "mandater",
    "mandatasses": "mandater",
    "mandatassiez": "mandater",
    "mandatassions": "mandater",
    "mandate": "mandater",
    "mandatent": "mandater",
    "mandatera": "mandater",
    "mandaterai": "mandater",
    "mandateraient": "mandater",
    "mandaterais": "mandater",
    "mandaterait": "mandater",
    "mandateras": "mandater",
    "mandaterez": "mandater",
    "mandateriez": "mandater",
    "mandaterions": "mandater",
    "mandaterons": "mandater",
    "mandateront": "mandater",
    "mandates": "mandater",
    "mandatez": "mandater",
    "mandatiez": "mandater",
    "mandations": "mandater",
    "mandatons": "mandater",
    "mandats": "mandat",
    "mandats-lettres": "mandat-lettre",
    "mandatâmes": "mandater",
    "mandatât": "mandater",
    "mandatâtes": "mandater",
    "mandatèrent": "mandater",
    "mandaté": "mandater",
    "mandatée": "mandater",
    "mandatées": "mandater",
    "mandatés": "mandater",
    "mandchoue": "mandchou",
    "mandchoues": "mandchou",
    "mandchous": "mandchou",
    "mande": "mander",
    "mandements": "mandement",
    "mandent": "mander",
    "mandera": "mander",
    "manderai": "mander",
    "manderaient": "mander",
    "manderais": "mander",
    "manderait": "mander",
    "manderas": "mander",
    "manderez": "mander",
    "manderiez": "mander",
    "manderions": "mander",
    "manderons": "mander",
    "manderont": "mander",
    "mandes": "mander",
    "mandez": "mander",
    "mandibules": "mandibule",
    "mandiez": "mander",
    "mandingues": "mandingue",
    "mandions": "mander",
    "mandolines": "mandoline",
    "mandons": "mander",
    "mandorles": "mandorle",
    "mandragores": "mandragore",
    "mandrills": "mandrill",
    "mandrins": "mandrin",
    "manducations": "manducation",
    "mandâmes": "mander",
    "mandât": "mander",
    "mandâtes": "mander",
    "mandèrent": "mander",
    "mandé": "mander",
    "mandée": "mander",
    "mandées": "mander",
    "mandés": "mander",
    "manettes": "manette",
    "manganèses": "manganèse",
    "mangas": "manga",
    "mange": "manger",
    "mange-disques": "mange-disque",
    "mangea": "manger",
    "mangeables": "mangeable",
    "mangeai": "manger",
    "mangeaient": "manger",
    "mangeailles": "mangeaille",
    "mangeais": "manger",
    "mangeait": "manger",
    "mangeant": "manger",
    "mangeas": "manger",
    "mangeasse": "manger",
    "mangeassent": "manger",
    "mangeasses": "manger",
    "mangeassiez": "manger",
    "mangeassions": "manger",
    "mangent": "manger",
    "mangeoires": "mangeoire",
    "mangeons": "manger",
    "mangeotta": "mangeotter",
    "mangeottai": "mangeotter",
    "mangeottaient": "mangeotter",
    "mangeottais": "mangeotter",
    "mangeottait": "mangeotter",
    "mangeottant": "mangeotter",
    "mangeottas": "mangeotter",
    "mangeottasse": "mangeotter",
    "mangeottassent": "mangeotter",
    "mangeottasses": "mangeotter",
    "mangeottassiez": "mangeotter",
    "mangeottassions": "mangeotter",
    "mangeotte": "mangeotter",
    "mangeottent": "mangeotter",
    "mangeottera": "mangeotter",
    "mangeotterai": "mangeotter",
    "mangeotteraient": "mangeotter",
    "mangeotterais": "mangeotter",
    "mangeotterait": "mangeotter",
    "mangeotteras": "mangeotter",
    "mangeotterez": "mangeotter",
    "mangeotteriez": "mangeotter",
    "mangeotterions": "mangeotter",
    "mangeotterons": "mangeotter",
    "mangeotteront": "mangeotter",
    "mangeottes": "mangeotter",
    "mangeottez": "mangeotter",
    "mangeottiez": "mangeotter",
    "mangeottions": "mangeotter",
    "mangeottons": "mangeotter",
    "mangeottâmes": "mangeotter",
    "mangeottât": "mangeotter",
    "mangeottâtes": "mangeotter",
    "mangeottèrent": "mangeotter",
    "mangeotté": "mangeotter",
    "mangeottée": "mangeotter",
    "mangeottées": "mangeotter",
    "mangeottés": "mangeotter",
    "mangera": "manger",
    "mangerai": "manger",
    "mangeraient": "manger",
    "mangerais": "manger",
    "mangerait": "manger",
    "mangeras": "manger",
    "mangerez": "manger",
    "mangeriez": "manger",
    "mangerions": "manger",
    "mangerons": "manger",
    "mangeront": "manger",
    "manges": "manger",
    "mangeurs": "mangeur",
    "mangeuse": "mangeur",
    "mangeuses": "mangeur",
    "mangez": "manger",
    "mangeâmes": "manger",
    "mangeât": "manger",
    "mangeâtes": "manger",
    "mangiez": "manger",
    "mangions": "manger",
    "mangonneaux": "mangonneau",
    "mangoustes": "mangouste",
    "mangroves": "mangrove",
    "mangues": "mangue",
    "manguiers": "manguier",
    "mangèrent": "manger",
    "mangé": "manger",
    "mangée": "manger",
    "mangées": "manger",
    "mangés": "manger",
    "mania": "manier",
    "maniables": "maniable",
    "maniaco-dépressifs": "maniaco-dépressif",
    "maniaco-dépressive": "maniaco-dépressif",
    "maniacodépressive": "maniacodépressif",
    "maniai": "manier",
    "maniaient": "manier",
    "maniais": "manier",
    "maniait": "manier",
    "maniant": "manier",
    "maniaqueries": "maniaquerie",
    "maniaques": "maniaque",
    "manias": "manier",
    "maniasse": "manier",
    "maniassent": "manier",
    "maniasses": "manier",
    "maniassiez": "manier",
    "maniassions": "manier",
    "manichéenne": "manichéen",
    "manichéennes": "manichéen",
    "manichéens": "manichéen",
    "manichéismes": "manichéisme",
    "manicles": "manicle",
    "manie": "manier",
    "maniements": "maniement",
    "manient": "manier",
    "maniera": "manier",
    "manierai": "manier",
    "manieraient": "manier",
    "manierais": "manier",
    "manierait": "manier",
    "manieras": "manier",
    "manierez": "manier",
    "manieriez": "manier",
    "manierions": "manier",
    "manierons": "manier",
    "manieront": "manier",
    "manies": "manier",
    "manieurs": "manieur",
    "manieuse": "manieur",
    "maniez": "manier",
    "manifesta": "manifester",
    "manifestai": "manifester",
    "manifestaient": "manifester",
    "manifestais": "manifester",
    "manifestait": "manifester",
    "manifestant": "manifester",
    "manifestante": "manifestant",
    "manifestantes": "manifestant",
    "manifestants": "manifestant",
    "manifestas": "manifester",
    "manifestasse": "manifester",
    "manifestassent": "manifester",
    "manifestasses": "manifester",
    "manifestassiez": "manifester",
    "manifestassions": "manifester",
    "manifestations": "manifestation",
    "manifeste": "manifester",
    "manifestent": "manifester",
    "manifestera": "manifester",
    "manifesterai": "manifester",
    "manifesteraient": "manifester",
    "manifesterais": "manifester",
    "manifesterait": "manifester",
    "manifesteras": "manifester",
    "manifesterez": "manifester",
    "manifesteriez": "manifester",
    "manifesterions": "manifester",
    "manifesterons": "manifester",
    "manifesteront": "manifester",
    "manifestes": "manifester",
    "manifestez": "manifester",
    "manifestiez": "manifester",
    "manifestions": "manifester",
    "manifestons": "manifester",
    "manifestâmes": "manifester",
    "manifestât": "manifester",
    "manifestâtes": "manifester",
    "manifestèrent": "manifester",
    "manifesté": "manifester",
    "manifestée": "manifester",
    "manifestées": "manifester",
    "manifestés": "manifester",
    "manifolds": "manifold",
    "manifs": "manif",
    "manigance": "manigancer",
    "manigancent": "manigancer",
    "manigancerait": "manigancer",
    "manigances": "manigancer",
    "manigancez": "manigancer",
    "maniganciez": "manigancer",
    "manigancé": "manigancer",
    "manigancée": "manigancer",
    "manigançaient": "manigancer",
    "manigançais": "manigancer",
    "manigançait": "manigancer",
    "maniiez": "manier",
    "maniions": "manier",
    "manilla": "maniller",
    "manilles": "manille",
    "manilleurs": "manilleur",
    "manillons": "manillon",
    "maniocs": "manioc",
    "manions": "manier",
    "manipe": "manip",
    "manipula": "manipuler",
    "manipulables": "manipulable",
    "manipulai": "manipuler",
    "manipulaient": "manipuler",
    "manipulais": "manipuler",
    "manipulait": "manipuler",
    "manipulant": "manipuler",
    "manipulas": "manipuler",
    "manipulasse": "manipuler",
    "manipulassent": "manipuler",
    "manipulasses": "manipuler",
    "manipulassiez": "manipuler",
    "manipulassions": "manipuler",
    "manipulateurs": "manipulateur",
    "manipulations": "manipulation",
    "manipulatrice": "manipulateur",
    "manipulatrices": "manipulateur",
    "manipule": "manipuler",
    "manipulent": "manipuler",
    "manipulera": "manipuler",
    "manipulerai": "manipuler",
    "manipuleraient": "manipuler",
    "manipulerais": "manipuler",
    "manipulerait": "manipuler",
    "manipuleras": "manipuler",
    "manipulerez": "manipuler",
    "manipuleriez": "manipuler",
    "manipulerions": "manipuler",
    "manipulerons": "manipuler",
    "manipuleront": "manipuler",
    "manipules": "manipuler",
    "manipulez": "manipuler",
    "manipuliez": "manipuler",
    "manipulions": "manipuler",
    "manipulons": "manipuler",
    "manipulâmes": "manipuler",
    "manipulât": "manipuler",
    "manipulâtes": "manipuler",
    "manipulèrent": "manipuler",
    "manipulé": "manipuler",
    "manipulée": "manipuler",
    "manipulées": "manipuler",
    "manipulés": "manipuler",
    "maniques": "manique",
    "manitous": "manitou",
    "manivelles": "manivelle",
    "maniâmes": "manier",
    "maniât": "manier",
    "maniâtes": "manier",
    "manièrent": "manier",
    "manières": "manière",
    "manié": "manier",
    "maniée": "manier",
    "maniées": "manier",
    "maniérismes": "maniérisme",
    "maniéristes": "maniériste",
    "maniéré": "maniérer",
    "maniérée": "maniéré",
    "maniérées": "maniérer",
    "maniérés": "maniérer",
    "maniés": "manier",
    "mannequine": "mannequiner",
    "mannequins": "mannequin",
    "mannes": "manne",
    "manoeuvra": "manoeuvrer",
    "manoeuvrai": "manoeuvrer",
    "manoeuvraient": "manoeuvrer",
    "manoeuvrais": "manoeuvrer",
    "manoeuvrait": "manoeuvrer",
    "manoeuvrant": "manoeuvrer",
    "manoeuvras": "manoeuvrer",
    "manoeuvrasse": "manoeuvrer",
    "manoeuvrassent": "manoeuvrer",
    "manoeuvrasses": "manoeuvrer",
    "manoeuvrassiez": "manoeuvrer",
    "manoeuvrassions": "manoeuvrer",
    "manoeuvre": "manoeuvrer",
    "manoeuvrent": "manoeuvrer",
    "manoeuvrera": "manoeuvrer",
    "manoeuvrerai": "manoeuvrer",
    "manoeuvreraient": "manoeuvrer",
    "manoeuvrerais": "manoeuvrer",
    "manoeuvrerait": "manoeuvrer",
    "manoeuvreras": "manoeuvrer",
    "manoeuvrerez": "manoeuvrer",
    "manoeuvreriez": "manoeuvrer",
    "manoeuvrerions": "manoeuvrer",
    "manoeuvrerons": "manoeuvrer",
    "manoeuvreront": "manoeuvrer",
    "manoeuvres": "manoeuvrer",
    "manoeuvrez": "manoeuvrer",
    "manoeuvriers": "manoeuvrier",
    "manoeuvriez": "manoeuvrer",
    "manoeuvrions": "manoeuvrer",
    "manoeuvrière": "manoeuvrier",
    "manoeuvrières": "manoeuvrier",
    "manoeuvrons": "manoeuvrer",
    "manoeuvrâmes": "manoeuvrer",
    "manoeuvrât": "manoeuvrer",
    "manoeuvrâtes": "manoeuvrer",
    "manoeuvrèrent": "manoeuvrer",
    "manoeuvré": "manoeuvrer",
    "manoeuvrée": "manoeuvrer",
    "manoeuvrées": "manoeuvrer",
    "manoeuvrés": "manoeuvrer",
    "manoirs": "manoir",
    "manomètres": "manomètre",
    "manouches": "manouche",
    "manqua": "manquer",
    "manquai": "manquer",
    "manquaient": "manquer",
    "manquais": "manquer",
    "manquait": "manquer",
    "manquant": "manquer",
    "manquante": "manquant",
    "manquantes": "manquant",
    "manquants": "manquant",
    "manquas": "manquer",
    "manquasse": "manquer",
    "manquassent": "manquer",
    "manquasses": "manquer",
    "manquassiez": "manquer",
    "manquassions": "manquer",
    "manque": "manquer",
    "manquements": "manquement",
    "manquent": "manquer",
    "manquera": "manquer",
    "manquerai": "manquer",
    "manqueraient": "manquer",
    "manquerais": "manquer",
    "manquerait": "manquer",
    "manqueras": "manquer",
    "manquerez": "manquer",
    "manqueriez": "manquer",
    "manquerions": "manquer",
    "manquerons": "manquer",
    "manqueront": "manquer",
    "manques": "manquer",
    "manquez": "manquer",
    "manquiez": "manquer",
    "manquions": "manquer",
    "manquons": "manquer",
    "manquâmes": "manquer",
    "manquât": "manquer",
    "manquâtes": "manquer",
    "manquèrent": "manquer",
    "manqué": "manquer",
    "manquée": "manquer",
    "manquées": "manquer",
    "manqués": "manquer",
    "mansardes": "mansarde",
    "mansardé": "mansarder",
    "mansardée": "mansarder",
    "mansardées": "mansarder",
    "manses": "manse",
    "mansions": "mansion",
    "mansuétudes": "mansuétude",
    "manteaux": "manteau",
    "mantelets": "mantelet",
    "mantes": "mante",
    "mantilles": "mantille",
    "manucure": "manucurer",
    "manucures": "manucure",
    "manucuré": "manucurer",
    "manucurée": "manucurer",
    "manucurées": "manucurer",
    "manucurés": "manucurer",
    "manuelle": "manuel",
    "manuelles": "manuel",
    "manuels": "manuel",
    "manufactura": "manufacturer",
    "manufacturai": "manufacturer",
    "manufacturaient": "manufacturer",
    "manufacturais": "manufacturer",
    "manufacturait": "manufacturer",
    "manufacturant": "manufacturer",
    "manufacturas": "manufacturer",
    "manufacturasse": "manufacturer",
    "manufacturassent": "manufacturer",
    "manufacturasses": "manufacturer",
    "manufacturassiez": "manufacturer",
    "manufacturassions": "manufacturer",
    "manufacture": "manufacturer",
    "manufacturent": "manufacturer",
    "manufacturera": "manufacturer",
    "manufacturerai": "manufacturer",
    "manufactureraient": "manufacturer",
    "manufacturerais": "manufacturer",
    "manufacturerait": "manufacturer",
    "manufactureras": "manufacturer",
    "manufacturerez": "manufacturer",
    "manufactureriez": "manufacturer",
    "manufacturerions": "manufacturer",
    "manufacturerons": "manufacturer",
    "manufactureront": "manufacturer",
    "manufactures": "manufacturer",
    "manufacturez": "manufacturer",
    "manufacturiers": "manufacturier",
    "manufacturiez": "manufacturer",
    "manufacturions": "manufacturer",
    "manufacturière": "manufacturier",
    "manufacturières": "manufacturier",
    "manufacturons": "manufacturer",
    "manufacturâmes": "manufacturer",
    "manufacturât": "manufacturer",
    "manufacturâtes": "manufacturer",
    "manufacturèrent": "manufacturer",
    "manufacturé": "manufacturer",
    "manufacturée": "manufacturer",
    "manufacturées": "manufacturer",
    "manufacturés": "manufacturer",
    "manumissions": "manumission",
    "manuscrite": "manuscrit",
    "manuscrites": "manuscrit",
    "manuscrits": "manuscrit",
    "manutentionnaires": "manutentionnaire",
    "manutentions": "manutention",
    "manèges": "manège",
    "manécanteries": "manécanterie",
    "manégés": "manéger",
    "maorie": "maori",
    "maos": "mao",
    "maoïsmes": "maoïsme",
    "maoïstes": "maoïste",
    "mappemondes": "mappemonde",
    "maquaient": "maquer",
    "maque": "maquer",
    "maquent": "maquer",
    "maquereautins": "maquereautin",
    "maquereaux": "maquereau",
    "maquerelle": "maquereau",
    "maquerelles": "maquereau",
    "maques": "maquer",
    "maquettes": "maquette",
    "maquettistes": "maquettiste",
    "maquignonna": "maquignonner",
    "maquignonnages": "maquignonnage",
    "maquignonnai": "maquignonner",
    "maquignonnaient": "maquignonner",
    "maquignonnais": "maquignonner",
    "maquignonnait": "maquignonner",
    "maquignonnant": "maquignonner",
    "maquignonnas": "maquignonner",
    "maquignonnasse": "maquignonner",
    "maquignonnassent": "maquignonner",
    "maquignonnasses": "maquignonner",
    "maquignonnassiez": "maquignonner",
    "maquignonnassions": "maquignonner",
    "maquignonne": "maquignonner",
    "maquignonnent": "maquignonner",
    "maquignonnera": "maquignonner",
    "maquignonnerai": "maquignonner",
    "maquignonneraient": "maquignonner",
    "maquignonnerais": "maquignonner",
    "maquignonnerait": "maquignonner",
    "maquignonneras": "maquignonner",
    "maquignonnerez": "maquignonner",
    "maquignonneriez": "maquignonner",
    "maquignonnerions": "maquignonner",
    "maquignonnerons": "maquignonner",
    "maquignonneront": "maquignonner",
    "maquignonnes": "maquignonner",
    "maquignonnez": "maquignonner",
    "maquignonniez": "maquignonner",
    "maquignonnions": "maquignonner",
    "maquignonnons": "maquignonner",
    "maquignonnâmes": "maquignonner",
    "maquignonnât": "maquignonner",
    "maquignonnâtes": "maquignonner",
    "maquignonnèrent": "maquignonner",
    "maquignonné": "maquignonner",
    "maquignonnée": "maquignonner",
    "maquignonnées": "maquignonner",
    "maquignonnés": "maquignonner",
    "maquignons": "maquignon",
    "maquilla": "maquiller",
    "maquillages": "maquillage",
    "maquillai": "maquiller",
    "maquillaient": "maquiller",
    "maquillais": "maquiller",
    "maquillait": "maquiller",
    "maquillant": "maquiller",
    "maquillas": "maquiller",
    "maquillasse": "maquiller",
    "maquillassent": "maquiller",
    "maquillasses": "maquiller",
    "maquillassiez": "maquiller",
    "maquillassions": "maquiller",
    "maquille": "maquiller",
    "maquillent": "maquiller",
    "maquillera": "maquiller",
    "maquillerai": "maquiller",
    "maquilleraient": "maquiller",
    "maquillerais": "maquiller",
    "maquillerait": "maquiller",
    "maquilleras": "maquiller",
    "maquillerez": "maquiller",
    "maquilleriez": "maquiller",
    "maquillerions": "maquiller",
    "maquillerons": "maquiller",
    "maquilleront": "maquiller",
    "maquilles": "maquiller",
    "maquilleurs": "maquilleur",
    "maquilleuse": "maquilleur",
    "maquilleuses": "maquilleur",
    "maquillez": "maquiller",
    "maquilliez": "maquiller",
    "maquillions": "maquiller",
    "maquillons": "maquiller",
    "maquillâmes": "maquiller",
    "maquillât": "maquiller",
    "maquillâtes": "maquiller",
    "maquillèrent": "maquiller",
    "maquillé": "maquiller",
    "maquillée": "maquiller",
    "maquillées": "maquiller",
    "maquillés": "maquiller",
    "maquisarde": "maquisard",
    "maquisardes": "maquisard",
    "maquisards": "maquisard",
    "maqué": "maquer",
    "maquée": "maquer",
    "maqués": "maquer",
    "marabouts": "marabout",
    "maracas": "maraca",
    "marasmes": "marasme",
    "marathonienne": "marathonien",
    "marathons": "marathon",
    "marauda": "marauder",
    "maraudai": "marauder",
    "maraudaient": "marauder",
    "maraudais": "marauder",
    "maraudait": "marauder",
    "maraudant": "marauder",
    "maraudas": "marauder",
    "maraudasse": "marauder",
    "maraudassent": "marauder",
    "maraudasses": "marauder",
    "maraudassiez": "marauder",
    "maraudassions": "marauder",
    "maraude": "marauder",
    "maraudent": "marauder",
    "maraudera": "marauder",
    "marauderai": "marauder",
    "marauderaient": "marauder",
    "marauderais": "marauder",
    "marauderait": "marauder",
    "marauderas": "marauder",
    "marauderez": "marauder",
    "marauderiez": "marauder",
    "marauderions": "marauder",
    "marauderons": "marauder",
    "marauderont": "marauder",
    "maraudes": "marauder",
    "maraudeurs": "maraudeur",
    "maraudeuse": "maraudeur",
    "maraudez": "marauder",
    "maraudiez": "marauder",
    "maraudions": "marauder",
    "maraudons": "marauder",
    "marauds": "maraud",
    "maraudâmes": "marauder",
    "maraudât": "marauder",
    "maraudâtes": "marauder",
    "maraudèrent": "marauder",
    "maraudé": "marauder",
    "maraudés": "marauder",
    "maraîchers": "maraîcher",
    "maraîchère": "maraîcher",
    "maraîchères": "maraîcher",
    "marbra": "marbrer",
    "marbrai": "marbrer",
    "marbraient": "marbrer",
    "marbrais": "marbrer",
    "marbrait": "marbrer",
    "marbrant": "marbrer",
    "marbras": "marbrer",
    "marbrasse": "marbrer",
    "marbrassent": "marbrer",
    "marbrasses": "marbrer",
    "marbrassiez": "marbrer",
    "marbrassions": "marbrer",
    "marbre": "marbrer",
    "marbrent": "marbrer",
    "marbrera": "marbrer",
    "marbrerai": "marbrer",
    "marbreraient": "marbrer",
    "marbrerais": "marbrer",
    "marbrerait": "marbrer",
    "marbreras": "marbrer",
    "marbrerez": "marbrer",
    "marbreries": "marbrerie",
    "marbreriez": "marbrer",
    "marbrerions": "marbrer",
    "marbrerons": "marbrer",
    "marbreront": "marbrer",
    "marbres": "marbrer",
    "marbrez": "marbrer",
    "marbriez": "marbrer",
    "marbrions": "marbrer",
    "marbrons": "marbrer",
    "marbrures": "marbrure",
    "marbrâmes": "marbrer",
    "marbrât": "marbrer",
    "marbrâtes": "marbrer",
    "marbrèrent": "marbrer",
    "marbré": "marbrer",
    "marbrée": "marbrer",
    "marbrées": "marbrer",
    "marbrés": "marbrer",
    "marcassins": "marcassin",
    "marcha": "marcher",
    "marchai": "marcher",
    "marchaient": "marcher",
    "marchais": "marcher",
    "marchait": "marcher",
    "marchanda": "marchander",
    "marchandages": "marchandage",
    "marchandai": "marchander",
    "marchandaient": "marchander",
    "marchandais": "marchander",
    "marchandait": "marchander",
    "marchandant": "marchander",
    "marchandas": "marchander",
    "marchandasse": "marchander",
    "marchandassent": "marchander",
    "marchandasses": "marchander",
    "marchandassiez": "marchander",
    "marchandassions": "marchander",
    "marchande": "marchander",
    "marchandent": "marchander",
    "marchandera": "marchander",
    "marchanderai": "marchander",
    "marchanderaient": "marchander",
    "marchanderais": "marchander",
    "marchanderait": "marchander",
    "marchanderas": "marchander",
    "marchanderez": "marchander",
    "marchanderiez": "marchander",
    "marchanderions": "marchander",
    "marchanderons": "marchander",
    "marchanderont": "marchander",
    "marchandes": "marchander",
    "marchandeuse": "marchandeur",
    "marchandez": "marchander",
    "marchandiez": "marchander",
    "marchandions": "marchander",
    "marchandises": "marchandise",
    "marchandons": "marchander",
    "marchands": "marchand",
    "marchandâmes": "marchander",
    "marchandât": "marchander",
    "marchandâtes": "marchander",
    "marchandèrent": "marchander",
    "marchandé": "marchander",
    "marchandée": "marchander",
    "marchandées": "marchander",
    "marchandés": "marchander",
    "marchant": "marcher",
    "marchante": "marchant",
    "marchantes": "marchant",
    "marchas": "marcher",
    "marchasse": "marcher",
    "marchassent": "marcher",
    "marchasses": "marcher",
    "marchassiez": "marcher",
    "marchassions": "marcher",
    "marche": "marcher",
    "marchent": "marcher",
    "marchepieds": "marchepied",
    "marchera": "marcher",
    "marcherai": "marcher",
    "marcheraient": "marcher",
    "marcherais": "marcher",
    "marcherait": "marcher",
    "marcheras": "marcher",
    "marcherez": "marcher",
    "marcheriez": "marcher",
    "marcherions": "marcher",
    "marcherons": "marcher",
    "marcheront": "marcher",
    "marches": "marcher",
    "marcheurs": "marcheur",
    "marcheuse": "marcheur",
    "marcheuses": "marcheur",
    "marchez": "marcher",
    "marchiez": "marcher",
    "marchions": "marcher",
    "marchons": "marcher",
    "marchâmes": "marcher",
    "marchât": "marcher",
    "marchâtes": "marcher",
    "marchèrent": "marcher",
    "marché": "marcher",
    "marchées": "marcher",
    "marchés": "marcher",
    "marcottes": "marcotte",
    "marcs": "marc",
    "mardis": "mardi",
    "mare": "mar",
    "marelles": "marelle",
    "mares": "mare",
    "mareyeurs": "mareyeur",
    "mareyeuse": "mareyeur",
    "mareyeuses": "mareyeur",
    "margarines": "margarine",
    "margeait": "marger",
    "margelles": "margelle",
    "marges": "marge",
    "margeuse": "margeur",
    "margina": "marginer",
    "marginale": "marginal",
    "marginales": "marginal",
    "marginalisa": "marginaliser",
    "marginalisai": "marginaliser",
    "marginalisaient": "marginaliser",
    "marginalisais": "marginaliser",
    "marginalisait": "marginaliser",
    "marginalisant": "marginaliser",
    "marginalisas": "marginaliser",
    "marginalisasse": "marginaliser",
    "marginalisassent": "marginaliser",
    "marginalisasses": "marginaliser",
    "marginalisassiez": "marginaliser",
    "marginalisassions": "marginaliser",
    "marginalisations": "marginalisation",
    "marginalise": "marginaliser",
    "marginalisent": "marginaliser",
    "marginalisera": "marginaliser",
    "marginaliserai": "marginaliser",
    "marginaliseraient": "marginaliser",
    "marginaliserais": "marginaliser",
    "marginaliserait": "marginaliser",
    "marginaliseras": "marginaliser",
    "marginaliserez": "marginaliser",
    "marginaliseriez": "marginaliser",
    "marginaliserions": "marginaliser",
    "marginaliserons": "marginaliser",
    "marginaliseront": "marginaliser",
    "marginalises": "marginaliser",
    "marginalisez": "marginaliser",
    "marginalisiez": "marginaliser",
    "marginalisions": "marginaliser",
    "marginalisons": "marginaliser",
    "marginalisâmes": "marginaliser",
    "marginalisât": "marginaliser",
    "marginalisâtes": "marginaliser",
    "marginalisèrent": "marginaliser",
    "marginalisé": "marginaliser",
    "marginalisée": "marginaliser",
    "marginalisées": "marginaliser",
    "marginalisés": "marginaliser",
    "marginalités": "marginalité",
    "marginaux": "marginal",
    "marginée": "marginer",
    "margotait": "margoter",
    "margotins": "margotin",
    "margotte": "margotter",
    "margottons": "margotter",
    "margouillats": "margouillat",
    "margoulins": "margoulin",
    "marguerites": "marguerite",
    "marguilliers": "marguillier",
    "maria": "marier",
    "mariachis": "mariachi",
    "mariages": "mariage",
    "mariai": "marier",
    "mariaient": "marier",
    "mariais": "marier",
    "mariait": "marier",
    "mariale": "marial",
    "mariales": "marial",
    "marials": "marial",
    "marianne": "marian",
    "mariant": "marier",
    "marias": "marier",
    "mariasse": "marier",
    "mariassent": "marier",
    "mariasses": "marier",
    "mariassiez": "marier",
    "mariassions": "marier",
    "maridas": "marida",
    "marie": "marier",
    "marient": "marier",
    "mariera": "marier",
    "marierai": "marier",
    "marieraient": "marier",
    "marierais": "marier",
    "marierait": "marier",
    "marieras": "marier",
    "marierez": "marier",
    "marieriez": "marier",
    "marierions": "marier",
    "marierons": "marier",
    "marieront": "marier",
    "maries": "marier",
    "maries-salopes": "marie-salope",
    "marieuse": "marieur",
    "marieuses": "marieur",
    "mariez": "marier",
    "marigots": "marigot",
    "mariiez": "marier",
    "mariions": "marier",
    "marijuanas": "marijuana",
    "marina": "mariner",
    "marinades": "marinade",
    "marinai": "mariner",
    "marinaient": "mariner",
    "marinais": "mariner",
    "marinait": "mariner",
    "marinant": "mariner",
    "marinas": "mariner",
    "marinasse": "mariner",
    "marinassent": "mariner",
    "marinasses": "mariner",
    "marinassiez": "mariner",
    "marinassions": "mariner",
    "marine": "mariner",
    "marinent": "mariner",
    "marinera": "mariner",
    "marinerai": "mariner",
    "marineraient": "mariner",
    "marinerais": "mariner",
    "marinerait": "mariner",
    "marineras": "mariner",
    "marinerez": "mariner",
    "marineriez": "mariner",
    "marinerions": "mariner",
    "marinerons": "mariner",
    "marineront": "mariner",
    "marines": "mariner",
    "marinez": "mariner",
    "maringoins": "maringoin",
    "maringouins": "maringouin",
    "mariniers": "marinier",
    "mariniez": "mariner",
    "marinions": "mariner",
    "marinière": "marinier",
    "marinières": "marinière",
    "marinons": "mariner",
    "marins": "marin",
    "marinâmes": "mariner",
    "marinât": "mariner",
    "marinâtes": "mariner",
    "marinèrent": "mariner",
    "mariné": "mariner",
    "marinée": "mariner",
    "marinées": "mariner",
    "marinés": "mariner",
    "marioles": "mariole",
    "mariolles": "mariolle",
    "mariols": "mariol",
    "marionnettes": "marionnette",
    "marionnettistes": "marionnettiste",
    "marions": "marier",
    "maris": "mari",
    "maristes": "mariste",
    "maritale": "marital",
    "maritales": "marital",
    "maritaux": "marital",
    "maritimes": "maritime",
    "maritornes": "maritorne",
    "marivauda": "marivauder",
    "marivaudages": "marivaudage",
    "marivaudai": "marivauder",
    "marivaudaient": "marivauder",
    "marivaudais": "marivauder",
    "marivaudait": "marivauder",
    "marivaudant": "marivauder",
    "marivaudas": "marivauder",
    "marivaudasse": "marivauder",
    "marivaudassent": "marivauder",
    "marivaudasses": "marivauder",
    "marivaudassiez": "marivauder",
    "marivaudassions": "marivauder",
    "marivaude": "marivauder",
    "marivaudent": "marivauder",
    "marivaudera": "marivauder",
    "marivauderai": "marivauder",
    "marivauderaient": "marivauder",
    "marivauderais": "marivauder",
    "marivauderait": "marivauder",
    "marivauderas": "marivauder",
    "marivauderez": "marivauder",
    "marivauderiez": "marivauder",
    "marivauderions": "marivauder",
    "marivauderons": "marivauder",
    "marivauderont": "marivauder",
    "marivaudes": "marivauder",
    "marivaudez": "marivauder",
    "marivaudiez": "marivauder",
    "marivaudions": "marivauder",
    "marivaudons": "marivauder",
    "marivaudâmes": "marivauder",
    "marivaudât": "marivauder",
    "marivaudâtes": "marivauder",
    "marivaudèrent": "marivauder",
    "marivaudé": "marivauder",
    "mariâmes": "marier",
    "mariât": "marier",
    "mariâtes": "marier",
    "marièrent": "marier",
    "marié": "marier",
    "mariée": "marier",
    "mariées": "marier",
    "mariés": "marier",
    "marjolaines": "marjolaine",
    "marketings": "marketing",
    "marks": "mark",
    "marles": "marle",
    "marloupineries": "marloupinerie",
    "marloupins": "marloupin",
    "marlous": "marlou",
    "marmailles": "marmaille",
    "marmelades": "marmelade",
    "marmenteaux": "marmenteau",
    "marmitages": "marmitage",
    "marmites": "marmite",
    "marmiteuse": "marmiteux",
    "marmitons": "marmiton",
    "marmitées": "marmitée",
    "marmités": "marmiter",
    "marmonna": "marmonner",
    "marmonnai": "marmonner",
    "marmonnaient": "marmonner",
    "marmonnais": "marmonner",
    "marmonnait": "marmonner",
    "marmonnant": "marmonner",
    "marmonnas": "marmonner",
    "marmonnasse": "marmonner",
    "marmonnassent": "marmonner",
    "marmonnasses": "marmonner",
    "marmonnassiez": "marmonner",
    "marmonnassions": "marmonner",
    "marmonne": "marmonner",
    "marmonnements": "marmonnement",
    "marmonnent": "marmonner",
    "marmonnera": "marmonner",
    "marmonnerai": "marmonner",
    "marmonneraient": "marmonner",
    "marmonnerais": "marmonner",
    "marmonnerait": "marmonner",
    "marmonneras": "marmonner",
    "marmonnerez": "marmonner",
    "marmonneriez": "marmonner",
    "marmonnerions": "marmonner",
    "marmonnerons": "marmonner",
    "marmonneront": "marmonner",
    "marmonnes": "marmonner",
    "marmonnez": "marmonner",
    "marmonniez": "marmonner",
    "marmonnions": "marmonner",
    "marmonnons": "marmonner",
    "marmonnâmes": "marmonner",
    "marmonnât": "marmonner",
    "marmonnâtes": "marmonner",
    "marmonnèrent": "marmonner",
    "marmonné": "marmonner",
    "marmonnée": "marmonner",
    "marmonnées": "marmonner",
    "marmonnés": "marmonner",
    "marmoréenne": "marmoréen",
    "marmoréennes": "marmoréen",
    "marmoréens": "marmoréen",
    "marmots": "marmot",
    "marmotta": "marmotter",
    "marmottages": "marmottage",
    "marmottai": "marmotter",
    "marmottaient": "marmotter",
    "marmottais": "marmotter",
    "marmottait": "marmotter",
    "marmottant": "marmotter",
    "marmottas": "marmotter",
    "marmottasse": "marmotter",
    "marmottassent": "marmotter",
    "marmottasses": "marmotter",
    "marmottassiez": "marmotter",
    "marmottassions": "marmotter",
    "marmotte": "marmotter",
    "marmottent": "marmotter",
    "marmottera": "marmotter",
    "marmotterai": "marmotter",
    "marmotteraient": "marmotter",
    "marmotterais": "marmotter",
    "marmotterait": "marmotter",
    "marmotteras": "marmotter",
    "marmotterez": "marmotter",
    "marmotteriez": "marmotter",
    "marmotterions": "marmotter",
    "marmotterons": "marmotter",
    "marmotteront": "marmotter",
    "marmottes": "marmotter",
    "marmottez": "marmotter",
    "marmottiez": "marmotter",
    "marmottions": "marmotter",
    "marmottons": "marmotter",
    "marmottâmes": "marmotter",
    "marmottât": "marmotter",
    "marmottâtes": "marmotter",
    "marmottèrent": "marmotter",
    "marmotté": "marmotter",
    "marmottée": "marmotter",
    "marmottées": "marmotter",
    "marmottés": "marmotter",
    "marmousets": "marmouset",
    "marna": "marner",
    "marnaise": "marnais",
    "marnait": "marner",
    "marne": "marner",
    "marnent": "marner",
    "marnes": "marne",
    "marneuse": "marneux",
    "marnières": "marnière",
    "marné": "marner",
    "marocaine": "marocain",
    "marocaines": "marocain",
    "marocains": "marocain",
    "maronites": "maronite",
    "maronna": "maronner",
    "maronnai": "maronner",
    "maronnaient": "maronner",
    "maronnais": "maronner",
    "maronnait": "maronner",
    "maronnant": "maronner",
    "maronnas": "maronner",
    "maronnasse": "maronner",
    "maronnassent": "maronner",
    "maronnasses": "maronner",
    "maronnassiez": "maronner",
    "maronnassions": "maronner",
    "maronne": "maronner",
    "maronnent": "maronner",
    "maronnera": "maronner",
    "maronnerai": "maronner",
    "maronneraient": "maronner",
    "maronnerais": "maronner",
    "maronnerait": "maronner",
    "maronneras": "maronner",
    "maronnerez": "maronner",
    "maronneriez": "maronner",
    "maronnerions": "maronner",
    "maronnerons": "maronner",
    "maronneront": "maronner",
    "maronnes": "maronner",
    "maronnez": "maronner",
    "maronniez": "maronner",
    "maronnions": "maronner",
    "maronnons": "maronner",
    "maronnâmes": "maronner",
    "maronnât": "maronner",
    "maronnâtes": "maronner",
    "maronnèrent": "maronner",
    "maronné": "maronner",
    "maronnée": "maronner",
    "maronnées": "maronner",
    "maronnés": "maronner",
    "maroquineries": "maroquinerie",
    "maroquiniers": "maroquinier",
    "maroquins": "maroquin",
    "marottes": "marotte",
    "maroufles": "maroufle",
    "marqua": "marquer",
    "marquages": "marquage",
    "marquai": "marquer",
    "marquaient": "marquer",
    "marquais": "marquer",
    "marquait": "marquer",
    "marquant": "marquer",
    "marquante": "marquant",
    "marquantes": "marquant",
    "marquants": "marquant",
    "marquas": "marquer",
    "marquasse": "marquer",
    "marquassent": "marquer",
    "marquasses": "marquer",
    "marquassiez": "marquer",
    "marquassions": "marquer",
    "marque": "marquer",
    "marque-pages": "marque-page",
    "marquent": "marquer",
    "marquera": "marquer",
    "marquerai": "marquer",
    "marqueraient": "marquer",
    "marquerais": "marquer",
    "marquerait": "marquer",
    "marqueras": "marquer",
    "marquerez": "marquer",
    "marqueriez": "marquer",
    "marquerions": "marquer",
    "marquerons": "marquer",
    "marqueront": "marquer",
    "marques": "marquer",
    "marqueta": "marqueter",
    "marquetai": "marqueter",
    "marquetaient": "marqueter",
    "marquetais": "marqueter",
    "marquetait": "marqueter",
    "marquetant": "marqueter",
    "marquetas": "marqueter",
    "marquetasse": "marqueter",
    "marquetassent": "marqueter",
    "marquetasses": "marqueter",
    "marquetassiez": "marqueter",
    "marquetassions": "marqueter",
    "marqueteries": "marqueterie",
    "marquetez": "marqueter",
    "marquetiez": "marqueter",
    "marquetions": "marqueter",
    "marquetons": "marqueter",
    "marquette": "marqueter",
    "marquettent": "marqueter",
    "marquettera": "marqueter",
    "marquetterai": "marqueter",
    "marquetteraient": "marqueter",
    "marquetterais": "marqueter",
    "marquetterait": "marqueter",
    "marquetteras": "marqueter",
    "marquetterez": "marqueter",
    "marquetteriez": "marqueter",
    "marquetterions": "marqueter",
    "marquetterons": "marqueter",
    "marquetteront": "marqueter",
    "marquettes": "marqueter",
    "marquetâmes": "marqueter",
    "marquetât": "marqueter",
    "marquetâtes": "marqueter",
    "marquetèrent": "marqueter",
    "marqueté": "marqueter",
    "marquetée": "marqueter",
    "marquetées": "marqueter",
    "marquetés": "marqueter",
    "marqueurs": "marqueur",
    "marquez": "marquer",
    "marquiez": "marquer",
    "marquions": "marquer",
    "marquisats": "marquisat",
    "marquise": "marquis",
    "marquises": "marquis",
    "marquisiens": "marquisien",
    "marquons": "marquer",
    "marquâmes": "marquer",
    "marquât": "marquer",
    "marquâtes": "marquer",
    "marquèrent": "marquer",
    "marqué": "marquer",
    "marquée": "marquer",
    "marquées": "marquer",
    "marqués": "marquer",
    "marra": "marrer",
    "marrai": "marrer",
    "marraient": "marrer",
    "marraines": "marraine",
    "marrais": "marrer",
    "marrait": "marrer",
    "marranes": "marrane",
    "marrant": "marrer",
    "marrante": "marrant",
    "marrantes": "marrant",
    "marrants": "marrant",
    "marras": "marrer",
    "marrasse": "marrer",
    "marrassent": "marrer",
    "marrasses": "marrer",
    "marrassiez": "marrer",
    "marrassions": "marrer",
    "marre": "marrer",
    "marrent": "marrer",
    "marrera": "marrer",
    "marrerai": "marrer",
    "marreraient": "marrer",
    "marrerais": "marrer",
    "marrerait": "marrer",
    "marreras": "marrer",
    "marrerez": "marrer",
    "marreriez": "marrer",
    "marrerions": "marrer",
    "marrerons": "marrer",
    "marreront": "marrer",
    "marres": "marrer",
    "marrez": "marrer",
    "marrie": "marri",
    "marries": "marri",
    "marriez": "marrer",
    "marrions": "marrer",
    "marris": "marri",
    "marronnais": "marronner",
    "marronne": "marron",
    "marronnera": "marronner",
    "marronnes": "marron",
    "marronniers": "marronnier",
    "marronné": "marronner",
    "marrons": "marron",
    "marrâmes": "marrer",
    "marrât": "marrer",
    "marrâtes": "marrer",
    "marrèrent": "marrer",
    "marré": "marrer",
    "marrée": "marrer",
    "marrées": "marrer",
    "marrés": "marrer",
    "marsaules": "marsaule",
    "marseillaise": "marseillais",
    "marseillaises": "marseillais",
    "marshals": "marshal",
    "marsouins": "marsouin",
    "marsupiaux": "marsupial",
    "marsupilamis": "marsupilami",
    "marteaux": "marteau",
    "marteaux-pilons": "marteau-pilon",
    "martela": "marteler",
    "martelages": "martelage",
    "martelai": "marteler",
    "martelaient": "marteler",
    "martelais": "marteler",
    "martelait": "marteler",
    "martelant": "marteler",
    "martelas": "marteler",
    "martelasse": "marteler",
    "martelassent": "marteler",
    "martelasses": "marteler",
    "martelassiez": "marteler",
    "martelassions": "marteler",
    "martelez": "marteler",
    "marteliez": "marteler",
    "martelions": "marteler",
    "martelons": "marteler",
    "martels": "martel",
    "martelâmes": "marteler",
    "martelât": "marteler",
    "martelâtes": "marteler",
    "martelèrent": "marteler",
    "martelé": "marteler",
    "martelée": "marteler",
    "martelées": "marteler",
    "martelés": "marteler",
    "martes": "marte",
    "martiale": "martial",
    "martiales": "martial",
    "martialités": "martialité",
    "martiaux": "martial",
    "martienne": "martien",
    "martiennes": "martienne",
    "martiens": "martien",
    "martine": "martiner",
    "martinets": "martinet",
    "martinez": "martiner",
    "martingales": "martingale",
    "martiniquaise": "martiniquais",
    "martiniquaises": "martiniquais",
    "martinis": "martini",
    "martins": "martin",
    "martins-chasseurs": "martin-chasseur",
    "martins-pêcheurs": "martin-pêcheur",
    "martres": "martre",
    "martyre": "martyr",
    "martyres": "martyre",
    "martyrisaient": "martyriser",
    "martyrisait": "martyriser",
    "martyrisant": "martyriser",
    "martyrise": "martyriser",
    "martyrisent": "martyriser",
    "martyriserait": "martyriser",
    "martyrisé": "martyriser",
    "martyrisée": "martyriser",
    "martyrisées": "martyriser",
    "martyrisés": "martyriser",
    "martyrologes": "martyrologe",
    "martyrs": "martyr",
    "martèle": "marteler",
    "martèlements": "martèlement",
    "martèlent": "marteler",
    "martèlera": "marteler",
    "martèlerai": "marteler",
    "martèleraient": "marteler",
    "martèlerais": "marteler",
    "martèlerait": "marteler",
    "martèleras": "marteler",
    "martèlerez": "marteler",
    "martèleriez": "marteler",
    "martèlerions": "marteler",
    "martèlerons": "marteler",
    "martèleront": "marteler",
    "martèles": "marteler",
    "marxismes": "marxisme",
    "marxistes": "marxiste",
    "marxistes-léninistes": "marxiste-léniniste",
    "marylands": "maryland",
    "marâtres": "marâtre",
    "marécages": "marécage",
    "marécageuse": "marécageux",
    "marécageuses": "marécageux",
    "maréchale": "maréchal",
    "maréchaleries": "maréchalerie",
    "maréchalismes": "maréchalisme",
    "maréchalistes": "maréchaliste",
    "maréchaussées": "maréchaussée",
    "maréchaux": "maréchal",
    "maréchaux-ferrants": "maréchal-ferrant",
    "marées": "marée",
    "marémotrice": "marémoteur",
    "mascarades": "mascarade",
    "mascarets": "mascaret",
    "mascarons": "mascaron",
    "mascottes": "mascotte",
    "masculine": "masculin",
    "masculines": "masculin",
    "masculinisa": "masculiniser",
    "masculinisai": "masculiniser",
    "masculinisaient": "masculiniser",
    "masculinisais": "masculiniser",
    "masculinisait": "masculiniser",
    "masculinisant": "masculiniser",
    "masculinisas": "masculiniser",
    "masculinisasse": "masculiniser",
    "masculinisassent": "masculiniser",
    "masculinisasses": "masculiniser",
    "masculinisassiez": "masculiniser",
    "masculinisassions": "masculiniser",
    "masculinise": "masculiniser",
    "masculinisent": "masculiniser",
    "masculinisera": "masculiniser",
    "masculiniserai": "masculiniser",
    "masculiniseraient": "masculiniser",
    "masculiniserais": "masculiniser",
    "masculiniserait": "masculiniser",
    "masculiniseras": "masculiniser",
    "masculiniserez": "masculiniser",
    "masculiniseriez": "masculiniser",
    "masculiniserions": "masculiniser",
    "masculiniserons": "masculiniser",
    "masculiniseront": "masculiniser",
    "masculinises": "masculiniser",
    "masculinisez": "masculiniser",
    "masculinisiez": "masculiniser",
    "masculinisions": "masculiniser",
    "masculinisons": "masculiniser",
    "masculinisâmes": "masculiniser",
    "masculinisât": "masculiniser",
    "masculinisâtes": "masculiniser",
    "masculinisèrent": "masculiniser",
    "masculinisé": "masculiniser",
    "masculinisée": "masculiniser",
    "masculinisées": "masculiniser",
    "masculinisés": "masculiniser",
    "masculins": "masculin",
    "masochismes": "masochisme",
    "masochistes": "masochiste",
    "masos": "maso",
    "masqua": "masquer",
    "masquages": "masquage",
    "masquai": "masquer",
    "masquaient": "masquer",
    "masquais": "masquer",
    "masquait": "masquer",
    "masquant": "masquer",
    "masquas": "masquer",
    "masquasse": "masquer",
    "masquassent": "masquer",
    "masquasses": "masquer",
    "masquassiez": "masquer",
    "masquassions": "masquer",
    "masque": "masquer",
    "masquent": "masquer",
    "masquera": "masquer",
    "masquerai": "masquer",
    "masqueraient": "masquer",
    "masquerais": "masquer",
    "masquerait": "masquer",
    "masqueras": "masquer",
    "masquerez": "masquer",
    "masqueriez": "masquer",
    "masquerions": "masquer",
    "masquerons": "masquer",
    "masqueront": "masquer",
    "masques": "masquer",
    "masquez": "masquer",
    "masquiez": "masquer",
    "masquions": "masquer",
    "masquons": "masquer",
    "masquâmes": "masquer",
    "masquât": "masquer",
    "masquâtes": "masquer",
    "masquèrent": "masquer",
    "masqué": "masquer",
    "masquée": "masquer",
    "masquées": "masquer",
    "masqués": "masquer",
    "massa": "masser",
    "massacra": "massacrer",
    "massacrai": "massacrer",
    "massacraient": "massacrer",
    "massacrais": "massacrer",
    "massacrait": "massacrer",
    "massacrant": "massacrer",
    "massacrante": "massacrant",
    "massacras": "massacrer",
    "massacrasse": "massacrer",
    "massacrassent": "massacrer",
    "massacrasses": "massacrer",
    "massacrassiez": "massacrer",
    "massacrassions": "massacrer",
    "massacre": "massacrer",
    "massacrent": "massacrer",
    "massacrera": "massacrer",
    "massacrerai": "massacrer",
    "massacreraient": "massacrer",
    "massacrerais": "massacrer",
    "massacrerait": "massacrer",
    "massacreras": "massacrer",
    "massacrerez": "massacrer",
    "massacreriez": "massacrer",
    "massacrerions": "massacrer",
    "massacrerons": "massacrer",
    "massacreront": "massacrer",
    "massacres": "massacrer",
    "massacreurs": "massacreur",
    "massacrez": "massacrer",
    "massacriez": "massacrer",
    "massacrions": "massacrer",
    "massacrons": "massacrer",
    "massacrâmes": "massacrer",
    "massacrât": "massacrer",
    "massacrâtes": "massacrer",
    "massacrèrent": "massacrer",
    "massacré": "massacrer",
    "massacrée": "massacrer",
    "massacrées": "massacrer",
    "massacrés": "massacrer",
    "massages": "massage",
    "massai": "masser",
    "massaient": "masser",
    "massais": "masser",
    "massait": "masser",
    "massant": "masser",
    "massas": "masser",
    "massasse": "masser",
    "massassent": "masser",
    "massasses": "masser",
    "massassiez": "masser",
    "massassions": "masser",
    "masse": "masser",
    "massent": "masser",
    "massepains": "massepain",
    "massera": "masser",
    "masserai": "masser",
    "masseraient": "masser",
    "masserais": "masser",
    "masserait": "masser",
    "masseras": "masser",
    "masserez": "masser",
    "masseriez": "masser",
    "masserions": "masser",
    "masserons": "masser",
    "masseront": "masser",
    "masses": "masser",
    "massettes": "massette",
    "masseurs": "masseur",
    "masseuse": "masseur",
    "masseuses": "masseur",
    "massez": "masser",
    "massicota": "massicoter",
    "massicotai": "massicoter",
    "massicotaient": "massicoter",
    "massicotais": "massicoter",
    "massicotait": "massicoter",
    "massicotant": "massicoter",
    "massicotas": "massicoter",
    "massicotasse": "massicoter",
    "massicotassent": "massicoter",
    "massicotasses": "massicoter",
    "massicotassiez": "massicoter",
    "massicotassions": "massicoter",
    "massicote": "massicoter",
    "massicotent": "massicoter",
    "massicotera": "massicoter",
    "massicoterai": "massicoter",
    "massicoteraient": "massicoter",
    "massicoterais": "massicoter",
    "massicoterait": "massicoter",
    "massicoteras": "massicoter",
    "massicoterez": "massicoter",
    "massicoteriez": "massicoter",
    "massicoterions": "massicoter",
    "massicoterons": "massicoter",
    "massicoteront": "massicoter",
    "massicotes": "massicoter",
    "massicotez": "massicoter",
    "massicotiez": "massicoter",
    "massicotions": "massicoter",
    "massicotons": "massicoter",
    "massicots": "massicot",
    "massicotâmes": "massicoter",
    "massicotât": "massicoter",
    "massicotâtes": "massicoter",
    "massicotèrent": "massicoter",
    "massicoté": "massicoter",
    "massicotée": "massicoter",
    "massicotées": "massicoter",
    "massicotés": "massicoter",
    "massiers": "massier",
    "massiez": "masser",
    "massifs": "massif",
    "massions": "masser",
    "massive": "massif",
    "massives": "massif",
    "massons": "masser",
    "massues": "massue",
    "massâmes": "masser",
    "massât": "masser",
    "massâtes": "masser",
    "massèrent": "masser",
    "massé": "masser",
    "massée": "masser",
    "massées": "masser",
    "massés": "masser",
    "masséters": "masséter",
    "mastabas": "mastaba",
    "mastards": "mastard",
    "masters": "master",
    "masticages": "masticage",
    "masticateurs": "masticateur",
    "mastications": "mastication",
    "mastics": "mastic",
    "mastiqua": "mastiquer",
    "mastiquai": "mastiquer",
    "mastiquaient": "mastiquer",
    "mastiquais": "mastiquer",
    "mastiquait": "mastiquer",
    "mastiquant": "mastiquer",
    "mastiquas": "mastiquer",
    "mastiquasse": "mastiquer",
    "mastiquassent": "mastiquer",
    "mastiquasses": "mastiquer",
    "mastiquassiez": "mastiquer",
    "mastiquassions": "mastiquer",
    "mastique": "mastiquer",
    "mastiquent": "mastiquer",
    "mastiquera": "mastiquer",
    "mastiquerai": "mastiquer",
    "mastiqueraient": "mastiquer",
    "mastiquerais": "mastiquer",
    "mastiquerait": "mastiquer",
    "mastiqueras": "mastiquer",
    "mastiquerez": "mastiquer",
    "mastiqueriez": "mastiquer",
    "mastiquerions": "mastiquer",
    "mastiquerons": "mastiquer",
    "mastiqueront": "mastiquer",
    "mastiques": "mastiquer",
    "mastiquez": "mastiquer",
    "mastiquiez": "mastiquer",
    "mastiquions": "mastiquer",
    "mastiquons": "mastiquer",
    "mastiquâmes": "mastiquer",
    "mastiquât": "mastiquer",
    "mastiquâtes": "mastiquer",
    "mastiquèrent": "mastiquer",
    "mastiqué": "mastiquer",
    "mastiquée": "mastiquer",
    "mastiquées": "mastiquer",
    "mastiqués": "mastiquer",
    "mastites": "mastite",
    "mastodontes": "mastodonte",
    "mastoïdes": "mastoïde",
    "mastroquets": "mastroquet",
    "masturba": "masturber",
    "masturbai": "masturber",
    "masturbaient": "masturber",
    "masturbais": "masturber",
    "masturbait": "masturber",
    "masturbant": "masturber",
    "masturbas": "masturber",
    "masturbasse": "masturber",
    "masturbassent": "masturber",
    "masturbasses": "masturber",
    "masturbassiez": "masturber",
    "masturbassions": "masturber",
    "masturbations": "masturbation",
    "masturbatoires": "masturbatoire",
    "masturbe": "masturber",
    "masturbent": "masturber",
    "masturbera": "masturber",
    "masturberai": "masturber",
    "masturberaient": "masturber",
    "masturberais": "masturber",
    "masturberait": "masturber",
    "masturberas": "masturber",
    "masturberez": "masturber",
    "masturberiez": "masturber",
    "masturberions": "masturber",
    "masturberons": "masturber",
    "masturberont": "masturber",
    "masturbes": "masturber",
    "masturbez": "masturber",
    "masturbiez": "masturber",
    "masturbions": "masturber",
    "masturbons": "masturber",
    "masturbâmes": "masturber",
    "masturbât": "masturber",
    "masturbâtes": "masturber",
    "masturbèrent": "masturber",
    "masturbé": "masturber",
    "masturbée": "masturber",
    "masturbées": "masturber",
    "masturbés": "masturber",
    "masures": "masure",
    "mat'": "mat",
    "mata": "mater",
    "matadors": "matador",
    "matafs": "mataf",
    "matai": "mater",
    "mataient": "mater",
    "matais": "mater",
    "matait": "mater",
    "matamores": "matamore",
    "matant": "mater",
    "matas": "mater",
    "matasse": "mater",
    "matassent": "mater",
    "matasses": "mater",
    "matassiez": "mater",
    "matassions": "mater",
    "matcha": "matcher",
    "matche": "matcher",
    "matches": "matche",
    "matchs": "match",
    "mate": "mater",
    "matelassa": "matelasser",
    "matelassai": "matelasser",
    "matelassaient": "matelasser",
    "matelassais": "matelasser",
    "matelassait": "matelasser",
    "matelassant": "matelasser",
    "matelassas": "matelasser",
    "matelassasse": "matelasser",
    "matelassassent": "matelasser",
    "matelassasses": "matelasser",
    "matelassassiez": "matelasser",
    "matelassassions": "matelasser",
    "matelasse": "matelasser",
    "matelassent": "matelasser",
    "matelassera": "matelasser",
    "matelasserai": "matelasser",
    "matelasseraient": "matelasser",
    "matelasserais": "matelasser",
    "matelasserait": "matelasser",
    "matelasseras": "matelasser",
    "matelasserez": "matelasser",
    "matelasseriez": "matelasser",
    "matelasserions": "matelasser",
    "matelasserons": "matelasser",
    "matelasseront": "matelasser",
    "matelasses": "matelasser",
    "matelassez": "matelasser",
    "matelassiers": "matelassier",
    "matelassiez": "matelasser",
    "matelassions": "matelasser",
    "matelassière": "matelassier",
    "matelassières": "matelassier",
    "matelassons": "matelasser",
    "matelassâmes": "matelasser",
    "matelassât": "matelasser",
    "matelassâtes": "matelasser",
    "matelassèrent": "matelasser",
    "matelassé": "matelasser",
    "matelassée": "matelasser",
    "matelassées": "matelasser",
    "matelassés": "matelasser",
    "matelotes": "matelote",
    "matelots": "matelot",
    "matent": "mater",
    "matera": "mater",
    "materai": "mater",
    "materaient": "mater",
    "materais": "mater",
    "materait": "mater",
    "materas": "mater",
    "materez": "mater",
    "materiez": "mater",
    "materions": "mater",
    "maternant": "materner",
    "maternelle": "maternel",
    "maternelles": "maternelle",
    "maternels": "maternel",
    "maternera": "materner",
    "maternisé": "materniser",
    "maternisée": "maternisé",
    "maternisées": "maternisé",
    "maternisés": "maternisé",
    "maternités": "maternité",
    "materné": "materner",
    "materons": "mater",
    "materont": "mater",
    "mates": "mater",
    "mateurs": "mateur",
    "mateuse": "mateur",
    "matez": "mater",
    "matheuse": "matheux",
    "matheuses": "matheux",
    "mathurins": "mathurin",
    "mathusalems": "mathusalem",
    "mathématicienne": "mathématicien",
    "mathématiciennes": "mathématicien",
    "mathématiciens": "mathématicien",
    "mathématiques": "mathématique",
    "mati": "matir",
    "matie": "matir",
    "maties": "matir",
    "matiez": "mater",
    "matinale": "matinal",
    "matinales": "matinal",
    "matinaux": "matinal",
    "matines": "mâtine",
    "matins": "matin",
    "matinées": "matinée",
    "mations": "mater",
    "matira": "matir",
    "matirai": "matir",
    "matiraient": "matir",
    "matirais": "matir",
    "matirait": "matir",
    "matiras": "matir",
    "matirent": "matir",
    "matirez": "matir",
    "matiriez": "matir",
    "matirions": "matir",
    "matirons": "matir",
    "matiront": "matir",
    "matis": "matir",
    "matissaient": "matir",
    "matissais": "matir",
    "matissait": "matir",
    "matissant": "matir",
    "matisse": "matir",
    "matissent": "matir",
    "matisses": "matir",
    "matissez": "matir",
    "matissiez": "matir",
    "matissions": "matir",
    "matissons": "matir",
    "matit": "matir",
    "matités": "matité",
    "matières": "matière",
    "matoise": "matois",
    "matoises": "matois",
    "matonne": "maton",
    "matonnes": "maton",
    "matons": "maton",
    "matorrals": "matorral",
    "matous": "matou",
    "matouse": "matouser",
    "matraqua": "matraquer",
    "matraquages": "matraquage",
    "matraquai": "matraquer",
    "matraquaient": "matraquer",
    "matraquais": "matraquer",
    "matraquait": "matraquer",
    "matraquant": "matraquer",
    "matraquas": "matraquer",
    "matraquasse": "matraquer",
    "matraquassent": "matraquer",
    "matraquasses": "matraquer",
    "matraquassiez": "matraquer",
    "matraquassions": "matraquer",
    "matraque": "matraquer",
    "matraquent": "matraquer",
    "matraquera": "matraquer",
    "matraquerai": "matraquer",
    "matraqueraient": "matraquer",
    "matraquerais": "matraquer",
    "matraquerait": "matraquer",
    "matraqueras": "matraquer",
    "matraquerez": "matraquer",
    "matraqueriez": "matraquer",
    "matraquerions": "matraquer",
    "matraquerons": "matraquer",
    "matraqueront": "matraquer",
    "matraques": "matraquer",
    "matraqueurs": "matraqueur",
    "matraquez": "matraquer",
    "matraquiez": "matraquer",
    "matraquions": "matraquer",
    "matraquons": "matraquer",
    "matraquâmes": "matraquer",
    "matraquât": "matraquer",
    "matraquâtes": "matraquer",
    "matraquèrent": "matraquer",
    "matraqué": "matraquer",
    "matraquée": "matraquer",
    "matraquées": "matraquer",
    "matraqués": "matraquer",
    "matriarcale": "matriarcal",
    "matriarcales": "matriarcal",
    "matriarcats": "matriarcat",
    "matriarcaux": "matriarcal",
    "matrices": "matrice",
    "matricielle": "matriciel",
    "matricielles": "matriciel",
    "matriciels": "matriciel",
    "matricules": "matricule",
    "matrilinéaires": "matrilinéaire",
    "matrilocale": "matrilocal",
    "matrilocales": "matrilocal",
    "matrilocaux": "matrilocal",
    "matrimoniale": "matrimonial",
    "matrimoniales": "matrimonial",
    "matrimoniaux": "matrimonial",
    "matrones": "matrone",
    "matronymes": "matronyme",
    "mats": "mat",
    "mattes": "matte",
    "maturations": "maturation",
    "matures": "mature",
    "maturités": "maturité",
    "matutinale": "matutinal",
    "matutinales": "matutinal",
    "matutinaux": "matutinal",
    "matâmes": "mater",
    "matât": "mater",
    "matâtes": "mater",
    "matèrent": "mater",
    "maté": "mater",
    "matée": "mater",
    "matées": "mater",
    "matérialisa": "matérialiser",
    "matérialisai": "matérialiser",
    "matérialisaient": "matérialiser",
    "matérialisais": "matérialiser",
    "matérialisait": "matérialiser",
    "matérialisant": "matérialiser",
    "matérialisas": "matérialiser",
    "matérialisasse": "matérialiser",
    "matérialisassent": "matérialiser",
    "matérialisasses": "matérialiser",
    "matérialisassiez": "matérialiser",
    "matérialisassions": "matérialiser",
    "matérialisations": "matérialisation",
    "matérialise": "matérialiser",
    "matérialisent": "matérialiser",
    "matérialisera": "matérialiser",
    "matérialiserai": "matérialiser",
    "matérialiseraient": "matérialiser",
    "matérialiserais": "matérialiser",
    "matérialiserait": "matérialiser",
    "matérialiseras": "matérialiser",
    "matérialiserez": "matérialiser",
    "matérialiseriez": "matérialiser",
    "matérialiserions": "matérialiser",
    "matérialiserons": "matérialiser",
    "matérialiseront": "matérialiser",
    "matérialises": "matérialiser",
    "matérialisez": "matérialiser",
    "matérialisiez": "matérialiser",
    "matérialisions": "matérialiser",
    "matérialismes": "matérialisme",
    "matérialisons": "matérialiser",
    "matérialistes": "matérialiste",
    "matérialisâmes": "matérialiser",
    "matérialisât": "matérialiser",
    "matérialisâtes": "matérialiser",
    "matérialisèrent": "matérialiser",
    "matérialisé": "matérialiser",
    "matérialisée": "matérialiser",
    "matérialisées": "matérialiser",
    "matérialisés": "matérialiser",
    "matérialités": "matérialité",
    "matériaux": "matériau",
    "matérielle": "matériel",
    "matérielles": "matériel",
    "matériels": "matériel",
    "matés": "mater",
    "matîmes": "matir",
    "matît": "matir",
    "matîtes": "matir",
    "maudira": "maudire",
    "maudirai": "maudire",
    "maudiraient": "maudire",
    "maudirais": "maudire",
    "maudirait": "maudire",
    "maudiras": "maudire",
    "maudirent": "maudire",
    "maudirez": "maudire",
    "maudiriez": "maudire",
    "maudirions": "maudire",
    "maudirons": "maudire",
    "maudiront": "maudire",
    "maudis": "maudire",
    "maudissaient": "maudire",
    "maudissais": "maudire",
    "maudissait": "maudire",
    "maudissant": "maudire",
    "maudisse": "maudire",
    "maudissent": "maudire",
    "maudisses": "maudire",
    "maudissez": "maudire",
    "maudissiez": "maudire",
    "maudissions": "maudire",
    "maudissons": "maudire",
    "maudit": "maudire",
    "maudite": "maudit",
    "maudites": "maudit",
    "maudits": "maudit",
    "maudîmes": "maudire",
    "maudît": "maudire",
    "maudîtes": "maudire",
    "maugréa": "maugréer",
    "maugréai": "maugréer",
    "maugréaient": "maugréer",
    "maugréais": "maugréer",
    "maugréait": "maugréer",
    "maugréant": "maugréer",
    "maugréas": "maugréer",
    "maugréasse": "maugréer",
    "maugréassent": "maugréer",
    "maugréasses": "maugréer",
    "maugréassiez": "maugréer",
    "maugréassions": "maugréer",
    "maugrée": "maugréer",
    "maugréent": "maugréer",
    "maugréera": "maugréer",
    "maugréerai": "maugréer",
    "maugréeraient": "maugréer",
    "maugréerais": "maugréer",
    "maugréerait": "maugréer",
    "maugréeras": "maugréer",
    "maugréerez": "maugréer",
    "maugréeriez": "maugréer",
    "maugréerions": "maugréer",
    "maugréerons": "maugréer",
    "maugréeront": "maugréer",
    "maugrées": "maugréer",
    "maugréez": "maugréer",
    "maugréiez": "maugréer",
    "maugréions": "maugréer",
    "maugréons": "maugréer",
    "maugréâmes": "maugréer",
    "maugréât": "maugréer",
    "maugréâtes": "maugréer",
    "maugréèrent": "maugréer",
    "maugréé": "maugréer",
    "maugréée": "maugréer",
    "maugréées": "maugréer",
    "maugréés": "maugréer",
    "maures": "maure",
    "mauresques": "mauresque",
    "mauricienne": "mauricien",
    "mauriciennes": "mauricien",
    "mauriciens": "mauricien",
    "mauritanienne": "mauritanien",
    "mauritaniens": "mauritanien",
    "mauroyistes": "mauroyiste",
    "maurrassienne": "maurrassien",
    "maurrassiennes": "maurrassien",
    "maurrassiens": "maurrassien",
    "mausers": "mauser",
    "mausolées": "mausolée",
    "maussaderies": "maussaderie",
    "maussades": "maussade",
    "mauvaise": "mauvais",
    "mauvaises": "mauvais",
    "mauves": "mauve",
    "mauviettes": "mauviette",
    "maux": "mal",
    "maxillaires": "maxillaire",
    "maxima": "maximum",
    "maximale": "maximal",
    "maximales": "maximal",
    "maximalise": "maximaliser",
    "maximalismes": "maximalisme",
    "maximalistes": "maximaliste",
    "maximaux": "maximal",
    "maximes": "maxime",
    "maximisa": "maximiser",
    "maximisai": "maximiser",
    "maximisaient": "maximiser",
    "maximisais": "maximiser",
    "maximisait": "maximiser",
    "maximisant": "maximiser",
    "maximisas": "maximiser",
    "maximisasse": "maximiser",
    "maximisassent": "maximiser",
    "maximisasses": "maximiser",
    "maximisassiez": "maximiser",
    "maximisassions": "maximiser",
    "maximise": "maximiser",
    "maximisent": "maximiser",
    "maximisera": "maximiser",
    "maximiserai": "maximiser",
    "maximiseraient": "maximiser",
    "maximiserais": "maximiser",
    "maximiserait": "maximiser",
    "maximiseras": "maximiser",
    "maximiserez": "maximiser",
    "maximiseriez": "maximiser",
    "maximiserions": "maximiser",
    "maximiserons": "maximiser",
    "maximiseront": "maximiser",
    "maximises": "maximiser",
    "maximisez": "maximiser",
    "maximisiez": "maximiser",
    "maximisions": "maximiser",
    "maximisons": "maximiser",
    "maximisâmes": "maximiser",
    "maximisât": "maximiser",
    "maximisâtes": "maximiser",
    "maximisèrent": "maximiser",
    "maximisé": "maximiser",
    "maximisée": "maximiser",
    "maximisées": "maximiser",
    "maximisés": "maximiser",
    "maximums": "maximum",
    "maxis": "maxi",
    "mayas": "maya",
    "mayonnaises": "mayonnaise",
    "mazagrans": "mazagran",
    "mazarinades": "mazarinade",
    "mazas": "mazer",
    "mazdéens": "mazdéen",
    "maze": "mazer",
    "mazettes": "mazette",
    "mazouts": "mazout",
    "mazouté": "mazouter",
    "mazoutés": "mazouté",
    "mazurkas": "mazurka",
    "mazé": "mazer",
    "maçonna": "maçonner",
    "maçonnai": "maçonner",
    "maçonnaient": "maçonner",
    "maçonnais": "maçonner",
    "maçonnait": "maçonner",
    "maçonnant": "maçonner",
    "maçonnas": "maçonner",
    "maçonnasse": "maçonner",
    "maçonnassent": "maçonner",
    "maçonnasses": "maçonner",
    "maçonnassiez": "maçonner",
    "maçonnassions": "maçonner",
    "maçonne": "maçonner",
    "maçonnent": "maçonner",
    "maçonnera": "maçonner",
    "maçonnerai": "maçonner",
    "maçonneraient": "maçonner",
    "maçonnerais": "maçonner",
    "maçonnerait": "maçonner",
    "maçonneras": "maçonner",
    "maçonnerez": "maçonner",
    "maçonneries": "maçonnerie",
    "maçonneriez": "maçonner",
    "maçonnerions": "maçonner",
    "maçonnerons": "maçonner",
    "maçonneront": "maçonner",
    "maçonnes": "maçonner",
    "maçonnez": "maçonner",
    "maçonniez": "maçonner",
    "maçonnions": "maçonner",
    "maçonniques": "maçonnique",
    "maçonnons": "maçonner",
    "maçonnâmes": "maçonner",
    "maçonnât": "maçonner",
    "maçonnâtes": "maçonner",
    "maçonnèrent": "maçonner",
    "maçonné": "maçonner",
    "maçonnée": "maçonner",
    "maçonnées": "maçonner",
    "maçonnés": "maçonner",
    "maçons": "maçon",
    "maëlstroms": "maëlstrom",
    "maître-assistante": "maître-assistant",
    "maîtres": "maître",
    "maîtres-assistantes": "maître-assistant",
    "maîtres-assistants": "maître-assistant",
    "maîtres-autels": "maître-autel",
    "maîtres-auxiliaires": "maître-auxiliaire",
    "maîtres-à-danser": "maître-à-danser",
    "maîtresse": "maître",
    "maîtresses": "maîtresse",
    "maîtrisa": "maîtriser",
    "maîtrisables": "maîtrisable",
    "maîtrisai": "maîtriser",
    "maîtrisaient": "maîtriser",
    "maîtrisais": "maîtriser",
    "maîtrisait": "maîtriser",
    "maîtrisant": "maîtriser",
    "maîtrisas": "maîtriser",
    "maîtrisasse": "maîtriser",
    "maîtrisassent": "maîtriser",
    "maîtrisasses": "maîtriser",
    "maîtrisassiez": "maîtriser",
    "maîtrisassions": "maîtriser",
    "maîtrise": "maîtriser",
    "maîtrisent": "maîtriser",
    "maîtrisera": "maîtriser",
    "maîtriserai": "maîtriser",
    "maîtriseraient": "maîtriser",
    "maîtriserais": "maîtriser",
    "maîtriserait": "maîtriser",
    "maîtriseras": "maîtriser",
    "maîtriserez": "maîtriser",
    "maîtriseriez": "maîtriser",
    "maîtriserions": "maîtriser",
    "maîtriserons": "maîtriser",
    "maîtriseront": "maîtriser",
    "maîtrises": "maîtriser",
    "maîtrisez": "maîtriser",
    "maîtrisiez": "maîtriser",
    "maîtrisions": "maîtriser",
    "maîtrisons": "maîtriser",
    "maîtrisâmes": "maîtriser",
    "maîtrisât": "maîtriser",
    "maîtrisâtes": "maîtriser",
    "maîtrisèrent": "maîtriser",
    "maîtrisé": "maîtriser",
    "maîtrisée": "maîtriser",
    "maîtrisées": "maîtriser",
    "maîtrisés": "maîtriser",
    "maïeutiques": "maïeutique",
    "me": "se",
    "meccanos": "meccano",
    "mechtas": "mechta",
    "mecs": "mec",
    "mectons": "mecton",
    "medersas": "medersa",
    "medias": "media",
    "medicine-balls": "medicine-ball",
    "meetings": "meeting",
    "megawatts": "megawatt",
    "meilleure": "meilleur",
    "meilleures": "meilleur",
    "meilleurs": "meilleur",
    "melkites": "melkite",
    "melliflues": "melliflue",
    "mellifères": "mellifère",
    "melonnières": "melonnière",
    "melons": "melon",
    "melting pot": "melting-pot",
    "melting-pots": "melting-pot",
    "membranes": "membrane",
    "membraneuse": "membraneux",
    "membraneuses": "membraneux",
    "membres": "membre",
    "membrues": "membru",
    "membrures": "membrure",
    "membré": "membrer",
    "memoranda": "memorandum",
    "mena": "mener",
    "menace": "menacer",
    "menacent": "menacer",
    "menacera": "menacer",
    "menacerai": "menacer",
    "menaceraient": "menacer",
    "menacerais": "menacer",
    "menacerait": "menacer",
    "menaceras": "menacer",
    "menacerez": "menacer",
    "menaceriez": "menacer",
    "menacerions": "menacer",
    "menacerons": "menacer",
    "menaceront": "menacer",
    "menaces": "menacer",
    "menacez": "menacer",
    "menaciez": "menacer",
    "menacions": "menacer",
    "menacèrent": "menacer",
    "menacé": "menacer",
    "menacée": "menacer",
    "menacées": "menacer",
    "menacés": "menacer",
    "menai": "mener",
    "menaient": "mener",
    "menais": "mener",
    "menait": "mener",
    "menant": "mener",
    "menas": "mener",
    "menasse": "mener",
    "menassent": "mener",
    "menasses": "mener",
    "menassiez": "mener",
    "menassions": "mener",
    "menaça": "menacer",
    "menaçai": "menacer",
    "menaçaient": "menacer",
    "menaçais": "menacer",
    "menaçait": "menacer",
    "menaçant": "menacer",
    "menaçante": "menaçant",
    "menaçantes": "menaçant",
    "menaçants": "menaçant",
    "menaças": "menacer",
    "menaçasse": "menacer",
    "menaçassent": "menacer",
    "menaçasses": "menacer",
    "menaçassiez": "menacer",
    "menaçassions": "menacer",
    "menaçons": "menacer",
    "menaçâmes": "menacer",
    "menaçât": "menacer",
    "menaçâtes": "menacer",
    "mencheviks": "menchevik",
    "mendia": "mendier",
    "mendiai": "mendier",
    "mendiaient": "mendier",
    "mendiais": "mendier",
    "mendiait": "mendier",
    "mendiant": "mendier",
    "mendiante": "mendiant",
    "mendiantes": "mendiant",
    "mendiants": "mendiant",
    "mendias": "mendier",
    "mendiasse": "mendier",
    "mendiassent": "mendier",
    "mendiasses": "mendier",
    "mendiassiez": "mendier",
    "mendiassions": "mendier",
    "mendicités": "mendicité",
    "mendie": "mendier",
    "mendient": "mendier",
    "mendiera": "mendier",
    "mendierai": "mendier",
    "mendieraient": "mendier",
    "mendierais": "mendier",
    "mendierait": "mendier",
    "mendieras": "mendier",
    "mendierez": "mendier",
    "mendieriez": "mendier",
    "mendierions": "mendier",
    "mendierons": "mendier",
    "mendieront": "mendier",
    "mendies": "mendier",
    "mendiez": "mendier",
    "mendigotant": "mendigoter",
    "mendigote": "mendigot",
    "mendigotes": "mendigot",
    "mendigots": "mendigot",
    "mendiiez": "mendier",
    "mendiions": "mendier",
    "mendions": "mendier",
    "mendiâmes": "mendier",
    "mendiât": "mendier",
    "mendiâtes": "mendier",
    "mendièrent": "mendier",
    "mendié": "mendier",
    "mendiée": "mendier",
    "mendiées": "mendier",
    "mendiés": "mendier",
    "meneaux": "meneau",
    "meneurs": "meneur",
    "meneuse": "meneur",
    "meneuses": "meneur",
    "menez": "mener",
    "menhirs": "menhir",
    "meniez": "mener",
    "menine": "menin",
    "menines": "menin",
    "menins": "menin",
    "menions": "mener",
    "mennonites": "mennonite",
    "menons": "menon",
    "menottes": "menotte",
    "menottez": "menotter",
    "menotté": "menotter",
    "menottée": "menotter",
    "menottés": "menotter",
    "mens": "mentir",
    "mensongers": "mensonger",
    "mensonges": "mensonge",
    "mensongère": "mensonger",
    "mensongères": "mensonger",
    "menstruations": "menstruation",
    "menstruelle": "menstruel",
    "menstruelles": "menstruel",
    "menstruels": "menstruel",
    "mensualités": "mensualité",
    "mensuelle": "mensuel",
    "mensuelles": "mensuel",
    "mensuels": "mensuel",
    "mensurations": "mensuration",
    "ment": "mentir",
    "mentaient": "mentir",
    "mentais": "mentir",
    "mentait": "mentir",
    "mentale": "mental",
    "mentales": "mental",
    "mentalités": "mentalité",
    "mentant": "mentir",
    "mentaux": "mental",
    "mente": "mentir",
    "mentent": "mentir",
    "menteries": "menterie",
    "mentes": "mentir",
    "menteurs": "menteur",
    "menteuse": "menteur",
    "menteuses": "menteur",
    "mentez": "mentir",
    "menthes": "menthe",
    "menthols": "menthol",
    "mentholée": "mentholé",
    "mentholées": "mentholé",
    "mentholés": "mentholé",
    "menti": "mentir",
    "mentiez": "mentir",
    "mentionna": "mentionner",
    "mentionnai": "mentionner",
    "mentionnaient": "mentionner",
    "mentionnais": "mentionner",
    "mentionnait": "mentionner",
    "mentionnant": "mentionner",
    "mentionnas": "mentionner",
    "mentionnasse": "mentionner",
    "mentionnassent": "mentionner",
    "mentionnasses": "mentionner",
    "mentionnassiez": "mentionner",
    "mentionnassions": "mentionner",
    "mentionne": "mentionner",
    "mentionnent": "mentionner",
    "mentionnera": "mentionner",
    "mentionnerai": "mentionner",
    "mentionneraient": "mentionner",
    "mentionnerais": "mentionner",
    "mentionnerait": "mentionner",
    "mentionneras": "mentionner",
    "mentionnerez": "mentionner",
    "mentionneriez": "mentionner",
    "mentionnerions": "mentionner",
    "mentionnerons": "mentionner",
    "mentionneront": "mentionner",
    "mentionnes": "mentionner",
    "mentionnez": "mentionner",
    "mentionniez": "mentionner",
    "mentionnions": "mentionner",
    "mentionnons": "mentionner",
    "mentionnâmes": "mentionner",
    "mentionnât": "mentionner",
    "mentionnâtes": "mentionner",
    "mentionnèrent": "mentionner",
    "mentionné": "mentionner",
    "mentionnée": "mentionner",
    "mentionnées": "mentionner",
    "mentionnés": "mentionner",
    "mentions": "mentir",
    "mentira": "mentir",
    "mentirai": "mentir",
    "mentiraient": "mentir",
    "mentirais": "mentir",
    "mentirait": "mentir",
    "mentiras": "mentir",
    "mentirent": "mentir",
    "mentirez": "mentir",
    "mentiriez": "mentir",
    "mentirions": "mentir",
    "mentirons": "mentir",
    "mentiront": "mentir",
    "mentis": "mentir",
    "mentisse": "mentir",
    "mentissent": "mentir",
    "mentisses": "mentir",
    "mentissiez": "mentir",
    "mentissions": "mentir",
    "mentit": "mentir",
    "mentonnière": "mentonnier",
    "mentonnières": "mentonnière",
    "mentons": "menton",
    "mentors": "mentor",
    "mentîmes": "mentir",
    "mentît": "mentir",
    "mentîtes": "mentir",
    "menue": "menu",
    "menues": "menu",
    "menuets": "menuet",
    "menuisa": "menuiser",
    "menuisai": "menuiser",
    "menuisaient": "menuiser",
    "menuisais": "menuiser",
    "menuisait": "menuiser",
    "menuisant": "menuiser",
    "menuisas": "menuiser",
    "menuisasse": "menuiser",
    "menuisassent": "menuiser",
    "menuisasses": "menuiser",
    "menuisassiez": "menuiser",
    "menuisassions": "menuiser",
    "menuise": "menuiser",
    "menuisent": "menuiser",
    "menuisera": "menuiser",
    "menuiserai": "menuiser",
    "menuiseraient": "menuiser",
    "menuiserais": "menuiser",
    "menuiserait": "menuiser",
    "menuiseras": "menuiser",
    "menuiserez": "menuiser",
    "menuiseries": "menuiserie",
    "menuiseriez": "menuiser",
    "menuiserions": "menuiser",
    "menuiserons": "menuiser",
    "menuiseront": "menuiser",
    "menuises": "menuiser",
    "menuisez": "menuiser",
    "menuisiers": "menuisier",
    "menuisiez": "menuiser",
    "menuisions": "menuiser",
    "menuisons": "menuiser",
    "menuisâmes": "menuiser",
    "menuisât": "menuiser",
    "menuisâtes": "menuiser",
    "menuisèrent": "menuiser",
    "menuisé": "menuiser",
    "menuisée": "menuiser",
    "menuisées": "menuiser",
    "menuisés": "menuiser",
    "menus": "menu",
    "menus-vairs": "menu-vair",
    "menâmes": "mener",
    "menât": "mener",
    "menâtes": "mener",
    "menèrent": "mener",
    "mené": "mener",
    "menée": "mener",
    "menées": "mener",
    "menés": "mener",
    "mercantiles": "mercantile",
    "mercantilismes": "mercantilisme",
    "mercantis": "mercanti",
    "mercenaires": "mercenaire",
    "merceries": "mercerie",
    "mercerisé": "merceriser",
    "merchandisings": "merchandising",
    "merciers": "mercier",
    "mercis": "merci",
    "mercière": "mercier",
    "mercières": "mercier",
    "mercredis": "mercredi",
    "mercures": "mercure",
    "mercuriales": "mercuriale",
    "merda": "merder",
    "merdait": "merder",
    "merde": "merder",
    "merdent": "merder",
    "merderai": "merder",
    "merdes": "merder",
    "merdeuse": "merdeux",
    "merdeuses": "merdeux",
    "merdez": "merder",
    "merdiers": "merdier",
    "merdiques": "merdique",
    "merdoie": "merdoyer",
    "merdouillé": "merdouiller",
    "merdoyait": "merdoyer",
    "merdé": "merder",
    "merdée": "merder",
    "meringues": "meringue",
    "meringué": "meringuer",
    "meringuée": "meringuer",
    "meringuées": "meringuer",
    "merises": "merise",
    "merisiers": "merisier",
    "merlans": "merlan",
    "merles": "merle",
    "merlins": "merlin",
    "merlots": "merlot",
    "merluches": "merluche",
    "merlus": "merlu",
    "mermazienne": "mermazien",
    "mermaziennes": "mermazien",
    "mermaziens": "mermazien",
    "merrains": "merrain",
    "mers": "mer",
    "merveilles": "merveille",
    "merveilleuse": "merveilleux",
    "merveilleuses": "merveilleux",
    "mes": "mon",
    "mescalines": "mescaline",
    "mesdames": "madame",
    "mesdemoiselles": "mademoiselle",
    "mesnils": "mesnil",
    "mesquine": "mesquin",
    "mesquineries": "mesquinerie",
    "mesquines": "mesquin",
    "mesquins": "mesquin",
    "messageries": "messagerie",
    "messagers": "messager",
    "messages": "message",
    "messagère": "messager",
    "messagères": "messager",
    "messalistes": "messaliste",
    "messeigneurs": "monseigneur",
    "messes": "messe",
    "messeyaient": "messeoir",
    "messeyait": "messeoir",
    "messianiques": "messianique",
    "messianismes": "messianisme",
    "messidors": "messidor",
    "messied": "messeoir",
    "messies": "messie",
    "messieurs": "monsieur",
    "messine": "messin",
    "messires": "messire",
    "messiée": "messeoir",
    "messiéent": "messeoir",
    "messiéra": "messeoir",
    "messiéraient": "messeoir",
    "messiérait": "messeoir",
    "messiéront": "messeoir",
    "messéant": "messeoir",
    "mesura": "mesurer",
    "mesurables": "mesurable",
    "mesurages": "mesurage",
    "mesurai": "mesurer",
    "mesuraient": "mesurer",
    "mesurais": "mesurer",
    "mesurait": "mesurer",
    "mesurant": "mesurer",
    "mesuras": "mesurer",
    "mesurasse": "mesurer",
    "mesurassent": "mesurer",
    "mesurasses": "mesurer",
    "mesurassiez": "mesurer",
    "mesurassions": "mesurer",
    "mesure": "mesurer",
    "mesurent": "mesurer",
    "mesurera": "mesurer",
    "mesurerai": "mesurer",
    "mesureraient": "mesurer",
    "mesurerais": "mesurer",
    "mesurerait": "mesurer",
    "mesureras": "mesurer",
    "mesurerez": "mesurer",
    "mesureriez": "mesurer",
    "mesurerions": "mesurer",
    "mesurerons": "mesurer",
    "mesureront": "mesurer",
    "mesures": "mesurer",
    "mesurez": "mesurer",
    "mesuriez": "mesurer",
    "mesurions": "mesurer",
    "mesurons": "mesuron",
    "mesurâmes": "mesurer",
    "mesurât": "mesurer",
    "mesurâtes": "mesurer",
    "mesurèrent": "mesurer",
    "mesuré": "mesurer",
    "mesurée": "mesurer",
    "mesurées": "mesurer",
    "mesurés": "mesurer",
    "met": "mettre",
    "mets": "mettre",
    "mettaient": "mettre",
    "mettais": "mettre",
    "mettait": "mettre",
    "mettant": "mettre",
    "mette": "mettre",
    "mettent": "mettre",
    "mettes": "mettre",
    "metteurs": "metteur",
    "metteuse": "metteur",
    "mettez": "mettre",
    "mettiez": "mettre",
    "mettions": "mettre",
    "mettons": "mettre",
    "mettra": "mettre",
    "mettrai": "mettre",
    "mettraient": "mettre",
    "mettrais": "mettre",
    "mettrait": "mettre",
    "mettras": "mettre",
    "mettrez": "mettre",
    "mettriez": "mettre",
    "mettrions": "mettre",
    "mettrons": "mettre",
    "mettront": "mettre",
    "meubla": "meubler",
    "meublai": "meubler",
    "meublaient": "meubler",
    "meublais": "meubler",
    "meublait": "meubler",
    "meublant": "meubler",
    "meublas": "meubler",
    "meublasse": "meubler",
    "meublassent": "meubler",
    "meublasses": "meubler",
    "meublassiez": "meubler",
    "meublassions": "meubler",
    "meuble": "meubler",
    "meublent": "meubler",
    "meublera": "meubler",
    "meublerai": "meubler",
    "meubleraient": "meubler",
    "meublerais": "meubler",
    "meublerait": "meubler",
    "meubleras": "meubler",
    "meublerez": "meubler",
    "meubleriez": "meubler",
    "meublerions": "meubler",
    "meublerons": "meubler",
    "meubleront": "meubler",
    "meubles": "meubler",
    "meublez": "meubler",
    "meubliez": "meubler",
    "meublions": "meubler",
    "meublons": "meubler",
    "meublâmes": "meubler",
    "meublât": "meubler",
    "meublâtes": "meubler",
    "meublèrent": "meubler",
    "meublé": "meubler",
    "meublée": "meubler",
    "meublées": "meubler",
    "meublés": "meubler",
    "meufs": "meuf",
    "meugla": "meugler",
    "meuglai": "meugler",
    "meuglaient": "meugler",
    "meuglais": "meugler",
    "meuglait": "meugler",
    "meuglant": "meugler",
    "meuglas": "meugler",
    "meuglasse": "meugler",
    "meuglassent": "meugler",
    "meuglasses": "meugler",
    "meuglassiez": "meugler",
    "meuglassions": "meugler",
    "meugle": "meugler",
    "meuglements": "meuglement",
    "meuglent": "meugler",
    "meuglera": "meugler",
    "meuglerai": "meugler",
    "meugleraient": "meugler",
    "meuglerais": "meugler",
    "meuglerait": "meugler",
    "meugleras": "meugler",
    "meuglerez": "meugler",
    "meugleriez": "meugler",
    "meuglerions": "meugler",
    "meuglerons": "meugler",
    "meugleront": "meugler",
    "meugles": "meugler",
    "meuglez": "meugler",
    "meugliez": "meugler",
    "meuglions": "meugler",
    "meuglons": "meugler",
    "meuglâmes": "meugler",
    "meuglât": "meugler",
    "meuglâtes": "meugler",
    "meuglèrent": "meugler",
    "meuglé": "meugler",
    "meuglée": "meugler",
    "meuglées": "meugler",
    "meuglés": "meugler",
    "meule": "meuler",
    "meules": "meuler",
    "meulez": "meuler",
    "meulière": "meulier",
    "meulières": "meulier",
    "meuneries": "meunerie",
    "meuniers": "meunier",
    "meunière": "meunier",
    "meunières": "meunier",
    "meure": "mourir",
    "meurent": "mourir",
    "meures": "mourir",
    "meurettes": "meurette",
    "meurs": "mourir",
    "meurt": "mourir",
    "meurtres": "meurtre",
    "meurtri": "meurtrir",
    "meurtrie": "meurtrir",
    "meurtriers": "meurtrier",
    "meurtries": "meurtrir",
    "meurtrira": "meurtrir",
    "meurtrirai": "meurtrir",
    "meurtriraient": "meurtrir",
    "meurtrirais": "meurtrir",
    "meurtrirait": "meurtrir",
    "meurtriras": "meurtrir",
    "meurtrirent": "meurtrir",
    "meurtrirez": "meurtrir",
    "meurtririez": "meurtrir",
    "meurtririons": "meurtrir",
    "meurtrirons": "meurtrir",
    "meurtriront": "meurtrir",
    "meurtris": "meurtrir",
    "meurtrissaient": "meurtrir",
    "meurtrissais": "meurtrir",
    "meurtrissait": "meurtrir",
    "meurtrissant": "meurtrir",
    "meurtrisse": "meurtrir",
    "meurtrissent": "meurtrir",
    "meurtrisses": "meurtrir",
    "meurtrissez": "meurtrir",
    "meurtrissiez": "meurtrir",
    "meurtrissions": "meurtrir",
    "meurtrissons": "meurtrir",
    "meurtrissures": "meurtrissure",
    "meurtrit": "meurtrir",
    "meurtrière": "meurtrier",
    "meurtrières": "meurtrier",
    "meurtrîmes": "meurtrir",
    "meurtrît": "meurtrir",
    "meurtrîtes": "meurtrir",
    "meus": "mouvoir",
    "meusienne": "meusien",
    "meusiennes": "meusienne",
    "meusiens": "meusien",
    "meut": "mouvoir",
    "meutes": "meute",
    "meuve": "mouvoir",
    "meuvent": "mouvoir",
    "meuves": "mouvoir",
    "mexicaine": "mexicain",
    "mexicaines": "mexicain",
    "mexicains": "mexicain",
    "mezzanines": "mezzanine",
    "mezzo-sopranos": "mezzo-soprano",
    "mezzos": "mezzo",
    "mi-appointées": "mi-appointé",
    "mi-braconniers": "mi-braconnier",
    "mi-bureaucrates": "mi-bureaucrate",
    "mi-carrière": "mi-carrier",
    "mi-carêmes": "mi-carême",
    "mi-châtaigniers": "mi-châtaignier",
    "mi-chênes": "mi-chêne",
    "mi-close": "mi-clos",
    "mi-closes": "mi-clos",
    "mi-complices": "mi-complice",
    "mi-confondus": "mi-confondu",
    "mi-connue": "mi-connu",
    "mi-contrariés": "mi-contrarié",
    "mi-cousine": "mi-cousin",
    "mi-cousins": "mi-cousin",
    "mi-cuisses": "mi-cuisse",
    "mi-effrayée": "mi-effrayé",
    "mi-effrayés": "mi-effrayé",
    "mi-enjouée": "mi-enjoué",
    "mi-goguenarde": "mi-goguenard",
    "mi-goélands": "mi-goéland",
    "mi-graves": "mi-grave",
    "mi-grossières": "mi-grossier",
    "mi-historiques": "mi-historique",
    "mi-images": "mi-image",
    "mi-indignée": "mi-indigné",
    "mi-inquiète": "mi-inquiet",
    "mi-ironiques": "mi-ironique",
    "mi-jambes": "mi-jambe",
    "mi-jaunes": "mi-jaune",
    "mi-lourds": "mi-lourd",
    "mi-machines": "mi-machine",
    "mi-marécages": "mi-marécage",
    "mi-menaçante": "mi-menaçant",
    "mi-mots": "mi-mot",
    "mi-moyens": "mi-moyen",
    "mi-obscure": "mi-obscur",
    "mi-partie": "mi-parti",
    "mi-parties": "mi-parti",
    "mi-partis": "mi-parti",
    "mi-pensées": "mi-pensée",
    "mi-plombiers": "mi-plombier",
    "mi-pêcheurs": "mi-pêcheur",
    "mi-respectueuse": "mi-respectueux",
    "mi-scientifiques": "mi-scientifique",
    "mi-sidérée": "mi-sidéré",
    "mi-souriante": "mi-souriant",
    "mi-éveillée": "mi-éveillé",
    "miaous": "miaou",
    "miasmes": "miasme",
    "miaula": "miauler",
    "miaulai": "miauler",
    "miaulaient": "miauler",
    "miaulais": "miauler",
    "miaulait": "miauler",
    "miaulant": "miauler",
    "miaulas": "miauler",
    "miaulasse": "miauler",
    "miaulassent": "miauler",
    "miaulasses": "miauler",
    "miaulassiez": "miauler",
    "miaulassions": "miauler",
    "miaule": "miauler",
    "miaulements": "miaulement",
    "miaulent": "miauler",
    "miaulera": "miauler",
    "miaulerai": "miauler",
    "miauleraient": "miauler",
    "miaulerais": "miauler",
    "miaulerait": "miauler",
    "miauleras": "miauler",
    "miaulerez": "miauler",
    "miauleriez": "miauler",
    "miaulerions": "miauler",
    "miaulerons": "miauler",
    "miauleront": "miauler",
    "miaules": "miauler",
    "miaulez": "miauler",
    "miauliez": "miauler",
    "miaulions": "miauler",
    "miaulons": "miauler",
    "miaulâmes": "miauler",
    "miaulât": "miauler",
    "miaulâtes": "miauler",
    "miaulèrent": "miauler",
    "miaulé": "miauler",
    "micacées": "micacé",
    "micas": "mica",
    "micelles": "micelle",
    "miches": "miche",
    "michetonnais": "michetonner",
    "michetonne": "michetonner",
    "michetonnes": "michetonner",
    "michetonneuses": "michetonneuse",
    "michetons": "micheton",
    "michés": "miché",
    "mickeys": "mickey",
    "micmacs": "micmac",
    "micocouliers": "micocoulier",
    "micro-ordinateurs": "micro-ordinateur",
    "micro-organismes": "micro-organisme",
    "microbes": "microbe",
    "microbienne": "microbien",
    "microbiennes": "microbien",
    "microbiens": "microbien",
    "microbiologies": "microbiologie",
    "microbiologiques": "microbiologique",
    "microcircuits": "microcircuit",
    "microclimats": "microclimat",
    "microcomposants": "microcomposant",
    "microcosmes": "microcosme",
    "microcycles": "microcycle",
    "microcéphales": "microcéphale",
    "microfiches": "microfiche",
    "microfilms": "microfilm",
    "microgrammes": "microgramme",
    "microgravités": "microgravité",
    "microlithes": "microlithe",
    "micromètres": "micromètre",
    "microns": "micron",
    "microorganismes": "microorganisme",
    "microphones": "microphone",
    "microprocesseurs": "microprocesseur",
    "microprojets": "microprojet",
    "microquotas": "microquota",
    "microréalisations": "microréalisation",
    "micros": "micro",
    "microscopes": "microscope",
    "microscopiques": "microscopique",
    "microsecondes": "microseconde",
    "microsillons": "microsillon",
    "microstructures": "microstructure",
    "microsystèmes": "microsystème",
    "microélectroniques": "microélectronique",
    "mictions": "miction",
    "midinettes": "midinette",
    "midis": "midi",
    "midships": "midship",
    "mielleuse": "mielleux",
    "mielleuses": "mielleux",
    "miellée": "miellé",
    "miellées": "miellé",
    "miels": "miel",
    "mienne": "mien",
    "miennes": "mien",
    "miens": "mien",
    "mies": "mie",
    "miettes": "miette",
    "migmatites": "migmatite",
    "mignardant": "mignarder",
    "mignarde": "mignarder",
    "mignardes": "mignard",
    "mignardises": "mignardise",
    "mignards": "mignard",
    "mignardé": "mignarder",
    "mignonne": "mignon",
    "mignonnes": "mignon",
    "mignonnets": "mignonnet",
    "mignonnette": "mignonnet",
    "mignonnettes": "mignonnette",
    "mignons": "mignon",
    "mignoteront": "mignoter",
    "mignoté": "mignoter",
    "migra": "migrer",
    "migrai": "migrer",
    "migraient": "migrer",
    "migraines": "migraine",
    "migrais": "migrer",
    "migrait": "migrer",
    "migrant": "migrer",
    "migrante": "migrant",
    "migrantes": "migrant",
    "migrants": "migrant",
    "migras": "migrer",
    "migrasse": "migrer",
    "migrassent": "migrer",
    "migrasses": "migrer",
    "migrassiez": "migrer",
    "migrassions": "migrer",
    "migrateurs": "migrateur",
    "migrations": "migration",
    "migratoires": "migratoire",
    "migratrice": "migrateur",
    "migratrices": "migrateur",
    "migre": "migrer",
    "migrent": "migrer",
    "migrera": "migrer",
    "migrerai": "migrer",
    "migreraient": "migrer",
    "migrerais": "migrer",
    "migrerait": "migrer",
    "migreras": "migrer",
    "migrerez": "migrer",
    "migreriez": "migrer",
    "migrerions": "migrer",
    "migrerons": "migrer",
    "migreront": "migrer",
    "migres": "migrer",
    "migrez": "migrer",
    "migriez": "migrer",
    "migrions": "migrer",
    "migrons": "migrer",
    "migrâmes": "migrer",
    "migrât": "migrer",
    "migrâtes": "migrer",
    "migrèrent": "migrer",
    "migré": "migrer",
    "migrée": "migrer",
    "migrées": "migrer",
    "migrés": "migrer",
    "mijaurées": "mijaurée",
    "mijota": "mijoter",
    "mijotai": "mijoter",
    "mijotaient": "mijoter",
    "mijotais": "mijoter",
    "mijotait": "mijoter",
    "mijotant": "mijoter",
    "mijotas": "mijoter",
    "mijotasse": "mijoter",
    "mijotassent": "mijoter",
    "mijotasses": "mijoter",
    "mijotassiez": "mijoter",
    "mijotassions": "mijoter",
    "mijote": "mijoter",
    "mijotent": "mijoter",
    "mijotera": "mijoter",
    "mijoterai": "mijoter",
    "mijoteraient": "mijoter",
    "mijoterais": "mijoter",
    "mijoterait": "mijoter",
    "mijoteras": "mijoter",
    "mijoterez": "mijoter",
    "mijoteriez": "mijoter",
    "mijoterions": "mijoter",
    "mijoterons": "mijoter",
    "mijoteront": "mijoter",
    "mijotes": "mijoter",
    "mijotez": "mijoter",
    "mijotiez": "mijoter",
    "mijotions": "mijoter",
    "mijotons": "mijoter",
    "mijotâmes": "mijoter",
    "mijotât": "mijoter",
    "mijotâtes": "mijoter",
    "mijotèrent": "mijoter",
    "mijoté": "mijoter",
    "mijotée": "mijoter",
    "mijotées": "mijoter",
    "mijotés": "mijoter",
    "mikados": "mikado",
    "milanaise": "milanais",
    "milanaises": "milanais",
    "milans": "milan",
    "mildious": "mildiou",
    "miles": "mile",
    "milices": "milice",
    "milicienne": "milicien",
    "miliciennes": "milicienne",
    "miliciens": "milicien",
    "milieux": "milieu",
    "milita": "militer",
    "militai": "militer",
    "militaient": "militer",
    "militaires": "militaire",
    "militais": "militer",
    "militait": "militer",
    "militant": "militer",
    "militante": "militant",
    "militantes": "militant",
    "militantismes": "militantisme",
    "militants": "militant",
    "militarisations": "militarisation",
    "militarismes": "militarisme",
    "militaristes": "militariste",
    "militarisé": "militariser",
    "militaro-industrielle": "militaro-industriel",
    "militas": "militer",
    "militasse": "militer",
    "militassent": "militer",
    "militasses": "militer",
    "militassiez": "militer",
    "militassions": "militer",
    "milite": "militer",
    "militent": "militer",
    "militera": "militer",
    "militerai": "militer",
    "militeraient": "militer",
    "militerais": "militer",
    "militerait": "militer",
    "militeras": "militer",
    "militerez": "militer",
    "militeriez": "militer",
    "militerions": "militer",
    "militerons": "militer",
    "militeront": "militer",
    "milites": "militer",
    "militez": "militer",
    "militiez": "militer",
    "militions": "militer",
    "militons": "militer",
    "militâmes": "militer",
    "militât": "militer",
    "militâtes": "militer",
    "militèrent": "militer",
    "milité": "militer",
    "milk shake": "milk-shake",
    "milk-bars": "milk-bar",
    "milk-shakes": "milk-shake",
    "mille-feuilles": "mille-feuille",
    "millefeuilles": "millefeuille",
    "milles": "mille",
    "millets": "millet",
    "milliardaires": "milliardaire",
    "milliards": "milliard",
    "milliers": "millier",
    "milligrammes": "milligramme",
    "millimètres": "millimètre",
    "millimétriques": "millimétrique",
    "millimétrées": "millimétré",
    "millimétrés": "millimétré",
    "millionièmes": "millionième",
    "millionnaires": "millionnaire",
    "millions": "million",
    "millisecondes": "milliseconde",
    "millièmes": "millième",
    "millénaires": "millénaire",
    "millénarismes": "millénarisme",
    "millésimes": "millésime",
    "millésimé": "millésimer",
    "millésimée": "millésimer",
    "millésimées": "millésimer",
    "millésimés": "millésimer",
    "milords": "milord",
    "mils": "mil",
    "milésiennes": "milésien",
    "mima": "mimer",
    "mimai": "mimer",
    "mimaient": "mimer",
    "mimais": "mimer",
    "mimait": "mimer",
    "mimant": "mimer",
    "mimas": "mimer",
    "mimasse": "mimer",
    "mimassent": "mimer",
    "mimasses": "mimer",
    "mimassiez": "mimer",
    "mimassions": "mimer",
    "mime": "mimer",
    "miment": "mimer",
    "mimera": "mimer",
    "mimerai": "mimer",
    "mimeraient": "mimer",
    "mimerais": "mimer",
    "mimerait": "mimer",
    "mimeras": "mimer",
    "mimerez": "mimer",
    "mimeriez": "mimer",
    "mimerions": "mimer",
    "mimerons": "mimer",
    "mimeront": "mimer",
    "mimes": "mimer",
    "mimez": "mimer",
    "mimiez": "mimer",
    "mimions": "mimer",
    "mimiques": "mimique",
    "mimis": "mimi",
    "mimodrames": "mimodrame",
    "mimons": "mimer",
    "mimosas": "mimosa",
    "mimosées": "mimosée",
    "mimâmes": "mimer",
    "mimât": "mimer",
    "mimâtes": "mimer",
    "mimèrent": "mimer",
    "mimé": "mimer",
    "mimée": "mimer",
    "mimées": "mimer",
    "mimés": "mimer",
    "mimétismes": "mimétisme",
    "mina": "miner",
    "minables": "minable",
    "minai": "miner",
    "minaient": "miner",
    "minais": "miner",
    "minait": "miner",
    "minant": "miner",
    "minarets": "minaret",
    "minas": "miner",
    "minasse": "miner",
    "minassent": "miner",
    "minasses": "miner",
    "minassiez": "miner",
    "minassions": "miner",
    "minauda": "minauder",
    "minaudai": "minauder",
    "minaudaient": "minauder",
    "minaudais": "minauder",
    "minaudait": "minauder",
    "minaudant": "minauder",
    "minaudants": "minaudant",
    "minaudas": "minauder",
    "minaudasse": "minauder",
    "minaudassent": "minauder",
    "minaudasses": "minauder",
    "minaudassiez": "minauder",
    "minaudassions": "minauder",
    "minaude": "minauder",
    "minaudent": "minauder",
    "minaudera": "minauder",
    "minauderai": "minauder",
    "minauderaient": "minauder",
    "minauderais": "minauder",
    "minauderait": "minauder",
    "minauderas": "minauder",
    "minauderez": "minauder",
    "minauderies": "minauderie",
    "minauderiez": "minauder",
    "minauderions": "minauder",
    "minauderons": "minauder",
    "minauderont": "minauder",
    "minaudes": "minauder",
    "minaudez": "minauder",
    "minaudiez": "minauder",
    "minaudions": "minauder",
    "minaudière": "minaudier",
    "minaudons": "minauder",
    "minaudâmes": "minauder",
    "minaudât": "minauder",
    "minaudâtes": "minauder",
    "minaudèrent": "minauder",
    "minaudé": "minauder",
    "minaudée": "minauder",
    "minaudées": "minauder",
    "minaudés": "minauder",
    "minces": "mince",
    "minceurs": "minceur",
    "minci": "mincir",
    "mincie": "mincir",
    "mincies": "mincir",
    "mincira": "mincir",
    "mincirai": "mincir",
    "minciraient": "mincir",
    "mincirais": "mincir",
    "mincirait": "mincir",
    "minciras": "mincir",
    "mincirent": "mincir",
    "mincirez": "mincir",
    "minciriez": "mincir",
    "mincirions": "mincir",
    "mincirons": "mincir",
    "minciront": "mincir",
    "mincis": "mincir",
    "mincissaient": "mincir",
    "mincissais": "mincir",
    "mincissait": "mincir",
    "mincissant": "mincir",
    "mincisse": "mincir",
    "mincissent": "mincir",
    "mincisses": "mincir",
    "mincissez": "mincir",
    "mincissiez": "mincir",
    "mincissions": "mincir",
    "mincissons": "mincir",
    "mincit": "mincir",
    "mincîmes": "mincir",
    "mincît": "mincir",
    "mincîtes": "mincir",
    "mine": "miner",
    "minent": "miner",
    "minera": "miner",
    "minerai": "miner",
    "mineraient": "miner",
    "minerais": "minerai",
    "minerait": "miner",
    "mineras": "miner",
    "minerez": "miner",
    "mineriez": "miner",
    "minerions": "miner",
    "minerons": "miner",
    "mineront": "miner",
    "minervals": "minerval",
    "minerves": "minerve",
    "mines": "miner",
    "minestrones": "minestrone",
    "minets": "minet",
    "minette": "minet",
    "minettes": "minet",
    "mineure": "mineur",
    "mineures": "mineur",
    "mineurs": "mineur",
    "minez": "miner",
    "mini-jupes": "mini-jupe",
    "miniatures": "miniature",
    "miniaturisations": "miniaturisation",
    "miniaturise": "miniaturiser",
    "miniaturisé": "miniaturiser",
    "miniaturisée": "miniaturiser",
    "miniaturisées": "miniaturiser",
    "miniaturisés": "miniaturiser",
    "minicassettes": "minicassette",
    "miniers": "minier",
    "miniez": "miner",
    "minijupes": "minijupe",
    "minikrachs": "minikrach",
    "minima": "minimum",
    "minimale": "minimal",
    "minimales": "minimal",
    "minimalisations": "minimalisation",
    "minimalistes": "minimaliste",
    "minimalisée": "minimalisé",
    "minimalisées": "minimalisé",
    "minimalisés": "minimalisé",
    "minimaux": "minimal",
    "minimes": "minime",
    "minimisa": "minimiser",
    "minimisai": "minimiser",
    "minimisaient": "minimiser",
    "minimisais": "minimiser",
    "minimisait": "minimiser",
    "minimisant": "minimiser",
    "minimisas": "minimiser",
    "minimisasse": "minimiser",
    "minimisassent": "minimiser",
    "minimisasses": "minimiser",
    "minimisassiez": "minimiser",
    "minimisassions": "minimiser",
    "minimise": "minimiser",
    "minimisent": "minimiser",
    "minimisera": "minimiser",
    "minimiserai": "minimiser",
    "minimiseraient": "minimiser",
    "minimiserais": "minimiser",
    "minimiserait": "minimiser",
    "minimiseras": "minimiser",
    "minimiserez": "minimiser",
    "minimiseriez": "minimiser",
    "minimiserions": "minimiser",
    "minimiserons": "minimiser",
    "minimiseront": "minimiser",
    "minimises": "minimiser",
    "minimisez": "minimiser",
    "minimisiez": "minimiser",
    "minimisions": "minimiser",
    "minimisons": "minimiser",
    "minimisâmes": "minimiser",
    "minimisât": "minimiser",
    "minimisâtes": "minimiser",
    "minimisèrent": "minimiser",
    "minimisé": "minimiser",
    "minimisée": "minimiser",
    "minimisées": "minimiser",
    "minimisés": "minimiser",
    "minimums": "minimum",
    "minions": "miner",
    "minis": "mini",
    "ministrables": "ministrable",
    "ministres": "ministre",
    "ministères": "ministère",
    "ministérielle": "ministériel",
    "ministérielles": "ministériel",
    "ministériels": "ministériel",
    "minitels": "minitel",
    "miniums": "minium",
    "minière": "minier",
    "minières": "minier",
    "minnesingers": "minnesinger",
    "minoenne": "minoen",
    "minoens": "minoen",
    "minons": "miner",
    "minora": "minorer",
    "minorai": "minorer",
    "minoraient": "minorer",
    "minorais": "minorer",
    "minorait": "minorer",
    "minorant": "minorer",
    "minoras": "minorer",
    "minorasse": "minorer",
    "minorassent": "minorer",
    "minorasses": "minorer",
    "minorassiez": "minorer",
    "minorassions": "minorer",
    "minore": "minorer",
    "minorent": "minorer",
    "minorera": "minorer",
    "minorerai": "minorer",
    "minoreraient": "minorer",
    "minorerais": "minorer",
    "minorerait": "minorer",
    "minoreras": "minorer",
    "minorerez": "minorer",
    "minoreriez": "minorer",
    "minorerions": "minorer",
    "minorerons": "minorer",
    "minoreront": "minorer",
    "minores": "minorer",
    "minorez": "minorer",
    "minoriez": "minorer",
    "minorions": "minorer",
    "minoritaires": "minoritaire",
    "minorités": "minorité",
    "minorons": "minorer",
    "minorâmes": "minorer",
    "minorât": "minorer",
    "minorâtes": "minorer",
    "minorèrent": "minorer",
    "minoré": "minorer",
    "minorée": "minorer",
    "minorées": "minorer",
    "minorés": "minorer",
    "minotaures": "minotaure",
    "minote": "minot",
    "minoteries": "minoterie",
    "minotes": "minot",
    "minotiers": "minotier",
    "minotière": "minotier",
    "minotières": "minotier",
    "minots": "minot",
    "minous": "minou",
    "minuits": "minuit",
    "minuscules": "minuscule",
    "minute": "minuter",
    "minuteries": "minuterie",
    "minutes": "minuter",
    "minuteurs": "minuteur",
    "minuties": "minutie",
    "minutieuse": "minutieux",
    "minutieuses": "minutieux",
    "minutions": "minuter",
    "minutât": "minuter",
    "minuté": "minuter",
    "minutée": "minuter",
    "minutés": "minuter",
    "minâmes": "miner",
    "minât": "miner",
    "minâtes": "miner",
    "minèrent": "miner",
    "miné": "miner",
    "minée": "miner",
    "minées": "miner",
    "minérale": "minéral",
    "minérales": "minéral",
    "minéraliers": "minéralier",
    "minéralisée": "minéralisé",
    "minéralisées": "minéralisé",
    "minéralisés": "minéraliser",
    "minéralogiques": "minéralogique",
    "minéraux": "minéral",
    "minés": "miner",
    "mioches": "mioche",
    "mira": "mirer",
    "mirabelles": "mirabelle",
    "mirabelliers": "mirabellier",
    "miracles": "miracle",
    "miraculantes": "miraculant",
    "miraculeuse": "miraculeux",
    "miraculeuses": "miraculeux",
    "miraculée": "miraculé",
    "miraculées": "miraculé",
    "miraculés": "miraculé",
    "miradors": "mirador",
    "mirages": "mirage",
    "mirai": "mirer",
    "miraient": "mirer",
    "mirais": "mirer",
    "mirait": "mirer",
    "mirant": "mirer",
    "miras": "mirer",
    "mirasse": "mirer",
    "mirassent": "mirer",
    "mirasses": "mirer",
    "mirassiez": "mirer",
    "mirassions": "mirer",
    "mirauds": "miraud",
    "mire": "mirer",
    "mirent": "mirer",
    "mirera": "mirer",
    "mirerai": "mirer",
    "mireraient": "mirer",
    "mirerais": "mirer",
    "mirerait": "mirer",
    "mireras": "mirer",
    "mirerez": "mirer",
    "mireriez": "mirer",
    "mirerions": "mirer",
    "mirerons": "mirer",
    "mireront": "mirer",
    "mires": "mirer",
    "mirettes": "mirette",
    "mirez": "mirer",
    "miriez": "mirer",
    "mirifiques": "mirifique",
    "mirions": "mirer",
    "mirlitons": "mirliton",
    "mirobolante": "mirobolant",
    "mirobolantes": "mirobolant",
    "mirobolants": "mirobolant",
    "miroirs": "miroir",
    "miroita": "miroiter",
    "miroitai": "miroiter",
    "miroitaient": "miroiter",
    "miroitais": "miroiter",
    "miroitait": "miroiter",
    "miroitant": "miroiter",
    "miroitante": "miroitant",
    "miroitantes": "miroitant",
    "miroitants": "miroitant",
    "miroitas": "miroiter",
    "miroitasse": "miroiter",
    "miroitassent": "miroiter",
    "miroitasses": "miroiter",
    "miroitassiez": "miroiter",
    "miroitassions": "miroiter",
    "miroite": "miroiter",
    "miroitements": "miroitement",
    "miroitent": "miroiter",
    "miroitera": "miroiter",
    "miroiterai": "miroiter",
    "miroiteraient": "miroiter",
    "miroiterais": "miroiter",
    "miroiterait": "miroiter",
    "miroiteras": "miroiter",
    "miroiterez": "miroiter",
    "miroiteries": "miroiterie",
    "miroiteriez": "miroiter",
    "miroiterions": "miroiter",
    "miroiterons": "miroiter",
    "miroiteront": "miroiter",
    "miroites": "miroiter",
    "miroitez": "miroiter",
    "miroitiers": "miroitier",
    "miroitiez": "miroiter",
    "miroitions": "miroiter",
    "miroitons": "miroiter",
    "miroitâmes": "miroiter",
    "miroitât": "miroiter",
    "miroitâtes": "miroiter",
    "miroitèrent": "miroiter",
    "miroité": "miroiter",
    "miroités": "miroité",
    "mirons": "mirer",
    "mirontons": "mironton",
    "miros": "miro",
    "mirotons": "miroton",
    "mirâmes": "mirer",
    "mirât": "mirer",
    "mirâtes": "mirer",
    "mirèrent": "mirer",
    "miré": "mirer",
    "mirée": "mirer",
    "mirées": "mirer",
    "mirés": "mirer",
    "mis": "mettre",
    "misa": "miser",
    "misai": "miser",
    "misaient": "miser",
    "misaines": "misaine",
    "misais": "miser",
    "misait": "miser",
    "misant": "miser",
    "misanthropes": "misanthrope",
    "misanthropies": "misanthropie",
    "misanthropiques": "misanthropique",
    "misas": "miser",
    "misasse": "miser",
    "misassent": "miser",
    "misasses": "miser",
    "misassiez": "miser",
    "misassions": "miser",
    "miscibles": "miscible",
    "mise": "miser",
    "misent": "miser",
    "misera": "miser",
    "miserai": "miser",
    "miseraient": "miser",
    "miserais": "miser",
    "miserait": "miser",
    "miseras": "miser",
    "misereres": "miserere",
    "miserez": "miser",
    "miseriez": "miser",
    "miserions": "miser",
    "miserons": "miser",
    "miseront": "miser",
    "mises": "miser",
    "misez": "miser",
    "misiez": "miser",
    "misions": "miser",
    "misogynes": "misogyne",
    "misogynies": "misogynie",
    "misons": "miser",
    "misse": "mettre",
    "missels": "missel",
    "missent": "mettre",
    "misses": "miss",
    "missiez": "mettre",
    "missiles": "missile",
    "missionna": "missionner",
    "missionnaires": "missionnaire",
    "missionné": "missionner",
    "missionnés": "missionner",
    "missions": "mission",
    "missives": "missive",
    "mistigris": "mistigri",
    "mistonne": "miston",
    "mistonnes": "miston",
    "mistoufles": "mistoufle",
    "mistrals": "mistral",
    "misâmes": "miser",
    "misât": "miser",
    "misâtes": "miser",
    "misèrent": "miser",
    "misères": "misère",
    "misé": "miser",
    "misée": "miser",
    "misées": "miser",
    "misérabilismes": "misérabilisme",
    "misérables": "misérable",
    "miséreuse": "miséreux",
    "miséreuses": "miséreux",
    "miséricordes": "miséricorde",
    "miséricordieuse": "miséricordieux",
    "miséricordieuses": "miséricordieux",
    "misérérés": "miséréré",
    "misés": "miser",
    "mit": "mettre",
    "mita": "miter",
    "mitai": "miter",
    "mitaient": "miter",
    "mitaines": "mitaine",
    "mitais": "miter",
    "mitait": "miter",
    "mitans": "mitan",
    "mitant": "miter",
    "mitards": "mitard",
    "mitardés": "mitarder",
    "mitas": "miter",
    "mitasse": "miter",
    "mitassent": "miter",
    "mitasses": "miter",
    "mitassiez": "miter",
    "mitassions": "miter",
    "mitchouriniens": "mitchourinien",
    "mite": "miter",
    "mitent": "miter",
    "mitera": "miter",
    "miterai": "miter",
    "miteraient": "miter",
    "miterais": "miter",
    "miterait": "miter",
    "miteras": "miter",
    "miterez": "miter",
    "miteriez": "miter",
    "miterions": "miter",
    "miterons": "miter",
    "miteront": "miter",
    "mites": "miter",
    "miteuse": "miteux",
    "miteuses": "miteux",
    "mitez": "miter",
    "mithridatisa": "mithridatiser",
    "mithridatisai": "mithridatiser",
    "mithridatisaient": "mithridatiser",
    "mithridatisais": "mithridatiser",
    "mithridatisait": "mithridatiser",
    "mithridatisant": "mithridatiser",
    "mithridatisas": "mithridatiser",
    "mithridatisasse": "mithridatiser",
    "mithridatisassent": "mithridatiser",
    "mithridatisasses": "mithridatiser",
    "mithridatisassiez": "mithridatiser",
    "mithridatisassions": "mithridatiser",
    "mithridatise": "mithridatiser",
    "mithridatisent": "mithridatiser",
    "mithridatisera": "mithridatiser",
    "mithridatiserai": "mithridatiser",
    "mithridatiseraient": "mithridatiser",
    "mithridatiserais": "mithridatiser",
    "mithridatiserait": "mithridatiser",
    "mithridatiseras": "mithridatiser",
    "mithridatiserez": "mithridatiser",
    "mithridatiseriez": "mithridatiser",
    "mithridatiserions": "mithridatiser",
    "mithridatiserons": "mithridatiser",
    "mithridatiseront": "mithridatiser",
    "mithridatises": "mithridatiser",
    "mithridatisez": "mithridatiser",
    "mithridatisiez": "mithridatiser",
    "mithridatisions": "mithridatiser",
    "mithridatisons": "mithridatiser",
    "mithridatisâmes": "mithridatiser",
    "mithridatisât": "mithridatiser",
    "mithridatisâtes": "mithridatiser",
    "mithridatisèrent": "mithridatiser",
    "mithridatisé": "mithridatiser",
    "mithridatisée": "mithridatiser",
    "mithridatisées": "mithridatiser",
    "mithridatisés": "mithridatiser",
    "mitiez": "miter",
    "mitige": "mitiger",
    "mitigea": "mitiger",
    "mitigeai": "mitiger",
    "mitigeaient": "mitiger",
    "mitigeais": "mitiger",
    "mitigeait": "mitiger",
    "mitigeant": "mitiger",
    "mitigeas": "mitiger",
    "mitigeasse": "mitiger",
    "mitigeassent": "mitiger",
    "mitigeasses": "mitiger",
    "mitigeassiez": "mitiger",
    "mitigeassions": "mitiger",
    "mitigent": "mitiger",
    "mitigeons": "mitiger",
    "mitigera": "mitiger",
    "mitigerai": "mitiger",
    "mitigeraient": "mitiger",
    "mitigerais": "mitiger",
    "mitigerait": "mitiger",
    "mitigeras": "mitiger",
    "mitigerez": "mitiger",
    "mitigeriez": "mitiger",
    "mitigerions": "mitiger",
    "mitigerons": "mitiger",
    "mitigeront": "mitiger",
    "mitiges": "mitiger",
    "mitigeurs": "mitigeur",
    "mitigez": "mitiger",
    "mitigeâmes": "mitiger",
    "mitigeât": "mitiger",
    "mitigeâtes": "mitiger",
    "mitigiez": "mitiger",
    "mitigions": "mitiger",
    "mitigèrent": "mitiger",
    "mitigé": "mitiger",
    "mitigée": "mitiger",
    "mitigées": "mitiger",
    "mitigés": "mitiger",
    "mitions": "miter",
    "mitochondries": "mitochondrie",
    "mitonna": "mitonner",
    "mitonnai": "mitonner",
    "mitonnaient": "mitonner",
    "mitonnais": "mitonner",
    "mitonnait": "mitonner",
    "mitonnant": "mitonner",
    "mitonnas": "mitonner",
    "mitonnasse": "mitonner",
    "mitonnassent": "mitonner",
    "mitonnasses": "mitonner",
    "mitonnassiez": "mitonner",
    "mitonnassions": "mitonner",
    "mitonne": "mitonner",
    "mitonnent": "mitonner",
    "mitonnera": "mitonner",
    "mitonnerai": "mitonner",
    "mitonneraient": "mitonner",
    "mitonnerais": "mitonner",
    "mitonnerait": "mitonner",
    "mitonneras": "mitonner",
    "mitonnerez": "mitonner",
    "mitonneriez": "mitonner",
    "mitonnerions": "mitonner",
    "mitonnerons": "mitonner",
    "mitonneront": "mitonner",
    "mitonnes": "mitonner",
    "mitonnez": "mitonner",
    "mitonniez": "mitonner",
    "mitonnions": "mitonner",
    "mitonnons": "mitonner",
    "mitonnâmes": "mitonner",
    "mitonnât": "mitonner",
    "mitonnâtes": "mitonner",
    "mitonnèrent": "mitonner",
    "mitonné": "mitonner",
    "mitonnée": "mitonner",
    "mitonnées": "mitonner",
    "mitonnés": "mitonner",
    "mitons": "miter",
    "mitoses": "mitose",
    "mitoyenne": "mitoyen",
    "mitoyennes": "mitoyen",
    "mitoyennetés": "mitoyenneté",
    "mitoyens": "mitoyen",
    "mitra": "mitrer",
    "mitrailla": "mitrailler",
    "mitraillades": "mitraillade",
    "mitraillages": "mitraillage",
    "mitraillai": "mitrailler",
    "mitraillaient": "mitrailler",
    "mitraillais": "mitrailler",
    "mitraillait": "mitrailler",
    "mitraillant": "mitrailler",
    "mitraillas": "mitrailler",
    "mitraillasse": "mitrailler",
    "mitraillassent": "mitrailler",
    "mitraillasses": "mitrailler",
    "mitraillassiez": "mitrailler",
    "mitraillassions": "mitrailler",
    "mitraille": "mitrailler",
    "mitraillent": "mitrailler",
    "mitraillera": "mitrailler",
    "mitraillerai": "mitrailler",
    "mitrailleraient": "mitrailler",
    "mitraillerais": "mitrailler",
    "mitraillerait": "mitrailler",
    "mitrailleras": "mitrailler",
    "mitraillerez": "mitrailler",
    "mitrailleriez": "mitrailler",
    "mitraillerions": "mitrailler",
    "mitraillerons": "mitrailler",
    "mitrailleront": "mitrailler",
    "mitrailles": "mitrailler",
    "mitraillettes": "mitraillette",
    "mitrailleurs": "mitrailleur",
    "mitrailleuse": "mitrailleur",
    "mitrailleuses": "mitrailleuse",
    "mitraillez": "mitrailler",
    "mitrailliez": "mitrailler",
    "mitraillions": "mitrailler",
    "mitraillons": "mitrailler",
    "mitraillâmes": "mitrailler",
    "mitraillât": "mitrailler",
    "mitraillâtes": "mitrailler",
    "mitraillèrent": "mitrailler",
    "mitraillé": "mitrailler",
    "mitraillée": "mitrailler",
    "mitraillées": "mitrailler",
    "mitraillés": "mitrailler",
    "mitrale": "mitral",
    "mitrales": "mitral",
    "mitraux": "mitral",
    "mitres": "mitre",
    "mitrons": "mitron",
    "mitré": "mitrer",
    "mitrés": "mitrer",
    "mitterrandienne": "mitterrandien",
    "mitterrandiennes": "mitterrandien",
    "mitterrandiens": "mitterrandien",
    "mitterrandismes": "mitterrandisme",
    "mitterrandistes": "mitterrandiste",
    "mitâmes": "miter",
    "mitât": "miter",
    "mitâtes": "miter",
    "mitèrent": "miter",
    "mité": "miter",
    "mitée": "miter",
    "mitées": "miter",
    "mités": "miter",
    "mixages": "mixage",
    "mixait": "mixer",
    "mixe": "mixer",
    "mixers": "mixer",
    "mixeurs": "mixeur",
    "mixités": "mixité",
    "mixtes": "mixte",
    "mixtions": "mixtion",
    "mixtures": "mixture",
    "mixé": "mixer",
    "mixée": "mixer",
    "mixés": "mixer",
    "mièvreries": "mièvrerie",
    "mièvres": "mièvre",
    "mns": "mn",
    "mnémoniques": "mnémonique",
    "mnémotechniques": "mnémotechnique",
    "mnésiques": "mnésique",
    "mobiles": "mobile",
    "mobiliers": "mobilier",
    "mobilisa": "mobiliser",
    "mobilisables": "mobilisable",
    "mobilisai": "mobiliser",
    "mobilisaient": "mobiliser",
    "mobilisais": "mobiliser",
    "mobilisait": "mobiliser",
    "mobilisant": "mobiliser",
    "mobilisas": "mobiliser",
    "mobilisasse": "mobiliser",
    "mobilisassent": "mobiliser",
    "mobilisasses": "mobiliser",
    "mobilisassiez": "mobiliser",
    "mobilisassions": "mobiliser",
    "mobilisateurs": "mobilisateur",
    "mobilisations": "mobilisation",
    "mobilisatrice": "mobilisateur",
    "mobilisatrices": "mobilisateur",
    "mobilise": "mobiliser",
    "mobilisent": "mobiliser",
    "mobilisera": "mobiliser",
    "mobiliserai": "mobiliser",
    "mobiliseraient": "mobiliser",
    "mobiliserais": "mobiliser",
    "mobiliserait": "mobiliser",
    "mobiliseras": "mobiliser",
    "mobiliserez": "mobiliser",
    "mobiliseriez": "mobiliser",
    "mobiliserions": "mobiliser",
    "mobiliserons": "mobiliser",
    "mobiliseront": "mobiliser",
    "mobilises": "mobiliser",
    "mobilisez": "mobiliser",
    "mobilisiez": "mobiliser",
    "mobilisions": "mobiliser",
    "mobilisons": "mobiliser",
    "mobilisâmes": "mobiliser",
    "mobilisât": "mobiliser",
    "mobilisâtes": "mobiliser",
    "mobilisèrent": "mobiliser",
    "mobilisé": "mobiliser",
    "mobilisée": "mobiliser",
    "mobilisées": "mobiliser",
    "mobilisés": "mobiliser",
    "mobilités": "mobilité",
    "mobilière": "mobilier",
    "mobilières": "mobilier",
    "mobylettes": "mobylette",
    "mocassins": "mocassin",
    "mocharde": "mochard",
    "moches": "moche",
    "mochetés": "mocheté",
    "modale": "modal",
    "modales": "modal",
    "modalités": "modalité",
    "modaux": "modal",
    "modela": "modeler",
    "modelages": "modelage",
    "modelai": "modeler",
    "modelaient": "modeler",
    "modelais": "modeler",
    "modelait": "modeler",
    "modelant": "modeler",
    "modelas": "modeler",
    "modelasse": "modeler",
    "modelassent": "modeler",
    "modelasses": "modeler",
    "modelassiez": "modeler",
    "modelassions": "modeler",
    "modelez": "modeler",
    "modeliez": "modeler",
    "modelions": "modeler",
    "modelons": "modeler",
    "modelâmes": "modeler",
    "modelât": "modeler",
    "modelâtes": "modeler",
    "modelèrent": "modeler",
    "modelé": "modeler",
    "modelée": "modeler",
    "modelées": "modeler",
    "modelés": "modeler",
    "modems": "modem",
    "modern-styles": "modern-style",
    "modernes": "moderne",
    "modernisa": "moderniser",
    "modernisai": "moderniser",
    "modernisaient": "moderniser",
    "modernisais": "moderniser",
    "modernisait": "moderniser",
    "modernisant": "moderniser",
    "modernisas": "moderniser",
    "modernisasse": "moderniser",
    "modernisassent": "moderniser",
    "modernisasses": "moderniser",
    "modernisassiez": "moderniser",
    "modernisassions": "moderniser",
    "modernisateurs": "modernisateur",
    "modernisations": "modernisation",
    "modernisatrice": "modernisateur",
    "modernisatrices": "modernisateur",
    "modernise": "moderniser",
    "modernisent": "moderniser",
    "modernisera": "moderniser",
    "moderniserai": "moderniser",
    "moderniseraient": "moderniser",
    "moderniserais": "moderniser",
    "moderniserait": "moderniser",
    "moderniseras": "moderniser",
    "moderniserez": "moderniser",
    "moderniseriez": "moderniser",
    "moderniserions": "moderniser",
    "moderniserons": "moderniser",
    "moderniseront": "moderniser",
    "modernises": "moderniser",
    "modernisez": "moderniser",
    "modernisiez": "moderniser",
    "modernisions": "moderniser",
    "modernismes": "modernisme",
    "modernisons": "moderniser",
    "modernistes": "moderniste",
    "modernisâmes": "moderniser",
    "modernisât": "moderniser",
    "modernisâtes": "moderniser",
    "modernisèrent": "moderniser",
    "modernisé": "moderniser",
    "modernisée": "moderniser",
    "modernisées": "moderniser",
    "modernisés": "moderniser",
    "modernités": "modernité",
    "modes": "mode",
    "modestes": "modeste",
    "modesties": "modestie",
    "modicités": "modicité",
    "modifia": "modifier",
    "modifiables": "modifiable",
    "modifiai": "modifier",
    "modifiaient": "modifier",
    "modifiais": "modifier",
    "modifiait": "modifier",
    "modifiant": "modifier",
    "modifias": "modifier",
    "modifiasse": "modifier",
    "modifiassent": "modifier",
    "modifiasses": "modifier",
    "modifiassiez": "modifier",
    "modifiassions": "modifier",
    "modifications": "modification",
    "modifie": "modifier",
    "modifient": "modifier",
    "modifiera": "modifier",
    "modifierai": "modifier",
    "modifieraient": "modifier",
    "modifierais": "modifier",
    "modifierait": "modifier",
    "modifieras": "modifier",
    "modifierez": "modifier",
    "modifieriez": "modifier",
    "modifierions": "modifier",
    "modifierons": "modifier",
    "modifieront": "modifier",
    "modifies": "modifier",
    "modifiez": "modifier",
    "modifiiez": "modifier",
    "modifiions": "modifier",
    "modifions": "modifier",
    "modifiâmes": "modifier",
    "modifiât": "modifier",
    "modifiâtes": "modifier",
    "modifièrent": "modifier",
    "modifié": "modifier",
    "modifiée": "modifier",
    "modifiées": "modifier",
    "modifiés": "modifier",
    "modillons": "modillon",
    "modiques": "modique",
    "modistes": "modiste",
    "modula": "moduler",
    "modulables": "modulable",
    "modulai": "moduler",
    "modulaient": "moduler",
    "modulaires": "modulaire",
    "modulais": "moduler",
    "modulait": "moduler",
    "modulant": "moduler",
    "modulas": "moduler",
    "modulasse": "moduler",
    "modulassent": "moduler",
    "modulasses": "moduler",
    "modulassiez": "moduler",
    "modulassions": "moduler",
    "modulations": "modulation",
    "module": "moduler",
    "modulent": "moduler",
    "modulera": "moduler",
    "modulerai": "moduler",
    "moduleraient": "moduler",
    "modulerais": "moduler",
    "modulerait": "moduler",
    "moduleras": "moduler",
    "modulerez": "moduler",
    "moduleriez": "moduler",
    "modulerions": "moduler",
    "modulerons": "moduler",
    "moduleront": "moduler",
    "modules": "moduler",
    "modulez": "moduler",
    "moduliez": "moduler",
    "modulions": "moduler",
    "modulons": "moduler",
    "modulâmes": "moduler",
    "modulât": "moduler",
    "modulâtes": "moduler",
    "modulèrent": "moduler",
    "modulé": "moduler",
    "modulée": "moduler",
    "modulées": "moduler",
    "modulés": "moduler",
    "modèle": "modeler",
    "modèlent": "modeler",
    "modèlera": "modeler",
    "modèlerai": "modeler",
    "modèleraient": "modeler",
    "modèlerais": "modeler",
    "modèlerait": "modeler",
    "modèleras": "modeler",
    "modèlerez": "modeler",
    "modèleriez": "modeler",
    "modèlerions": "modeler",
    "modèlerons": "modeler",
    "modèleront": "modeler",
    "modèles": "modeler",
    "modère": "modérer",
    "modèrent": "modérer",
    "modères": "modérer",
    "modélisations": "modélisation",
    "modélistes": "modéliste",
    "modélisé": "modéliser",
    "modélisée": "modéliser",
    "modéra": "modérer",
    "modérai": "modérer",
    "modéraient": "modérer",
    "modérais": "modérer",
    "modérait": "modérer",
    "modérant": "modérer",
    "modéras": "modérer",
    "modérasse": "modérer",
    "modérassent": "modérer",
    "modérasses": "modérer",
    "modérassiez": "modérer",
    "modérassions": "modérer",
    "modérateurs": "modérateur",
    "modérations": "modération",
    "modérera": "modérer",
    "modérerai": "modérer",
    "modéreraient": "modérer",
    "modérerais": "modérer",
    "modérerait": "modérer",
    "modéreras": "modérer",
    "modérerez": "modérer",
    "modéreriez": "modérer",
    "modérerions": "modérer",
    "modérerons": "modérer",
    "modéreront": "modérer",
    "modérez": "modérer",
    "modériez": "modérer",
    "modérions": "modérer",
    "modérons": "modérer",
    "modérâmes": "modérer",
    "modérât": "modérer",
    "modérâtes": "modérer",
    "modérèrent": "modérer",
    "modéré": "modérer",
    "modérée": "modérer",
    "modérées": "modérer",
    "modérés": "modérer",
    "moelles": "moelle",
    "moelleuse": "moelleux",
    "moelleuses": "moelleux",
    "moellons": "moellon",
    "mofettes": "mofette",
    "mohairs": "mohair",
    "moi": "lui",
    "moies": "moie",
    "moignons": "moignon",
    "moindres": "moindre",
    "moineaux": "moineau",
    "moines": "moine",
    "moinillons": "moinillon",
    "moins-perçus": "moins-perçu",
    "moins-values": "moins-value",
    "moira": "moirer",
    "moirai": "moirer",
    "moiraient": "moirer",
    "moirais": "moirer",
    "moirait": "moirer",
    "moirant": "moirer",
    "moiras": "moirer",
    "moirasse": "moirer",
    "moirassent": "moirer",
    "moirasses": "moirer",
    "moirassiez": "moirer",
    "moirassions": "moirer",
    "moire": "moirer",
    "moirent": "moirer",
    "moirera": "moirer",
    "moirerai": "moirer",
    "moireraient": "moirer",
    "moirerais": "moirer",
    "moirerait": "moirer",
    "moireras": "moirer",
    "moirerez": "moirer",
    "moireriez": "moirer",
    "moirerions": "moirer",
    "moirerons": "moirer",
    "moireront": "moirer",
    "moires": "moirer",
    "moirez": "moirer",
    "moiriez": "moirer",
    "moirions": "moirer",
    "moirons": "moirer",
    "moirures": "moirure",
    "moirâmes": "moirer",
    "moirât": "moirer",
    "moirâtes": "moirer",
    "moirèrent": "moirer",
    "moiré": "moirer",
    "moirée": "moirer",
    "moirées": "moirer",
    "moirés": "moirer",
    "moises": "moise",
    "moisi": "moisir",
    "moisie": "moisir",
    "moisies": "moisir",
    "moisira": "moisir",
    "moisirai": "moisir",
    "moisiraient": "moisir",
    "moisirais": "moisir",
    "moisirait": "moisir",
    "moisiras": "moisir",
    "moisirent": "moisir",
    "moisirez": "moisir",
    "moisiriez": "moisir",
    "moisirions": "moisir",
    "moisirons": "moisir",
    "moisiront": "moisir",
    "moisis": "moisir",
    "moisissaient": "moisir",
    "moisissais": "moisir",
    "moisissait": "moisir",
    "moisissant": "moisir",
    "moisisse": "moisir",
    "moisissent": "moisir",
    "moisisses": "moisir",
    "moisissez": "moisir",
    "moisissiez": "moisir",
    "moisissions": "moisir",
    "moisissons": "moisir",
    "moisissures": "moisissure",
    "moisit": "moisir",
    "moissonna": "moissonner",
    "moissonnai": "moissonner",
    "moissonnaient": "moissonner",
    "moissonnais": "moissonner",
    "moissonnait": "moissonner",
    "moissonnant": "moissonner",
    "moissonnas": "moissonner",
    "moissonnasse": "moissonner",
    "moissonnassent": "moissonner",
    "moissonnasses": "moissonner",
    "moissonnassiez": "moissonner",
    "moissonnassions": "moissonner",
    "moissonne": "moissonner",
    "moissonnent": "moissonner",
    "moissonnera": "moissonner",
    "moissonnerai": "moissonner",
    "moissonneraient": "moissonner",
    "moissonnerais": "moissonner",
    "moissonnerait": "moissonner",
    "moissonneras": "moissonner",
    "moissonnerez": "moissonner",
    "moissonneriez": "moissonner",
    "moissonnerions": "moissonner",
    "moissonnerons": "moissonner",
    "moissonneront": "moissonner",
    "moissonnes": "moissonner",
    "moissonneurs": "moissonneur",
    "moissonneuse": "moissonneur",
    "moissonneuses": "moissonneur",
    "moissonneuses-batteuses": "moissonneuse-batteuse",
    "moissonneuses-lieuses": "moissonneuse-lieuse",
    "moissonnez": "moissonner",
    "moissonniez": "moissonner",
    "moissonnions": "moissonner",
    "moissonnons": "moissonner",
    "moissonnâmes": "moissonner",
    "moissonnât": "moissonner",
    "moissonnâtes": "moissonner",
    "moissonnèrent": "moissonner",
    "moissonné": "moissonner",
    "moissonnée": "moissonner",
    "moissonnées": "moissonner",
    "moissonnés": "moissonner",
    "moissons": "moisson",
    "moisîmes": "moisir",
    "moisît": "moisir",
    "moisîtes": "moisir",
    "moites": "moite",
    "moiteurs": "moiteur",
    "moiti": "moitir",
    "moitie": "moitir",
    "moities": "moitir",
    "moitira": "moitir",
    "moitirai": "moitir",
    "moitiraient": "moitir",
    "moitirais": "moitir",
    "moitirait": "moitir",
    "moitiras": "moitir",
    "moitirent": "moitir",
    "moitirez": "moitir",
    "moitiriez": "moitir",
    "moitirions": "moitir",
    "moitirons": "moitir",
    "moitiront": "moitir",
    "moitis": "moitir",
    "moitissaient": "moitir",
    "moitissais": "moitir",
    "moitissait": "moitir",
    "moitissant": "moitir",
    "moitisse": "moitir",
    "moitissent": "moitir",
    "moitisses": "moitir",
    "moitissez": "moitir",
    "moitissiez": "moitir",
    "moitissions": "moitir",
    "moitissons": "moitir",
    "moitit": "moitir",
    "moitiés": "moitié",
    "moitîmes": "moitir",
    "moitît": "moitir",
    "moitîtes": "moitir",
    "mokas": "moka",
    "mol": "mou",
    "molaires": "molaire",
    "moldaves": "moldave",
    "moles": "mole",
    "moleskines": "moleskine",
    "molesquines": "molesquine",
    "molesta": "molester",
    "molestai": "molester",
    "molestaient": "molester",
    "molestais": "molester",
    "molestait": "molester",
    "molestant": "molester",
    "molestas": "molester",
    "molestasse": "molester",
    "molestassent": "molester",
    "molestasses": "molester",
    "molestassiez": "molester",
    "molestassions": "molester",
    "moleste": "molester",
    "molestent": "molester",
    "molestera": "molester",
    "molesterai": "molester",
    "molesteraient": "molester",
    "molesterais": "molester",
    "molesterait": "molester",
    "molesteras": "molester",
    "molesterez": "molester",
    "molesteriez": "molester",
    "molesterions": "molester",
    "molesterons": "molester",
    "molesteront": "molester",
    "molestes": "molester",
    "molestez": "molester",
    "molestiez": "molester",
    "molestions": "molester",
    "molestons": "molester",
    "molestâmes": "molester",
    "molestât": "molester",
    "molestâtes": "molester",
    "molestèrent": "molester",
    "molesté": "molester",
    "molestée": "molester",
    "molestées": "molester",
    "molestés": "molester",
    "moleta": "moleter",
    "moletai": "moleter",
    "moletaient": "moleter",
    "moletais": "moleter",
    "moletait": "moleter",
    "moletant": "moleter",
    "moletas": "moleter",
    "moletasse": "moleter",
    "moletassent": "moleter",
    "moletasses": "moleter",
    "moletassiez": "moleter",
    "moletassions": "moleter",
    "moletez": "moleter",
    "moletiez": "moleter",
    "moletions": "moleter",
    "moletons": "moleter",
    "molette": "moleter",
    "molettent": "moleter",
    "molettera": "moleter",
    "moletterai": "moleter",
    "moletteraient": "moleter",
    "moletterais": "moleter",
    "moletterait": "moleter",
    "moletteras": "moleter",
    "moletterez": "moleter",
    "moletteriez": "moleter",
    "moletterions": "moleter",
    "moletterons": "moleter",
    "moletteront": "moleter",
    "molettes": "molette",
    "moletâmes": "moleter",
    "moletât": "moleter",
    "moletâtes": "moleter",
    "moletèrent": "moleter",
    "moleté": "moleter",
    "moletée": "moleter",
    "moletées": "moleter",
    "moletés": "moleter",
    "molinismes": "molinisme",
    "mollahs": "mollah",
    "mollards": "mollard",
    "mollardé": "mollarder",
    "mollasses": "mollasse",
    "mollassonne": "mollasson",
    "mollassons": "mollasson",
    "molle": "mou",
    "molles": "mou",
    "mollesses": "mollesse",
    "molletières": "molletière",
    "molletonna": "molletonner",
    "molletonnai": "molletonner",
    "molletonnaient": "molletonner",
    "molletonnais": "molletonner",
    "molletonnait": "molletonner",
    "molletonnant": "molletonner",
    "molletonnas": "molletonner",
    "molletonnasse": "molletonner",
    "molletonnassent": "molletonner",
    "molletonnasses": "molletonner",
    "molletonnassiez": "molletonner",
    "molletonnassions": "molletonner",
    "molletonne": "molletonner",
    "molletonnent": "molletonner",
    "molletonnera": "molletonner",
    "molletonnerai": "molletonner",
    "molletonneraient": "molletonner",
    "molletonnerais": "molletonner",
    "molletonnerait": "molletonner",
    "molletonneras": "molletonner",
    "molletonnerez": "molletonner",
    "molletonneriez": "molletonner",
    "molletonnerions": "molletonner",
    "molletonnerons": "molletonner",
    "molletonneront": "molletonner",
    "molletonnes": "molletonner",
    "molletonnez": "molletonner",
    "molletonniez": "molletonner",
    "molletonnions": "molletonner",
    "molletonnons": "molletonner",
    "molletonnâmes": "molletonner",
    "molletonnât": "molletonner",
    "molletonnâtes": "molletonner",
    "molletonnèrent": "molletonner",
    "molletonné": "molletonner",
    "molletonnée": "molletonner",
    "molletonnées": "molletonner",
    "molletonnés": "molletonner",
    "molletons": "molleton",
    "mollets": "mollet",
    "mollette": "mollet",
    "mollettes": "mollet",
    "molli": "mollir",
    "mollie": "mollir",
    "mollies": "mollir",
    "mollira": "mollir",
    "mollirai": "mollir",
    "molliraient": "mollir",
    "mollirais": "mollir",
    "mollirait": "mollir",
    "molliras": "mollir",
    "mollirent": "mollir",
    "mollirez": "mollir",
    "molliriez": "mollir",
    "mollirions": "mollir",
    "mollirons": "mollir",
    "molliront": "mollir",
    "mollis": "mollir",
    "mollissaient": "mollir",
    "mollissais": "mollir",
    "mollissait": "mollir",
    "mollissant": "mollir",
    "mollisse": "mollir",
    "mollissent": "mollir",
    "mollisses": "mollir",
    "mollissez": "mollir",
    "mollissiez": "mollir",
    "mollissions": "mollir",
    "mollissons": "mollir",
    "mollit": "mollir",
    "mollusques": "mollusque",
    "mollétistes": "mollétiste",
    "mollîmes": "mollir",
    "mollît": "mollir",
    "mollîtes": "mollir",
    "molochs": "moloch",
    "molosses": "molosse",
    "mols": "mol",
    "moluquoise": "moluquois",
    "moluquoises": "moluquois",
    "molybdènes": "molybdène",
    "molènes": "molène",
    "moléculaires": "moléculaire",
    "molécules": "molécule",
    "moléculteurs": "moléculteur",
    "molécultrice": "moléculteur",
    "molécultrices": "moléculteur",
    "momentanée": "momentané",
    "momentanées": "momentané",
    "momentanés": "momentané",
    "moments": "moment",
    "moments-clés": "moments-clé",
    "momeries": "momerie",
    "momichons": "momichon",
    "momie": "momi",
    "momies": "momie",
    "momifiait": "momifier",
    "momifiant": "momifier",
    "momifie": "momifier",
    "momifié": "momifier",
    "momifiée": "momifier",
    "momifiées": "momifier",
    "momifiés": "momifier",
    "monacale": "monacal",
    "monacales": "monacal",
    "monacaux": "monacal",
    "monachismes": "monachisme",
    "monades": "monade",
    "monarchies": "monarchie",
    "monarchiques": "monarchique",
    "monarchistes": "monarchiste",
    "monarques": "monarque",
    "monastiques": "monastique",
    "monastères": "monastère",
    "monaurale": "monaural",
    "monaurales": "monaural",
    "monauraux": "monaural",
    "monceaux": "monceau",
    "monda": "monder",
    "mondai": "monder",
    "mondaient": "monder",
    "mondaine": "mondain",
    "mondaines": "mondain",
    "mondains": "mondain",
    "mondais": "monder",
    "mondait": "monder",
    "mondanisaient": "mondaniser",
    "mondanisé": "mondaniser",
    "mondanités": "mondanité",
    "mondant": "monder",
    "mondas": "monder",
    "mondasse": "monder",
    "mondassent": "monder",
    "mondasses": "monder",
    "mondassiez": "monder",
    "mondassions": "monder",
    "monde": "monder",
    "mondent": "monder",
    "mondera": "monder",
    "monderai": "monder",
    "monderaient": "monder",
    "monderais": "monder",
    "monderait": "monder",
    "monderas": "monder",
    "monderez": "monder",
    "monderiez": "monder",
    "monderions": "monder",
    "monderons": "monder",
    "monderont": "monder",
    "mondes": "monder",
    "mondez": "monder",
    "mondiale": "mondial",
    "mondiales": "mondial",
    "mondialisations": "mondialisation",
    "mondialisent": "mondialiser",
    "mondialistes": "mondialiste",
    "mondialisée": "mondialisé",
    "mondialisées": "mondialisé",
    "mondialisés": "mondialisé",
    "mondiaux": "mondial",
    "mondiez": "monder",
    "mondions": "monder",
    "mondons": "monder",
    "mondâmes": "monder",
    "mondât": "monder",
    "mondâtes": "monder",
    "mondèrent": "monder",
    "mondé": "monder",
    "mondée": "monder",
    "mondées": "monder",
    "mondés": "monder",
    "mongole": "mongol",
    "mongoles": "mongol",
    "mongolienne": "mongolien",
    "mongoliennes": "mongolien",
    "mongoliens": "mongolien",
    "mongoliques": "mongolique",
    "mongols": "mongol",
    "moniales": "moniale",
    "monismes": "monisme",
    "moniteurs": "moniteur",
    "monitions": "monition",
    "monitoires": "monitoire",
    "monitorages": "monitorage",
    "monitorats": "monitorat",
    "monitorings": "monitoring",
    "monitrice": "moniteur",
    "monitrices": "moniteur",
    "monnaie": "monnayer",
    "monnaient": "monnayer",
    "monnaiera": "monnayer",
    "monnaierai": "monnayer",
    "monnaieraient": "monnayer",
    "monnaierais": "monnayer",
    "monnaierait": "monnayer",
    "monnaieras": "monnayer",
    "monnaierez": "monnayer",
    "monnaieriez": "monnayer",
    "monnaierions": "monnayer",
    "monnaierons": "monnayer",
    "monnaieront": "monnayer",
    "monnaies": "monnayer",
    "monnaies-du-pape": "monnaie-du-pape",
    "monnaya": "monnayer",
    "monnayables": "monnayable",
    "monnayai": "monnayer",
    "monnayaient": "monnayer",
    "monnayais": "monnayer",
    "monnayait": "monnayer",
    "monnayant": "monnayer",
    "monnayas": "monnayer",
    "monnayasse": "monnayer",
    "monnayassent": "monnayer",
    "monnayasses": "monnayer",
    "monnayassiez": "monnayer",
    "monnayassions": "monnayer",
    "monnaye": "monnayer",
    "monnayent": "monnayer",
    "monnayera": "monnayer",
    "monnayerai": "monnayer",
    "monnayeraient": "monnayer",
    "monnayerais": "monnayer",
    "monnayerait": "monnayer",
    "monnayeras": "monnayer",
    "monnayerez": "monnayer",
    "monnayeriez": "monnayer",
    "monnayerions": "monnayer",
    "monnayerons": "monnayer",
    "monnayeront": "monnayer",
    "monnayes": "monnayer",
    "monnayeurs": "monnayeur",
    "monnayez": "monnayer",
    "monnayiez": "monnayer",
    "monnayions": "monnayer",
    "monnayons": "monnayer",
    "monnayâmes": "monnayer",
    "monnayât": "monnayer",
    "monnayâtes": "monnayer",
    "monnayèrent": "monnayer",
    "monnayé": "monnayer",
    "monnayée": "monnayer",
    "monnayées": "monnayer",
    "monnayés": "monnayer",
    "monochromes": "monochrome",
    "monocles": "monocle",
    "monoclinale": "monoclinal",
    "monoclinales": "monoclinal",
    "monoclinaux": "monoclinal",
    "monoclonaux": "monoclonal",
    "monocoques": "monocoque",
    "monocordes": "monocorde",
    "monoculaires": "monoculaire",
    "monocultures": "monoculture",
    "monodies": "monodie",
    "monogames": "monogame",
    "monogrammes": "monogramme",
    "monogrammées": "monogrammé",
    "monographies": "monographie",
    "monographiques": "monographique",
    "monolingues": "monolingue",
    "monolithes": "monolithe",
    "monolithiques": "monolithique",
    "monolithismes": "monolithisme",
    "monologua": "monologuer",
    "monologuaient": "monologuer",
    "monologuais": "monologuer",
    "monologuait": "monologuer",
    "monologuant": "monologuer",
    "monologue": "monologuer",
    "monologues": "monologue",
    "monomanes": "monomane",
    "monomaniaques": "monomaniaque",
    "monomanies": "monomanie",
    "monomoteurs": "monomoteur",
    "monoparentale": "monoparental",
    "monoparentales": "monoparental",
    "monoparentaux": "monoparental",
    "monopartismes": "monopartisme",
    "monophasée": "monophasé",
    "monoplaces": "monoplace",
    "monoplans": "monoplan",
    "monopoles": "monopole",
    "monopolisa": "monopoliser",
    "monopolisai": "monopoliser",
    "monopolisaient": "monopoliser",
    "monopolisais": "monopoliser",
    "monopolisait": "monopoliser",
    "monopolisant": "monopoliser",
    "monopolisas": "monopoliser",
    "monopolisasse": "monopoliser",
    "monopolisassent": "monopoliser",
    "monopolisasses": "monopoliser",
    "monopolisassiez": "monopoliser",
    "monopolisassions": "monopoliser",
    "monopolise": "monopoliser",
    "monopolisent": "monopoliser",
    "monopolisera": "monopoliser",
    "monopoliserai": "monopoliser",
    "monopoliseraient": "monopoliser",
    "monopoliserais": "monopoliser",
    "monopoliserait": "monopoliser",
    "monopoliseras": "monopoliser",
    "monopoliserez": "monopoliser",
    "monopoliseriez": "monopoliser",
    "monopoliserions": "monopoliser",
    "monopoliserons": "monopoliser",
    "monopoliseront": "monopoliser",
    "monopolises": "monopoliser",
    "monopolisez": "monopoliser",
    "monopolisiez": "monopoliser",
    "monopolisions": "monopoliser",
    "monopolisons": "monopoliser",
    "monopolistiques": "monopolistique",
    "monopolisâmes": "monopoliser",
    "monopolisât": "monopoliser",
    "monopolisâtes": "monopoliser",
    "monopolisèrent": "monopoliser",
    "monopolisé": "monopoliser",
    "monopolisée": "monopoliser",
    "monopolisées": "monopoliser",
    "monopolisés": "monopoliser",
    "monorails": "monorail",
    "monoskis": "monoski",
    "monosyllabes": "monosyllabe",
    "monosyllabiques": "monosyllabique",
    "monothéismes": "monothéisme",
    "monothéistes": "monothéiste",
    "monotones": "monotone",
    "monotonies": "monotonie",
    "monovalente": "monovalent",
    "monovalentes": "monovalent",
    "monovalents": "monovalent",
    "monozygotes": "monozygote",
    "monstrances": "monstrance",
    "monstres": "monstre",
    "monstrueuse": "monstrueux",
    "monstrueuses": "monstrueux",
    "monstruosités": "monstruosité",
    "monta": "monter",
    "montages": "montage",
    "montagnarde": "montagnard",
    "montagnardes": "montagnard",
    "montagnards": "montagnard",
    "montagnes": "montagne",
    "montagneuse": "montagneux",
    "montagneuses": "montagneux",
    "montai": "monter",
    "montaient": "monter",
    "montais": "monter",
    "montait": "monter",
    "montant": "monter",
    "montante": "montant",
    "montantes": "montant",
    "montants": "montant",
    "montas": "monter",
    "montasse": "monter",
    "montassent": "monter",
    "montasses": "monter",
    "montassiez": "monter",
    "montassions": "monter",
    "monte": "monter",
    "monte-charges": "monte-charge",
    "monte-plats": "monte-plat",
    "monte-sacs": "monte-sac",
    "montent": "monter",
    "montera": "monter",
    "monterai": "monter",
    "monteraient": "monter",
    "monterais": "monter",
    "monterait": "monter",
    "monteras": "monter",
    "monterez": "monter",
    "monteriez": "monter",
    "monterions": "monter",
    "monterons": "monter",
    "monteront": "monter",
    "montes": "monter",
    "monteurs": "monteur",
    "monteuse": "monteur",
    "monteuses": "monteur",
    "montez": "monter",
    "montgolfières": "montgolfière",
    "monticules": "monticule",
    "montiez": "monter",
    "montions": "monter",
    "montmartroise": "montmartrois",
    "montmartroises": "montmartrois",
    "montons": "monter",
    "montpelliéraine": "montpelliérain",
    "montpelliéraines": "montpelliérain",
    "montpelliérains": "montpelliérain",
    "montra": "montrer",
    "montrables": "montrable",
    "montrai": "montrer",
    "montraient": "montrer",
    "montrais": "montrer",
    "montrait": "montrer",
    "montrant": "montrer",
    "montras": "montrer",
    "montrasse": "montrer",
    "montrassent": "montrer",
    "montrasses": "montrer",
    "montrassiez": "montrer",
    "montrassions": "montrer",
    "montre": "montrer",
    "montre-la-moi": "montrer",
    "montrent": "montrer",
    "montrera": "montrer",
    "montrerai": "montrer",
    "montreraient": "montrer",
    "montrerais": "montrer",
    "montrerait": "montrer",
    "montreras": "montrer",
    "montrerez": "montrer",
    "montreriez": "montrer",
    "montrerions": "montrer",
    "montrerons": "montrer",
    "montreront": "montrer",
    "montres": "montrer",
    "montres-bracelets": "montre-bracelet",
    "montreurs": "montreur",
    "montreuse": "montreur",
    "montreuses": "montreur",
    "montrez": "montrer",
    "montriez": "montrer",
    "montrions": "montrer",
    "montrons": "montrer",
    "montrâmes": "montrer",
    "montrât": "montrer",
    "montrâtes": "montrer",
    "montrèrent": "montrer",
    "montré": "montrer",
    "montrée": "montrer",
    "montrées": "montrer",
    "montrés": "montrer",
    "monts": "mont",
    "monts-blancs": "mont-blanc",
    "monts-d'or": "mont-d'or",
    "monts-de-piété": "mont-de-piété",
    "monts-joie": "mont-joie",
    "montueuse": "montueux",
    "montueuses": "montueux",
    "montures": "monture",
    "montâmes": "monter",
    "montât": "monter",
    "montâtes": "monter",
    "montèrent": "monter",
    "monté": "monter",
    "montée": "monter",
    "montées": "monter",
    "monténégrines": "monténégrin",
    "montés": "monter",
    "monumentale": "monumental",
    "monumentales": "monumental",
    "monumentaux": "monumental",
    "monuments": "monument",
    "monégasques": "monégasque",
    "monétaires": "monétaire",
    "monômes": "monôme",
    "moonistes": "mooniste",
    "moqua": "moquer",
    "moquai": "moquer",
    "moquaient": "moquer",
    "moquais": "moquer",
    "moquait": "moquer",
    "moquant": "moquer",
    "moquas": "moquer",
    "moquasse": "moquer",
    "moquassent": "moquer",
    "moquasses": "moquer",
    "moquassiez": "moquer",
    "moquassions": "moquer",
    "moque": "moquer",
    "moquent": "moquer",
    "moquera": "moquer",
    "moquerai": "moquer",
    "moqueraient": "moquer",
    "moquerais": "moquer",
    "moquerait": "moquer",
    "moqueras": "moquer",
    "moquerez": "moquer",
    "moqueries": "moquerie",
    "moqueriez": "moquer",
    "moquerions": "moquer",
    "moquerons": "moquer",
    "moqueront": "moquer",
    "moques": "moquer",
    "moquetta": "moquetter",
    "moquettai": "moquetter",
    "moquettaient": "moquetter",
    "moquettais": "moquetter",
    "moquettait": "moquetter",
    "moquettant": "moquetter",
    "moquettas": "moquetter",
    "moquettasse": "moquetter",
    "moquettassent": "moquetter",
    "moquettasses": "moquetter",
    "moquettassiez": "moquetter",
    "moquettassions": "moquetter",
    "moquette": "moquetter",
    "moquettent": "moquetter",
    "moquettera": "moquetter",
    "moquetterai": "moquetter",
    "moquetteraient": "moquetter",
    "moquetterais": "moquetter",
    "moquetterait": "moquetter",
    "moquetteras": "moquetter",
    "moquetterez": "moquetter",
    "moquetteriez": "moquetter",
    "moquetterions": "moquetter",
    "moquetterons": "moquetter",
    "moquetteront": "moquetter",
    "moquettes": "moquetter",
    "moquettez": "moquetter",
    "moquettiez": "moquetter",
    "moquettions": "moquetter",
    "moquettons": "moquetter",
    "moquettâmes": "moquetter",
    "moquettât": "moquetter",
    "moquettâtes": "moquetter",
    "moquettèrent": "moquetter",
    "moquetté": "moquetter",
    "moquettée": "moquetter",
    "moquettées": "moquetter",
    "moquettés": "moquetter",
    "moqueurs": "moqueur",
    "moqueuse": "moqueur",
    "moqueuses": "moqueur",
    "moquez": "moquer",
    "moquiez": "moquer",
    "moquions": "moquer",
    "moquons": "moquer",
    "moquâmes": "moquer",
    "moquât": "moquer",
    "moquâtes": "moquer",
    "moquèrent": "moquer",
    "moqué": "moquer",
    "moquée": "moquer",
    "moquées": "moquer",
    "moqués": "moquer",
    "moraines": "moraine",
    "morainiques": "morainique",
    "morale": "moral",
    "morales": "morale",
    "moralisa": "moraliser",
    "moralisai": "moraliser",
    "moralisaient": "moraliser",
    "moralisais": "moraliser",
    "moralisait": "moraliser",
    "moralisant": "moraliser",
    "moralisante": "moralisant",
    "moralisas": "moraliser",
    "moralisasse": "moraliser",
    "moralisassent": "moraliser",
    "moralisasses": "moraliser",
    "moralisassiez": "moraliser",
    "moralisassions": "moraliser",
    "moralisateurs": "moralisateur",
    "moralisations": "moralisation",
    "moralisatrice": "moralisateur",
    "moralise": "moraliser",
    "moralisent": "moraliser",
    "moralisera": "moraliser",
    "moraliserai": "moraliser",
    "moraliseraient": "moraliser",
    "moraliserais": "moraliser",
    "moraliserait": "moraliser",
    "moraliseras": "moraliser",
    "moraliserez": "moraliser",
    "moraliseriez": "moraliser",
    "moraliserions": "moraliser",
    "moraliserons": "moraliser",
    "moraliseront": "moraliser",
    "moralises": "moraliser",
    "moralisez": "moraliser",
    "moralisiez": "moraliser",
    "moralisions": "moraliser",
    "moralismes": "moralisme",
    "moralisons": "moraliser",
    "moralistes": "moraliste",
    "moralisâmes": "moraliser",
    "moralisât": "moraliser",
    "moralisâtes": "moraliser",
    "moralisèrent": "moraliser",
    "moralisé": "moraliser",
    "moralisée": "moraliser",
    "moralisées": "moraliser",
    "moralisés": "moraliser",
    "moralités": "moralité",
    "morasses": "morasse",
    "moratoires": "moratoire",
    "moraux": "moral",
    "moraves": "morave",
    "morbacs": "morbac",
    "morbaques": "morbaque",
    "morbides": "morbide",
    "morbidités": "morbidité",
    "morceaux": "morceau",
    "morcela": "morceler",
    "morcelai": "morceler",
    "morcelaient": "morceler",
    "morcelais": "morceler",
    "morcelait": "morceler",
    "morcelant": "morceler",
    "morcelas": "morceler",
    "morcelasse": "morceler",
    "morcelassent": "morceler",
    "morcelasses": "morceler",
    "morcelassiez": "morceler",
    "morcelassions": "morceler",
    "morcelez": "morceler",
    "morceliez": "morceler",
    "morcelions": "morceler",
    "morcelle": "morceler",
    "morcellements": "morcellement",
    "morcellent": "morceler",
    "morcellera": "morceler",
    "morcellerai": "morceler",
    "morcelleraient": "morceler",
    "morcellerais": "morceler",
    "morcellerait": "morceler",
    "morcelleras": "morceler",
    "morcellerez": "morceler",
    "morcelleriez": "morceler",
    "morcellerions": "morceler",
    "morcellerons": "morceler",
    "morcelleront": "morceler",
    "morcelles": "morceler",
    "morcelons": "morceler",
    "morcelâmes": "morceler",
    "morcelât": "morceler",
    "morcelâtes": "morceler",
    "morcelèrent": "morceler",
    "morcelé": "morceler",
    "morcelée": "morceler",
    "morcelées": "morceler",
    "morcelés": "morceler",
    "morcifs": "morcif",
    "mord": "mordre",
    "mordacités": "mordacité",
    "mordaient": "mordre",
    "mordais": "mordre",
    "mordait": "mordre",
    "mordance": "mordancer",
    "mordancent": "mordancer",
    "mordancera": "mordancer",
    "mordancerai": "mordancer",
    "mordanceraient": "mordancer",
    "mordancerais": "mordancer",
    "mordancerait": "mordancer",
    "mordanceras": "mordancer",
    "mordancerez": "mordancer",
    "mordanceriez": "mordancer",
    "mordancerions": "mordancer",
    "mordancerons": "mordancer",
    "mordanceront": "mordancer",
    "mordances": "mordancer",
    "mordancez": "mordancer",
    "mordanciez": "mordancer",
    "mordancions": "mordancer",
    "mordancèrent": "mordancer",
    "mordancé": "mordancer",
    "mordancée": "mordancer",
    "mordancées": "mordancer",
    "mordancés": "mordancer",
    "mordant": "mordre",
    "mordante": "mordant",
    "mordantes": "mordant",
    "mordants": "mordant",
    "mordança": "mordancer",
    "mordançages": "mordançage",
    "mordançai": "mordancer",
    "mordançaient": "mordancer",
    "mordançais": "mordancer",
    "mordançait": "mordancer",
    "mordançant": "mordancer",
    "mordanças": "mordancer",
    "mordançasse": "mordancer",
    "mordançassent": "mordancer",
    "mordançasses": "mordancer",
    "mordançassiez": "mordancer",
    "mordançassions": "mordancer",
    "mordançons": "mordancer",
    "mordançâmes": "mordancer",
    "mordançât": "mordancer",
    "mordançâtes": "mordancer",
    "morde": "mordre",
    "mordent": "mordre",
    "mordes": "mordre",
    "mordeurs": "mordeur",
    "mordeuse": "mordeur",
    "mordez": "mordre",
    "mordiez": "mordre",
    "mordilla": "mordiller",
    "mordillai": "mordiller",
    "mordillaient": "mordiller",
    "mordillais": "mordiller",
    "mordillait": "mordiller",
    "mordillant": "mordiller",
    "mordillas": "mordiller",
    "mordillasse": "mordiller",
    "mordillassent": "mordiller",
    "mordillasses": "mordiller",
    "mordillassiez": "mordiller",
    "mordillassions": "mordiller",
    "mordille": "mordiller",
    "mordillements": "mordillement",
    "mordillent": "mordiller",
    "mordillera": "mordiller",
    "mordillerai": "mordiller",
    "mordilleraient": "mordiller",
    "mordillerais": "mordiller",
    "mordillerait": "mordiller",
    "mordilleras": "mordiller",
    "mordillerez": "mordiller",
    "mordilleriez": "mordiller",
    "mordillerions": "mordiller",
    "mordillerons": "mordiller",
    "mordilleront": "mordiller",
    "mordilles": "mordiller",
    "mordillez": "mordiller",
    "mordilliez": "mordiller",
    "mordillions": "mordiller",
    "mordillons": "mordiller",
    "mordillâmes": "mordiller",
    "mordillât": "mordiller",
    "mordillâtes": "mordiller",
    "mordillèrent": "mordiller",
    "mordillé": "mordiller",
    "mordillée": "mordiller",
    "mordillées": "mordiller",
    "mordillés": "mordiller",
    "mordions": "mordre",
    "mordirent": "mordre",
    "mordis": "mordre",
    "mordisse": "mordre",
    "mordissent": "mordre",
    "mordisses": "mordre",
    "mordissiez": "mordre",
    "mordissions": "mordre",
    "mordit": "mordre",
    "mordons": "mordre",
    "mordora": "mordorer",
    "mordorai": "mordorer",
    "mordoraient": "mordorer",
    "mordorais": "mordorer",
    "mordorait": "mordorer",
    "mordorant": "mordorer",
    "mordoras": "mordorer",
    "mordorasse": "mordorer",
    "mordorassent": "mordorer",
    "mordorasses": "mordorer",
    "mordorassiez": "mordorer",
    "mordorassions": "mordorer",
    "mordore": "mordorer",
    "mordorent": "mordorer",
    "mordorera": "mordorer",
    "mordorerai": "mordorer",
    "mordoreraient": "mordorer",
    "mordorerais": "mordorer",
    "mordorerait": "mordorer",
    "mordoreras": "mordorer",
    "mordorerez": "mordorer",
    "mordoreriez": "mordorer",
    "mordorerions": "mordorer",
    "mordorerons": "mordorer",
    "mordoreront": "mordorer",
    "mordores": "mordorer",
    "mordorez": "mordorer",
    "mordoriez": "mordorer",
    "mordorions": "mordorer",
    "mordorons": "mordorer",
    "mordorâmes": "mordorer",
    "mordorât": "mordorer",
    "mordorâtes": "mordorer",
    "mordorèrent": "mordorer",
    "mordoré": "mordorer",
    "mordorée": "mordorer",
    "mordorées": "mordorer",
    "mordorés": "mordorer",
    "mordra": "mordre",
    "mordrai": "mordre",
    "mordraient": "mordre",
    "mordrais": "mordre",
    "mordrait": "mordre",
    "mordras": "mordre",
    "mordrez": "mordre",
    "mordriez": "mordre",
    "mordrions": "mordre",
    "mordrons": "mordre",
    "mordront": "mordre",
    "mords": "mordre",
    "mordu": "mordre",
    "mordue": "mordu",
    "mordues": "mordu",
    "mordus": "mordu",
    "mordîmes": "mordre",
    "mordît": "mordre",
    "mordîtes": "mordre",
    "morelles": "morelle",
    "mores": "more",
    "moresques": "moresque",
    "morfale": "morfaler",
    "morfales": "morfal",
    "morfals": "morfal",
    "morfalé": "morfaler",
    "morfalée": "morfaler",
    "morfalés": "morfaler",
    "morfils": "morfil",
    "morflais": "morfler",
    "morflait": "morfler",
    "morfle": "morfler",
    "morflera": "morfler",
    "morfleras": "morfler",
    "morflerez": "morfler",
    "morfles": "morfler",
    "morflé": "morfler",
    "morflée": "morfler",
    "morfond": "morfondre",
    "morfondaient": "morfondre",
    "morfondais": "morfondre",
    "morfondait": "morfondre",
    "morfondant": "morfondre",
    "morfonde": "morfondre",
    "morfondent": "morfondre",
    "morfondes": "morfondre",
    "morfondez": "morfondre",
    "morfondiez": "morfondre",
    "morfondions": "morfondre",
    "morfondirent": "morfondre",
    "morfondis": "morfondre",
    "morfondisse": "morfondre",
    "morfondissent": "morfondre",
    "morfondisses": "morfondre",
    "morfondissiez": "morfondre",
    "morfondissions": "morfondre",
    "morfondit": "morfondre",
    "morfondons": "morfondre",
    "morfondra": "morfondre",
    "morfondrai": "morfondre",
    "morfondraient": "morfondre",
    "morfondrais": "morfondre",
    "morfondrait": "morfondre",
    "morfondras": "morfondre",
    "morfondrez": "morfondre",
    "morfondriez": "morfondre",
    "morfondrions": "morfondre",
    "morfondrons": "morfondre",
    "morfondront": "morfondre",
    "morfonds": "morfondre",
    "morfondu": "morfondre",
    "morfondue": "morfondu",
    "morfondues": "morfondre",
    "morfondus": "morfondre",
    "morfondîmes": "morfondre",
    "morfondît": "morfondre",
    "morfondîtes": "morfondre",
    "morgana": "morganer",
    "morganatiques": "morganatique",
    "morgane": "morganer",
    "morganerai": "morganer",
    "morgues": "morgue",
    "moribonde": "moribond",
    "moribondes": "moribond",
    "moribonds": "moribond",
    "moricaude": "moricaud",
    "moricaudes": "moricaud",
    "moricauds": "moricaud",
    "morigène": "morigéner",
    "morigènent": "morigéner",
    "morigènes": "morigéner",
    "morigéna": "morigéner",
    "morigénai": "morigéner",
    "morigénaient": "morigéner",
    "morigénais": "morigéner",
    "morigénait": "morigéner",
    "morigénant": "morigéner",
    "morigénas": "morigéner",
    "morigénasse": "morigéner",
    "morigénassent": "morigéner",
    "morigénasses": "morigéner",
    "morigénassiez": "morigéner",
    "morigénassions": "morigéner",
    "morigénera": "morigéner",
    "morigénerai": "morigéner",
    "morigéneraient": "morigéner",
    "morigénerais": "morigéner",
    "morigénerait": "morigéner",
    "morigéneras": "morigéner",
    "morigénerez": "morigéner",
    "morigéneriez": "morigéner",
    "morigénerions": "morigéner",
    "morigénerons": "morigéner",
    "morigéneront": "morigéner",
    "morigénez": "morigéner",
    "morigéniez": "morigéner",
    "morigénions": "morigéner",
    "morigénons": "morigéner",
    "morigénâmes": "morigéner",
    "morigénât": "morigéner",
    "morigénâtes": "morigéner",
    "morigénèrent": "morigéner",
    "morigéné": "morigéner",
    "morigénée": "morigéner",
    "morigénées": "morigéner",
    "morigénés": "morigéner",
    "morilles": "morille",
    "morillons": "morillon",
    "morlingues": "morlingue",
    "mormone": "mormon",
    "mormones": "mormon",
    "mormons": "mormon",
    "mornes": "morne",
    "mornifles": "mornifle",
    "moroses": "morose",
    "morosités": "morosité",
    "morphines": "morphine",
    "morphologies": "morphologie",
    "morphologiques": "morphologique",
    "morpions": "morpion",
    "morses": "morse",
    "morsures": "morsure",
    "mort": "mourir",
    "mort-née": "mort-né",
    "mort-nées": "mort-né",
    "mort-nés": "mort-né",
    "mortadelles": "mortadelle",
    "mortaises": "mortaise",
    "mortaiseuse": "mortaiseur",
    "mortalités": "mortalité",
    "morte": "mourir",
    "mortelle": "mortel",
    "mortelles": "mortel",
    "mortels": "mortel",
    "mortes": "mourir",
    "mortes-eaux": "morte-eau",
    "mortes-saisons": "morte-saison",
    "mortiers": "mortier",
    "mortifia": "mortifier",
    "mortifiai": "mortifier",
    "mortifiaient": "mortifier",
    "mortifiais": "mortifier",
    "mortifiait": "mortifier",
    "mortifiant": "mortifier",
    "mortifiante": "mortifiant",
    "mortifiantes": "mortifiant",
    "mortifiants": "mortifiant",
    "mortifias": "mortifier",
    "mortifiasse": "mortifier",
    "mortifiassent": "mortifier",
    "mortifiasses": "mortifier",
    "mortifiassiez": "mortifier",
    "mortifiassions": "mortifier",
    "mortifications": "mortification",
    "mortifie": "mortifier",
    "mortifient": "mortifier",
    "mortifiera": "mortifier",
    "mortifierai": "mortifier",
    "mortifieraient": "mortifier",
    "mortifierais": "mortifier",
    "mortifierait": "mortifier",
    "mortifieras": "mortifier",
    "mortifierez": "mortifier",
    "mortifieriez": "mortifier",
    "mortifierions": "mortifier",
    "mortifierons": "mortifier",
    "mortifieront": "mortifier",
    "mortifies": "mortifier",
    "mortifiez": "mortifier",
    "mortifiiez": "mortifier",
    "mortifiions": "mortifier",
    "mortifions": "mortifier",
    "mortifiâmes": "mortifier",
    "mortifiât": "mortifier",
    "mortifiâtes": "mortifier",
    "mortifièrent": "mortifier",
    "mortifié": "mortifier",
    "mortifiée": "mortifier",
    "mortifiées": "mortifier",
    "mortifiés": "mortifier",
    "mortifères": "mortifère",
    "mortinatalités": "mortinatalité",
    "morts": "mourir",
    "morts-bois": "mort-bois",
    "morts-vivants": "mort-vivant",
    "mortuaires": "mortuaire",
    "morues": "morue",
    "morulas": "morula",
    "morutiers": "morutier",
    "morutière": "morutier",
    "morutières": "morutier",
    "morves": "morve",
    "morveuse": "morveux",
    "morveuses": "morveux",
    "mosaïques": "mosaïque",
    "mosaïquée": "mosaïqué",
    "mosaïqués": "mosaïqué",
    "moscovites": "moscovite",
    "mosellane": "mosellan",
    "mosellanes": "mosellan",
    "mosquées": "mosquée",
    "motarde": "motard",
    "motardes": "motard",
    "motards": "motard",
    "motels": "motel",
    "motets": "motet",
    "moteurs": "moteur",
    "moteurs-fusées": "moteur-fusée",
    "motifs": "motif",
    "motions": "motion",
    "motiva": "motiver",
    "motivai": "motiver",
    "motivaient": "motiver",
    "motivais": "motiver",
    "motivait": "motiver",
    "motivant": "motiver",
    "motivante": "motivant",
    "motivas": "motiver",
    "motivasse": "motiver",
    "motivassent": "motiver",
    "motivasses": "motiver",
    "motivassiez": "motiver",
    "motivassions": "motiver",
    "motivations": "motivation",
    "motive": "motiver",
    "motivent": "motiver",
    "motivera": "motiver",
    "motiverai": "motiver",
    "motiveraient": "motiver",
    "motiverais": "motiver",
    "motiverait": "motiver",
    "motiveras": "motiver",
    "motiverez": "motiver",
    "motiveriez": "motiver",
    "motiverions": "motiver",
    "motiverons": "motiver",
    "motiveront": "motiver",
    "motives": "motiver",
    "motivez": "motiver",
    "motiviez": "motiver",
    "motivions": "motiver",
    "motivons": "motiver",
    "motivâmes": "motiver",
    "motivât": "motiver",
    "motivâtes": "motiver",
    "motivèrent": "motiver",
    "motivé": "motiver",
    "motivée": "motiver",
    "motivées": "motiver",
    "motivés": "motiver",
    "motocultures": "motoculture",
    "motocycles": "motocycle",
    "motocyclettes": "motocyclette",
    "motocyclistes": "motocycliste",
    "motoneiges": "motoneige",
    "motopompes": "motopompe",
    "motorisations": "motorisation",
    "motoristes": "motoriste",
    "motorisé": "motoriser",
    "motorisée": "motoriser",
    "motorisées": "motoriser",
    "motorisés": "motoriser",
    "motos": "moto",
    "mototaxis": "mototaxi",
    "motrice": "moteur",
    "motrices": "motrice",
    "motricités": "motricité",
    "mots": "mot",
    "mots-clefs": "mot-clef",
    "mots-clés": "mot-clé",
    "mottes": "motte",
    "moucha": "moucher",
    "mouchai": "moucher",
    "mouchaient": "moucher",
    "mouchais": "moucher",
    "mouchait": "moucher",
    "mouchant": "moucher",
    "moucharabiehs": "moucharabieh",
    "moucharda": "moucharder",
    "mouchardait": "moucharder",
    "moucharde": "moucharder",
    "mouchardent": "moucharder",
    "mouchardera": "moucharder",
    "moucharderait": "moucharder",
    "mouchardes": "moucharder",
    "mouchards": "mouchard",
    "mouchardé": "moucharder",
    "mouchas": "moucher",
    "mouchasse": "moucher",
    "mouchassent": "moucher",
    "mouchasses": "moucher",
    "mouchassiez": "moucher",
    "mouchassions": "moucher",
    "mouche": "moucher",
    "mouchent": "moucher",
    "mouchera": "moucher",
    "moucherai": "moucher",
    "moucheraient": "moucher",
    "moucherais": "moucher",
    "moucherait": "moucher",
    "moucheras": "moucher",
    "moucherez": "moucher",
    "moucheriez": "moucher",
    "moucherions": "moucher",
    "moucherons": "moucheron",
    "moucheront": "moucher",
    "mouches": "moucher",
    "moucheta": "moucheter",
    "mouchetai": "moucheter",
    "mouchetaient": "moucheter",
    "mouchetais": "moucheter",
    "mouchetait": "moucheter",
    "mouchetant": "moucheter",
    "mouchetas": "moucheter",
    "mouchetasse": "moucheter",
    "mouchetassent": "moucheter",
    "mouchetasses": "moucheter",
    "mouchetassiez": "moucheter",
    "mouchetassions": "moucheter",
    "mouchetez": "moucheter",
    "mouchetiez": "moucheter",
    "mouchetions": "moucheter",
    "mouchetons": "moucheter",
    "mouchette": "moucheter",
    "mouchettent": "moucheter",
    "mouchettera": "moucheter",
    "mouchetterai": "moucheter",
    "mouchetteraient": "moucheter",
    "mouchetterais": "moucheter",
    "mouchetterait": "moucheter",
    "mouchetteras": "moucheter",
    "mouchetterez": "moucheter",
    "mouchetteriez": "moucheter",
    "mouchetterions": "moucheter",
    "mouchetterons": "moucheter",
    "mouchetteront": "moucheter",
    "mouchettes": "mouchette",
    "mouchetures": "moucheture",
    "mouchetâmes": "moucheter",
    "mouchetât": "moucheter",
    "mouchetâtes": "moucheter",
    "mouchetèrent": "moucheter",
    "moucheté": "moucheter",
    "mouchetée": "moucheter",
    "mouchetées": "moucheter",
    "mouchetés": "moucheter",
    "mouchez": "moucher",
    "mouchiez": "moucher",
    "mouchions": "moucher",
    "mouchoirs": "mouchoir",
    "mouchons": "moucher",
    "mouchâmes": "moucher",
    "mouchât": "moucher",
    "mouchâtes": "moucher",
    "mouchèrent": "moucher",
    "mouché": "moucher",
    "mouchée": "moucher",
    "mouchées": "moucher",
    "mouchés": "moucher",
    "moud": "moudre",
    "moudra": "moudre",
    "moudrai": "moudre",
    "moudraient": "moudre",
    "moudrais": "moudre",
    "moudrait": "moudre",
    "moudras": "moudre",
    "moudrez": "moudre",
    "moudriez": "moudre",
    "moudrions": "moudre",
    "moudrons": "moudre",
    "moudront": "moudre",
    "mouds": "moudre",
    "moues": "moue",
    "mouettes": "mouette",
    "moufetait": "moufeter",
    "moufettes": "moufette",
    "moufeté": "moufeter",
    "mouffettes": "mouffette",
    "moufles": "moufle",
    "mouflets": "mouflet",
    "mouflette": "mouflet",
    "mouflettes": "mouflette",
    "mouflons": "mouflon",
    "moufta": "moufter",
    "mouftai": "moufter",
    "mouftaient": "moufter",
    "mouftais": "moufter",
    "mouftait": "moufter",
    "mouftant": "moufter",
    "mouftas": "moufter",
    "mouftasse": "moufter",
    "mouftassent": "moufter",
    "mouftasses": "moufter",
    "mouftassiez": "moufter",
    "mouftassions": "moufter",
    "moufte": "moufter",
    "mouftent": "moufter",
    "mouftera": "moufter",
    "moufterai": "moufter",
    "moufteraient": "moufter",
    "moufterais": "moufter",
    "moufterait": "moufter",
    "moufteras": "moufter",
    "moufterez": "moufter",
    "moufteriez": "moufter",
    "moufterions": "moufter",
    "moufterons": "moufter",
    "moufteront": "moufter",
    "mouftes": "moufter",
    "mouftez": "moufter",
    "mouftiez": "moufter",
    "mouftions": "moufter",
    "mouftons": "moufter",
    "mouftâmes": "moufter",
    "mouftât": "moufter",
    "mouftâtes": "moufter",
    "mouftèrent": "moufter",
    "moufté": "moufter",
    "mouftée": "moufter",
    "mouftées": "moufter",
    "mouftés": "moufter",
    "mouilla": "mouiller",
    "mouillages": "mouillage",
    "mouillai": "mouiller",
    "mouillaient": "mouiller",
    "mouillais": "mouiller",
    "mouillait": "mouiller",
    "mouillant": "mouiller",
    "mouillante": "mouillant",
    "mouillas": "mouiller",
    "mouillasse": "mouiller",
    "mouillassent": "mouiller",
    "mouillasses": "mouiller",
    "mouillassiez": "mouiller",
    "mouillassions": "mouiller",
    "mouille": "mouiller",
    "mouillent": "mouiller",
    "mouillera": "mouiller",
    "mouillerai": "mouiller",
    "mouilleraient": "mouiller",
    "mouillerais": "mouiller",
    "mouillerait": "mouiller",
    "mouilleras": "mouiller",
    "mouillerez": "mouiller",
    "mouilleriez": "mouiller",
    "mouillerions": "mouiller",
    "mouillerons": "mouiller",
    "mouilleront": "mouiller",
    "mouilles": "mouiller",
    "mouillettes": "mouillette",
    "mouilleuse": "mouilleur",
    "mouillez": "mouiller",
    "mouilliez": "mouiller",
    "mouillions": "mouiller",
    "mouillons": "mouillon",
    "mouillures": "mouillure",
    "mouillâmes": "mouiller",
    "mouillât": "mouiller",
    "mouillâtes": "mouiller",
    "mouillèrent": "mouiller",
    "mouillé": "mouiller",
    "mouillée": "mouiller",
    "mouillées": "mouiller",
    "mouillés": "mouiller",
    "mouises": "mouise",
    "moujiks": "moujik",
    "moujingues": "moujingue",
    "moukères": "moukère",
    "moula": "mouler",
    "moulages": "moulage",
    "moulai": "mouler",
    "moulaient": "mouler",
    "moulais": "mouler",
    "moulait": "mouler",
    "moulant": "mouler",
    "moulante": "moulant",
    "moulantes": "moulant",
    "moulants": "moulant",
    "moulas": "mouler",
    "moulasse": "mouler",
    "moulassent": "mouler",
    "moulasses": "mouler",
    "moulassiez": "mouler",
    "moulassions": "mouler",
    "moule": "mouler",
    "moulent": "mouler",
    "moulera": "mouler",
    "moulerai": "mouler",
    "mouleraient": "mouler",
    "moulerais": "mouler",
    "moulerait": "mouler",
    "mouleras": "mouler",
    "moulerez": "mouler",
    "mouleriez": "mouler",
    "moulerions": "mouler",
    "moulerons": "mouler",
    "mouleront": "mouler",
    "moules": "mouler",
    "moulez": "mouler",
    "mouliez": "mouler",
    "moulina": "mouliner",
    "moulinai": "mouliner",
    "moulinaient": "mouliner",
    "moulinais": "mouliner",
    "moulinait": "mouliner",
    "moulinant": "mouliner",
    "moulinas": "mouliner",
    "moulinasse": "mouliner",
    "moulinassent": "mouliner",
    "moulinasses": "mouliner",
    "moulinassiez": "mouliner",
    "moulinassions": "mouliner",
    "mouline": "mouliner",
    "moulinent": "mouliner",
    "moulinera": "mouliner",
    "moulinerai": "mouliner",
    "moulineraient": "mouliner",
    "moulinerais": "mouliner",
    "moulinerait": "mouliner",
    "moulineras": "mouliner",
    "moulinerez": "mouliner",
    "moulineriez": "mouliner",
    "moulinerions": "mouliner",
    "moulinerons": "mouliner",
    "moulineront": "mouliner",
    "moulines": "mouliner",
    "moulinets": "moulinet",
    "moulinettes": "moulinette",
    "moulinez": "mouliner",
    "mouliniez": "mouliner",
    "moulinions": "mouliner",
    "moulinons": "mouliner",
    "moulins": "moulin",
    "moulinâmes": "mouliner",
    "moulinât": "mouliner",
    "moulinâtes": "mouliner",
    "moulinèrent": "mouliner",
    "mouliné": "mouliner",
    "moulinée": "mouliner",
    "moulinées": "mouliner",
    "moulinés": "mouliner",
    "moulions": "mouler",
    "moulons": "mouler",
    "moulu": "moudre",
    "moulue": "moulu",
    "moulues": "moulu",
    "moulurations": "mouluration",
    "moulurent": "moudre",
    "moulures": "moulure",
    "mouluré": "moulurer",
    "moulus": "moulu",
    "moulusse": "moudre",
    "moulussent": "moudre",
    "moulusses": "moudre",
    "moulussiez": "moudre",
    "moulussions": "moudre",
    "moulut": "moudre",
    "moulâmes": "mouler",
    "moulât": "mouler",
    "moulâtes": "mouler",
    "moulèrent": "mouler",
    "moulé": "mouler",
    "moulée": "mouler",
    "moulées": "mouler",
    "moulés": "mouler",
    "moulûmes": "moudre",
    "moulût": "moudre",
    "moulûtes": "moudre",
    "moumounes": "moumoune",
    "moumoutes": "moumoute",
    "mouraient": "mourir",
    "mourais": "mourir",
    "mourait": "mourir",
    "mourant": "mourir",
    "mourante": "mourant",
    "mourantes": "mourant",
    "mourants": "mourant",
    "mourez": "mourir",
    "mourides": "mouride",
    "mouriez": "mourir",
    "mourions": "mourir",
    "mouronne": "mouronner",
    "mourons": "mouron",
    "mourra": "mourir",
    "mourrai": "mourir",
    "mourraient": "mourir",
    "mourrais": "mourir",
    "mourrait": "mourir",
    "mourras": "mourir",
    "mourrez": "mourir",
    "mourriez": "mourir",
    "mourrions": "mourir",
    "mourrons": "mourir",
    "mourront": "mourir",
    "moururent": "mourir",
    "mourus": "mourir",
    "mourusse": "mourir",
    "mourussent": "mourir",
    "mourusses": "mourir",
    "mourussiez": "mourir",
    "mourussions": "mourir",
    "mourut": "mourir",
    "mourûmes": "mourir",
    "mourût": "mourir",
    "mourûtes": "mourir",
    "mous": "mou",
    "mouscailles": "mouscaille",
    "mousmés": "mousmé",
    "mousquetades": "mousquetade",
    "mousquetaires": "mousquetaire",
    "mousquetons": "mousqueton",
    "mousquets": "mousquet",
    "moussa": "mousser",
    "moussai": "mousser",
    "moussaient": "mousser",
    "moussaillons": "moussaillon",
    "moussais": "mousser",
    "moussait": "mousser",
    "moussakas": "moussaka",
    "moussant": "mousser",
    "moussante": "moussant",
    "moussants": "moussant",
    "moussas": "mousser",
    "moussasse": "mousser",
    "moussassent": "mousser",
    "moussasses": "mousser",
    "moussassiez": "mousser",
    "moussassions": "mousser",
    "mousse": "mousser",
    "mousselines": "mousseline",
    "moussent": "mousser",
    "moussera": "mousser",
    "mousserai": "mousser",
    "mousseraient": "mousser",
    "mousserais": "mousser",
    "mousserait": "mousser",
    "mousseras": "mousser",
    "mousserez": "mousser",
    "mousseriez": "mousser",
    "mousserions": "mousser",
    "mousserons": "mousseron",
    "mousseront": "mousser",
    "mousses": "mousser",
    "mousseuse": "mousseux",
    "mousseuses": "mousseux",
    "moussez": "mousser",
    "moussiez": "mousser",
    "moussions": "mousser",
    "moussons": "mousson",
    "moussue": "moussu",
    "moussues": "moussu",
    "moussus": "moussu",
    "moussâmes": "mousser",
    "moussât": "mousser",
    "moussâtes": "mousser",
    "moussèrent": "mousser",
    "moussé": "mousser",
    "moussée": "mousser",
    "moussées": "mousser",
    "moussés": "mousser",
    "moustaches": "moustache",
    "moustachue": "moustachu",
    "moustachues": "moustachu",
    "moustachus": "moustachu",
    "moustagaches": "moustagache",
    "moustiquaires": "moustiquaire",
    "moustiques": "moustique",
    "moutardes": "moutarde",
    "moutards": "moutard",
    "moutardé": "moutarder",
    "moutiers": "moutier",
    "moutonna": "moutonner",
    "moutonnai": "moutonner",
    "moutonnaient": "moutonner",
    "moutonnais": "moutonner",
    "moutonnait": "moutonner",
    "moutonnant": "moutonner",
    "moutonnante": "moutonnant",
    "moutonnantes": "moutonnant",
    "moutonnants": "moutonnant",
    "moutonnas": "moutonner",
    "moutonnasse": "moutonner",
    "moutonnassent": "moutonner",
    "moutonnasses": "moutonner",
    "moutonnassiez": "moutonner",
    "moutonnassions": "moutonner",
    "moutonne": "moutonner",
    "moutonnements": "moutonnement",
    "moutonnent": "moutonner",
    "moutonnera": "moutonner",
    "moutonnerai": "moutonner",
    "moutonneraient": "moutonner",
    "moutonnerais": "moutonner",
    "moutonnerait": "moutonner",
    "moutonneras": "moutonner",
    "moutonnerez": "moutonner",
    "moutonneriez": "moutonner",
    "moutonnerions": "moutonner",
    "moutonnerons": "moutonner",
    "moutonneront": "moutonner",
    "moutonnes": "moutonner",
    "moutonnez": "moutonner",
    "moutonniers": "moutonnier",
    "moutonniez": "moutonner",
    "moutonnions": "moutonner",
    "moutonnière": "moutonnier",
    "moutonnons": "moutonner",
    "moutonnâmes": "moutonner",
    "moutonnât": "moutonner",
    "moutonnâtes": "moutonner",
    "moutonnèrent": "moutonner",
    "moutonné": "moutonner",
    "moutons": "mouton",
    "moutures": "mouture",
    "mouvaient": "mouvoir",
    "mouvais": "mouvoir",
    "mouvait": "mouvoir",
    "mouvances": "mouvance",
    "mouvant": "mouvoir",
    "mouvante": "mouvant",
    "mouvantes": "mouvant",
    "mouvants": "mouvant",
    "mouvementent": "mouvementer",
    "mouvements": "mouvement",
    "mouvementé": "mouvementer",
    "mouvementée": "mouvementer",
    "mouvementées": "mouvementer",
    "mouvementés": "mouvementer",
    "mouvez": "mouvoir",
    "mouviez": "mouvoir",
    "mouvions": "mouvoir",
    "mouvons": "mouvoir",
    "mouvra": "mouvoir",
    "mouvrai": "mouvoir",
    "mouvraient": "mouvoir",
    "mouvrais": "mouvoir",
    "mouvrait": "mouvoir",
    "mouvras": "mouvoir",
    "mouvrez": "mouvoir",
    "mouvriez": "mouvoir",
    "mouvrions": "mouvoir",
    "mouvrons": "mouvoir",
    "mouvront": "mouvoir",
    "moyen-courriers": "moyen-courrier",
    "moyennant": "moyenner",
    "moyenne": "moyenner",
    "moyennes": "moyenne",
    "moyens": "moyen",
    "moyenâgeuse": "moyenâgeux",
    "moyenâgeuses": "moyenâgeux",
    "moyes": "moye",
    "moyettes": "moyette",
    "moyeux": "moyeu",
    "mozarabes": "mozarabe",
    "mozartienne": "mozartien",
    "mozartiennes": "mozartien",
    "mozartiens": "mozartien",
    "moïses": "moïse",
    "moûts": "moût",
    "mua": "muer",
    "muai": "muer",
    "muaient": "muer",
    "muais": "muer",
    "muait": "muer",
    "muant": "muer",
    "muas": "muer",
    "muasse": "muer",
    "muassent": "muer",
    "muasses": "muer",
    "muassiez": "muer",
    "muassions": "muer",
    "muchachos": "muchacho",
    "muchas": "mucher",
    "muche": "mucher",
    "mucilages": "mucilage",
    "mucilagineuse": "mucilagineux",
    "mucosités": "mucosité",
    "mucoviscidoses": "mucoviscidose",
    "mudéjare": "mudéjar",
    "mue": "muer",
    "muent": "muer",
    "muera": "muer",
    "muerai": "muer",
    "mueraient": "muer",
    "muerais": "muer",
    "muerait": "muer",
    "mueras": "muer",
    "muerez": "muer",
    "mueriez": "muer",
    "muerions": "muer",
    "muerons": "muer",
    "mueront": "muer",
    "mues": "muer",
    "muets": "muet",
    "muette": "muet",
    "muettes": "muette",
    "muez": "muer",
    "muezzins": "muezzin",
    "muffins": "muffin",
    "mufleries": "muflerie",
    "mufles": "mufle",
    "mufliers": "muflier",
    "muftis": "mufti",
    "muges": "muge",
    "mugi": "mugir",
    "mugira": "mugir",
    "mugirai": "mugir",
    "mugiraient": "mugir",
    "mugirais": "mugir",
    "mugirait": "mugir",
    "mugiras": "mugir",
    "mugirent": "mugir",
    "mugirez": "mugir",
    "mugiriez": "mugir",
    "mugirions": "mugir",
    "mugirons": "mugir",
    "mugiront": "mugir",
    "mugis": "mugir",
    "mugissaient": "mugir",
    "mugissais": "mugir",
    "mugissait": "mugir",
    "mugissant": "mugir",
    "mugissante": "mugissant",
    "mugissantes": "mugissant",
    "mugissants": "mugissant",
    "mugisse": "mugir",
    "mugissements": "mugissement",
    "mugissent": "mugir",
    "mugisses": "mugir",
    "mugissez": "mugir",
    "mugissiez": "mugir",
    "mugissions": "mugir",
    "mugissons": "mugir",
    "mugit": "mugir",
    "muguets": "muguet",
    "muguette": "mugueter",
    "mugîmes": "mugir",
    "mugît": "mugir",
    "mugîtes": "mugir",
    "muids": "muid",
    "muiez": "muer",
    "muions": "muer",
    "mule": "mulet",
    "mule-jennys": "mule-jenny",
    "mules": "mulet",
    "muletas": "muleta",
    "muletiers": "muletier",
    "muletière": "muletier",
    "muletières": "muletier",
    "mulets": "mulet",
    "mulettes": "mulette",
    "mulots": "mulot",
    "multicolores": "multicolore",
    "multicouches": "multicouche",
    "multiculturelle": "multiculturel",
    "multiculturelles": "multiculturel",
    "multiculturels": "multiculturel",
    "multidimensionnelle": "multidimensionnel",
    "multidimensionnelles": "multidimensionnel",
    "multidimensionnels": "multidimensionnel",
    "multidisciplinaires": "multidisciplinaire",
    "multifibres": "multifibre",
    "multiformes": "multiforme",
    "multifréquences": "multifréquence",
    "multilatérale": "multilatéral",
    "multilatérales": "multilatéral",
    "multilatéraux": "multilatéral",
    "multilingues": "multilingue",
    "multilinguismes": "multilinguisme",
    "multimillionnaires": "multimillionnaire",
    "multimodale": "multimodal",
    "multimodales": "multimodal",
    "multimodaux": "multimodal",
    "multimédias": "multimédia",
    "multinationale": "multinational",
    "multinationales": "multinationale",
    "multinationaux": "multinational",
    "multipares": "multipare",
    "multipartenaires": "multipartenaire",
    "multipartismes": "multipartisme",
    "multipartites": "multipartite",
    "multiples": "multiple",
    "multiplexes": "multiplexe",
    "multiplexé": "multiplexer",
    "multiplia": "multiplier",
    "multipliai": "multiplier",
    "multipliaient": "multiplier",
    "multipliais": "multiplier",
    "multipliait": "multiplier",
    "multipliant": "multiplier",
    "multiplias": "multiplier",
    "multipliasse": "multiplier",
    "multipliassent": "multiplier",
    "multipliasses": "multiplier",
    "multipliassiez": "multiplier",
    "multipliassions": "multiplier",
    "multiplicateurs": "multiplicateur",
    "multiplications": "multiplication",
    "multiplicités": "multiplicité",
    "multiplie": "multiplier",
    "multiplient": "multiplier",
    "multipliera": "multiplier",
    "multiplierai": "multiplier",
    "multiplieraient": "multiplier",
    "multiplierais": "multiplier",
    "multiplierait": "multiplier",
    "multiplieras": "multiplier",
    "multiplierez": "multiplier",
    "multiplieriez": "multiplier",
    "multiplierions": "multiplier",
    "multiplierons": "multiplier",
    "multiplieront": "multiplier",
    "multiplies": "multiplier",
    "multipliez": "multiplier",
    "multipliiez": "multiplier",
    "multipliions": "multiplier",
    "multiplions": "multiplier",
    "multipliâmes": "multiplier",
    "multipliât": "multiplier",
    "multipliâtes": "multiplier",
    "multiplièrent": "multiplier",
    "multiplié": "multiplier",
    "multipliée": "multiplier",
    "multipliées": "multiplier",
    "multipliés": "multiplier",
    "multipropriétés": "multipropriété",
    "multiraciale": "multiracial",
    "multiraciales": "multiracial",
    "multiraciaux": "multiracial",
    "multirisques": "multirisque",
    "multirégionale": "multirégional",
    "multirégionales": "multirégional",
    "multirégionaux": "multirégional",
    "multisectorielle": "multisectoriel",
    "multisectorielles": "multisectoriel",
    "multisectoriels": "multisectoriel",
    "multiséculaires": "multiséculaire",
    "multitudes": "multitude",
    "multitâches": "multitâche",
    "mulâtres": "mulâtre",
    "mulâtresse": "mulâtre",
    "mulâtresses": "mulâtresse",
    "muni": "munir",
    "munichoise": "munichois",
    "munichoises": "munichois",
    "municipale": "municipal",
    "municipales": "municipal",
    "municipalisations": "municipalisation",
    "municipalités": "municipalité",
    "municipaux": "municipal",
    "municipes": "municipe",
    "munie": "munir",
    "munies": "munir",
    "munificences": "munificence",
    "munificente": "munificent",
    "munificentes": "munificent",
    "munificents": "munificent",
    "munira": "munir",
    "munirai": "munir",
    "muniraient": "munir",
    "munirais": "munir",
    "munirait": "munir",
    "muniras": "munir",
    "munirent": "munir",
    "munirez": "munir",
    "muniriez": "munir",
    "munirions": "munir",
    "munirons": "munir",
    "muniront": "munir",
    "munis": "munir",
    "munissaient": "munir",
    "munissais": "munir",
    "munissait": "munir",
    "munissant": "munir",
    "munisse": "munir",
    "munissent": "munir",
    "munisses": "munir",
    "munissez": "munir",
    "munissiez": "munir",
    "munissions": "munir",
    "munissons": "munir",
    "munit": "munir",
    "munitions": "munition",
    "munîmes": "munir",
    "munît": "munir",
    "munîtes": "munir",
    "muons": "muer",
    "muphtis": "muphti",
    "muqueuse": "muqueux",
    "muqueuses": "muqueux",
    "mura": "murer",
    "muraient": "murer",
    "murailles": "muraille",
    "murait": "murer",
    "murale": "mural",
    "murales": "mural",
    "murant": "murer",
    "muraux": "mural",
    "mure": "murer",
    "murent": "mouvoir",
    "murerait": "murer",
    "mures": "murer",
    "muretins": "muretin",
    "murets": "muret",
    "murettes": "murette",
    "murez": "murer",
    "muridés": "muridé",
    "murmura": "murmurer",
    "murmurai": "murmurer",
    "murmuraient": "murmurer",
    "murmurais": "murmurer",
    "murmurait": "murmurer",
    "murmurant": "murmurer",
    "murmurante": "murmurant",
    "murmurantes": "murmurant",
    "murmurants": "murmurant",
    "murmuras": "murmurer",
    "murmurasse": "murmurer",
    "murmurassent": "murmurer",
    "murmurasses": "murmurer",
    "murmurassiez": "murmurer",
    "murmurassions": "murmurer",
    "murmure": "murmurer",
    "murmurent": "murmurer",
    "murmurera": "murmurer",
    "murmurerai": "murmurer",
    "murmureraient": "murmurer",
    "murmurerais": "murmurer",
    "murmurerait": "murmurer",
    "murmureras": "murmurer",
    "murmurerez": "murmurer",
    "murmureriez": "murmurer",
    "murmurerions": "murmurer",
    "murmurerons": "murmurer",
    "murmureront": "murmurer",
    "murmures": "murmurer",
    "murmurez": "murmurer",
    "murmuriez": "murmurer",
    "murmurions": "murmurer",
    "murmurons": "murmurer",
    "murmurâmes": "murmurer",
    "murmurât": "murmurer",
    "murmurâtes": "murmurer",
    "murmurèrent": "murmurer",
    "murmuré": "murmurer",
    "murmurée": "murmurer",
    "murmurées": "murmurer",
    "murmurés": "murmurer",
    "murs": "mur",
    "murènes": "murène",
    "murèrent": "murer",
    "muré": "murer",
    "murée": "murer",
    "murées": "murer",
    "murés": "murer",
    "mus": "mu",
    "musa": "muser",
    "musagètes": "musagète",
    "musai": "muser",
    "musaient": "muser",
    "musais": "muser",
    "musait": "muser",
    "musant": "muser",
    "musaraignes": "musaraigne",
    "musarda": "musarder",
    "musardai": "musarder",
    "musardaient": "musarder",
    "musardais": "musarder",
    "musardait": "musarder",
    "musardant": "musarder",
    "musardas": "musarder",
    "musardasse": "musarder",
    "musardassent": "musarder",
    "musardasses": "musarder",
    "musardassiez": "musarder",
    "musardassions": "musarder",
    "musarde": "musarder",
    "musardent": "musarder",
    "musardera": "musarder",
    "musarderai": "musarder",
    "musarderaient": "musarder",
    "musarderais": "musarder",
    "musarderait": "musarder",
    "musarderas": "musarder",
    "musarderez": "musarder",
    "musarderiez": "musarder",
    "musarderions": "musarder",
    "musarderons": "musarder",
    "musarderont": "musarder",
    "musardes": "musarder",
    "musardez": "musarder",
    "musardiez": "musarder",
    "musardions": "musarder",
    "musardons": "musarder",
    "musards": "musard",
    "musardâmes": "musarder",
    "musardât": "musarder",
    "musardâtes": "musarder",
    "musardèrent": "musarder",
    "musardé": "musarder",
    "musas": "muser",
    "musasse": "muser",
    "musassent": "muser",
    "musasses": "muser",
    "musassiez": "muser",
    "musassions": "muser",
    "muscades": "muscade",
    "muscadets": "muscadet",
    "muscadins": "muscadin",
    "muscats": "muscat",
    "muscla": "muscler",
    "musclai": "muscler",
    "musclaient": "muscler",
    "musclais": "muscler",
    "musclait": "muscler",
    "musclant": "muscler",
    "musclas": "muscler",
    "musclasse": "muscler",
    "musclassent": "muscler",
    "musclasses": "muscler",
    "musclassiez": "muscler",
    "musclassions": "muscler",
    "muscle": "muscler",
    "musclent": "muscler",
    "musclera": "muscler",
    "musclerai": "muscler",
    "muscleraient": "muscler",
    "musclerais": "muscler",
    "musclerait": "muscler",
    "muscleras": "muscler",
    "musclerez": "muscler",
    "muscleriez": "muscler",
    "musclerions": "muscler",
    "musclerons": "muscler",
    "muscleront": "muscler",
    "muscles": "muscler",
    "musclez": "muscler",
    "muscliez": "muscler",
    "musclions": "muscler",
    "musclons": "muscler",
    "musclâmes": "muscler",
    "musclât": "muscler",
    "musclâtes": "muscler",
    "musclèrent": "muscler",
    "musclé": "muscler",
    "musclée": "muscler",
    "musclées": "muscler",
    "musclés": "muscler",
    "muscs": "musc",
    "musculaires": "musculaire",
    "musculeuse": "musculeux",
    "musculeuses": "musculeux",
    "muse": "muser",
    "museaux": "museau",
    "musela": "museler",
    "muselai": "museler",
    "muselaient": "museler",
    "muselais": "museler",
    "muselait": "museler",
    "muselant": "museler",
    "muselas": "museler",
    "muselasse": "museler",
    "muselassent": "museler",
    "muselasses": "museler",
    "muselassiez": "museler",
    "muselassions": "museler",
    "muselez": "museler",
    "museliez": "museler",
    "muselions": "museler",
    "muselières": "muselière",
    "muselle": "museler",
    "musellent": "museler",
    "musellera": "museler",
    "musellerai": "museler",
    "muselleraient": "museler",
    "musellerais": "museler",
    "musellerait": "museler",
    "muselleras": "museler",
    "musellerez": "museler",
    "muselleriez": "museler",
    "musellerions": "museler",
    "musellerons": "museler",
    "muselleront": "museler",
    "muselles": "museler",
    "muselons": "museler",
    "muselâmes": "museler",
    "muselât": "museler",
    "muselâtes": "museler",
    "muselèrent": "museler",
    "muselé": "museler",
    "muselée": "museler",
    "muselées": "museler",
    "muselés": "museler",
    "musent": "muser",
    "musera": "muser",
    "muserai": "muser",
    "museraient": "muser",
    "muserais": "muser",
    "muserait": "muser",
    "museras": "muser",
    "muserez": "muser",
    "museriez": "muser",
    "muserions": "muser",
    "muserons": "muser",
    "museront": "muser",
    "muses": "muser",
    "musettes": "musette",
    "musettes-repas": "musette-repas",
    "museums": "museum",
    "musez": "muser",
    "music hall": "music-hall",
    "music-halls": "music-hall",
    "musicale": "musical",
    "musicales": "musical",
    "musicalités": "musicalité",
    "musicaux": "musical",
    "musicienne": "musicien",
    "musiciennes": "musicien",
    "musiciens": "musicien",
    "musicographes": "musicographe",
    "musicologies": "musicologie",
    "musicologues": "musicologue",
    "musiez": "muser",
    "musions": "muser",
    "musiquait": "musiquer",
    "musique": "musiquer",
    "musiques": "musiquer",
    "musiquettes": "musiquette",
    "musons": "muser",
    "musqué": "musquer",
    "musquée": "musquer",
    "musquées": "musquer",
    "musqués": "musqué",
    "mussais": "musser",
    "musse": "musser",
    "mussent": "musser",
    "musses": "mouvoir",
    "mussiez": "mouvoir",
    "mussions": "mouvoir",
    "mussolinienne": "mussolinien",
    "mussoliniens": "mussolinien",
    "mussolinistes": "mussoliniste",
    "mussée": "musser",
    "mussés": "musser",
    "mustangs": "mustang",
    "mustélidés": "mustélidé",
    "musulmane": "musulman",
    "musulmanes": "musulman",
    "musulmans": "musulman",
    "musâmes": "muser",
    "musât": "muser",
    "musâtes": "muser",
    "musèrent": "muser",
    "musé": "muser",
    "musée": "muser",
    "musées": "muser",
    "muséographies": "muséographie",
    "muséums": "muséum",
    "mut": "mouvoir",
    "muta": "muter",
    "mutables": "mutable",
    "mutai": "muter",
    "mutaient": "muter",
    "mutais": "muter",
    "mutait": "muter",
    "mutant": "muter",
    "mutante": "mutant",
    "mutantes": "mutant",
    "mutants": "mutant",
    "mutas": "muter",
    "mutasse": "muter",
    "mutassent": "muter",
    "mutasses": "muter",
    "mutassiez": "muter",
    "mutassions": "muter",
    "mutations": "mutation",
    "mute": "muter",
    "mutent": "muter",
    "mutera": "muter",
    "muterai": "muter",
    "muteraient": "muter",
    "muterais": "muter",
    "muterait": "muter",
    "muteras": "muter",
    "muterez": "muter",
    "muteriez": "muter",
    "muterions": "muter",
    "muterons": "muter",
    "muteront": "muter",
    "mutes": "muter",
    "mutez": "muter",
    "mutiez": "muter",
    "mutila": "mutiler",
    "mutilai": "mutiler",
    "mutilaient": "mutiler",
    "mutilais": "mutiler",
    "mutilait": "mutiler",
    "mutilant": "mutiler",
    "mutilante": "mutilant",
    "mutilantes": "mutilant",
    "mutilants": "mutilant",
    "mutilas": "mutiler",
    "mutilasse": "mutiler",
    "mutilassent": "mutiler",
    "mutilasses": "mutiler",
    "mutilassiez": "mutiler",
    "mutilassions": "mutiler",
    "mutilations": "mutilation",
    "mutile": "mutiler",
    "mutilent": "mutiler",
    "mutilera": "mutiler",
    "mutilerai": "mutiler",
    "mutileraient": "mutiler",
    "mutilerais": "mutiler",
    "mutilerait": "mutiler",
    "mutileras": "mutiler",
    "mutilerez": "mutiler",
    "mutileriez": "mutiler",
    "mutilerions": "mutiler",
    "mutilerons": "mutiler",
    "mutileront": "mutiler",
    "mutiles": "mutiler",
    "mutilez": "mutiler",
    "mutiliez": "mutiler",
    "mutilions": "mutiler",
    "mutilons": "mutiler",
    "mutilâmes": "mutiler",
    "mutilât": "mutiler",
    "mutilâtes": "mutiler",
    "mutilèrent": "mutiler",
    "mutilé": "mutiler",
    "mutilée": "mutiler",
    "mutilées": "mutiler",
    "mutilés": "mutiler",
    "mutina": "mutiner",
    "mutinai": "mutiner",
    "mutinaient": "mutiner",
    "mutinais": "mutiner",
    "mutinait": "mutiner",
    "mutinant": "mutiner",
    "mutinas": "mutiner",
    "mutinasse": "mutiner",
    "mutinassent": "mutiner",
    "mutinasses": "mutiner",
    "mutinassiez": "mutiner",
    "mutinassions": "mutiner",
    "mutine": "mutiner",
    "mutinent": "mutiner",
    "mutinera": "mutiner",
    "mutinerai": "mutiner",
    "mutineraient": "mutiner",
    "mutinerais": "mutiner",
    "mutinerait": "mutiner",
    "mutineras": "mutiner",
    "mutinerez": "mutiner",
    "mutineries": "mutinerie",
    "mutineriez": "mutiner",
    "mutinerions": "mutiner",
    "mutinerons": "mutiner",
    "mutineront": "mutiner",
    "mutines": "mutiner",
    "mutinez": "mutiner",
    "mutiniez": "mutiner",
    "mutinions": "mutiner",
    "mutinons": "mutiner",
    "mutins": "mutin",
    "mutinâmes": "mutiner",
    "mutinât": "mutiner",
    "mutinâtes": "mutiner",
    "mutinèrent": "mutiner",
    "mutiné": "mutiner",
    "mutinée": "mutiner",
    "mutinées": "mutiner",
    "mutinés": "mutiner",
    "mutions": "muter",
    "mutismes": "mutisme",
    "mutités": "mutité",
    "mutons": "muter",
    "mutualismes": "mutualisme",
    "mutualistes": "mutualiste",
    "mutualités": "mutualité",
    "mutuelle": "mutuel",
    "mutuelles": "mutuel",
    "mutuels": "mutuel",
    "mutâmes": "muter",
    "mutât": "muter",
    "mutâtes": "muter",
    "mutèrent": "muter",
    "muté": "muter",
    "mutée": "muter",
    "mutées": "muter",
    "mutés": "muter",
    "muâmes": "muer",
    "muât": "muer",
    "muâtes": "muer",
    "muèrent": "muer",
    "mué": "muer",
    "muée": "muer",
    "muées": "muer",
    "mués": "muer",
    "mycologies": "mycologie",
    "mycologues": "mycologue",
    "mycoses": "mycose",
    "mycotoxines": "mycotoxine",
    "mycéliums": "mycélium",
    "mycénienne": "mycénien",
    "mycéniennes": "mycénien",
    "mycéniens": "mycénien",
    "mygales": "mygale",
    "myocardes": "myocarde",
    "myopathes": "myopathe",
    "myopes": "myope",
    "myopies": "myopie",
    "myriades": "myriade",
    "myrmidons": "myrmidon",
    "myrrhes": "myrrhe",
    "myrtes": "myrte",
    "myrtilles": "myrtille",
    "mysticismes": "mysticisme",
    "mystifia": "mystifier",
    "mystifiai": "mystifier",
    "mystifiaient": "mystifier",
    "mystifiais": "mystifier",
    "mystifiait": "mystifier",
    "mystifiant": "mystifier",
    "mystifias": "mystifier",
    "mystifiasse": "mystifier",
    "mystifiassent": "mystifier",
    "mystifiasses": "mystifier",
    "mystifiassiez": "mystifier",
    "mystifiassions": "mystifier",
    "mystificateurs": "mystificateur",
    "mystifications": "mystification",
    "mystificatrice": "mystificateur",
    "mystifie": "mystifier",
    "mystifient": "mystifier",
    "mystifiera": "mystifier",
    "mystifierai": "mystifier",
    "mystifieraient": "mystifier",
    "mystifierais": "mystifier",
    "mystifierait": "mystifier",
    "mystifieras": "mystifier",
    "mystifierez": "mystifier",
    "mystifieriez": "mystifier",
    "mystifierions": "mystifier",
    "mystifierons": "mystifier",
    "mystifieront": "mystifier",
    "mystifies": "mystifier",
    "mystifiez": "mystifier",
    "mystifiiez": "mystifier",
    "mystifiions": "mystifier",
    "mystifions": "mystifier",
    "mystifiâmes": "mystifier",
    "mystifiât": "mystifier",
    "mystifiâtes": "mystifier",
    "mystifièrent": "mystifier",
    "mystifié": "mystifier",
    "mystifiée": "mystifier",
    "mystifiées": "mystifier",
    "mystifiés": "mystifier",
    "mystiques": "mystique",
    "mystères": "mystère",
    "mystérieuse": "mystérieux",
    "mystérieuses": "mystérieux",
    "mythes": "mythe",
    "mythifiait": "mythifier",
    "mythiques": "mythique",
    "mythologies": "mythologie",
    "mythologiques": "mythologique",
    "mythologisé": "mythologiser",
    "mythologues": "mythologue",
    "mythomanes": "mythomane",
    "mytilicoles": "mytilicole",
    "mytiliculteurs": "mytiliculteur",
    "mytilicultrice": "mytiliculteur",
    "mytilicultrices": "mytiliculteur",
    "myxoedémateuse": "myxoedémateux",
    "myxomatoses": "myxomatose",
    "myélines": "myéline",
    "myéloblastes": "myéloblaste",
    "mâcha": "mâcher",
    "mâchai": "mâcher",
    "mâchaient": "mâcher",
    "mâchais": "mâcher",
    "mâchait": "mâcher",
    "mâchant": "mâcher",
    "mâchas": "mâcher",
    "mâchasse": "mâcher",
    "mâchassent": "mâcher",
    "mâchasses": "mâcher",
    "mâchassiez": "mâcher",
    "mâchassions": "mâcher",
    "mâche": "mâcher",
    "mâchefers": "mâchefer",
    "mâchent": "mâcher",
    "mâchera": "mâcher",
    "mâcherai": "mâcher",
    "mâcheraient": "mâcher",
    "mâcherais": "mâcher",
    "mâcherait": "mâcher",
    "mâcheras": "mâcher",
    "mâcherez": "mâcher",
    "mâcheriez": "mâcher",
    "mâcherions": "mâcher",
    "mâcherons": "mâcher",
    "mâcheront": "mâcher",
    "mâches": "mâcher",
    "mâcheurs": "mâcheur",
    "mâcheuse": "mâcheur",
    "mâchez": "mâcher",
    "mâchiez": "mâcher",
    "mâchions": "mâcher",
    "mâchoires": "mâchoire",
    "mâchonna": "mâchonner",
    "mâchonnai": "mâchonner",
    "mâchonnaient": "mâchonner",
    "mâchonnais": "mâchonner",
    "mâchonnait": "mâchonner",
    "mâchonnant": "mâchonner",
    "mâchonnas": "mâchonner",
    "mâchonnasse": "mâchonner",
    "mâchonnassent": "mâchonner",
    "mâchonnasses": "mâchonner",
    "mâchonnassiez": "mâchonner",
    "mâchonnassions": "mâchonner",
    "mâchonne": "mâchonner",
    "mâchonnements": "mâchonnement",
    "mâchonnent": "mâchonner",
    "mâchonnera": "mâchonner",
    "mâchonnerai": "mâchonner",
    "mâchonneraient": "mâchonner",
    "mâchonnerais": "mâchonner",
    "mâchonnerait": "mâchonner",
    "mâchonneras": "mâchonner",
    "mâchonnerez": "mâchonner",
    "mâchonneriez": "mâchonner",
    "mâchonnerions": "mâchonner",
    "mâchonnerons": "mâchonner",
    "mâchonneront": "mâchonner",
    "mâchonnes": "mâchonner",
    "mâchonnez": "mâchonner",
    "mâchonniez": "mâchonner",
    "mâchonnions": "mâchonner",
    "mâchonnons": "mâchonner",
    "mâchonnâmes": "mâchonner",
    "mâchonnât": "mâchonner",
    "mâchonnâtes": "mâchonner",
    "mâchonnèrent": "mâchonner",
    "mâchonné": "mâchonner",
    "mâchonnée": "mâchonner",
    "mâchonnées": "mâchonner",
    "mâchonnés": "mâchonner",
    "mâchons": "mâcher",
    "mâchouilla": "mâchouiller",
    "mâchouillait": "mâchouiller",
    "mâchouillant": "mâchouiller",
    "mâchouille": "mâchouiller",
    "mâchouilles": "mâchouiller",
    "mâchouillé": "mâchouiller",
    "mâchouillée": "mâchouiller",
    "mâchures": "mâchure",
    "mâchuré": "mâchurer",
    "mâchurée": "mâchurer",
    "mâchâmes": "mâcher",
    "mâchât": "mâcher",
    "mâchâtes": "mâcher",
    "mâchèrent": "mâcher",
    "mâché": "mâcher",
    "mâchée": "mâcher",
    "mâchées": "mâcher",
    "mâchés": "mâcher",
    "mâconnaise": "mâconnais",
    "mâconnaises": "mâconnais",
    "mâles": "mâle",
    "mâta": "mâter",
    "mâtai": "mâter",
    "mâtaient": "mâter",
    "mâtais": "mâter",
    "mâtait": "mâter",
    "mâtant": "mâter",
    "mâtas": "mâter",
    "mâtasse": "mâter",
    "mâtassent": "mâter",
    "mâtasses": "mâter",
    "mâtassiez": "mâter",
    "mâtassions": "mâter",
    "mâte": "mâter",
    "mâtent": "mâter",
    "mâtera": "mâter",
    "mâterai": "mâter",
    "mâteraient": "mâter",
    "mâterais": "mâter",
    "mâterait": "mâter",
    "mâteras": "mâter",
    "mâtereaux": "mâtereau",
    "mâterez": "mâter",
    "mâteriez": "mâter",
    "mâterions": "mâter",
    "mâterons": "mâter",
    "mâteront": "mâter",
    "mâtes": "mâter",
    "mâtez": "mâter",
    "mâtiez": "mâter",
    "mâtinant": "mâtiner",
    "mâtine": "mâtin",
    "mâtines": "mâtine",
    "mâtins": "mâtin",
    "mâtiné": "mâtiner",
    "mâtinée": "mâtiner",
    "mâtinés": "mâtiner",
    "mâtions": "mâter",
    "mâtons": "mâter",
    "mâts": "mât",
    "mâtures": "mâture",
    "mâtâmes": "mâter",
    "mâtât": "mâter",
    "mâtâtes": "mâter",
    "mâtèrent": "mâter",
    "mâté": "mâter",
    "mâtée": "mâter",
    "mâtées": "mâter",
    "mâtés": "mâter",
    "mèche": "mécher",
    "mèchent": "mécher",
    "mèches": "mécher",
    "mène": "mener",
    "mènent": "mener",
    "mènera": "mener",
    "mènerai": "mener",
    "mèneraient": "mener",
    "mènerais": "mener",
    "mènerait": "mener",
    "mèneras": "mener",
    "mènerez": "mener",
    "mèneriez": "mener",
    "mènerions": "mener",
    "mènerons": "mener",
    "mèneront": "mener",
    "mènes": "mener",
    "mères": "mère",
    "mères-grand": "mère-grand",
    "mètre": "métrer",
    "mètrent": "métrer",
    "mètres": "métrer",
    "méandres": "méandre",
    "méats": "méat",
    "mécanicienne": "mécanicien",
    "mécaniciennes": "mécanicien",
    "mécaniciens": "mécanicien",
    "mécaniques": "mécanique",
    "mécanisait": "mécaniser",
    "mécanisations": "mécanisation",
    "mécanise": "mécaniser",
    "mécanismes": "mécanisme",
    "mécanistes": "mécaniste",
    "mécanisé": "mécaniser",
    "mécanisée": "mécaniser",
    "mécanisées": "mécaniser",
    "mécanisés": "mécaniser",
    "mécanographies": "mécanographie",
    "mécanographiques": "mécanographique",
    "mécanos": "mécano",
    "mécanothérapies": "mécanothérapie",
    "mécha": "mécher",
    "méchai": "mécher",
    "méchaient": "mécher",
    "méchais": "mécher",
    "méchait": "mécher",
    "méchancetés": "méchanceté",
    "méchant": "mécher",
    "méchante": "méchant",
    "méchantes": "méchant",
    "méchants": "méchant",
    "méchas": "mécher",
    "méchasse": "mécher",
    "méchassent": "mécher",
    "méchasses": "mécher",
    "méchassiez": "mécher",
    "méchassions": "mécher",
    "méchera": "mécher",
    "mécherai": "mécher",
    "mécheraient": "mécher",
    "mécherais": "mécher",
    "mécherait": "mécher",
    "mécheras": "mécher",
    "mécherez": "mécher",
    "mécheriez": "mécher",
    "mécherions": "mécher",
    "mécherons": "mécher",
    "mécheront": "mécher",
    "méchez": "mécher",
    "méchiez": "mécher",
    "méchions": "mécher",
    "méchons": "mécher",
    "méchouis": "méchoui",
    "méchâmes": "mécher",
    "méchât": "mécher",
    "méchâtes": "mécher",
    "méchèrent": "mécher",
    "méché": "mécher",
    "méchée": "mécher",
    "méchées": "mécher",
    "méchés": "mécher",
    "mécompta": "mécompter",
    "mécomptai": "mécompter",
    "mécomptaient": "mécompter",
    "mécomptais": "mécompter",
    "mécomptait": "mécompter",
    "mécomptant": "mécompter",
    "mécomptas": "mécompter",
    "mécomptasse": "mécompter",
    "mécomptassent": "mécompter",
    "mécomptasses": "mécompter",
    "mécomptassiez": "mécompter",
    "mécomptassions": "mécompter",
    "mécompte": "mécompter",
    "mécomptent": "mécompter",
    "mécomptera": "mécompter",
    "mécompterai": "mécompter",
    "mécompteraient": "mécompter",
    "mécompterais": "mécompter",
    "mécompterait": "mécompter",
    "mécompteras": "mécompter",
    "mécompterez": "mécompter",
    "mécompteriez": "mécompter",
    "mécompterions": "mécompter",
    "mécompterons": "mécompter",
    "mécompteront": "mécompter",
    "mécomptes": "mécompter",
    "mécomptez": "mécompter",
    "mécomptiez": "mécompter",
    "mécomptions": "mécompter",
    "mécomptons": "mécompter",
    "mécomptâmes": "mécompter",
    "mécomptât": "mécompter",
    "mécomptâtes": "mécompter",
    "mécomptèrent": "mécompter",
    "mécompté": "mécompter",
    "mécomptée": "mécompter",
    "mécomptées": "mécompter",
    "mécomptés": "mécompter",
    "méconnais": "méconnaître",
    "méconnaissables": "méconnaissable",
    "méconnaissaient": "méconnaître",
    "méconnaissais": "méconnaître",
    "méconnaissait": "méconnaître",
    "méconnaissances": "méconnaissance",
    "méconnaissant": "méconnaître",
    "méconnaisse": "méconnaître",
    "méconnaissent": "méconnaître",
    "méconnaisses": "méconnaître",
    "méconnaissez": "méconnaître",
    "méconnaissiez": "méconnaître",
    "méconnaissions": "méconnaître",
    "méconnaissons": "méconnaître",
    "méconnaît": "méconnaître",
    "méconnaîtra": "méconnaître",
    "méconnaîtrai": "méconnaître",
    "méconnaîtraient": "méconnaître",
    "méconnaîtrais": "méconnaître",
    "méconnaîtrait": "méconnaître",
    "méconnaîtras": "méconnaître",
    "méconnaîtrez": "méconnaître",
    "méconnaîtriez": "méconnaître",
    "méconnaîtrions": "méconnaître",
    "méconnaîtrons": "méconnaître",
    "méconnaîtront": "méconnaître",
    "méconnu": "méconnaître",
    "méconnue": "méconnu",
    "méconnues": "méconnaître",
    "méconnurent": "méconnaître",
    "méconnus": "méconnu",
    "méconnusse": "méconnaître",
    "méconnussent": "méconnaître",
    "méconnusses": "méconnaître",
    "méconnussiez": "méconnaître",
    "méconnussions": "méconnaître",
    "méconnut": "méconnaître",
    "méconnûmes": "méconnaître",
    "méconnût": "méconnaître",
    "méconnûtes": "méconnaître",
    "mécontenta": "mécontenter",
    "mécontentai": "mécontenter",
    "mécontentaient": "mécontenter",
    "mécontentais": "mécontenter",
    "mécontentait": "mécontenter",
    "mécontentant": "mécontenter",
    "mécontentas": "mécontenter",
    "mécontentasse": "mécontenter",
    "mécontentassent": "mécontenter",
    "mécontentasses": "mécontenter",
    "mécontentassiez": "mécontenter",
    "mécontentassions": "mécontenter",
    "mécontente": "mécontenter",
    "mécontentements": "mécontentement",
    "mécontentent": "mécontenter",
    "mécontentera": "mécontenter",
    "mécontenterai": "mécontenter",
    "mécontenteraient": "mécontenter",
    "mécontenterais": "mécontenter",
    "mécontenterait": "mécontenter",
    "mécontenteras": "mécontenter",
    "mécontenterez": "mécontenter",
    "mécontenteriez": "mécontenter",
    "mécontenterions": "mécontenter",
    "mécontenterons": "mécontenter",
    "mécontenteront": "mécontenter",
    "mécontentes": "mécontenter",
    "mécontentez": "mécontenter",
    "mécontentiez": "mécontenter",
    "mécontentions": "mécontenter",
    "mécontentons": "mécontenter",
    "mécontents": "mécontent",
    "mécontentâmes": "mécontenter",
    "mécontentât": "mécontenter",
    "mécontentâtes": "mécontenter",
    "mécontentèrent": "mécontenter",
    "mécontenté": "mécontenter",
    "mécontentée": "mécontenter",
    "mécontentées": "mécontenter",
    "mécontentés": "mécontenter",
    "mécroie": "mécroire",
    "mécroient": "mécroire",
    "mécroies": "mécroire",
    "mécroira": "mécroire",
    "mécroirai": "mécroire",
    "mécroiraient": "mécroire",
    "mécroirais": "mécroire",
    "mécroirait": "mécroire",
    "mécroiras": "mécroire",
    "mécroirez": "mécroire",
    "mécroiriez": "mécroire",
    "mécroirions": "mécroire",
    "mécroirons": "mécroire",
    "mécroiront": "mécroire",
    "mécrois": "mécroire",
    "mécroit": "mécroire",
    "mécroyaient": "mécroire",
    "mécroyais": "mécroire",
    "mécroyait": "mécroire",
    "mécroyant": "mécroire",
    "mécroyez": "mécroire",
    "mécroyiez": "mécroire",
    "mécroyions": "mécroire",
    "mécroyons": "mécroire",
    "mécru": "mécroire",
    "mécrue": "mécroire",
    "mécrues": "mécroire",
    "mécrurent": "mécroire",
    "mécrus": "mécroire",
    "mécrusse": "mécroire",
    "mécrussent": "mécroire",
    "mécrusses": "mécroire",
    "mécrussiez": "mécroire",
    "mécrussions": "mécroire",
    "mécrut": "mécroire",
    "mécréante": "mécréant",
    "mécréants": "mécréant",
    "mécrûmes": "mécroire",
    "mécrût": "mécroire",
    "mécrûtes": "mécroire",
    "mécènes": "mécène",
    "mécénats": "mécénat",
    "médailles": "médaille",
    "médailleurs": "médailleur",
    "médaillons": "médaillon",
    "médaillé": "médailler",
    "médaillée": "médailler",
    "médaillées": "médaillé",
    "médaillés": "médaillé",
    "médecin-majors": "médecin-major",
    "médecine-balls": "médecine-ball",
    "médecines": "médecine",
    "médecinismes": "médecinisme",
    "médecins": "médecin",
    "médiane": "médian",
    "médianes": "médiane",
    "médianoches": "médianoche",
    "médians": "médian",
    "médias": "média",
    "médiate": "médiat",
    "médiates": "médiat",
    "médiateurs": "médiateur",
    "médiathèques": "médiathèque",
    "médiations": "médiation",
    "médiatiques": "médiatique",
    "médiatisa": "médiatiser",
    "médiatisai": "médiatiser",
    "médiatisaient": "médiatiser",
    "médiatisais": "médiatiser",
    "médiatisait": "médiatiser",
    "médiatisant": "médiatiser",
    "médiatisas": "médiatiser",
    "médiatisasse": "médiatiser",
    "médiatisassent": "médiatiser",
    "médiatisasses": "médiatiser",
    "médiatisassiez": "médiatiser",
    "médiatisassions": "médiatiser",
    "médiatisations": "médiatisation",
    "médiatise": "médiatiser",
    "médiatisent": "médiatiser",
    "médiatisera": "médiatiser",
    "médiatiserai": "médiatiser",
    "médiatiseraient": "médiatiser",
    "médiatiserais": "médiatiser",
    "médiatiserait": "médiatiser",
    "médiatiseras": "médiatiser",
    "médiatiserez": "médiatiser",
    "médiatiseriez": "médiatiser",
    "médiatiserions": "médiatiser",
    "médiatiserons": "médiatiser",
    "médiatiseront": "médiatiser",
    "médiatises": "médiatiser",
    "médiatisez": "médiatiser",
    "médiatisiez": "médiatiser",
    "médiatisions": "médiatiser",
    "médiatisons": "médiatiser",
    "médiatisâmes": "médiatiser",
    "médiatisât": "médiatiser",
    "médiatisâtes": "médiatiser",
    "médiatisèrent": "médiatiser",
    "médiatisé": "médiatiser",
    "médiatisée": "médiatiser",
    "médiatisées": "médiatiser",
    "médiatisés": "médiatiser",
    "médiatrice": "médiateur",
    "médiatrices": "médiateur",
    "médiats": "médiat",
    "médicale": "médical",
    "médicales": "médical",
    "médicalisé": "médicaliser",
    "médicalisée": "médicaliser",
    "médicamentait": "médicamenter",
    "médicamenteuse": "médicamenteux",
    "médicamenteuses": "médicamenteux",
    "médicaments": "médicament",
    "médicamenté": "médicamenter",
    "médicastres": "médicastre",
    "médications": "médication",
    "médicaux": "médical",
    "médicinale": "médicinal",
    "médicinales": "médicinal",
    "médicinaux": "médicinal",
    "médicine": "médiciner",
    "médico-légale": "médico-légal",
    "médico-légales": "médico-légal",
    "médico-légaux": "médico-légal",
    "médico-sociale": "médico-social",
    "médico-sociales": "médico-social",
    "médico-sociaux": "médico-social",
    "médinas": "médina",
    "médiocres": "médiocre",
    "médiocrités": "médiocrité",
    "médira": "médire",
    "médirai": "médire",
    "médiraient": "médire",
    "médirais": "médire",
    "médirait": "médire",
    "médiras": "médire",
    "médirent": "médire",
    "médirez": "médire",
    "médiriez": "médire",
    "médirions": "médire",
    "médirons": "médire",
    "médiront": "médire",
    "médis": "médire",
    "médisaient": "médire",
    "médisais": "médire",
    "médisait": "médire",
    "médisances": "médisance",
    "médisant": "médire",
    "médisante": "médisant",
    "médisantes": "médisant",
    "médisants": "médisant",
    "médise": "médire",
    "médisent": "médire",
    "médises": "médire",
    "médisez": "médire",
    "médisiez": "médire",
    "médisions": "médire",
    "médisons": "médire",
    "médisse": "médire",
    "médissent": "médire",
    "médisses": "médire",
    "médissiez": "médire",
    "médissions": "médire",
    "médit": "médire",
    "médita": "méditer",
    "méditai": "méditer",
    "méditaient": "méditer",
    "méditais": "méditer",
    "méditait": "méditer",
    "méditant": "méditer",
    "méditas": "méditer",
    "méditasse": "méditer",
    "méditassent": "méditer",
    "méditasses": "méditer",
    "méditassiez": "méditer",
    "méditassions": "méditer",
    "méditatifs": "méditatif",
    "méditations": "méditation",
    "méditative": "méditatif",
    "méditatives": "méditatif",
    "médite": "méditer",
    "méditent": "méditer",
    "méditera": "méditer",
    "méditerai": "méditer",
    "méditeraient": "méditer",
    "méditerais": "méditer",
    "méditerait": "méditer",
    "méditeras": "méditer",
    "méditerez": "méditer",
    "méditeriez": "méditer",
    "méditerions": "méditer",
    "méditerons": "méditer",
    "méditeront": "méditer",
    "méditerranée": "méditerrané",
    "méditerranéenne": "méditerranéen",
    "méditerranéennes": "méditerranéenne",
    "méditerranéens": "méditerranéen",
    "médites": "méditer",
    "méditez": "méditer",
    "méditiez": "méditer",
    "méditions": "méditer",
    "méditons": "méditer",
    "méditâmes": "méditer",
    "méditât": "méditer",
    "méditâtes": "méditer",
    "méditèrent": "méditer",
    "médité": "méditer",
    "méditée": "méditer",
    "méditées": "méditer",
    "médités": "méditer",
    "médiumniques": "médiumnique",
    "médiums": "médium",
    "médiévale": "médiéval",
    "médiévales": "médiéval",
    "médiévaux": "médiéval",
    "médiévistes": "médiéviste",
    "médocs": "médoc",
    "médullaires": "médullaire",
    "médusa": "méduser",
    "médusai": "méduser",
    "médusaient": "méduser",
    "médusais": "méduser",
    "médusait": "méduser",
    "médusant": "méduser",
    "médusas": "méduser",
    "médusasse": "méduser",
    "médusassent": "méduser",
    "médusasses": "méduser",
    "médusassiez": "méduser",
    "médusassions": "méduser",
    "méduse": "méduser",
    "médusent": "méduser",
    "médusera": "méduser",
    "méduserai": "méduser",
    "méduseraient": "méduser",
    "méduserais": "méduser",
    "méduserait": "méduser",
    "méduseras": "méduser",
    "méduserez": "méduser",
    "méduseriez": "méduser",
    "méduserions": "méduser",
    "méduserons": "méduser",
    "méduseront": "méduser",
    "méduses": "méduser",
    "médusez": "méduser",
    "médusiez": "méduser",
    "médusions": "méduser",
    "médusons": "méduser",
    "médusâmes": "méduser",
    "médusât": "méduser",
    "médusâtes": "méduser",
    "médusèrent": "méduser",
    "médusé": "méduser",
    "médusée": "méduser",
    "médusées": "méduser",
    "médusés": "méduser",
    "médîmes": "médire",
    "médît": "médire",
    "médîtes": "médire",
    "méfaits": "méfait",
    "méfia": "méfier",
    "méfiai": "méfier",
    "méfiaient": "méfier",
    "méfiais": "méfier",
    "méfiait": "méfier",
    "méfiances": "méfiance",
    "méfiant": "méfier",
    "méfiante": "méfiant",
    "méfiantes": "méfiant",
    "méfiants": "méfiant",
    "méfias": "méfier",
    "méfiasse": "méfier",
    "méfiassent": "méfier",
    "méfiasses": "méfier",
    "méfiassiez": "méfier",
    "méfiassions": "méfier",
    "méfie": "méfier",
    "méfient": "méfier",
    "méfiera": "méfier",
    "méfierai": "méfier",
    "méfieraient": "méfier",
    "méfierais": "méfier",
    "méfierait": "méfier",
    "méfieras": "méfier",
    "méfierez": "méfier",
    "méfieriez": "méfier",
    "méfierions": "méfier",
    "méfierons": "méfier",
    "méfieront": "méfier",
    "méfies": "méfier",
    "méfiez": "méfier",
    "méfiiez": "méfier",
    "méfiions": "méfier",
    "méfions": "méfier",
    "méfiâmes": "méfier",
    "méfiât": "méfier",
    "méfiâtes": "méfier",
    "méfièrent": "méfier",
    "méfié": "méfier",
    "méfiée": "méfier",
    "méfiées": "méfier",
    "méfiés": "méfier",
    "méformes": "méforme",
    "mégajoules": "mégajoule",
    "mégalithes": "mégalithe",
    "mégalomanes": "mégalomane",
    "mégalomanies": "mégalomanie",
    "mégalos": "mégalo",
    "mégaphones": "mégaphone",
    "mégaprojets": "mégaprojet",
    "mégatendances": "mégatendance",
    "mégathériums": "mégathérium",
    "mégatonnes": "mégatonne",
    "mégawatts": "mégawatt",
    "mégi": "mégir",
    "mégie": "mégir",
    "mégies": "mégir",
    "mégira": "mégir",
    "mégirai": "mégir",
    "mégiraient": "mégir",
    "mégirais": "mégir",
    "mégirait": "mégir",
    "mégiras": "mégir",
    "mégirent": "mégir",
    "mégirez": "mégir",
    "mégiriez": "mégir",
    "mégirions": "mégir",
    "mégirons": "mégir",
    "mégiront": "mégir",
    "mégis": "mégir",
    "mégissa": "mégisser",
    "mégissai": "mégisser",
    "mégissaient": "mégisser",
    "mégissais": "mégisser",
    "mégissait": "mégisser",
    "mégissant": "mégisser",
    "mégissas": "mégisser",
    "mégissasse": "mégisser",
    "mégissassent": "mégisser",
    "mégissasses": "mégisser",
    "mégissassiez": "mégisser",
    "mégissassions": "mégisser",
    "mégisse": "mégisser",
    "mégissent": "mégisser",
    "mégissera": "mégisser",
    "mégisserai": "mégisser",
    "mégisseraient": "mégisser",
    "mégisserais": "mégisser",
    "mégisserait": "mégisser",
    "mégisseras": "mégisser",
    "mégisserez": "mégisser",
    "mégisseriez": "mégisser",
    "mégisserions": "mégisser",
    "mégisserons": "mégisser",
    "mégisseront": "mégisser",
    "mégisses": "mégisser",
    "mégissez": "mégisser",
    "mégissiers": "mégissier",
    "mégissiez": "mégisser",
    "mégissions": "mégisser",
    "mégissons": "mégisser",
    "mégissâmes": "mégisser",
    "mégissât": "mégisser",
    "mégissâtes": "mégisser",
    "mégissèrent": "mégisser",
    "mégissé": "mégisser",
    "mégissée": "mégisser",
    "mégissées": "mégisser",
    "mégissés": "mégisser",
    "mégit": "mégir",
    "mégota": "mégoter",
    "mégotages": "mégotage",
    "mégotai": "mégoter",
    "mégotaient": "mégoter",
    "mégotais": "mégoter",
    "mégotait": "mégoter",
    "mégotant": "mégoter",
    "mégotas": "mégoter",
    "mégotasse": "mégoter",
    "mégotassent": "mégoter",
    "mégotasses": "mégoter",
    "mégotassiez": "mégoter",
    "mégotassions": "mégoter",
    "mégote": "mégoter",
    "mégotent": "mégoter",
    "mégotera": "mégoter",
    "mégoterai": "mégoter",
    "mégoteraient": "mégoter",
    "mégoterais": "mégoter",
    "mégoterait": "mégoter",
    "mégoteras": "mégoter",
    "mégoterez": "mégoter",
    "mégoteriez": "mégoter",
    "mégoterions": "mégoter",
    "mégoterons": "mégoter",
    "mégoteront": "mégoter",
    "mégotes": "mégoter",
    "mégotez": "mégoter",
    "mégotiez": "mégoter",
    "mégotions": "mégoter",
    "mégotons": "mégoter",
    "mégots": "mégot",
    "mégotâmes": "mégoter",
    "mégotât": "mégoter",
    "mégotâtes": "mégoter",
    "mégotèrent": "mégoter",
    "mégoté": "mégoter",
    "mégère": "méger",
    "mégères": "mégère",
    "mégîmes": "mégir",
    "mégît": "mégir",
    "mégîtes": "mégir",
    "méharis": "méhari",
    "méharistes": "méhariste",
    "méjuge": "méjuger",
    "méjugea": "méjuger",
    "méjugeai": "méjuger",
    "méjugeaient": "méjuger",
    "méjugeais": "méjuger",
    "méjugeait": "méjuger",
    "méjugeant": "méjuger",
    "méjugeas": "méjuger",
    "méjugeasse": "méjuger",
    "méjugeassent": "méjuger",
    "méjugeasses": "méjuger",
    "méjugeassiez": "méjuger",
    "méjugeassions": "méjuger",
    "méjugent": "méjuger",
    "méjugeons": "méjuger",
    "méjugera": "méjuger",
    "méjugerai": "méjuger",
    "méjugeraient": "méjuger",
    "méjugerais": "méjuger",
    "méjugerait": "méjuger",
    "méjugeras": "méjuger",
    "méjugerez": "méjuger",
    "méjugeriez": "méjuger",
    "méjugerions": "méjuger",
    "méjugerons": "méjuger",
    "méjugeront": "méjuger",
    "méjuges": "méjuger",
    "méjugez": "méjuger",
    "méjugeâmes": "méjuger",
    "méjugeât": "méjuger",
    "méjugeâtes": "méjuger",
    "méjugiez": "méjuger",
    "méjugions": "méjuger",
    "méjugèrent": "méjuger",
    "méjugé": "méjuger",
    "méjugée": "méjuger",
    "méjugées": "méjuger",
    "méjugés": "méjuger",
    "mélampyres": "mélampyre",
    "mélancolies": "mélancolie",
    "mélancoliques": "mélancolique",
    "mélange": "mélanger",
    "mélangea": "mélanger",
    "mélangeai": "mélanger",
    "mélangeaient": "mélanger",
    "mélangeais": "mélanger",
    "mélangeait": "mélanger",
    "mélangeant": "mélanger",
    "mélangeas": "mélanger",
    "mélangeasse": "mélanger",
    "mélangeassent": "mélanger",
    "mélangeasses": "mélanger",
    "mélangeassiez": "mélanger",
    "mélangeassions": "mélanger",
    "mélangent": "mélanger",
    "mélangeons": "mélanger",
    "mélangera": "mélanger",
    "mélangerai": "mélanger",
    "mélangeraient": "mélanger",
    "mélangerais": "mélanger",
    "mélangerait": "mélanger",
    "mélangeras": "mélanger",
    "mélangerez": "mélanger",
    "mélangeriez": "mélanger",
    "mélangerions": "mélanger",
    "mélangerons": "mélanger",
    "mélangeront": "mélanger",
    "mélanges": "mélanger",
    "mélangeurs": "mélangeur",
    "mélangez": "mélanger",
    "mélangeâmes": "mélanger",
    "mélangeât": "mélanger",
    "mélangeâtes": "mélanger",
    "mélangiez": "mélanger",
    "mélangions": "mélanger",
    "mélangèrent": "mélanger",
    "mélangé": "mélanger",
    "mélangée": "mélanger",
    "mélangées": "mélanger",
    "mélangés": "mélanger",
    "mélanomes": "mélanome",
    "mélanésienne": "mélanésien",
    "mélanésiennes": "mélanésienne",
    "mélanésiens": "mélanésien",
    "mélasses": "mélasse",
    "mélinites": "mélinite",
    "mélioratifs": "mélioratif",
    "méliorative": "mélioratif",
    "mélioratives": "mélioratif",
    "mélis-mélos": "méli-mélo",
    "mélisses": "mélisse",
    "mélodies": "mélodie",
    "mélodieuse": "mélodieux",
    "mélodieuses": "mélodieux",
    "mélodiques": "mélodique",
    "mélodramatiques": "mélodramatique",
    "mélodrames": "mélodrame",
    "mélomanes": "mélomane",
    "mélopées": "mélopée",
    "mélos": "mélo",
    "mélèzes": "mélèze",
    "mémentos": "mémento",
    "mémoires": "mémoire",
    "mémorables": "mémorable",
    "mémorandums": "mémorandum",
    "mémorialistes": "mémorialiste",
    "mémoriaux": "mémorial",
    "mémorielle": "mémoriel",
    "mémoriels": "mémoriel",
    "mémorisables": "mémorisable",
    "mémorisaient": "mémoriser",
    "mémorisait": "mémoriser",
    "mémorisations": "mémorisation",
    "mémorise": "mémoriser",
    "mémorisent": "mémoriser",
    "mémoriserai": "mémoriser",
    "mémoriserais": "mémoriser",
    "mémorisez": "mémoriser",
    "mémorisiez": "mémoriser",
    "mémorisé": "mémoriser",
    "mémorisée": "mémoriser",
    "mémorisées": "mémoriser",
    "mémorisés": "mémoriser",
    "mémos": "mémo",
    "mémères": "mémère",
    "mémés": "mémé",
    "ménades": "ménade",
    "ménage": "ménager",
    "ménagea": "ménager",
    "ménageai": "ménager",
    "ménageaient": "ménager",
    "ménageais": "ménager",
    "ménageait": "ménager",
    "ménageant": "ménager",
    "ménageas": "ménager",
    "ménageasse": "ménager",
    "ménageassent": "ménager",
    "ménageasses": "ménager",
    "ménageassiez": "ménager",
    "ménageassions": "ménager",
    "ménagements": "ménagement",
    "ménagent": "ménager",
    "ménageons": "ménager",
    "ménagera": "ménager",
    "ménagerai": "ménager",
    "ménageraient": "ménager",
    "ménagerais": "ménager",
    "ménagerait": "ménager",
    "ménageras": "ménager",
    "ménagerez": "ménager",
    "ménageries": "ménagerie",
    "ménageriez": "ménager",
    "ménagerions": "ménager",
    "ménagerons": "ménager",
    "ménageront": "ménager",
    "ménagers": "ménager",
    "ménages": "ménager",
    "ménagez": "ménager",
    "ménageâmes": "ménager",
    "ménageât": "ménager",
    "ménageâtes": "ménager",
    "ménagiez": "ménager",
    "ménagions": "ménager",
    "ménagère": "ménager",
    "ménagèrent": "ménager",
    "ménagères": "ménager",
    "ménagé": "ménager",
    "ménagée": "ménager",
    "ménagées": "ménager",
    "ménagés": "ménager",
    "ménestrels": "ménestrel",
    "méninges": "méninge",
    "méningites": "méningite",
    "méningée": "méningé",
    "méniscale": "méniscal",
    "méniscales": "méniscal",
    "méniscaux": "méniscal",
    "ménisques": "ménisque",
    "ménopauses": "ménopause",
    "ménopausée": "ménopausé",
    "ménopausées": "ménopausé",
    "ménétriers": "ménétrier",
    "méphistophéliques": "méphistophélique",
    "méphitiques": "méphitique",
    "méplate": "méplat",
    "méplates": "méplat",
    "méplats": "méplat",
    "méprenaient": "méprendre",
    "méprenais": "méprendre",
    "méprenait": "méprendre",
    "méprenant": "méprendre",
    "méprend": "méprendre",
    "méprendra": "méprendre",
    "méprendrai": "méprendre",
    "méprendraient": "méprendre",
    "méprendrais": "méprendre",
    "méprendrait": "méprendre",
    "méprendras": "méprendre",
    "méprendrez": "méprendre",
    "méprendriez": "méprendre",
    "méprendrions": "méprendre",
    "méprendrons": "méprendre",
    "méprendront": "méprendre",
    "méprends": "méprendre",
    "méprenez": "méprendre",
    "mépreniez": "méprendre",
    "méprenions": "méprendre",
    "méprenne": "méprendre",
    "méprennent": "méprendre",
    "méprennes": "méprendre",
    "méprenons": "méprendre",
    "méprirent": "méprendre",
    "mépris": "méprendre",
    "méprisa": "mépriser",
    "méprisables": "méprisable",
    "méprisai": "mépriser",
    "méprisaient": "mépriser",
    "méprisais": "mépriser",
    "méprisait": "mépriser",
    "méprisant": "mépriser",
    "méprisante": "méprisant",
    "méprisantes": "méprisant",
    "méprisants": "méprisant",
    "méprisas": "mépriser",
    "méprisasse": "mépriser",
    "méprisassent": "mépriser",
    "méprisasses": "mépriser",
    "méprisassiez": "mépriser",
    "méprisassions": "mépriser",
    "méprise": "mépriser",
    "méprisent": "mépriser",
    "méprisera": "mépriser",
    "mépriserai": "mépriser",
    "mépriseraient": "mépriser",
    "mépriserais": "mépriser",
    "mépriserait": "mépriser",
    "mépriseras": "mépriser",
    "mépriserez": "mépriser",
    "mépriseriez": "mépriser",
    "mépriserions": "mépriser",
    "mépriserons": "mépriser",
    "mépriseront": "mépriser",
    "méprises": "mépriser",
    "méprisez": "mépriser",
    "méprisiez": "mépriser",
    "méprisions": "mépriser",
    "méprisons": "mépriser",
    "méprisse": "méprendre",
    "méprissent": "méprendre",
    "méprisses": "méprendre",
    "méprissiez": "méprendre",
    "méprissions": "méprendre",
    "méprisâmes": "mépriser",
    "méprisât": "mépriser",
    "méprisâtes": "mépriser",
    "méprisèrent": "mépriser",
    "méprisé": "mépriser",
    "méprisée": "mépriser",
    "méprisées": "mépriser",
    "méprisés": "mépriser",
    "méprit": "méprendre",
    "méprîmes": "méprendre",
    "méprît": "méprendre",
    "méprîtes": "méprendre",
    "méridienne": "méridien",
    "méridiennes": "méridien",
    "méridiens": "méridien",
    "méridionale": "méridional",
    "méridionales": "méridional",
    "méridionaux": "méridional",
    "mérita": "mériter",
    "méritai": "mériter",
    "méritaient": "mériter",
    "méritais": "mériter",
    "méritait": "mériter",
    "méritant": "mériter",
    "méritante": "méritant",
    "méritantes": "méritant",
    "méritants": "méritant",
    "méritas": "mériter",
    "méritasse": "mériter",
    "méritassent": "mériter",
    "méritasses": "mériter",
    "méritassiez": "mériter",
    "méritassions": "mériter",
    "mérite": "mériter",
    "méritent": "mériter",
    "méritera": "mériter",
    "mériterai": "mériter",
    "mériteraient": "mériter",
    "mériterais": "mériter",
    "mériterait": "mériter",
    "mériteras": "mériter",
    "mériterez": "mériter",
    "mériteriez": "mériter",
    "mériterions": "mériter",
    "mériterons": "mériter",
    "mériteront": "mériter",
    "mérites": "mériter",
    "méritez": "mériter",
    "méritiez": "mériter",
    "méritions": "mériter",
    "méritoires": "méritoire",
    "méritons": "mériter",
    "méritâmes": "mériter",
    "méritât": "mériter",
    "méritâtes": "mériter",
    "méritèrent": "mériter",
    "mérité": "mériter",
    "méritée": "mériter",
    "méritées": "mériter",
    "mérités": "mériter",
    "mérous": "mérou",
    "mérovingienne": "mérovingien",
    "mérovingiennes": "mérovingien",
    "mérules": "mérule",
    "mésallia": "mésallier",
    "mésalliai": "mésallier",
    "mésalliaient": "mésallier",
    "mésalliais": "mésallier",
    "mésalliait": "mésallier",
    "mésalliances": "mésalliance",
    "mésalliant": "mésallier",
    "mésallias": "mésallier",
    "mésalliasse": "mésallier",
    "mésalliassent": "mésallier",
    "mésalliasses": "mésallier",
    "mésalliassiez": "mésallier",
    "mésalliassions": "mésallier",
    "mésallie": "mésallier",
    "mésallient": "mésallier",
    "mésalliera": "mésallier",
    "mésallierai": "mésallier",
    "mésallieraient": "mésallier",
    "mésallierais": "mésallier",
    "mésallierait": "mésallier",
    "mésallieras": "mésallier",
    "mésallierez": "mésallier",
    "mésallieriez": "mésallier",
    "mésallierions": "mésallier",
    "mésallierons": "mésallier",
    "mésallieront": "mésallier",
    "mésallies": "mésallier",
    "mésalliez": "mésallier",
    "mésalliiez": "mésallier",
    "mésalliions": "mésallier",
    "mésallions": "mésallier",
    "mésalliâmes": "mésallier",
    "mésalliât": "mésallier",
    "mésalliâtes": "mésallier",
    "mésallièrent": "mésallier",
    "mésallié": "mésallier",
    "mésalliée": "mésallier",
    "mésalliées": "mésallier",
    "mésalliés": "mésallier",
    "mésanges": "mésange",
    "mésaventures": "mésaventure",
    "mésententes": "mésentente",
    "mésestima": "mésestimer",
    "mésestimai": "mésestimer",
    "mésestimaient": "mésestimer",
    "mésestimais": "mésestimer",
    "mésestimait": "mésestimer",
    "mésestimant": "mésestimer",
    "mésestimas": "mésestimer",
    "mésestimasse": "mésestimer",
    "mésestimassent": "mésestimer",
    "mésestimasses": "mésestimer",
    "mésestimassiez": "mésestimer",
    "mésestimassions": "mésestimer",
    "mésestime": "mésestimer",
    "mésestiment": "mésestimer",
    "mésestimera": "mésestimer",
    "mésestimerai": "mésestimer",
    "mésestimeraient": "mésestimer",
    "mésestimerais": "mésestimer",
    "mésestimerait": "mésestimer",
    "mésestimeras": "mésestimer",
    "mésestimerez": "mésestimer",
    "mésestimeriez": "mésestimer",
    "mésestimerions": "mésestimer",
    "mésestimerons": "mésestimer",
    "mésestimeront": "mésestimer",
    "mésestimes": "mésestimer",
    "mésestimez": "mésestimer",
    "mésestimiez": "mésestimer",
    "mésestimions": "mésestimer",
    "mésestimons": "mésestimer",
    "mésestimâmes": "mésestimer",
    "mésestimât": "mésestimer",
    "mésestimâtes": "mésestimer",
    "mésestimèrent": "mésestimer",
    "mésestimé": "mésestimer",
    "mésestimée": "mésestimer",
    "mésestimées": "mésestimer",
    "mésestimés": "mésestimer",
    "mésintelligences": "mésintelligence",
    "mésodermiques": "mésodermique",
    "mésons": "méson",
    "mésopotamiens": "mésopotamien",
    "métaboliques": "métabolique",
    "métabolismes": "métabolisme",
    "métacarpes": "métacarpe",
    "métacarpiens": "métacarpien",
    "métairies": "métairie",
    "métalliques": "métallique",
    "métallise": "métalliser",
    "métallisent": "métalliser",
    "métallisé": "métalliser",
    "métallisée": "métalliser",
    "métallisées": "métalliser",
    "métallisés": "métalliser",
    "métallos": "métallo",
    "métallurgies": "métallurgie",
    "métallurgiques": "métallurgique",
    "métallurgistes": "métallurgiste",
    "métals": "métal",
    "métamorphosa": "métamorphoser",
    "métamorphosaient": "métamorphoser",
    "métamorphosait": "métamorphoser",
    "métamorphosant": "métamorphoser",
    "métamorphose": "métamorphoser",
    "métamorphosent": "métamorphoser",
    "métamorphoseraient": "métamorphoser",
    "métamorphoserait": "métamorphoser",
    "métamorphoses": "métamorphoser",
    "métamorphosez": "métamorphoser",
    "métamorphosions": "métamorphoser",
    "métamorphosât": "métamorphoser",
    "métamorphosèrent": "métamorphoser",
    "métamorphosé": "métamorphoser",
    "métamorphosée": "métamorphoser",
    "métamorphosées": "métamorphoser",
    "métamorphosés": "métamorphoser",
    "métaphores": "métaphore",
    "métaphoriques": "métaphorique",
    "métaphysicienne": "métaphysicien",
    "métaphysiciens": "métaphysicien",
    "métaphysiques": "métaphysique",
    "métapsychiques": "métapsychique",
    "métastases": "métastase",
    "métastasé": "métastaser",
    "métatarses": "métatarse",
    "métatarsienne": "métatarsien",
    "métathèses": "métathèse",
    "métaux": "métal",
    "métayers": "métayer",
    "métayère": "métayer",
    "métayères": "métayer",
    "métazoaires": "métazoaire",
    "métempsycoses": "métempsycose",
    "méthadones": "méthadone",
    "méthanes": "méthane",
    "méthodes": "méthode",
    "méthodiques": "méthodique",
    "méthodistes": "méthodiste",
    "méthodologies": "méthodologie",
    "méthodologiques": "méthodologique",
    "méthyles": "méthyle",
    "méthyliques": "méthylique",
    "méticuleuse": "méticuleux",
    "méticuleuses": "méticuleux",
    "métiers": "métier",
    "métissa": "métisser",
    "métissages": "métissage",
    "métissai": "métisser",
    "métissaient": "métisser",
    "métissais": "métisser",
    "métissait": "métisser",
    "métissant": "métisser",
    "métissas": "métisser",
    "métissasse": "métisser",
    "métissassent": "métisser",
    "métissasses": "métisser",
    "métissassiez": "métisser",
    "métissassions": "métisser",
    "métisse": "métisser",
    "métissent": "métisser",
    "métissera": "métisser",
    "métisserai": "métisser",
    "métisseraient": "métisser",
    "métisserais": "métisser",
    "métisserait": "métisser",
    "métisseras": "métisser",
    "métisserez": "métisser",
    "métisseriez": "métisser",
    "métisserions": "métisser",
    "métisserons": "métisser",
    "métisseront": "métisser",
    "métisses": "métisser",
    "métissez": "métisser",
    "métissiez": "métisser",
    "métissions": "métisser",
    "métissons": "métisser",
    "métissâmes": "métisser",
    "métissât": "métisser",
    "métissâtes": "métisser",
    "métissèrent": "métisser",
    "métissé": "métisser",
    "métissée": "métisser",
    "métissées": "métisser",
    "métissés": "métisser",
    "métonymies": "métonymie",
    "métopes": "métope",
    "métra": "métrer",
    "métrages": "métrage",
    "métrai": "métrer",
    "métraient": "métrer",
    "métrais": "métrer",
    "métrait": "métrer",
    "métrant": "métrer",
    "métras": "métrer",
    "métrasse": "métrer",
    "métrassent": "métrer",
    "métrasses": "métrer",
    "métrassiez": "métrer",
    "métrassions": "métrer",
    "métrera": "métrer",
    "métrerai": "métrer",
    "métreraient": "métrer",
    "métrerais": "métrer",
    "métrerait": "métrer",
    "métreras": "métrer",
    "métrerez": "métrer",
    "métreriez": "métrer",
    "métrerions": "métrer",
    "métrerons": "métrer",
    "métreront": "métrer",
    "métrez": "métrer",
    "métriez": "métrer",
    "métrions": "métrer",
    "métriques": "métrique",
    "métrites": "métrite",
    "métrologies": "métrologie",
    "métrologiques": "métrologique",
    "métronomes": "métronome",
    "métrons": "métrer",
    "métropoles": "métropole",
    "métropolitaine": "métropolitain",
    "métropolitaines": "métropolitain",
    "métropolitains": "métropolitain",
    "métros": "métro",
    "métrâmes": "métrer",
    "métrât": "métrer",
    "métrâtes": "métrer",
    "métrèrent": "métrer",
    "métré": "métrer",
    "métrée": "métrer",
    "métrées": "métrer",
    "métrés": "métrer",
    "métèques": "métèque",
    "météores": "météore",
    "météorites": "météorite",
    "météorologies": "météorologie",
    "météorologiques": "météorologique",
    "météorologues": "météorologue",
    "météos": "météo",
    "mévend": "mévendre",
    "mévendaient": "mévendre",
    "mévendais": "mévendre",
    "mévendait": "mévendre",
    "mévendant": "mévendre",
    "mévende": "mévendre",
    "mévendent": "mévendre",
    "mévendes": "mévendre",
    "mévendez": "mévendre",
    "mévendiez": "mévendre",
    "mévendions": "mévendre",
    "mévendirent": "mévendre",
    "mévendis": "mévendre",
    "mévendisse": "mévendre",
    "mévendissent": "mévendre",
    "mévendisses": "mévendre",
    "mévendissiez": "mévendre",
    "mévendissions": "mévendre",
    "mévendit": "mévendre",
    "mévendons": "mévendre",
    "mévendra": "mévendre",
    "mévendrai": "mévendre",
    "mévendraient": "mévendre",
    "mévendrais": "mévendre",
    "mévendrait": "mévendre",
    "mévendras": "mévendre",
    "mévendrez": "mévendre",
    "mévendriez": "mévendre",
    "mévendrions": "mévendre",
    "mévendrons": "mévendre",
    "mévendront": "mévendre",
    "mévends": "mévendre",
    "mévendu": "mévendre",
    "mévendue": "mévendre",
    "mévendues": "mévendre",
    "mévendus": "mévendre",
    "mévendîmes": "mévendre",
    "mévendît": "mévendre",
    "mévendîtes": "mévendre",
    "méventes": "mévente",
    "mêla": "mêler",
    "mêlai": "mêler",
    "mêlaient": "mêler",
    "mêlais": "mêler",
    "mêlait": "mêler",
    "mêlant": "mêler",
    "mêlas": "mêler",
    "mêlasse": "mêler",
    "mêlassent": "mêler",
    "mêlasses": "mêler",
    "mêlassiez": "mêler",
    "mêlassions": "mêler",
    "mêle": "mêler",
    "mêlent": "mêler",
    "mêlera": "mêler",
    "mêlerai": "mêler",
    "mêleraient": "mêler",
    "mêlerais": "mêler",
    "mêlerait": "mêler",
    "mêleras": "mêler",
    "mêlerez": "mêler",
    "mêleriez": "mêler",
    "mêlerions": "mêler",
    "mêlerons": "mêler",
    "mêleront": "mêler",
    "mêles": "mêler",
    "mêlez": "mêler",
    "mêliez": "mêler",
    "mêlions": "mêler",
    "mêlons": "mêler",
    "mêlâmes": "mêler",
    "mêlât": "mêler",
    "mêlâtes": "mêler",
    "mêlèrent": "mêler",
    "mêlé": "mêler",
    "mêlée": "mêler",
    "mêlées": "mêler",
    "mêlés": "mêler",
    "mêmes": "même",
    "mîmes": "mettre",
    "mît": "mettre",
    "mîtes": "mettre",
    "môles": "môle",
    "mômeries": "mômerie",
    "mômes": "môme",
    "mû": "mouvoir",
    "mûmes": "mouvoir",
    "mûre": "mûr",
    "mûres": "mûre",
    "mûri": "mûrir",
    "mûrie": "mûrir",
    "mûriers": "mûrier",
    "mûries": "mûrir",
    "mûrira": "mûrir",
    "mûrirai": "mûrir",
    "mûriraient": "mûrir",
    "mûrirais": "mûrir",
    "mûrirait": "mûrir",
    "mûriras": "mûrir",
    "mûrirent": "mûrir",
    "mûrirez": "mûrir",
    "mûririez": "mûrir",
    "mûririons": "mûrir",
    "mûrirons": "mûrir",
    "mûriront": "mûrir",
    "mûris": "mûrir",
    "mûrissaient": "mûrir",
    "mûrissais": "mûrir",
    "mûrissait": "mûrir",
    "mûrissant": "mûrir",
    "mûrissante": "mûrissant",
    "mûrissantes": "mûrissant",
    "mûrissants": "mûrissant",
    "mûrisse": "mûrir",
    "mûrissements": "mûrissement",
    "mûrissent": "mûrir",
    "mûrisseries": "mûrisserie",
    "mûrisses": "mûrir",
    "mûrissez": "mûrir",
    "mûrissiez": "mûrir",
    "mûrissions": "mûrir",
    "mûrissons": "mûrir",
    "mûrit": "mûrir",
    "mûrs": "mûr",
    "mûrîmes": "mûrir",
    "mûrît": "mûrir",
    "mûrîtes": "mûrir",
    "mût": "mouvoir",
    "mûtes": "mouvoir",
    "n": "ne",
    "n'": "ne",
    "nababs": "nabab",
    "nabis": "nabi",
    "nabote": "nabot",
    "nabotes": "nabot",
    "nabots": "nabot",
    "nacelles": "nacelle",
    "nacra": "nacrer",
    "nacraient": "nacrer",
    "nacres": "nacre",
    "nacré": "nacrer",
    "nacrée": "nacrer",
    "nacrées": "nacrer",
    "nacrés": "nacrer",
    "nadirs": "nadir",
    "nage": "nager",
    "nagea": "nager",
    "nageai": "nager",
    "nageaient": "nager",
    "nageais": "nager",
    "nageait": "nager",
    "nageant": "nager",
    "nageante": "nageant",
    "nageas": "nager",
    "nageasse": "nager",
    "nageassent": "nager",
    "nageasses": "nager",
    "nageassiez": "nager",
    "nageassions": "nager",
    "nagent": "nager",
    "nageoires": "nageoire",
    "nageons": "nager",
    "nagera": "nager",
    "nagerai": "nager",
    "nageraient": "nager",
    "nagerais": "nager",
    "nagerait": "nager",
    "nageras": "nager",
    "nagerez": "nager",
    "nageriez": "nager",
    "nagerions": "nager",
    "nagerons": "nager",
    "nageront": "nager",
    "nages": "nager",
    "nageurs": "nageur",
    "nageuse": "nageur",
    "nageuses": "nageur",
    "nagez": "nager",
    "nageâmes": "nager",
    "nageât": "nager",
    "nageâtes": "nager",
    "nagiez": "nager",
    "nagions": "nager",
    "nagèrent": "nager",
    "nagé": "nager",
    "nagée": "nager",
    "nagées": "nager",
    "nagés": "nager",
    "naine": "nain",
    "naines": "nain",
    "nains": "nain",
    "nais": "naître",
    "naissaient": "naître",
    "naissains": "naissain",
    "naissais": "naître",
    "naissait": "naître",
    "naissances": "naissance",
    "naissant": "naître",
    "naissante": "naissant",
    "naissantes": "naissant",
    "naissants": "naissant",
    "naisse": "naître",
    "naissent": "naître",
    "naisses": "naître",
    "naissez": "naître",
    "naissiez": "naître",
    "naissions": "naître",
    "naissons": "naître",
    "najas": "naja",
    "namibienne": "namibien",
    "namibiennes": "namibien",
    "namibiens": "namibien",
    "nanans": "nanan",
    "nanas": "nana",
    "nancéiens": "nancéien",
    "nandous": "nandou",
    "nanismes": "nanisme",
    "nankins": "nankin",
    "nanomètres": "nanomètre",
    "nanosecondes": "nanoseconde",
    "nanoélectroniques": "nanoélectronique",
    "nantaise": "nantais",
    "nantaises": "nantais",
    "nanti": "nantir",
    "nantie": "nantir",
    "nanties": "nantir",
    "nantira": "nantir",
    "nantirai": "nantir",
    "nantiraient": "nantir",
    "nantirais": "nantir",
    "nantirait": "nantir",
    "nantiras": "nantir",
    "nantirent": "nantir",
    "nantirez": "nantir",
    "nantiriez": "nantir",
    "nantirions": "nantir",
    "nantirons": "nantir",
    "nantiront": "nantir",
    "nantis": "nantir",
    "nantissaient": "nantir",
    "nantissais": "nantir",
    "nantissait": "nantir",
    "nantissant": "nantir",
    "nantisse": "nantir",
    "nantissements": "nantissement",
    "nantissent": "nantir",
    "nantisses": "nantir",
    "nantissez": "nantir",
    "nantissiez": "nantir",
    "nantissions": "nantir",
    "nantissons": "nantir",
    "nantit": "nantir",
    "nantîmes": "nantir",
    "nantît": "nantir",
    "nantîtes": "nantir",
    "napalms": "napalm",
    "naphtalines": "naphtaline",
    "naphtes": "naphte",
    "napolitaine": "napolitain",
    "napolitaines": "napolitain",
    "napolitains": "napolitain",
    "napoléonienne": "napoléonien",
    "napoléoniennes": "napoléonien",
    "napoléoniens": "napoléonien",
    "napoléons": "napoléon",
    "nappa": "napper",
    "nappai": "napper",
    "nappaient": "napper",
    "nappais": "napper",
    "nappait": "napper",
    "nappant": "napper",
    "nappas": "napper",
    "nappasse": "napper",
    "nappassent": "napper",
    "nappasses": "napper",
    "nappassiez": "napper",
    "nappassions": "napper",
    "nappe": "napper",
    "nappent": "napper",
    "nappera": "napper",
    "napperai": "napper",
    "napperaient": "napper",
    "napperais": "napper",
    "napperait": "napper",
    "napperas": "napper",
    "napperez": "napper",
    "napperiez": "napper",
    "napperions": "napper",
    "napperons": "napperon",
    "napperont": "napper",
    "nappes": "napper",
    "nappez": "napper",
    "nappiez": "napper",
    "nappions": "napper",
    "nappons": "napper",
    "nappâmes": "napper",
    "nappât": "napper",
    "nappâtes": "napper",
    "nappèrent": "napper",
    "nappé": "napper",
    "nappée": "napper",
    "nappées": "napper",
    "nappés": "napper",
    "naquirent": "naître",
    "naquis": "naître",
    "naquisse": "naître",
    "naquissent": "naître",
    "naquisses": "naître",
    "naquissiez": "naître",
    "naquissions": "naître",
    "naquit": "naître",
    "naquîmes": "naître",
    "naquît": "naître",
    "naquîtes": "naître",
    "narcisses": "narcisse",
    "narcissiques": "narcissique",
    "narcissismes": "narcissisme",
    "narco-analyses": "narco-analyse",
    "narcodollars": "narcodollar",
    "narcoses": "narcose",
    "narcotiques": "narcotique",
    "narcotrafiquante": "narcotrafiquant",
    "narcotrafiquantes": "narcotrafiquant",
    "narcotrafiquants": "narcotrafiquant",
    "nards": "nard",
    "narghilés": "narghilé",
    "nargua": "narguer",
    "narguai": "narguer",
    "narguaient": "narguer",
    "narguais": "narguer",
    "narguait": "narguer",
    "narguant": "narguer",
    "narguas": "narguer",
    "narguasse": "narguer",
    "narguassent": "narguer",
    "narguasses": "narguer",
    "narguassiez": "narguer",
    "narguassions": "narguer",
    "nargue": "narguer",
    "narguent": "narguer",
    "narguera": "narguer",
    "narguerai": "narguer",
    "nargueraient": "narguer",
    "narguerais": "narguer",
    "narguerait": "narguer",
    "nargueras": "narguer",
    "narguerez": "narguer",
    "nargueriez": "narguer",
    "narguerions": "narguer",
    "narguerons": "narguer",
    "nargueront": "narguer",
    "nargues": "narguer",
    "narguez": "narguer",
    "narguiez": "narguer",
    "narguilés": "narguilé",
    "narguions": "narguer",
    "narguons": "narguer",
    "narguâmes": "narguer",
    "narguât": "narguer",
    "narguâtes": "narguer",
    "narguèrent": "narguer",
    "nargué": "narguer",
    "narguée": "narguer",
    "narguées": "narguer",
    "nargués": "narguer",
    "narines": "narine",
    "narquoise": "narquois",
    "narquoises": "narquois",
    "narra": "narrer",
    "narrai": "narrer",
    "narraient": "narrer",
    "narrais": "narrer",
    "narrait": "narrer",
    "narrant": "narrer",
    "narras": "narrer",
    "narrasse": "narrer",
    "narrassent": "narrer",
    "narrasses": "narrer",
    "narrassiez": "narrer",
    "narrassions": "narrer",
    "narrateurs": "narrateur",
    "narratifs": "narratif",
    "narrations": "narration",
    "narrative": "narratif",
    "narratives": "narratif",
    "narratrice": "narrateur",
    "narratrices": "narrateur",
    "narre": "narrer",
    "narrent": "narrer",
    "narrera": "narrer",
    "narrerai": "narrer",
    "narreraient": "narrer",
    "narrerais": "narrer",
    "narrerait": "narrer",
    "narreras": "narrer",
    "narrerez": "narrer",
    "narreriez": "narrer",
    "narrerions": "narrer",
    "narrerons": "narrer",
    "narreront": "narrer",
    "narres": "narrer",
    "narrez": "narrer",
    "narriez": "narrer",
    "narrions": "narrer",
    "narrons": "narrer",
    "narrâmes": "narrer",
    "narrât": "narrer",
    "narrâtes": "narrer",
    "narrèrent": "narrer",
    "narré": "narrer",
    "narrée": "narrer",
    "narrées": "narrer",
    "narrés": "narrer",
    "narvals": "narval",
    "nasale": "nasal",
    "nasales": "nasal",
    "nasals": "nasal",
    "nasardes": "nasard",
    "nasaux": "nasal",
    "naseaux": "naseau",
    "nases": "nase",
    "nasilla": "nasiller",
    "nasillai": "nasiller",
    "nasillaient": "nasiller",
    "nasillais": "nasiller",
    "nasillait": "nasiller",
    "nasillant": "nasiller",
    "nasillarde": "nasillard",
    "nasillardes": "nasillard",
    "nasillards": "nasillard",
    "nasillas": "nasiller",
    "nasillasse": "nasiller",
    "nasillassent": "nasiller",
    "nasillasses": "nasiller",
    "nasillassiez": "nasiller",
    "nasillassions": "nasiller",
    "nasille": "nasiller",
    "nasillent": "nasiller",
    "nasillera": "nasiller",
    "nasillerai": "nasiller",
    "nasilleraient": "nasiller",
    "nasillerais": "nasiller",
    "nasillerait": "nasiller",
    "nasilleras": "nasiller",
    "nasillerez": "nasiller",
    "nasilleriez": "nasiller",
    "nasillerions": "nasiller",
    "nasillerons": "nasiller",
    "nasilleront": "nasiller",
    "nasilles": "nasiller",
    "nasillez": "nasiller",
    "nasilliez": "nasiller",
    "nasillions": "nasiller",
    "nasillonne": "nasillonner",
    "nasillons": "nasiller",
    "nasillâmes": "nasiller",
    "nasillât": "nasiller",
    "nasillâtes": "nasiller",
    "nasillèrent": "nasiller",
    "nasillé": "nasiller",
    "nasses": "nasse",
    "natale": "natal",
    "natales": "natal",
    "natalistes": "nataliste",
    "natalités": "natalité",
    "natals": "natal",
    "natations": "natation",
    "nataux": "natal",
    "natifs": "natif",
    "nationale": "national",
    "nationales": "nationale",
    "nationalisa": "nationaliser",
    "nationalisai": "nationaliser",
    "nationalisaient": "nationaliser",
    "nationalisais": "nationaliser",
    "nationalisait": "nationaliser",
    "nationalisant": "nationaliser",
    "nationalisas": "nationaliser",
    "nationalisasse": "nationaliser",
    "nationalisassent": "nationaliser",
    "nationalisasses": "nationaliser",
    "nationalisassiez": "nationaliser",
    "nationalisassions": "nationaliser",
    "nationalisations": "nationalisation",
    "nationalise": "nationaliser",
    "nationalisent": "nationaliser",
    "nationalisera": "nationaliser",
    "nationaliserai": "nationaliser",
    "nationaliseraient": "nationaliser",
    "nationaliserais": "nationaliser",
    "nationaliserait": "nationaliser",
    "nationaliseras": "nationaliser",
    "nationaliserez": "nationaliser",
    "nationaliseriez": "nationaliser",
    "nationaliserions": "nationaliser",
    "nationaliserons": "nationaliser",
    "nationaliseront": "nationaliser",
    "nationalises": "nationaliser",
    "nationalisez": "nationaliser",
    "nationalisiez": "nationaliser",
    "nationalisions": "nationaliser",
    "nationalismes": "nationalisme",
    "nationalisons": "nationaliser",
    "nationalistes": "nationaliste",
    "nationalisâmes": "nationaliser",
    "nationalisât": "nationaliser",
    "nationalisâtes": "nationaliser",
    "nationalisèrent": "nationaliser",
    "nationalisé": "nationaliser",
    "nationalisée": "nationaliser",
    "nationalisées": "nationaliser",
    "nationalisés": "nationaliser",
    "nationalités": "nationalité",
    "nationaux": "national",
    "nations": "nation",
    "native": "natif",
    "natives": "native",
    "nativités": "nativité",
    "natrons": "natron",
    "natrums": "natrum",
    "natta": "natter",
    "natte": "natter",
    "nattes": "natte",
    "natté": "natter",
    "nattée": "natter",
    "nattées": "natter",
    "nattés": "natter",
    "naturalisa": "naturaliser",
    "naturalisai": "naturaliser",
    "naturalisaient": "naturaliser",
    "naturalisais": "naturaliser",
    "naturalisait": "naturaliser",
    "naturalisant": "naturaliser",
    "naturalisas": "naturaliser",
    "naturalisasse": "naturaliser",
    "naturalisassent": "naturaliser",
    "naturalisasses": "naturaliser",
    "naturalisassiez": "naturaliser",
    "naturalisassions": "naturaliser",
    "naturalisations": "naturalisation",
    "naturalise": "naturaliser",
    "naturalisent": "naturaliser",
    "naturalisera": "naturaliser",
    "naturaliserai": "naturaliser",
    "naturaliseraient": "naturaliser",
    "naturaliserais": "naturaliser",
    "naturaliserait": "naturaliser",
    "naturaliseras": "naturaliser",
    "naturaliserez": "naturaliser",
    "naturaliseriez": "naturaliser",
    "naturaliserions": "naturaliser",
    "naturaliserons": "naturaliser",
    "naturaliseront": "naturaliser",
    "naturalises": "naturaliser",
    "naturalisez": "naturaliser",
    "naturalisiez": "naturaliser",
    "naturalisions": "naturaliser",
    "naturalismes": "naturalisme",
    "naturalisons": "naturaliser",
    "naturalistes": "naturaliste",
    "naturalisâmes": "naturaliser",
    "naturalisât": "naturaliser",
    "naturalisâtes": "naturaliser",
    "naturalisèrent": "naturaliser",
    "naturalisé": "naturaliser",
    "naturalisée": "naturaliser",
    "naturalisées": "naturaliser",
    "naturalisés": "naturaliser",
    "naturelle": "naturel",
    "naturelles": "naturel",
    "naturels": "naturel",
    "natures": "nature",
    "naturistes": "naturiste",
    "naufrage": "naufrager",
    "naufrageant": "naufrager",
    "naufragent": "naufrager",
    "naufrages": "naufrage",
    "naufrageurs": "naufrageur",
    "naufrageuse": "naufrageur",
    "naufragé": "naufrager",
    "naufragée": "naufrager",
    "naufragées": "naufragé",
    "naufragés": "naufrager",
    "nauséabonde": "nauséabond",
    "nauséabondes": "nauséabond",
    "nauséabonds": "nauséabond",
    "nausées": "nausée",
    "nauséeuse": "nauséeux",
    "nauséeuses": "nauséeux",
    "nautes": "naute",
    "nautiques": "nautique",
    "nautoniers": "nautonier",
    "navajas": "navaja",
    "navajos": "navajo",
    "navale": "naval",
    "navales": "navale",
    "navals": "naval",
    "navarins": "navarin",
    "navets": "navet",
    "navettes": "navette",
    "navigabilités": "navigabilité",
    "navigables": "navigable",
    "navigante": "navigant",
    "navigantes": "navigant",
    "navigants": "navigant",
    "navigateurs": "navigateur",
    "navigations": "navigation",
    "navigatrice": "navigateur",
    "navigatrices": "navigateur",
    "navigua": "naviguer",
    "naviguai": "naviguer",
    "naviguaient": "naviguer",
    "naviguais": "naviguer",
    "naviguait": "naviguer",
    "naviguant": "naviguer",
    "naviguas": "naviguer",
    "naviguasse": "naviguer",
    "naviguassent": "naviguer",
    "naviguasses": "naviguer",
    "naviguassiez": "naviguer",
    "naviguassions": "naviguer",
    "navigue": "naviguer",
    "naviguent": "naviguer",
    "naviguera": "naviguer",
    "naviguerai": "naviguer",
    "navigueraient": "naviguer",
    "naviguerais": "naviguer",
    "naviguerait": "naviguer",
    "navigueras": "naviguer",
    "naviguerez": "naviguer",
    "navigueriez": "naviguer",
    "naviguerions": "naviguer",
    "naviguerons": "naviguer",
    "navigueront": "naviguer",
    "navigues": "naviguer",
    "naviguez": "naviguer",
    "naviguiez": "naviguer",
    "naviguions": "naviguer",
    "naviguons": "naviguer",
    "naviguâmes": "naviguer",
    "naviguât": "naviguer",
    "naviguâtes": "naviguer",
    "naviguèrent": "naviguer",
    "navigué": "naviguer",
    "navires": "navire",
    "navires-citernes": "navire-citerne",
    "navires-hôpitaux": "navire-hôpital",
    "navires-écoles": "navire-école",
    "navra": "navrer",
    "navrai": "navrer",
    "navraient": "navrer",
    "navrais": "navrer",
    "navrait": "navrer",
    "navrant": "navrer",
    "navrante": "navrant",
    "navrantes": "navrant",
    "navrants": "navrant",
    "navras": "navrer",
    "navrasse": "navrer",
    "navrassent": "navrer",
    "navrasses": "navrer",
    "navrassiez": "navrer",
    "navrassions": "navrer",
    "navre": "navrer",
    "navrent": "navrer",
    "navrera": "navrer",
    "navrerai": "navrer",
    "navreraient": "navrer",
    "navrerais": "navrer",
    "navrerait": "navrer",
    "navreras": "navrer",
    "navrerez": "navrer",
    "navreriez": "navrer",
    "navrerions": "navrer",
    "navrerons": "navrer",
    "navreront": "navrer",
    "navres": "navrer",
    "navrez": "navrer",
    "navriez": "navrer",
    "navrions": "navrer",
    "navrons": "navrer",
    "navrâmes": "navrer",
    "navrât": "navrer",
    "navrâtes": "navrer",
    "navrèrent": "navrer",
    "navré": "navrer",
    "navrée": "navrer",
    "navrées": "navrer",
    "navrés": "navrer",
    "nazes": "naze",
    "nazie": "nazi",
    "nazies": "nazi",
    "nazillons": "nazillon",
    "nazis": "nazi",
    "nazismes": "nazisme",
    "naît": "naître",
    "naîtra": "naître",
    "naîtrai": "naître",
    "naîtraient": "naître",
    "naîtrais": "naître",
    "naîtrait": "naître",
    "naîtras": "naître",
    "naîtrez": "naître",
    "naîtriez": "naître",
    "naîtrions": "naître",
    "naîtrons": "naître",
    "naîtront": "naître",
    "naïades": "naïade",
    "naïfs": "naïve",
    "naïve": "naïf",
    "naïves": "naïve",
    "naïvetés": "naïveté",
    "nectaires": "nectaire",
    "nectarines": "nectarine",
    "nectars": "nectar",
    "nefs": "nef",
    "negro spirituals": "negro spiritual",
    "negro-spirituals": "negro-spiritual",
    "neige": "neiger",
    "neigea": "neiger",
    "neigeait": "neiger",
    "neigeant": "neiger",
    "neigera": "neiger",
    "neigerait": "neiger",
    "neiges": "neiger",
    "neigeuse": "neigeux",
    "neigeuses": "neigeux",
    "neigeât": "neiger",
    "neigé": "neiger",
    "nems": "nem",
    "neptunienne": "neptunien",
    "neptuniens": "neptunien",
    "nerfs": "nerf",
    "nerpruns": "nerprun",
    "nerva": "nerver",
    "nerveuse": "nerveux",
    "nerveuses": "nerveux",
    "nervis": "nervi",
    "nervosités": "nervosité",
    "nervures": "nervure",
    "nervuré": "nervurer",
    "nervurée": "nervurer",
    "nervurées": "nervurer",
    "nervé": "nerver",
    "nestorienne": "nestorien",
    "nestoriennes": "nestorien",
    "nestoriens": "nestorien",
    "nets": "net",
    "nette": "net",
    "nettes": "net",
    "nettetés": "netteté",
    "nettoie": "nettoyer",
    "nettoiements": "nettoiement",
    "nettoient": "nettoyer",
    "nettoiera": "nettoyer",
    "nettoierai": "nettoyer",
    "nettoieraient": "nettoyer",
    "nettoierais": "nettoyer",
    "nettoierait": "nettoyer",
    "nettoieras": "nettoyer",
    "nettoierez": "nettoyer",
    "nettoieriez": "nettoyer",
    "nettoierions": "nettoyer",
    "nettoierons": "nettoyer",
    "nettoieront": "nettoyer",
    "nettoies": "nettoyer",
    "nettoya": "nettoyer",
    "nettoyables": "nettoyable",
    "nettoyages": "nettoyage",
    "nettoyai": "nettoyer",
    "nettoyaient": "nettoyer",
    "nettoyais": "nettoyer",
    "nettoyait": "nettoyer",
    "nettoyant": "nettoyer",
    "nettoyante": "nettoyant",
    "nettoyants": "nettoyant",
    "nettoyas": "nettoyer",
    "nettoyasse": "nettoyer",
    "nettoyassent": "nettoyer",
    "nettoyasses": "nettoyer",
    "nettoyassiez": "nettoyer",
    "nettoyassions": "nettoyer",
    "nettoyeurs": "nettoyeur",
    "nettoyeuse": "nettoyeur",
    "nettoyeuses": "nettoyeur",
    "nettoyez": "nettoyer",
    "nettoyiez": "nettoyer",
    "nettoyions": "nettoyer",
    "nettoyons": "nettoyer",
    "nettoyâmes": "nettoyer",
    "nettoyât": "nettoyer",
    "nettoyâtes": "nettoyer",
    "nettoyèrent": "nettoyer",
    "nettoyé": "nettoyer",
    "nettoyée": "nettoyer",
    "nettoyées": "nettoyer",
    "nettoyés": "nettoyer",
    "neufs": "neuf",
    "neurale": "neural",
    "neurales": "neural",
    "neurasthénies": "neurasthénie",
    "neurasthéniques": "neurasthénique",
    "neuraux": "neural",
    "neurobiologies": "neurobiologie",
    "neurochirurgienne": "neurochirurgien",
    "neuroleptiques": "neuroleptique",
    "neurologies": "neurologie",
    "neurologiques": "neurologique",
    "neurologues": "neurologue",
    "neuronale": "neuronal",
    "neuronales": "neuronal",
    "neuronaux": "neuronal",
    "neurones": "neurone",
    "neuropsychiatres": "neuropsychiatre",
    "neuropsychiques": "neuropsychique",
    "neuropsychologiques": "neuropsychologique",
    "neurotransmetteurs": "neurotransmetteur",
    "neutralisa": "neutraliser",
    "neutralisai": "neutraliser",
    "neutralisaient": "neutraliser",
    "neutralisais": "neutraliser",
    "neutralisait": "neutraliser",
    "neutralisant": "neutraliser",
    "neutralisante": "neutralisant",
    "neutralisas": "neutraliser",
    "neutralisasse": "neutraliser",
    "neutralisassent": "neutraliser",
    "neutralisasses": "neutraliser",
    "neutralisassiez": "neutraliser",
    "neutralisassions": "neutraliser",
    "neutralisations": "neutralisation",
    "neutralise": "neutraliser",
    "neutralisent": "neutraliser",
    "neutralisera": "neutraliser",
    "neutraliserai": "neutraliser",
    "neutraliseraient": "neutraliser",
    "neutraliserais": "neutraliser",
    "neutraliserait": "neutraliser",
    "neutraliseras": "neutraliser",
    "neutraliserez": "neutraliser",
    "neutraliseriez": "neutraliser",
    "neutraliserions": "neutraliser",
    "neutraliserons": "neutraliser",
    "neutraliseront": "neutraliser",
    "neutralises": "neutraliser",
    "neutralisez": "neutraliser",
    "neutralisiez": "neutraliser",
    "neutralisions": "neutraliser",
    "neutralisons": "neutraliser",
    "neutralisâmes": "neutraliser",
    "neutralisât": "neutraliser",
    "neutralisâtes": "neutraliser",
    "neutralisèrent": "neutraliser",
    "neutralisé": "neutraliser",
    "neutralisée": "neutraliser",
    "neutralisées": "neutraliser",
    "neutralisés": "neutraliser",
    "neutralités": "neutralité",
    "neutres": "neutre",
    "neutrinos": "neutrino",
    "neutroniques": "neutronique",
    "neutrons": "neutron",
    "neuvaines": "neuvaine",
    "neuve": "neuf",
    "neuves": "neuf",
    "neuvièmes": "neuvième",
    "neveux": "neveu",
    "new-yorkaise": "new-yorkais",
    "new-yorkaises": "new-yorkais",
    "news": "new",
    "nia": "nier",
    "niables": "niable",
    "niai": "nier",
    "niaient": "nier",
    "niais": "nier",
    "niaise": "niais",
    "niaiseries": "niaiserie",
    "niaises": "niais",
    "niaiseuse": "niaiseux",
    "niaisé": "niaiser",
    "niait": "nier",
    "niakoués": "niakoué",
    "niant": "nier",
    "nias": "nier",
    "niasse": "nier",
    "niassent": "nier",
    "niasses": "nier",
    "niassiez": "nier",
    "niassions": "nier",
    "nibards": "nibard",
    "nicaraguayenne": "nicaraguayen",
    "nicaraguayennes": "nicaraguayen",
    "nicaraguayens": "nicaraguayen",
    "nicha": "nicher",
    "nichai": "nicher",
    "nichaient": "nicher",
    "nichais": "nicher",
    "nichait": "nicher",
    "nichant": "nicher",
    "nichas": "nicher",
    "nichasse": "nicher",
    "nichassent": "nicher",
    "nichasses": "nicher",
    "nichassiez": "nicher",
    "nichassions": "nicher",
    "niche": "nicher",
    "nichent": "nicher",
    "nichera": "nicher",
    "nicherai": "nicher",
    "nicheraient": "nicher",
    "nicherais": "nicher",
    "nicherait": "nicher",
    "nicheras": "nicher",
    "nicherez": "nicher",
    "nicheriez": "nicher",
    "nicherions": "nicher",
    "nicherons": "nicher",
    "nicheront": "nicher",
    "niches": "nicher",
    "nicheurs": "nicheur",
    "nichez": "nicher",
    "nichiez": "nicher",
    "nichions": "nicher",
    "nichonnées": "nichonnée",
    "nichons": "nichon",
    "nichâmes": "nicher",
    "nichât": "nicher",
    "nichâtes": "nicher",
    "nichèrent": "nicher",
    "niché": "nicher",
    "nichée": "nicher",
    "nichées": "nicher",
    "nichés": "nicher",
    "nickelle": "nickeler",
    "nickels": "nickel",
    "nickelé": "nickeler",
    "nickelée": "nickeler",
    "nickelées": "nickeler",
    "nickelés": "nickeler",
    "nicotines": "nicotine",
    "nicotinisé": "nicotiniser",
    "nicotinisés": "nicotiniser",
    "nictitante": "nictitant",
    "nidifications": "nidification",
    "nidificatrices": "nidificateur",
    "nidifie": "nidifier",
    "nids": "nid",
    "nids-de-poule": "nid-de-poule",
    "nie": "nier",
    "nielles": "nielle",
    "niellé": "nieller",
    "nient": "nier",
    "niera": "nier",
    "nierai": "nier",
    "nieraient": "nier",
    "nierais": "nier",
    "nierait": "nier",
    "nieras": "nier",
    "nierez": "nier",
    "nieriez": "nier",
    "nierions": "nier",
    "nierons": "nier",
    "nieront": "nier",
    "nies": "nier",
    "nietzschéenne": "nietzschéen",
    "nietzschéennes": "nietzschéenne",
    "niez": "nier",
    "nigaude": "nigaud",
    "nigaudes": "nigaud",
    "nigauds": "nigaud",
    "nigelle": "nigel",
    "night club": "night-club",
    "night-clubs": "night-club",
    "nigériane": "nigérian",
    "nigérianes": "nigérian",
    "nigérians": "nigérian",
    "nigériens": "nigérien",
    "nihilismes": "nihilisme",
    "nihilistes": "nihiliste",
    "niiez": "nier",
    "niions": "nier",
    "nimba": "nimber",
    "nimbaient": "nimber",
    "nimbait": "nimber",
    "nimbant": "nimber",
    "nimbent": "nimber",
    "nimbes": "nimbe",
    "nimbé": "nimber",
    "nimbée": "nimber",
    "nimbées": "nimber",
    "nimbés": "nimber",
    "nions": "nier",
    "nippa": "nipper",
    "nippai": "nipper",
    "nippaient": "nipper",
    "nippais": "nipper",
    "nippait": "nipper",
    "nippant": "nipper",
    "nippas": "nipper",
    "nippasse": "nipper",
    "nippassent": "nipper",
    "nippasses": "nipper",
    "nippassiez": "nipper",
    "nippassions": "nipper",
    "nippe": "nipper",
    "nippent": "nipper",
    "nippera": "nipper",
    "nipperai": "nipper",
    "nipperaient": "nipper",
    "nipperais": "nipper",
    "nipperait": "nipper",
    "nipperas": "nipper",
    "nipperez": "nipper",
    "nipperiez": "nipper",
    "nipperions": "nipper",
    "nipperons": "nipper",
    "nipperont": "nipper",
    "nippes": "nipper",
    "nippez": "nipper",
    "nippiez": "nipper",
    "nippions": "nipper",
    "nippone": "nippon",
    "nippones": "nippon",
    "nipponne": "nippon",
    "nipponnes": "nippon",
    "nippons": "nippon",
    "nippâmes": "nipper",
    "nippât": "nipper",
    "nippâtes": "nipper",
    "nippèrent": "nipper",
    "nippé": "nipper",
    "nippée": "nipper",
    "nippées": "nipper",
    "nippés": "nipper",
    "niquait": "niquer",
    "nique": "niquer",
    "niquent": "niquer",
    "niquera": "niquer",
    "niquerait": "niquer",
    "niques": "niquer",
    "niquez": "niquer",
    "niquons": "niquer",
    "niqué": "niquer",
    "niquée": "niquer",
    "niqués": "niquer",
    "nirvanas": "nirvana",
    "nitratant": "nitrater",
    "nitrates": "nitrate",
    "nitres": "nitre",
    "nitreuse": "nitreux",
    "nivale": "nival",
    "nivales": "nival",
    "nivaux": "nival",
    "niveaux": "niveau",
    "nivela": "niveler",
    "nivelai": "niveler",
    "nivelaient": "niveler",
    "nivelais": "niveler",
    "nivelait": "niveler",
    "nivelant": "niveler",
    "nivelas": "niveler",
    "nivelasse": "niveler",
    "nivelassent": "niveler",
    "nivelasses": "niveler",
    "nivelassiez": "niveler",
    "nivelassions": "niveler",
    "niveleurs": "niveleur",
    "niveleuse": "niveleur",
    "nivelez": "niveler",
    "niveliez": "niveler",
    "nivelions": "niveler",
    "nivelle": "niveler",
    "nivellements": "nivellement",
    "nivellent": "niveler",
    "nivellera": "niveler",
    "nivellerai": "niveler",
    "nivelleraient": "niveler",
    "nivellerais": "niveler",
    "nivellerait": "niveler",
    "nivelleras": "niveler",
    "nivellerez": "niveler",
    "nivelleriez": "niveler",
    "nivellerions": "niveler",
    "nivellerons": "niveler",
    "nivelleront": "niveler",
    "nivelles": "niveler",
    "nivelons": "niveler",
    "nivelâmes": "niveler",
    "nivelât": "niveler",
    "nivelâtes": "niveler",
    "nivelèrent": "niveler",
    "nivelé": "niveler",
    "nivelée": "niveler",
    "nivelées": "niveler",
    "nivelés": "niveler",
    "nivéoles": "nivéole",
    "nivôses": "nivôse",
    "niâmes": "nier",
    "niât": "nier",
    "niâtes": "nier",
    "niçoise": "niçois",
    "niçoises": "niçois",
    "nièces": "nièce",
    "nièrent": "nier",
    "nié": "nier",
    "niée": "nier",
    "niées": "nier",
    "niés": "nier",
    "no.": "numéro",
    "nobiliaires": "nobiliaire",
    "nobles": "noble",
    "noblesses": "noblesse",
    "nobliaux": "nobliau",
    "nobélisables": "nobélisable",
    "noces": "noce",
    "noceurs": "noceur",
    "noceuse": "noceur",
    "noceuses": "noceur",
    "nochers": "nocher",
    "nocifs": "nocif",
    "nocive": "nocif",
    "nocives": "nocif",
    "nocivités": "nocivité",
    "noctambules": "noctambule",
    "nocturnes": "nocturne",
    "nodale": "nodal",
    "nodales": "nodal",
    "nodaux": "nodal",
    "nodosités": "nodosité",
    "nodules": "nodule",
    "noeuds": "noeud",
    "noie": "noyer",
    "noient": "noyer",
    "noiera": "noyer",
    "noierai": "noyer",
    "noieraient": "noyer",
    "noierais": "noyer",
    "noierait": "noyer",
    "noieras": "noyer",
    "noierez": "noyer",
    "noieriez": "noyer",
    "noierions": "noyer",
    "noierons": "noyer",
    "noieront": "noyer",
    "noies": "noyer",
    "noiraude": "noiraud",
    "noiraudes": "noiraud",
    "noirauds": "noiraud",
    "noirceurs": "noirceur",
    "noirci": "noircir",
    "noircie": "noircir",
    "noircies": "noircir",
    "noircira": "noircir",
    "noircirai": "noircir",
    "noirciraient": "noircir",
    "noircirais": "noircir",
    "noircirait": "noircir",
    "noirciras": "noircir",
    "noircirent": "noircir",
    "noircirez": "noircir",
    "noirciriez": "noircir",
    "noircirions": "noircir",
    "noircirons": "noircir",
    "noirciront": "noircir",
    "noircis": "noircir",
    "noircissaient": "noircir",
    "noircissais": "noircir",
    "noircissait": "noircir",
    "noircissant": "noircir",
    "noircisse": "noircir",
    "noircissent": "noircir",
    "noircisses": "noircir",
    "noircissez": "noircir",
    "noircissiez": "noircir",
    "noircissions": "noircir",
    "noircissons": "noircir",
    "noircit": "noircir",
    "noircîmes": "noircir",
    "noircît": "noircir",
    "noircîtes": "noircir",
    "noire": "noir",
    "noires": "noir",
    "noirs": "noir",
    "noirâtres": "noirâtre",
    "noises": "noise",
    "noisetiers": "noisetier",
    "noisettes": "noisette",
    "nolisa": "noliser",
    "nolisai": "noliser",
    "nolisaient": "noliser",
    "nolisais": "noliser",
    "nolisait": "noliser",
    "nolisant": "noliser",
    "nolisas": "noliser",
    "nolisasse": "noliser",
    "nolisassent": "noliser",
    "nolisasses": "noliser",
    "nolisassiez": "noliser",
    "nolisassions": "noliser",
    "nolise": "noliser",
    "nolisent": "noliser",
    "nolisera": "noliser",
    "noliserai": "noliser",
    "noliseraient": "noliser",
    "noliserais": "noliser",
    "noliserait": "noliser",
    "noliseras": "noliser",
    "noliserez": "noliser",
    "noliseriez": "noliser",
    "noliserions": "noliser",
    "noliserons": "noliser",
    "noliseront": "noliser",
    "nolises": "noliser",
    "nolisez": "noliser",
    "nolisiez": "noliser",
    "nolisions": "noliser",
    "nolisons": "noliser",
    "nolisâmes": "noliser",
    "nolisât": "noliser",
    "nolisâtes": "noliser",
    "nolisèrent": "noliser",
    "nolisé": "noliser",
    "nolisée": "noliser",
    "nolisées": "noliser",
    "nolisés": "noliser",
    "nomades": "nomade",
    "nomadisait": "nomadiser",
    "nomadisant": "nomadiser",
    "nomadisent": "nomadiser",
    "nomadismes": "nomadisme",
    "nombres": "nombre",
    "nombreuse": "nombreux",
    "nombreuses": "nombreux",
    "nombrilismes": "nombrilisme",
    "nombrils": "nombril",
    "nomenclatures": "nomenclature",
    "nomes": "nome",
    "nominale": "nominal",
    "nominales": "nominal",
    "nominatifs": "nominatif",
    "nominations": "nomination",
    "nominative": "nominatif",
    "nominatives": "nominatif",
    "nominaux": "nominal",
    "nomine": "nominer",
    "nominé": "nominer",
    "nominée": "nominer",
    "nominées": "nominer",
    "nominés": "nominer",
    "nomma": "nommer",
    "nommai": "nommer",
    "nommaient": "nommer",
    "nommais": "nommer",
    "nommait": "nommer",
    "nommant": "nommer",
    "nommas": "nommer",
    "nommasse": "nommer",
    "nommassent": "nommer",
    "nommasses": "nommer",
    "nommassiez": "nommer",
    "nommassions": "nommer",
    "nomme": "nommer",
    "nomment": "nommer",
    "nommera": "nommer",
    "nommerai": "nommer",
    "nommeraient": "nommer",
    "nommerais": "nommer",
    "nommerait": "nommer",
    "nommeras": "nommer",
    "nommerez": "nommer",
    "nommeriez": "nommer",
    "nommerions": "nommer",
    "nommerons": "nommer",
    "nommeront": "nommer",
    "nommes": "nommer",
    "nommez": "nommer",
    "nommiez": "nommer",
    "nommions": "nommer",
    "nommons": "nommer",
    "nommâmes": "nommer",
    "nommât": "nommer",
    "nommâtes": "nommer",
    "nommèrent": "nommer",
    "nommé": "nommer",
    "nommée": "nommer",
    "nommées": "nommer",
    "nommés": "nommer",
    "noms": "nom",
    "non-activités": "non-activité",
    "non-agressions": "non-agression",
    "non-alignements": "non-alignement",
    "non-alignée": "non-aligné",
    "non-alignées": "non-aligné",
    "non-alignés": "non-aligné",
    "non-assistances": "non-assistance",
    "non-belligérante": "non-belligérant",
    "non-belligérantes": "non-belligérant",
    "non-belligérants": "non-belligérant",
    "non-blancs": "non-blanc",
    "non-combattants": "non-combattant",
    "non-conformismes": "non-conformisme",
    "non-conformistes": "non-conformiste",
    "non-croyante": "non-croyant",
    "non-croyantes": "non-croyant",
    "non-croyants": "non-croyant",
    "non-directifs": "non-directif",
    "non-directive": "non-directif",
    "non-directives": "non-directif",
    "non-dits": "non-dit",
    "non-engagée": "non-engagé",
    "non-engagées": "non-engagé",
    "non-engagés": "non-engagé",
    "non-ingérences": "non-ingérence",
    "non-initiés": "non-initié",
    "non-lieux": "non-lieu",
    "non-malades": "non-malade",
    "non-paiements": "non-paiement",
    "non-proliférations": "non-prolifération",
    "non-respects": "non-respect",
    "non-résidente": "non-résident",
    "non-résidentes": "non-résident",
    "non-résidents": "non-résident",
    "non-réussites": "non-réussite",
    "non-spécialistes": "non-spécialiste",
    "non-stops": "non-stop",
    "non-valeurs": "non-valeur",
    "non-violences": "non-violence",
    "non-violente": "non-violent",
    "non-violentes": "non-violent",
    "non-violents": "non-violent",
    "non-voyante": "non-voyant",
    "non-voyants": "non-voyant",
    "nonagénaires": "nonagénaire",
    "nonces": "nonce",
    "nonchalances": "nonchalance",
    "nonchalante": "nonchalant",
    "nonchalantes": "nonchalant",
    "nonchalants": "nonchalant",
    "nonciatures": "nonciature",
    "nones": "none",
    "nonettes": "nonette",
    "nonnes": "nonne",
    "nonnettes": "nonnette",
    "nonpareille": "nonpareil",
    "nopals": "nopal",
    "nord-africaine": "nord-africain",
    "nord-africaines": "nord-africain",
    "nord-africains": "nord-africain",
    "nord-américaine": "nord-américain",
    "nord-américaines": "nord-américain",
    "nord-américains": "nord-américain",
    "nord-coréenne": "nord-coréen",
    "nord-coréennes": "nord-coréen",
    "nord-coréens": "nord-coréen",
    "nord-vietnamienne": "nord-vietnamien",
    "nord-vietnamiens": "nord-vietnamien",
    "nordi": "nordir",
    "nordie": "nordir",
    "nordies": "nordir",
    "nordiques": "nordique",
    "nordira": "nordir",
    "nordirai": "nordir",
    "nordiraient": "nordir",
    "nordirais": "nordir",
    "nordirait": "nordir",
    "nordiras": "nordir",
    "nordirent": "nordir",
    "nordirez": "nordir",
    "nordiriez": "nordir",
    "nordirions": "nordir",
    "nordirons": "nordir",
    "nordiront": "nordir",
    "nordis": "nordir",
    "nordissaient": "nordir",
    "nordissais": "nordir",
    "nordissait": "nordir",
    "nordissant": "nordir",
    "nordisse": "nordir",
    "nordissent": "nordir",
    "nordisses": "nordir",
    "nordissez": "nordir",
    "nordissiez": "nordir",
    "nordissions": "nordir",
    "nordissons": "nordir",
    "nordistes": "nordiste",
    "nordit": "nordir",
    "nordîmes": "nordir",
    "nordît": "nordir",
    "nordîtes": "nordir",
    "norias": "noria",
    "normale": "normal",
    "normales": "normale",
    "normalienne": "normalien",
    "normaliennes": "normalien",
    "normaliens": "normalien",
    "normalisa": "normaliser",
    "normalisai": "normaliser",
    "normalisaient": "normaliser",
    "normalisais": "normaliser",
    "normalisait": "normaliser",
    "normalisant": "normaliser",
    "normalisas": "normaliser",
    "normalisasse": "normaliser",
    "normalisassent": "normaliser",
    "normalisasses": "normaliser",
    "normalisassiez": "normaliser",
    "normalisassions": "normaliser",
    "normalisations": "normalisation",
    "normalise": "normaliser",
    "normalisent": "normaliser",
    "normalisera": "normaliser",
    "normaliserai": "normaliser",
    "normaliseraient": "normaliser",
    "normaliserais": "normaliser",
    "normaliserait": "normaliser",
    "normaliseras": "normaliser",
    "normaliserez": "normaliser",
    "normaliseriez": "normaliser",
    "normaliserions": "normaliser",
    "normaliserons": "normaliser",
    "normaliseront": "normaliser",
    "normalises": "normaliser",
    "normalisez": "normaliser",
    "normalisiez": "normaliser",
    "normalisions": "normaliser",
    "normalisons": "normaliser",
    "normalisâmes": "normaliser",
    "normalisât": "normaliser",
    "normalisâtes": "normaliser",
    "normalisèrent": "normaliser",
    "normalisé": "normaliser",
    "normalisée": "normaliser",
    "normalisées": "normaliser",
    "normalisés": "normaliser",
    "normalités": "normalité",
    "normande": "normand",
    "normandes": "normand",
    "normands": "normand",
    "normatifs": "normatif",
    "normative": "normatif",
    "normatives": "normatif",
    "normaux": "normal",
    "normes": "norme",
    "norroise": "norrois",
    "norvégienne": "norvégien",
    "norvégiennes": "norvégienne",
    "norvégiens": "norvégien",
    "nos": "notre",
    "nosocomiale": "nosocomial",
    "nosocomiales": "nosocomial",
    "nosocomiaux": "nosocomial",
    "nosologies": "nosologie",
    "nostalgies": "nostalgie",
    "nostalgiques": "nostalgique",
    "nota": "noter",
    "notabilités": "notabilité",
    "notables": "notable",
    "notai": "noter",
    "notaient": "noter",
    "notaires": "notaire",
    "notairesse": "notaire",
    "notairesses": "notaire",
    "notais": "noter",
    "notait": "noter",
    "notant": "noter",
    "notariale": "notarial",
    "notariales": "notarial",
    "notariats": "notariat",
    "notariaux": "notarial",
    "notarié": "notarier",
    "notariée": "notarié",
    "notariées": "notarier",
    "notariés": "notarier",
    "notas": "noter",
    "notasse": "noter",
    "notassent": "noter",
    "notasses": "noter",
    "notassiez": "noter",
    "notassions": "noter",
    "notations": "notation",
    "note": "noter",
    "notent": "noter",
    "notera": "noter",
    "noterai": "noter",
    "noteraient": "noter",
    "noterais": "noter",
    "noterait": "noter",
    "noteras": "noter",
    "noterez": "noter",
    "noteriez": "noter",
    "noterions": "noter",
    "noterons": "noter",
    "noteront": "noter",
    "notes": "noter",
    "notez": "noter",
    "notices": "notice",
    "notiez": "noter",
    "notifia": "notifier",
    "notifiai": "notifier",
    "notifiaient": "notifier",
    "notifiais": "notifier",
    "notifiait": "notifier",
    "notifiant": "notifier",
    "notifias": "notifier",
    "notifiasse": "notifier",
    "notifiassent": "notifier",
    "notifiasses": "notifier",
    "notifiassiez": "notifier",
    "notifiassions": "notifier",
    "notifications": "notification",
    "notifie": "notifier",
    "notifient": "notifier",
    "notifiera": "notifier",
    "notifierai": "notifier",
    "notifieraient": "notifier",
    "notifierais": "notifier",
    "notifierait": "notifier",
    "notifieras": "notifier",
    "notifierez": "notifier",
    "notifieriez": "notifier",
    "notifierions": "notifier",
    "notifierons": "notifier",
    "notifieront": "notifier",
    "notifies": "notifier",
    "notifiez": "notifier",
    "notifiiez": "notifier",
    "notifiions": "notifier",
    "notifions": "notifier",
    "notifiâmes": "notifier",
    "notifiât": "notifier",
    "notifiâtes": "notifier",
    "notifièrent": "notifier",
    "notifié": "notifier",
    "notifiée": "notifier",
    "notifiées": "notifier",
    "notifiés": "notifier",
    "notionnelle": "notionnel",
    "notionnelles": "notionnel",
    "notionnels": "notionnel",
    "notions": "notion",
    "notoires": "notoire",
    "notonectes": "notonecte",
    "notons": "noter",
    "notoriétés": "notoriété",
    "notules": "notule",
    "notâmes": "noter",
    "notât": "noter",
    "notâtes": "noter",
    "notèrent": "noter",
    "noté": "noter",
    "notée": "noter",
    "notées": "noter",
    "notés": "noter",
    "noua": "nouer",
    "nouai": "nouer",
    "nouaient": "nouer",
    "nouais": "nouer",
    "nouait": "nouer",
    "nouant": "nouer",
    "nouas": "nouer",
    "nouasse": "nouer",
    "nouassent": "nouer",
    "nouasses": "nouer",
    "nouassiez": "nouer",
    "nouassions": "nouer",
    "noubas": "nouba",
    "noue": "nouer",
    "nouent": "nouer",
    "nouera": "nouer",
    "nouerai": "nouer",
    "noueraient": "nouer",
    "nouerais": "nouer",
    "nouerait": "nouer",
    "noueras": "nouer",
    "nouerez": "nouer",
    "noueriez": "nouer",
    "nouerions": "nouer",
    "nouerons": "nouer",
    "noueront": "nouer",
    "noues": "nouer",
    "noueuse": "noueux",
    "noueuses": "noueux",
    "nouez": "nouer",
    "nougatines": "nougatine",
    "nougats": "nougat",
    "nouiez": "nouer",
    "nouilles": "nouille",
    "nouions": "nouer",
    "noumènes": "noumène",
    "nounous": "nounou",
    "nouons": "nouer",
    "nourrains": "nourrain",
    "nourri": "nourrir",
    "nourrices": "nourrice",
    "nourriciers": "nourricier",
    "nourricière": "nourricier",
    "nourricières": "nourricier",
    "nourrie": "nourrir",
    "nourries": "nourrir",
    "nourrira": "nourrir",
    "nourrirai": "nourrir",
    "nourriraient": "nourrir",
    "nourrirais": "nourrir",
    "nourrirait": "nourrir",
    "nourriras": "nourrir",
    "nourrirent": "nourrir",
    "nourrirez": "nourrir",
    "nourririez": "nourrir",
    "nourririons": "nourrir",
    "nourrirons": "nourrir",
    "nourriront": "nourrir",
    "nourris": "nourrir",
    "nourrissaient": "nourrir",
    "nourrissais": "nourrir",
    "nourrissait": "nourrir",
    "nourrissant": "nourrir",
    "nourrissante": "nourrissant",
    "nourrissantes": "nourrissant",
    "nourrissants": "nourrissant",
    "nourrisse": "nourrir",
    "nourrissent": "nourrir",
    "nourrisses": "nourrir",
    "nourrissez": "nourrir",
    "nourrissiez": "nourrir",
    "nourrissions": "nourrir",
    "nourrissons": "nourrisson",
    "nourrit": "nourrir",
    "nourritures": "nourriture",
    "nourrîmes": "nourrir",
    "nourrît": "nourrir",
    "nourrîtes": "nourrir",
    "nous": "se",
    "nouures": "nouure",
    "nouveau-née": "nouveau-né",
    "nouveau-nées": "nouveau-né",
    "nouveau-nés": "nouveau-né",
    "nouveautés": "nouveauté",
    "nouveaux": "nouveau",
    "nouveaux-nés": "nouveau-né",
    "nouvel": "nouveau",
    "nouvelle": "nouveau",
    "nouvelles": "nouvelle",
    "nouvellistes": "nouvelliste",
    "nouâmes": "nouer",
    "nouât": "nouer",
    "nouâtes": "nouer",
    "nouèrent": "nouer",
    "noué": "nouer",
    "nouée": "nouer",
    "nouées": "nouer",
    "noués": "nouer",
    "nova": "nover",
    "novas": "nova",
    "novateurs": "novateur",
    "novations": "novation",
    "novatrice": "novateur",
    "novatrices": "novateur",
    "nove": "nover",
    "novelettes": "novelette",
    "novembres": "novembre",
    "novices": "novice",
    "novilleros": "novillero",
    "noya": "noyer",
    "noyades": "noyade",
    "noyai": "noyer",
    "noyaient": "noyer",
    "noyais": "noyer",
    "noyait": "noyer",
    "noyant": "noyer",
    "noyas": "noyer",
    "noyasse": "noyer",
    "noyassent": "noyer",
    "noyasses": "noyer",
    "noyassiez": "noyer",
    "noyassions": "noyer",
    "noyauta": "noyauter",
    "noyautages": "noyautage",
    "noyautant": "noyauter",
    "noyautent": "noyauter",
    "noyauté": "noyauter",
    "noyautée": "noyauter",
    "noyautées": "noyauter",
    "noyaux": "noyau",
    "noyers": "noyer",
    "noyez": "noyer",
    "noyiez": "noyer",
    "noyions": "noyer",
    "noyons": "noyer",
    "noyâmes": "noyer",
    "noyât": "noyer",
    "noyâtes": "noyer",
    "noyèrent": "noyer",
    "noyé": "noyer",
    "noyée": "noyer",
    "noyées": "noyer",
    "noyés": "noyer",
    "noëls": "noël",
    "nu-pieds": "nu-pied",
    "nuages": "nuage",
    "nuageuse": "nuageux",
    "nuageuses": "nuageux",
    "nuance": "nuancer",
    "nuancent": "nuancer",
    "nuancera": "nuancer",
    "nuancerai": "nuancer",
    "nuanceraient": "nuancer",
    "nuancerais": "nuancer",
    "nuancerait": "nuancer",
    "nuanceras": "nuancer",
    "nuancerez": "nuancer",
    "nuanceriez": "nuancer",
    "nuancerions": "nuancer",
    "nuancerons": "nuancer",
    "nuanceront": "nuancer",
    "nuances": "nuancer",
    "nuancez": "nuancer",
    "nuanciez": "nuancer",
    "nuancions": "nuancer",
    "nuancèrent": "nuancer",
    "nuancé": "nuancer",
    "nuancée": "nuancer",
    "nuancées": "nuancer",
    "nuancés": "nuancer",
    "nuança": "nuancer",
    "nuançai": "nuancer",
    "nuançaient": "nuancer",
    "nuançais": "nuancer",
    "nuançait": "nuancer",
    "nuançant": "nuancer",
    "nuanças": "nuancer",
    "nuançasse": "nuancer",
    "nuançassent": "nuancer",
    "nuançasses": "nuancer",
    "nuançassiez": "nuancer",
    "nuançassions": "nuancer",
    "nuançons": "nuancer",
    "nuançâmes": "nuancer",
    "nuançât": "nuancer",
    "nuançâtes": "nuancer",
    "nuas": "nuer",
    "nubienne": "nubien",
    "nubiens": "nubien",
    "nubiles": "nubile",
    "nucale": "nucal",
    "nucales": "nucal",
    "nucaux": "nucal",
    "nucléaires": "nucléaire",
    "nucléoles": "nucléole",
    "nucléotides": "nucléotide",
    "nucléée": "nucléé",
    "nudistes": "nudiste",
    "nudités": "nudité",
    "nue": "nu",
    "nue-propriétaire": "nu-propriétaire",
    "nues": "nu",
    "nues-propriétaires": "nu-propriétaire",
    "nues-propriétés": "nue-propriété",
    "nui": "nuire",
    "nuira": "nuire",
    "nuirai": "nuire",
    "nuiraient": "nuire",
    "nuirais": "nuire",
    "nuirait": "nuire",
    "nuiras": "nuire",
    "nuirez": "nuire",
    "nuiriez": "nuire",
    "nuirions": "nuire",
    "nuirons": "nuire",
    "nuiront": "nuire",
    "nuis": "nuire",
    "nuisaient": "nuire",
    "nuisais": "nuire",
    "nuisait": "nuire",
    "nuisances": "nuisance",
    "nuisant": "nuire",
    "nuise": "nuire",
    "nuisent": "nuire",
    "nuises": "nuire",
    "nuisez": "nuire",
    "nuisibles": "nuisible",
    "nuisiez": "nuire",
    "nuisions": "nuire",
    "nuisirent": "nuire",
    "nuisis": "nuire",
    "nuisisse": "nuire",
    "nuisissent": "nuire",
    "nuisisses": "nuire",
    "nuisissiez": "nuire",
    "nuisissions": "nuire",
    "nuisit": "nuire",
    "nuisons": "nuire",
    "nuisîmes": "nuire",
    "nuisît": "nuire",
    "nuisîtes": "nuire",
    "nuit": "nuire",
    "nuitards": "nuitard",
    "nuits": "nuit",
    "nuitées": "nuitée",
    "nullarde": "nullard",
    "nullardes": "nullard",
    "nullards": "nullard",
    "nulle": "nul",
    "nulles": "nul",
    "nullités": "nullité",
    "nuls": "nul",
    "numides": "numide",
    "numismates": "numismate",
    "numéraires": "numéraire",
    "numérale": "numéral",
    "numérales": "numéral",
    "numérations": "numération",
    "numéraux": "numéral",
    "numériques": "numérique",
    "numérise": "numériser",
    "numérisez": "numériser",
    "numérisé": "numériser",
    "numérisée": "numériser",
    "numérisées": "numériser",
    "numéros": "numéro",
    "numérota": "numéroter",
    "numérotai": "numéroter",
    "numérotaient": "numéroter",
    "numérotais": "numéroter",
    "numérotait": "numéroter",
    "numérotant": "numéroter",
    "numérotas": "numéroter",
    "numérotasse": "numéroter",
    "numérotassent": "numéroter",
    "numérotasses": "numéroter",
    "numérotassiez": "numéroter",
    "numérotassions": "numéroter",
    "numérote": "numéroter",
    "numérotent": "numéroter",
    "numérotera": "numéroter",
    "numéroterai": "numéroter",
    "numéroteraient": "numéroter",
    "numéroterais": "numéroter",
    "numéroterait": "numéroter",
    "numéroteras": "numéroter",
    "numéroterez": "numéroter",
    "numéroteriez": "numéroter",
    "numéroterions": "numéroter",
    "numéroterons": "numéroter",
    "numéroteront": "numéroter",
    "numérotes": "numéroter",
    "numérotez": "numéroter",
    "numérotiez": "numéroter",
    "numérotions": "numéroter",
    "numérotons": "numéroter",
    "numérotâmes": "numéroter",
    "numérotât": "numéroter",
    "numérotâtes": "numéroter",
    "numérotèrent": "numéroter",
    "numéroté": "numéroter",
    "numérotée": "numéroter",
    "numérotées": "numéroter",
    "numérotés": "numéroter",
    "nunchakus": "nunchaku",
    "nuncupatifs": "nuncupatif",
    "nunuches": "nunuche",
    "nuptiale": "nuptial",
    "nuptiales": "nuptial",
    "nuptiaux": "nuptial",
    "nuques": "nuque",
    "nurserys": "nursery",
    "nurses": "nurse",
    "nursings": "nursing",
    "nus": "nu",
    "nus-propriétaires": "nu-propriétaire",
    "nutations": "nutation",
    "nutriments": "nutriment",
    "nutritifs": "nutritif",
    "nutritionnelle": "nutritionnel",
    "nutritionnelles": "nutritionnel",
    "nutritionnels": "nutritionnel",
    "nutritions": "nutrition",
    "nutritive": "nutritif",
    "nutritives": "nutritif",
    "nuées": "nuer",
    "nyctalopes": "nyctalope",
    "nycthémères": "nycthémère",
    "nylons": "nylon",
    "nymphale": "nymphal",
    "nymphales": "nymphal",
    "nymphals": "nymphal",
    "nymphes": "nymphe",
    "nymphettes": "nymphette",
    "nymphomanes": "nymphomane",
    "nymphos": "nympho",
    "nymphéas": "nymphéa",
    "nymphées": "nymphée",
    "nèfles": "nèfle",
    "nègres": "nègre",
    "nèpes": "nèpe",
    "né": "naître",
    "néandertaliens": "néandertalien",
    "néantisée": "néantiser",
    "néants": "néant",
    "nébuleuse": "nébuleux",
    "nébuleuses": "nébuleux",
    "nébulisa": "nébuliser",
    "nébulisai": "nébuliser",
    "nébulisaient": "nébuliser",
    "nébulisais": "nébuliser",
    "nébulisait": "nébuliser",
    "nébulisant": "nébuliser",
    "nébulisas": "nébuliser",
    "nébulisasse": "nébuliser",
    "nébulisassent": "nébuliser",
    "nébulisasses": "nébuliser",
    "nébulisassiez": "nébuliser",
    "nébulisassions": "nébuliser",
    "nébulise": "nébuliser",
    "nébulisent": "nébuliser",
    "nébulisera": "nébuliser",
    "nébuliserai": "nébuliser",
    "nébuliseraient": "nébuliser",
    "nébuliserais": "nébuliser",
    "nébuliserait": "nébuliser",
    "nébuliseras": "nébuliser",
    "nébuliserez": "nébuliser",
    "nébuliseriez": "nébuliser",
    "nébuliserions": "nébuliser",
    "nébuliserons": "nébuliser",
    "nébuliseront": "nébuliser",
    "nébulises": "nébuliser",
    "nébulisez": "nébuliser",
    "nébulisiez": "nébuliser",
    "nébulisions": "nébuliser",
    "nébulisons": "nébuliser",
    "nébulisâmes": "nébuliser",
    "nébulisât": "nébuliser",
    "nébulisâtes": "nébuliser",
    "nébulisèrent": "nébuliser",
    "nébulisé": "nébuliser",
    "nébulisée": "nébuliser",
    "nébulisées": "nébuliser",
    "nébulisés": "nébuliser",
    "nécessaires": "nécessaire",
    "nécessita": "nécessiter",
    "nécessitai": "nécessiter",
    "nécessitaient": "nécessiter",
    "nécessitais": "nécessiter",
    "nécessitait": "nécessiter",
    "nécessitant": "nécessiter",
    "nécessitas": "nécessiter",
    "nécessitasse": "nécessiter",
    "nécessitassent": "nécessiter",
    "nécessitasses": "nécessiter",
    "nécessitassiez": "nécessiter",
    "nécessitassions": "nécessiter",
    "nécessite": "nécessiter",
    "nécessitent": "nécessiter",
    "nécessitera": "nécessiter",
    "nécessiterai": "nécessiter",
    "nécessiteraient": "nécessiter",
    "nécessiterais": "nécessiter",
    "nécessiterait": "nécessiter",
    "nécessiteras": "nécessiter",
    "nécessiterez": "nécessiter",
    "nécessiteriez": "nécessiter",
    "nécessiterions": "nécessiter",
    "nécessiterons": "nécessiter",
    "nécessiteront": "nécessiter",
    "nécessites": "nécessiter",
    "nécessiteuse": "nécessiteux",
    "nécessiteuses": "nécessiteux",
    "nécessitez": "nécessiter",
    "nécessitiez": "nécessiter",
    "nécessitions": "nécessiter",
    "nécessitons": "nécessiter",
    "nécessitâmes": "nécessiter",
    "nécessitât": "nécessiter",
    "nécessitâtes": "nécessiter",
    "nécessitèrent": "nécessiter",
    "nécessité": "nécessiter",
    "nécessitée": "nécessiter",
    "nécessitées": "nécessiter",
    "nécessités": "nécessiter",
    "nécrobioses": "nécrobiose",
    "nécrologies": "nécrologie",
    "nécrologiques": "nécrologique",
    "nécromancienne": "nécromancien",
    "nécromanciens": "nécromancien",
    "nécromancies": "nécromancie",
    "nécrophiles": "nécrophile",
    "nécropoles": "nécropole",
    "nécros": "nécro",
    "nécrosant": "nécroser",
    "nécroses": "nécrose",
    "nécrosé": "nécroser",
    "nécrosée": "nécroser",
    "née": "né",
    "néerlandaise": "néerlandais",
    "néerlandaises": "néerlandais",
    "nées": "né",
    "néfastes": "néfaste",
    "néfliers": "néflier",
    "négatifs": "négatif",
    "négations": "négation",
    "négative": "négatif",
    "négatives": "négative",
    "négativismes": "négativisme",
    "néglige": "négliger",
    "négligea": "négliger",
    "négligeables": "négligeable",
    "négligeai": "négliger",
    "négligeaient": "négliger",
    "négligeais": "négliger",
    "négligeait": "négliger",
    "négligeant": "négliger",
    "négligeas": "négliger",
    "négligeasse": "négliger",
    "négligeassent": "négliger",
    "négligeasses": "négliger",
    "négligeassiez": "négliger",
    "négligeassions": "négliger",
    "négligences": "négligence",
    "négligent": "négliger",
    "négligente": "négligent",
    "négligentes": "négligent",
    "négligents": "négligent",
    "négligeons": "négliger",
    "négligera": "négliger",
    "négligerai": "négliger",
    "négligeraient": "négliger",
    "négligerais": "négliger",
    "négligerait": "négliger",
    "négligeras": "négliger",
    "négligerez": "négliger",
    "négligeriez": "négliger",
    "négligerions": "négliger",
    "négligerons": "négliger",
    "négligeront": "négliger",
    "négliges": "négliger",
    "négligez": "négliger",
    "négligeâmes": "négliger",
    "négligeât": "négliger",
    "négligeâtes": "négliger",
    "négligiez": "négliger",
    "négligions": "négliger",
    "négligèrent": "négliger",
    "négligé": "négliger",
    "négligée": "négliger",
    "négligées": "négliger",
    "négligés": "négliger",
    "négoces": "négoce",
    "négocia": "négocier",
    "négociabilités": "négociabilité",
    "négociables": "négociable",
    "négociai": "négocier",
    "négociaient": "négocier",
    "négociais": "négocier",
    "négociait": "négocier",
    "négociant": "négocier",
    "négociante": "négociant",
    "négociantes": "négociant",
    "négociants": "négociant",
    "négocias": "négocier",
    "négociasse": "négocier",
    "négociassent": "négocier",
    "négociasses": "négocier",
    "négociassiez": "négocier",
    "négociassions": "négocier",
    "négociateurs": "négociateur",
    "négociations": "négociation",
    "négociatrice": "négociateur",
    "négociatrices": "négociateur",
    "négocie": "négocier",
    "négocient": "négocier",
    "négociera": "négocier",
    "négocierai": "négocier",
    "négocieraient": "négocier",
    "négocierais": "négocier",
    "négocierait": "négocier",
    "négocieras": "négocier",
    "négocierez": "négocier",
    "négocieriez": "négocier",
    "négocierions": "négocier",
    "négocierons": "négocier",
    "négocieront": "négocier",
    "négocies": "négocier",
    "négociez": "négocier",
    "négociiez": "négocier",
    "négociions": "négocier",
    "négocions": "négocier",
    "négociâmes": "négocier",
    "négociât": "négocier",
    "négociâtes": "négocier",
    "négocièrent": "négocier",
    "négocié": "négocier",
    "négociée": "négocier",
    "négociées": "négocier",
    "négociés": "négocier",
    "négresse": "nègre",
    "négresses": "nègre",
    "négriers": "négrier",
    "négrillons": "négrillon",
    "négrière": "négrier",
    "négro-africaine": "négro-africain",
    "négro-africaines": "négro-africain",
    "négro-africains": "négro-africain",
    "négrophiles": "négrophile",
    "négros": "négro",
    "négroïdes": "négroïde",
    "némathelminthes": "némathelminthe",
    "nématodes": "nématode",
    "nénesses": "nénesse",
    "nénettes": "nénette",
    "nénuphars": "nénuphar",
    "nénés": "néné",
    "néo-barbares": "néo-barbare",
    "néo-fascistes": "néo-fasciste",
    "néo-flics": "néo-flic",
    "néo-gothiques": "néo-gothique",
    "néo-helléniques": "néo-hellénique",
    "néo-impressionnismes": "néo-impressionnisme",
    "néo-mauresques": "néo-mauresque",
    "néo-réalistes": "néo-réaliste",
    "néo-zélandaise": "néo-zélandais",
    "néoclassicismes": "néoclassicisme",
    "néoclassiques": "néoclassique",
    "néocolonialismes": "néocolonialisme",
    "néoformations": "néoformation",
    "néogrecque": "néogrec",
    "néogrecques": "néogrec",
    "néogrecs": "néogrec",
    "néohelléniques": "néohellénique",
    "néolithiques": "néolithique",
    "néologies": "néologie",
    "néologismes": "néologisme",
    "néonatale": "néonatal",
    "néonatales": "néonatal",
    "néonatals": "néonatal",
    "néonationalismes": "néonationalisme",
    "néonazie": "néonazi",
    "néonazies": "néonazi",
    "néonazis": "néonazi",
    "néons": "néon",
    "néophytes": "néophyte",
    "néoréalismes": "néoréalisme",
    "néoréalistes": "néoréaliste",
    "néostalinienne": "néostalinien",
    "néostaliniennes": "néostalinien",
    "néostaliniens": "néostalinien",
    "népalaise": "népalais",
    "népalaises": "népalais",
    "néphrites": "néphrite",
    "néphrétiques": "néphrétique",
    "népotismes": "népotisme",
    "néritiques": "néritique",
    "néréides": "néréide",
    "nés": "né",
    "névralgies": "névralgie",
    "névralgiques": "névralgique",
    "névrites": "névrite",
    "névropathes": "névropathe",
    "névroptères": "névroptère",
    "névroses": "névrose",
    "névrosée": "névrosé",
    "névrosées": "névrosé",
    "névrosés": "névrosé",
    "névrotiques": "névrotique",
    "névés": "névé",
    "nôs": "nô",
    "nôtres": "nôtre",
    "obis": "obi",
    "objecta": "objecter",
    "objectai": "objecter",
    "objectaient": "objecter",
    "objectais": "objecter",
    "objectait": "objecter",
    "objectale": "objectal",
    "objectales": "objectal",
    "objectant": "objecter",
    "objectas": "objecter",
    "objectasse": "objecter",
    "objectassent": "objecter",
    "objectasses": "objecter",
    "objectassiez": "objecter",
    "objectassions": "objecter",
    "objectaux": "objectal",
    "objecte": "objecter",
    "objectent": "objecter",
    "objectera": "objecter",
    "objecterai": "objecter",
    "objecteraient": "objecter",
    "objecterais": "objecter",
    "objecterait": "objecter",
    "objecteras": "objecter",
    "objecterez": "objecter",
    "objecteriez": "objecter",
    "objecterions": "objecter",
    "objecterons": "objecter",
    "objecteront": "objecter",
    "objectes": "objecter",
    "objecteurs": "objecteur",
    "objectez": "objecter",
    "objectiez": "objecter",
    "objectifs": "objectif",
    "objections": "objection",
    "objectiva": "objectiver",
    "objectivai": "objectiver",
    "objectivaient": "objectiver",
    "objectivais": "objectiver",
    "objectivait": "objectiver",
    "objectivant": "objectiver",
    "objectivas": "objectiver",
    "objectivasse": "objectiver",
    "objectivassent": "objectiver",
    "objectivasses": "objectiver",
    "objectivassiez": "objectiver",
    "objectivassions": "objectiver",
    "objectivations": "objectivation",
    "objective": "objectiver",
    "objectivent": "objectiver",
    "objectivera": "objectiver",
    "objectiverai": "objectiver",
    "objectiveraient": "objectiver",
    "objectiverais": "objectiver",
    "objectiverait": "objectiver",
    "objectiveras": "objectiver",
    "objectiverez": "objectiver",
    "objectiveriez": "objectiver",
    "objectiverions": "objectiver",
    "objectiverons": "objectiver",
    "objectiveront": "objectiver",
    "objectives": "objectiver",
    "objectivez": "objectiver",
    "objectiviez": "objectiver",
    "objectivions": "objectiver",
    "objectivités": "objectivité",
    "objectivons": "objectiver",
    "objectivâmes": "objectiver",
    "objectivât": "objectiver",
    "objectivâtes": "objectiver",
    "objectivèrent": "objectiver",
    "objectivé": "objectiver",
    "objectivée": "objectiver",
    "objectivées": "objectiver",
    "objectivés": "objectiver",
    "objectons": "objecter",
    "objectâmes": "objecter",
    "objectât": "objecter",
    "objectâtes": "objecter",
    "objectèrent": "objecter",
    "objecté": "objecter",
    "objectée": "objecter",
    "objectées": "objecter",
    "objectés": "objecter",
    "objets": "objet",
    "objurgations": "objurgation",
    "objurgua": "objurguer",
    "objurguant": "objurguer",
    "oblate": "oblat",
    "oblates": "oblat",
    "oblations": "oblation",
    "oblative": "oblatif",
    "oblats": "oblat",
    "obligataires": "obligataire",
    "obligations": "obligation",
    "obligatoires": "obligatoire",
    "oblige": "obliger",
    "obligea": "obliger",
    "obligeai": "obliger",
    "obligeaient": "obliger",
    "obligeais": "obliger",
    "obligeait": "obliger",
    "obligeances": "obligeance",
    "obligeant": "obliger",
    "obligeante": "obligeant",
    "obligeantes": "obligeant",
    "obligeants": "obligeant",
    "obligeas": "obliger",
    "obligeasse": "obliger",
    "obligeassent": "obliger",
    "obligeasses": "obliger",
    "obligeassiez": "obliger",
    "obligeassions": "obliger",
    "obligent": "obliger",
    "obligeons": "obliger",
    "obligera": "obliger",
    "obligerai": "obliger",
    "obligeraient": "obliger",
    "obligerais": "obliger",
    "obligerait": "obliger",
    "obligeras": "obliger",
    "obligerez": "obliger",
    "obligeriez": "obliger",
    "obligerions": "obliger",
    "obligerons": "obliger",
    "obligeront": "obliger",
    "obliges": "obliger",
    "obligez": "obliger",
    "obligeâmes": "obliger",
    "obligeât": "obliger",
    "obligeâtes": "obliger",
    "obligiez": "obliger",
    "obligions": "obliger",
    "obligèrent": "obliger",
    "obligé": "obliger",
    "obligée": "obliger",
    "obligées": "obliger",
    "obligés": "obliger",
    "obliqua": "obliquer",
    "obliquai": "obliquer",
    "obliquaient": "obliquer",
    "obliquais": "obliquer",
    "obliquait": "obliquer",
    "obliquant": "obliquer",
    "obliquas": "obliquer",
    "obliquasse": "obliquer",
    "obliquassent": "obliquer",
    "obliquasses": "obliquer",
    "obliquassiez": "obliquer",
    "obliquassions": "obliquer",
    "oblique": "obliquer",
    "obliquent": "obliquer",
    "obliquera": "obliquer",
    "obliquerai": "obliquer",
    "obliqueraient": "obliquer",
    "obliquerais": "obliquer",
    "obliquerait": "obliquer",
    "obliqueras": "obliquer",
    "obliquerez": "obliquer",
    "obliqueriez": "obliquer",
    "obliquerions": "obliquer",
    "obliquerons": "obliquer",
    "obliqueront": "obliquer",
    "obliques": "obliquer",
    "obliquez": "obliquer",
    "obliquiez": "obliquer",
    "obliquions": "obliquer",
    "obliquons": "obliquer",
    "obliquâmes": "obliquer",
    "obliquât": "obliquer",
    "obliquâtes": "obliquer",
    "obliquèrent": "obliquer",
    "obliqué": "obliquer",
    "obliquée": "obliquer",
    "obliquées": "obliquer",
    "obliqués": "obliquer",
    "oblitère": "oblitérer",
    "oblitèrent": "oblitérer",
    "oblitères": "oblitérer",
    "oblitéra": "oblitérer",
    "oblitérai": "oblitérer",
    "oblitéraient": "oblitérer",
    "oblitérais": "oblitérer",
    "oblitérait": "oblitérer",
    "oblitérant": "oblitérer",
    "oblitéras": "oblitérer",
    "oblitérasse": "oblitérer",
    "oblitérassent": "oblitérer",
    "oblitérasses": "oblitérer",
    "oblitérassiez": "oblitérer",
    "oblitérassions": "oblitérer",
    "oblitérations": "oblitération",
    "oblitérera": "oblitérer",
    "oblitérerai": "oblitérer",
    "oblitéreraient": "oblitérer",
    "oblitérerais": "oblitérer",
    "oblitérerait": "oblitérer",
    "oblitéreras": "oblitérer",
    "oblitérerez": "oblitérer",
    "oblitéreriez": "oblitérer",
    "oblitérerions": "oblitérer",
    "oblitérerons": "oblitérer",
    "oblitéreront": "oblitérer",
    "oblitérez": "oblitérer",
    "oblitériez": "oblitérer",
    "oblitérions": "oblitérer",
    "oblitérons": "oblitérer",
    "oblitérâmes": "oblitérer",
    "oblitérât": "oblitérer",
    "oblitérâtes": "oblitérer",
    "oblitérèrent": "oblitérer",
    "oblitéré": "oblitérer",
    "oblitérée": "oblitérer",
    "oblitérées": "oblitérer",
    "oblitérés": "oblitérer",
    "oblongs": "oblong",
    "oblongue": "oblong",
    "oblongues": "oblong",
    "obnubila": "obnubiler",
    "obnubilai": "obnubiler",
    "obnubilaient": "obnubiler",
    "obnubilais": "obnubiler",
    "obnubilait": "obnubiler",
    "obnubilant": "obnubiler",
    "obnubilas": "obnubiler",
    "obnubilasse": "obnubiler",
    "obnubilassent": "obnubiler",
    "obnubilasses": "obnubiler",
    "obnubilassiez": "obnubiler",
    "obnubilassions": "obnubiler",
    "obnubile": "obnubiler",
    "obnubilent": "obnubiler",
    "obnubilera": "obnubiler",
    "obnubilerai": "obnubiler",
    "obnubileraient": "obnubiler",
    "obnubilerais": "obnubiler",
    "obnubilerait": "obnubiler",
    "obnubileras": "obnubiler",
    "obnubilerez": "obnubiler",
    "obnubileriez": "obnubiler",
    "obnubilerions": "obnubiler",
    "obnubilerons": "obnubiler",
    "obnubileront": "obnubiler",
    "obnubiles": "obnubiler",
    "obnubilez": "obnubiler",
    "obnubiliez": "obnubiler",
    "obnubilions": "obnubiler",
    "obnubilons": "obnubiler",
    "obnubilâmes": "obnubiler",
    "obnubilât": "obnubiler",
    "obnubilâtes": "obnubiler",
    "obnubilèrent": "obnubiler",
    "obnubilé": "obnubiler",
    "obnubilée": "obnubiler",
    "obnubilées": "obnubiler",
    "obnubilés": "obnubiler",
    "oboles": "obole",
    "obscurantismes": "obscurantisme",
    "obscurantistes": "obscurantiste",
    "obscurci": "obscurcir",
    "obscurcie": "obscurcir",
    "obscurcies": "obscurcir",
    "obscurcira": "obscurcir",
    "obscurcirai": "obscurcir",
    "obscurciraient": "obscurcir",
    "obscurcirais": "obscurcir",
    "obscurcirait": "obscurcir",
    "obscurciras": "obscurcir",
    "obscurcirent": "obscurcir",
    "obscurcirez": "obscurcir",
    "obscurciriez": "obscurcir",
    "obscurcirions": "obscurcir",
    "obscurcirons": "obscurcir",
    "obscurciront": "obscurcir",
    "obscurcis": "obscurcir",
    "obscurcissaient": "obscurcir",
    "obscurcissais": "obscurcir",
    "obscurcissait": "obscurcir",
    "obscurcissant": "obscurcir",
    "obscurcisse": "obscurcir",
    "obscurcissements": "obscurcissement",
    "obscurcissent": "obscurcir",
    "obscurcisses": "obscurcir",
    "obscurcissez": "obscurcir",
    "obscurcissiez": "obscurcir",
    "obscurcissions": "obscurcir",
    "obscurcissons": "obscurcir",
    "obscurcit": "obscurcir",
    "obscurcîmes": "obscurcir",
    "obscurcît": "obscurcir",
    "obscurcîtes": "obscurcir",
    "obscure": "obscur",
    "obscures": "obscur",
    "obscurités": "obscurité",
    "obscurs": "obscur",
    "obscènes": "obscène",
    "obscénités": "obscénité",
    "observa": "observer",
    "observai": "observer",
    "observaient": "observer",
    "observais": "observer",
    "observait": "observer",
    "observances": "observance",
    "observant": "observer",
    "observas": "observer",
    "observasse": "observer",
    "observassent": "observer",
    "observasses": "observer",
    "observassiez": "observer",
    "observassions": "observer",
    "observateurs": "observateur",
    "observations": "observation",
    "observatoires": "observatoire",
    "observatrice": "observateur",
    "observatrices": "observateur",
    "observe": "observer",
    "observent": "observer",
    "observera": "observer",
    "observerai": "observer",
    "observeraient": "observer",
    "observerais": "observer",
    "observerait": "observer",
    "observeras": "observer",
    "observerez": "observer",
    "observeriez": "observer",
    "observerions": "observer",
    "observerons": "observer",
    "observeront": "observer",
    "observes": "observer",
    "observez": "observer",
    "observiez": "observer",
    "observions": "observer",
    "observons": "observer",
    "observâmes": "observer",
    "observât": "observer",
    "observâtes": "observer",
    "observèrent": "observer",
    "observé": "observer",
    "observée": "observer",
    "observées": "observer",
    "observés": "observer",
    "obsessionnelle": "obsessionnel",
    "obsessionnelles": "obsessionnel",
    "obsessionnels": "obsessionnel",
    "obsessions": "obsession",
    "obsessive": "obsessif",
    "obsidiennes": "obsidienne",
    "obsidionale": "obsidional",
    "obsidionales": "obsidional",
    "obsidionaux": "obsidional",
    "obsolescences": "obsolescence",
    "obsolescente": "obsolescent",
    "obsolescentes": "obsolescent",
    "obsolescents": "obsolescent",
    "obsolètes": "obsolète",
    "obstacles": "obstacle",
    "obstina": "obstiner",
    "obstinai": "obstiner",
    "obstinaient": "obstiner",
    "obstinais": "obstiner",
    "obstinait": "obstiner",
    "obstinant": "obstiner",
    "obstinas": "obstiner",
    "obstinasse": "obstiner",
    "obstinassent": "obstiner",
    "obstinasses": "obstiner",
    "obstinassiez": "obstiner",
    "obstinassions": "obstiner",
    "obstinations": "obstination",
    "obstine": "obstiner",
    "obstinent": "obstiner",
    "obstinera": "obstiner",
    "obstinerai": "obstiner",
    "obstineraient": "obstiner",
    "obstinerais": "obstiner",
    "obstinerait": "obstiner",
    "obstineras": "obstiner",
    "obstinerez": "obstiner",
    "obstineriez": "obstiner",
    "obstinerions": "obstiner",
    "obstinerons": "obstiner",
    "obstineront": "obstiner",
    "obstines": "obstiner",
    "obstinez": "obstiner",
    "obstiniez": "obstiner",
    "obstinions": "obstiner",
    "obstinons": "obstiner",
    "obstinâmes": "obstiner",
    "obstinât": "obstiner",
    "obstinâtes": "obstiner",
    "obstinèrent": "obstiner",
    "obstiné": "obstiner",
    "obstinée": "obstiner",
    "obstinées": "obstiner",
    "obstinés": "obstiner",
    "obstrua": "obstruer",
    "obstruai": "obstruer",
    "obstruaient": "obstruer",
    "obstruais": "obstruer",
    "obstruait": "obstruer",
    "obstruant": "obstruer",
    "obstruas": "obstruer",
    "obstruasse": "obstruer",
    "obstruassent": "obstruer",
    "obstruasses": "obstruer",
    "obstruassiez": "obstruer",
    "obstruassions": "obstruer",
    "obstructionnismes": "obstructionnisme",
    "obstructions": "obstruction",
    "obstructive": "obstructif",
    "obstrue": "obstruer",
    "obstruent": "obstruer",
    "obstruera": "obstruer",
    "obstruerai": "obstruer",
    "obstrueraient": "obstruer",
    "obstruerais": "obstruer",
    "obstruerait": "obstruer",
    "obstrueras": "obstruer",
    "obstruerez": "obstruer",
    "obstrueriez": "obstruer",
    "obstruerions": "obstruer",
    "obstruerons": "obstruer",
    "obstrueront": "obstruer",
    "obstrues": "obstruer",
    "obstruez": "obstruer",
    "obstruiez": "obstruer",
    "obstruions": "obstruer",
    "obstruons": "obstruer",
    "obstruâmes": "obstruer",
    "obstruât": "obstruer",
    "obstruâtes": "obstruer",
    "obstruèrent": "obstruer",
    "obstrué": "obstruer",
    "obstruée": "obstruer",
    "obstruées": "obstruer",
    "obstrués": "obstruer",
    "obstétricale": "obstétrical",
    "obstétricales": "obstétrical",
    "obstétricaux": "obstétrical",
    "obstétricienne": "obstétricien",
    "obstétriciennes": "obstétricien",
    "obstétriciens": "obstétricien",
    "obstétriques": "obstétrique",
    "obsède": "obséder",
    "obsèdent": "obséder",
    "obsèdes": "obséder",
    "obséda": "obséder",
    "obsédai": "obséder",
    "obsédaient": "obséder",
    "obsédais": "obséder",
    "obsédait": "obséder",
    "obsédant": "obséder",
    "obsédante": "obsédant",
    "obsédantes": "obsédant",
    "obsédants": "obsédant",
    "obsédas": "obséder",
    "obsédasse": "obséder",
    "obsédassent": "obséder",
    "obsédasses": "obséder",
    "obsédassiez": "obséder",
    "obsédassions": "obséder",
    "obsédera": "obséder",
    "obséderai": "obséder",
    "obséderaient": "obséder",
    "obséderais": "obséder",
    "obséderait": "obséder",
    "obséderas": "obséder",
    "obséderez": "obséder",
    "obséderiez": "obséder",
    "obséderions": "obséder",
    "obséderons": "obséder",
    "obséderont": "obséder",
    "obsédez": "obséder",
    "obsédiez": "obséder",
    "obsédions": "obséder",
    "obsédons": "obséder",
    "obsédâmes": "obséder",
    "obsédât": "obséder",
    "obsédâtes": "obséder",
    "obsédèrent": "obséder",
    "obsédé": "obséder",
    "obsédée": "obséder",
    "obsédées": "obséder",
    "obsédés": "obséder",
    "obséquieuse": "obséquieux",
    "obséquieuses": "obséquieux",
    "obtempère": "obtempérer",
    "obtempèrent": "obtempérer",
    "obtempères": "obtempérer",
    "obtempéra": "obtempérer",
    "obtempérai": "obtempérer",
    "obtempéraient": "obtempérer",
    "obtempérais": "obtempérer",
    "obtempérait": "obtempérer",
    "obtempérant": "obtempérer",
    "obtempéras": "obtempérer",
    "obtempérasse": "obtempérer",
    "obtempérassent": "obtempérer",
    "obtempérasses": "obtempérer",
    "obtempérassiez": "obtempérer",
    "obtempérassions": "obtempérer",
    "obtempérera": "obtempérer",
    "obtempérerai": "obtempérer",
    "obtempéreraient": "obtempérer",
    "obtempérerais": "obtempérer",
    "obtempérerait": "obtempérer",
    "obtempéreras": "obtempérer",
    "obtempérerez": "obtempérer",
    "obtempéreriez": "obtempérer",
    "obtempérerions": "obtempérer",
    "obtempérerons": "obtempérer",
    "obtempéreront": "obtempérer",
    "obtempérez": "obtempérer",
    "obtempériez": "obtempérer",
    "obtempérions": "obtempérer",
    "obtempérons": "obtempérer",
    "obtempérâmes": "obtempérer",
    "obtempérât": "obtempérer",
    "obtempérâtes": "obtempérer",
    "obtempérèrent": "obtempérer",
    "obtempéré": "obtempérer",
    "obtenaient": "obtenir",
    "obtenais": "obtenir",
    "obtenait": "obtenir",
    "obtenant": "obtenir",
    "obtenez": "obtenir",
    "obteniez": "obtenir",
    "obtenions": "obtenir",
    "obtenons": "obtenir",
    "obtenteurs": "obtenteur",
    "obtentions": "obtention",
    "obtentrice": "obtenteur",
    "obtentrices": "obtenteur",
    "obtenu": "obtenir",
    "obtenue": "obtenir",
    "obtenues": "obtenir",
    "obtenus": "obtenir",
    "obtiendra": "obtenir",
    "obtiendrai": "obtenir",
    "obtiendraient": "obtenir",
    "obtiendrais": "obtenir",
    "obtiendrait": "obtenir",
    "obtiendras": "obtenir",
    "obtiendrez": "obtenir",
    "obtiendriez": "obtenir",
    "obtiendrions": "obtenir",
    "obtiendrons": "obtenir",
    "obtiendront": "obtenir",
    "obtienne": "obtenir",
    "obtiennent": "obtenir",
    "obtiennes": "obtenir",
    "obtiens": "obtenir",
    "obtient": "obtenir",
    "obtinrent": "obtenir",
    "obtins": "obtenir",
    "obtinsse": "obtenir",
    "obtinssent": "obtenir",
    "obtinsses": "obtenir",
    "obtinssiez": "obtenir",
    "obtinssions": "obtenir",
    "obtint": "obtenir",
    "obtura": "obturer",
    "obturai": "obturer",
    "obturaient": "obturer",
    "obturais": "obturer",
    "obturait": "obturer",
    "obturant": "obturer",
    "obturas": "obturer",
    "obturasse": "obturer",
    "obturassent": "obturer",
    "obturasses": "obturer",
    "obturassiez": "obturer",
    "obturassions": "obturer",
    "obturateurs": "obturateur",
    "obture": "obturer",
    "obturent": "obturer",
    "obturera": "obturer",
    "obturerai": "obturer",
    "obtureraient": "obturer",
    "obturerais": "obturer",
    "obturerait": "obturer",
    "obtureras": "obturer",
    "obturerez": "obturer",
    "obtureriez": "obturer",
    "obturerions": "obturer",
    "obturerons": "obturer",
    "obtureront": "obturer",
    "obtures": "obturer",
    "obturez": "obturer",
    "obturiez": "obturer",
    "obturions": "obturer",
    "obturons": "obturer",
    "obturâmes": "obturer",
    "obturât": "obturer",
    "obturâtes": "obturer",
    "obturèrent": "obturer",
    "obturé": "obturer",
    "obturée": "obturer",
    "obturées": "obturer",
    "obturés": "obturer",
    "obtuse": "obtus",
    "obtuses": "obtus",
    "obtînmes": "obtenir",
    "obtînt": "obtenir",
    "obtîntes": "obtenir",
    "obusiers": "obusier",
    "obvenaient": "obvenir",
    "obvenais": "obvenir",
    "obvenait": "obvenir",
    "obvenant": "obvenir",
    "obvenez": "obvenir",
    "obveniez": "obvenir",
    "obvenions": "obvenir",
    "obvenons": "obvenir",
    "obvenu": "obvenir",
    "obvenue": "obvenir",
    "obvenues": "obvenir",
    "obvenus": "obvenir",
    "obverse": "obvers",
    "obvia": "obvier",
    "obviai": "obvier",
    "obviaient": "obvier",
    "obviais": "obvier",
    "obviait": "obvier",
    "obviant": "obvier",
    "obvias": "obvier",
    "obviasse": "obvier",
    "obviassent": "obvier",
    "obviasses": "obvier",
    "obviassiez": "obvier",
    "obviassions": "obvier",
    "obvie": "obvier",
    "obviendra": "obvenir",
    "obviendrai": "obvenir",
    "obviendraient": "obvenir",
    "obviendrais": "obvenir",
    "obviendrait": "obvenir",
    "obviendras": "obvenir",
    "obviendrez": "obvenir",
    "obviendriez": "obvenir",
    "obviendrions": "obvenir",
    "obviendrons": "obvenir",
    "obviendront": "obvenir",
    "obvienne": "obvenir",
    "obviennent": "obvenir",
    "obviennes": "obvenir",
    "obviens": "obvenir",
    "obvient": "obvier",
    "obviera": "obvier",
    "obvierai": "obvier",
    "obvieraient": "obvier",
    "obvierais": "obvier",
    "obvierait": "obvier",
    "obvieras": "obvier",
    "obvierez": "obvier",
    "obvieriez": "obvier",
    "obvierions": "obvier",
    "obvierons": "obvier",
    "obvieront": "obvier",
    "obvies": "obvier",
    "obviez": "obvier",
    "obviiez": "obvier",
    "obviions": "obvier",
    "obvinrent": "obvenir",
    "obvins": "obvenir",
    "obvinsse": "obvenir",
    "obvinssent": "obvenir",
    "obvinsses": "obvenir",
    "obvinssiez": "obvenir",
    "obvinssions": "obvenir",
    "obvint": "obvenir",
    "obvions": "obvier",
    "obviâmes": "obvier",
    "obviât": "obvier",
    "obviâtes": "obvier",
    "obvièrent": "obvier",
    "obvié": "obvier",
    "obvînmes": "obvenir",
    "obvînt": "obvenir",
    "obvîntes": "obvenir",
    "obère": "obérer",
    "obèrent": "obérer",
    "obères": "obérer",
    "obèses": "obèse",
    "obédiences": "obédience",
    "obéi": "obéir",
    "obéie": "obéir",
    "obéies": "obéir",
    "obéira": "obéir",
    "obéirai": "obéir",
    "obéiraient": "obéir",
    "obéirais": "obéir",
    "obéirait": "obéir",
    "obéiras": "obéir",
    "obéirent": "obéir",
    "obéirez": "obéir",
    "obéiriez": "obéir",
    "obéirions": "obéir",
    "obéirons": "obéir",
    "obéiront": "obéir",
    "obéis": "obéir",
    "obéissaient": "obéir",
    "obéissais": "obéir",
    "obéissait": "obéir",
    "obéissances": "obéissance",
    "obéissant": "obéir",
    "obéissante": "obéissant",
    "obéissantes": "obéissant",
    "obéissants": "obéissant",
    "obéisse": "obéir",
    "obéissent": "obéir",
    "obéisses": "obéir",
    "obéissez": "obéir",
    "obéissiez": "obéir",
    "obéissions": "obéir",
    "obéissons": "obéir",
    "obéit": "obéir",
    "obélisques": "obélisque",
    "obéra": "obérer",
    "obérai": "obérer",
    "obéraient": "obérer",
    "obérais": "obérer",
    "obérait": "obérer",
    "obérant": "obérer",
    "obéras": "obérer",
    "obérasse": "obérer",
    "obérassent": "obérer",
    "obérasses": "obérer",
    "obérassiez": "obérer",
    "obérassions": "obérer",
    "obérera": "obérer",
    "obérerai": "obérer",
    "obéreraient": "obérer",
    "obérerais": "obérer",
    "obérerait": "obérer",
    "obéreras": "obérer",
    "obérerez": "obérer",
    "obéreriez": "obérer",
    "obérerions": "obérer",
    "obérerons": "obérer",
    "obéreront": "obérer",
    "obérez": "obérer",
    "obériez": "obérer",
    "obérions": "obérer",
    "obérons": "obérer",
    "obérâmes": "obérer",
    "obérât": "obérer",
    "obérâtes": "obérer",
    "obérèrent": "obérer",
    "obéré": "obérer",
    "obérée": "obérer",
    "obérées": "obérer",
    "obérés": "obérer",
    "obésités": "obésité",
    "obéîmes": "obéir",
    "obéît": "obéir",
    "obéîtes": "obéir",
    "ocarinas": "ocarina",
    "occases": "occase",
    "occasionna": "occasionner",
    "occasionnai": "occasionner",
    "occasionnaient": "occasionner",
    "occasionnais": "occasionner",
    "occasionnait": "occasionner",
    "occasionnant": "occasionner",
    "occasionnas": "occasionner",
    "occasionnasse": "occasionner",
    "occasionnassent": "occasionner",
    "occasionnasses": "occasionner",
    "occasionnassiez": "occasionner",
    "occasionnassions": "occasionner",
    "occasionne": "occasionner",
    "occasionnelle": "occasionnel",
    "occasionnelles": "occasionnel",
    "occasionnels": "occasionnel",
    "occasionnent": "occasionner",
    "occasionnera": "occasionner",
    "occasionnerai": "occasionner",
    "occasionneraient": "occasionner",
    "occasionnerais": "occasionner",
    "occasionnerait": "occasionner",
    "occasionneras": "occasionner",
    "occasionnerez": "occasionner",
    "occasionneriez": "occasionner",
    "occasionnerions": "occasionner",
    "occasionnerons": "occasionner",
    "occasionneront": "occasionner",
    "occasionnes": "occasionner",
    "occasionnez": "occasionner",
    "occasionniez": "occasionner",
    "occasionnions": "occasionner",
    "occasionnons": "occasionner",
    "occasionnâmes": "occasionner",
    "occasionnât": "occasionner",
    "occasionnâtes": "occasionner",
    "occasionnèrent": "occasionner",
    "occasionné": "occasionner",
    "occasionnée": "occasionner",
    "occasionnées": "occasionner",
    "occasionnés": "occasionner",
    "occasions": "occasion",
    "occidentale": "occidental",
    "occidentales": "occidental",
    "occidentalisations": "occidentalisation",
    "occidentalise": "occidentaliser",
    "occidentaux": "occidental",
    "occidents": "occident",
    "occipitale": "occipital",
    "occipitales": "occipital",
    "occipitaux": "occipital",
    "occiputs": "occiput",
    "occis": "occire",
    "occise": "occire",
    "occises": "occire",
    "occitane": "occitan",
    "occitanes": "occitan",
    "occitans": "occitan",
    "occluaient": "occlure",
    "occluais": "occlure",
    "occluait": "occlure",
    "occluant": "occlure",
    "occlue": "occlure",
    "occluent": "occlure",
    "occlues": "occlure",
    "occluez": "occlure",
    "occluiez": "occlure",
    "occluions": "occlure",
    "occluons": "occlure",
    "occlura": "occlure",
    "occlurai": "occlure",
    "occluraient": "occlure",
    "occlurais": "occlure",
    "occlurait": "occlure",
    "occluras": "occlure",
    "occlurent": "occlure",
    "occlurez": "occlure",
    "occluriez": "occlure",
    "occlurions": "occlure",
    "occlurons": "occlure",
    "occluront": "occlure",
    "occlus": "occlure",
    "occluse": "occlure",
    "occluses": "occlure",
    "occlusifs": "occlusif",
    "occlusions": "occlusion",
    "occlusive": "occlusif",
    "occlusives": "occlusif",
    "occlusse": "occlure",
    "occlussent": "occlure",
    "occlusses": "occlure",
    "occlussiez": "occlure",
    "occlussions": "occlure",
    "occlut": "occlure",
    "occlûmes": "occlure",
    "occlût": "occlure",
    "occlûtes": "occlure",
    "occulta": "occulter",
    "occultai": "occulter",
    "occultaient": "occulter",
    "occultais": "occulter",
    "occultait": "occulter",
    "occultant": "occulter",
    "occultas": "occulter",
    "occultasse": "occulter",
    "occultassent": "occulter",
    "occultasses": "occulter",
    "occultassiez": "occulter",
    "occultassions": "occulter",
    "occultations": "occultation",
    "occulte": "occulter",
    "occultent": "occulter",
    "occultera": "occulter",
    "occulterai": "occulter",
    "occulteraient": "occulter",
    "occulterais": "occulter",
    "occulterait": "occulter",
    "occulteras": "occulter",
    "occulterez": "occulter",
    "occulteriez": "occulter",
    "occulterions": "occulter",
    "occulterons": "occulter",
    "occulteront": "occulter",
    "occultes": "occulter",
    "occultez": "occulter",
    "occultiez": "occulter",
    "occultions": "occulter",
    "occultismes": "occultisme",
    "occultistes": "occultiste",
    "occultons": "occulter",
    "occultâmes": "occulter",
    "occultât": "occulter",
    "occultâtes": "occulter",
    "occultèrent": "occulter",
    "occulté": "occulter",
    "occultée": "occulter",
    "occultées": "occulter",
    "occultés": "occulter",
    "occupa": "occuper",
    "occupai": "occuper",
    "occupaient": "occuper",
    "occupais": "occuper",
    "occupait": "occuper",
    "occupant": "occuper",
    "occupante": "occupant",
    "occupantes": "occupant",
    "occupants": "occupant",
    "occupas": "occuper",
    "occupasse": "occuper",
    "occupassent": "occuper",
    "occupasses": "occuper",
    "occupassiez": "occuper",
    "occupassions": "occuper",
    "occupations": "occupation",
    "occupe": "occuper",
    "occupent": "occuper",
    "occupera": "occuper",
    "occuperai": "occuper",
    "occuperaient": "occuper",
    "occuperais": "occuper",
    "occuperait": "occuper",
    "occuperas": "occuper",
    "occuperez": "occuper",
    "occuperiez": "occuper",
    "occuperions": "occuper",
    "occuperons": "occuper",
    "occuperont": "occuper",
    "occupes": "occuper",
    "occupez": "occuper",
    "occupiez": "occuper",
    "occupions": "occuper",
    "occupons": "occuper",
    "occupâmes": "occuper",
    "occupât": "occuper",
    "occupâtes": "occuper",
    "occupèrent": "occuper",
    "occupé": "occuper",
    "occupée": "occuper",
    "occupées": "occuper",
    "occupés": "occuper",
    "occurrences": "occurrence",
    "occurrente": "occurrent",
    "occurrentes": "occurrent",
    "occurrents": "occurrent",
    "ocelles": "ocelle",
    "ocellée": "ocellé",
    "ocellés": "ocellé",
    "ocelots": "ocelot",
    "ocres": "ocre",
    "ocré": "ocrer",
    "ocrée": "ocrer",
    "ocrées": "ocrer",
    "ocrés": "ocrer",
    "octale": "octal",
    "octales": "octal",
    "octanes": "octane",
    "octaux": "octal",
    "octaves": "octave",
    "octavia": "octavier",
    "octavie": "octavier",
    "octets": "octet",
    "octobres": "octobre",
    "octogonale": "octogonal",
    "octogonales": "octogonal",
    "octogonaux": "octogonal",
    "octogones": "octogone",
    "octogénaires": "octogénaire",
    "octosyllabes": "octosyllabe",
    "octroie": "octroyer",
    "octroient": "octroyer",
    "octroiera": "octroyer",
    "octroierai": "octroyer",
    "octroieraient": "octroyer",
    "octroierais": "octroyer",
    "octroierait": "octroyer",
    "octroieras": "octroyer",
    "octroierez": "octroyer",
    "octroieriez": "octroyer",
    "octroierions": "octroyer",
    "octroierons": "octroyer",
    "octroieront": "octroyer",
    "octroies": "octroyer",
    "octrois": "octroi",
    "octroya": "octroyer",
    "octroyai": "octroyer",
    "octroyaient": "octroyer",
    "octroyais": "octroyer",
    "octroyait": "octroyer",
    "octroyant": "octroyer",
    "octroyas": "octroyer",
    "octroyasse": "octroyer",
    "octroyassent": "octroyer",
    "octroyasses": "octroyer",
    "octroyassiez": "octroyer",
    "octroyassions": "octroyer",
    "octroyez": "octroyer",
    "octroyiez": "octroyer",
    "octroyions": "octroyer",
    "octroyons": "octroyer",
    "octroyâmes": "octroyer",
    "octroyât": "octroyer",
    "octroyâtes": "octroyer",
    "octroyèrent": "octroyer",
    "octroyé": "octroyer",
    "octroyée": "octroyer",
    "octroyées": "octroyer",
    "octroyés": "octroyer",
    "oculaires": "oculaire",
    "oculi": "oculus",
    "oculistes": "oculiste",
    "océane": "océan",
    "océanienne": "océanien",
    "océaniennes": "océanien",
    "océaniens": "océanien",
    "océaniques": "océanique",
    "océanographies": "océanographie",
    "océanographiques": "océanographique",
    "océans": "océan",
    "odalisques": "odalisque",
    "odelettes": "odelette",
    "odes": "ode",
    "odeurs": "odeur",
    "odieuse": "odieux",
    "odieuses": "odieux",
    "odontologies": "odontologie",
    "odontologues": "odontologue",
    "odorant": "odorer",
    "odorante": "odorant",
    "odorantes": "odorant",
    "odorants": "odorant",
    "odorats": "odorat",
    "odoriférante": "odoriférant",
    "odoriférantes": "odoriférant",
    "odoriférants": "odoriférant",
    "odyssées": "odyssée",
    "oecuméniques": "oecuménique",
    "oedipes": "oedipe",
    "oedipienne": "oedipien",
    "oedèmes": "oedème",
    "oedémateuse": "oedémateux",
    "oedémateuses": "oedémateux",
    "oeillades": "oeillade",
    "oeilletonna": "oeilletonner",
    "oeilletonnai": "oeilletonner",
    "oeilletonnaient": "oeilletonner",
    "oeilletonnais": "oeilletonner",
    "oeilletonnait": "oeilletonner",
    "oeilletonnant": "oeilletonner",
    "oeilletonnas": "oeilletonner",
    "oeilletonnasse": "oeilletonner",
    "oeilletonnassent": "oeilletonner",
    "oeilletonnasses": "oeilletonner",
    "oeilletonnassiez": "oeilletonner",
    "oeilletonnassions": "oeilletonner",
    "oeilletonne": "oeilletonner",
    "oeilletonnent": "oeilletonner",
    "oeilletonnera": "oeilletonner",
    "oeilletonnerai": "oeilletonner",
    "oeilletonneraient": "oeilletonner",
    "oeilletonnerais": "oeilletonner",
    "oeilletonnerait": "oeilletonner",
    "oeilletonneras": "oeilletonner",
    "oeilletonnerez": "oeilletonner",
    "oeilletonneriez": "oeilletonner",
    "oeilletonnerions": "oeilletonner",
    "oeilletonnerons": "oeilletonner",
    "oeilletonneront": "oeilletonner",
    "oeilletonnes": "oeilletonner",
    "oeilletonnez": "oeilletonner",
    "oeilletonniez": "oeilletonner",
    "oeilletonnions": "oeilletonner",
    "oeilletonnons": "oeilletonner",
    "oeilletonnâmes": "oeilletonner",
    "oeilletonnât": "oeilletonner",
    "oeilletonnâtes": "oeilletonner",
    "oeilletonnèrent": "oeilletonner",
    "oeilletonné": "oeilletonner",
    "oeilletonnée": "oeilletonner",
    "oeilletonnées": "oeilletonner",
    "oeilletonnés": "oeilletonner",
    "oeilletons": "oeilleton",
    "oeillets": "oeillet",
    "oeillettes": "oeillette",
    "oeillères": "oeillère",
    "oeils": "oeil",
    "oeils-de-boeuf": "oeil-de-boeuf",
    "oeils-de-chat": "oeil-de-chat",
    "oeils-de-perdrix": "oeil-de-perdrix",
    "oeils-de-pie": "oeil-de-pie",
    "oenologies": "oenologie",
    "oenologues": "oenologue",
    "oesophages": "oesophage",
    "oesophagienne": "oesophagien",
    "oesophagiennes": "oesophagien",
    "oestrale": "oestral",
    "oestrales": "oestral",
    "oestraux": "oestral",
    "oestrogènes": "oestrogène",
    "oeufs": "oeuf",
    "oeuvra": "oeuvrer",
    "oeuvrai": "oeuvrer",
    "oeuvraient": "oeuvrer",
    "oeuvrais": "oeuvrer",
    "oeuvrait": "oeuvrer",
    "oeuvrant": "oeuvrer",
    "oeuvras": "oeuvrer",
    "oeuvrasse": "oeuvrer",
    "oeuvrassent": "oeuvrer",
    "oeuvrasses": "oeuvrer",
    "oeuvrassiez": "oeuvrer",
    "oeuvrassions": "oeuvrer",
    "oeuvre": "oeuvrer",
    "oeuvrent": "oeuvrer",
    "oeuvrera": "oeuvrer",
    "oeuvrerai": "oeuvrer",
    "oeuvreraient": "oeuvrer",
    "oeuvrerais": "oeuvrer",
    "oeuvrerait": "oeuvrer",
    "oeuvreras": "oeuvrer",
    "oeuvrerez": "oeuvrer",
    "oeuvreriez": "oeuvrer",
    "oeuvrerions": "oeuvrer",
    "oeuvrerons": "oeuvrer",
    "oeuvreront": "oeuvrer",
    "oeuvres": "oeuvrer",
    "oeuvrettes": "oeuvrette",
    "oeuvrez": "oeuvrer",
    "oeuvriez": "oeuvrer",
    "oeuvrions": "oeuvrer",
    "oeuvrons": "oeuvrer",
    "oeuvrâmes": "oeuvrer",
    "oeuvrât": "oeuvrer",
    "oeuvrâtes": "oeuvrer",
    "oeuvrèrent": "oeuvrer",
    "oeuvré": "oeuvrer",
    "oeuvrée": "oeuvrer",
    "oeuvrées": "oeuvrer",
    "oeuvrés": "oeuvrer",
    "offensa": "offenser",
    "offensai": "offenser",
    "offensaient": "offenser",
    "offensais": "offenser",
    "offensait": "offenser",
    "offensant": "offenser",
    "offensante": "offensant",
    "offensantes": "offensant",
    "offensants": "offensant",
    "offensas": "offenser",
    "offensasse": "offenser",
    "offensassent": "offenser",
    "offensasses": "offenser",
    "offensassiez": "offenser",
    "offensassions": "offenser",
    "offense": "offenser",
    "offensent": "offenser",
    "offensera": "offenser",
    "offenserai": "offenser",
    "offenseraient": "offenser",
    "offenserais": "offenser",
    "offenserait": "offenser",
    "offenseras": "offenser",
    "offenserez": "offenser",
    "offenseriez": "offenser",
    "offenserions": "offenser",
    "offenserons": "offenser",
    "offenseront": "offenser",
    "offenses": "offenser",
    "offenseurs": "offenseur",
    "offensez": "offenser",
    "offensiez": "offenser",
    "offensifs": "offensif",
    "offensions": "offenser",
    "offensive": "offensif",
    "offensives": "offensive",
    "offensons": "offenser",
    "offensâmes": "offenser",
    "offensât": "offenser",
    "offensâtes": "offenser",
    "offensèrent": "offenser",
    "offensé": "offenser",
    "offensée": "offenser",
    "offensées": "offenser",
    "offensés": "offenser",
    "offert": "offrir",
    "offerte": "offrir",
    "offertes": "offrir",
    "offertoires": "offertoire",
    "offerts": "offrir",
    "offices": "office",
    "officia": "officier",
    "officiai": "officier",
    "officiaient": "officier",
    "officiais": "officier",
    "officiait": "officier",
    "officialisa": "officialiser",
    "officialisai": "officialiser",
    "officialisaient": "officialiser",
    "officialisais": "officialiser",
    "officialisait": "officialiser",
    "officialisant": "officialiser",
    "officialisas": "officialiser",
    "officialisasse": "officialiser",
    "officialisassent": "officialiser",
    "officialisasses": "officialiser",
    "officialisassiez": "officialiser",
    "officialisassions": "officialiser",
    "officialise": "officialiser",
    "officialisent": "officialiser",
    "officialisera": "officialiser",
    "officialiserai": "officialiser",
    "officialiseraient": "officialiser",
    "officialiserais": "officialiser",
    "officialiserait": "officialiser",
    "officialiseras": "officialiser",
    "officialiserez": "officialiser",
    "officialiseriez": "officialiser",
    "officialiserions": "officialiser",
    "officialiserons": "officialiser",
    "officialiseront": "officialiser",
    "officialises": "officialiser",
    "officialisez": "officialiser",
    "officialisiez": "officialiser",
    "officialisions": "officialiser",
    "officialisons": "officialiser",
    "officialisâmes": "officialiser",
    "officialisât": "officialiser",
    "officialisâtes": "officialiser",
    "officialisèrent": "officialiser",
    "officialisé": "officialiser",
    "officialisée": "officialiser",
    "officialisées": "officialiser",
    "officialisés": "officialiser",
    "officiant": "officier",
    "officiants": "officiant",
    "officias": "officier",
    "officiasse": "officier",
    "officiassent": "officier",
    "officiasses": "officier",
    "officiassiez": "officier",
    "officiassions": "officier",
    "officiaux": "official",
    "officie": "officier",
    "officielle": "officiel",
    "officielles": "officiel",
    "officiels": "officiel",
    "officient": "officier",
    "officiera": "officier",
    "officierai": "officier",
    "officieraient": "officier",
    "officierais": "officier",
    "officierait": "officier",
    "officieras": "officier",
    "officierez": "officier",
    "officieriez": "officier",
    "officierions": "officier",
    "officierons": "officier",
    "officieront": "officier",
    "officiers": "officier",
    "officies": "officier",
    "officieuse": "officieux",
    "officieuses": "officieux",
    "officiez": "officier",
    "officiiez": "officier",
    "officiions": "officier",
    "officinale": "officinal",
    "officinales": "officinal",
    "officinaux": "officinal",
    "officines": "officine",
    "officions": "officier",
    "officiâmes": "officier",
    "officiât": "officier",
    "officiâtes": "officier",
    "officière": "officier",
    "officièrent": "officier",
    "officié": "officier",
    "offraient": "offrir",
    "offrais": "offrir",
    "offrait": "offrir",
    "offrandes": "offrande",
    "offrant": "offrir",
    "offrante": "offrant",
    "offrantes": "offrant",
    "offrants": "offrant",
    "offre": "offrir",
    "offrent": "offrir",
    "offres": "offrir",
    "offrez": "offrir",
    "offriez": "offrir",
    "offrions": "offrir",
    "offrira": "offrir",
    "offrirai": "offrir",
    "offriraient": "offrir",
    "offrirais": "offrir",
    "offrirait": "offrir",
    "offriras": "offrir",
    "offrirent": "offrir",
    "offrirez": "offrir",
    "offririez": "offrir",
    "offririons": "offrir",
    "offrirons": "offrir",
    "offriront": "offrir",
    "offris": "offrir",
    "offrisse": "offrir",
    "offrissent": "offrir",
    "offrisses": "offrir",
    "offrissiez": "offrir",
    "offrissions": "offrir",
    "offrit": "offrir",
    "offrons": "offrir",
    "offrîmes": "offrir",
    "offrît": "offrir",
    "offrîtes": "offrir",
    "offuscations": "offuscation",
    "offusqua": "offusquer",
    "offusquai": "offusquer",
    "offusquaient": "offusquer",
    "offusquais": "offusquer",
    "offusquait": "offusquer",
    "offusquant": "offusquer",
    "offusquas": "offusquer",
    "offusquasse": "offusquer",
    "offusquassent": "offusquer",
    "offusquasses": "offusquer",
    "offusquassiez": "offusquer",
    "offusquassions": "offusquer",
    "offusque": "offusquer",
    "offusquent": "offusquer",
    "offusquera": "offusquer",
    "offusquerai": "offusquer",
    "offusqueraient": "offusquer",
    "offusquerais": "offusquer",
    "offusquerait": "offusquer",
    "offusqueras": "offusquer",
    "offusquerez": "offusquer",
    "offusqueriez": "offusquer",
    "offusquerions": "offusquer",
    "offusquerons": "offusquer",
    "offusqueront": "offusquer",
    "offusques": "offusquer",
    "offusquez": "offusquer",
    "offusquiez": "offusquer",
    "offusquions": "offusquer",
    "offusquons": "offusquer",
    "offusquâmes": "offusquer",
    "offusquât": "offusquer",
    "offusquâtes": "offusquer",
    "offusquèrent": "offusquer",
    "offusqué": "offusquer",
    "offusquée": "offusquer",
    "offusquées": "offusquer",
    "offusqués": "offusquer",
    "oflags": "oflag",
    "ogivale": "ogival",
    "ogivales": "ogival",
    "ogivaux": "ogival",
    "ogives": "ogive",
    "ognons": "ognon",
    "ogres": "ogre",
    "ogresse": "ogre",
    "ogresses": "ogresse",
    "ohms": "ohm",
    "oie": "ouïr",
    "oient": "ouïr",
    "oies": "ouïr",
    "oignait": "oindre",
    "oignant": "oindre",
    "oigne": "oindre",
    "oignes": "oindre",
    "oignez": "oindre",
    "oignit": "oindre",
    "oignonades": "oignonade",
    "oignons": "oindre",
    "oindra": "oindre",
    "oings": "oing",
    "oins": "oindre",
    "oint": "oindre",
    "ointe": "oint",
    "ointes": "oint",
    "oints": "oint",
    "ois": "ouïr",
    "oiseaux": "oiseau",
    "oiseaux-lyres": "oiseau-lyre",
    "oiseaux-mouches": "oiseau-mouche",
    "oisela": "oiseler",
    "oiselai": "oiseler",
    "oiselaient": "oiseler",
    "oiselais": "oiseler",
    "oiselait": "oiseler",
    "oiselant": "oiseler",
    "oiselas": "oiseler",
    "oiselasse": "oiseler",
    "oiselassent": "oiseler",
    "oiselasses": "oiseler",
    "oiselassiez": "oiseler",
    "oiselassions": "oiseler",
    "oiselets": "oiselet",
    "oiseleurs": "oiseleur",
    "oiselez": "oiseler",
    "oiseliers": "oiselier",
    "oiseliez": "oiseler",
    "oiselions": "oiseler",
    "oiselière": "oiselier",
    "oiselle": "oiseler",
    "oisellent": "oiseler",
    "oisellera": "oiseler",
    "oisellerai": "oiseler",
    "oiselleraient": "oiseler",
    "oisellerais": "oiseler",
    "oisellerait": "oiseler",
    "oiselleras": "oiseler",
    "oisellerez": "oiseler",
    "oiselleriez": "oiseler",
    "oisellerions": "oiseler",
    "oisellerons": "oiseler",
    "oiselleront": "oiseler",
    "oiselles": "oiselle",
    "oiselons": "oiseler",
    "oiselâmes": "oiseler",
    "oiselât": "oiseler",
    "oiselâtes": "oiseler",
    "oiselèrent": "oiseler",
    "oiselé": "oiseler",
    "oiselée": "oiseler",
    "oiselées": "oiseler",
    "oiselés": "oiseler",
    "oiseuse": "oiseux",
    "oiseuses": "oiseux",
    "oisifs": "oisif",
    "oisillons": "oisillon",
    "oisive": "oisif",
    "oisives": "oisif",
    "oisivetés": "oisiveté",
    "oisons": "oison",
    "oit": "ouïr",
    "okapis": "okapi",
    "okoumés": "okoumé",
    "olfactifs": "olfactif",
    "olfactive": "olfactif",
    "olfactives": "olfactif",
    "olifants": "olifant",
    "oligarchies": "oligarchie",
    "oligo-éléments": "oligo-élément",
    "oligocènes": "oligocène",
    "oligophrénies": "oligophrénie",
    "oligopoles": "oligopole",
    "oligoéléments": "oligoélément",
    "olivaies": "olivaie",
    "oliveraies": "oliveraie",
    "olives": "olive",
    "olivettes": "olivette",
    "oliviers": "olivier",
    "olivâtres": "olivâtre",
    "olla podrida": "olla-podrida",
    "olmèques": "olmèque",
    "olographes": "olographe",
    "olympes": "olympe",
    "olympiades": "olympiade",
    "olympienne": "olympien",
    "olympiens": "olympien",
    "olympiques": "olympique",
    "oléagineuse": "oléagineux",
    "oléagineuses": "oléagineux",
    "oléicoles": "oléicole",
    "oléiculteurs": "oléiculteur",
    "oléicultrice": "oléiculteur",
    "oléicultrices": "oléiculteur",
    "oléicultures": "oléiculture",
    "oléoducs": "oléoduc",
    "ombelles": "ombelle",
    "ombellifères": "ombellifère",
    "ombilicale": "ombilical",
    "ombilicales": "ombilical",
    "ombilicaux": "ombilical",
    "ombilics": "ombilic",
    "ombles": "omble",
    "ombra": "ombrer",
    "ombrage": "ombrager",
    "ombragea": "ombrager",
    "ombrageai": "ombrager",
    "ombrageaient": "ombrager",
    "ombrageais": "ombrager",
    "ombrageait": "ombrager",
    "ombrageant": "ombrager",
    "ombrageas": "ombrager",
    "ombrageasse": "ombrager",
    "ombrageassent": "ombrager",
    "ombrageasses": "ombrager",
    "ombrageassiez": "ombrager",
    "ombrageassions": "ombrager",
    "ombragent": "ombrager",
    "ombrageons": "ombrager",
    "ombragera": "ombrager",
    "ombragerai": "ombrager",
    "ombrageraient": "ombrager",
    "ombragerais": "ombrager",
    "ombragerait": "ombrager",
    "ombrageras": "ombrager",
    "ombragerez": "ombrager",
    "ombrageriez": "ombrager",
    "ombragerions": "ombrager",
    "ombragerons": "ombrager",
    "ombrageront": "ombrager",
    "ombrages": "ombrager",
    "ombrageuse": "ombrageux",
    "ombrageuses": "ombrageux",
    "ombragez": "ombrager",
    "ombrageâmes": "ombrager",
    "ombrageât": "ombrager",
    "ombrageâtes": "ombrager",
    "ombragiez": "ombrager",
    "ombragions": "ombrager",
    "ombragèrent": "ombrager",
    "ombragé": "ombrager",
    "ombragée": "ombrager",
    "ombragées": "ombrager",
    "ombragés": "ombrager",
    "ombraient": "ombrer",
    "ombrait": "ombrer",
    "ombrant": "ombrer",
    "ombre": "ombrer",
    "ombrelles": "ombrelle",
    "ombres": "ombrer",
    "ombreuse": "ombreux",
    "ombreuses": "ombreux",
    "ombrophiles": "ombrophile",
    "ombré": "ombrer",
    "ombrée": "ombrer",
    "ombrées": "ombrer",
    "ombrés": "ombrer",
    "omelettes": "omelette",
    "omelettes-surprises": "omelette-surprise",
    "omet": "omettre",
    "omets": "omettre",
    "omettaient": "omettre",
    "omettais": "omettre",
    "omettait": "omettre",
    "omettant": "omettre",
    "omette": "omettre",
    "omettent": "omettre",
    "omettes": "omettre",
    "omettez": "omettre",
    "omettiez": "omettre",
    "omettions": "omettre",
    "omettons": "omettre",
    "omettra": "omettre",
    "omettrai": "omettre",
    "omettraient": "omettre",
    "omettrais": "omettre",
    "omettrait": "omettre",
    "omettras": "omettre",
    "omettrez": "omettre",
    "omettriez": "omettre",
    "omettrions": "omettre",
    "omettrons": "omettre",
    "omettront": "omettre",
    "omirent": "omettre",
    "omis": "omettre",
    "omise": "omettre",
    "omises": "omettre",
    "omisse": "omettre",
    "omissent": "omettre",
    "omisses": "omettre",
    "omissiez": "omettre",
    "omissions": "omission",
    "omit": "omettre",
    "omnidirectionnelle": "omnidirectionnel",
    "omnidirectionnelles": "omnidirectionnel",
    "omnidirectionnels": "omnidirectionnel",
    "omnipotente": "omnipotent",
    "omnipotentes": "omnipotent",
    "omnipotents": "omnipotent",
    "omniprésences": "omniprésence",
    "omniprésente": "omniprésent",
    "omniprésentes": "omniprésent",
    "omniprésents": "omniprésent",
    "omnisciente": "omniscient",
    "omniscientes": "omniscient",
    "omniscients": "omniscient",
    "omniums": "omnium",
    "omnivores": "omnivore",
    "omoplates": "omoplate",
    "omégas": "oméga",
    "omîmes": "omettre",
    "omît": "omettre",
    "omîtes": "omettre",
    "onagres": "onagre",
    "onanismes": "onanisme",
    "onces": "once",
    "onciale": "oncial",
    "onciales": "onciale",
    "onciaux": "oncial",
    "oncles": "oncle",
    "oncogènes": "oncogène",
    "oncologiques": "oncologique",
    "oncologues": "oncologue",
    "onctions": "onction",
    "onctueuse": "onctueux",
    "onctueuses": "onctueux",
    "ondes": "onde",
    "ondine": "ondin",
    "ondines": "ondine",
    "ondins": "ondin",
    "ondoie": "ondoyer",
    "ondoiements": "ondoiement",
    "ondoient": "ondoyer",
    "ondoiera": "ondoyer",
    "ondoierai": "ondoyer",
    "ondoieraient": "ondoyer",
    "ondoierais": "ondoyer",
    "ondoierait": "ondoyer",
    "ondoieras": "ondoyer",
    "ondoierez": "ondoyer",
    "ondoieriez": "ondoyer",
    "ondoierions": "ondoyer",
    "ondoierons": "ondoyer",
    "ondoieront": "ondoyer",
    "ondoies": "ondoyer",
    "ondoya": "ondoyer",
    "ondoyai": "ondoyer",
    "ondoyaient": "ondoyer",
    "ondoyais": "ondoyer",
    "ondoyait": "ondoyer",
    "ondoyant": "ondoyer",
    "ondoyante": "ondoyant",
    "ondoyantes": "ondoyant",
    "ondoyants": "ondoyant",
    "ondoyas": "ondoyer",
    "ondoyasse": "ondoyer",
    "ondoyassent": "ondoyer",
    "ondoyasses": "ondoyer",
    "ondoyassiez": "ondoyer",
    "ondoyassions": "ondoyer",
    "ondoyez": "ondoyer",
    "ondoyiez": "ondoyer",
    "ondoyions": "ondoyer",
    "ondoyons": "ondoyer",
    "ondoyâmes": "ondoyer",
    "ondoyât": "ondoyer",
    "ondoyâtes": "ondoyer",
    "ondoyèrent": "ondoyer",
    "ondoyé": "ondoyer",
    "ondoyée": "ondoyer",
    "ondoyées": "ondoyer",
    "ondoyés": "ondoyer",
    "ondula": "onduler",
    "ondulai": "onduler",
    "ondulaient": "onduler",
    "ondulais": "onduler",
    "ondulait": "onduler",
    "ondulant": "onduler",
    "ondulante": "ondulant",
    "ondulantes": "ondulant",
    "ondulants": "ondulant",
    "ondulas": "onduler",
    "ondulasse": "onduler",
    "ondulassent": "onduler",
    "ondulasses": "onduler",
    "ondulassiez": "onduler",
    "ondulassions": "onduler",
    "ondulations": "ondulation",
    "ondulatoires": "ondulatoire",
    "ondule": "onduler",
    "ondulent": "onduler",
    "ondulera": "onduler",
    "ondulerai": "onduler",
    "onduleraient": "onduler",
    "ondulerais": "onduler",
    "ondulerait": "onduler",
    "onduleras": "onduler",
    "ondulerez": "onduler",
    "onduleriez": "onduler",
    "ondulerions": "onduler",
    "ondulerons": "onduler",
    "onduleront": "onduler",
    "ondules": "onduler",
    "onduleuse": "onduleux",
    "onduleuses": "onduleux",
    "ondulez": "onduler",
    "onduliez": "onduler",
    "ondulions": "onduler",
    "ondulons": "onduler",
    "ondulâmes": "onduler",
    "ondulât": "onduler",
    "ondulâtes": "onduler",
    "ondulèrent": "onduler",
    "ondulé": "onduler",
    "ondulée": "onduler",
    "ondulées": "onduler",
    "ondulés": "onduler",
    "ondées": "ondée",
    "ondés": "ondé",
    "one-man-shows": "one-man-show",
    "ongles": "ongle",
    "onglets": "onglet",
    "onguents": "onguent",
    "ongulés": "ongulé",
    "oniriques": "onirique",
    "oniromancies": "oniromancie",
    "onomastiques": "onomastique",
    "onomatopées": "onomatopée",
    "onopordons": "onopordon",
    "ont": "avoir",
    "ontogénèses": "ontogénèse",
    "ontologies": "ontologie",
    "ontologiques": "ontologique",
    "onusienne": "onusien",
    "onusiennes": "onusien",
    "onusiens": "onusien",
    "onychophagies": "onychophagie",
    "onzains": "onzain",
    "onzièmes": "onzième",
    "onéreuse": "onéreux",
    "onéreuses": "onéreux",
    "oolites": "oolite",
    "oolithes": "oolithe",
    "opacifia": "opacifier",
    "opacifiai": "opacifier",
    "opacifiaient": "opacifier",
    "opacifiais": "opacifier",
    "opacifiait": "opacifier",
    "opacifiant": "opacifier",
    "opacifias": "opacifier",
    "opacifiasse": "opacifier",
    "opacifiassent": "opacifier",
    "opacifiasses": "opacifier",
    "opacifiassiez": "opacifier",
    "opacifiassions": "opacifier",
    "opacifie": "opacifier",
    "opacifient": "opacifier",
    "opacifiera": "opacifier",
    "opacifierai": "opacifier",
    "opacifieraient": "opacifier",
    "opacifierais": "opacifier",
    "opacifierait": "opacifier",
    "opacifieras": "opacifier",
    "opacifierez": "opacifier",
    "opacifieriez": "opacifier",
    "opacifierions": "opacifier",
    "opacifierons": "opacifier",
    "opacifieront": "opacifier",
    "opacifies": "opacifier",
    "opacifiez": "opacifier",
    "opacifiiez": "opacifier",
    "opacifiions": "opacifier",
    "opacifions": "opacifier",
    "opacifiâmes": "opacifier",
    "opacifiât": "opacifier",
    "opacifiâtes": "opacifier",
    "opacifièrent": "opacifier",
    "opacifié": "opacifier",
    "opacifiée": "opacifier",
    "opacifiées": "opacifier",
    "opacifiés": "opacifier",
    "opacités": "opacité",
    "opales": "opale",
    "opalescente": "opalescent",
    "opalescentes": "opalescent",
    "opaline": "opalin",
    "opalines": "opaline",
    "opalins": "opalin",
    "opaques": "opaque",
    "opens": "open",
    "opercules": "opercule",
    "ophicléides": "ophicléide",
    "ophidiens": "ophidien",
    "ophtalmies": "ophtalmie",
    "ophtalmologies": "ophtalmologie",
    "ophtalmologistes": "ophtalmologiste",
    "opiacé": "opiacer",
    "opiacée": "opiacé",
    "opiacées": "opiacer",
    "opiacés": "opiacé",
    "opiats": "opiat",
    "opina": "opiner",
    "opinai": "opiner",
    "opinaient": "opiner",
    "opinais": "opiner",
    "opinait": "opiner",
    "opinant": "opiner",
    "opinas": "opiner",
    "opinasse": "opiner",
    "opinassent": "opiner",
    "opinasses": "opiner",
    "opinassiez": "opiner",
    "opinassions": "opiner",
    "opine": "opiner",
    "opinels": "opinel",
    "opinent": "opiner",
    "opinera": "opiner",
    "opinerai": "opiner",
    "opineraient": "opiner",
    "opinerais": "opiner",
    "opinerait": "opiner",
    "opineras": "opiner",
    "opinerez": "opiner",
    "opineriez": "opiner",
    "opinerions": "opiner",
    "opinerons": "opiner",
    "opineront": "opiner",
    "opines": "opiner",
    "opinez": "opiner",
    "opiniez": "opiner",
    "opinions": "opinion",
    "opiniâtra": "opiniâtrer",
    "opiniâtre": "opiniâtrer",
    "opiniâtres": "opiniâtre",
    "opiniâtretés": "opiniâtreté",
    "opiniâtrez": "opiniâtrer",
    "opinons": "opiner",
    "opinâmes": "opiner",
    "opinât": "opiner",
    "opinâtes": "opiner",
    "opinèrent": "opiner",
    "opiné": "opiner",
    "opiomanes": "opiomane",
    "opiums": "opium",
    "opossums": "opossum",
    "opothérapiques": "opothérapique",
    "oppidums": "oppidum",
    "opportune": "opportun",
    "opportunes": "opportun",
    "opportunismes": "opportunisme",
    "opportunistes": "opportuniste",
    "opportunités": "opportunité",
    "opportuns": "opportun",
    "opposa": "opposer",
    "opposables": "opposable",
    "opposai": "opposer",
    "opposaient": "opposer",
    "opposais": "opposer",
    "opposait": "opposer",
    "opposant": "opposer",
    "opposante": "opposant",
    "opposantes": "opposant",
    "opposants": "opposant",
    "opposas": "opposer",
    "opposasse": "opposer",
    "opposassent": "opposer",
    "opposasses": "opposer",
    "opposassiez": "opposer",
    "opposassions": "opposer",
    "oppose": "opposer",
    "opposent": "opposer",
    "opposera": "opposer",
    "opposerai": "opposer",
    "opposeraient": "opposer",
    "opposerais": "opposer",
    "opposerait": "opposer",
    "opposeras": "opposer",
    "opposerez": "opposer",
    "opposeriez": "opposer",
    "opposerions": "opposer",
    "opposerons": "opposer",
    "opposeront": "opposer",
    "opposes": "opposer",
    "opposez": "opposer",
    "opposiez": "opposer",
    "opposions": "opposer",
    "oppositionnelle": "oppositionnel",
    "oppositionnelles": "oppositionnel",
    "oppositionnels": "oppositionnel",
    "oppositions": "opposition",
    "opposons": "opposer",
    "opposâmes": "opposer",
    "opposât": "opposer",
    "opposâtes": "opposer",
    "opposèrent": "opposer",
    "opposé": "opposer",
    "opposée": "opposer",
    "opposées": "opposer",
    "opposés": "opposer",
    "oppressa": "oppresser",
    "oppressai": "oppresser",
    "oppressaient": "oppresser",
    "oppressais": "oppresser",
    "oppressait": "oppresser",
    "oppressant": "oppresser",
    "oppressante": "oppressant",
    "oppressantes": "oppressant",
    "oppressants": "oppressant",
    "oppressas": "oppresser",
    "oppressasse": "oppresser",
    "oppressassent": "oppresser",
    "oppressasses": "oppresser",
    "oppressassiez": "oppresser",
    "oppressassions": "oppresser",
    "oppresse": "oppresser",
    "oppressent": "oppresser",
    "oppressera": "oppresser",
    "oppresserai": "oppresser",
    "oppresseraient": "oppresser",
    "oppresserais": "oppresser",
    "oppresserait": "oppresser",
    "oppresseras": "oppresser",
    "oppresserez": "oppresser",
    "oppresseriez": "oppresser",
    "oppresserions": "oppresser",
    "oppresserons": "oppresser",
    "oppresseront": "oppresser",
    "oppresses": "oppresser",
    "oppresseurs": "oppresseur",
    "oppressez": "oppresser",
    "oppressiez": "oppresser",
    "oppressions": "oppression",
    "oppressive": "oppressif",
    "oppressons": "oppresser",
    "oppressâmes": "oppresser",
    "oppressât": "oppresser",
    "oppressâtes": "oppresser",
    "oppressèrent": "oppresser",
    "oppressé": "oppresser",
    "oppressée": "oppresser",
    "oppressées": "oppresser",
    "oppressés": "oppresser",
    "opprima": "opprimer",
    "opprimai": "opprimer",
    "opprimaient": "opprimer",
    "opprimais": "opprimer",
    "opprimait": "opprimer",
    "opprimant": "opprimer",
    "opprimas": "opprimer",
    "opprimasse": "opprimer",
    "opprimassent": "opprimer",
    "opprimasses": "opprimer",
    "opprimassiez": "opprimer",
    "opprimassions": "opprimer",
    "opprime": "opprimer",
    "oppriment": "opprimer",
    "opprimera": "opprimer",
    "opprimerai": "opprimer",
    "opprimeraient": "opprimer",
    "opprimerais": "opprimer",
    "opprimerait": "opprimer",
    "opprimeras": "opprimer",
    "opprimerez": "opprimer",
    "opprimeriez": "opprimer",
    "opprimerions": "opprimer",
    "opprimerons": "opprimer",
    "opprimeront": "opprimer",
    "opprimes": "opprimer",
    "opprimez": "opprimer",
    "opprimiez": "opprimer",
    "opprimions": "opprimer",
    "opprimons": "opprimer",
    "opprimâmes": "opprimer",
    "opprimât": "opprimer",
    "opprimâtes": "opprimer",
    "opprimèrent": "opprimer",
    "opprimé": "opprimer",
    "opprimée": "opprimer",
    "opprimées": "opprimer",
    "opprimés": "opprimer",
    "opprobres": "opprobre",
    "opta": "opter",
    "optai": "opter",
    "optaient": "opter",
    "optais": "opter",
    "optait": "opter",
    "optant": "opter",
    "optas": "opter",
    "optasse": "opter",
    "optassent": "opter",
    "optasses": "opter",
    "optassiez": "opter",
    "optassions": "opter",
    "optatifs": "optatif",
    "opte": "opter",
    "optent": "opter",
    "optera": "opter",
    "opterai": "opter",
    "opteraient": "opter",
    "opterais": "opter",
    "opterait": "opter",
    "opteras": "opter",
    "opterez": "opter",
    "opteriez": "opter",
    "opterions": "opter",
    "opterons": "opter",
    "opteront": "opter",
    "optes": "opter",
    "optez": "opter",
    "opticienne": "opticien",
    "opticiennes": "opticien",
    "opticiens": "opticien",
    "optiez": "opter",
    "optima": "optimum",
    "optimale": "optimal",
    "optimales": "optimal",
    "optimaux": "optimal",
    "optimisa": "optimiser",
    "optimisai": "optimiser",
    "optimisaient": "optimiser",
    "optimisais": "optimiser",
    "optimisait": "optimiser",
    "optimisant": "optimiser",
    "optimisas": "optimiser",
    "optimisasse": "optimiser",
    "optimisassent": "optimiser",
    "optimisasses": "optimiser",
    "optimisassiez": "optimiser",
    "optimisassions": "optimiser",
    "optimisations": "optimisation",
    "optimise": "optimiser",
    "optimisent": "optimiser",
    "optimisera": "optimiser",
    "optimiserai": "optimiser",
    "optimiseraient": "optimiser",
    "optimiserais": "optimiser",
    "optimiserait": "optimiser",
    "optimiseras": "optimiser",
    "optimiserez": "optimiser",
    "optimiseriez": "optimiser",
    "optimiserions": "optimiser",
    "optimiserons": "optimiser",
    "optimiseront": "optimiser",
    "optimises": "optimiser",
    "optimisez": "optimiser",
    "optimisiez": "optimiser",
    "optimisions": "optimiser",
    "optimismes": "optimisme",
    "optimisons": "optimiser",
    "optimistes": "optimiste",
    "optimisâmes": "optimiser",
    "optimisât": "optimiser",
    "optimisâtes": "optimiser",
    "optimisèrent": "optimiser",
    "optimisé": "optimiser",
    "optimisée": "optimiser",
    "optimisées": "optimiser",
    "optimisés": "optimiser",
    "optimums": "optimum",
    "optionnelle": "optionnel",
    "optionnelles": "optionnel",
    "optionnels": "optionnel",
    "options": "option",
    "optiques": "optique",
    "optométries": "optométrie",
    "optons": "opter",
    "optroniques": "optronique",
    "optâmes": "opter",
    "optât": "opter",
    "optâtes": "opter",
    "optèrent": "opter",
    "opté": "opter",
    "opulences": "opulence",
    "opulente": "opulent",
    "opulentes": "opulent",
    "opulents": "opulent",
    "opuntias": "opuntia",
    "opuscules": "opuscule",
    "opère": "opérer",
    "opèrent": "opérer",
    "opères": "opérer",
    "opéables": "opéable",
    "opéra": "opérer",
    "opérabilités": "opérabilité",
    "opérai": "opérer",
    "opéraient": "opérer",
    "opérais": "opérer",
    "opérait": "opérer",
    "opérant": "opérer",
    "opéras": "opérer",
    "opéras-comiques": "opéra-comique",
    "opérasse": "opérer",
    "opérassent": "opérer",
    "opérasses": "opérer",
    "opérassiez": "opérer",
    "opérassions": "opérer",
    "opérateurs": "opérateur",
    "opérationnelle": "opérationnel",
    "opérationnelles": "opérationnel",
    "opérationnels": "opérationnel",
    "opérations": "opération",
    "opératoires": "opératoire",
    "opératrice": "opérateur",
    "opératrices": "opérateur",
    "opérera": "opérer",
    "opérerai": "opérer",
    "opéreraient": "opérer",
    "opérerais": "opérer",
    "opérerait": "opérer",
    "opéreras": "opérer",
    "opérerez": "opérer",
    "opéreriez": "opérer",
    "opérerions": "opérer",
    "opérerons": "opérer",
    "opéreront": "opérer",
    "opérettes": "opérette",
    "opérez": "opérer",
    "opériez": "opérer",
    "opérions": "opérer",
    "opérons": "opérer",
    "opérâmes": "opérer",
    "opérât": "opérer",
    "opérâtes": "opérer",
    "opérèrent": "opérer",
    "opéré": "opérer",
    "opérée": "opérer",
    "opérées": "opérer",
    "opérés": "opérer",
    "oracles": "oracle",
    "orages": "orage",
    "orageuse": "orageux",
    "orageuses": "orageux",
    "oraisons": "oraison",
    "orale": "oral",
    "orales": "oral",
    "oranaise": "oranais",
    "orangeades": "orangeade",
    "orangeraies": "orangeraie",
    "orangeries": "orangerie",
    "orangers": "oranger",
    "oranges": "orange",
    "orangistes": "orangiste",
    "orangs-outangs": "orang-outang",
    "orangs-outans": "orang-outan",
    "orangé": "oranger",
    "orangée": "oranger",
    "orangées": "oranger",
    "orangés": "oranger",
    "orante": "orant",
    "orantes": "orant",
    "orants": "orant",
    "orateurs": "orateur",
    "oratoires": "oratoire",
    "oratoriens": "oratorien",
    "oratorios": "oratorio",
    "oratrice": "orateur",
    "oratrices": "orateur",
    "oraux": "oral",
    "orbes": "orbe",
    "orbiculaires": "orbiculaire",
    "orbitaires": "orbitaire",
    "orbitale": "orbital",
    "orbitales": "orbital",
    "orbitaux": "orbital",
    "orbites": "orbite",
    "orbitons": "orbiter",
    "orbitèles": "orbitèle",
    "orcanettes": "orcanette",
    "orchestra": "orchestrer",
    "orchestrai": "orchestrer",
    "orchestraient": "orchestrer",
    "orchestrais": "orchestrer",
    "orchestrait": "orchestrer",
    "orchestrale": "orchestral",
    "orchestrales": "orchestral",
    "orchestrant": "orchestrer",
    "orchestras": "orchestrer",
    "orchestrasse": "orchestrer",
    "orchestrassent": "orchestrer",
    "orchestrasses": "orchestrer",
    "orchestrassiez": "orchestrer",
    "orchestrassions": "orchestrer",
    "orchestrations": "orchestration",
    "orchestraux": "orchestral",
    "orchestre": "orchestrer",
    "orchestrent": "orchestrer",
    "orchestrera": "orchestrer",
    "orchestrerai": "orchestrer",
    "orchestreraient": "orchestrer",
    "orchestrerais": "orchestrer",
    "orchestrerait": "orchestrer",
    "orchestreras": "orchestrer",
    "orchestrerez": "orchestrer",
    "orchestreriez": "orchestrer",
    "orchestrerions": "orchestrer",
    "orchestrerons": "orchestrer",
    "orchestreront": "orchestrer",
    "orchestres": "orchestrer",
    "orchestrez": "orchestrer",
    "orchestriez": "orchestrer",
    "orchestrions": "orchestrer",
    "orchestrons": "orchestrer",
    "orchestrâmes": "orchestrer",
    "orchestrât": "orchestrer",
    "orchestrâtes": "orchestrer",
    "orchestrèrent": "orchestrer",
    "orchestré": "orchestrer",
    "orchestrée": "orchestrer",
    "orchestrées": "orchestrer",
    "orchestrés": "orchestrer",
    "orchidées": "orchidée",
    "orchites": "orchite",
    "ordalies": "ordalie",
    "ordinaires": "ordinaire",
    "ordinale": "ordinal",
    "ordinales": "ordinal",
    "ordinands": "ordinand",
    "ordinants": "ordinant",
    "ordinateurs": "ordinateur",
    "ordinations": "ordination",
    "ordinaux": "ordinal",
    "ordonna": "ordonner",
    "ordonnai": "ordonner",
    "ordonnaient": "ordonner",
    "ordonnais": "ordonner",
    "ordonnait": "ordonner",
    "ordonnance": "ordonnancer",
    "ordonnancements": "ordonnancement",
    "ordonnancent": "ordonnancer",
    "ordonnancera": "ordonnancer",
    "ordonnancerai": "ordonnancer",
    "ordonnanceraient": "ordonnancer",
    "ordonnancerais": "ordonnancer",
    "ordonnancerait": "ordonnancer",
    "ordonnanceras": "ordonnancer",
    "ordonnancerez": "ordonnancer",
    "ordonnanceriez": "ordonnancer",
    "ordonnancerions": "ordonnancer",
    "ordonnancerons": "ordonnancer",
    "ordonnanceront": "ordonnancer",
    "ordonnances": "ordonnancer",
    "ordonnancez": "ordonnancer",
    "ordonnanciez": "ordonnancer",
    "ordonnancions": "ordonnancer",
    "ordonnancèrent": "ordonnancer",
    "ordonnancé": "ordonnancer",
    "ordonnancée": "ordonnancer",
    "ordonnancées": "ordonnancer",
    "ordonnancés": "ordonnancer",
    "ordonnant": "ordonner",
    "ordonnança": "ordonnancer",
    "ordonnançai": "ordonnancer",
    "ordonnançaient": "ordonnancer",
    "ordonnançais": "ordonnancer",
    "ordonnançait": "ordonnancer",
    "ordonnançant": "ordonnancer",
    "ordonnanças": "ordonnancer",
    "ordonnançasse": "ordonnancer",
    "ordonnançassent": "ordonnancer",
    "ordonnançasses": "ordonnancer",
    "ordonnançassiez": "ordonnancer",
    "ordonnançassions": "ordonnancer",
    "ordonnançons": "ordonnancer",
    "ordonnançâmes": "ordonnancer",
    "ordonnançât": "ordonnancer",
    "ordonnançâtes": "ordonnancer",
    "ordonnas": "ordonner",
    "ordonnasse": "ordonner",
    "ordonnassent": "ordonner",
    "ordonnasses": "ordonner",
    "ordonnassiez": "ordonner",
    "ordonnassions": "ordonner",
    "ordonnateurs": "ordonnateur",
    "ordonnatrice": "ordonnateur",
    "ordonnatrices": "ordonnateur",
    "ordonne": "ordonner",
    "ordonnent": "ordonner",
    "ordonnera": "ordonner",
    "ordonnerai": "ordonner",
    "ordonneraient": "ordonner",
    "ordonnerais": "ordonner",
    "ordonnerait": "ordonner",
    "ordonneras": "ordonner",
    "ordonnerez": "ordonner",
    "ordonneriez": "ordonner",
    "ordonnerions": "ordonner",
    "ordonnerons": "ordonner",
    "ordonneront": "ordonner",
    "ordonnes": "ordonner",
    "ordonnez": "ordonner",
    "ordonniez": "ordonner",
    "ordonnions": "ordonner",
    "ordonnons": "ordonner",
    "ordonnâmes": "ordonner",
    "ordonnât": "ordonner",
    "ordonnâtes": "ordonner",
    "ordonnèrent": "ordonner",
    "ordonné": "ordonner",
    "ordonnée": "ordonner",
    "ordonnées": "ordonner",
    "ordonnés": "ordonner",
    "ordres": "ordre",
    "ordureries": "ordurerie",
    "ordures": "ordure",
    "orduriers": "ordurier",
    "ordurière": "ordurier",
    "ordurières": "ordurier",
    "oreillers": "oreiller",
    "oreilles": "oreille",
    "oreilles-de-mer": "oreille-de-mer",
    "oreilles-de-souris": "oreille-de-souris",
    "oreillettes": "oreillette",
    "oreillons": "oreillon",
    "orfraies": "orfraie",
    "orfèvreries": "orfèvrerie",
    "orfèvres": "orfèvre",
    "orfévrée": "orfévré",
    "organdis": "organdi",
    "organeaux": "organeau",
    "organes": "organe",
    "organigrammes": "organigramme",
    "organiques": "organique",
    "organisa": "organiser",
    "organisai": "organiser",
    "organisaient": "organiser",
    "organisais": "organiser",
    "organisait": "organiser",
    "organisant": "organiser",
    "organisas": "organiser",
    "organisasse": "organiser",
    "organisassent": "organiser",
    "organisasses": "organiser",
    "organisassiez": "organiser",
    "organisassions": "organiser",
    "organisateurs": "organisateur",
    "organisationnelle": "organisationnel",
    "organisationnelles": "organisationnel",
    "organisationnels": "organisationnel",
    "organisations": "organisation",
    "organisatrice": "organisateur",
    "organisatrices": "organisateur",
    "organise": "organiser",
    "organisent": "organiser",
    "organisera": "organiser",
    "organiserai": "organiser",
    "organiseraient": "organiser",
    "organiserais": "organiser",
    "organiserait": "organiser",
    "organiseras": "organiser",
    "organiserez": "organiser",
    "organiseriez": "organiser",
    "organiserions": "organiser",
    "organiserons": "organiser",
    "organiseront": "organiser",
    "organises": "organiser",
    "organisez": "organiser",
    "organisiez": "organiser",
    "organisions": "organiser",
    "organismes": "organisme",
    "organisons": "organiser",
    "organistes": "organiste",
    "organisâmes": "organiser",
    "organisât": "organiser",
    "organisâtes": "organiser",
    "organisèrent": "organiser",
    "organisé": "organiser",
    "organisée": "organiser",
    "organisées": "organiser",
    "organisés": "organiser",
    "orgasmes": "orgasme",
    "orgeats": "orgeat",
    "orgelets": "orgelet",
    "orges": "orge",
    "orgiastiques": "orgiastique",
    "orgies": "orgie",
    "orgueilleuse": "orgueilleux",
    "orgueilleuses": "orgueilleux",
    "orgueils": "orgueil",
    "orgues": "orgue",
    "orienta": "orienter",
    "orientai": "orienter",
    "orientaient": "orienter",
    "orientais": "orienter",
    "orientait": "orienter",
    "orientale": "oriental",
    "orientales": "oriental",
    "orientalismes": "orientalisme",
    "orientalistes": "orientaliste",
    "orientant": "orienter",
    "orientas": "orienter",
    "orientasse": "orienter",
    "orientassent": "orienter",
    "orientasses": "orienter",
    "orientassiez": "orienter",
    "orientassions": "orienter",
    "orientateurs": "orientateur",
    "orientations": "orientation",
    "orientaux": "oriental",
    "oriente": "orienter",
    "orientent": "orienter",
    "orientera": "orienter",
    "orienterai": "orienter",
    "orienteraient": "orienter",
    "orienterais": "orienter",
    "orienterait": "orienter",
    "orienteras": "orienter",
    "orienterez": "orienter",
    "orienteriez": "orienter",
    "orienterions": "orienter",
    "orienterons": "orienter",
    "orienteront": "orienter",
    "orientes": "orienter",
    "orienteurs": "orienteur",
    "orienteuse": "orienteur",
    "orienteuses": "orienteur",
    "orientez": "orienter",
    "orientiez": "orienter",
    "orientions": "orienter",
    "orientons": "orienter",
    "orients": "orient",
    "orientâmes": "orienter",
    "orientât": "orienter",
    "orientâtes": "orienter",
    "orientèrent": "orienter",
    "orienté": "orienter",
    "orientée": "orienter",
    "orientées": "orienter",
    "orientés": "orienter",
    "orifices": "orifice",
    "oriflammes": "oriflamme",
    "origans": "origan",
    "originaires": "originaire",
    "originale": "original",
    "originales": "original",
    "originalités": "originalité",
    "originaux": "original",
    "originelle": "originel",
    "originelles": "originel",
    "originels": "originel",
    "origines": "origine",
    "orignaux": "orignal",
    "orillons": "orillon",
    "oripeaux": "oripeau",
    "orléanaise": "orléanais",
    "orléanaises": "orléanais",
    "orléanistes": "orléaniste",
    "ormeaux": "ormeau",
    "ormes": "orme",
    "orna": "orner",
    "ornai": "orner",
    "ornaient": "orner",
    "ornais": "orner",
    "ornait": "orner",
    "ornant": "orner",
    "ornas": "orner",
    "ornasse": "orner",
    "ornassent": "orner",
    "ornasses": "orner",
    "ornassiez": "orner",
    "ornassions": "orner",
    "orne": "orner",
    "ornementale": "ornemental",
    "ornementales": "ornemental",
    "ornementations": "ornementation",
    "ornementaux": "ornemental",
    "ornements": "ornement",
    "ornementé": "ornementer",
    "ornementée": "ornementer",
    "ornementés": "ornementer",
    "ornent": "orner",
    "ornera": "orner",
    "ornerai": "orner",
    "orneraient": "orner",
    "ornerais": "orner",
    "ornerait": "orner",
    "orneras": "orner",
    "ornerez": "orner",
    "orneriez": "orner",
    "ornerions": "orner",
    "ornerons": "orner",
    "orneront": "orner",
    "ornes": "orner",
    "ornez": "orner",
    "orniez": "orner",
    "ornions": "orner",
    "ornithologies": "ornithologie",
    "ornithologiques": "ornithologique",
    "ornithologues": "ornithologue",
    "ornithorynques": "ornithorynque",
    "ornières": "ornière",
    "ornons": "orner",
    "ornâmes": "orner",
    "ornât": "orner",
    "ornâtes": "orner",
    "ornèrent": "orner",
    "orné": "orner",
    "ornée": "orner",
    "ornées": "orner",
    "ornés": "orner",
    "orogénèses": "orogénèse",
    "oronges": "oronge",
    "orpailleurs": "orpailleur",
    "orphelinats": "orphelinat",
    "orpheline": "orphelin",
    "orphelines": "orphelin",
    "orphelins": "orphelin",
    "orphies": "orphie",
    "orphiques": "orphique",
    "orphéonistes": "orphéoniste",
    "orphéons": "orphéon",
    "orques": "orque",
    "ors": "or",
    "orteils": "orteil",
    "orthodontistes": "orthodontiste",
    "orthodoxes": "orthodoxe",
    "orthodoxies": "orthodoxie",
    "orthogonale": "orthogonal",
    "orthogonales": "orthogonal",
    "orthogonaux": "orthogonal",
    "orthographes": "orthographe",
    "orthographiait": "orthographier",
    "orthographie": "orthographier",
    "orthographiques": "orthographique",
    "orthographié": "orthographier",
    "orthographiées": "orthographier",
    "orthophonies": "orthophonie",
    "orthophonistes": "orthophoniste",
    "orthoptères": "orthoptère",
    "orthopédies": "orthopédie",
    "orthopédiques": "orthopédique",
    "orties": "ortie",
    "ortolans": "ortolan",
    "orvets": "orvet",
    "orviétans": "orviétan",
    "orées": "orée",
    "osa": "oser",
    "osai": "oser",
    "osaient": "oser",
    "osais": "oser",
    "osait": "oser",
    "osant": "oser",
    "osas": "oser",
    "osasse": "oser",
    "osassent": "oser",
    "osasses": "oser",
    "osassiez": "oser",
    "osassions": "oser",
    "oscars": "oscar",
    "oscilla": "osciller",
    "oscillai": "osciller",
    "oscillaient": "osciller",
    "oscillais": "osciller",
    "oscillait": "osciller",
    "oscillant": "osciller",
    "oscillante": "oscillant",
    "oscillants": "oscillant",
    "oscillas": "osciller",
    "oscillasse": "osciller",
    "oscillassent": "osciller",
    "oscillasses": "osciller",
    "oscillassiez": "osciller",
    "oscillassions": "osciller",
    "oscillations": "oscillation",
    "oscillatoires": "oscillatoire",
    "oscille": "osciller",
    "oscillent": "osciller",
    "oscillera": "osciller",
    "oscillerai": "osciller",
    "oscilleraient": "osciller",
    "oscillerais": "osciller",
    "oscillerait": "osciller",
    "oscilleras": "osciller",
    "oscillerez": "osciller",
    "oscilleriez": "osciller",
    "oscillerions": "osciller",
    "oscillerons": "osciller",
    "oscilleront": "osciller",
    "oscilles": "osciller",
    "oscillez": "osciller",
    "oscilliez": "osciller",
    "oscillions": "osciller",
    "oscillons": "osciller",
    "oscillâmes": "osciller",
    "oscillât": "osciller",
    "oscillâtes": "osciller",
    "oscillèrent": "osciller",
    "oscillé": "osciller",
    "ose": "oser",
    "oseilles": "oseille",
    "osent": "oser",
    "osera": "oser",
    "oserai": "oser",
    "oseraient": "oser",
    "oseraies": "oseraie",
    "oserais": "oser",
    "oserait": "oser",
    "oseras": "oser",
    "oserez": "oser",
    "oseriez": "oser",
    "oserions": "oser",
    "oserons": "oser",
    "oseront": "oser",
    "oses": "oser",
    "osez": "oser",
    "osiers": "osier",
    "osiez": "oser",
    "osions": "oser",
    "osmoses": "osmose",
    "osons": "oser",
    "ossatures": "ossature",
    "osselets": "osselet",
    "ossements": "ossement",
    "osseuse": "osseux",
    "osseuses": "osseux",
    "ossifié": "ossifier",
    "ossuaires": "ossuaire",
    "ossue": "ossu",
    "ostensibles": "ostensible",
    "ostensoirs": "ostensoir",
    "ostentations": "ostentation",
    "ostentatoires": "ostentatoire",
    "ostracismes": "ostracisme",
    "ostrogoths": "ostrogoth",
    "ostréicoles": "ostréicole",
    "ostréiculteurs": "ostréiculteur",
    "ostréicultrice": "ostréiculteur",
    "ostréicultrices": "ostréiculteur",
    "ostréicultures": "ostréiculture",
    "ostéites": "ostéite",
    "ostéogéniques": "ostéogénique",
    "ostéomyélites": "ostéomyélite",
    "ostéopathes": "ostéopathe",
    "osâmes": "oser",
    "osât": "oser",
    "osâtes": "oser",
    "osèrent": "oser",
    "osé": "oser",
    "osée": "oser",
    "osées": "oser",
    "osés": "oser",
    "otages": "otage",
    "otaries": "otarie",
    "otites": "otite",
    "oto rhino": "oto-rhino",
    "oto-rhinos": "oto-rhino",
    "ottomane": "ottoman",
    "ottomanes": "ottoman",
    "ottomans": "ottoman",
    "ouailles": "ouaille",
    "ouananiches": "ouananiche",
    "ouata": "ouater",
    "ouatant": "ouater",
    "ouates": "ouate",
    "ouateuse": "ouateux",
    "ouatiné": "ouatiner",
    "ouatinée": "ouatiner",
    "ouatinées": "ouatiner",
    "ouaté": "ouater",
    "ouatée": "ouater",
    "ouatées": "ouater",
    "ouatés": "ouater",
    "oublia": "oublier",
    "oubliai": "oublier",
    "oubliaient": "oublier",
    "oubliais": "oublier",
    "oubliait": "oublier",
    "oubliant": "oublier",
    "oublias": "oublier",
    "oubliasse": "oublier",
    "oubliassent": "oublier",
    "oubliasses": "oublier",
    "oubliassiez": "oublier",
    "oubliassions": "oublier",
    "oublie": "oublier",
    "oublient": "oublier",
    "oubliera": "oublier",
    "oublierai": "oublier",
    "oublieraient": "oublier",
    "oublierais": "oublier",
    "oublierait": "oublier",
    "oublieras": "oublier",
    "oublierez": "oublier",
    "oublieriez": "oublier",
    "oublierions": "oublier",
    "oublierons": "oublier",
    "oublieront": "oublier",
    "oublies": "oublier",
    "oubliettes": "oubliette",
    "oublieuse": "oublieux",
    "oublieuses": "oublieux",
    "oubliez": "oublier",
    "oubliiez": "oublier",
    "oubliions": "oublier",
    "oublions": "oublier",
    "oublis": "oubli",
    "oubliâmes": "oublier",
    "oubliât": "oublier",
    "oubliâtes": "oublier",
    "oublièrent": "oublier",
    "oublié": "oublier",
    "oubliée": "oublier",
    "oubliées": "oublier",
    "oubliés": "oublier",
    "oueds": "oued",
    "ougandaise": "ougandais",
    "ougandaises": "ougandais",
    "ouighours": "ouighour",
    "ouille": "ouiller",
    "ouistitis": "ouistiti",
    "oukases": "oukase",
    "oulémas": "ouléma",
    "ouragans": "ouragan",
    "ouralienne": "ouralien",
    "ouraniennes": "ouranien",
    "ourdi": "ourdir",
    "ourdie": "ourdir",
    "ourdies": "ourdir",
    "ourdira": "ourdir",
    "ourdirai": "ourdir",
    "ourdiraient": "ourdir",
    "ourdirais": "ourdir",
    "ourdirait": "ourdir",
    "ourdiras": "ourdir",
    "ourdirent": "ourdir",
    "ourdirez": "ourdir",
    "ourdiriez": "ourdir",
    "ourdirions": "ourdir",
    "ourdirons": "ourdir",
    "ourdiront": "ourdir",
    "ourdis": "ourdir",
    "ourdissaient": "ourdir",
    "ourdissais": "ourdir",
    "ourdissait": "ourdir",
    "ourdissant": "ourdir",
    "ourdisse": "ourdir",
    "ourdissent": "ourdir",
    "ourdisses": "ourdir",
    "ourdisseurs": "ourdisseur",
    "ourdisseuses": "ourdisseur",
    "ourdissez": "ourdir",
    "ourdissiez": "ourdir",
    "ourdissions": "ourdir",
    "ourdissons": "ourdir",
    "ourdit": "ourdir",
    "ourdîmes": "ourdir",
    "ourdît": "ourdir",
    "ourdîtes": "ourdir",
    "ourla": "ourler",
    "ourlai": "ourler",
    "ourlaient": "ourler",
    "ourlais": "ourler",
    "ourlait": "ourler",
    "ourlant": "ourler",
    "ourlas": "ourler",
    "ourlasse": "ourler",
    "ourlassent": "ourler",
    "ourlasses": "ourler",
    "ourlassiez": "ourler",
    "ourlassions": "ourler",
    "ourle": "ourler",
    "ourlent": "ourler",
    "ourlera": "ourler",
    "ourlerai": "ourler",
    "ourleraient": "ourler",
    "ourlerais": "ourler",
    "ourlerait": "ourler",
    "ourleras": "ourler",
    "ourlerez": "ourler",
    "ourleriez": "ourler",
    "ourlerions": "ourler",
    "ourlerons": "ourler",
    "ourleront": "ourler",
    "ourles": "ourler",
    "ourlets": "ourlet",
    "ourlez": "ourler",
    "ourliez": "ourler",
    "ourlions": "ourler",
    "ourlons": "ourler",
    "ourlâmes": "ourler",
    "ourlât": "ourler",
    "ourlâtes": "ourler",
    "ourlèrent": "ourler",
    "ourlé": "ourler",
    "ourlée": "ourler",
    "ourlées": "ourler",
    "ourlés": "ourler",
    "ourse": "ours",
    "ourses": "ours",
    "oursins": "oursin",
    "oursonne": "ourson",
    "oursonnes": "ourson",
    "oursons": "ourson",
    "oustachis": "oustachi",
    "outardeaux": "outardeau",
    "outardes": "outarde",
    "outillages": "outillage",
    "outillé": "outiller",
    "outillée": "outillé",
    "outillées": "outiller",
    "outillés": "outiller",
    "outils": "outil",
    "outlaws": "outlaw",
    "outra": "outrer",
    "outrage": "outrager",
    "outrageant": "outrager",
    "outrageante": "outrageant",
    "outrageantes": "outrageant",
    "outrageants": "outrageant",
    "outragent": "outrager",
    "outragerais": "outrager",
    "outrages": "outrager",
    "outrageuse": "outrageux",
    "outrageuses": "outrageux",
    "outragez": "outrager",
    "outragèrent": "outrager",
    "outragé": "outrager",
    "outragée": "outrager",
    "outragées": "outrager",
    "outragés": "outrager",
    "outrai": "outrer",
    "outraient": "outrer",
    "outrais": "outrer",
    "outrait": "outrer",
    "outrances": "outrance",
    "outranciers": "outrancier",
    "outrancière": "outrancier",
    "outrancières": "outrancier",
    "outrant": "outrer",
    "outras": "outrer",
    "outrasse": "outrer",
    "outrassent": "outrer",
    "outrasses": "outrer",
    "outrassiez": "outrer",
    "outrassions": "outrer",
    "outre": "outrer",
    "outrecuidante": "outrecuidant",
    "outrecuidantes": "outrecuidant",
    "outrecuidants": "outrecuidant",
    "outremers": "outremer",
    "outrent": "outrer",
    "outrepassa": "outrepasser",
    "outrepassai": "outrepasser",
    "outrepassaient": "outrepasser",
    "outrepassais": "outrepasser",
    "outrepassait": "outrepasser",
    "outrepassant": "outrepasser",
    "outrepassas": "outrepasser",
    "outrepassasse": "outrepasser",
    "outrepassassent": "outrepasser",
    "outrepassasses": "outrepasser",
    "outrepassassiez": "outrepasser",
    "outrepassassions": "outrepasser",
    "outrepasse": "outrepasser",
    "outrepassent": "outrepasser",
    "outrepassera": "outrepasser",
    "outrepasserai": "outrepasser",
    "outrepasseraient": "outrepasser",
    "outrepasserais": "outrepasser",
    "outrepasserait": "outrepasser",
    "outrepasseras": "outrepasser",
    "outrepasserez": "outrepasser",
    "outrepasseriez": "outrepasser",
    "outrepasserions": "outrepasser",
    "outrepasserons": "outrepasser",
    "outrepasseront": "outrepasser",
    "outrepasses": "outrepasser",
    "outrepassez": "outrepasser",
    "outrepassiez": "outrepasser",
    "outrepassions": "outrepasser",
    "outrepassons": "outrepasser",
    "outrepassâmes": "outrepasser",
    "outrepassât": "outrepasser",
    "outrepassâtes": "outrepasser",
    "outrepassèrent": "outrepasser",
    "outrepassé": "outrepasser",
    "outrepassée": "outrepasser",
    "outrepassées": "outrepasser",
    "outrepassés": "outrepasser",
    "outrera": "outrer",
    "outrerai": "outrer",
    "outreraient": "outrer",
    "outrerais": "outrer",
    "outrerait": "outrer",
    "outreras": "outrer",
    "outrerez": "outrer",
    "outreriez": "outrer",
    "outrerions": "outrer",
    "outrerons": "outrer",
    "outreront": "outrer",
    "outres": "outrer",
    "outrez": "outrer",
    "outriez": "outrer",
    "outrions": "outrer",
    "outrons": "outrer",
    "outrâmes": "outrer",
    "outrât": "outrer",
    "outrâtes": "outrer",
    "outrèrent": "outrer",
    "outré": "outrer",
    "outrée": "outrer",
    "outrées": "outrer",
    "outrés": "outrer",
    "outsiders": "outsider",
    "ouvert": "ouvrir",
    "ouverte": "ouvrir",
    "ouvertes": "ouvrir",
    "ouverts": "ouvrir",
    "ouvertures": "ouverture",
    "ouvra": "ouvrer",
    "ouvrables": "ouvrable",
    "ouvrage": "ouvrager",
    "ouvrageant": "ouvrager",
    "ouvrages": "ouvrage",
    "ouvragé": "ouvrager",
    "ouvragée": "ouvrager",
    "ouvragées": "ouvrager",
    "ouvragés": "ouvragé",
    "ouvrai": "ouvrer",
    "ouvraient": "ouvrir",
    "ouvrais": "ouvrir",
    "ouvrait": "ouvrir",
    "ouvrant": "ouvrir",
    "ouvrante": "ouvrant",
    "ouvrantes": "ouvrant",
    "ouvrants": "ouvrant",
    "ouvras": "ouvrer",
    "ouvrasse": "ouvrer",
    "ouvrassent": "ouvrer",
    "ouvrasses": "ouvrer",
    "ouvrassiez": "ouvrer",
    "ouvrassions": "ouvrer",
    "ouvre": "ouvrir",
    "ouvre-bouteilles": "ouvre-bouteille",
    "ouvre-boîtes": "ouvre-boîte",
    "ouvre-huîtres": "ouvre-huître",
    "ouvrent": "ouvrir",
    "ouvrera": "ouvrer",
    "ouvrerai": "ouvrer",
    "ouvreraient": "ouvrer",
    "ouvrerais": "ouvrer",
    "ouvrerait": "ouvrer",
    "ouvreras": "ouvrer",
    "ouvrerez": "ouvrer",
    "ouvreriez": "ouvrer",
    "ouvrerions": "ouvrer",
    "ouvrerons": "ouvrer",
    "ouvreront": "ouvrer",
    "ouvres": "ouvrir",
    "ouvreurs": "ouvreur",
    "ouvreuse": "ouvreur",
    "ouvreuses": "ouvreur",
    "ouvrez": "ouvrir",
    "ouvriers": "ouvrier",
    "ouvriez": "ouvrir",
    "ouvrions": "ouvrir",
    "ouvrira": "ouvrir",
    "ouvrirai": "ouvrir",
    "ouvriraient": "ouvrir",
    "ouvrirais": "ouvrir",
    "ouvrirait": "ouvrir",
    "ouvriras": "ouvrir",
    "ouvrirent": "ouvrir",
    "ouvrirez": "ouvrir",
    "ouvririez": "ouvrir",
    "ouvririons": "ouvrir",
    "ouvrirons": "ouvrir",
    "ouvriront": "ouvrir",
    "ouvris": "ouvrir",
    "ouvrisse": "ouvrir",
    "ouvrissent": "ouvrir",
    "ouvrisses": "ouvrir",
    "ouvrissiez": "ouvrir",
    "ouvrissions": "ouvrir",
    "ouvrit": "ouvrir",
    "ouvrière": "ouvrier",
    "ouvrières": "ouvrier",
    "ouvriérismes": "ouvriérisme",
    "ouvroirs": "ouvroir",
    "ouvrons": "ouvrir",
    "ouvrâmes": "ouvrer",
    "ouvrât": "ouvrer",
    "ouvrâtes": "ouvrer",
    "ouvrèrent": "ouvrer",
    "ouvré": "ouvrer",
    "ouvrée": "ouvrer",
    "ouvrées": "ouvrer",
    "ouvrés": "ouvrer",
    "ouvrîmes": "ouvrir",
    "ouvrît": "ouvrir",
    "ouvrîtes": "ouvrir",
    "ouzbeks": "ouzbek",
    "ouzos": "ouzo",
    "ouï": "ouïr",
    "ouïe": "ouïr",
    "ouïes": "ouïr",
    "ouïmes": "ouïr",
    "ouïra": "ouïr",
    "ouïrai": "ouïr",
    "ouïraient": "ouïr",
    "ouïrais": "ouïr",
    "ouïrait": "ouïr",
    "ouïras": "ouïr",
    "ouïrent": "ouïr",
    "ouïrez": "ouïr",
    "ouïriez": "ouïr",
    "ouïrions": "ouïr",
    "ouïrons": "ouïr",
    "ouïront": "ouïr",
    "ouïs": "ouïr",
    "ouïsse": "ouïr",
    "ouïssent": "ouïr",
    "ouïsses": "ouïr",
    "ouïssiez": "ouïr",
    "ouïssions": "ouïr",
    "ouït": "ouïr",
    "ouïtes": "ouïr",
    "ovaires": "ovaire",
    "ovales": "ovale",
    "ovalisées": "ovaliser",
    "ovarienne": "ovarien",
    "ovationna": "ovationner",
    "ovationnai": "ovationner",
    "ovationnaient": "ovationner",
    "ovationnais": "ovationner",
    "ovationnait": "ovationner",
    "ovationnant": "ovationner",
    "ovationnas": "ovationner",
    "ovationnasse": "ovationner",
    "ovationnassent": "ovationner",
    "ovationnasses": "ovationner",
    "ovationnassiez": "ovationner",
    "ovationnassions": "ovationner",
    "ovationne": "ovationner",
    "ovationnent": "ovationner",
    "ovationnera": "ovationner",
    "ovationnerai": "ovationner",
    "ovationneraient": "ovationner",
    "ovationnerais": "ovationner",
    "ovationnerait": "ovationner",
    "ovationneras": "ovationner",
    "ovationnerez": "ovationner",
    "ovationneriez": "ovationner",
    "ovationnerions": "ovationner",
    "ovationnerons": "ovationner",
    "ovationneront": "ovationner",
    "ovationnes": "ovationner",
    "ovationnez": "ovationner",
    "ovationniez": "ovationner",
    "ovationnions": "ovationner",
    "ovationnons": "ovationner",
    "ovationnâmes": "ovationner",
    "ovationnât": "ovationner",
    "ovationnâtes": "ovationner",
    "ovationnèrent": "ovationner",
    "ovationné": "ovationner",
    "ovationnée": "ovationner",
    "ovationnées": "ovationner",
    "ovationnés": "ovationner",
    "ovations": "ovation",
    "overdoses": "overdose",
    "oves": "ove",
    "ovine": "ovin",
    "ovines": "ovin",
    "ovins": "ovin",
    "ovipares": "ovipare",
    "ovnis": "ovni",
    "ovocytes": "ovocyte",
    "ovovivipares": "ovovivipare",
    "ovoïdale": "ovoïdal",
    "ovoïdes": "ovoïde",
    "ovule": "ovuler",
    "ovules": "ovuler",
    "ovée": "ové",
    "oxfordiennes": "oxfordien",
    "oxfords": "oxford",
    "oxhydriques": "oxhydrique",
    "oxonienne": "oxonien",
    "oxyda": "oxyder",
    "oxydai": "oxyder",
    "oxydaient": "oxyder",
    "oxydais": "oxyder",
    "oxydait": "oxyder",
    "oxydant": "oxyder",
    "oxydants": "oxydant",
    "oxydas": "oxyder",
    "oxydasse": "oxyder",
    "oxydassent": "oxyder",
    "oxydasses": "oxyder",
    "oxydassiez": "oxyder",
    "oxydassions": "oxyder",
    "oxyde": "oxyder",
    "oxydent": "oxyder",
    "oxydera": "oxyder",
    "oxyderai": "oxyder",
    "oxyderaient": "oxyder",
    "oxyderais": "oxyder",
    "oxyderait": "oxyder",
    "oxyderas": "oxyder",
    "oxyderez": "oxyder",
    "oxyderiez": "oxyder",
    "oxyderions": "oxyder",
    "oxyderons": "oxyder",
    "oxyderont": "oxyder",
    "oxydes": "oxyder",
    "oxydez": "oxyder",
    "oxydiez": "oxyder",
    "oxydions": "oxyder",
    "oxydons": "oxyder",
    "oxydâmes": "oxyder",
    "oxydât": "oxyder",
    "oxydâtes": "oxyder",
    "oxydèrent": "oxyder",
    "oxydé": "oxyder",
    "oxydée": "oxyder",
    "oxydées": "oxyder",
    "oxydés": "oxyder",
    "oxygène": "oxygéner",
    "oxygènent": "oxygéner",
    "oxygènes": "oxygéner",
    "oxygéna": "oxygéner",
    "oxygénai": "oxygéner",
    "oxygénaient": "oxygéner",
    "oxygénais": "oxygéner",
    "oxygénait": "oxygéner",
    "oxygénant": "oxygéner",
    "oxygénas": "oxygéner",
    "oxygénasse": "oxygéner",
    "oxygénassent": "oxygéner",
    "oxygénasses": "oxygéner",
    "oxygénassiez": "oxygéner",
    "oxygénassions": "oxygéner",
    "oxygénations": "oxygénation",
    "oxygénera": "oxygéner",
    "oxygénerai": "oxygéner",
    "oxygéneraient": "oxygéner",
    "oxygénerais": "oxygéner",
    "oxygénerait": "oxygéner",
    "oxygéneras": "oxygéner",
    "oxygénerez": "oxygéner",
    "oxygéneriez": "oxygéner",
    "oxygénerions": "oxygéner",
    "oxygénerons": "oxygéner",
    "oxygéneront": "oxygéner",
    "oxygénez": "oxygéner",
    "oxygéniez": "oxygéner",
    "oxygénions": "oxygéner",
    "oxygénons": "oxygéner",
    "oxygénâmes": "oxygéner",
    "oxygénât": "oxygéner",
    "oxygénâtes": "oxygéner",
    "oxygénèrent": "oxygéner",
    "oxygéné": "oxygéner",
    "oxygénée": "oxygéner",
    "oxygénées": "oxygéner",
    "oxygénés": "oxygéner",
    "oxymores": "oxymore",
    "oxytons": "oxyton",
    "oxyures": "oxyure",
    "oyaient": "ouïr",
    "oyais": "ouïr",
    "oyait": "ouïr",
    "oyant": "ouïr",
    "oyats": "oyat",
    "oyez": "ouïr",
    "oyiez": "ouïr",
    "oyions": "ouïr",
    "oyons": "ouïr",
    "ozones": "ozone",
    "pacages": "pacage",
    "pacas": "paca",
    "pacemakers": "pacemaker",
    "pachas": "pacha",
    "pachydermes": "pachyderme",
    "pachydermiques": "pachydermique",
    "pacifia": "pacifier",
    "pacifiai": "pacifier",
    "pacifiaient": "pacifier",
    "pacifiais": "pacifier",
    "pacifiait": "pacifier",
    "pacifiant": "pacifier",
    "pacifiante": "pacifiant",
    "pacifiantes": "pacifiant",
    "pacifias": "pacifier",
    "pacifiasse": "pacifier",
    "pacifiassent": "pacifier",
    "pacifiasses": "pacifier",
    "pacifiassiez": "pacifier",
    "pacifiassions": "pacifier",
    "pacificateurs": "pacificateur",
    "pacifications": "pacification",
    "pacificatrice": "pacificateur",
    "pacifie": "pacifier",
    "pacifient": "pacifier",
    "pacifiera": "pacifier",
    "pacifierai": "pacifier",
    "pacifieraient": "pacifier",
    "pacifierais": "pacifier",
    "pacifierait": "pacifier",
    "pacifieras": "pacifier",
    "pacifierez": "pacifier",
    "pacifieriez": "pacifier",
    "pacifierions": "pacifier",
    "pacifierons": "pacifier",
    "pacifieront": "pacifier",
    "pacifies": "pacifier",
    "pacifiez": "pacifier",
    "pacifiiez": "pacifier",
    "pacifiions": "pacifier",
    "pacifions": "pacifier",
    "pacifiques": "pacifique",
    "pacifismes": "pacifisme",
    "pacifistes": "pacifiste",
    "pacifiâmes": "pacifier",
    "pacifiât": "pacifier",
    "pacifiâtes": "pacifier",
    "pacifièrent": "pacifier",
    "pacifié": "pacifier",
    "pacifiée": "pacifier",
    "pacifiées": "pacifier",
    "pacifiés": "pacifier",
    "packs": "pack",
    "pacotilles": "pacotille",
    "pacsifs": "pacsif",
    "pacsons": "pacson",
    "pacsés": "pacser",
    "pactes": "pacte",
    "pactisa": "pactiser",
    "pactisai": "pactiser",
    "pactisaient": "pactiser",
    "pactisais": "pactiser",
    "pactisait": "pactiser",
    "pactisant": "pactiser",
    "pactisas": "pactiser",
    "pactisasse": "pactiser",
    "pactisassent": "pactiser",
    "pactisasses": "pactiser",
    "pactisassiez": "pactiser",
    "pactisassions": "pactiser",
    "pactise": "pactiser",
    "pactisent": "pactiser",
    "pactisera": "pactiser",
    "pactiserai": "pactiser",
    "pactiseraient": "pactiser",
    "pactiserais": "pactiser",
    "pactiserait": "pactiser",
    "pactiseras": "pactiser",
    "pactiserez": "pactiser",
    "pactiseriez": "pactiser",
    "pactiserions": "pactiser",
    "pactiserons": "pactiser",
    "pactiseront": "pactiser",
    "pactises": "pactiser",
    "pactiseurs": "pactiseur",
    "pactisez": "pactiser",
    "pactisiez": "pactiser",
    "pactisions": "pactiser",
    "pactisons": "pactiser",
    "pactisâmes": "pactiser",
    "pactisât": "pactiser",
    "pactisâtes": "pactiser",
    "pactisèrent": "pactiser",
    "pactisé": "pactiser",
    "pactoles": "pactole",
    "paddocks": "paddock",
    "paddys": "paddy",
    "padouanes": "padouan",
    "paellas": "paella",
    "pagaie": "pagayer",
    "pagaient": "pagayer",
    "pagaiera": "pagayer",
    "pagaierai": "pagayer",
    "pagaieraient": "pagayer",
    "pagaierais": "pagayer",
    "pagaierait": "pagayer",
    "pagaieras": "pagayer",
    "pagaierez": "pagayer",
    "pagaieriez": "pagayer",
    "pagaierions": "pagayer",
    "pagaierons": "pagayer",
    "pagaieront": "pagayer",
    "pagaies": "pagayer",
    "pagailles": "pagaille",
    "paganismes": "paganisme",
    "pagaya": "pagayer",
    "pagayai": "pagayer",
    "pagayaient": "pagayer",
    "pagayais": "pagayer",
    "pagayait": "pagayer",
    "pagayant": "pagayer",
    "pagayas": "pagayer",
    "pagayasse": "pagayer",
    "pagayassent": "pagayer",
    "pagayasses": "pagayer",
    "pagayassiez": "pagayer",
    "pagayassions": "pagayer",
    "pagaye": "pagayer",
    "pagayent": "pagayer",
    "pagayera": "pagayer",
    "pagayerai": "pagayer",
    "pagayeraient": "pagayer",
    "pagayerais": "pagayer",
    "pagayerait": "pagayer",
    "pagayeras": "pagayer",
    "pagayerez": "pagayer",
    "pagayeriez": "pagayer",
    "pagayerions": "pagayer",
    "pagayerons": "pagayer",
    "pagayeront": "pagayer",
    "pagayes": "pagayer",
    "pagayeurs": "pagayeur",
    "pagayez": "pagayer",
    "pagayiez": "pagayer",
    "pagayions": "pagayer",
    "pagayons": "pagayer",
    "pagayâmes": "pagayer",
    "pagayât": "pagayer",
    "pagayâtes": "pagayer",
    "pagayèrent": "pagayer",
    "pagayé": "pagayer",
    "pagaïes": "pagaïe",
    "pageais": "pager",
    "pageait": "pager",
    "pageant": "pager",
    "pagels": "pagel",
    "pageots": "pageot",
    "pages": "page",
    "pagina": "paginer",
    "paginai": "paginer",
    "paginaient": "paginer",
    "paginais": "paginer",
    "paginait": "paginer",
    "paginant": "paginer",
    "paginas": "paginer",
    "paginasse": "paginer",
    "paginassent": "paginer",
    "paginasses": "paginer",
    "paginassiez": "paginer",
    "paginassions": "paginer",
    "pagine": "paginer",
    "paginent": "paginer",
    "paginera": "paginer",
    "paginerai": "paginer",
    "pagineraient": "paginer",
    "paginerais": "paginer",
    "paginerait": "paginer",
    "pagineras": "paginer",
    "paginerez": "paginer",
    "pagineriez": "paginer",
    "paginerions": "paginer",
    "paginerons": "paginer",
    "pagineront": "paginer",
    "pagines": "paginer",
    "paginez": "paginer",
    "paginiez": "paginer",
    "paginions": "paginer",
    "paginons": "paginer",
    "paginâmes": "paginer",
    "paginât": "paginer",
    "paginâtes": "paginer",
    "paginèrent": "paginer",
    "paginé": "paginer",
    "paginée": "paginer",
    "paginées": "paginer",
    "paginés": "paginer",
    "pagnes": "pagne",
    "pagnote": "pagnoter",
    "pagodes": "pagode",
    "pagures": "pagure",
    "pagé": "pager",
    "pagée": "pager",
    "pagés": "pager",
    "paie": "payer",
    "paiements": "paiement",
    "paient": "payer",
    "paiera": "payer",
    "paierai": "payer",
    "paieraient": "payer",
    "paierais": "payer",
    "paierait": "payer",
    "paieras": "payer",
    "paierez": "payer",
    "paieries": "paierie",
    "paieriez": "payer",
    "paierions": "payer",
    "paierons": "payer",
    "paieront": "payer",
    "paies": "payer",
    "paillardait": "paillarder",
    "paillarde": "paillard",
    "paillardes": "paillard",
    "paillards": "paillard",
    "paillasses": "paillasse",
    "paillassons": "paillasson",
    "pailles": "paille",
    "pailles-en-queue": "paille-en-queue",
    "pailleta": "pailleter",
    "pailletai": "pailleter",
    "pailletaient": "pailleter",
    "pailletais": "pailleter",
    "pailletait": "pailleter",
    "pailletant": "pailleter",
    "pailletas": "pailleter",
    "pailletasse": "pailleter",
    "pailletassent": "pailleter",
    "pailletasses": "pailleter",
    "pailletassiez": "pailleter",
    "pailletassions": "pailleter",
    "pailletez": "pailleter",
    "pailletiez": "pailleter",
    "pailletions": "pailleter",
    "pailletons": "pailleter",
    "paillets": "paillet",
    "paillette": "pailleter",
    "paillettent": "pailleter",
    "paillettera": "pailleter",
    "pailletterai": "pailleter",
    "pailletteraient": "pailleter",
    "pailletterais": "pailleter",
    "pailletterait": "pailleter",
    "pailletteras": "pailleter",
    "pailletterez": "pailleter",
    "pailletteriez": "pailleter",
    "pailletterions": "pailleter",
    "pailletterons": "pailleter",
    "pailletteront": "pailleter",
    "paillettes": "paillette",
    "pailletâmes": "pailleter",
    "pailletât": "pailleter",
    "pailletâtes": "pailleter",
    "pailletèrent": "pailleter",
    "pailleté": "pailleter",
    "pailletée": "pailleter",
    "pailletées": "pailleter",
    "pailletés": "pailleter",
    "paillons": "paillon",
    "paillotes": "paillote",
    "paillottes": "paillotte",
    "paillée": "pailler",
    "paillées": "pailler",
    "paimpolaise": "paimpolais",
    "paimpolaises": "paimpolais",
    "pains": "pain",
    "paire": "pair",
    "paires": "paire",
    "pairesse": "pair",
    "pairesses": "pairesse",
    "pairies": "pairie",
    "pairs": "pair",
    "pais": "paître",
    "paisibles": "paisible",
    "paissaient": "paître",
    "paissais": "paître",
    "paissait": "paître",
    "paissances": "paissance",
    "paissant": "paître",
    "paisse": "paître",
    "paisseaux": "paisseau",
    "paissent": "paître",
    "paisses": "paître",
    "paissez": "paître",
    "paissiez": "paître",
    "paissions": "paître",
    "paissons": "paître",
    "paiutes": "paiute",
    "pakistanais": "pakistanien",
    "pakistanaise": "pakistanien",
    "pakistanaises": "pakistanien",
    "palabra": "palabrer",
    "palabraient": "palabrer",
    "palabrait": "palabrer",
    "palabrant": "palabrer",
    "palabre": "palabrer",
    "palabrent": "palabrer",
    "palabres": "palabre",
    "palabreurs": "palabreur",
    "palabré": "palabrer",
    "palaces": "palace",
    "paladins": "paladin",
    "palanches": "palanche",
    "palangriers": "palangrier",
    "palangrière": "palangrier",
    "palangrières": "palangrier",
    "palanques": "palanque",
    "palanquins": "palanquin",
    "palanquée": "palanquer",
    "palanquées": "palanquer",
    "palans": "palan",
    "palatale": "palatal",
    "palatales": "palatal",
    "palataux": "palatal",
    "palatiale": "palatial",
    "palatiales": "palatial",
    "palatiaux": "palatial",
    "palatine": "palatin",
    "palatines": "palatine",
    "palatins": "palatin",
    "pale-ales": "pale-ale",
    "palefreniers": "palefrenier",
    "palefrenière": "palefrenier",
    "palefrois": "palefroi",
    "palerons": "paleron",
    "pales": "pale",
    "palestinienne": "palestinien",
    "palestiniens": "palestinien",
    "palestres": "palestre",
    "paletots": "paletot",
    "palets": "palet",
    "palettes": "palette",
    "palie": "pali",
    "paliers": "palier",
    "palies": "pali",
    "palikares": "palikare",
    "palimpsestes": "palimpseste",
    "palindromes": "palindrome",
    "palingénésies": "palingénésie",
    "palinodies": "palinodie",
    "palis": "pali",
    "palissa": "palisser",
    "palissades": "palissade",
    "palissadé": "palissader",
    "palissadée": "palissader",
    "palissadés": "palissader",
    "palissai": "palisser",
    "palissaient": "palisser",
    "palissais": "palisser",
    "palissait": "palisser",
    "palissandres": "palissandre",
    "palissant": "palisser",
    "palissas": "palisser",
    "palissasse": "palisser",
    "palissassent": "palisser",
    "palissasses": "palisser",
    "palissassiez": "palisser",
    "palissassions": "palisser",
    "palisse": "palisser",
    "palissent": "palisser",
    "palissera": "palisser",
    "palisserai": "palisser",
    "palisseraient": "palisser",
    "palisserais": "palisser",
    "palisserait": "palisser",
    "palisseras": "palisser",
    "palisserez": "palisser",
    "palisseriez": "palisser",
    "palisserions": "palisser",
    "palisserons": "palisser",
    "palisseront": "palisser",
    "palisses": "palisser",
    "palissez": "palisser",
    "palissiez": "palisser",
    "palissions": "palisser",
    "palissons": "palisson",
    "palissâmes": "palisser",
    "palissât": "palisser",
    "palissâtes": "palisser",
    "palissèrent": "palisser",
    "palissé": "palisser",
    "palissée": "palisser",
    "palissées": "palisser",
    "palissés": "palisser",
    "palière": "palier",
    "palladianismes": "palladianisme",
    "palladiennes": "palladien",
    "palladiums": "palladium",
    "pallia": "pallier",
    "palliai": "pallier",
    "palliaient": "pallier",
    "palliais": "pallier",
    "palliait": "pallier",
    "palliant": "pallier",
    "pallias": "pallier",
    "palliasse": "pallier",
    "palliassent": "pallier",
    "palliasses": "pallier",
    "palliassiez": "pallier",
    "palliassions": "pallier",
    "palliatifs": "palliatif",
    "pallie": "pallier",
    "pallient": "pallier",
    "palliera": "pallier",
    "pallierai": "pallier",
    "pallieraient": "pallier",
    "pallierais": "pallier",
    "pallierait": "pallier",
    "pallieras": "pallier",
    "pallierez": "pallier",
    "pallieriez": "pallier",
    "pallierions": "pallier",
    "pallierons": "pallier",
    "pallieront": "pallier",
    "pallies": "pallier",
    "palliez": "pallier",
    "palliiez": "pallier",
    "palliions": "pallier",
    "pallions": "pallier",
    "palliums": "pallium",
    "palliâmes": "pallier",
    "palliât": "pallier",
    "palliâtes": "pallier",
    "pallièrent": "pallier",
    "pallié": "pallier",
    "palliée": "pallier",
    "palliées": "pallier",
    "palliés": "pallier",
    "palléale": "palléal",
    "palléales": "palléal",
    "palléaux": "palléal",
    "palmaient": "palmer",
    "palmaires": "palmaire",
    "palmas": "palma",
    "palmeraies": "palmeraie",
    "palmers": "palmer",
    "palmes": "palme",
    "palmettes": "palmette",
    "palmiers": "palmier",
    "palmipèdes": "palmipède",
    "palmistes": "palmiste",
    "palmures": "palmure",
    "palmé": "palmer",
    "palmée": "palmé",
    "palmées": "palmer",
    "palmés": "palmer",
    "palombes": "palombe",
    "palonniers": "palonnier",
    "palots": "palot",
    "palourdes": "palourde",
    "palpa": "palper",
    "palpables": "palpable",
    "palpai": "palper",
    "palpaient": "palper",
    "palpais": "palper",
    "palpait": "palper",
    "palpant": "palper",
    "palpas": "palper",
    "palpasse": "palper",
    "palpassent": "palper",
    "palpasses": "palper",
    "palpassiez": "palper",
    "palpassions": "palper",
    "palpations": "palpation",
    "palpe": "palper",
    "palpent": "palper",
    "palpera": "palper",
    "palperai": "palper",
    "palperaient": "palper",
    "palperais": "palper",
    "palperait": "palper",
    "palperas": "palper",
    "palperez": "palper",
    "palperiez": "palper",
    "palperions": "palper",
    "palperons": "palper",
    "palperont": "palper",
    "palpes": "palper",
    "palpeurs": "palpeur",
    "palpez": "palper",
    "palpiez": "palper",
    "palpions": "palper",
    "palpita": "palpiter",
    "palpitai": "palpiter",
    "palpitaient": "palpiter",
    "palpitais": "palpiter",
    "palpitait": "palpiter",
    "palpitant": "palpiter",
    "palpitante": "palpitant",
    "palpitantes": "palpitant",
    "palpitants": "palpitant",
    "palpitas": "palpiter",
    "palpitasse": "palpiter",
    "palpitassent": "palpiter",
    "palpitasses": "palpiter",
    "palpitassiez": "palpiter",
    "palpitassions": "palpiter",
    "palpitations": "palpitation",
    "palpite": "palpiter",
    "palpitent": "palpiter",
    "palpitera": "palpiter",
    "palpiterai": "palpiter",
    "palpiteraient": "palpiter",
    "palpiterais": "palpiter",
    "palpiterait": "palpiter",
    "palpiteras": "palpiter",
    "palpiterez": "palpiter",
    "palpiteriez": "palpiter",
    "palpiterions": "palpiter",
    "palpiterons": "palpiter",
    "palpiteront": "palpiter",
    "palpites": "palpiter",
    "palpitez": "palpiter",
    "palpitiez": "palpiter",
    "palpitions": "palpiter",
    "palpitons": "palpiter",
    "palpitâmes": "palpiter",
    "palpitât": "palpiter",
    "palpitâtes": "palpiter",
    "palpitèrent": "palpiter",
    "palpité": "palpiter",
    "palpons": "palper",
    "palpâmes": "palper",
    "palpât": "palper",
    "palpâtes": "palper",
    "palpèrent": "palper",
    "palpé": "palper",
    "palpébrale": "palpébral",
    "palpébrales": "palpébral",
    "palpébraux": "palpébral",
    "palpée": "palper",
    "palpées": "palper",
    "palpés": "palper",
    "pals": "pal",
    "paltoquets": "paltoquet",
    "paluchait": "palucher",
    "paluches": "paluche",
    "paludes": "palude",
    "paludiers": "paludier",
    "paludiques": "paludique",
    "paludismes": "paludisme",
    "paludéenne": "paludéen",
    "paludéennes": "paludéen",
    "paludéens": "paludéen",
    "palustres": "palustre",
    "paléographies": "paléographie",
    "paléolithiques": "paléolithique",
    "paléontologies": "paléontologie",
    "paléontologiques": "paléontologique",
    "paléontologistes": "paléontologiste",
    "paléontologues": "paléontologue",
    "palétuviers": "palétuvier",
    "pampas": "pampa",
    "pamphlets": "pamphlet",
    "pamphlétaires": "pamphlétaire",
    "pamplemousses": "pamplemousse",
    "pamplemoussiers": "pamplemoussier",
    "pampres": "pampre",
    "pana": "paner",
    "panacha": "panacher",
    "panachai": "panacher",
    "panachaient": "panacher",
    "panachais": "panacher",
    "panachait": "panacher",
    "panachant": "panacher",
    "panachas": "panacher",
    "panachasse": "panacher",
    "panachassent": "panacher",
    "panachasses": "panacher",
    "panachassiez": "panacher",
    "panachassions": "panacher",
    "panache": "panacher",
    "panachent": "panacher",
    "panachera": "panacher",
    "panacherai": "panacher",
    "panacheraient": "panacher",
    "panacherais": "panacher",
    "panacherait": "panacher",
    "panacheras": "panacher",
    "panacherez": "panacher",
    "panacheriez": "panacher",
    "panacherions": "panacher",
    "panacherons": "panacher",
    "panacheront": "panacher",
    "panaches": "panacher",
    "panachez": "panacher",
    "panachiez": "panacher",
    "panachions": "panacher",
    "panachons": "panacher",
    "panachâmes": "panacher",
    "panachât": "panacher",
    "panachâtes": "panacher",
    "panachèrent": "panacher",
    "panaché": "panacher",
    "panachée": "panacher",
    "panachées": "panacher",
    "panachés": "panacher",
    "panacées": "panacée",
    "panades": "panade",
    "panafricaine": "panafricain",
    "panafricaines": "panafricain",
    "panafricains": "panafricain",
    "panai": "paner",
    "panaient": "paner",
    "panais": "paner",
    "panait": "paner",
    "panamas": "panama",
    "panamienne": "panamien",
    "panamiens": "panamien",
    "panaméenne": "panaméen",
    "panaméennes": "panaméen",
    "panaméens": "panaméen",
    "panaméricaine": "panaméricain",
    "panaméricaines": "panaméricain",
    "panaméricains": "panaméricain",
    "panant": "paner",
    "panarabismes": "panarabisme",
    "panarde": "panard",
    "panardes": "panard",
    "panards": "panard",
    "panas": "paner",
    "panasse": "paner",
    "panassent": "paner",
    "panasses": "paner",
    "panassiez": "paner",
    "panassions": "paner",
    "pancakes": "pancake",
    "pancartes": "pancarte",
    "panchen-lamas": "panchen-lama",
    "panchromatiques": "panchromatique",
    "pancraces": "pancrace",
    "pancréatiques": "pancréatique",
    "pandas": "panda",
    "pandores": "pandore",
    "pandémies": "pandémie",
    "pandémoniums": "pandémonium",
    "pane": "paner",
    "panels": "panel",
    "panent": "paner",
    "panera": "paner",
    "panerai": "paner",
    "paneraient": "paner",
    "panerais": "paner",
    "panerait": "paner",
    "paneras": "paner",
    "panerez": "paner",
    "paneriez": "paner",
    "panerions": "paner",
    "panerons": "paner",
    "paneront": "paner",
    "panes": "paner",
    "panetière": "panetier",
    "panetières": "panetier",
    "panetons": "paneton",
    "paneuropéenne": "paneuropéen",
    "paneuropéennes": "paneuropéen",
    "paneuropéens": "paneuropéen",
    "panez": "paner",
    "pangermanismes": "pangermanisme",
    "pangolins": "pangolin",
    "panhelléniques": "panhellénique",
    "panhellénismes": "panhellénisme",
    "panicauts": "panicaut",
    "panicules": "panicule",
    "paniers": "panier",
    "paniez": "paner",
    "panifiables": "panifiable",
    "panifications": "panification",
    "panions": "paner",
    "paniqua": "paniquer",
    "paniquai": "paniquer",
    "paniquaient": "paniquer",
    "paniquais": "paniquer",
    "paniquait": "paniquer",
    "paniquant": "paniquer",
    "paniquards": "paniquard",
    "paniquas": "paniquer",
    "paniquasse": "paniquer",
    "paniquassent": "paniquer",
    "paniquasses": "paniquer",
    "paniquassiez": "paniquer",
    "paniquassions": "paniquer",
    "panique": "paniquer",
    "paniquent": "paniquer",
    "paniquera": "paniquer",
    "paniquerai": "paniquer",
    "paniqueraient": "paniquer",
    "paniquerais": "paniquer",
    "paniquerait": "paniquer",
    "paniqueras": "paniquer",
    "paniquerez": "paniquer",
    "paniqueriez": "paniquer",
    "paniquerions": "paniquer",
    "paniquerons": "paniquer",
    "paniqueront": "paniquer",
    "paniques": "paniquer",
    "paniquez": "paniquer",
    "paniquiez": "paniquer",
    "paniquions": "paniquer",
    "paniquons": "paniquer",
    "paniquâmes": "paniquer",
    "paniquât": "paniquer",
    "paniquâtes": "paniquer",
    "paniquèrent": "paniquer",
    "paniqué": "paniquer",
    "paniquée": "paniquer",
    "paniquées": "paniquer",
    "paniqués": "paniquer",
    "panislamiques": "panislamique",
    "panières": "panière",
    "pankas": "panka",
    "panna": "panner",
    "pannais": "panner",
    "pannait": "panner",
    "panneaux": "panneau",
    "panneaux-façades": "panneau-façade",
    "pannes": "panne",
    "pannetons": "panneton",
    "panné": "panner",
    "panonceaux": "panonceau",
    "panons": "paner",
    "panoplies": "panoplie",
    "panoramas": "panorama",
    "panoramiques": "panoramique",
    "panoramiqué": "panoramiquer",
    "panos": "pano",
    "panouilles": "panouille",
    "pans": "pan",
    "pans-bagnats": "pan-bagnat",
    "pansa": "panser",
    "pansai": "panser",
    "pansaient": "panser",
    "pansais": "panser",
    "pansait": "panser",
    "pansant": "panser",
    "pansas": "panser",
    "pansasse": "panser",
    "pansassent": "panser",
    "pansasses": "panser",
    "pansassiez": "panser",
    "pansassions": "panser",
    "panse": "panser",
    "pansements": "pansement",
    "pansent": "panser",
    "pansera": "panser",
    "panserai": "panser",
    "panseraient": "panser",
    "panserais": "panser",
    "panserait": "panser",
    "panseras": "panser",
    "panserez": "panser",
    "panseriez": "panser",
    "panserions": "panser",
    "panserons": "panser",
    "panseront": "panser",
    "panses": "panser",
    "pansez": "panser",
    "pansiez": "panser",
    "pansions": "panser",
    "panslaves": "panslave",
    "pansons": "panser",
    "pansue": "pansu",
    "pansues": "pansu",
    "pansus": "pansu",
    "pansâmes": "panser",
    "pansât": "panser",
    "pansâtes": "panser",
    "pansèrent": "panser",
    "pansé": "panser",
    "pansée": "panser",
    "pansées": "panser",
    "pansés": "panser",
    "pantagruéliques": "pantagruélique",
    "pantalonnades": "pantalonnade",
    "pantalons": "pantalon",
    "pantela": "panteler",
    "pantelaient": "panteler",
    "pantelait": "panteler",
    "pantelant": "panteler",
    "pantelante": "pantelant",
    "pantelantes": "pantelant",
    "pantelants": "pantelant",
    "pantelle": "panteler",
    "pantelé": "panteler",
    "pantes": "pante",
    "panthères": "panthère",
    "panthéismes": "panthéisme",
    "panthéistes": "panthéiste",
    "panthéons": "panthéon",
    "pantins": "pantin",
    "pantières": "pantière",
    "pantographes": "pantographe",
    "pantoise": "pantois",
    "pantoises": "pantois",
    "pantomimes": "pantomime",
    "pantomètres": "pantomètre",
    "pantouflarde": "pantouflard",
    "pantouflards": "pantouflard",
    "pantoufle": "pantoufler",
    "pantoufles": "pantoufler",
    "pantoums": "pantoum",
    "panturquismes": "panturquisme",
    "panzers": "panzer",
    "panâmes": "paner",
    "panât": "paner",
    "panâtes": "paner",
    "panèrent": "paner",
    "pané": "paner",
    "panée": "paner",
    "panées": "paner",
    "panégyriques": "panégyrique",
    "panégyristes": "panégyriste",
    "panés": "paner",
    "paolistes": "paoliste",
    "paonne": "paon",
    "paonnes": "paon",
    "paons": "paon",
    "papale": "papal",
    "papales": "papal",
    "paparazzis": "paparazzi",
    "papas": "papa",
    "papaux": "papal",
    "papayers": "papayer",
    "papayes": "papaye",
    "papegais": "papegai",
    "papelarde": "papelard",
    "papelardes": "papelard",
    "papelards": "papelard",
    "paperasseries": "paperasserie",
    "paperasses": "paperasse",
    "papes": "pape",
    "papesse": "pape",
    "papesses": "pape",
    "papeteries": "papeterie",
    "papetiers": "papetier",
    "papetière": "papetier",
    "papetières": "papetier",
    "papiers": "papier",
    "papiers-calque": "papier-calque",
    "papiers-filtres": "papier-filtre",
    "papiers-monnaies": "papier-monnaie",
    "papiers-émeri": "papier-émeri",
    "papilionacée": "papilionacé",
    "papilionacées": "papilionacé",
    "papilles": "papille",
    "papillomes": "papillome",
    "papillonna": "papillonner",
    "papillonnaient": "papillonner",
    "papillonnais": "papillonner",
    "papillonnait": "papillonner",
    "papillonnante": "papillonnant",
    "papillonne": "papillonner",
    "papillonnent": "papillonner",
    "papillonnes": "papillonner",
    "papillonné": "papillonner",
    "papillons": "papillon",
    "papillota": "papilloter",
    "papillotai": "papilloter",
    "papillotaient": "papilloter",
    "papillotais": "papilloter",
    "papillotait": "papilloter",
    "papillotant": "papilloter",
    "papillotantes": "papillotant",
    "papillotants": "papillotant",
    "papillotas": "papilloter",
    "papillotasse": "papilloter",
    "papillotassent": "papilloter",
    "papillotasses": "papilloter",
    "papillotassiez": "papilloter",
    "papillotassions": "papilloter",
    "papillote": "papilloter",
    "papillotent": "papilloter",
    "papillotera": "papilloter",
    "papilloterai": "papilloter",
    "papilloteraient": "papilloter",
    "papilloterais": "papilloter",
    "papilloterait": "papilloter",
    "papilloteras": "papilloter",
    "papilloterez": "papilloter",
    "papilloteriez": "papilloter",
    "papilloterions": "papilloter",
    "papilloterons": "papilloter",
    "papilloteront": "papilloter",
    "papillotes": "papilloter",
    "papillotez": "papilloter",
    "papillotiez": "papilloter",
    "papillotions": "papilloter",
    "papillotons": "papilloter",
    "papillotâmes": "papilloter",
    "papillotât": "papilloter",
    "papillotâtes": "papilloter",
    "papillotèrent": "papilloter",
    "papilloté": "papilloter",
    "papis": "papi",
    "papistes": "papiste",
    "papota": "papoter",
    "papotages": "papotage",
    "papotai": "papoter",
    "papotaient": "papoter",
    "papotais": "papoter",
    "papotait": "papoter",
    "papotant": "papoter",
    "papotas": "papoter",
    "papotasse": "papoter",
    "papotassent": "papoter",
    "papotasses": "papoter",
    "papotassiez": "papoter",
    "papotassions": "papoter",
    "papote": "papoter",
    "papotent": "papoter",
    "papotera": "papoter",
    "papoterai": "papoter",
    "papoteraient": "papoter",
    "papoterais": "papoter",
    "papoterait": "papoter",
    "papoteras": "papoter",
    "papoterez": "papoter",
    "papoteriez": "papoter",
    "papoterions": "papoter",
    "papoterons": "papoter",
    "papoteront": "papoter",
    "papotes": "papoter",
    "papotez": "papoter",
    "papotiez": "papoter",
    "papotions": "papoter",
    "papotons": "papoter",
    "papotâmes": "papoter",
    "papotât": "papoter",
    "papotâtes": "papoter",
    "papotèrent": "papoter",
    "papoté": "papoter",
    "papoue": "papou",
    "papoues": "papou",
    "papouillent": "papouiller",
    "papouilles": "papouille",
    "papouillez": "papouiller",
    "papouillé": "papouiller",
    "papous": "papou",
    "paprikas": "paprika",
    "papules": "papule",
    "papys": "papy",
    "paquebots": "paquebot",
    "paqueta": "paqueter",
    "paquetages": "paquetage",
    "paquets": "paquet",
    "paquette": "paqueter",
    "para": "parer",
    "para-militaires": "para-militaire",
    "parabellums": "parabellum",
    "paraboles": "parabole",
    "paraboliques": "parabolique",
    "paracheva": "parachever",
    "parachevai": "parachever",
    "parachevaient": "parachever",
    "parachevais": "parachever",
    "parachevait": "parachever",
    "parachevant": "parachever",
    "parachevas": "parachever",
    "parachevasse": "parachever",
    "parachevassent": "parachever",
    "parachevasses": "parachever",
    "parachevassiez": "parachever",
    "parachevassions": "parachever",
    "parachevez": "parachever",
    "paracheviez": "parachever",
    "parachevions": "parachever",
    "parachevons": "parachever",
    "parachevâmes": "parachever",
    "parachevât": "parachever",
    "parachevâtes": "parachever",
    "parachevèrent": "parachever",
    "parachevé": "parachever",
    "parachevée": "parachever",
    "parachevées": "parachever",
    "parachevés": "parachever",
    "parachutages": "parachutage",
    "parachute": "parachuter",
    "parachutent": "parachuter",
    "parachuterais": "parachuter",
    "parachuterons": "parachuter",
    "parachutes": "parachuter",
    "parachutez": "parachuter",
    "parachutistes": "parachutiste",
    "parachutèrent": "parachuter",
    "parachuté": "parachuter",
    "parachutée": "parachuter",
    "parachutées": "parachuter",
    "parachutés": "parachuter",
    "parachève": "parachever",
    "parachèvements": "parachèvement",
    "parachèvent": "parachever",
    "parachèvera": "parachever",
    "parachèverai": "parachever",
    "parachèveraient": "parachever",
    "parachèverais": "parachever",
    "parachèverait": "parachever",
    "parachèveras": "parachever",
    "parachèverez": "parachever",
    "parachèveriez": "parachever",
    "parachèverions": "parachever",
    "parachèverons": "parachever",
    "parachèveront": "parachever",
    "parachèves": "parachever",
    "parada": "parader",
    "paradai": "parader",
    "paradaient": "parader",
    "paradais": "parader",
    "paradait": "parader",
    "paradant": "parader",
    "paradas": "parader",
    "paradasse": "parader",
    "paradassent": "parader",
    "paradasses": "parader",
    "paradassiez": "parader",
    "paradassions": "parader",
    "parade": "parader",
    "paradent": "parader",
    "paradera": "parader",
    "paraderai": "parader",
    "paraderaient": "parader",
    "paraderais": "parader",
    "paraderait": "parader",
    "paraderas": "parader",
    "paraderez": "parader",
    "paraderiez": "parader",
    "paraderions": "parader",
    "paraderons": "parader",
    "paraderont": "parader",
    "parades": "parader",
    "paradeurs": "paradeur",
    "paradez": "parader",
    "paradiez": "parader",
    "paradigmes": "paradigme",
    "paradions": "parader",
    "paradisiaques": "paradisiaque",
    "paradisiers": "paradisier",
    "paradons": "parader",
    "paradoxale": "paradoxal",
    "paradoxales": "paradoxal",
    "paradoxaux": "paradoxal",
    "paradoxes": "paradoxe",
    "paradâmes": "parader",
    "paradât": "parader",
    "paradâtes": "parader",
    "paradèrent": "parader",
    "paradé": "parader",
    "paradée": "parader",
    "paradées": "parader",
    "paradés": "parader",
    "parafes": "parafe",
    "paraffines": "paraffine",
    "paraffinée": "paraffiné",
    "paraffinés": "paraffiné",
    "parafiscale": "parafiscal",
    "parafiscales": "parafiscal",
    "parafiscaux": "parafiscal",
    "parages": "parage",
    "paragouvernementales": "paragouvernemental",
    "paragraphes": "paragraphe",
    "paragrêles": "paragrêle",
    "paraguayenne": "paraguayen",
    "paraguayennes": "paraguayen",
    "paraguayens": "paraguayen",
    "parai": "parer",
    "paraient": "parer",
    "parais": "parer",
    "paraisonna": "paraisonner",
    "paraisonnai": "paraisonner",
    "paraisonnaient": "paraisonner",
    "paraisonnais": "paraisonner",
    "paraisonnait": "paraisonner",
    "paraisonnant": "paraisonner",
    "paraisonnas": "paraisonner",
    "paraisonnasse": "paraisonner",
    "paraisonnassent": "paraisonner",
    "paraisonnasses": "paraisonner",
    "paraisonnassiez": "paraisonner",
    "paraisonnassions": "paraisonner",
    "paraisonne": "paraisonner",
    "paraisonnent": "paraisonner",
    "paraisonnera": "paraisonner",
    "paraisonnerai": "paraisonner",
    "paraisonneraient": "paraisonner",
    "paraisonnerais": "paraisonner",
    "paraisonnerait": "paraisonner",
    "paraisonneras": "paraisonner",
    "paraisonnerez": "paraisonner",
    "paraisonneriez": "paraisonner",
    "paraisonnerions": "paraisonner",
    "paraisonnerons": "paraisonner",
    "paraisonneront": "paraisonner",
    "paraisonnes": "paraisonner",
    "paraisonnez": "paraisonner",
    "paraisonniez": "paraisonner",
    "paraisonnions": "paraisonner",
    "paraisonnons": "paraisonner",
    "paraisonnâmes": "paraisonner",
    "paraisonnât": "paraisonner",
    "paraisonnâtes": "paraisonner",
    "paraisonnèrent": "paraisonner",
    "paraisonné": "paraisonner",
    "paraisonnée": "paraisonner",
    "paraisonnées": "paraisonner",
    "paraisonnés": "paraisonner",
    "paraissaient": "paraître",
    "paraissais": "paraître",
    "paraissait": "paraître",
    "paraissant": "paraître",
    "paraisse": "paraître",
    "paraissent": "paraître",
    "paraisses": "paraître",
    "paraissez": "paraître",
    "paraissiez": "paraître",
    "paraissions": "paraître",
    "paraissons": "paraître",
    "parait": "parer",
    "parallaxes": "parallaxe",
    "parallèles": "parallèle",
    "parallélismes": "parallélisme",
    "parallélogrammes": "parallélogramme",
    "parallélépipèdes": "parallélépipède",
    "paralogismes": "paralogisme",
    "paralympiques": "paralympique",
    "paralysa": "paralyser",
    "paralysai": "paralyser",
    "paralysaient": "paralyser",
    "paralysais": "paralyser",
    "paralysait": "paralyser",
    "paralysant": "paralyser",
    "paralysante": "paralysant",
    "paralysantes": "paralysant",
    "paralysants": "paralysant",
    "paralysas": "paralyser",
    "paralysasse": "paralyser",
    "paralysassent": "paralyser",
    "paralysasses": "paralyser",
    "paralysassiez": "paralyser",
    "paralysassions": "paralyser",
    "paralyse": "paralyser",
    "paralysent": "paralyser",
    "paralysera": "paralyser",
    "paralyserai": "paralyser",
    "paralyseraient": "paralyser",
    "paralyserais": "paralyser",
    "paralyserait": "paralyser",
    "paralyseras": "paralyser",
    "paralyserez": "paralyser",
    "paralyseriez": "paralyser",
    "paralyserions": "paralyser",
    "paralyserons": "paralyser",
    "paralyseront": "paralyser",
    "paralyses": "paralyser",
    "paralysez": "paralyser",
    "paralysies": "paralysie",
    "paralysiez": "paralyser",
    "paralysions": "paralyser",
    "paralysons": "paralyser",
    "paralysâmes": "paralyser",
    "paralysât": "paralyser",
    "paralysâtes": "paralyser",
    "paralysèrent": "paralyser",
    "paralysé": "paralyser",
    "paralysée": "paralyser",
    "paralysées": "paralyser",
    "paralysés": "paralyser",
    "paralytiques": "paralytique",
    "paramilitaires": "paramilitaire",
    "paramètres": "paramètre",
    "paramédicale": "paramédical",
    "paramédicales": "paramédical",
    "paramédicaux": "paramédical",
    "parangonna": "parangonner",
    "parangonnages": "parangonnage",
    "parangonnai": "parangonner",
    "parangonnaient": "parangonner",
    "parangonnais": "parangonner",
    "parangonnait": "parangonner",
    "parangonnant": "parangonner",
    "parangonnas": "parangonner",
    "parangonnasse": "parangonner",
    "parangonnassent": "parangonner",
    "parangonnasses": "parangonner",
    "parangonnassiez": "parangonner",
    "parangonnassions": "parangonner",
    "parangonne": "parangonner",
    "parangonnent": "parangonner",
    "parangonnera": "parangonner",
    "parangonnerai": "parangonner",
    "parangonneraient": "parangonner",
    "parangonnerais": "parangonner",
    "parangonnerait": "parangonner",
    "parangonneras": "parangonner",
    "parangonnerez": "parangonner",
    "parangonneriez": "parangonner",
    "parangonnerions": "parangonner",
    "parangonnerons": "parangonner",
    "parangonneront": "parangonner",
    "parangonnes": "parangonner",
    "parangonnez": "parangonner",
    "parangonniez": "parangonner",
    "parangonnions": "parangonner",
    "parangonnons": "parangonner",
    "parangonnâmes": "parangonner",
    "parangonnât": "parangonner",
    "parangonnâtes": "parangonner",
    "parangonnèrent": "parangonner",
    "parangonné": "parangonner",
    "parangonnée": "parangonner",
    "parangonnées": "parangonner",
    "parangonnés": "parangonner",
    "parangons": "parangon",
    "paranormale": "paranormal",
    "paranormales": "paranormal",
    "paranormaux": "paranormal",
    "paranos": "parano",
    "paranoïaques": "paranoïaque",
    "parant": "parer",
    "parapentes": "parapente",
    "parapets": "parapet",
    "paraphait": "parapher",
    "paraphant": "parapher",
    "paraphe": "parapher",
    "paraphernale": "paraphernal",
    "paraphernales": "paraphernal",
    "paraphernaux": "paraphernal",
    "paraphes": "parapher",
    "parapheurs": "parapheur",
    "paraphez": "parapher",
    "paraphrasa": "paraphraser",
    "paraphrasai": "paraphraser",
    "paraphrasaient": "paraphraser",
    "paraphrasais": "paraphraser",
    "paraphrasait": "paraphraser",
    "paraphrasant": "paraphraser",
    "paraphrasas": "paraphraser",
    "paraphrasasse": "paraphraser",
    "paraphrasassent": "paraphraser",
    "paraphrasasses": "paraphraser",
    "paraphrasassiez": "paraphraser",
    "paraphrasassions": "paraphraser",
    "paraphrase": "paraphraser",
    "paraphrasent": "paraphraser",
    "paraphrasera": "paraphraser",
    "paraphraserai": "paraphraser",
    "paraphraseraient": "paraphraser",
    "paraphraserais": "paraphraser",
    "paraphraserait": "paraphraser",
    "paraphraseras": "paraphraser",
    "paraphraserez": "paraphraser",
    "paraphraseriez": "paraphraser",
    "paraphraserions": "paraphraser",
    "paraphraserons": "paraphraser",
    "paraphraseront": "paraphraser",
    "paraphrases": "paraphraser",
    "paraphrasez": "paraphraser",
    "paraphrasiez": "paraphraser",
    "paraphrasions": "paraphraser",
    "paraphrasons": "paraphraser",
    "paraphrasâmes": "paraphraser",
    "paraphrasât": "paraphraser",
    "paraphrasâtes": "paraphraser",
    "paraphrasèrent": "paraphraser",
    "paraphrasé": "paraphraser",
    "paraphrasée": "paraphraser",
    "paraphrasées": "paraphraser",
    "paraphrasés": "paraphraser",
    "paraphé": "parapher",
    "paraphée": "parapher",
    "paraphées": "paraphé",
    "paraphés": "parapher",
    "parapluies": "parapluie",
    "paraplégies": "paraplégie",
    "paraplégiques": "paraplégique",
    "parapsychologies": "parapsychologie",
    "parapsychologiques": "parapsychologique",
    "parapsychologues": "parapsychologue",
    "parapétroliers": "parapétrolier",
    "parapétrolière": "parapétrolier",
    "parapétrolières": "parapétrolier",
    "parareligieuse": "parareligieux",
    "paras": "parer",
    "parascolaires": "parascolaire",
    "parasita": "parasiter",
    "parasitai": "parasiter",
    "parasitaient": "parasiter",
    "parasitaires": "parasitaire",
    "parasitais": "parasiter",
    "parasitait": "parasiter",
    "parasitant": "parasiter",
    "parasitas": "parasiter",
    "parasitasse": "parasiter",
    "parasitassent": "parasiter",
    "parasitasses": "parasiter",
    "parasitassiez": "parasiter",
    "parasitassions": "parasiter",
    "parasite": "parasiter",
    "parasitent": "parasiter",
    "parasitera": "parasiter",
    "parasiterai": "parasiter",
    "parasiteraient": "parasiter",
    "parasiterais": "parasiter",
    "parasiterait": "parasiter",
    "parasiteras": "parasiter",
    "parasiterez": "parasiter",
    "parasiteriez": "parasiter",
    "parasiterions": "parasiter",
    "parasiterons": "parasiter",
    "parasiteront": "parasiter",
    "parasites": "parasiter",
    "parasitez": "parasiter",
    "parasiticides": "parasiticide",
    "parasitiez": "parasiter",
    "parasitions": "parasiter",
    "parasitologies": "parasitologie",
    "parasitons": "parasiter",
    "parasitoses": "parasitose",
    "parasitâmes": "parasiter",
    "parasitât": "parasiter",
    "parasitâtes": "parasiter",
    "parasitèrent": "parasiter",
    "parasité": "parasiter",
    "parasitée": "parasiter",
    "parasitées": "parasiter",
    "parasités": "parasiter",
    "parasols": "parasol",
    "parasse": "parer",
    "parassent": "parer",
    "parasses": "parer",
    "parassiez": "parer",
    "parassions": "parer",
    "parasympathiques": "parasympathique",
    "parathyroïdes": "parathyroïde",
    "parathyroïdienne": "parathyroïdien",
    "paratonnerres": "paratonnerre",
    "paratyphoïdes": "paratyphoïde",
    "paravalanches": "paravalanche",
    "paravents": "paravent",
    "paraît": "paraître",
    "paraîtra": "paraître",
    "paraîtrai": "paraître",
    "paraîtraient": "paraître",
    "paraîtrais": "paraître",
    "paraîtrait": "paraître",
    "paraîtras": "paraître",
    "paraîtrez": "paraître",
    "paraîtriez": "paraître",
    "paraîtrions": "paraître",
    "paraîtrons": "paraître",
    "paraîtront": "paraître",
    "parcages": "parcage",
    "parcellaires": "parcellaire",
    "parcelles": "parcelle",
    "parchemineuse": "parchemineux",
    "parchemins": "parchemin",
    "parcheminé": "parcheminer",
    "parcheminée": "parcheminer",
    "parcheminées": "parcheminer",
    "parcheminés": "parcheminé",
    "parcimonies": "parcimonie",
    "parcimonieuse": "parcimonieux",
    "parcimonieuses": "parcimonieux",
    "parcmètres": "parcmètre",
    "parcouraient": "parcourir",
    "parcourais": "parcourir",
    "parcourait": "parcourir",
    "parcourant": "parcourir",
    "parcoure": "parcourir",
    "parcourent": "parcourir",
    "parcoures": "parcourir",
    "parcourez": "parcourir",
    "parcouriez": "parcourir",
    "parcourions": "parcourir",
    "parcourons": "parcourir",
    "parcourra": "parcourir",
    "parcourrai": "parcourir",
    "parcourraient": "parcourir",
    "parcourrais": "parcourir",
    "parcourrait": "parcourir",
    "parcourras": "parcourir",
    "parcourrez": "parcourir",
    "parcourriez": "parcourir",
    "parcourrions": "parcourir",
    "parcourrons": "parcourir",
    "parcourront": "parcourir",
    "parcours": "parcourir",
    "parcourt": "parcourir",
    "parcouru": "parcourir",
    "parcourue": "parcourir",
    "parcourues": "parcourir",
    "parcoururent": "parcourir",
    "parcourus": "parcourir",
    "parcourusse": "parcourir",
    "parcourussent": "parcourir",
    "parcourusses": "parcourir",
    "parcourussiez": "parcourir",
    "parcourussions": "parcourir",
    "parcourut": "parcourir",
    "parcourûmes": "parcourir",
    "parcourût": "parcourir",
    "parcourûtes": "parcourir",
    "parcs": "parc",
    "pardonna": "pardonner",
    "pardonnai": "pardonner",
    "pardonnaient": "pardonner",
    "pardonnais": "pardonner",
    "pardonnait": "pardonner",
    "pardonnant": "pardonner",
    "pardonnas": "pardonner",
    "pardonnasse": "pardonner",
    "pardonnassent": "pardonner",
    "pardonnasses": "pardonner",
    "pardonnassiez": "pardonner",
    "pardonnassions": "pardonner",
    "pardonne": "pardonner",
    "pardonnent": "pardonner",
    "pardonnera": "pardonner",
    "pardonnerai": "pardonner",
    "pardonneraient": "pardonner",
    "pardonnerais": "pardonner",
    "pardonnerait": "pardonner",
    "pardonneras": "pardonner",
    "pardonnerez": "pardonner",
    "pardonneriez": "pardonner",
    "pardonnerions": "pardonner",
    "pardonnerons": "pardonner",
    "pardonneront": "pardonner",
    "pardonnes": "pardonner",
    "pardonnez": "pardonner",
    "pardonniez": "pardonner",
    "pardonnions": "pardonner",
    "pardonnons": "pardonner",
    "pardonnâmes": "pardonner",
    "pardonnât": "pardonner",
    "pardonnâtes": "pardonner",
    "pardonnèrent": "pardonner",
    "pardonné": "pardonner",
    "pardonnée": "pardonner",
    "pardonnées": "pardonner",
    "pardonnés": "pardonner",
    "pardons": "pardon",
    "pare": "parer",
    "pare-brises": "pare-brise",
    "pare-feux": "pare-feu",
    "pareille": "pareil",
    "pareilles": "pareil",
    "pareils": "pareil",
    "parements": "parement",
    "parenchymes": "parenchyme",
    "parent": "parer",
    "parentale": "parental",
    "parentales": "parental",
    "parentaux": "parental",
    "parente": "parent",
    "parentes": "parent",
    "parenthèses": "parenthèse",
    "parents": "parent",
    "parentèles": "parentèle",
    "parentérale": "parentéral",
    "parentérales": "parentéral",
    "parentéraux": "parentéral",
    "parentés": "parenté",
    "parera": "parer",
    "parerai": "parer",
    "pareraient": "parer",
    "parerais": "parer",
    "parerait": "parer",
    "pareras": "parer",
    "parerez": "parer",
    "pareriez": "parer",
    "parerions": "parer",
    "parerons": "parer",
    "pareront": "parer",
    "pares": "parer",
    "paressa": "paresser",
    "paressai": "paresser",
    "paressaient": "paresser",
    "paressais": "paresser",
    "paressait": "paresser",
    "paressant": "paresser",
    "paressas": "paresser",
    "paressasse": "paresser",
    "paressassent": "paresser",
    "paressasses": "paresser",
    "paressassiez": "paresser",
    "paressassions": "paresser",
    "paresse": "paresser",
    "paressent": "paresser",
    "paressera": "paresser",
    "paresserai": "paresser",
    "paresseraient": "paresser",
    "paresserais": "paresser",
    "paresserait": "paresser",
    "paresseras": "paresser",
    "paresserez": "paresser",
    "paresseriez": "paresser",
    "paresserions": "paresser",
    "paresserons": "paresser",
    "paresseront": "paresser",
    "paresses": "paresser",
    "paresseuse": "paresseux",
    "paresseuses": "paresseux",
    "paressez": "paresser",
    "paressiez": "paresser",
    "paressions": "paresser",
    "paressons": "paresser",
    "paressâmes": "paresser",
    "paressât": "paresser",
    "paressâtes": "paresser",
    "paressèrent": "paresser",
    "paressé": "paresser",
    "paressée": "paresser",
    "paressées": "paresser",
    "paressés": "paresser",
    "parez": "parer",
    "parfais": "parfaire",
    "parfaisais": "parfaire",
    "parfaisait": "parfaire",
    "parfaisons": "parfaire",
    "parfait": "parfaire",
    "parfaite": "parfait",
    "parfaites": "parfait",
    "parfaits": "parfait",
    "parferont": "parfaire",
    "parfit": "parfaire",
    "parfond": "parfondre",
    "parfondaient": "parfondre",
    "parfondais": "parfondre",
    "parfondait": "parfondre",
    "parfondant": "parfondre",
    "parfonde": "parfondre",
    "parfondent": "parfondre",
    "parfondes": "parfondre",
    "parfondez": "parfondre",
    "parfondiez": "parfondre",
    "parfondions": "parfondre",
    "parfondirent": "parfondre",
    "parfondis": "parfondre",
    "parfondisse": "parfondre",
    "parfondissent": "parfondre",
    "parfondisses": "parfondre",
    "parfondissiez": "parfondre",
    "parfondissions": "parfondre",
    "parfondit": "parfondre",
    "parfondons": "parfondre",
    "parfondra": "parfondre",
    "parfondrai": "parfondre",
    "parfondraient": "parfondre",
    "parfondrais": "parfondre",
    "parfondrait": "parfondre",
    "parfondras": "parfondre",
    "parfondrez": "parfondre",
    "parfondriez": "parfondre",
    "parfondrions": "parfondre",
    "parfondrons": "parfondre",
    "parfondront": "parfondre",
    "parfonds": "parfondre",
    "parfondu": "parfondre",
    "parfondue": "parfondre",
    "parfondues": "parfondre",
    "parfondus": "parfondre",
    "parfondîmes": "parfondre",
    "parfondît": "parfondre",
    "parfondîtes": "parfondre",
    "parfont": "parfaire",
    "parfuma": "parfumer",
    "parfumai": "parfumer",
    "parfumaient": "parfumer",
    "parfumais": "parfumer",
    "parfumait": "parfumer",
    "parfumant": "parfumer",
    "parfumas": "parfumer",
    "parfumasse": "parfumer",
    "parfumassent": "parfumer",
    "parfumasses": "parfumer",
    "parfumassiez": "parfumer",
    "parfumassions": "parfumer",
    "parfume": "parfumer",
    "parfument": "parfumer",
    "parfumera": "parfumer",
    "parfumerai": "parfumer",
    "parfumeraient": "parfumer",
    "parfumerais": "parfumer",
    "parfumerait": "parfumer",
    "parfumeras": "parfumer",
    "parfumerez": "parfumer",
    "parfumeries": "parfumerie",
    "parfumeriez": "parfumer",
    "parfumerions": "parfumer",
    "parfumerons": "parfumer",
    "parfumeront": "parfumer",
    "parfumes": "parfumer",
    "parfumeurs": "parfumeur",
    "parfumeuse": "parfumeur",
    "parfumez": "parfumer",
    "parfumiez": "parfumer",
    "parfumions": "parfumer",
    "parfumons": "parfumer",
    "parfums": "parfum",
    "parfumâmes": "parfumer",
    "parfumât": "parfumer",
    "parfumâtes": "parfumer",
    "parfumèrent": "parfumer",
    "parfumé": "parfumer",
    "parfumée": "parfumer",
    "parfumées": "parfumer",
    "parfumés": "parfumer",
    "parhélies": "parhélie",
    "paria": "parier",
    "pariai": "parier",
    "pariaient": "parier",
    "pariais": "parier",
    "pariait": "parier",
    "pariant": "parier",
    "parias": "parier",
    "pariasse": "parier",
    "pariassent": "parier",
    "pariasses": "parier",
    "pariassiez": "parier",
    "pariassions": "parier",
    "parie": "parier",
    "parient": "parier",
    "pariera": "parier",
    "parierai": "parier",
    "parieraient": "parier",
    "parierais": "parier",
    "parierait": "parier",
    "parieras": "parier",
    "parierez": "parier",
    "parieriez": "parier",
    "parierions": "parier",
    "parierons": "parier",
    "parieront": "parier",
    "paries": "parier",
    "parieurs": "parieur",
    "parieuse": "parieur",
    "pariez": "parier",
    "parigote": "parigot",
    "parigotes": "parigot",
    "parigots": "parigot",
    "pariiez": "parier",
    "pariions": "parier",
    "parions": "parier",
    "paris": "pari",
    "parisianismes": "parisianisme",
    "parisienne": "parisien",
    "parisiennes": "parisien",
    "parisiens": "parisien",
    "parisyllabiques": "parisyllabique",
    "paritaires": "paritaire",
    "parités": "parité",
    "pariâmes": "parier",
    "pariât": "parier",
    "pariâtes": "parier",
    "parièrent": "parier",
    "parié": "parier",
    "pariée": "parier",
    "pariées": "parier",
    "pariés": "parier",
    "pariétaires": "pariétaire",
    "pariétale": "pariétal",
    "pariétales": "pariétal",
    "pariétaux": "pariétal",
    "parjura": "parjurer",
    "parjurai": "parjurer",
    "parjuraient": "parjurer",
    "parjurais": "parjurer",
    "parjurait": "parjurer",
    "parjurant": "parjurer",
    "parjuras": "parjurer",
    "parjurasse": "parjurer",
    "parjurassent": "parjurer",
    "parjurasses": "parjurer",
    "parjurassiez": "parjurer",
    "parjurassions": "parjurer",
    "parjure": "parjurer",
    "parjurent": "parjurer",
    "parjurera": "parjurer",
    "parjurerai": "parjurer",
    "parjureraient": "parjurer",
    "parjurerais": "parjurer",
    "parjurerait": "parjurer",
    "parjureras": "parjurer",
    "parjurerez": "parjurer",
    "parjureriez": "parjurer",
    "parjurerions": "parjurer",
    "parjurerons": "parjurer",
    "parjureront": "parjurer",
    "parjures": "parjurer",
    "parjurez": "parjurer",
    "parjuriez": "parjurer",
    "parjurions": "parjurer",
    "parjurons": "parjurer",
    "parjurâmes": "parjurer",
    "parjurât": "parjurer",
    "parjurâtes": "parjurer",
    "parjurèrent": "parjurer",
    "parjuré": "parjurer",
    "parjurée": "parjurer",
    "parjurées": "parjurer",
    "parjurés": "parjurer",
    "parkings": "parking",
    "parkinsonienne": "parkinsonien",
    "parkinsoniens": "parkinsonien",
    "parla": "parler",
    "parlai": "parler",
    "parlaient": "parler",
    "parlais": "parler",
    "parlait": "parler",
    "parlant": "parler",
    "parlante": "parlant",
    "parlantes": "parlant",
    "parlants": "parlant",
    "parlas": "parler",
    "parlasse": "parler",
    "parlassent": "parler",
    "parlasses": "parler",
    "parlassiez": "parler",
    "parlassions": "parler",
    "parle": "parler",
    "parlementa": "parlementer",
    "parlementai": "parlementer",
    "parlementaient": "parlementer",
    "parlementaires": "parlementaire",
    "parlementais": "parlementer",
    "parlementait": "parlementer",
    "parlementant": "parlementer",
    "parlementas": "parlementer",
    "parlementasse": "parlementer",
    "parlementassent": "parlementer",
    "parlementasses": "parlementer",
    "parlementassiez": "parlementer",
    "parlementassions": "parlementer",
    "parlemente": "parlementer",
    "parlementent": "parlementer",
    "parlementera": "parlementer",
    "parlementerai": "parlementer",
    "parlementeraient": "parlementer",
    "parlementerais": "parlementer",
    "parlementerait": "parlementer",
    "parlementeras": "parlementer",
    "parlementerez": "parlementer",
    "parlementeriez": "parlementer",
    "parlementerions": "parlementer",
    "parlementerons": "parlementer",
    "parlementeront": "parlementer",
    "parlementes": "parlementer",
    "parlementez": "parlementer",
    "parlementiez": "parlementer",
    "parlementions": "parlementer",
    "parlementons": "parlementer",
    "parlements": "parlement",
    "parlementâmes": "parlementer",
    "parlementât": "parlementer",
    "parlementâtes": "parlementer",
    "parlementèrent": "parlementer",
    "parlementé": "parlementer",
    "parlent": "parler",
    "parlera": "parler",
    "parlerai": "parler",
    "parleraient": "parler",
    "parlerais": "parler",
    "parlerait": "parler",
    "parleras": "parler",
    "parlerez": "parler",
    "parleriez": "parler",
    "parlerions": "parler",
    "parlerons": "parler",
    "parleront": "parler",
    "parlers": "parler",
    "parles": "parler",
    "parleurs": "parleur",
    "parleuse": "parleur",
    "parlez": "parler",
    "parliez": "parler",
    "parlions": "parler",
    "parloirs": "parloir",
    "parlons": "parler",
    "parlotaient": "parloter",
    "parlotes": "parlote",
    "parlottes": "parlotte",
    "parlâmes": "parler",
    "parlât": "parler",
    "parlâtes": "parler",
    "parlèrent": "parler",
    "parlé": "parler",
    "parlée": "parler",
    "parlées": "parler",
    "parlés": "parler",
    "parmentures": "parmenture",
    "parmesane": "parmesan",
    "parmesans": "parmesan",
    "parmélies": "parmélie",
    "parnassienne": "parnassien",
    "parodiai": "parodier",
    "parodiait": "parodier",
    "parodiant": "parodier",
    "parodie": "parodier",
    "parodies": "parodie",
    "parodiques": "parodique",
    "parodontale": "parodontal",
    "parodontales": "parodontal",
    "parodontaux": "parodontal",
    "parodontes": "parodonte",
    "paroirs": "paroir",
    "parois": "paroi",
    "paroisses": "paroisse",
    "paroissiale": "paroissial",
    "paroissiales": "paroissial",
    "paroissiaux": "paroissial",
    "paroissienne": "paroissien",
    "paroissiennes": "paroissien",
    "paroissiens": "paroissien",
    "paroles": "parole",
    "paroliers": "parolier",
    "parolis": "paroli",
    "parolière": "parolier",
    "paronomases": "paronomase",
    "parons": "parer",
    "paronymes": "paronyme",
    "parotides": "parotide",
    "parotidienne": "parotidien",
    "parousies": "parousie",
    "paroxysmale": "paroxysmal",
    "paroxysmales": "paroxysmal",
    "paroxysmaux": "paroxysmal",
    "paroxysmes": "paroxysme",
    "paroxysmiques": "paroxysmique",
    "paroxystiques": "paroxystique",
    "parpaillote": "parpaillot",
    "parpaillotes": "parpaillot",
    "parpaillots": "parpaillot",
    "parpaings": "parpaing",
    "parqua": "parquer",
    "parquai": "parquer",
    "parquaient": "parquer",
    "parquais": "parquer",
    "parquait": "parquer",
    "parquant": "parquer",
    "parquas": "parquer",
    "parquasse": "parquer",
    "parquassent": "parquer",
    "parquasses": "parquer",
    "parquassiez": "parquer",
    "parquassions": "parquer",
    "parque": "parquer",
    "parquent": "parquer",
    "parquera": "parquer",
    "parquerai": "parquer",
    "parqueraient": "parquer",
    "parquerais": "parquer",
    "parquerait": "parquer",
    "parqueras": "parquer",
    "parquerez": "parquer",
    "parqueriez": "parquer",
    "parquerions": "parquer",
    "parquerons": "parquer",
    "parqueront": "parquer",
    "parques": "parquer",
    "parqueta": "parqueter",
    "parquetai": "parqueter",
    "parquetaient": "parqueter",
    "parquetais": "parqueter",
    "parquetait": "parqueter",
    "parquetant": "parqueter",
    "parquetas": "parqueter",
    "parquetasse": "parqueter",
    "parquetassent": "parqueter",
    "parquetasses": "parqueter",
    "parquetassiez": "parqueter",
    "parquetassions": "parqueter",
    "parqueteuse": "parqueteur",
    "parquetez": "parqueter",
    "parquetiez": "parqueter",
    "parquetions": "parqueter",
    "parquetons": "parqueter",
    "parquets": "parquet",
    "parquette": "parqueter",
    "parquettent": "parqueter",
    "parquettera": "parqueter",
    "parquetterai": "parqueter",
    "parquetteraient": "parqueter",
    "parquetterais": "parqueter",
    "parquetterait": "parqueter",
    "parquetteras": "parqueter",
    "parquetterez": "parqueter",
    "parquetteriez": "parqueter",
    "parquetterions": "parqueter",
    "parquetterons": "parqueter",
    "parquetteront": "parqueter",
    "parquettes": "parqueter",
    "parquetâmes": "parqueter",
    "parquetât": "parqueter",
    "parquetâtes": "parqueter",
    "parquetèrent": "parqueter",
    "parqueté": "parqueter",
    "parquetée": "parqueter",
    "parquetées": "parqueter",
    "parquetés": "parqueter",
    "parquez": "parquer",
    "parquiez": "parquer",
    "parquions": "parquer",
    "parquons": "parquer",
    "parquâmes": "parquer",
    "parquât": "parquer",
    "parquâtes": "parquer",
    "parquèrent": "parquer",
    "parqué": "parquer",
    "parquée": "parquer",
    "parquées": "parquer",
    "parqués": "parquer",
    "parraina": "parrainer",
    "parrainages": "parrainage",
    "parrainai": "parrainer",
    "parrainaient": "parrainer",
    "parrainais": "parrainer",
    "parrainait": "parrainer",
    "parrainant": "parrainer",
    "parrainas": "parrainer",
    "parrainasse": "parrainer",
    "parrainassent": "parrainer",
    "parrainasses": "parrainer",
    "parrainassiez": "parrainer",
    "parrainassions": "parrainer",
    "parraine": "parrainer",
    "parrainent": "parrainer",
    "parrainera": "parrainer",
    "parrainerai": "parrainer",
    "parraineraient": "parrainer",
    "parrainerais": "parrainer",
    "parrainerait": "parrainer",
    "parraineras": "parrainer",
    "parrainerez": "parrainer",
    "parraineriez": "parrainer",
    "parrainerions": "parrainer",
    "parrainerons": "parrainer",
    "parraineront": "parrainer",
    "parraines": "parrainer",
    "parraineuse": "parraineur",
    "parrainez": "parrainer",
    "parrainiez": "parrainer",
    "parrainions": "parrainer",
    "parrainons": "parrainer",
    "parrains": "parrain",
    "parrainâmes": "parrainer",
    "parrainât": "parrainer",
    "parrainâtes": "parrainer",
    "parrainèrent": "parrainer",
    "parrainé": "parrainer",
    "parrainée": "parrainer",
    "parrainées": "parrainer",
    "parrainés": "parrainer",
    "parricides": "parricide",
    "pars": "partir",
    "parsecs": "parsec",
    "parsema": "parsemer",
    "parsemai": "parsemer",
    "parsemaient": "parsemer",
    "parsemais": "parsemer",
    "parsemait": "parsemer",
    "parsemant": "parsemer",
    "parsemas": "parsemer",
    "parsemasse": "parsemer",
    "parsemassent": "parsemer",
    "parsemasses": "parsemer",
    "parsemassiez": "parsemer",
    "parsemassions": "parsemer",
    "parsemez": "parsemer",
    "parsemiez": "parsemer",
    "parsemions": "parsemer",
    "parsemons": "parsemer",
    "parsemâmes": "parsemer",
    "parsemât": "parsemer",
    "parsemâtes": "parsemer",
    "parsemèrent": "parsemer",
    "parsemé": "parsemer",
    "parsemée": "parsemer",
    "parsemées": "parsemer",
    "parsemés": "parsemer",
    "parsie": "parsi",
    "parsies": "parsi",
    "parsis": "parsi",
    "parsème": "parsemer",
    "parsèment": "parsemer",
    "parsèmera": "parsemer",
    "parsèmerai": "parsemer",
    "parsèmeraient": "parsemer",
    "parsèmerais": "parsemer",
    "parsèmerait": "parsemer",
    "parsèmeras": "parsemer",
    "parsèmerez": "parsemer",
    "parsèmeriez": "parsemer",
    "parsèmerions": "parsemer",
    "parsèmerons": "parsemer",
    "parsèmeront": "parsemer",
    "parsèmes": "parsemer",
    "part": "partir",
    "partage": "partager",
    "partagea": "partager",
    "partageai": "partager",
    "partageaient": "partager",
    "partageais": "partager",
    "partageait": "partager",
    "partageant": "partager",
    "partageas": "partager",
    "partageasse": "partager",
    "partageassent": "partager",
    "partageasses": "partager",
    "partageassiez": "partager",
    "partageassions": "partager",
    "partagent": "partager",
    "partageons": "partager",
    "partagera": "partager",
    "partagerai": "partager",
    "partageraient": "partager",
    "partagerais": "partager",
    "partagerait": "partager",
    "partageras": "partager",
    "partagerez": "partager",
    "partageriez": "partager",
    "partagerions": "partager",
    "partagerons": "partager",
    "partageront": "partager",
    "partages": "partager",
    "partageurs": "partageur",
    "partageuse": "partageux",
    "partagez": "partager",
    "partageâmes": "partager",
    "partageât": "partager",
    "partageâtes": "partager",
    "partagiez": "partager",
    "partagions": "partager",
    "partagèrent": "partager",
    "partagé": "partager",
    "partagée": "partager",
    "partagées": "partager",
    "partagés": "partager",
    "partaient": "partir",
    "partais": "partir",
    "partait": "partir",
    "partances": "partance",
    "partant": "partir",
    "partante": "partant",
    "partantes": "partant",
    "partants": "partant",
    "parte": "partir",
    "partenaires": "partenaire",
    "partenariale": "partenarial",
    "partenariales": "partenarial",
    "partenariats": "partenariat",
    "partenariaux": "partenarial",
    "partent": "partir",
    "parterres": "parterre",
    "partes": "partir",
    "partez": "partir",
    "parthes": "parthe",
    "parthénogenèses": "parthénogenèse",
    "parti": "partir",
    "partiale": "partial",
    "partiales": "partial",
    "partiaux": "partial",
    "participa": "participer",
    "participai": "participer",
    "participaient": "participer",
    "participais": "participer",
    "participait": "participer",
    "participant": "participer",
    "participante": "participant",
    "participantes": "participant",
    "participants": "participant",
    "participas": "participer",
    "participasse": "participer",
    "participassent": "participer",
    "participasses": "participer",
    "participassiez": "participer",
    "participassions": "participer",
    "participatifs": "participatif",
    "participations": "participation",
    "participative": "participatif",
    "participatives": "participatif",
    "participe": "participer",
    "participent": "participer",
    "participera": "participer",
    "participerai": "participer",
    "participeraient": "participer",
    "participerais": "participer",
    "participerait": "participer",
    "participeras": "participer",
    "participerez": "participer",
    "participeriez": "participer",
    "participerions": "participer",
    "participerons": "participer",
    "participeront": "participer",
    "participes": "participer",
    "participez": "participer",
    "participiale": "participial",
    "participiales": "participial",
    "participiaux": "participial",
    "participiez": "participer",
    "participions": "participer",
    "participons": "participer",
    "participâmes": "participer",
    "participât": "participer",
    "participâtes": "participer",
    "participèrent": "participer",
    "participé": "participer",
    "participés": "participer",
    "particularismes": "particularisme",
    "particularisées": "particulariser",
    "particularités": "particularité",
    "particules": "particule",
    "particuliers": "particulier",
    "particulière": "particulier",
    "particulières": "particulier",
    "partie": "partir",
    "partielle": "partiel",
    "partielles": "partiel",
    "partiels": "partiel",
    "parties": "partir",
    "partiez": "partir",
    "partions": "partir",
    "partira": "partir",
    "partirai": "partir",
    "partiraient": "partir",
    "partirais": "partir",
    "partirait": "partir",
    "partiras": "partir",
    "partirent": "partir",
    "partirez": "partir",
    "partiriez": "partir",
    "partirions": "partir",
    "partirons": "partir",
    "partiront": "partir",
    "partis": "partir",
    "partisane": "partisan",
    "partisanes": "partisan",
    "partisans": "partisan",
    "partisse": "partir",
    "partissent": "partir",
    "partisses": "partir",
    "partissiez": "partir",
    "partissions": "partir",
    "partit": "partir",
    "partitas": "partita",
    "partitifs": "partitif",
    "partitions": "partition",
    "partitive": "partitif",
    "partitives": "partitif",
    "partitocratiques": "partitocratique",
    "partons": "partir",
    "partouzait": "partouzer",
    "partouzarde": "partouzard",
    "partouzardes": "partouzard",
    "partouzards": "partouzard",
    "partouzent": "partouzer",
    "partouzes": "partouze",
    "partouzeurs": "partouzeur",
    "parts": "part",
    "parturientes": "parturiente",
    "parturitions": "parturition",
    "partîmes": "partir",
    "partît": "partir",
    "partîtes": "partir",
    "paru": "paraître",
    "parue": "paraître",
    "parues": "paraître",
    "parurent": "paraître",
    "parures": "parure",
    "parus": "paraître",
    "parusse": "paraître",
    "parussent": "paraître",
    "parusses": "paraître",
    "parussiez": "paraître",
    "parussions": "paraître",
    "parut": "paraître",
    "parutions": "parution",
    "parvenaient": "parvenir",
    "parvenais": "parvenir",
    "parvenait": "parvenir",
    "parvenant": "parvenir",
    "parvenez": "parvenir",
    "parveniez": "parvenir",
    "parvenions": "parvenir",
    "parvenons": "parvenir",
    "parvenu": "parvenir",
    "parvenue": "parvenu",
    "parvenues": "parvenu",
    "parvenus": "parvenu",
    "parviendra": "parvenir",
    "parviendrai": "parvenir",
    "parviendraient": "parvenir",
    "parviendrais": "parvenir",
    "parviendrait": "parvenir",
    "parviendras": "parvenir",
    "parviendrez": "parvenir",
    "parviendriez": "parvenir",
    "parviendrions": "parvenir",
    "parviendrons": "parvenir",
    "parviendront": "parvenir",
    "parvienne": "parvenir",
    "parviennent": "parvenir",
    "parviennes": "parvenir",
    "parviens": "parvenir",
    "parvient": "parvenir",
    "parvinrent": "parvenir",
    "parvins": "parvenir",
    "parvinsse": "parvenir",
    "parvinssent": "parvenir",
    "parvinsses": "parvenir",
    "parvinssiez": "parvenir",
    "parvinssions": "parvenir",
    "parvint": "parvenir",
    "parvînmes": "parvenir",
    "parvînt": "parvenir",
    "parvîntes": "parvenir",
    "parâmes": "parer",
    "parât": "parer",
    "parâtes": "parer",
    "parèdres": "parèdre",
    "parèrent": "parer",
    "paré": "parer",
    "parée": "parer",
    "parées": "parer",
    "parégoriques": "parégorique",
    "parélies": "parélie",
    "paréos": "paréo",
    "parés": "parer",
    "parésies": "parésie",
    "parûmes": "paraître",
    "parût": "paraître",
    "parûtes": "paraître",
    "pascale": "pascal",
    "pascales": "pascal",
    "pascaliennes": "pascalien",
    "pascaliens": "pascalien",
    "pascals": "pascal",
    "pascaux": "pascal",
    "pasionarias": "pasionaria",
    "pasos": "paso",
    "pasquins": "pasquin",
    "passa": "passer",
    "passables": "passable",
    "passacailles": "passacaille",
    "passades": "passade",
    "passagers": "passager",
    "passages": "passage",
    "passagère": "passager",
    "passagères": "passager",
    "passai": "passer",
    "passaient": "passer",
    "passais": "passer",
    "passait": "passer",
    "passant": "passer",
    "passante": "passant",
    "passantes": "passant",
    "passants": "passant",
    "passas": "passer",
    "passasse": "passer",
    "passassent": "passer",
    "passasses": "passer",
    "passassiez": "passer",
    "passassions": "passer",
    "passations": "passation",
    "passavants": "passavant",
    "passe": "passer",
    "passe-boules": "passe-boule",
    "passe-crassanes": "passe-crassane",
    "passe-droits": "passe-droit",
    "passe-lacets": "passe-lacet",
    "passe-montagnes": "passe-montagne",
    "passe-pieds": "passe-pied",
    "passe-plats": "passe-plat",
    "passe-roses": "passe-rose",
    "passe-volants": "passe-volant",
    "passementaient": "passementer",
    "passementent": "passementer",
    "passementeries": "passementerie",
    "passementière": "passementier",
    "passements": "passement",
    "passementé": "passementer",
    "passent": "passer",
    "passepoils": "passepoil",
    "passeports": "passeport",
    "passer": "prendre",
    "passera": "passer",
    "passerai": "passer",
    "passeraient": "passer",
    "passerais": "passer",
    "passerait": "passer",
    "passeras": "passer",
    "passereaux": "passereau",
    "passerelles": "passerelle",
    "passerez": "passer",
    "passeriez": "passer",
    "passerions": "passer",
    "passerons": "passer",
    "passeront": "passer",
    "passeroses": "passerose",
    "passes": "passer",
    "passeurs": "passeur",
    "passeuse": "passeur",
    "passez": "passer",
    "passibles": "passible",
    "passiez": "passer",
    "passifs": "passif",
    "passing-shots": "passing-shot",
    "passings": "passing",
    "passionna": "passionner",
    "passionnai": "passionner",
    "passionnaient": "passionner",
    "passionnais": "passionner",
    "passionnait": "passionner",
    "passionnant": "passionner",
    "passionnante": "passionnant",
    "passionnantes": "passionnant",
    "passionnants": "passionnant",
    "passionnas": "passionner",
    "passionnasse": "passionner",
    "passionnassent": "passionner",
    "passionnasses": "passionner",
    "passionnassiez": "passionner",
    "passionnassions": "passionner",
    "passionne": "passionner",
    "passionnelle": "passionnel",
    "passionnelles": "passionnel",
    "passionnels": "passionnel",
    "passionnent": "passionner",
    "passionnera": "passionner",
    "passionnerai": "passionner",
    "passionneraient": "passionner",
    "passionnerais": "passionner",
    "passionnerait": "passionner",
    "passionneras": "passionner",
    "passionnerez": "passionner",
    "passionneriez": "passionner",
    "passionnerions": "passionner",
    "passionnerons": "passionner",
    "passionneront": "passionner",
    "passionnes": "passionner",
    "passionnez": "passionner",
    "passionniez": "passionner",
    "passionnions": "passionner",
    "passionnons": "passionner",
    "passionnâmes": "passionner",
    "passionnât": "passionner",
    "passionnâtes": "passionner",
    "passionnèrent": "passionner",
    "passionné": "passionner",
    "passionnée": "passionner",
    "passionnées": "passionner",
    "passionnés": "passionner",
    "passions": "passion",
    "passive": "passiver",
    "passives": "passif",
    "passivités": "passivité",
    "passoires": "passoire",
    "passons": "passer",
    "passâmes": "passer",
    "passât": "passer",
    "passâtes": "passer",
    "passèrent": "passer",
    "passé": "passer",
    "passée": "passer",
    "passées": "passer",
    "passéismes": "passéisme",
    "passés": "passer",
    "pastagas": "pastaga",
    "pastellistes": "pastelliste",
    "pastels": "pastel",
    "pasteurisations": "pasteurisation",
    "pasteurisée": "pasteurisé",
    "pasteurisés": "pasteurisé",
    "pasteurs": "pasteur",
    "pasticha": "pasticher",
    "pastichai": "pasticher",
    "pastichait": "pasticher",
    "pastiches": "pastiche",
    "pastiché": "pasticher",
    "pastilles": "pastille",
    "pastorale": "pastoral",
    "pastorales": "pastorale",
    "pastoraux": "pastoral",
    "pastoureaux": "pastoureau",
    "pastourelle": "pastoureau",
    "pastourelles": "pastoureau",
    "pastèques": "pastèque",
    "pataches": "patache",
    "patachons": "patachon",
    "patafiole": "patafioler",
    "patagons": "patagon",
    "patapoufs": "patapouf",
    "patates": "patate",
    "pataude": "pataud",
    "pataudes": "pataud",
    "patauds": "pataud",
    "patauge": "patauger",
    "pataugea": "patauger",
    "pataugeai": "patauger",
    "pataugeaient": "patauger",
    "pataugeais": "patauger",
    "pataugeait": "patauger",
    "pataugeant": "patauger",
    "pataugeas": "patauger",
    "pataugeasse": "patauger",
    "pataugeassent": "patauger",
    "pataugeasses": "patauger",
    "pataugeassiez": "patauger",
    "pataugeassions": "patauger",
    "pataugent": "patauger",
    "pataugeons": "patauger",
    "pataugera": "patauger",
    "pataugerai": "patauger",
    "pataugeraient": "patauger",
    "pataugerais": "patauger",
    "pataugerait": "patauger",
    "pataugeras": "patauger",
    "pataugerez": "patauger",
    "pataugeriez": "patauger",
    "pataugerions": "patauger",
    "pataugerons": "patauger",
    "pataugeront": "patauger",
    "patauges": "patauger",
    "pataugez": "patauger",
    "pataugeâmes": "patauger",
    "pataugeât": "patauger",
    "pataugeâtes": "patauger",
    "pataugiez": "patauger",
    "pataugions": "patauger",
    "pataugèrent": "patauger",
    "pataugé": "patauger",
    "patches": "patch",
    "patchoulis": "patchouli",
    "patchs": "patch",
    "patchworks": "patchwork",
    "pateline": "patelin",
    "patelines": "patelin",
    "patelins": "patelin",
    "patelles": "patelle",
    "patenta": "patenter",
    "patentai": "patenter",
    "patentaient": "patenter",
    "patentais": "patenter",
    "patentait": "patenter",
    "patentant": "patenter",
    "patentas": "patenter",
    "patentasse": "patenter",
    "patentassent": "patenter",
    "patentasses": "patenter",
    "patentassiez": "patenter",
    "patentassions": "patenter",
    "patente": "patenter",
    "patentent": "patenter",
    "patentera": "patenter",
    "patenterai": "patenter",
    "patenteraient": "patenter",
    "patenterais": "patenter",
    "patenterait": "patenter",
    "patenteras": "patenter",
    "patenterez": "patenter",
    "patenteriez": "patenter",
    "patenterions": "patenter",
    "patenterons": "patenter",
    "patenteront": "patenter",
    "patentes": "patenter",
    "patentez": "patenter",
    "patentiez": "patenter",
    "patentions": "patenter",
    "patentons": "patenter",
    "patents": "patent",
    "patentâmes": "patenter",
    "patentât": "patenter",
    "patentâtes": "patenter",
    "patentèrent": "patenter",
    "patenté": "patenter",
    "patentée": "patenter",
    "patentées": "patenter",
    "patentés": "patenter",
    "patenôtres": "patenôtre",
    "paternalismes": "paternalisme",
    "paternalistes": "paternaliste",
    "paternelle": "paternel",
    "paternelles": "paternel",
    "paternels": "paternel",
    "paternes": "paterne",
    "paternités": "paternité",
    "pathogènes": "pathogène",
    "pathologies": "pathologie",
    "pathologiques": "pathologique",
    "pathophysiologies": "pathophysiologie",
    "pathétiques": "pathétique",
    "patibulaires": "patibulaire",
    "patiences": "patience",
    "patienta": "patienter",
    "patientai": "patienter",
    "patientaient": "patienter",
    "patientais": "patienter",
    "patientait": "patienter",
    "patientant": "patienter",
    "patientas": "patienter",
    "patientasse": "patienter",
    "patientassent": "patienter",
    "patientasses": "patienter",
    "patientassiez": "patienter",
    "patientassions": "patienter",
    "patiente": "patienter",
    "patientent": "patienter",
    "patientera": "patienter",
    "patienterai": "patienter",
    "patienteraient": "patienter",
    "patienterais": "patienter",
    "patienterait": "patienter",
    "patienteras": "patienter",
    "patienterez": "patienter",
    "patienteriez": "patienter",
    "patienterions": "patienter",
    "patienterons": "patienter",
    "patienteront": "patienter",
    "patientes": "patienter",
    "patientez": "patienter",
    "patientiez": "patienter",
    "patientions": "patienter",
    "patientons": "patienter",
    "patients": "patient",
    "patientâmes": "patienter",
    "patientât": "patienter",
    "patientâtes": "patienter",
    "patientèrent": "patienter",
    "patienté": "patienter",
    "patina": "patiner",
    "patinages": "patinage",
    "patinai": "patiner",
    "patinaient": "patiner",
    "patinais": "patiner",
    "patinait": "patiner",
    "patinant": "patiner",
    "patinas": "patiner",
    "patinasse": "patiner",
    "patinassent": "patiner",
    "patinasses": "patiner",
    "patinassiez": "patiner",
    "patinassions": "patiner",
    "patine": "patiner",
    "patinent": "patiner",
    "patinera": "patiner",
    "patinerai": "patiner",
    "patineraient": "patiner",
    "patinerais": "patiner",
    "patinerait": "patiner",
    "patineras": "patiner",
    "patinerez": "patiner",
    "patineriez": "patiner",
    "patinerions": "patiner",
    "patinerons": "patiner",
    "patineront": "patiner",
    "patines": "patiner",
    "patinettes": "patinette",
    "patineurs": "patineur",
    "patineuse": "patineur",
    "patineuses": "patineur",
    "patinez": "patiner",
    "patiniez": "patiner",
    "patinions": "patiner",
    "patinoires": "patinoire",
    "patinons": "patiner",
    "patins": "patin",
    "patinâmes": "patiner",
    "patinât": "patiner",
    "patinâtes": "patiner",
    "patinèrent": "patiner",
    "patiné": "patiner",
    "patinée": "patiner",
    "patinées": "patiner",
    "patinés": "patiner",
    "patios": "patio",
    "patoches": "patoche",
    "patoisante": "patoisant",
    "patoise": "patoiser",
    "patouilla": "patouiller",
    "patouillai": "patouiller",
    "patouillaient": "patouiller",
    "patouillais": "patouiller",
    "patouillait": "patouiller",
    "patouillant": "patouiller",
    "patouillas": "patouiller",
    "patouillasse": "patouiller",
    "patouillassent": "patouiller",
    "patouillasses": "patouiller",
    "patouillassiez": "patouiller",
    "patouillassions": "patouiller",
    "patouille": "patouiller",
    "patouillent": "patouiller",
    "patouillera": "patouiller",
    "patouillerai": "patouiller",
    "patouilleraient": "patouiller",
    "patouillerais": "patouiller",
    "patouillerait": "patouiller",
    "patouilleras": "patouiller",
    "patouillerez": "patouiller",
    "patouilleriez": "patouiller",
    "patouillerions": "patouiller",
    "patouillerons": "patouiller",
    "patouilleront": "patouiller",
    "patouilles": "patouiller",
    "patouillez": "patouiller",
    "patouilliez": "patouiller",
    "patouillions": "patouiller",
    "patouillons": "patouiller",
    "patouillâmes": "patouiller",
    "patouillât": "patouiller",
    "patouillâtes": "patouiller",
    "patouillèrent": "patouiller",
    "patouillé": "patouiller",
    "patraques": "patraque",
    "patriarcale": "patriarcal",
    "patriarcales": "patriarcal",
    "patriarcats": "patriarcat",
    "patriarcaux": "patriarcal",
    "patriarches": "patriarche",
    "patricienne": "patricien",
    "patriciennes": "patricien",
    "patriciens": "patricien",
    "patries": "patrie",
    "patrilocale": "patrilocal",
    "patrilocales": "patrilocal",
    "patrilocaux": "patrilocal",
    "patrimoines": "patrimoine",
    "patrimoniale": "patrimonial",
    "patrimoniales": "patrimonial",
    "patrimoniaux": "patrimonial",
    "patriotardes": "patriotard",
    "patriotards": "patriotard",
    "patriotes": "patriote",
    "patriotiques": "patriotique",
    "patriotismes": "patriotisme",
    "patrologies": "patrologie",
    "patronages": "patronage",
    "patronale": "patronal",
    "patronales": "patronal",
    "patronats": "patronat",
    "patronaux": "patronal",
    "patronna": "patronner",
    "patronnai": "patronner",
    "patronnaient": "patronner",
    "patronnais": "patronner",
    "patronnait": "patronner",
    "patronnant": "patronner",
    "patronnas": "patronner",
    "patronnasse": "patronner",
    "patronnassent": "patronner",
    "patronnasses": "patronner",
    "patronnassiez": "patronner",
    "patronnassions": "patronner",
    "patronne": "patronner",
    "patronnent": "patronner",
    "patronnera": "patronner",
    "patronnerai": "patronner",
    "patronneraient": "patronner",
    "patronnerais": "patronner",
    "patronnerait": "patronner",
    "patronneras": "patronner",
    "patronnerez": "patronner",
    "patronneriez": "patronner",
    "patronnerions": "patronner",
    "patronnerons": "patronner",
    "patronneront": "patronner",
    "patronnes": "patronner",
    "patronnesses": "patronnesse",
    "patronnez": "patronner",
    "patronniez": "patronner",
    "patronnions": "patronner",
    "patronnons": "patronner",
    "patronnâmes": "patronner",
    "patronnât": "patronner",
    "patronnâtes": "patronner",
    "patronnèrent": "patronner",
    "patronné": "patronner",
    "patronnée": "patronner",
    "patronnées": "patronner",
    "patronnés": "patronner",
    "patrons": "patron",
    "patronymes": "patronyme",
    "patronymiques": "patronymique",
    "patrouilla": "patrouiller",
    "patrouillai": "patrouiller",
    "patrouillaient": "patrouiller",
    "patrouillais": "patrouiller",
    "patrouillait": "patrouiller",
    "patrouillant": "patrouiller",
    "patrouillas": "patrouiller",
    "patrouillasse": "patrouiller",
    "patrouillassent": "patrouiller",
    "patrouillasses": "patrouiller",
    "patrouillassiez": "patrouiller",
    "patrouillassions": "patrouiller",
    "patrouille": "patrouiller",
    "patrouillent": "patrouiller",
    "patrouillera": "patrouiller",
    "patrouillerai": "patrouiller",
    "patrouilleraient": "patrouiller",
    "patrouillerais": "patrouiller",
    "patrouillerait": "patrouiller",
    "patrouilleras": "patrouiller",
    "patrouillerez": "patrouiller",
    "patrouilleriez": "patrouiller",
    "patrouillerions": "patrouiller",
    "patrouillerons": "patrouiller",
    "patrouilleront": "patrouiller",
    "patrouilles": "patrouiller",
    "patrouilleurs": "patrouilleur",
    "patrouillez": "patrouiller",
    "patrouilliez": "patrouiller",
    "patrouillions": "patrouiller",
    "patrouillons": "patrouiller",
    "patrouillâmes": "patrouiller",
    "patrouillât": "patrouiller",
    "patrouillâtes": "patrouiller",
    "patrouillèrent": "patrouiller",
    "patrouillé": "patrouiller",
    "patrouillée": "patrouiller",
    "patrouillées": "patrouiller",
    "patrouillés": "patrouiller",
    "pattemouilles": "pattemouille",
    "pattes": "patte",
    "pattes-d'oie": "patte-d'oie",
    "pattes-de-loup": "patte-de-loup",
    "pattus": "pattu",
    "pattée": "patté",
    "paturons": "paturon",
    "patènes": "patène",
    "patères": "patère",
    "paulinienne": "paulinien",
    "paulownias": "paulownia",
    "pauma": "paumer",
    "paumai": "paumer",
    "paumaient": "paumer",
    "paumais": "paumer",
    "paumait": "paumer",
    "paumant": "paumer",
    "paumas": "paumer",
    "paumasse": "paumer",
    "paumassent": "paumer",
    "paumasses": "paumer",
    "paumassiez": "paumer",
    "paumassions": "paumer",
    "paume": "paumer",
    "paumelles": "paumelle",
    "paument": "paumer",
    "paumera": "paumer",
    "paumerai": "paumer",
    "paumeraient": "paumer",
    "paumerais": "paumer",
    "paumerait": "paumer",
    "paumeras": "paumer",
    "paumerez": "paumer",
    "paumeriez": "paumer",
    "paumerions": "paumer",
    "paumerons": "paumer",
    "paumeront": "paumer",
    "paumes": "paumer",
    "paumez": "paumer",
    "paumiez": "paumer",
    "paumions": "paumer",
    "paumons": "paumer",
    "paumâmes": "paumer",
    "paumât": "paumer",
    "paumâtes": "paumer",
    "paumèrent": "paumer",
    "paumé": "paumer",
    "paumée": "paumer",
    "paumées": "paumer",
    "paumés": "paumer",
    "paupiettes": "paupiette",
    "paupières": "paupière",
    "paupérisations": "paupérisation",
    "paupérise": "paupériser",
    "paupérismes": "paupérisme",
    "pauses": "pause",
    "pauses-café": "pause-café",
    "pauses-repas": "pause-repas",
    "pausez": "pauser",
    "pauvres": "pauvre",
    "pauvresse": "pauvre",
    "pauvresses": "pauvresse",
    "pauvrets": "pauvret",
    "pauvrettes": "pauvrette",
    "pauvretés": "pauvreté",
    "pava": "paver",
    "pavages": "pavage",
    "pavai": "paver",
    "pavaient": "paver",
    "pavais": "paver",
    "pavait": "paver",
    "pavana": "pavaner",
    "pavanai": "pavaner",
    "pavanaient": "pavaner",
    "pavanais": "pavaner",
    "pavanait": "pavaner",
    "pavanant": "pavaner",
    "pavanas": "pavaner",
    "pavanasse": "pavaner",
    "pavanassent": "pavaner",
    "pavanasses": "pavaner",
    "pavanassiez": "pavaner",
    "pavanassions": "pavaner",
    "pavane": "pavaner",
    "pavanent": "pavaner",
    "pavanera": "pavaner",
    "pavanerai": "pavaner",
    "pavaneraient": "pavaner",
    "pavanerais": "pavaner",
    "pavanerait": "pavaner",
    "pavaneras": "pavaner",
    "pavanerez": "pavaner",
    "pavaneriez": "pavaner",
    "pavanerions": "pavaner",
    "pavanerons": "pavaner",
    "pavaneront": "pavaner",
    "pavanes": "pavaner",
    "pavanez": "pavaner",
    "pavaniez": "pavaner",
    "pavanions": "pavaner",
    "pavanons": "pavaner",
    "pavant": "paver",
    "pavanâmes": "pavaner",
    "pavanât": "pavaner",
    "pavanâtes": "pavaner",
    "pavanèrent": "pavaner",
    "pavané": "pavaner",
    "pavanée": "pavaner",
    "pavanées": "pavaner",
    "pavanés": "pavaner",
    "pavas": "paver",
    "pavasse": "paver",
    "pavassent": "paver",
    "pavasses": "paver",
    "pavassiez": "paver",
    "pavassions": "paver",
    "pave": "paver",
    "pavements": "pavement",
    "pavent": "paver",
    "pavera": "paver",
    "paverai": "paver",
    "paveraient": "paver",
    "paverais": "paver",
    "paverait": "paver",
    "paveras": "paver",
    "paverez": "paver",
    "paveriez": "paver",
    "paverions": "paver",
    "paverons": "paver",
    "paveront": "paver",
    "paves": "paver",
    "pavetons": "paveton",
    "paveurs": "paveur",
    "pavez": "paver",
    "paviez": "paver",
    "pavillonnaires": "pavillonnaire",
    "pavillons": "pavillon",
    "pavions": "paver",
    "pavlovienne": "pavlovien",
    "pavoisa": "pavoiser",
    "pavoisai": "pavoiser",
    "pavoisaient": "pavoiser",
    "pavoisais": "pavoiser",
    "pavoisait": "pavoiser",
    "pavoisant": "pavoiser",
    "pavoisas": "pavoiser",
    "pavoisasse": "pavoiser",
    "pavoisassent": "pavoiser",
    "pavoisasses": "pavoiser",
    "pavoisassiez": "pavoiser",
    "pavoisassions": "pavoiser",
    "pavoise": "pavoiser",
    "pavoisent": "pavoiser",
    "pavoisera": "pavoiser",
    "pavoiserai": "pavoiser",
    "pavoiseraient": "pavoiser",
    "pavoiserais": "pavoiser",
    "pavoiserait": "pavoiser",
    "pavoiseras": "pavoiser",
    "pavoiserez": "pavoiser",
    "pavoiseriez": "pavoiser",
    "pavoiserions": "pavoiser",
    "pavoiserons": "pavoiser",
    "pavoiseront": "pavoiser",
    "pavoises": "pavoiser",
    "pavoisez": "pavoiser",
    "pavoisiez": "pavoiser",
    "pavoisions": "pavoiser",
    "pavoisons": "pavoiser",
    "pavoisâmes": "pavoiser",
    "pavoisât": "pavoiser",
    "pavoisâtes": "pavoiser",
    "pavoisèrent": "pavoiser",
    "pavoisé": "pavoiser",
    "pavoisée": "pavoiser",
    "pavoisées": "pavoiser",
    "pavoisés": "pavoiser",
    "pavons": "paver",
    "pavots": "pavot",
    "pavâmes": "paver",
    "pavât": "paver",
    "pavâtes": "paver",
    "pavèrent": "paver",
    "pavé": "paver",
    "pavée": "paver",
    "pavées": "paver",
    "pavés": "paver",
    "paya": "payer",
    "payables": "payable",
    "payai": "payer",
    "payaient": "payer",
    "payais": "payer",
    "payait": "payer",
    "payant": "payer",
    "payante": "payant",
    "payantes": "payant",
    "payants": "payant",
    "payas": "payer",
    "payasse": "payer",
    "payassent": "payer",
    "payasses": "payer",
    "payassiez": "payer",
    "payassions": "payer",
    "paye": "payer",
    "payements": "payement",
    "payent": "payer",
    "payera": "payer",
    "payerai": "payer",
    "payeraient": "payer",
    "payerais": "payer",
    "payerait": "payer",
    "payeras": "payer",
    "payerez": "payer",
    "payeriez": "payer",
    "payerions": "payer",
    "payerons": "payer",
    "payeront": "payer",
    "payes": "payer",
    "payeurs": "payeur",
    "payeuse": "payeur",
    "payeuses": "payeur",
    "payez": "payer",
    "payiez": "payer",
    "payions": "payer",
    "payons": "payer",
    "paysagers": "paysager",
    "paysages": "paysage",
    "paysagistes": "paysagiste",
    "paysagés": "paysagé",
    "paysannats": "paysannat",
    "paysanne": "paysan",
    "paysanneries": "paysannerie",
    "paysannes": "paysan",
    "paysans": "paysan",
    "payâmes": "payer",
    "payât": "payer",
    "payâtes": "payer",
    "payèrent": "payer",
    "payé": "payer",
    "payée": "payer",
    "payées": "payer",
    "payés": "payer",
    "paît": "paître",
    "paîtra": "paître",
    "paîtrai": "paître",
    "paîtraient": "paître",
    "paîtrais": "paître",
    "paîtrait": "paître",
    "paîtras": "paître",
    "paîtrez": "paître",
    "paîtriez": "paître",
    "paîtrions": "paître",
    "paîtrons": "paître",
    "paîtront": "paître",
    "païenne": "païen",
    "païennes": "païen",
    "païens": "païen",
    "peauciers": "peaucier",
    "peaufina": "peaufiner",
    "peaufinai": "peaufiner",
    "peaufinaient": "peaufiner",
    "peaufinais": "peaufiner",
    "peaufinait": "peaufiner",
    "peaufinant": "peaufiner",
    "peaufinas": "peaufiner",
    "peaufinasse": "peaufiner",
    "peaufinassent": "peaufiner",
    "peaufinasses": "peaufiner",
    "peaufinassiez": "peaufiner",
    "peaufinassions": "peaufiner",
    "peaufine": "peaufiner",
    "peaufinent": "peaufiner",
    "peaufinera": "peaufiner",
    "peaufinerai": "peaufiner",
    "peaufineraient": "peaufiner",
    "peaufinerais": "peaufiner",
    "peaufinerait": "peaufiner",
    "peaufineras": "peaufiner",
    "peaufinerez": "peaufiner",
    "peaufineriez": "peaufiner",
    "peaufinerions": "peaufiner",
    "peaufinerons": "peaufiner",
    "peaufineront": "peaufiner",
    "peaufines": "peaufiner",
    "peaufinez": "peaufiner",
    "peaufiniez": "peaufiner",
    "peaufinions": "peaufiner",
    "peaufinons": "peaufiner",
    "peaufinâmes": "peaufiner",
    "peaufinât": "peaufiner",
    "peaufinâtes": "peaufiner",
    "peaufinèrent": "peaufiner",
    "peaufiné": "peaufiner",
    "peaufinée": "peaufiner",
    "peaufinées": "peaufiner",
    "peaufinés": "peaufiner",
    "peausseries": "peausserie",
    "peaux": "peau",
    "peaux-rouges": "peau-rouge",
    "peccadilles": "peccadille",
    "pechblendes": "pechblende",
    "pecnots": "pecnot",
    "pectorale": "pectoral",
    "pectorales": "pectoral",
    "pectoraux": "pectoral",
    "pedigrees": "pedigree",
    "pedzouilles": "pedzouille",
    "peelings": "peeling",
    "pegmatites": "pegmatite",
    "peigna": "peigner",
    "peignai": "peigner",
    "peignaient": "peindre",
    "peignais": "peindre",
    "peignait": "peindre",
    "peignant": "peindre",
    "peignas": "peigner",
    "peignasse": "peigner",
    "peignassent": "peigner",
    "peignasses": "peigner",
    "peignassiez": "peigner",
    "peignassions": "peigner",
    "peigne": "peindre",
    "peigne-culs": "peigne-cul",
    "peignent": "peindre",
    "peignera": "peigner",
    "peignerai": "peigner",
    "peigneraient": "peigner",
    "peignerais": "peigner",
    "peignerait": "peigner",
    "peigneras": "peigner",
    "peignerez": "peigner",
    "peigneriez": "peigner",
    "peignerions": "peigner",
    "peignerons": "peigner",
    "peigneront": "peigner",
    "peignes": "peindre",
    "peignez": "peindre",
    "peigniez": "peindre",
    "peignions": "peindre",
    "peignirent": "peindre",
    "peignis": "peindre",
    "peignisse": "peindre",
    "peignissent": "peindre",
    "peignisses": "peindre",
    "peignissiez": "peindre",
    "peignissions": "peindre",
    "peignit": "peindre",
    "peignoirs": "peignoir",
    "peignons": "peindre",
    "peignâmes": "peigner",
    "peignât": "peigner",
    "peignâtes": "peigner",
    "peignèrent": "peigner",
    "peigné": "peigner",
    "peignée": "peigner",
    "peignées": "peigner",
    "peignés": "peigner",
    "peignîmes": "peindre",
    "peignît": "peindre",
    "peignîtes": "peindre",
    "peina": "peiner",
    "peinai": "peiner",
    "peinaient": "peiner",
    "peinais": "peiner",
    "peinait": "peiner",
    "peinant": "peiner",
    "peinarde": "peinard",
    "peinardes": "peinard",
    "peinards": "peinard",
    "peinas": "peiner",
    "peinasse": "peiner",
    "peinassent": "peiner",
    "peinasses": "peiner",
    "peinassiez": "peiner",
    "peinassions": "peiner",
    "peindra": "peindre",
    "peindrai": "peindre",
    "peindraient": "peindre",
    "peindrais": "peindre",
    "peindrait": "peindre",
    "peindras": "peindre",
    "peindrez": "peindre",
    "peindriez": "peindre",
    "peindrions": "peindre",
    "peindrons": "peindre",
    "peindront": "peindre",
    "peine": "peiner",
    "peinent": "peiner",
    "peinera": "peiner",
    "peinerai": "peiner",
    "peineraient": "peiner",
    "peinerais": "peiner",
    "peinerait": "peiner",
    "peineras": "peiner",
    "peinerez": "peiner",
    "peineriez": "peiner",
    "peinerions": "peiner",
    "peinerons": "peiner",
    "peineront": "peiner",
    "peines": "peiner",
    "peinez": "peiner",
    "peiniez": "peiner",
    "peinions": "peiner",
    "peinons": "peiner",
    "peins": "peindre",
    "peint": "peindre",
    "peinte": "peint",
    "peintes": "peint",
    "peintres": "peintre",
    "peints": "peint",
    "peintures": "peinture",
    "peinturlura": "peinturlurer",
    "peinturlurai": "peinturlurer",
    "peinturluraient": "peinturlurer",
    "peinturlurais": "peinturlurer",
    "peinturlurait": "peinturlurer",
    "peinturlurant": "peinturlurer",
    "peinturluras": "peinturlurer",
    "peinturlurasse": "peinturlurer",
    "peinturlurassent": "peinturlurer",
    "peinturlurasses": "peinturlurer",
    "peinturlurassiez": "peinturlurer",
    "peinturlurassions": "peinturlurer",
    "peinturlure": "peinturlurer",
    "peinturlurent": "peinturlurer",
    "peinturlurera": "peinturlurer",
    "peinturlurerai": "peinturlurer",
    "peinturlureraient": "peinturlurer",
    "peinturlurerais": "peinturlurer",
    "peinturlurerait": "peinturlurer",
    "peinturlureras": "peinturlurer",
    "peinturlurerez": "peinturlurer",
    "peinturlureriez": "peinturlurer",
    "peinturlurerions": "peinturlurer",
    "peinturlurerons": "peinturlurer",
    "peinturlureront": "peinturlurer",
    "peinturlures": "peinturlurer",
    "peinturlureurs": "peinturlureur",
    "peinturlurez": "peinturlurer",
    "peinturluriez": "peinturlurer",
    "peinturlurions": "peinturlurer",
    "peinturlurons": "peinturlurer",
    "peinturlurâmes": "peinturlurer",
    "peinturlurât": "peinturlurer",
    "peinturlurâtes": "peinturlurer",
    "peinturlurèrent": "peinturlurer",
    "peinturluré": "peinturlurer",
    "peinturlurée": "peinturlurer",
    "peinturlurées": "peinturlurer",
    "peinturlurés": "peinturlurer",
    "peinturé": "peinturer",
    "peinturée": "peinturer",
    "peinâmes": "peiner",
    "peinât": "peiner",
    "peinâtes": "peiner",
    "peinèrent": "peiner",
    "peiné": "peiner",
    "peinée": "peiner",
    "peinées": "peiner",
    "peinés": "peiner",
    "pela": "peler",
    "pelades": "pelade",
    "pelages": "pelage",
    "pelai": "peler",
    "pelaient": "peler",
    "pelais": "peler",
    "pelait": "peler",
    "pelant": "peler",
    "pelas": "peler",
    "pelasse": "peler",
    "pelassent": "peler",
    "pelasses": "peler",
    "pelassiez": "peler",
    "pelassions": "peler",
    "pelez": "peler",
    "peliez": "peler",
    "pelions": "peler",
    "pelisses": "pelisse",
    "pellagres": "pellagre",
    "pelles": "pelle",
    "pelles-bêches": "pelle-bêche",
    "pelles-pioches": "pelle-pioche",
    "pelleta": "pelleter",
    "pelletai": "pelleter",
    "pelletaient": "pelleter",
    "pelletais": "pelleter",
    "pelletait": "pelleter",
    "pelletant": "pelleter",
    "pelletas": "pelleter",
    "pelletasse": "pelleter",
    "pelletassent": "pelleter",
    "pelletasses": "pelleter",
    "pelletassiez": "pelleter",
    "pelletassions": "pelleter",
    "pelleteries": "pelleterie",
    "pelleteuse": "pelleteur",
    "pelleteuses": "pelleteuse",
    "pelletez": "pelleter",
    "pelletiers": "pelletier",
    "pelletiez": "pelleter",
    "pelletions": "pelleter",
    "pelletons": "pelleter",
    "pellette": "pelleter",
    "pellettent": "pelleter",
    "pellettera": "pelleter",
    "pelletterai": "pelleter",
    "pelletteraient": "pelleter",
    "pelletterais": "pelleter",
    "pelletterait": "pelleter",
    "pelletteras": "pelleter",
    "pelletterez": "pelleter",
    "pelletteriez": "pelleter",
    "pelletterions": "pelleter",
    "pelletterons": "pelleter",
    "pelletteront": "pelleter",
    "pellettes": "pelleter",
    "pelletâmes": "pelleter",
    "pelletât": "pelleter",
    "pelletâtes": "pelleter",
    "pelletèrent": "pelleter",
    "pelleté": "pelleter",
    "pelletée": "pelleter",
    "pelletées": "pelleter",
    "pelletés": "pelleter",
    "pelliculages": "pelliculage",
    "pellicules": "pellicule",
    "pelliculé": "pelliculer",
    "pelliculée": "pelliculer",
    "pelons": "peler",
    "pelota": "peloter",
    "pelotages": "pelotage",
    "pelotai": "peloter",
    "pelotaient": "peloter",
    "pelotais": "peloter",
    "pelotait": "peloter",
    "pelotant": "peloter",
    "pelotaris": "pelotari",
    "pelotas": "peloter",
    "pelotasse": "peloter",
    "pelotassent": "peloter",
    "pelotasses": "peloter",
    "pelotassiez": "peloter",
    "pelotassions": "peloter",
    "pelote": "peloter",
    "pelotent": "peloter",
    "pelotera": "peloter",
    "peloterai": "peloter",
    "peloteraient": "peloter",
    "peloterais": "peloter",
    "peloterait": "peloter",
    "peloteras": "peloter",
    "peloterez": "peloter",
    "peloteriez": "peloter",
    "peloterions": "peloter",
    "peloterons": "peloter",
    "peloteront": "peloter",
    "pelotes": "peloter",
    "peloteurs": "peloteur",
    "peloteuse": "peloteur",
    "pelotez": "peloter",
    "pelotiez": "peloter",
    "pelotions": "peloter",
    "pelotonna": "pelotonner",
    "pelotonnai": "pelotonner",
    "pelotonnaient": "pelotonner",
    "pelotonnais": "pelotonner",
    "pelotonnait": "pelotonner",
    "pelotonnant": "pelotonner",
    "pelotonnas": "pelotonner",
    "pelotonnasse": "pelotonner",
    "pelotonnassent": "pelotonner",
    "pelotonnasses": "pelotonner",
    "pelotonnassiez": "pelotonner",
    "pelotonnassions": "pelotonner",
    "pelotonne": "pelotonner",
    "pelotonnent": "pelotonner",
    "pelotonnera": "pelotonner",
    "pelotonnerai": "pelotonner",
    "pelotonneraient": "pelotonner",
    "pelotonnerais": "pelotonner",
    "pelotonnerait": "pelotonner",
    "pelotonneras": "pelotonner",
    "pelotonnerez": "pelotonner",
    "pelotonneriez": "pelotonner",
    "pelotonnerions": "pelotonner",
    "pelotonnerons": "pelotonner",
    "pelotonneront": "pelotonner",
    "pelotonnes": "pelotonner",
    "pelotonnez": "pelotonner",
    "pelotonniez": "pelotonner",
    "pelotonnions": "pelotonner",
    "pelotonnons": "pelotonner",
    "pelotonnâmes": "pelotonner",
    "pelotonnât": "pelotonner",
    "pelotonnâtes": "pelotonner",
    "pelotonnèrent": "pelotonner",
    "pelotonné": "pelotonner",
    "pelotonnée": "pelotonner",
    "pelotonnées": "pelotonner",
    "pelotonnés": "pelotonner",
    "pelotons": "peloton",
    "pelotâmes": "peloter",
    "pelotât": "peloter",
    "pelotâtes": "peloter",
    "pelotèrent": "peloter",
    "peloté": "peloter",
    "pelotée": "peloter",
    "pelotées": "peloter",
    "pelotés": "peloter",
    "pelouses": "pelouse",
    "peltastes": "peltaste",
    "peluches": "peluche",
    "pelucheuse": "pelucheux",
    "pelucheuses": "pelucheux",
    "peluchée": "peluché",
    "pelures": "pelure",
    "pelvienne": "pelvien",
    "pelâmes": "peler",
    "pelât": "peler",
    "pelâtes": "peler",
    "pelèrent": "peler",
    "pelé": "peler",
    "pelée": "peler",
    "pelées": "peler",
    "pelés": "peler",
    "pemmicans": "pemmican",
    "penalties": "penalty",
    "penaltys": "penalty",
    "penaude": "penaud",
    "penaudes": "penaud",
    "penauds": "penaud",
    "pence": "penny",
    "pencha": "pencher",
    "penchai": "pencher",
    "penchaient": "pencher",
    "penchais": "pencher",
    "penchait": "pencher",
    "penchant": "pencher",
    "penchante": "penchant",
    "penchants": "penchant",
    "penchas": "pencher",
    "penchasse": "pencher",
    "penchassent": "pencher",
    "penchasses": "pencher",
    "penchassiez": "pencher",
    "penchassions": "pencher",
    "penche": "pencher",
    "penchent": "pencher",
    "penchera": "pencher",
    "pencherai": "pencher",
    "pencheraient": "pencher",
    "pencherais": "pencher",
    "pencherait": "pencher",
    "pencheras": "pencher",
    "pencherez": "pencher",
    "pencheriez": "pencher",
    "pencherions": "pencher",
    "pencherons": "pencher",
    "pencheront": "pencher",
    "penches": "pencher",
    "penchez": "pencher",
    "penchiez": "pencher",
    "penchions": "pencher",
    "penchons": "pencher",
    "penchâmes": "pencher",
    "penchât": "pencher",
    "penchâtes": "pencher",
    "penchèrent": "pencher",
    "penché": "pencher",
    "penchée": "pencher",
    "penchées": "pencher",
    "penchés": "pencher",
    "pend": "pendre",
    "pendables": "pendable",
    "pendaient": "pendre",
    "pendais": "pendre",
    "pendaisons": "pendaison",
    "pendait": "pendre",
    "pendant": "pendre",
    "pendante": "pendant",
    "pendantes": "pendante",
    "pendants": "pendante",
    "pendarde": "pendard",
    "pendardes": "pendard",
    "pendards": "pendard",
    "pende": "pendre",
    "pendeloques": "pendeloque",
    "pendent": "pendre",
    "pendentifs": "pendentif",
    "penderies": "penderie",
    "pendes": "pendre",
    "pendez": "pendre",
    "pendiez": "pendre",
    "pendillaient": "pendiller",
    "pendillait": "pendiller",
    "pendillant": "pendiller",
    "pendille": "pendiller",
    "pendions": "pendre",
    "pendirent": "pendre",
    "pendis": "pendre",
    "pendisse": "pendre",
    "pendissent": "pendre",
    "pendisses": "pendre",
    "pendissiez": "pendre",
    "pendissions": "pendre",
    "pendit": "pendre",
    "pendons": "pendre",
    "pendouillaient": "pendouiller",
    "pendouillait": "pendouiller",
    "pendouillant": "pendouiller",
    "pendouille": "pendouiller",
    "pendouillent": "pendouiller",
    "pendouilles": "pendouiller",
    "pendra": "pendre",
    "pendrai": "pendre",
    "pendraient": "pendre",
    "pendrais": "pendre",
    "pendrait": "pendre",
    "pendras": "pendre",
    "pendrez": "pendre",
    "pendriez": "pendre",
    "pendrions": "pendre",
    "pendrons": "pendre",
    "pendront": "pendre",
    "pends": "pendre",
    "pendu": "pendre",
    "pendue": "pendu",
    "pendues": "pendu",
    "pendulait": "penduler",
    "pendules": "pendule",
    "pendulettes": "pendulette",
    "pendus": "pendu",
    "pendîmes": "pendre",
    "pendît": "pendre",
    "pendîtes": "pendre",
    "pennes": "penne",
    "pennies": "penny",
    "pennons": "pennon",
    "pennées": "penné",
    "pensa": "penser",
    "pensai": "penser",
    "pensaient": "penser",
    "pensais": "penser",
    "pensait": "penser",
    "pensant": "penser",
    "pensante": "pensant",
    "pensantes": "pensant",
    "pensants": "pensant",
    "pensas": "penser",
    "pensasse": "penser",
    "pensassent": "penser",
    "pensasses": "penser",
    "pensassiez": "penser",
    "pensassions": "penser",
    "pense": "penser",
    "pense-bêtes": "pense-bête",
    "pensent": "penser",
    "pensera": "penser",
    "penserai": "penser",
    "penseraient": "penser",
    "penserais": "penser",
    "penserait": "penser",
    "penseras": "penser",
    "penserez": "penser",
    "penseriez": "penser",
    "penserions": "penser",
    "penserons": "penser",
    "penseront": "penser",
    "penses": "penser",
    "penseurs": "penseur",
    "penseuse": "penseur",
    "penseuses": "penseur",
    "pensez": "penser",
    "pensiez": "penser",
    "pensifs": "pensif",
    "pensionna": "pensionner",
    "pensionnaires": "pensionnaire",
    "pensionnats": "pensionnat",
    "pensionné": "pensionner",
    "pensionnée": "pensionné",
    "pensionnées": "pensionné",
    "pensionnés": "pensionner",
    "pensions": "pension",
    "pensive": "pensif",
    "pensons": "penser",
    "pensums": "pensum",
    "pensâmes": "penser",
    "pensât": "penser",
    "pensâtes": "penser",
    "pensèrent": "penser",
    "pensé": "penser",
    "pensée": "penser",
    "pensées": "penser",
    "pensés": "penser",
    "pentacles": "pentacle",
    "pentagones": "pentagone",
    "pentagrammes": "pentagramme",
    "pentamètres": "pentamètre",
    "pentathlons": "pentathlon",
    "pentecôtistes": "pentecôtiste",
    "pentes": "pente",
    "penthrites": "penthrite",
    "pentrites": "pentrite",
    "pentue": "pentu",
    "pentues": "pentu",
    "pentures": "penture",
    "pentus": "pentu",
    "peppermints": "peppermint",
    "peps": "pep",
    "pepsines": "pepsine",
    "peptones": "peptone",
    "percales": "percale",
    "perce": "percer",
    "perce-murailles": "perce-muraille",
    "perce-neiges": "perce-neige",
    "perce-oreilles": "perce-oreille",
    "perce-pierres": "perce-pierre",
    "percements": "percement",
    "percent": "percer",
    "percepteurs": "percepteur",
    "perceptibles": "perceptible",
    "perceptions": "perception",
    "perceptive": "perceptif",
    "perceptives": "perceptif",
    "perceptrice": "percepteur",
    "perceptuels": "perceptuel",
    "percera": "percer",
    "percerai": "percer",
    "perceraient": "percer",
    "percerais": "percer",
    "percerait": "percer",
    "perceras": "percer",
    "percerez": "percer",
    "perceriez": "percer",
    "percerions": "percer",
    "percerons": "percer",
    "perceront": "percer",
    "perces": "percer",
    "perceurs": "perceur",
    "perceuse": "perceur",
    "perceuses": "perceur",
    "percevaient": "percevoir",
    "percevais": "percevoir",
    "percevait": "percevoir",
    "percevant": "percevoir",
    "percevez": "percevoir",
    "perceviez": "percevoir",
    "percevions": "percevoir",
    "percevons": "percevoir",
    "percevra": "percevoir",
    "percevrai": "percevoir",
    "percevraient": "percevoir",
    "percevrais": "percevoir",
    "percevrait": "percevoir",
    "percevras": "percevoir",
    "percevrez": "percevoir",
    "percevriez": "percevoir",
    "percevrions": "percevoir",
    "percevrons": "percevoir",
    "percevront": "percevoir",
    "percez": "percer",
    "percha": "percher",
    "perchai": "percher",
    "perchaient": "percher",
    "perchais": "percher",
    "perchait": "percher",
    "perchant": "percher",
    "perchas": "percher",
    "perchasse": "percher",
    "perchassent": "percher",
    "perchasses": "percher",
    "perchassiez": "percher",
    "perchassions": "percher",
    "perche": "percher",
    "perchent": "percher",
    "perchera": "percher",
    "percherai": "percher",
    "percheraient": "percher",
    "percherais": "percher",
    "percherait": "percher",
    "percheras": "percher",
    "percherez": "percher",
    "percheriez": "percher",
    "percherions": "percher",
    "percheronne": "percheron",
    "percheronnes": "percheron",
    "percherons": "percheron",
    "percheront": "percher",
    "perches": "percher",
    "perchettes": "perchette",
    "percheurs": "percheur",
    "perchez": "percher",
    "perchiez": "percher",
    "perchions": "percher",
    "perchistes": "perchiste",
    "perchlorates": "perchlorate",
    "perchmans": "perchman",
    "perchoirs": "perchoir",
    "perchons": "percher",
    "perchâmes": "percher",
    "perchât": "percher",
    "perchâtes": "percher",
    "perchèrent": "percher",
    "perché": "percher",
    "perchée": "percher",
    "perchées": "percher",
    "perchés": "percher",
    "perciez": "percer",
    "percions": "percer",
    "percluse": "perclus",
    "percluses": "perclus",
    "percolateurs": "percolateur",
    "percolations": "percolation",
    "percos": "perco",
    "percussionnistes": "percussionniste",
    "percussions": "percussion",
    "percuta": "percuter",
    "percutai": "percuter",
    "percutaient": "percuter",
    "percutais": "percuter",
    "percutait": "percuter",
    "percutant": "percuter",
    "percutante": "percutant",
    "percutantes": "percutant",
    "percutants": "percutant",
    "percutanée": "percutané",
    "percutanées": "percutané",
    "percutanés": "percutané",
    "percutas": "percuter",
    "percutasse": "percuter",
    "percutassent": "percuter",
    "percutasses": "percuter",
    "percutassiez": "percuter",
    "percutassions": "percuter",
    "percute": "percuter",
    "percutent": "percuter",
    "percutera": "percuter",
    "percuterai": "percuter",
    "percuteraient": "percuter",
    "percuterais": "percuter",
    "percuterait": "percuter",
    "percuteras": "percuter",
    "percuterez": "percuter",
    "percuteriez": "percuter",
    "percuterions": "percuter",
    "percuterons": "percuter",
    "percuteront": "percuter",
    "percutes": "percuter",
    "percuteurs": "percuteur",
    "percutez": "percuter",
    "percutiez": "percuter",
    "percutions": "percuter",
    "percutons": "percuter",
    "percutâmes": "percuter",
    "percutât": "percuter",
    "percutâtes": "percuter",
    "percutèrent": "percuter",
    "percuté": "percuter",
    "percutée": "percuter",
    "percutées": "percuter",
    "percutés": "percuter",
    "percèrent": "percer",
    "percé": "percer",
    "percée": "percer",
    "percées": "percer",
    "percés": "percer",
    "perd": "perdre",
    "perdaient": "perdre",
    "perdais": "perdre",
    "perdait": "perdre",
    "perdant": "perdre",
    "perdante": "perdant",
    "perdantes": "perdant",
    "perdants": "perdant",
    "perde": "perdre",
    "perdent": "perdre",
    "perdes": "perdre",
    "perdez": "perdre",
    "perdiez": "perdre",
    "perdions": "perdre",
    "perdirent": "perdre",
    "perdis": "perdre",
    "perdisse": "perdre",
    "perdissent": "perdre",
    "perdisses": "perdre",
    "perdissiez": "perdre",
    "perdissions": "perdre",
    "perdit": "perdre",
    "perditions": "perdition",
    "perdons": "perdre",
    "perdra": "perdre",
    "perdrai": "perdre",
    "perdraient": "perdre",
    "perdrais": "perdre",
    "perdrait": "perdre",
    "perdras": "perdre",
    "perdreaux": "perdreau",
    "perdrez": "perdre",
    "perdriez": "perdre",
    "perdrions": "perdre",
    "perdrons": "perdre",
    "perdront": "perdre",
    "perds": "perdre",
    "perdu": "perdre",
    "perdue": "perdu",
    "perdues": "perdu",
    "perdura": "perdurer",
    "perdurai": "perdurer",
    "perduraient": "perdurer",
    "perdurais": "perdurer",
    "perdurait": "perdurer",
    "perdurant": "perdurer",
    "perduras": "perdurer",
    "perdurasse": "perdurer",
    "perdurassent": "perdurer",
    "perdurasses": "perdurer",
    "perdurassiez": "perdurer",
    "perdurassions": "perdurer",
    "perdure": "perdurer",
    "perdurent": "perdurer",
    "perdurera": "perdurer",
    "perdurerai": "perdurer",
    "perdureraient": "perdurer",
    "perdurerais": "perdurer",
    "perdurerait": "perdurer",
    "perdureras": "perdurer",
    "perdurerez": "perdurer",
    "perdureriez": "perdurer",
    "perdurerions": "perdurer",
    "perdurerons": "perdurer",
    "perdureront": "perdurer",
    "perdures": "perdurer",
    "perdurez": "perdurer",
    "perduriez": "perdurer",
    "perdurions": "perdurer",
    "perdurons": "perdurer",
    "perdurâmes": "perdurer",
    "perdurât": "perdurer",
    "perdurâtes": "perdurer",
    "perdurèrent": "perdurer",
    "perduré": "perdurer",
    "perdus": "perdu",
    "perdîmes": "perdre",
    "perdît": "perdre",
    "perdîtes": "perdre",
    "perestroïkas": "perestroïka",
    "perfectibles": "perfectible",
    "perfectionna": "perfectionner",
    "perfectionnai": "perfectionner",
    "perfectionnaient": "perfectionner",
    "perfectionnais": "perfectionner",
    "perfectionnait": "perfectionner",
    "perfectionnant": "perfectionner",
    "perfectionnas": "perfectionner",
    "perfectionnasse": "perfectionner",
    "perfectionnassent": "perfectionner",
    "perfectionnasses": "perfectionner",
    "perfectionnassiez": "perfectionner",
    "perfectionnassions": "perfectionner",
    "perfectionne": "perfectionner",
    "perfectionnements": "perfectionnement",
    "perfectionnent": "perfectionner",
    "perfectionnera": "perfectionner",
    "perfectionnerai": "perfectionner",
    "perfectionneraient": "perfectionner",
    "perfectionnerais": "perfectionner",
    "perfectionnerait": "perfectionner",
    "perfectionneras": "perfectionner",
    "perfectionnerez": "perfectionner",
    "perfectionneriez": "perfectionner",
    "perfectionnerions": "perfectionner",
    "perfectionnerons": "perfectionner",
    "perfectionneront": "perfectionner",
    "perfectionnes": "perfectionner",
    "perfectionnez": "perfectionner",
    "perfectionniez": "perfectionner",
    "perfectionnions": "perfectionner",
    "perfectionnismes": "perfectionnisme",
    "perfectionnistes": "perfectionniste",
    "perfectionnons": "perfectionner",
    "perfectionnâmes": "perfectionner",
    "perfectionnât": "perfectionner",
    "perfectionnâtes": "perfectionner",
    "perfectionnèrent": "perfectionner",
    "perfectionné": "perfectionner",
    "perfectionnée": "perfectionner",
    "perfectionnées": "perfectionner",
    "perfectionnés": "perfectionner",
    "perfections": "perfection",
    "perfectos": "perfecto",
    "perfides": "perfide",
    "perfidies": "perfidie",
    "perfora": "perforer",
    "perforai": "perforer",
    "perforaient": "perforer",
    "perforais": "perforer",
    "perforait": "perforer",
    "perforant": "perforer",
    "perforante": "perforant",
    "perforantes": "perforant",
    "perforants": "perforant",
    "perforas": "perforer",
    "perforasse": "perforer",
    "perforassent": "perforer",
    "perforasses": "perforer",
    "perforassiez": "perforer",
    "perforassions": "perforer",
    "perforations": "perforation",
    "perforatrice": "perforateur",
    "perfore": "perforer",
    "perforent": "perforer",
    "perforera": "perforer",
    "perforerai": "perforer",
    "perforeraient": "perforer",
    "perforerais": "perforer",
    "perforerait": "perforer",
    "perforeras": "perforer",
    "perforerez": "perforer",
    "perforeriez": "perforer",
    "perforerions": "perforer",
    "perforerons": "perforer",
    "perforeront": "perforer",
    "perfores": "perforer",
    "perforez": "perforer",
    "perforiez": "perforer",
    "perforions": "perforer",
    "performances": "performance",
    "performante": "performant",
    "performantes": "performant",
    "performants": "performant",
    "performatifs": "performatif",
    "performative": "performatif",
    "performatives": "performatif",
    "perforons": "perforer",
    "perforâmes": "perforer",
    "perforât": "perforer",
    "perforâtes": "perforer",
    "perforèrent": "perforer",
    "perforé": "perforer",
    "perforée": "perforer",
    "perforées": "perforer",
    "perforés": "perforer",
    "perfuse": "perfuser",
    "perfusions": "perfusion",
    "perfusé": "perfuser",
    "pergolas": "pergola",
    "perla": "perler",
    "perlai": "perler",
    "perlaient": "perler",
    "perlais": "perler",
    "perlait": "perler",
    "perlant": "perler",
    "perlas": "perler",
    "perlasse": "perler",
    "perlassent": "perler",
    "perlasses": "perler",
    "perlassiez": "perler",
    "perlassions": "perler",
    "perle": "perler",
    "perlent": "perler",
    "perlera": "perler",
    "perlerai": "perler",
    "perleraient": "perler",
    "perlerais": "perler",
    "perlerait": "perler",
    "perleras": "perler",
    "perlerez": "perler",
    "perleriez": "perler",
    "perlerions": "perler",
    "perlerons": "perler",
    "perleront": "perler",
    "perles": "perler",
    "perlez": "perler",
    "perliez": "perler",
    "perlimpinpins": "perlimpinpin",
    "perlions": "perler",
    "perlière": "perlier",
    "perlières": "perlier",
    "perlons": "perler",
    "perlots": "perlot",
    "perlouses": "perlouse",
    "perlouzes": "perlouze",
    "perlâmes": "perler",
    "perlât": "perler",
    "perlâtes": "perler",
    "perlèrent": "perler",
    "perlé": "perler",
    "perlée": "perler",
    "perlées": "perler",
    "perlés": "perler",
    "permafrosts": "permafrost",
    "permane": "permaner",
    "permanences": "permanence",
    "permanente": "permanenter",
    "permanentes": "permanente",
    "permanents": "permanent",
    "permanenté": "permanenter",
    "permanentée": "permanenter",
    "permanentés": "permanenter",
    "permanganates": "permanganate",
    "permes": "perme",
    "permet": "permettre",
    "permets": "permettre",
    "permettaient": "permettre",
    "permettais": "permettre",
    "permettait": "permettre",
    "permettant": "permettre",
    "permette": "permettre",
    "permettent": "permettre",
    "permettes": "permettre",
    "permettez": "permettre",
    "permettiez": "permettre",
    "permettions": "permettre",
    "permettons": "permettre",
    "permettra": "permettre",
    "permettrai": "permettre",
    "permettraient": "permettre",
    "permettrais": "permettre",
    "permettrait": "permettre",
    "permettras": "permettre",
    "permettrez": "permettre",
    "permettriez": "permettre",
    "permettrions": "permettre",
    "permettrons": "permettre",
    "permettront": "permettre",
    "permirent": "permettre",
    "permis": "permettre",
    "permise": "permis",
    "permises": "permis",
    "permisse": "permettre",
    "permissent": "permettre",
    "permisses": "permettre",
    "permissibles": "permissible",
    "permissiez": "permettre",
    "permissifs": "permissif",
    "permissionnaires": "permissionnaire",
    "permissions": "permission",
    "permissive": "permissif",
    "permissives": "permissif",
    "permit": "permettre",
    "permuta": "permuter",
    "permutai": "permuter",
    "permutaient": "permuter",
    "permutais": "permuter",
    "permutait": "permuter",
    "permutant": "permuter",
    "permutas": "permuter",
    "permutasse": "permuter",
    "permutassent": "permuter",
    "permutasses": "permuter",
    "permutassiez": "permuter",
    "permutassions": "permuter",
    "permutations": "permutation",
    "permute": "permuter",
    "permutent": "permuter",
    "permutera": "permuter",
    "permuterai": "permuter",
    "permuteraient": "permuter",
    "permuterais": "permuter",
    "permuterait": "permuter",
    "permuteras": "permuter",
    "permuterez": "permuter",
    "permuteriez": "permuter",
    "permuterions": "permuter",
    "permuterons": "permuter",
    "permuteront": "permuter",
    "permutes": "permuter",
    "permutez": "permuter",
    "permutiez": "permuter",
    "permutions": "permuter",
    "permutons": "permuter",
    "permutâmes": "permuter",
    "permutât": "permuter",
    "permutâtes": "permuter",
    "permutèrent": "permuter",
    "permuté": "permuter",
    "permutée": "permuter",
    "permutées": "permuter",
    "permutés": "permuter",
    "perméabilisa": "perméabiliser",
    "perméabilisai": "perméabiliser",
    "perméabilisaient": "perméabiliser",
    "perméabilisais": "perméabiliser",
    "perméabilisait": "perméabiliser",
    "perméabilisant": "perméabiliser",
    "perméabilisas": "perméabiliser",
    "perméabilisasse": "perméabiliser",
    "perméabilisassent": "perméabiliser",
    "perméabilisasses": "perméabiliser",
    "perméabilisassiez": "perméabiliser",
    "perméabilisassions": "perméabiliser",
    "perméabilise": "perméabiliser",
    "perméabilisent": "perméabiliser",
    "perméabilisera": "perméabiliser",
    "perméabiliserai": "perméabiliser",
    "perméabiliseraient": "perméabiliser",
    "perméabiliserais": "perméabiliser",
    "perméabiliserait": "perméabiliser",
    "perméabiliseras": "perméabiliser",
    "perméabiliserez": "perméabiliser",
    "perméabiliseriez": "perméabiliser",
    "perméabiliserions": "perméabiliser",
    "perméabiliserons": "perméabiliser",
    "perméabiliseront": "perméabiliser",
    "perméabilises": "perméabiliser",
    "perméabilisez": "perméabiliser",
    "perméabilisiez": "perméabiliser",
    "perméabilisions": "perméabiliser",
    "perméabilisons": "perméabiliser",
    "perméabilisâmes": "perméabiliser",
    "perméabilisât": "perméabiliser",
    "perméabilisâtes": "perméabiliser",
    "perméabilisèrent": "perméabiliser",
    "perméabilisé": "perméabiliser",
    "perméabilisée": "perméabiliser",
    "perméabilisées": "perméabiliser",
    "perméabilisés": "perméabiliser",
    "perméabilités": "perméabilité",
    "perméables": "perméable",
    "permîmes": "permettre",
    "permît": "permettre",
    "permîtes": "permettre",
    "pernicieuse": "pernicieux",
    "pernicieuses": "pernicieux",
    "pernods": "pernod",
    "peroxydé": "peroxyder",
    "perpendiculaires": "perpendiculaire",
    "perplexes": "perplexe",
    "perplexités": "perplexité",
    "perpètre": "perpétrer",
    "perpètrent": "perpétrer",
    "perpètres": "perpétrer",
    "perpétra": "perpétrer",
    "perpétrai": "perpétrer",
    "perpétraient": "perpétrer",
    "perpétrais": "perpétrer",
    "perpétrait": "perpétrer",
    "perpétrant": "perpétrer",
    "perpétras": "perpétrer",
    "perpétrasse": "perpétrer",
    "perpétrassent": "perpétrer",
    "perpétrasses": "perpétrer",
    "perpétrassiez": "perpétrer",
    "perpétrassions": "perpétrer",
    "perpétrera": "perpétrer",
    "perpétrerai": "perpétrer",
    "perpétreraient": "perpétrer",
    "perpétrerais": "perpétrer",
    "perpétrerait": "perpétrer",
    "perpétreras": "perpétrer",
    "perpétrerez": "perpétrer",
    "perpétreriez": "perpétrer",
    "perpétrerions": "perpétrer",
    "perpétrerons": "perpétrer",
    "perpétreront": "perpétrer",
    "perpétrez": "perpétrer",
    "perpétriez": "perpétrer",
    "perpétrions": "perpétrer",
    "perpétrons": "perpétrer",
    "perpétrâmes": "perpétrer",
    "perpétrât": "perpétrer",
    "perpétrâtes": "perpétrer",
    "perpétrèrent": "perpétrer",
    "perpétré": "perpétrer",
    "perpétrée": "perpétrer",
    "perpétrées": "perpétrer",
    "perpétrés": "perpétrer",
    "perpétua": "perpétuer",
    "perpétuai": "perpétuer",
    "perpétuaient": "perpétuer",
    "perpétuais": "perpétuer",
    "perpétuait": "perpétuer",
    "perpétuant": "perpétuer",
    "perpétuas": "perpétuer",
    "perpétuasse": "perpétuer",
    "perpétuassent": "perpétuer",
    "perpétuasses": "perpétuer",
    "perpétuassiez": "perpétuer",
    "perpétuassions": "perpétuer",
    "perpétuations": "perpétuation",
    "perpétue": "perpétuer",
    "perpétuelle": "perpétuel",
    "perpétuelles": "perpétuel",
    "perpétuels": "perpétuel",
    "perpétuent": "perpétuer",
    "perpétuera": "perpétuer",
    "perpétuerai": "perpétuer",
    "perpétueraient": "perpétuer",
    "perpétuerais": "perpétuer",
    "perpétuerait": "perpétuer",
    "perpétueras": "perpétuer",
    "perpétuerez": "perpétuer",
    "perpétueriez": "perpétuer",
    "perpétuerions": "perpétuer",
    "perpétuerons": "perpétuer",
    "perpétueront": "perpétuer",
    "perpétues": "perpétuer",
    "perpétuez": "perpétuer",
    "perpétuiez": "perpétuer",
    "perpétuions": "perpétuer",
    "perpétuités": "perpétuité",
    "perpétuons": "perpétuer",
    "perpétuâmes": "perpétuer",
    "perpétuât": "perpétuer",
    "perpétuâtes": "perpétuer",
    "perpétuèrent": "perpétuer",
    "perpétué": "perpétuer",
    "perpétuée": "perpétuer",
    "perpétuées": "perpétuer",
    "perpétués": "perpétuer",
    "perquisitionna": "perquisitionner",
    "perquisitionnai": "perquisitionner",
    "perquisitionnaient": "perquisitionner",
    "perquisitionnais": "perquisitionner",
    "perquisitionnait": "perquisitionner",
    "perquisitionnant": "perquisitionner",
    "perquisitionnas": "perquisitionner",
    "perquisitionnasse": "perquisitionner",
    "perquisitionnassent": "perquisitionner",
    "perquisitionnasses": "perquisitionner",
    "perquisitionnassiez": "perquisitionner",
    "perquisitionnassions": "perquisitionner",
    "perquisitionne": "perquisitionner",
    "perquisitionnent": "perquisitionner",
    "perquisitionnera": "perquisitionner",
    "perquisitionnerai": "perquisitionner",
    "perquisitionneraient": "perquisitionner",
    "perquisitionnerais": "perquisitionner",
    "perquisitionnerait": "perquisitionner",
    "perquisitionneras": "perquisitionner",
    "perquisitionnerez": "perquisitionner",
    "perquisitionneriez": "perquisitionner",
    "perquisitionnerions": "perquisitionner",
    "perquisitionnerons": "perquisitionner",
    "perquisitionneront": "perquisitionner",
    "perquisitionnes": "perquisitionner",
    "perquisitionnez": "perquisitionner",
    "perquisitionniez": "perquisitionner",
    "perquisitionnions": "perquisitionner",
    "perquisitionnons": "perquisitionner",
    "perquisitionnâmes": "perquisitionner",
    "perquisitionnât": "perquisitionner",
    "perquisitionnâtes": "perquisitionner",
    "perquisitionnèrent": "perquisitionner",
    "perquisitionné": "perquisitionner",
    "perquisitionnée": "perquisitionner",
    "perquisitionnées": "perquisitionner",
    "perquisitionnés": "perquisitionner",
    "perquisitions": "perquisition",
    "perrières": "perrière",
    "perrons": "perron",
    "perroquets": "perroquet",
    "perruches": "perruche",
    "perruques": "perruque",
    "perruquiers": "perruquier",
    "perruquière": "perruquier",
    "perrés": "perré",
    "persane": "persan",
    "persanes": "persan",
    "persans": "persan",
    "perses": "perse",
    "persicaires": "persicaire",
    "persiennes": "persienne",
    "persifla": "persifler",
    "persiflages": "persiflage",
    "persiflai": "persifler",
    "persiflaient": "persifler",
    "persiflais": "persifler",
    "persiflait": "persifler",
    "persiflant": "persifler",
    "persiflas": "persifler",
    "persiflasse": "persifler",
    "persiflassent": "persifler",
    "persiflasses": "persifler",
    "persiflassiez": "persifler",
    "persiflassions": "persifler",
    "persifle": "persifler",
    "persiflent": "persifler",
    "persiflera": "persifler",
    "persiflerai": "persifler",
    "persifleraient": "persifler",
    "persiflerais": "persifler",
    "persiflerait": "persifler",
    "persifleras": "persifler",
    "persiflerez": "persifler",
    "persifleriez": "persifler",
    "persiflerions": "persifler",
    "persiflerons": "persifler",
    "persifleront": "persifler",
    "persifles": "persifler",
    "persifleurs": "persifleur",
    "persifleuse": "persifleur",
    "persiflez": "persifler",
    "persifliez": "persifler",
    "persiflions": "persifler",
    "persiflons": "persifler",
    "persiflâmes": "persifler",
    "persiflât": "persifler",
    "persiflâtes": "persifler",
    "persiflèrent": "persifler",
    "persiflé": "persifler",
    "persiflée": "persifler",
    "persiflées": "persifler",
    "persiflés": "persifler",
    "persillades": "persillade",
    "persillé": "persiller",
    "persillée": "persiller",
    "persillées": "persillé",
    "persils": "persil",
    "persiques": "persique",
    "persista": "persister",
    "persistai": "persister",
    "persistaient": "persister",
    "persistais": "persister",
    "persistait": "persister",
    "persistances": "persistance",
    "persistant": "persister",
    "persistante": "persistant",
    "persistantes": "persistant",
    "persistants": "persistant",
    "persistas": "persister",
    "persistasse": "persister",
    "persistassent": "persister",
    "persistasses": "persister",
    "persistassiez": "persister",
    "persistassions": "persister",
    "persiste": "persister",
    "persistent": "persister",
    "persistera": "persister",
    "persisterai": "persister",
    "persisteraient": "persister",
    "persisterais": "persister",
    "persisterait": "persister",
    "persisteras": "persister",
    "persisterez": "persister",
    "persisteriez": "persister",
    "persisterions": "persister",
    "persisterons": "persister",
    "persisteront": "persister",
    "persistes": "persister",
    "persistez": "persister",
    "persistiez": "persister",
    "persistions": "persister",
    "persistons": "persister",
    "persistâmes": "persister",
    "persistât": "persister",
    "persistâtes": "persister",
    "persistèrent": "persister",
    "persisté": "persister",
    "personnages": "personnage",
    "personnalisa": "personnaliser",
    "personnalisai": "personnaliser",
    "personnalisaient": "personnaliser",
    "personnalisais": "personnaliser",
    "personnalisait": "personnaliser",
    "personnalisant": "personnaliser",
    "personnalisas": "personnaliser",
    "personnalisasse": "personnaliser",
    "personnalisassent": "personnaliser",
    "personnalisasses": "personnaliser",
    "personnalisassiez": "personnaliser",
    "personnalisassions": "personnaliser",
    "personnalisations": "personnalisation",
    "personnalise": "personnaliser",
    "personnalisent": "personnaliser",
    "personnalisera": "personnaliser",
    "personnaliserai": "personnaliser",
    "personnaliseraient": "personnaliser",
    "personnaliserais": "personnaliser",
    "personnaliserait": "personnaliser",
    "personnaliseras": "personnaliser",
    "personnaliserez": "personnaliser",
    "personnaliseriez": "personnaliser",
    "personnaliserions": "personnaliser",
    "personnaliserons": "personnaliser",
    "personnaliseront": "personnaliser",
    "personnalises": "personnaliser",
    "personnalisez": "personnaliser",
    "personnalisiez": "personnaliser",
    "personnalisions": "personnaliser",
    "personnalisons": "personnaliser",
    "personnalisâmes": "personnaliser",
    "personnalisât": "personnaliser",
    "personnalisâtes": "personnaliser",
    "personnalisèrent": "personnaliser",
    "personnalisé": "personnaliser",
    "personnalisée": "personnaliser",
    "personnalisées": "personnaliser",
    "personnalisés": "personnaliser",
    "personnalités": "personnalité",
    "personnelle": "personnel",
    "personnelles": "personnel",
    "personnels": "personnel",
    "personnes": "personne",
    "personnifia": "personnifier",
    "personnifiai": "personnifier",
    "personnifiaient": "personnifier",
    "personnifiais": "personnifier",
    "personnifiait": "personnifier",
    "personnifiant": "personnifier",
    "personnifias": "personnifier",
    "personnifiasse": "personnifier",
    "personnifiassent": "personnifier",
    "personnifiasses": "personnifier",
    "personnifiassiez": "personnifier",
    "personnifiassions": "personnifier",
    "personnifications": "personnification",
    "personnifie": "personnifier",
    "personnifient": "personnifier",
    "personnifiera": "personnifier",
    "personnifierai": "personnifier",
    "personnifieraient": "personnifier",
    "personnifierais": "personnifier",
    "personnifierait": "personnifier",
    "personnifieras": "personnifier",
    "personnifierez": "personnifier",
    "personnifieriez": "personnifier",
    "personnifierions": "personnifier",
    "personnifierons": "personnifier",
    "personnifieront": "personnifier",
    "personnifies": "personnifier",
    "personnifiez": "personnifier",
    "personnifiiez": "personnifier",
    "personnifiions": "personnifier",
    "personnifions": "personnifier",
    "personnifiâmes": "personnifier",
    "personnifiât": "personnifier",
    "personnifiâtes": "personnifier",
    "personnifièrent": "personnifier",
    "personnifié": "personnifier",
    "personnifiée": "personnifier",
    "personnifiées": "personnifier",
    "personnifiés": "personnifier",
    "persos": "perso",
    "perspectifs": "perspectif",
    "perspective": "perspectif",
    "perspectives": "perspective",
    "perspicaces": "perspicace",
    "persuada": "persuader",
    "persuadai": "persuader",
    "persuadaient": "persuader",
    "persuadais": "persuader",
    "persuadait": "persuader",
    "persuadant": "persuader",
    "persuadas": "persuader",
    "persuadasse": "persuader",
    "persuadassent": "persuader",
    "persuadasses": "persuader",
    "persuadassiez": "persuader",
    "persuadassions": "persuader",
    "persuade": "persuader",
    "persuadent": "persuader",
    "persuadera": "persuader",
    "persuaderai": "persuader",
    "persuaderaient": "persuader",
    "persuaderais": "persuader",
    "persuaderait": "persuader",
    "persuaderas": "persuader",
    "persuaderez": "persuader",
    "persuaderiez": "persuader",
    "persuaderions": "persuader",
    "persuaderons": "persuader",
    "persuaderont": "persuader",
    "persuades": "persuader",
    "persuadez": "persuader",
    "persuadiez": "persuader",
    "persuadions": "persuader",
    "persuadons": "persuader",
    "persuadâmes": "persuader",
    "persuadât": "persuader",
    "persuadâtes": "persuader",
    "persuadèrent": "persuader",
    "persuadé": "persuader",
    "persuadée": "persuader",
    "persuadées": "persuader",
    "persuadés": "persuader",
    "persuasifs": "persuasif",
    "persuasions": "persuasion",
    "persuasive": "persuasif",
    "persuasives": "persuasif",
    "persécuta": "persécuter",
    "persécutai": "persécuter",
    "persécutaient": "persécuter",
    "persécutais": "persécuter",
    "persécutait": "persécuter",
    "persécutant": "persécuter",
    "persécutas": "persécuter",
    "persécutasse": "persécuter",
    "persécutassent": "persécuter",
    "persécutasses": "persécuter",
    "persécutassiez": "persécuter",
    "persécutassions": "persécuter",
    "persécute": "persécuter",
    "persécutent": "persécuter",
    "persécutera": "persécuter",
    "persécuterai": "persécuter",
    "persécuteraient": "persécuter",
    "persécuterais": "persécuter",
    "persécuterait": "persécuter",
    "persécuteras": "persécuter",
    "persécuterez": "persécuter",
    "persécuteriez": "persécuter",
    "persécuterions": "persécuter",
    "persécuterons": "persécuter",
    "persécuteront": "persécuter",
    "persécutes": "persécuter",
    "persécuteurs": "persécuteur",
    "persécutez": "persécuter",
    "persécutiez": "persécuter",
    "persécutions": "persécution",
    "persécutons": "persécuter",
    "persécutrices": "persécuteur",
    "persécutâmes": "persécuter",
    "persécutât": "persécuter",
    "persécutâtes": "persécuter",
    "persécutèrent": "persécuter",
    "persécuté": "persécuter",
    "persécutée": "persécuter",
    "persécutées": "persécuter",
    "persécutés": "persécuter",
    "persévère": "persévérer",
    "persévèrent": "persévérer",
    "persévères": "persévérer",
    "persévéra": "persévérer",
    "persévérai": "persévérer",
    "persévéraient": "persévérer",
    "persévérais": "persévérer",
    "persévérait": "persévérer",
    "persévérances": "persévérance",
    "persévérant": "persévérer",
    "persévérante": "persévérant",
    "persévérantes": "persévérant",
    "persévérants": "persévérant",
    "persévéras": "persévérer",
    "persévérasse": "persévérer",
    "persévérassent": "persévérer",
    "persévérasses": "persévérer",
    "persévérassiez": "persévérer",
    "persévérassions": "persévérer",
    "persévérera": "persévérer",
    "persévérerai": "persévérer",
    "persévéreraient": "persévérer",
    "persévérerais": "persévérer",
    "persévérerait": "persévérer",
    "persévéreras": "persévérer",
    "persévérerez": "persévérer",
    "persévéreriez": "persévérer",
    "persévérerions": "persévérer",
    "persévérerons": "persévérer",
    "persévéreront": "persévérer",
    "persévérez": "persévérer",
    "persévériez": "persévérer",
    "persévérions": "persévérer",
    "persévérons": "persévérer",
    "persévérâmes": "persévérer",
    "persévérât": "persévérer",
    "persévérâtes": "persévérer",
    "persévérèrent": "persévérer",
    "persévéré": "persévérer",
    "pertes": "perte",
    "pertinences": "pertinence",
    "pertinente": "pertinent",
    "pertinentes": "pertinent",
    "pertinents": "pertinent",
    "pertuisanes": "pertuisane",
    "perturba": "perturber",
    "perturbai": "perturber",
    "perturbaient": "perturber",
    "perturbais": "perturber",
    "perturbait": "perturber",
    "perturbant": "perturber",
    "perturbante": "perturbant",
    "perturbants": "perturbant",
    "perturbas": "perturber",
    "perturbasse": "perturber",
    "perturbassent": "perturber",
    "perturbasses": "perturber",
    "perturbassiez": "perturber",
    "perturbassions": "perturber",
    "perturbateurs": "perturbateur",
    "perturbations": "perturbation",
    "perturbatrice": "perturbateur",
    "perturbatrices": "perturbateur",
    "perturbe": "perturber",
    "perturbent": "perturber",
    "perturbera": "perturber",
    "perturberai": "perturber",
    "perturberaient": "perturber",
    "perturberais": "perturber",
    "perturberait": "perturber",
    "perturberas": "perturber",
    "perturberez": "perturber",
    "perturberiez": "perturber",
    "perturberions": "perturber",
    "perturberons": "perturber",
    "perturberont": "perturber",
    "perturbes": "perturber",
    "perturbez": "perturber",
    "perturbiez": "perturber",
    "perturbions": "perturber",
    "perturbons": "perturber",
    "perturbâmes": "perturber",
    "perturbât": "perturber",
    "perturbâtes": "perturber",
    "perturbèrent": "perturber",
    "perturbé": "perturber",
    "perturbée": "perturber",
    "perturbées": "perturber",
    "perturbés": "perturber",
    "pervenches": "pervenche",
    "perverse": "pervers",
    "perverses": "pervers",
    "perversions": "perversion",
    "perversités": "perversité",
    "perverti": "pervertir",
    "pervertie": "pervertir",
    "perverties": "pervertir",
    "pervertira": "pervertir",
    "pervertirai": "pervertir",
    "pervertiraient": "pervertir",
    "pervertirais": "pervertir",
    "pervertirait": "pervertir",
    "pervertiras": "pervertir",
    "pervertirent": "pervertir",
    "pervertirez": "pervertir",
    "pervertiriez": "pervertir",
    "pervertirions": "pervertir",
    "pervertirons": "pervertir",
    "pervertiront": "pervertir",
    "pervertis": "pervertir",
    "pervertissaient": "pervertir",
    "pervertissais": "pervertir",
    "pervertissait": "pervertir",
    "pervertissant": "pervertir",
    "pervertisse": "pervertir",
    "pervertissent": "pervertir",
    "pervertisses": "pervertir",
    "pervertissez": "pervertir",
    "pervertissiez": "pervertir",
    "pervertissions": "pervertir",
    "pervertissons": "pervertir",
    "pervertit": "pervertir",
    "pervertîmes": "pervertir",
    "pervertît": "pervertir",
    "pervertîtes": "pervertir",
    "perça": "percer",
    "perçages": "perçage",
    "perçai": "percer",
    "perçaient": "percer",
    "perçais": "percer",
    "perçait": "percer",
    "perçant": "percer",
    "perçante": "perçant",
    "perçantes": "perçant",
    "perçants": "perçant",
    "perças": "percer",
    "perçasse": "percer",
    "perçassent": "percer",
    "perçasses": "percer",
    "perçassiez": "percer",
    "perçassions": "percer",
    "perçois": "percevoir",
    "perçoit": "percevoir",
    "perçoive": "percevoir",
    "perçoivent": "percevoir",
    "perçoives": "percevoir",
    "perçons": "percer",
    "perçu": "percevoir",
    "perçue": "perçu",
    "perçues": "perçu",
    "perçurent": "percevoir",
    "perçus": "perçu",
    "perçusse": "percevoir",
    "perçussent": "percevoir",
    "perçusses": "percevoir",
    "perçussiez": "percevoir",
    "perçussions": "percevoir",
    "perçut": "percevoir",
    "perçâmes": "percer",
    "perçât": "percer",
    "perçâtes": "percer",
    "perçûmes": "percevoir",
    "perçût": "percevoir",
    "perçûtes": "percevoir",
    "pesa": "peser",
    "pesades": "pesade",
    "pesages": "pesage",
    "pesai": "peser",
    "pesaient": "peser",
    "pesais": "peser",
    "pesait": "peser",
    "pesant": "peser",
    "pesante": "pesant",
    "pesantes": "pesant",
    "pesanteurs": "pesanteur",
    "pesants": "pesant",
    "pesas": "peser",
    "pesasse": "peser",
    "pesassent": "peser",
    "pesasses": "peser",
    "pesassiez": "peser",
    "pesassions": "peser",
    "pesetas": "peseta",
    "peseurs": "peseur",
    "pesez": "peser",
    "pesiez": "peser",
    "pesions": "peser",
    "pesons": "peser",
    "pesos": "peso",
    "pessimismes": "pessimisme",
    "pessimistes": "pessimiste",
    "pesta": "pester",
    "pestai": "pester",
    "pestaient": "pester",
    "pestais": "pester",
    "pestait": "pester",
    "pestant": "pester",
    "pestas": "pester",
    "pestasse": "pester",
    "pestassent": "pester",
    "pestasses": "pester",
    "pestassiez": "pester",
    "pestassions": "pester",
    "peste": "pester",
    "pestent": "pester",
    "pestera": "pester",
    "pesterai": "pester",
    "pesteraient": "pester",
    "pesterais": "pester",
    "pesterait": "pester",
    "pesteras": "pester",
    "pesterez": "pester",
    "pesteriez": "pester",
    "pesterions": "pester",
    "pesterons": "pester",
    "pesteront": "pester",
    "pestes": "pester",
    "pesteuse": "pesteux",
    "pestez": "pester",
    "pesticides": "pesticide",
    "pestiez": "pester",
    "pestiférée": "pestiféré",
    "pestiférées": "pestiféré",
    "pestiférés": "pestiféré",
    "pestilences": "pestilence",
    "pestilentielle": "pestilentiel",
    "pestilentielles": "pestilentiel",
    "pestilentiels": "pestilentiel",
    "pestions": "pester",
    "pestons": "pester",
    "pestâmes": "pester",
    "pestât": "pester",
    "pestâtes": "pester",
    "pestèrent": "pester",
    "pesté": "pester",
    "pesâmes": "peser",
    "pesât": "peser",
    "pesâtes": "peser",
    "pesèrent": "peser",
    "pesé": "peser",
    "pesée": "peser",
    "pesées": "peser",
    "pesés": "peser",
    "petiote": "petiot",
    "petiotes": "petiot",
    "petiots": "petiot",
    "petite": "petit",
    "petite-bourgeoise": "petit-bourgeois",
    "petite-maîtresse": "petit-maître",
    "petites": "petit",
    "petites-bourgeoises": "petite-bourgeoise",
    "petites-filles": "petite-fille",
    "petites-maîtresses": "petit-maître",
    "petites-nièces": "petite-nièce",
    "petitesses": "petitesse",
    "petits": "petit",
    "petits-beurre": "petit-beurre",
    "petits-bourgeois": "petit-bourgeois",
    "petits-déjeuners": "petit-déjeuner",
    "petits-enfants": "petit-enfant",
    "petits-fils": "petit-fils",
    "petits-fours": "petits-four",
    "petits-gris": "petit-gris",
    "petits-laits": "petit-lait",
    "petits-maîtres": "petit-maître",
    "petits-neveux": "petit-neveu",
    "petits-pois": "petit-pois",
    "petits-suisses": "petit-suisse",
    "petons": "peton",
    "petros": "petro",
    "pets": "pet",
    "pets-de-nonne": "pet-de-nonne",
    "petzouilles": "petzouille",
    "peupla": "peupler",
    "peuplades": "peuplade",
    "peuplai": "peupler",
    "peuplaient": "peupler",
    "peuplais": "peupler",
    "peuplait": "peupler",
    "peuplant": "peupler",
    "peuplas": "peupler",
    "peuplasse": "peupler",
    "peuplassent": "peupler",
    "peuplasses": "peupler",
    "peuplassiez": "peupler",
    "peuplassions": "peupler",
    "peuple": "peupler",
    "peuplements": "peuplement",
    "peuplent": "peupler",
    "peuplera": "peupler",
    "peuplerai": "peupler",
    "peupleraient": "peupler",
    "peuplerais": "peupler",
    "peuplerait": "peupler",
    "peupleras": "peupler",
    "peuplerez": "peupler",
    "peupleriez": "peupler",
    "peuplerions": "peupler",
    "peuplerons": "peupler",
    "peupleront": "peupler",
    "peuples": "peupler",
    "peuplez": "peupler",
    "peupliers": "peuplier",
    "peupliez": "peupler",
    "peuplions": "peupler",
    "peuplons": "peupler",
    "peuplâmes": "peupler",
    "peuplât": "peupler",
    "peuplâtes": "peupler",
    "peuplèrent": "peupler",
    "peuplé": "peupler",
    "peuplée": "peupler",
    "peuplées": "peupler",
    "peuplés": "peupler",
    "peureuse": "peureux",
    "peureuses": "peureux",
    "peurs": "peur",
    "peut": "pouvoir",
    "peuvent": "pouvoir",
    "peux": "pouvoir",
    "pfennige": "pfennig",
    "pfennigs": "pfennig",
    "phacochères": "phacochère",
    "phagocyte": "phagocyter",
    "phagocytes": "phagocyte",
    "phalanges": "phalange",
    "phalangettes": "phalangette",
    "phalangistes": "phalangiste",
    "phalanstères": "phalanstère",
    "phalliques": "phallique",
    "phallocratiques": "phallocratique",
    "phalloïdes": "phalloïde",
    "phalènes": "phalène",
    "phantasmes": "phantasme",
    "phanères": "phanère",
    "phanérogames": "phanérogame",
    "pharamineuse": "pharamineux",
    "pharamineuses": "pharamineux",
    "pharaoniques": "pharaonique",
    "pharaonnes": "pharaon",
    "pharaons": "pharaon",
    "phares": "phare",
    "pharisaïques": "pharisaïque",
    "pharisaïsmes": "pharisaïsme",
    "pharisiens": "pharisien",
    "pharmaceutiques": "pharmaceutique",
    "pharmacienne": "pharmacien",
    "pharmaciennes": "pharmacien",
    "pharmaciens": "pharmacien",
    "pharmacies": "pharmacie",
    "pharmacologiques": "pharmacologique",
    "pharmacopées": "pharmacopée",
    "pharmacotoxicologies": "pharmacotoxicologie",
    "pharmacovigilances": "pharmacovigilance",
    "pharyngienne": "pharyngien",
    "pharyngiennes": "pharyngien",
    "pharyngiens": "pharyngien",
    "phases": "phase",
    "phasmes": "phasme",
    "phaétons": "phaéton",
    "philanthropes": "philanthrope",
    "philanthropies": "philanthropie",
    "philanthropiques": "philanthropique",
    "philantropiques": "philantropique",
    "philathéliques": "philathélique",
    "philatélies": "philatélie",
    "philatéliques": "philatélique",
    "philatélistes": "philatéliste",
    "philharmonies": "philharmonie",
    "philharmoniques": "philharmonique",
    "philhellènes": "philhellène",
    "philippine": "philippin",
    "philippines": "philippin",
    "philippins": "philippin",
    "philippiques": "philippique",
    "philistins": "philistin",
    "philodendrons": "philodendron",
    "philologies": "philologie",
    "philologiques": "philologique",
    "philologues": "philologue",
    "philos": "philo",
    "philosopha": "philosopher",
    "philosophai": "philosopher",
    "philosophaient": "philosopher",
    "philosophais": "philosopher",
    "philosophait": "philosopher",
    "philosophale": "philosophal",
    "philosophales": "philosophale",
    "philosophant": "philosopher",
    "philosophas": "philosopher",
    "philosophasse": "philosopher",
    "philosophassent": "philosopher",
    "philosophasses": "philosopher",
    "philosophassiez": "philosopher",
    "philosophassions": "philosopher",
    "philosophe": "philosopher",
    "philosophent": "philosopher",
    "philosophera": "philosopher",
    "philosopherai": "philosopher",
    "philosopheraient": "philosopher",
    "philosopherais": "philosopher",
    "philosopherait": "philosopher",
    "philosopheras": "philosopher",
    "philosopherez": "philosopher",
    "philosopheriez": "philosopher",
    "philosopherions": "philosopher",
    "philosopherons": "philosopher",
    "philosopheront": "philosopher",
    "philosophes": "philosopher",
    "philosophez": "philosopher",
    "philosophies": "philosophie",
    "philosophiez": "philosopher",
    "philosophions": "philosopher",
    "philosophiques": "philosophique",
    "philosophons": "philosopher",
    "philosophâmes": "philosopher",
    "philosophât": "philosopher",
    "philosophâtes": "philosopher",
    "philosophèrent": "philosopher",
    "philosophé": "philosopher",
    "philosémites": "philosémite",
    "philtres": "philtre",
    "phlegmons": "phlegmon",
    "phlogistiques": "phlogistique",
    "phlébites": "phlébite",
    "phobies": "phobie",
    "phobiques": "phobique",
    "phocéenne": "phocéen",
    "phonations": "phonation",
    "phones": "phone",
    "phoniatres": "phoniatre",
    "phoniques": "phonique",
    "phonogrammes": "phonogramme",
    "phonographes": "phonographe",
    "phonographiques": "phonographique",
    "phonos": "phono",
    "phonothèques": "phonothèque",
    "phonèmes": "phonème",
    "phonéticienne": "phonéticien",
    "phonéticiennes": "phonéticien",
    "phonéticiens": "phonéticien",
    "phonétiques": "phonétique",
    "phoques": "phoque",
    "phosphata": "phosphater",
    "phosphatai": "phosphater",
    "phosphataient": "phosphater",
    "phosphatais": "phosphater",
    "phosphatait": "phosphater",
    "phosphatant": "phosphater",
    "phosphatas": "phosphater",
    "phosphatasse": "phosphater",
    "phosphatassent": "phosphater",
    "phosphatasses": "phosphater",
    "phosphatassiez": "phosphater",
    "phosphatassions": "phosphater",
    "phosphate": "phosphater",
    "phosphatent": "phosphater",
    "phosphatera": "phosphater",
    "phosphaterai": "phosphater",
    "phosphateraient": "phosphater",
    "phosphaterais": "phosphater",
    "phosphaterait": "phosphater",
    "phosphateras": "phosphater",
    "phosphaterez": "phosphater",
    "phosphateriez": "phosphater",
    "phosphaterions": "phosphater",
    "phosphaterons": "phosphater",
    "phosphateront": "phosphater",
    "phosphates": "phosphater",
    "phosphatez": "phosphater",
    "phosphatiez": "phosphater",
    "phosphations": "phosphater",
    "phosphatons": "phosphater",
    "phosphatâmes": "phosphater",
    "phosphatât": "phosphater",
    "phosphatâtes": "phosphater",
    "phosphatèrent": "phosphater",
    "phosphaté": "phosphater",
    "phosphatée": "phosphater",
    "phosphatées": "phosphater",
    "phosphatés": "phosphater",
    "phosphore": "phosphorer",
    "phosphores": "phosphore",
    "phosphorescences": "phosphorescence",
    "phosphorescente": "phosphorescent",
    "phosphorescentes": "phosphorescent",
    "phosphorescents": "phosphorescent",
    "phosphoriques": "phosphorique",
    "phosphoré": "phosphorer",
    "phosphènes": "phosphène",
    "photochimiques": "photochimique",
    "photocompositions": "photocomposition",
    "photocopia": "photocopier",
    "photocopiai": "photocopier",
    "photocopiaient": "photocopier",
    "photocopiais": "photocopier",
    "photocopiait": "photocopier",
    "photocopiant": "photocopier",
    "photocopias": "photocopier",
    "photocopiasse": "photocopier",
    "photocopiassent": "photocopier",
    "photocopiasses": "photocopier",
    "photocopiassiez": "photocopier",
    "photocopiassions": "photocopier",
    "photocopie": "photocopier",
    "photocopient": "photocopier",
    "photocopiera": "photocopier",
    "photocopierai": "photocopier",
    "photocopieraient": "photocopier",
    "photocopierais": "photocopier",
    "photocopierait": "photocopier",
    "photocopieras": "photocopier",
    "photocopierez": "photocopier",
    "photocopieriez": "photocopier",
    "photocopierions": "photocopier",
    "photocopierons": "photocopier",
    "photocopieront": "photocopier",
    "photocopies": "photocopier",
    "photocopieurs": "photocopieur",
    "photocopieuse": "photocopieur",
    "photocopieuses": "photocopieur",
    "photocopiez": "photocopier",
    "photocopiiez": "photocopier",
    "photocopiions": "photocopier",
    "photocopions": "photocopier",
    "photocopiâmes": "photocopier",
    "photocopiât": "photocopier",
    "photocopiâtes": "photocopier",
    "photocopièrent": "photocopier",
    "photocopié": "photocopier",
    "photocopiée": "photocopier",
    "photocopiées": "photocopier",
    "photocopiés": "photocopier",
    "photographes": "photographe",
    "photographia": "photographier",
    "photographiai": "photographier",
    "photographiaient": "photographier",
    "photographiais": "photographier",
    "photographiait": "photographier",
    "photographiant": "photographier",
    "photographias": "photographier",
    "photographiasse": "photographier",
    "photographiassent": "photographier",
    "photographiasses": "photographier",
    "photographiassiez": "photographier",
    "photographiassions": "photographier",
    "photographie": "photographier",
    "photographient": "photographier",
    "photographiera": "photographier",
    "photographierai": "photographier",
    "photographieraient": "photographier",
    "photographierais": "photographier",
    "photographierait": "photographier",
    "photographieras": "photographier",
    "photographierez": "photographier",
    "photographieriez": "photographier",
    "photographierions": "photographier",
    "photographierons": "photographier",
    "photographieront": "photographier",
    "photographies": "photographier",
    "photographiez": "photographier",
    "photographiiez": "photographier",
    "photographiions": "photographier",
    "photographions": "photographier",
    "photographiques": "photographique",
    "photographiâmes": "photographier",
    "photographiât": "photographier",
    "photographiâtes": "photographier",
    "photographièrent": "photographier",
    "photographié": "photographier",
    "photographiée": "photographier",
    "photographiées": "photographier",
    "photographiés": "photographier",
    "photogéniques": "photogénique",
    "photomatons": "photomaton",
    "photomontages": "photomontage",
    "photons": "photon",
    "photophores": "photophore",
    "photopiles": "photopile",
    "photos": "photo",
    "photos-finish": "photo-finish",
    "photos-robots": "photo-robot",
    "photos-romans": "photo-roman",
    "photosensibles": "photosensible",
    "photostoppeurs": "photostoppeur",
    "photostoppeuse": "photostoppeur",
    "photostoppeuses": "photostoppeur",
    "photothèques": "photothèque",
    "photovoltaïques": "photovoltaïque",
    "photoélectriques": "photoélectrique",
    "phragmites": "phragmite",
    "phrase": "phraser",
    "phrases": "phraser",
    "phrases-clés": "phrase-clé",
    "phraseurs": "phraseur",
    "phrasé": "phraser",
    "phrasée": "phraser",
    "phraséologies": "phraséologie",
    "phrasés": "phrasé",
    "phratries": "phratrie",
    "phrygienne": "phrygien",
    "phrygiennes": "phrygien",
    "phrygiens": "phrygien",
    "phréatiques": "phréatique",
    "phrénologies": "phrénologie",
    "phrénologistes": "phrénologiste",
    "phrénologues": "phrénologue",
    "phtaléines": "phtaléine",
    "phtisies": "phtisie",
    "phtisiques": "phtisique",
    "phylactères": "phylactère",
    "phylloxeras": "phylloxera",
    "phylloxéras": "phylloxéra",
    "phylogenèses": "phylogenèse",
    "physicienne": "physicien",
    "physiciennes": "physicien",
    "physiciens": "physicien",
    "physico-chimiques": "physico-chimique",
    "physiocrates": "physiocrate",
    "physiocratiques": "physiocratique",
    "physiognomonies": "physiognomonie",
    "physiologies": "physiologie",
    "physiologiques": "physiologique",
    "physionomies": "physionomie",
    "physionomistes": "physionomiste",
    "physiothérapeutes": "physiothérapeute",
    "physiothérapies": "physiothérapie",
    "physiques": "physique",
    "phytopathologies": "phytopathologie",
    "phytopharmaceutiques": "phytopharmaceutique",
    "phytosanitaires": "phytosanitaire",
    "phytothérapies": "phytothérapie",
    "phénicienne": "phénicien",
    "phéniciennes": "phénicien",
    "phéniciens": "phénicien",
    "phéniqués": "phéniqué",
    "phénols": "phénol",
    "phénomènes": "phénomène",
    "phénoménale": "phénoménal",
    "phénoménales": "phénoménal",
    "phénoménaux": "phénoménal",
    "phénoménologies": "phénoménologie",
    "phénoménologiques": "phénoménologique",
    "phénoménologues": "phénoménologue",
    "phénotypes": "phénotype",
    "phéromones": "phéromone",
    "piaffa": "piaffer",
    "piaffai": "piaffer",
    "piaffaient": "piaffer",
    "piaffais": "piaffer",
    "piaffait": "piaffer",
    "piaffant": "piaffer",
    "piaffante": "piaffant",
    "piaffantes": "piaffant",
    "piaffants": "piaffant",
    "piaffas": "piaffer",
    "piaffasse": "piaffer",
    "piaffassent": "piaffer",
    "piaffasses": "piaffer",
    "piaffassiez": "piaffer",
    "piaffassions": "piaffer",
    "piaffe": "piaffer",
    "piaffements": "piaffement",
    "piaffent": "piaffer",
    "piaffera": "piaffer",
    "piafferai": "piaffer",
    "piafferaient": "piaffer",
    "piafferais": "piaffer",
    "piafferait": "piaffer",
    "piafferas": "piaffer",
    "piafferez": "piaffer",
    "piafferiez": "piaffer",
    "piafferions": "piaffer",
    "piafferons": "piaffer",
    "piafferont": "piaffer",
    "piaffes": "piaffer",
    "piaffez": "piaffer",
    "piaffiez": "piaffer",
    "piaffions": "piaffer",
    "piaffons": "piaffer",
    "piaffâmes": "piaffer",
    "piaffât": "piaffer",
    "piaffâtes": "piaffer",
    "piaffèrent": "piaffer",
    "piaffé": "piaffer",
    "piafs": "piaf",
    "piailla": "piailler",
    "piaillai": "piailler",
    "piaillaient": "piailler",
    "piaillais": "piailler",
    "piaillait": "piailler",
    "piaillant": "piailler",
    "piaillante": "piaillant",
    "piaillantes": "piaillant",
    "piaillarde": "piaillard",
    "piaillards": "piaillard",
    "piaillas": "piailler",
    "piaillasse": "piailler",
    "piaillassent": "piailler",
    "piaillasses": "piailler",
    "piaillassiez": "piailler",
    "piaillassions": "piailler",
    "piaille": "piailler",
    "piaillements": "piaillement",
    "piaillent": "piailler",
    "piaillera": "piailler",
    "piaillerai": "piailler",
    "piailleraient": "piailler",
    "piaillerais": "piailler",
    "piaillerait": "piailler",
    "piailleras": "piailler",
    "piaillerez": "piailler",
    "piailleries": "piaillerie",
    "piailleriez": "piailler",
    "piaillerions": "piailler",
    "piaillerons": "piailler",
    "piailleront": "piailler",
    "piailles": "piailler",
    "piailleurs": "piailleur",
    "piailleuse": "piailleur",
    "piaillez": "piailler",
    "piailliez": "piailler",
    "piaillions": "piailler",
    "piaillons": "piailler",
    "piaillâmes": "piailler",
    "piaillât": "piailler",
    "piaillâtes": "piailler",
    "piaillèrent": "piailler",
    "piaillé": "piailler",
    "pianissimos": "pianissimo",
    "pianistes": "pianiste",
    "pianistiques": "pianistique",
    "pianos": "piano",
    "pianota": "pianoter",
    "pianotai": "pianoter",
    "pianotaient": "pianoter",
    "pianotais": "pianoter",
    "pianotait": "pianoter",
    "pianotant": "pianoter",
    "pianotas": "pianoter",
    "pianotasse": "pianoter",
    "pianotassent": "pianoter",
    "pianotasses": "pianoter",
    "pianotassiez": "pianoter",
    "pianotassions": "pianoter",
    "pianote": "pianoter",
    "pianotent": "pianoter",
    "pianotera": "pianoter",
    "pianoterai": "pianoter",
    "pianoteraient": "pianoter",
    "pianoterais": "pianoter",
    "pianoterait": "pianoter",
    "pianoteras": "pianoter",
    "pianoterez": "pianoter",
    "pianoteriez": "pianoter",
    "pianoterions": "pianoter",
    "pianoterons": "pianoter",
    "pianoteront": "pianoter",
    "pianotes": "pianoter",
    "pianotez": "pianoter",
    "pianotiez": "pianoter",
    "pianotions": "pianoter",
    "pianotons": "pianoter",
    "pianotâmes": "pianoter",
    "pianotât": "pianoter",
    "pianotâtes": "pianoter",
    "pianotèrent": "pianoter",
    "pianoté": "pianoter",
    "pianotée": "pianoter",
    "pianotées": "pianoter",
    "pianotés": "pianoter",
    "piastres": "piastre",
    "piaula": "piauler",
    "piaulai": "piauler",
    "piaulaient": "piauler",
    "piaulais": "piauler",
    "piaulait": "piauler",
    "piaulant": "piauler",
    "piaulante": "piaulant",
    "piaulas": "piauler",
    "piaulasse": "piauler",
    "piaulassent": "piauler",
    "piaulasses": "piauler",
    "piaulassiez": "piauler",
    "piaulassions": "piauler",
    "piaule": "piauler",
    "piaulements": "piaulement",
    "piaulent": "piauler",
    "piaulera": "piauler",
    "piaulerai": "piauler",
    "piauleraient": "piauler",
    "piaulerais": "piauler",
    "piaulerait": "piauler",
    "piauleras": "piauler",
    "piaulerez": "piauler",
    "piauleriez": "piauler",
    "piaulerions": "piauler",
    "piaulerons": "piauler",
    "piauleront": "piauler",
    "piaules": "piauler",
    "piaulez": "piauler",
    "piauliez": "piauler",
    "piaulions": "piauler",
    "piaulons": "piauler",
    "piaulâmes": "piauler",
    "piaulât": "piauler",
    "piaulâtes": "piauler",
    "piaulèrent": "piauler",
    "piaulé": "piauler",
    "piazzas": "piazza",
    "pic-verts": "pic-vert",
    "picadors": "picador",
    "picaillons": "picaillon",
    "picarde": "picard",
    "picardes": "picard",
    "picards": "picard",
    "picaresques": "picaresque",
    "piccolos": "piccolo",
    "pichenettes": "pichenette",
    "pichets": "pichet",
    "pickles": "pickle",
    "pickpockets": "pickpocket",
    "picolaient": "picoler",
    "picolais": "picoler",
    "picolait": "picoler",
    "picolant": "picoler",
    "picole": "picoler",
    "picolent": "picoler",
    "picolerait": "picoler",
    "picoles": "picoler",
    "picoleurs": "picoleur",
    "picolez": "picoler",
    "picoliez": "picoler",
    "picolé": "picoler",
    "picora": "picorer",
    "picorai": "picorer",
    "picoraient": "picorer",
    "picorais": "picorer",
    "picorait": "picorer",
    "picorant": "picorer",
    "picoras": "picorer",
    "picorasse": "picorer",
    "picorassent": "picorer",
    "picorasses": "picorer",
    "picorassiez": "picorer",
    "picorassions": "picorer",
    "picore": "picorer",
    "picorent": "picorer",
    "picorera": "picorer",
    "picorerai": "picorer",
    "picoreraient": "picorer",
    "picorerais": "picorer",
    "picorerait": "picorer",
    "picoreras": "picorer",
    "picorerez": "picorer",
    "picoreriez": "picorer",
    "picorerions": "picorer",
    "picorerons": "picorer",
    "picoreront": "picorer",
    "picores": "picorer",
    "picorez": "picorer",
    "picoriez": "picorer",
    "picorions": "picorer",
    "picorons": "picorer",
    "picorâmes": "picorer",
    "picorât": "picorer",
    "picorâtes": "picorer",
    "picorèrent": "picorer",
    "picoré": "picorer",
    "picorée": "picorer",
    "picorées": "picorer",
    "picorés": "picorer",
    "picota": "picoter",
    "picotai": "picoter",
    "picotaient": "picoter",
    "picotais": "picoter",
    "picotait": "picoter",
    "picotant": "picoter",
    "picotas": "picoter",
    "picotasse": "picoter",
    "picotassent": "picoter",
    "picotasses": "picoter",
    "picotassiez": "picoter",
    "picotassions": "picoter",
    "picote": "picoter",
    "picotements": "picotement",
    "picotent": "picoter",
    "picotera": "picoter",
    "picoterai": "picoter",
    "picoteraient": "picoter",
    "picoterais": "picoter",
    "picoterait": "picoter",
    "picoteras": "picoter",
    "picoterez": "picoter",
    "picoteriez": "picoter",
    "picoterions": "picoter",
    "picoterons": "picoter",
    "picoteront": "picoter",
    "picotes": "picoter",
    "picotez": "picoter",
    "picotiez": "picoter",
    "picotins": "picotin",
    "picotions": "picoter",
    "picotons": "picoter",
    "picots": "picot",
    "picotâmes": "picoter",
    "picotât": "picoter",
    "picotâtes": "picoter",
    "picotèrent": "picoter",
    "picoté": "picoter",
    "picotée": "picoter",
    "picotées": "picoter",
    "picotés": "picoter",
    "picpouls": "picpoul",
    "picriques": "picrique",
    "pics": "pic",
    "pics-verts": "pic-vert",
    "pictogrammes": "pictogramme",
    "picturale": "pictural",
    "picturales": "pictural",
    "picturaux": "pictural",
    "picté": "picter",
    "pieds": "pied",
    "pieds-bots": "pied-bot",
    "pieds-d'alouettes": "pied-d'alouette",
    "pieds-de-biche": "pied-de-biche",
    "pieds-de-cheval": "pied-de-cheval",
    "pieds-de-coq": "pied-de-coq",
    "pieds-de-loup": "pied-de-loup",
    "pieds-de-mouton": "pied-de-mouton",
    "pieds-de-poule": "pied-de-poule",
    "pieds-droits": "pied-droit",
    "pieds-forts": "pied-fort",
    "pieds-noirs": "pied-noir",
    "piercings": "piercing",
    "pierrailles": "pierraille",
    "pierres": "pierre",
    "pierreuse": "pierreux",
    "pierreuses": "pierreux",
    "pierriers": "pierrier",
    "pierrots": "pierrot",
    "pierrures": "pierrure",
    "pies": "pie",
    "pies-grièches": "pie-grièche",
    "pies-mères": "pie-mère",
    "pieuse": "pieux",
    "pieuses": "pieux",
    "pieutait": "pieuter",
    "pieute": "pieuter",
    "pieuterez": "pieuter",
    "pieutes": "pieuter",
    "pieutez": "pieuter",
    "pieuté": "pieuter",
    "pieutée": "pieuter",
    "pieutés": "pieuter",
    "pieuvres": "pieuvre",
    "pieux": "pieu",
    "piffait": "piffer",
    "piffé": "piffer",
    "pifomètres": "pifomètre",
    "pifs": "pif",
    "pige": "piger",
    "pigea": "piger",
    "pigeai": "piger",
    "pigeaient": "piger",
    "pigeais": "piger",
    "pigeait": "piger",
    "pigeant": "piger",
    "pigeas": "piger",
    "pigeasse": "piger",
    "pigeassent": "piger",
    "pigeasses": "piger",
    "pigeassiez": "piger",
    "pigeassions": "piger",
    "pigent": "piger",
    "pigeonnant": "pigeonner",
    "pigeonnante": "pigeonnant",
    "pigeonnants": "pigeonnant",
    "pigeonne": "pigeonner",
    "pigeonneaux": "pigeonneau",
    "pigeonnes": "pigeon",
    "pigeonniers": "pigeonnier",
    "pigeonné": "pigeonner",
    "pigeons": "piger",
    "pigera": "piger",
    "pigerai": "piger",
    "pigeraient": "piger",
    "pigerais": "piger",
    "pigerait": "piger",
    "pigeras": "piger",
    "pigerez": "piger",
    "pigeriez": "piger",
    "pigerions": "piger",
    "pigerons": "piger",
    "pigeront": "piger",
    "piges": "piger",
    "pigez": "piger",
    "pigeâmes": "piger",
    "pigeât": "piger",
    "pigeâtes": "piger",
    "pigiez": "piger",
    "pigions": "piger",
    "pigistes": "pigiste",
    "pigmenta": "pigmenter",
    "pigmentai": "pigmenter",
    "pigmentaient": "pigmenter",
    "pigmentaires": "pigmentaire",
    "pigmentais": "pigmenter",
    "pigmentait": "pigmenter",
    "pigmentant": "pigmenter",
    "pigmentas": "pigmenter",
    "pigmentasse": "pigmenter",
    "pigmentassent": "pigmenter",
    "pigmentasses": "pigmenter",
    "pigmentassiez": "pigmenter",
    "pigmentassions": "pigmenter",
    "pigmente": "pigmenter",
    "pigmentent": "pigmenter",
    "pigmentera": "pigmenter",
    "pigmenterai": "pigmenter",
    "pigmenteraient": "pigmenter",
    "pigmenterais": "pigmenter",
    "pigmenterait": "pigmenter",
    "pigmenteras": "pigmenter",
    "pigmenterez": "pigmenter",
    "pigmenteriez": "pigmenter",
    "pigmenterions": "pigmenter",
    "pigmenterons": "pigmenter",
    "pigmenteront": "pigmenter",
    "pigmentes": "pigmenter",
    "pigmentez": "pigmenter",
    "pigmentiez": "pigmenter",
    "pigmentions": "pigmenter",
    "pigmentons": "pigmenter",
    "pigments": "pigment",
    "pigmentâmes": "pigmenter",
    "pigmentât": "pigmenter",
    "pigmentâtes": "pigmenter",
    "pigmentèrent": "pigmenter",
    "pigmenté": "pigmenter",
    "pigmentée": "pigmenter",
    "pigmentées": "pigmenter",
    "pigmentés": "pigmenter",
    "pignes": "pigne",
    "pignocha": "pignocher",
    "pignochai": "pignocher",
    "pignochaient": "pignocher",
    "pignochais": "pignocher",
    "pignochait": "pignocher",
    "pignochant": "pignocher",
    "pignochas": "pignocher",
    "pignochasse": "pignocher",
    "pignochassent": "pignocher",
    "pignochasses": "pignocher",
    "pignochassiez": "pignocher",
    "pignochassions": "pignocher",
    "pignoche": "pignocher",
    "pignochent": "pignocher",
    "pignochera": "pignocher",
    "pignocherai": "pignocher",
    "pignocheraient": "pignocher",
    "pignocherais": "pignocher",
    "pignocherait": "pignocher",
    "pignocheras": "pignocher",
    "pignocherez": "pignocher",
    "pignocheriez": "pignocher",
    "pignocherions": "pignocher",
    "pignocherons": "pignocher",
    "pignocheront": "pignocher",
    "pignoches": "pignocher",
    "pignochez": "pignocher",
    "pignochiez": "pignocher",
    "pignochions": "pignocher",
    "pignochons": "pignocher",
    "pignochâmes": "pignocher",
    "pignochât": "pignocher",
    "pignochâtes": "pignocher",
    "pignochèrent": "pignocher",
    "pignoché": "pignocher",
    "pignons": "pignon",
    "pignoufs": "pignouf",
    "pigèrent": "piger",
    "pigé": "piger",
    "pigée": "piger",
    "pigées": "piger",
    "pigés": "piger",
    "pila": "piler",
    "pilafs": "pilaf",
    "pilai": "piler",
    "pilaient": "piler",
    "pilais": "piler",
    "pilait": "piler",
    "pilant": "piler",
    "pilas": "piler",
    "pilasse": "piler",
    "pilassent": "piler",
    "pilasses": "piler",
    "pilassiez": "piler",
    "pilassions": "piler",
    "pilastres": "pilastre",
    "pilchards": "pilchard",
    "pile": "piler",
    "pilent": "piler",
    "pilera": "piler",
    "pilerai": "piler",
    "pileraient": "piler",
    "pilerais": "piler",
    "pilerait": "piler",
    "pileras": "piler",
    "pilerez": "piler",
    "pileriez": "piler",
    "pilerions": "piler",
    "pilerons": "piler",
    "pileront": "piler",
    "piles": "piler",
    "pileuse": "pileux",
    "pileuses": "pileux",
    "pilez": "piler",
    "piliers": "pilier",
    "piliez": "piler",
    "pilions": "piler",
    "pilla": "piller",
    "pillages": "pillage",
    "pillai": "piller",
    "pillaient": "piller",
    "pillais": "piller",
    "pillait": "piller",
    "pillant": "piller",
    "pillarde": "pillard",
    "pillardes": "pillard",
    "pillards": "pillard",
    "pillas": "piller",
    "pillasse": "piller",
    "pillassent": "piller",
    "pillasses": "piller",
    "pillassiez": "piller",
    "pillassions": "piller",
    "pille": "piller",
    "pillent": "piller",
    "pillera": "piller",
    "pillerai": "piller",
    "pilleraient": "piller",
    "pillerais": "piller",
    "pillerait": "piller",
    "pilleras": "piller",
    "pillerez": "piller",
    "pilleriez": "piller",
    "pillerions": "piller",
    "pillerons": "piller",
    "pilleront": "piller",
    "pilles": "piller",
    "pilleurs": "pilleur",
    "pilleuse": "pilleur",
    "pilleuses": "pilleur",
    "pillez": "piller",
    "pilliez": "piller",
    "pillions": "piller",
    "pillons": "piller",
    "pillow-lavas": "pillow-lava",
    "pillâmes": "piller",
    "pillât": "piller",
    "pillâtes": "piller",
    "pillèrent": "piller",
    "pillé": "piller",
    "pillée": "piller",
    "pillées": "piller",
    "pillés": "piller",
    "piloches": "piloche",
    "pilonna": "pilonner",
    "pilonnages": "pilonnage",
    "pilonnai": "pilonner",
    "pilonnaient": "pilonner",
    "pilonnais": "pilonner",
    "pilonnait": "pilonner",
    "pilonnant": "pilonner",
    "pilonnas": "pilonner",
    "pilonnasse": "pilonner",
    "pilonnassent": "pilonner",
    "pilonnasses": "pilonner",
    "pilonnassiez": "pilonner",
    "pilonnassions": "pilonner",
    "pilonne": "pilonner",
    "pilonnent": "pilonner",
    "pilonnera": "pilonner",
    "pilonnerai": "pilonner",
    "pilonneraient": "pilonner",
    "pilonnerais": "pilonner",
    "pilonnerait": "pilonner",
    "pilonneras": "pilonner",
    "pilonnerez": "pilonner",
    "pilonneriez": "pilonner",
    "pilonnerions": "pilonner",
    "pilonnerons": "pilonner",
    "pilonneront": "pilonner",
    "pilonnes": "pilonner",
    "pilonneurs": "pilonneur",
    "pilonnez": "pilonner",
    "pilonniez": "pilonner",
    "pilonnions": "pilonner",
    "pilonnons": "pilonner",
    "pilonnâmes": "pilonner",
    "pilonnât": "pilonner",
    "pilonnâtes": "pilonner",
    "pilonnèrent": "pilonner",
    "pilonné": "pilonner",
    "pilonnée": "pilonner",
    "pilonnées": "pilonner",
    "pilonnés": "pilonner",
    "pilons": "pilon",
    "piloris": "pilori",
    "piloselles": "piloselle",
    "pilota": "piloter",
    "pilotages": "pilotage",
    "pilotai": "piloter",
    "pilotaient": "piloter",
    "pilotais": "piloter",
    "pilotait": "piloter",
    "pilotant": "piloter",
    "pilotas": "piloter",
    "pilotasse": "piloter",
    "pilotassent": "piloter",
    "pilotasses": "piloter",
    "pilotassiez": "piloter",
    "pilotassions": "piloter",
    "pilote": "piloter",
    "pilotent": "piloter",
    "pilotera": "piloter",
    "piloterai": "piloter",
    "piloteraient": "piloter",
    "piloterais": "piloter",
    "piloterait": "piloter",
    "piloteras": "piloter",
    "piloterez": "piloter",
    "piloteriez": "piloter",
    "piloterions": "piloter",
    "piloterons": "piloter",
    "piloteront": "piloter",
    "pilotes": "piloter",
    "pilotez": "piloter",
    "pilotiez": "piloter",
    "pilotions": "piloter",
    "pilotons": "piloter",
    "pilotâmes": "piloter",
    "pilotât": "piloter",
    "pilotâtes": "piloter",
    "pilotèrent": "piloter",
    "piloté": "piloter",
    "pilotée": "piloter",
    "pilotées": "piloter",
    "pilotés": "piloter",
    "pilous": "pilou",
    "pilules": "pilule",
    "pilâmes": "piler",
    "pilât": "piler",
    "pilâtes": "piler",
    "pilèrent": "piler",
    "pilé": "piler",
    "pilée": "piler",
    "pilées": "piler",
    "pilés": "piler",
    "pimbêches": "pimbêche",
    "pimenta": "pimenter",
    "pimentai": "pimenter",
    "pimentaient": "pimenter",
    "pimentais": "pimenter",
    "pimentait": "pimenter",
    "pimentant": "pimenter",
    "pimentas": "pimenter",
    "pimentasse": "pimenter",
    "pimentassent": "pimenter",
    "pimentasses": "pimenter",
    "pimentassiez": "pimenter",
    "pimentassions": "pimenter",
    "pimente": "pimenter",
    "pimentent": "pimenter",
    "pimentera": "pimenter",
    "pimenterai": "pimenter",
    "pimenteraient": "pimenter",
    "pimenterais": "pimenter",
    "pimenterait": "pimenter",
    "pimenteras": "pimenter",
    "pimenterez": "pimenter",
    "pimenteriez": "pimenter",
    "pimenterions": "pimenter",
    "pimenterons": "pimenter",
    "pimenteront": "pimenter",
    "pimentes": "pimenter",
    "pimentez": "pimenter",
    "pimentiez": "pimenter",
    "pimentions": "pimenter",
    "pimentons": "pimenter",
    "piments": "piment",
    "pimentâmes": "pimenter",
    "pimentât": "pimenter",
    "pimentâtes": "pimenter",
    "pimentèrent": "pimenter",
    "pimenté": "pimenter",
    "pimentée": "pimenter",
    "pimentées": "pimenter",
    "pimentés": "pimenter",
    "pimpante": "pimpant",
    "pimpantes": "pimpant",
    "pimpants": "pimpant",
    "pimpons": "pimpon",
    "pimprenelles": "pimprenelle",
    "pina": "piner",
    "pinacles": "pinacle",
    "pinacothèques": "pinacothèque",
    "pinailla": "pinailler",
    "pinaillai": "pinailler",
    "pinaillaient": "pinailler",
    "pinaillais": "pinailler",
    "pinaillait": "pinailler",
    "pinaillant": "pinailler",
    "pinaillas": "pinailler",
    "pinaillasse": "pinailler",
    "pinaillassent": "pinailler",
    "pinaillasses": "pinailler",
    "pinaillassiez": "pinailler",
    "pinaillassions": "pinailler",
    "pinaille": "pinailler",
    "pinaillent": "pinailler",
    "pinaillera": "pinailler",
    "pinaillerai": "pinailler",
    "pinailleraient": "pinailler",
    "pinaillerais": "pinailler",
    "pinaillerait": "pinailler",
    "pinailleras": "pinailler",
    "pinaillerez": "pinailler",
    "pinailleriez": "pinailler",
    "pinaillerions": "pinailler",
    "pinaillerons": "pinailler",
    "pinailleront": "pinailler",
    "pinailles": "pinailler",
    "pinaillez": "pinailler",
    "pinailliez": "pinailler",
    "pinaillions": "pinailler",
    "pinaillons": "pinailler",
    "pinaillâmes": "pinailler",
    "pinaillât": "pinailler",
    "pinaillâtes": "pinailler",
    "pinaillèrent": "pinailler",
    "pinaillé": "pinailler",
    "pinardiers": "pinardier",
    "pinardière": "pinardier",
    "pinards": "pinard",
    "pinasses": "pinasse",
    "pince": "pincer",
    "pince-fesses": "pince-fesse",
    "pince-mailles": "pince-maille",
    "pinceaux": "pinceau",
    "pincements": "pincement",
    "pincent": "pincer",
    "pincer": "pouvoir",
    "pincera": "pincer",
    "pincerai": "pincer",
    "pinceraient": "pincer",
    "pincerais": "pincer",
    "pincerait": "pincer",
    "pinceras": "pincer",
    "pincerez": "pincer",
    "pinceriez": "pincer",
    "pincerions": "pincer",
    "pincerons": "pincer",
    "pinceront": "pincer",
    "pinces": "pincer",
    "pinces-monseigneur": "pince-monseigneur",
    "pincettes": "pincette",
    "pincez": "pincer",
    "pinciez": "pincer",
    "pincions": "pincer",
    "pincèrent": "pincer",
    "pincé": "pincer",
    "pincée": "pincer",
    "pincées": "pincer",
    "pincés": "pincer",
    "pine": "piner",
    "pineaux": "pineau",
    "pines": "pine",
    "ping-pongs": "ping-pong",
    "pinglots": "pinglot",
    "pingouins": "pingouin",
    "pingreries": "pingrerie",
    "pingres": "pingre",
    "pinots": "pinot",
    "pins": "pin",
    "pinsons": "pinson",
    "pinta": "pinter",
    "pintadeaux": "pintadeau",
    "pintades": "pintade",
    "pintait": "pinter",
    "pinte": "pinter",
    "pintes": "pinte",
    "pinté": "pinter",
    "pintée": "pinter",
    "pintés": "pinter",
    "pinyins": "pinyin",
    "pinça": "pincer",
    "pinçai": "pincer",
    "pinçaient": "pincer",
    "pinçais": "pincer",
    "pinçait": "pincer",
    "pinçant": "pincer",
    "pinças": "pincer",
    "pinçasse": "pincer",
    "pinçassent": "pincer",
    "pinçasses": "pincer",
    "pinçassiez": "pincer",
    "pinçassions": "pincer",
    "pinçons": "pinçon",
    "pinçotait": "pinçoter",
    "pinçotant": "pinçoter",
    "pinçote": "pinçoter",
    "pinçâmes": "pincer",
    "pinçât": "pincer",
    "pinçâtes": "pincer",
    "pinèdes": "pinède",
    "piné": "piner",
    "pinéale": "pinéal",
    "pinéales": "pinéal",
    "pinéaux": "pinéal",
    "piocha": "piocher",
    "piochai": "piocher",
    "piochaient": "piocher",
    "piochais": "piocher",
    "piochait": "piocher",
    "piochant": "piocher",
    "piochas": "piocher",
    "piochasse": "piocher",
    "piochassent": "piocher",
    "piochasses": "piocher",
    "piochassiez": "piocher",
    "piochassions": "piocher",
    "pioche": "piocher",
    "piochent": "piocher",
    "piochera": "piocher",
    "piocherai": "piocher",
    "piocheraient": "piocher",
    "piocherais": "piocher",
    "piocherait": "piocher",
    "piocheras": "piocher",
    "piocherez": "piocher",
    "piocheriez": "piocher",
    "piocherions": "piocher",
    "piocherons": "piocher",
    "piocheront": "piocher",
    "pioches": "piocher",
    "piochez": "piocher",
    "piochiez": "piocher",
    "piochions": "piocher",
    "piochons": "piocher",
    "piochâmes": "piocher",
    "piochât": "piocher",
    "piochâtes": "piocher",
    "piochèrent": "piocher",
    "pioché": "piocher",
    "piochée": "piocher",
    "piochées": "piocher",
    "piochés": "piocher",
    "piolets": "piolet",
    "pionce": "pioncer",
    "pioncent": "pioncer",
    "pioncera": "pioncer",
    "pioncerai": "pioncer",
    "pionceraient": "pioncer",
    "pioncerais": "pioncer",
    "pioncerait": "pioncer",
    "pionceras": "pioncer",
    "pioncerez": "pioncer",
    "pionceriez": "pioncer",
    "pioncerions": "pioncer",
    "pioncerons": "pioncer",
    "pionceront": "pioncer",
    "pionces": "pioncer",
    "pioncez": "pioncer",
    "pionciez": "pioncer",
    "pioncions": "pioncer",
    "pioncèrent": "pioncer",
    "pioncé": "pioncer",
    "pionne": "pion",
    "pionnes": "pion",
    "pionniers": "pionnier",
    "pionnière": "pionnier",
    "pionnières": "pionnier",
    "pions": "pion",
    "pionça": "pioncer",
    "pionçai": "pioncer",
    "pionçaient": "pioncer",
    "pionçais": "pioncer",
    "pionçait": "pioncer",
    "pionçant": "pioncer",
    "pionças": "pioncer",
    "pionçasse": "pioncer",
    "pionçassent": "pioncer",
    "pionçasses": "pioncer",
    "pionçassiez": "pioncer",
    "pionçassions": "pioncer",
    "pionçons": "pioncer",
    "pionçâmes": "pioncer",
    "pionçât": "pioncer",
    "pionçâtes": "pioncer",
    "piots": "piot",
    "pioupious": "pioupiou",
    "pipa": "piper",
    "pipai": "piper",
    "pipaient": "piper",
    "pipais": "piper",
    "pipait": "piper",
    "pipant": "piper",
    "pipas": "piper",
    "pipasse": "piper",
    "pipassent": "piper",
    "pipasses": "piper",
    "pipassiez": "piper",
    "pipassions": "piper",
    "pipe": "piper",
    "pipe-lines": "pipe-line",
    "pipeaux": "pipeau",
    "pipelets": "pipelet",
    "pipelette": "pipelet",
    "pipelettes": "pipelette",
    "pipelines": "pipeline",
    "pipent": "piper",
    "piper-cubs": "piper-cub",
    "pipera": "piper",
    "piperai": "piper",
    "piperaient": "piper",
    "piperais": "piper",
    "piperait": "piper",
    "piperas": "piper",
    "piperez": "piper",
    "piperiez": "piper",
    "piperions": "piper",
    "piperons": "piper",
    "piperont": "piper",
    "pipes": "piper",
    "pipettes": "pipette",
    "pipeuse": "pipeur",
    "pipeuses": "pipeur",
    "pipez": "piper",
    "pipiers": "pipier",
    "pipiez": "piper",
    "pipions": "piper",
    "pipis": "pipi",
    "pipistrelles": "pipistrelle",
    "pipons": "piper",
    "pipâmes": "piper",
    "pipât": "piper",
    "pipâtes": "piper",
    "pipèrent": "piper",
    "pipé": "piper",
    "pipée": "piper",
    "pipées": "piper",
    "pipés": "piper",
    "piqua": "piquer",
    "piquages": "piquage",
    "piquai": "piquer",
    "piquaient": "piquer",
    "piquais": "piquer",
    "piquait": "piquer",
    "piquant": "piquer",
    "piquante": "piquant",
    "piquantes": "piquante",
    "piquants": "piquant",
    "piquas": "piquer",
    "piquasse": "piquer",
    "piquassent": "piquer",
    "piquasses": "piquer",
    "piquassiez": "piquer",
    "piquassions": "piquer",
    "pique": "piquer",
    "pique-assiettes": "pique-assiette",
    "pique-boeufs": "pique-boeuf",
    "pique-feux": "pique-feu",
    "pique-niqua": "pique-niquer",
    "pique-niquai": "pique-niquer",
    "pique-niquaient": "pique-niquer",
    "pique-niquais": "pique-niquer",
    "pique-niquait": "pique-niquer",
    "pique-niquant": "pique-niquer",
    "pique-niquas": "pique-niquer",
    "pique-niquasse": "pique-niquer",
    "pique-niquassent": "pique-niquer",
    "pique-niquasses": "pique-niquer",
    "pique-niquassiez": "pique-niquer",
    "pique-niquassions": "pique-niquer",
    "pique-nique": "pique-niquer",
    "pique-niquent": "pique-niquer",
    "pique-niquera": "pique-niquer",
    "pique-niquerai": "pique-niquer",
    "pique-niqueraient": "pique-niquer",
    "pique-niquerais": "pique-niquer",
    "pique-niquerait": "pique-niquer",
    "pique-niqueras": "pique-niquer",
    "pique-niquerez": "pique-niquer",
    "pique-niqueriez": "pique-niquer",
    "pique-niquerions": "pique-niquer",
    "pique-niquerons": "pique-niquer",
    "pique-niqueront": "pique-niquer",
    "pique-niques": "pique-niquer",
    "pique-niqueurs": "pique-niqueur",
    "pique-niquez": "pique-niquer",
    "pique-niquiez": "pique-niquer",
    "pique-niquions": "pique-niquer",
    "pique-niquons": "pique-niquer",
    "pique-niquâmes": "pique-niquer",
    "pique-niquât": "pique-niquer",
    "pique-niquâtes": "pique-niquer",
    "pique-niquèrent": "pique-niquer",
    "pique-niqué": "pique-niquer",
    "piquent": "piquer",
    "piquera": "piquer",
    "piquerai": "piquer",
    "piqueraient": "piquer",
    "piquerais": "piquer",
    "piquerait": "piquer",
    "piqueras": "piquer",
    "piquerez": "piquer",
    "piqueriez": "piquer",
    "piquerions": "piquer",
    "piquerons": "piqueron",
    "piqueront": "piquer",
    "piques": "piquer",
    "piqueta": "piqueter",
    "piquetai": "piqueter",
    "piquetaient": "piqueter",
    "piquetais": "piqueter",
    "piquetait": "piqueter",
    "piquetant": "piqueter",
    "piquetas": "piqueter",
    "piquetasse": "piqueter",
    "piquetassent": "piqueter",
    "piquetasses": "piqueter",
    "piquetassiez": "piqueter",
    "piquetassions": "piqueter",
    "piquetez": "piqueter",
    "piquetiez": "piqueter",
    "piquetions": "piqueter",
    "piquetons": "piqueter",
    "piquets": "piquet",
    "piquette": "piqueter",
    "piquettent": "piqueter",
    "piquettera": "piqueter",
    "piquetterai": "piqueter",
    "piquetteraient": "piqueter",
    "piquetterais": "piqueter",
    "piquetterait": "piqueter",
    "piquetteras": "piqueter",
    "piquetterez": "piqueter",
    "piquetteriez": "piqueter",
    "piquetterions": "piqueter",
    "piquetterons": "piqueter",
    "piquetteront": "piqueter",
    "piquettes": "piquette",
    "piquetâmes": "piqueter",
    "piquetât": "piqueter",
    "piquetâtes": "piqueter",
    "piquetèrent": "piqueter",
    "piqueté": "piqueter",
    "piquetée": "piqueter",
    "piquetées": "piqueter",
    "piquetés": "piqueter",
    "piqueurs": "piqueur",
    "piqueuse": "piqueux",
    "piqueuses": "piqueux",
    "piquez": "piquer",
    "piquiez": "piquer",
    "piquions": "piquer",
    "piquons": "piquer",
    "piquouses": "piquouse",
    "piquouzes": "piquouze",
    "piquâmes": "piquer",
    "piquât": "piquer",
    "piquâtes": "piquer",
    "piquèrent": "piquer",
    "piqué": "piquer",
    "piquée": "piquer",
    "piquées": "piquer",
    "piqués": "piquer",
    "piqûres": "piqûre",
    "pirandellienne": "pirandellien",
    "piranhas": "piranha",
    "pirata": "pirater",
    "piratages": "piratage",
    "piratai": "pirater",
    "pirataient": "pirater",
    "piratais": "pirater",
    "piratait": "pirater",
    "piratant": "pirater",
    "piratas": "pirater",
    "piratasse": "pirater",
    "piratassent": "pirater",
    "piratasses": "pirater",
    "piratassiez": "pirater",
    "piratassions": "pirater",
    "pirate": "pirater",
    "piratent": "pirater",
    "piratera": "pirater",
    "piraterai": "pirater",
    "pirateraient": "pirater",
    "piraterais": "pirater",
    "piraterait": "pirater",
    "pirateras": "pirater",
    "piraterez": "pirater",
    "pirateries": "piraterie",
    "pirateriez": "pirater",
    "piraterions": "pirater",
    "piraterons": "pirater",
    "pirateront": "pirater",
    "pirates": "pirater",
    "piratez": "pirater",
    "piratiez": "pirater",
    "pirations": "pirater",
    "piratons": "pirater",
    "piratâmes": "pirater",
    "piratât": "pirater",
    "piratâtes": "pirater",
    "piratèrent": "pirater",
    "piraté": "pirater",
    "piratée": "pirater",
    "piratées": "pirater",
    "piratés": "pirater",
    "pirayas": "piraya",
    "pires": "pire",
    "piriformes": "piriforme",
    "pirogues": "pirogue",
    "pirojkis": "pirojki",
    "pirouetta": "pirouetter",
    "pirouettai": "pirouetter",
    "pirouettaient": "pirouetter",
    "pirouettais": "pirouetter",
    "pirouettait": "pirouetter",
    "pirouettant": "pirouetter",
    "pirouettas": "pirouetter",
    "pirouettasse": "pirouetter",
    "pirouettassent": "pirouetter",
    "pirouettasses": "pirouetter",
    "pirouettassiez": "pirouetter",
    "pirouettassions": "pirouetter",
    "pirouette": "pirouetter",
    "pirouettent": "pirouetter",
    "pirouettera": "pirouetter",
    "pirouetterai": "pirouetter",
    "pirouetteraient": "pirouetter",
    "pirouetterais": "pirouetter",
    "pirouetterait": "pirouetter",
    "pirouetteras": "pirouetter",
    "pirouetterez": "pirouetter",
    "pirouetteriez": "pirouetter",
    "pirouetterions": "pirouetter",
    "pirouetterons": "pirouetter",
    "pirouetteront": "pirouetter",
    "pirouettes": "pirouetter",
    "pirouettez": "pirouetter",
    "pirouettiez": "pirouetter",
    "pirouettions": "pirouetter",
    "pirouettons": "pirouetter",
    "pirouettâmes": "pirouetter",
    "pirouettât": "pirouetter",
    "pirouettâtes": "pirouetter",
    "pirouettèrent": "pirouetter",
    "pirouetté": "pirouetter",
    "pisa": "piser",
    "pisans": "pisan",
    "piscicoles": "piscicole",
    "piscicultures": "pisciculture",
    "piscines": "piscine",
    "pissa": "pisser",
    "pissai": "pisser",
    "pissaient": "pisser",
    "pissais": "pisser",
    "pissait": "pisser",
    "pissant": "pisser",
    "pissas": "pisser",
    "pissasse": "pisser",
    "pissassent": "pisser",
    "pissasses": "pisser",
    "pissassiez": "pisser",
    "pissassions": "pisser",
    "pisse": "pisser",
    "pisse-copies": "pisse-copie",
    "pissenlits": "pissenlit",
    "pissent": "pisser",
    "pissera": "pisser",
    "pisserai": "pisser",
    "pisseraient": "pisser",
    "pisserais": "pisser",
    "pisserait": "pisser",
    "pisseras": "pisser",
    "pisserez": "pisser",
    "pisseriez": "pisser",
    "pisserions": "pisser",
    "pisserons": "pisser",
    "pisseront": "pisser",
    "pisses": "pisser",
    "pisseurs": "pisseur",
    "pisseuse": "pisseur",
    "pisseuses": "pisseur",
    "pissez": "pisser",
    "pissiez": "pisser",
    "pissions": "pisser",
    "pissons": "pisser",
    "pissotières": "pissotière",
    "pissâmes": "pisser",
    "pissât": "pisser",
    "pissâtes": "pisser",
    "pissèrent": "pisser",
    "pissé": "pisser",
    "pissée": "pisser",
    "pissées": "pisser",
    "pissés": "pisser",
    "pista": "pister",
    "pistaches": "pistache",
    "pistachiers": "pistachier",
    "pistai": "pister",
    "pistaient": "pister",
    "pistais": "pister",
    "pistait": "pister",
    "pistant": "pister",
    "pistards": "pistard",
    "pistas": "pister",
    "pistasse": "pister",
    "pistassent": "pister",
    "pistasses": "pister",
    "pistassiez": "pister",
    "pistassions": "pister",
    "piste": "pister",
    "pistent": "pister",
    "pistera": "pister",
    "pisterai": "pister",
    "pisteraient": "pister",
    "pisterais": "pister",
    "pisterait": "pister",
    "pisteras": "pister",
    "pisterez": "pister",
    "pisteriez": "pister",
    "pisterions": "pister",
    "pisterons": "pister",
    "pisteront": "pister",
    "pistes": "pister",
    "pisteurs": "pisteur",
    "pistez": "pister",
    "pistiez": "pister",
    "pistils": "pistil",
    "pistions": "pister",
    "pistoleros": "pistolero",
    "pistoles": "pistole",
    "pistolets": "pistolet",
    "pistolets-mitrailleurs": "pistolet-mitrailleur",
    "pistoleurs": "pistoleur",
    "pistonna": "pistonner",
    "pistonnai": "pistonner",
    "pistonnaient": "pistonner",
    "pistonnais": "pistonner",
    "pistonnait": "pistonner",
    "pistonnant": "pistonner",
    "pistonnas": "pistonner",
    "pistonnasse": "pistonner",
    "pistonnassent": "pistonner",
    "pistonnasses": "pistonner",
    "pistonnassiez": "pistonner",
    "pistonnassions": "pistonner",
    "pistonne": "pistonner",
    "pistonnent": "pistonner",
    "pistonnera": "pistonner",
    "pistonnerai": "pistonner",
    "pistonneraient": "pistonner",
    "pistonnerais": "pistonner",
    "pistonnerait": "pistonner",
    "pistonneras": "pistonner",
    "pistonnerez": "pistonner",
    "pistonneriez": "pistonner",
    "pistonnerions": "pistonner",
    "pistonnerons": "pistonner",
    "pistonneront": "pistonner",
    "pistonnes": "pistonner",
    "pistonnez": "pistonner",
    "pistonniez": "pistonner",
    "pistonnions": "pistonner",
    "pistonnons": "pistonner",
    "pistonnâmes": "pistonner",
    "pistonnât": "pistonner",
    "pistonnâtes": "pistonner",
    "pistonnèrent": "pistonner",
    "pistonné": "pistonner",
    "pistonnée": "pistonner",
    "pistonnées": "pistonner",
    "pistonnés": "pistonner",
    "pistons": "piston",
    "pistous": "pistou",
    "pistâmes": "pister",
    "pistât": "pister",
    "pistâtes": "pister",
    "pistèrent": "pister",
    "pisté": "pister",
    "pistée": "pister",
    "pistées": "pister",
    "pistés": "pister",
    "pisés": "pisé",
    "pit bull": "pit-bull",
    "pit-bulls": "pit-bull",
    "pitances": "pitance",
    "pitancherai": "pitancher",
    "pitas": "pita",
    "pitbulls": "pitbull",
    "pitchoune": "pitchoun",
    "pitchpins": "pitchpin",
    "piteuse": "piteux",
    "piteuses": "piteux",
    "pithécanthropes": "pithécanthrope",
    "pitiés": "pitié",
    "pitonna": "pitonner",
    "pitonnai": "pitonner",
    "pitonnaient": "pitonner",
    "pitonnais": "pitonner",
    "pitonnait": "pitonner",
    "pitonnant": "pitonner",
    "pitonnas": "pitonner",
    "pitonnasse": "pitonner",
    "pitonnassent": "pitonner",
    "pitonnasses": "pitonner",
    "pitonnassiez": "pitonner",
    "pitonnassions": "pitonner",
    "pitonne": "pitonner",
    "pitonnent": "pitonner",
    "pitonnera": "pitonner",
    "pitonnerai": "pitonner",
    "pitonneraient": "pitonner",
    "pitonnerais": "pitonner",
    "pitonnerait": "pitonner",
    "pitonneras": "pitonner",
    "pitonnerez": "pitonner",
    "pitonneriez": "pitonner",
    "pitonnerions": "pitonner",
    "pitonnerons": "pitonner",
    "pitonneront": "pitonner",
    "pitonnes": "pitonner",
    "pitonnez": "pitonner",
    "pitonniez": "pitonner",
    "pitonnions": "pitonner",
    "pitonnons": "pitonner",
    "pitonnâmes": "pitonner",
    "pitonnât": "pitonner",
    "pitonnâtes": "pitonner",
    "pitonnèrent": "pitonner",
    "pitonné": "pitonner",
    "pitonnée": "pitonner",
    "pitonnées": "pitonner",
    "pitonnés": "pitonner",
    "pitons": "piton",
    "pitoyables": "pitoyable",
    "pitreries": "pitrerie",
    "pitres": "pitre",
    "pittoresques": "pittoresque",
    "pituitaires": "pituitaire",
    "piverts": "pivert",
    "pivoines": "pivoine",
    "pivota": "pivoter",
    "pivotai": "pivoter",
    "pivotaient": "pivoter",
    "pivotais": "pivoter",
    "pivotait": "pivoter",
    "pivotant": "pivoter",
    "pivotante": "pivotant",
    "pivotantes": "pivotant",
    "pivotants": "pivotant",
    "pivotas": "pivoter",
    "pivotasse": "pivoter",
    "pivotassent": "pivoter",
    "pivotasses": "pivoter",
    "pivotassiez": "pivoter",
    "pivotassions": "pivoter",
    "pivote": "pivoter",
    "pivotent": "pivoter",
    "pivotera": "pivoter",
    "pivoterai": "pivoter",
    "pivoteraient": "pivoter",
    "pivoterais": "pivoter",
    "pivoterait": "pivoter",
    "pivoteras": "pivoter",
    "pivoterez": "pivoter",
    "pivoteriez": "pivoter",
    "pivoterions": "pivoter",
    "pivoterons": "pivoter",
    "pivoteront": "pivoter",
    "pivotes": "pivoter",
    "pivotez": "pivoter",
    "pivotiez": "pivoter",
    "pivotions": "pivoter",
    "pivotons": "pivoter",
    "pivots": "pivot",
    "pivotâmes": "pivoter",
    "pivotât": "pivoter",
    "pivotâtes": "pivoter",
    "pivotèrent": "pivoter",
    "pivoté": "pivoter",
    "pixellisés": "pixelliser",
    "pixels": "pixel",
    "pizzas": "pizza",
    "pizzerias": "pizzeria",
    "pizzicatos": "pizzicato",
    "pièces": "pièce",
    "piège": "piéger",
    "piègent": "piéger",
    "pièges": "piéger",
    "piète": "piéter",
    "piètent": "piéter",
    "piètes": "piéter",
    "piètres": "piètre",
    "piécettes": "piécette",
    "piédestaux": "piédestal",
    "piédouches": "piédouche",
    "piédroits": "piédroit",
    "piéforts": "piéfort",
    "piégea": "piéger",
    "piégeages": "piégeage",
    "piégeai": "piéger",
    "piégeaient": "piéger",
    "piégeais": "piéger",
    "piégeait": "piéger",
    "piégeant": "piéger",
    "piégeas": "piéger",
    "piégeasse": "piéger",
    "piégeassent": "piéger",
    "piégeasses": "piéger",
    "piégeassiez": "piéger",
    "piégeassions": "piéger",
    "piégeons": "piéger",
    "piégera": "piéger",
    "piégerai": "piéger",
    "piégeraient": "piéger",
    "piégerais": "piéger",
    "piégerait": "piéger",
    "piégeras": "piéger",
    "piégerez": "piéger",
    "piégeriez": "piéger",
    "piégerions": "piéger",
    "piégerons": "piéger",
    "piégeront": "piéger",
    "piégeurs": "piégeur",
    "piégeuse": "piégeur",
    "piégeuses": "piégeur",
    "piégez": "piéger",
    "piégeâmes": "piéger",
    "piégeât": "piéger",
    "piégeâtes": "piéger",
    "piégiez": "piéger",
    "piégions": "piéger",
    "piégèrent": "piéger",
    "piégé": "piéger",
    "piégée": "piéger",
    "piégées": "piéger",
    "piégés": "piéger",
    "piémontaise": "piémontais",
    "piémontaises": "piémontais",
    "piérides": "piéride",
    "piéta": "piéter",
    "piétai": "piéter",
    "piétaient": "piéter",
    "piétailles": "piétaille",
    "piétais": "piéter",
    "piétait": "piéter",
    "piétant": "piéter",
    "piétas": "piéter",
    "piétasse": "piéter",
    "piétassent": "piéter",
    "piétasses": "piéter",
    "piétassiez": "piéter",
    "piétassions": "piéter",
    "piétements": "piétement",
    "piétera": "piéter",
    "piéterai": "piéter",
    "piéteraient": "piéter",
    "piéterais": "piéter",
    "piéterait": "piéter",
    "piéteras": "piéter",
    "piéterez": "piéter",
    "piéteriez": "piéter",
    "piéterions": "piéter",
    "piéterons": "piéter",
    "piéteront": "piéter",
    "piétez": "piéter",
    "piétiez": "piéter",
    "piétina": "piétiner",
    "piétinai": "piétiner",
    "piétinaient": "piétiner",
    "piétinais": "piétiner",
    "piétinait": "piétiner",
    "piétinant": "piétiner",
    "piétinante": "piétinant",
    "piétinas": "piétiner",
    "piétinasse": "piétiner",
    "piétinassent": "piétiner",
    "piétinasses": "piétiner",
    "piétinassiez": "piétiner",
    "piétinassions": "piétiner",
    "piétine": "piétiner",
    "piétinements": "piétinement",
    "piétinent": "piétiner",
    "piétinera": "piétiner",
    "piétinerai": "piétiner",
    "piétineraient": "piétiner",
    "piétinerais": "piétiner",
    "piétinerait": "piétiner",
    "piétineras": "piétiner",
    "piétinerez": "piétiner",
    "piétineriez": "piétiner",
    "piétinerions": "piétiner",
    "piétinerons": "piétiner",
    "piétineront": "piétiner",
    "piétines": "piétiner",
    "piétinez": "piétiner",
    "piétiniez": "piétiner",
    "piétinions": "piétiner",
    "piétinons": "piétiner",
    "piétins": "piétin",
    "piétinâmes": "piétiner",
    "piétinât": "piétiner",
    "piétinâtes": "piétiner",
    "piétinèrent": "piétiner",
    "piétiné": "piétiner",
    "piétinée": "piétiner",
    "piétinées": "piétiner",
    "piétinés": "piétiner",
    "piétions": "piéter",
    "piétonne": "piéton",
    "piétonnes": "piéton",
    "piétonniers": "piétonnier",
    "piétonnière": "piétonnier",
    "piétonnières": "piétonnier",
    "piétons": "piéton",
    "piétâmes": "piéter",
    "piétât": "piéter",
    "piétâtes": "piéter",
    "piétèrent": "piéter",
    "piété": "piéter",
    "piétés": "piété",
    "placages": "placage",
    "placarda": "placarder",
    "placardai": "placarder",
    "placardaient": "placarder",
    "placardais": "placarder",
    "placardait": "placarder",
    "placardant": "placarder",
    "placardas": "placarder",
    "placardasse": "placarder",
    "placardassent": "placarder",
    "placardasses": "placarder",
    "placardassiez": "placarder",
    "placardassions": "placarder",
    "placarde": "placarder",
    "placardent": "placarder",
    "placardera": "placarder",
    "placarderai": "placarder",
    "placarderaient": "placarder",
    "placarderais": "placarder",
    "placarderait": "placarder",
    "placarderas": "placarder",
    "placarderez": "placarder",
    "placarderiez": "placarder",
    "placarderions": "placarder",
    "placarderons": "placarder",
    "placarderont": "placarder",
    "placardes": "placarder",
    "placardez": "placarder",
    "placardiez": "placarder",
    "placardions": "placarder",
    "placardons": "placarder",
    "placards": "placard",
    "placardâmes": "placarder",
    "placardât": "placarder",
    "placardâtes": "placarder",
    "placardèrent": "placarder",
    "placardé": "placarder",
    "placardée": "placarder",
    "placardées": "placarder",
    "placardés": "placarder",
    "place": "placer",
    "placebos": "placebo",
    "placements": "placement",
    "placent": "placer",
    "placentas": "placenta",
    "placera": "placer",
    "placerai": "placer",
    "placeraient": "placer",
    "placerais": "placer",
    "placerait": "placer",
    "placeras": "placer",
    "placerez": "placer",
    "placeriez": "placer",
    "placerions": "placer",
    "placerons": "placer",
    "placeront": "placer",
    "placers": "placer",
    "places": "placer",
    "placets": "placet",
    "placettes": "placette",
    "placeurs": "placeur",
    "placeuse": "placeur",
    "placeuses": "placeur",
    "placez": "placer",
    "placides": "placide",
    "placiers": "placier",
    "placiez": "placer",
    "placions": "placer",
    "placèrent": "placer",
    "placé": "placer",
    "placée": "placer",
    "placées": "placer",
    "placés": "placer",
    "plafonds": "plafond",
    "plafonna": "plafonner",
    "plafonnai": "plafonner",
    "plafonnaient": "plafonner",
    "plafonnais": "plafonner",
    "plafonnait": "plafonner",
    "plafonnant": "plafonner",
    "plafonnas": "plafonner",
    "plafonnasse": "plafonner",
    "plafonnassent": "plafonner",
    "plafonnasses": "plafonner",
    "plafonnassiez": "plafonner",
    "plafonnassions": "plafonner",
    "plafonne": "plafonner",
    "plafonnent": "plafonner",
    "plafonnera": "plafonner",
    "plafonnerai": "plafonner",
    "plafonneraient": "plafonner",
    "plafonnerais": "plafonner",
    "plafonnerait": "plafonner",
    "plafonneras": "plafonner",
    "plafonnerez": "plafonner",
    "plafonneriez": "plafonner",
    "plafonnerions": "plafonner",
    "plafonnerons": "plafonner",
    "plafonneront": "plafonner",
    "plafonnes": "plafonner",
    "plafonnez": "plafonner",
    "plafonniers": "plafonnier",
    "plafonniez": "plafonner",
    "plafonnions": "plafonner",
    "plafonnière": "plafonnier",
    "plafonnons": "plafonner",
    "plafonnâmes": "plafonner",
    "plafonnât": "plafonner",
    "plafonnâtes": "plafonner",
    "plafonnèrent": "plafonner",
    "plafonné": "plafonner",
    "plafonnée": "plafonner",
    "plafonnées": "plafonner",
    "plafonnés": "plafonner",
    "plages": "plage",
    "plagia": "plagier",
    "plagiai": "plagier",
    "plagiaient": "plagier",
    "plagiaires": "plagiaire",
    "plagiais": "plagier",
    "plagiait": "plagier",
    "plagiant": "plagier",
    "plagias": "plagier",
    "plagiasse": "plagier",
    "plagiassent": "plagier",
    "plagiasses": "plagier",
    "plagiassiez": "plagier",
    "plagiassions": "plagier",
    "plagiats": "plagiat",
    "plagie": "plagier",
    "plagient": "plagier",
    "plagiera": "plagier",
    "plagierai": "plagier",
    "plagieraient": "plagier",
    "plagierais": "plagier",
    "plagierait": "plagier",
    "plagieras": "plagier",
    "plagierez": "plagier",
    "plagieriez": "plagier",
    "plagierions": "plagier",
    "plagierons": "plagier",
    "plagieront": "plagier",
    "plagies": "plagier",
    "plagiez": "plagier",
    "plagiiez": "plagier",
    "plagiions": "plagier",
    "plagions": "plagier",
    "plagiâmes": "plagier",
    "plagiât": "plagier",
    "plagiâtes": "plagier",
    "plagièrent": "plagier",
    "plagié": "plagier",
    "plagiée": "plagier",
    "plagiées": "plagier",
    "plagiés": "plagier",
    "plaida": "plaider",
    "plaidai": "plaider",
    "plaidaient": "plaider",
    "plaidais": "plaider",
    "plaidait": "plaider",
    "plaidant": "plaider",
    "plaidants": "plaidant",
    "plaidas": "plaider",
    "plaidasse": "plaider",
    "plaidassent": "plaider",
    "plaidasses": "plaider",
    "plaidassiez": "plaider",
    "plaidassions": "plaider",
    "plaide": "plaider",
    "plaident": "plaider",
    "plaidera": "plaider",
    "plaiderai": "plaider",
    "plaideraient": "plaider",
    "plaiderais": "plaider",
    "plaiderait": "plaider",
    "plaideras": "plaider",
    "plaiderez": "plaider",
    "plaideriez": "plaider",
    "plaiderions": "plaider",
    "plaiderons": "plaider",
    "plaideront": "plaider",
    "plaides": "plaider",
    "plaideurs": "plaideur",
    "plaideuse": "plaideur",
    "plaideuses": "plaideur",
    "plaidez": "plaider",
    "plaidiez": "plaider",
    "plaidions": "plaider",
    "plaidoiries": "plaidoirie",
    "plaidons": "plaider",
    "plaidoyers": "plaidoyer",
    "plaids": "plaid",
    "plaidâmes": "plaider",
    "plaidât": "plaider",
    "plaidâtes": "plaider",
    "plaidèrent": "plaider",
    "plaidé": "plaider",
    "plaidée": "plaider",
    "plaidées": "plaider",
    "plaidés": "plaider",
    "plaies": "plaie",
    "plaignaient": "plaindre",
    "plaignais": "plaindre",
    "plaignait": "plaindre",
    "plaignant": "plaindre",
    "plaignante": "plaignant",
    "plaignantes": "plaignant",
    "plaignants": "plaignant",
    "plaigne": "plaindre",
    "plaignent": "plaindre",
    "plaignes": "plaindre",
    "plaignez": "plaindre",
    "plaigniez": "plaindre",
    "plaignions": "plaindre",
    "plaignirent": "plaindre",
    "plaignis": "plaindre",
    "plaignisse": "plaindre",
    "plaignissent": "plaindre",
    "plaignisses": "plaindre",
    "plaignissiez": "plaindre",
    "plaignissions": "plaindre",
    "plaignit": "plaindre",
    "plaignons": "plaindre",
    "plaignîmes": "plaindre",
    "plaignît": "plaindre",
    "plaignîtes": "plaindre",
    "plaindra": "plaindre",
    "plaindrai": "plaindre",
    "plaindraient": "plaindre",
    "plaindrais": "plaindre",
    "plaindrait": "plaindre",
    "plaindras": "plaindre",
    "plaindrez": "plaindre",
    "plaindriez": "plaindre",
    "plaindrions": "plaindre",
    "plaindrons": "plaindre",
    "plaindront": "plaindre",
    "plaine": "plain",
    "plaines": "plaine",
    "plains": "plaindre",
    "plains-chants": "plain-chant",
    "plaint": "plaindre",
    "plainte": "plaindre",
    "plaintes": "plainte",
    "plaintifs": "plaintif",
    "plaintive": "plaintif",
    "plaintives": "plaintif",
    "plaints": "plaindre",
    "plaira": "plaire",
    "plairai": "plaire",
    "plairaient": "plaire",
    "plairais": "plaire",
    "plairait": "plaire",
    "plairas": "plaire",
    "plairez": "plaire",
    "plairiez": "plaire",
    "plairions": "plaire",
    "plairons": "plaire",
    "plairont": "plaire",
    "plais": "plaire",
    "plaisaient": "plaire",
    "plaisais": "plaire",
    "plaisait": "plaire",
    "plaisances": "plaisance",
    "plaisanciers": "plaisancier",
    "plaisancière": "plaisancier",
    "plaisancières": "plaisancier",
    "plaisant": "plaire",
    "plaisanta": "plaisanter",
    "plaisantai": "plaisanter",
    "plaisantaient": "plaisanter",
    "plaisantais": "plaisanter",
    "plaisantait": "plaisanter",
    "plaisantant": "plaisanter",
    "plaisantas": "plaisanter",
    "plaisantasse": "plaisanter",
    "plaisantassent": "plaisanter",
    "plaisantasses": "plaisanter",
    "plaisantassiez": "plaisanter",
    "plaisantassions": "plaisanter",
    "plaisante": "plaisanter",
    "plaisantent": "plaisanter",
    "plaisantera": "plaisanter",
    "plaisanterai": "plaisanter",
    "plaisanteraient": "plaisanter",
    "plaisanterais": "plaisanter",
    "plaisanterait": "plaisanter",
    "plaisanteras": "plaisanter",
    "plaisanterez": "plaisanter",
    "plaisanteries": "plaisanterie",
    "plaisanteriez": "plaisanter",
    "plaisanterions": "plaisanter",
    "plaisanterons": "plaisanter",
    "plaisanteront": "plaisanter",
    "plaisantes": "plaisanter",
    "plaisantez": "plaisanter",
    "plaisantiez": "plaisanter",
    "plaisantins": "plaisantin",
    "plaisantions": "plaisanter",
    "plaisantons": "plaisanter",
    "plaisants": "plaisant",
    "plaisantâmes": "plaisanter",
    "plaisantât": "plaisanter",
    "plaisantâtes": "plaisanter",
    "plaisantèrent": "plaisanter",
    "plaisanté": "plaisanter",
    "plaisantée": "plaisanter",
    "plaisantées": "plaisanter",
    "plaisantés": "plaisanter",
    "plaise": "plaire",
    "plaisent": "plaire",
    "plaises": "plaire",
    "plaisez": "plaire",
    "plaisiez": "plaire",
    "plaisions": "plaire",
    "plaisirs": "plaisir",
    "plaisons": "plaire",
    "plana": "planer",
    "planai": "planer",
    "planaient": "planer",
    "planais": "planer",
    "planait": "planer",
    "planant": "planer",
    "planante": "planant",
    "planantes": "planant",
    "planants": "planant",
    "planas": "planer",
    "planasse": "planer",
    "planassent": "planer",
    "planasses": "planer",
    "planassiez": "planer",
    "planassions": "planer",
    "plancha": "plancher",
    "planchai": "plancher",
    "planchaient": "plancher",
    "planchais": "plancher",
    "planchait": "plancher",
    "planchant": "plancher",
    "planchas": "plancher",
    "planchasse": "plancher",
    "planchassent": "plancher",
    "planchasses": "plancher",
    "planchassiez": "plancher",
    "planchassions": "plancher",
    "planche": "plancher",
    "planchent": "plancher",
    "planchera": "plancher",
    "plancherai": "plancher",
    "plancheraient": "plancher",
    "plancherais": "plancher",
    "plancherait": "plancher",
    "plancheras": "plancher",
    "plancherez": "plancher",
    "plancheriez": "plancher",
    "plancherions": "plancher",
    "plancherons": "plancher",
    "plancheront": "plancher",
    "planchers": "plancher",
    "planches": "plancher",
    "planches-contacts": "planche-contact",
    "planchettes": "planchette",
    "planchez": "plancher",
    "planchiez": "plancher",
    "planchions": "plancher",
    "planchons": "plancher",
    "planchâmes": "plancher",
    "planchât": "plancher",
    "planchâtes": "plancher",
    "planchèrent": "plancher",
    "planché": "plancher",
    "planchée": "plancher",
    "planchées": "plancher",
    "planchéia": "planchéier",
    "planchéiai": "planchéier",
    "planchéiaient": "planchéier",
    "planchéiais": "planchéier",
    "planchéiait": "planchéier",
    "planchéiant": "planchéier",
    "planchéias": "planchéier",
    "planchéiasse": "planchéier",
    "planchéiassent": "planchéier",
    "planchéiasses": "planchéier",
    "planchéiassiez": "planchéier",
    "planchéiassions": "planchéier",
    "planchéie": "planchéier",
    "planchéient": "planchéier",
    "planchéiera": "planchéier",
    "planchéierai": "planchéier",
    "planchéieraient": "planchéier",
    "planchéierais": "planchéier",
    "planchéierait": "planchéier",
    "planchéieras": "planchéier",
    "planchéierez": "planchéier",
    "planchéieriez": "planchéier",
    "planchéierions": "planchéier",
    "planchéierons": "planchéier",
    "planchéieront": "planchéier",
    "planchéies": "planchéier",
    "planchéiez": "planchéier",
    "planchéiiez": "planchéier",
    "planchéiions": "planchéier",
    "planchéions": "planchéier",
    "planchéiâmes": "planchéier",
    "planchéiât": "planchéier",
    "planchéiâtes": "planchéier",
    "planchéièrent": "planchéier",
    "planchéié": "planchéier",
    "planchéiée": "planchéier",
    "planchéiées": "planchéier",
    "planchéiés": "planchéier",
    "planchés": "plancher",
    "planctons": "plancton",
    "plane": "planer",
    "planent": "planer",
    "planera": "planer",
    "planerai": "planer",
    "planeraient": "planer",
    "planerais": "planer",
    "planerait": "planer",
    "planeras": "planer",
    "planerez": "planer",
    "planeriez": "planer",
    "planerions": "planer",
    "planerons": "planer",
    "planeront": "planer",
    "planes": "planer",
    "planeurs": "planeur",
    "planez": "planer",
    "planiez": "planer",
    "planifia": "planifier",
    "planifiables": "planifiable",
    "planifiai": "planifier",
    "planifiaient": "planifier",
    "planifiais": "planifier",
    "planifiait": "planifier",
    "planifiant": "planifier",
    "planifias": "planifier",
    "planifiasse": "planifier",
    "planifiassent": "planifier",
    "planifiasses": "planifier",
    "planifiassiez": "planifier",
    "planifiassions": "planifier",
    "planificateurs": "planificateur",
    "planifications": "planification",
    "planificatrice": "planificateur",
    "planificatrices": "planificateur",
    "planifie": "planifier",
    "planifient": "planifier",
    "planifiera": "planifier",
    "planifierai": "planifier",
    "planifieraient": "planifier",
    "planifierais": "planifier",
    "planifierait": "planifier",
    "planifieras": "planifier",
    "planifierez": "planifier",
    "planifieriez": "planifier",
    "planifierions": "planifier",
    "planifierons": "planifier",
    "planifieront": "planifier",
    "planifies": "planifier",
    "planifiez": "planifier",
    "planifiiez": "planifier",
    "planifiions": "planifier",
    "planifions": "planifier",
    "planifiâmes": "planifier",
    "planifiât": "planifier",
    "planifiâtes": "planifier",
    "planifièrent": "planifier",
    "planifié": "planifier",
    "planifiée": "planifier",
    "planifiées": "planifier",
    "planifiés": "planifier",
    "planions": "planer",
    "planisphères": "planisphère",
    "plannings": "planning",
    "planons": "planer",
    "planqua": "planquer",
    "planquai": "planquer",
    "planquaient": "planquer",
    "planquais": "planquer",
    "planquait": "planquer",
    "planquant": "planquer",
    "planquas": "planquer",
    "planquasse": "planquer",
    "planquassent": "planquer",
    "planquasses": "planquer",
    "planquassiez": "planquer",
    "planquassions": "planquer",
    "planque": "planquer",
    "planquent": "planquer",
    "planquera": "planquer",
    "planquerai": "planquer",
    "planqueraient": "planquer",
    "planquerais": "planquer",
    "planquerait": "planquer",
    "planqueras": "planquer",
    "planquerez": "planquer",
    "planqueriez": "planquer",
    "planquerions": "planquer",
    "planquerons": "planquer",
    "planqueront": "planquer",
    "planques": "planquer",
    "planquez": "planquer",
    "planquiez": "planquer",
    "planquions": "planquer",
    "planquons": "planquer",
    "planquâmes": "planquer",
    "planquât": "planquer",
    "planquâtes": "planquer",
    "planquèrent": "planquer",
    "planqué": "planquer",
    "planquée": "planquer",
    "planquées": "planquer",
    "planqués": "planquer",
    "plans": "plan",
    "plans-masses": "plan-masse",
    "planta": "planter",
    "plantai": "planter",
    "plantaient": "planter",
    "plantains": "plantain",
    "plantaires": "plantaire",
    "plantais": "planter",
    "plantait": "planter",
    "plantant": "planter",
    "plantas": "planter",
    "plantasse": "planter",
    "plantassent": "planter",
    "plantasses": "planter",
    "plantassiez": "planter",
    "plantassions": "planter",
    "plantations": "plantation",
    "plante": "planter",
    "plantent": "planter",
    "plantera": "planter",
    "planterai": "planter",
    "planteraient": "planter",
    "planterais": "planter",
    "planterait": "planter",
    "planteras": "planter",
    "planterez": "planter",
    "planteriez": "planter",
    "planterions": "planter",
    "planterons": "planter",
    "planteront": "planter",
    "plantes": "planter",
    "planteurs": "planteur",
    "plantez": "planter",
    "plantiez": "planter",
    "plantigrades": "plantigrade",
    "plantions": "planter",
    "plantons": "planton",
    "plantrice": "planteur",
    "plantrices": "planteur",
    "plants": "plant",
    "plantureuse": "plantureux",
    "plantureuses": "plantureux",
    "plantâmes": "planter",
    "plantât": "planter",
    "plantâtes": "planter",
    "plantèrent": "planter",
    "planté": "planter",
    "plantée": "planter",
    "plantées": "planter",
    "plantés": "planter",
    "planâmes": "planer",
    "planât": "planer",
    "planâtes": "planer",
    "planèrent": "planer",
    "planètes": "planète",
    "planèzes": "planèze",
    "plané": "planer",
    "planée": "planer",
    "planées": "planer",
    "planés": "planer",
    "planétaires": "planétaire",
    "planétariums": "planétarium",
    "plaqua": "plaquer",
    "plaquages": "plaquage",
    "plaquai": "plaquer",
    "plaquaient": "plaquer",
    "plaquais": "plaquer",
    "plaquait": "plaquer",
    "plaquant": "plaquer",
    "plaquas": "plaquer",
    "plaquasse": "plaquer",
    "plaquassent": "plaquer",
    "plaquasses": "plaquer",
    "plaquassiez": "plaquer",
    "plaquassions": "plaquer",
    "plaque": "plaquer",
    "plaqueminiers": "plaqueminier",
    "plaquent": "plaquer",
    "plaquera": "plaquer",
    "plaquerai": "plaquer",
    "plaqueraient": "plaquer",
    "plaquerais": "plaquer",
    "plaquerait": "plaquer",
    "plaqueras": "plaquer",
    "plaquerez": "plaquer",
    "plaqueriez": "plaquer",
    "plaquerions": "plaquer",
    "plaquerons": "plaquer",
    "plaqueront": "plaquer",
    "plaques": "plaquer",
    "plaquettes": "plaquette",
    "plaquez": "plaquer",
    "plaquiez": "plaquer",
    "plaquions": "plaquer",
    "plaquons": "plaquer",
    "plaquâmes": "plaquer",
    "plaquât": "plaquer",
    "plaquâtes": "plaquer",
    "plaquèrent": "plaquer",
    "plaqué": "plaquer",
    "plaquée": "plaquer",
    "plaquées": "plaquer",
    "plaqués": "plaquer",
    "plasmas": "plasma",
    "plasticages": "plasticage",
    "plasticienne": "plasticien",
    "plasticiennes": "plasticien",
    "plasticiens": "plasticien",
    "plasticités": "plasticité",
    "plastics": "plastic",
    "plastifié": "plastifier",
    "plastifiée": "plastifier",
    "plastifiées": "plastifier",
    "plastifiés": "plastifier",
    "plastiqua": "plastiquer",
    "plastiquai": "plastiquer",
    "plastiquaient": "plastiquer",
    "plastiquais": "plastiquer",
    "plastiquait": "plastiquer",
    "plastiquant": "plastiquer",
    "plastiquas": "plastiquer",
    "plastiquasse": "plastiquer",
    "plastiquassent": "plastiquer",
    "plastiquasses": "plastiquer",
    "plastiquassiez": "plastiquer",
    "plastiquassions": "plastiquer",
    "plastique": "plastiquer",
    "plastiquent": "plastiquer",
    "plastiquera": "plastiquer",
    "plastiquerai": "plastiquer",
    "plastiqueraient": "plastiquer",
    "plastiquerais": "plastiquer",
    "plastiquerait": "plastiquer",
    "plastiqueras": "plastiquer",
    "plastiquerez": "plastiquer",
    "plastiqueriez": "plastiquer",
    "plastiquerions": "plastiquer",
    "plastiquerons": "plastiquer",
    "plastiqueront": "plastiquer",
    "plastiques": "plastiquer",
    "plastiquez": "plastiquer",
    "plastiquiez": "plastiquer",
    "plastiquions": "plastiquer",
    "plastiquons": "plastiquer",
    "plastiquâmes": "plastiquer",
    "plastiquât": "plastiquer",
    "plastiquâtes": "plastiquer",
    "plastiquèrent": "plastiquer",
    "plastiqué": "plastiquer",
    "plastiquée": "plastiquer",
    "plastiquées": "plastiquer",
    "plastiqués": "plastiquer",
    "plastronna": "plastronner",
    "plastronnai": "plastronner",
    "plastronnaient": "plastronner",
    "plastronnais": "plastronner",
    "plastronnait": "plastronner",
    "plastronnant": "plastronner",
    "plastronnas": "plastronner",
    "plastronnasse": "plastronner",
    "plastronnassent": "plastronner",
    "plastronnasses": "plastronner",
    "plastronnassiez": "plastronner",
    "plastronnassions": "plastronner",
    "plastronne": "plastronner",
    "plastronnent": "plastronner",
    "plastronnera": "plastronner",
    "plastronnerai": "plastronner",
    "plastronneraient": "plastronner",
    "plastronnerais": "plastronner",
    "plastronnerait": "plastronner",
    "plastronneras": "plastronner",
    "plastronnerez": "plastronner",
    "plastronneriez": "plastronner",
    "plastronnerions": "plastronner",
    "plastronnerons": "plastronner",
    "plastronneront": "plastronner",
    "plastronnes": "plastronner",
    "plastronnez": "plastronner",
    "plastronniez": "plastronner",
    "plastronnions": "plastronner",
    "plastronnons": "plastronner",
    "plastronnâmes": "plastronner",
    "plastronnât": "plastronner",
    "plastronnâtes": "plastronner",
    "plastronnèrent": "plastronner",
    "plastronné": "plastronner",
    "plastrons": "plastron",
    "plasturgies": "plasturgie",
    "platanes": "platane",
    "plate": "plat",
    "plateaux": "plateau",
    "plateaux-repas": "plateau-repas",
    "platebandes": "platebande",
    "plateformes": "plateforme",
    "plateresques": "plateresque",
    "plates": "plate",
    "plates-bandes": "plate-bande",
    "plates-formes": "plate-forme",
    "platines": "platine",
    "platinée": "platiner",
    "platinées": "platiné",
    "platinés": "platiné",
    "platitudes": "platitude",
    "platonicienne": "platonicien",
    "platoniciens": "platonicien",
    "platoniques": "platonique",
    "plats": "plat",
    "plats-bords": "plat-bord",
    "platures": "plature",
    "platyrrhiniens": "platyrrhinien",
    "platées": "platée",
    "plausibles": "plausible",
    "play back": "play-back",
    "play-boys": "play-boy",
    "playboys": "playboy",
    "playmates": "playmate",
    "plaça": "placer",
    "plaçai": "placer",
    "plaçaient": "placer",
    "plaçais": "placer",
    "plaçait": "placer",
    "plaçant": "placer",
    "plaças": "placer",
    "plaçasse": "placer",
    "plaçassent": "placer",
    "plaçasses": "placer",
    "plaçassiez": "placer",
    "plaçassions": "placer",
    "plaçons": "placer",
    "plaçâmes": "placer",
    "plaçât": "placer",
    "plaçâtes": "placer",
    "plaît": "plaire",
    "plectres": "plectre",
    "pleine": "plein",
    "pleines": "plein",
    "pleiniers": "pleinier",
    "pleinière": "pleinier",
    "pleinières": "pleinier",
    "pleins": "plein",
    "pleins-emplois": "plein-emploi",
    "pleins-temps": "plein-temps",
    "pleins-vents": "plein-vent",
    "pleura": "pleurer",
    "pleurai": "pleurer",
    "pleuraient": "pleurer",
    "pleurais": "pleurer",
    "pleurait": "pleurer",
    "pleurale": "pleural",
    "pleurales": "pleural",
    "pleurant": "pleurer",
    "pleurante": "pleurant",
    "pleurantes": "pleurant",
    "pleurants": "pleurant",
    "pleurarde": "pleurard",
    "pleurardes": "pleurard",
    "pleurards": "pleurard",
    "pleuras": "pleurer",
    "pleurasse": "pleurer",
    "pleurassent": "pleurer",
    "pleurasses": "pleurer",
    "pleurassiez": "pleurer",
    "pleurassions": "pleurer",
    "pleuraux": "pleural",
    "pleure": "pleurer",
    "pleurements": "pleurement",
    "pleurent": "pleurer",
    "pleurera": "pleurer",
    "pleurerai": "pleurer",
    "pleureraient": "pleurer",
    "pleurerais": "pleurer",
    "pleurerait": "pleurer",
    "pleureras": "pleurer",
    "pleurerez": "pleurer",
    "pleureriez": "pleurer",
    "pleurerions": "pleurer",
    "pleurerons": "pleurer",
    "pleureront": "pleurer",
    "pleures": "pleurer",
    "pleureurs": "pleureur",
    "pleureuse": "pleureur",
    "pleureuses": "pleureuse",
    "pleureux": "pleureur",
    "pleurez": "pleurer",
    "pleuriez": "pleurer",
    "pleurions": "pleurer",
    "pleurites": "pleurite",
    "pleurnicha": "pleurnicher",
    "pleurnichages": "pleurnichage",
    "pleurnichai": "pleurnicher",
    "pleurnichaient": "pleurnicher",
    "pleurnichais": "pleurnicher",
    "pleurnichait": "pleurnicher",
    "pleurnichant": "pleurnicher",
    "pleurnicharde": "pleurnichard",
    "pleurnichardes": "pleurnichard",
    "pleurnichards": "pleurnichard",
    "pleurnichas": "pleurnicher",
    "pleurnichasse": "pleurnicher",
    "pleurnichassent": "pleurnicher",
    "pleurnichasses": "pleurnicher",
    "pleurnichassiez": "pleurnicher",
    "pleurnichassions": "pleurnicher",
    "pleurniche": "pleurnicher",
    "pleurnichements": "pleurnichement",
    "pleurnichent": "pleurnicher",
    "pleurnichera": "pleurnicher",
    "pleurnicherai": "pleurnicher",
    "pleurnicheraient": "pleurnicher",
    "pleurnicherais": "pleurnicher",
    "pleurnicherait": "pleurnicher",
    "pleurnicheras": "pleurnicher",
    "pleurnicherez": "pleurnicher",
    "pleurnicheries": "pleurnicherie",
    "pleurnicheriez": "pleurnicher",
    "pleurnicherions": "pleurnicher",
    "pleurnicherons": "pleurnicher",
    "pleurnicheront": "pleurnicher",
    "pleurniches": "pleurnicher",
    "pleurnicheurs": "pleurnicheur",
    "pleurnicheuse": "pleurnicheur",
    "pleurnicheuses": "pleurnicheur",
    "pleurnichez": "pleurnicher",
    "pleurnichiez": "pleurnicher",
    "pleurnichions": "pleurnicher",
    "pleurnichons": "pleurnicher",
    "pleurnichâmes": "pleurnicher",
    "pleurnichât": "pleurnicher",
    "pleurnichâtes": "pleurnicher",
    "pleurnichèrent": "pleurnicher",
    "pleurniché": "pleurnicher",
    "pleurons": "pleurer",
    "pleurotes": "pleurote",
    "pleurs": "pleur",
    "pleurâmes": "pleurer",
    "pleurât": "pleurer",
    "pleurâtes": "pleurer",
    "pleurèrent": "pleurer",
    "pleuré": "pleurer",
    "pleurée": "pleurer",
    "pleurées": "pleurer",
    "pleurés": "pleurer",
    "pleurésies": "pleurésie",
    "pleut": "pleuvoir",
    "pleutres": "pleutre",
    "pleuvaient": "pleuvoir",
    "pleuvait": "pleuvoir",
    "pleuvant": "pleuvoir",
    "pleuve": "pleuvoir",
    "pleuvent": "pleuvoir",
    "pleuvinait": "pleuviner",
    "pleuvine": "pleuviner",
    "pleuvra": "pleuvoir",
    "pleuvraient": "pleuvoir",
    "pleuvrait": "pleuvoir",
    "pleuvront": "pleuvoir",
    "plia": "plier",
    "pliages": "pliage",
    "pliai": "plier",
    "pliaient": "plier",
    "pliais": "plier",
    "pliait": "plier",
    "pliant": "plier",
    "pliante": "pliant",
    "pliantes": "pliant",
    "pliants": "pliant",
    "plias": "plier",
    "pliasse": "plier",
    "pliassent": "plier",
    "pliasses": "plier",
    "pliassiez": "plier",
    "pliassions": "plier",
    "plie": "plier",
    "pliements": "pliement",
    "plient": "plier",
    "pliera": "plier",
    "plierai": "plier",
    "plieraient": "plier",
    "plierais": "plier",
    "plierait": "plier",
    "plieras": "plier",
    "plierez": "plier",
    "plieriez": "plier",
    "plierions": "plier",
    "plierons": "plier",
    "plieront": "plier",
    "plies": "plier",
    "plieuse": "plieur",
    "pliez": "plier",
    "pliiez": "plier",
    "pliions": "plier",
    "plinthes": "plinthe",
    "plions": "plion",
    "plis": "pli",
    "plissa": "plisser",
    "plissai": "plisser",
    "plissaient": "plisser",
    "plissais": "plisser",
    "plissait": "plisser",
    "plissant": "plisser",
    "plissas": "plisser",
    "plissasse": "plisser",
    "plissassent": "plisser",
    "plissasses": "plisser",
    "plissassiez": "plisser",
    "plissassions": "plisser",
    "plisse": "plisser",
    "plissements": "plissement",
    "plissent": "plisser",
    "plissera": "plisser",
    "plisserai": "plisser",
    "plisseraient": "plisser",
    "plisserais": "plisser",
    "plisserait": "plisser",
    "plisseras": "plisser",
    "plisserez": "plisser",
    "plisseriez": "plisser",
    "plisserions": "plisser",
    "plisserons": "plisser",
    "plisseront": "plisser",
    "plisses": "plisser",
    "plissez": "plisser",
    "plissiez": "plisser",
    "plissions": "plisser",
    "plissons": "plisser",
    "plissures": "plissure",
    "plissâmes": "plisser",
    "plissât": "plisser",
    "plissâtes": "plisser",
    "plissèrent": "plisser",
    "plissé": "plisser",
    "plissée": "plisser",
    "plissées": "plisser",
    "plissés": "plisser",
    "pliures": "pliure",
    "pliâmes": "plier",
    "pliât": "plier",
    "pliâtes": "plier",
    "plièrent": "plier",
    "plié": "plier",
    "pliée": "plier",
    "pliées": "plier",
    "pliés": "plier",
    "ploie": "ployer",
    "ploient": "ployer",
    "ploiera": "ployer",
    "ploierai": "ployer",
    "ploieraient": "ployer",
    "ploierais": "ployer",
    "ploierait": "ployer",
    "ploieras": "ployer",
    "ploierez": "ployer",
    "ploieriez": "ployer",
    "ploierions": "ployer",
    "ploierons": "ployer",
    "ploieront": "ployer",
    "ploies": "ployer",
    "plomba": "plomber",
    "plombages": "plombage",
    "plombai": "plomber",
    "plombaient": "plomber",
    "plombais": "plomber",
    "plombait": "plomber",
    "plombant": "plomber",
    "plombas": "plomber",
    "plombasse": "plomber",
    "plombassent": "plomber",
    "plombasses": "plomber",
    "plombassiez": "plomber",
    "plombassions": "plomber",
    "plombe": "plomber",
    "plombent": "plomber",
    "plombera": "plomber",
    "plomberai": "plomber",
    "plomberaient": "plomber",
    "plomberais": "plomber",
    "plomberait": "plomber",
    "plomberas": "plomber",
    "plomberez": "plomber",
    "plomberies": "plomberie",
    "plomberiez": "plomber",
    "plomberions": "plomber",
    "plomberons": "plomber",
    "plomberont": "plomber",
    "plombes": "plomber",
    "plombez": "plomber",
    "plombiers": "plombier",
    "plombiez": "plomber",
    "plombifères": "plombifère",
    "plombions": "plomber",
    "plombons": "plomber",
    "plombs": "plomb",
    "plombâmes": "plomber",
    "plombât": "plomber",
    "plombâtes": "plomber",
    "plombèrent": "plomber",
    "plombé": "plomber",
    "plombée": "plomber",
    "plombées": "plomber",
    "plombés": "plomber",
    "plonge": "plonger",
    "plongea": "plonger",
    "plongeai": "plonger",
    "plongeaient": "plonger",
    "plongeais": "plonger",
    "plongeait": "plonger",
    "plongeant": "plonger",
    "plongeante": "plongeant",
    "plongeantes": "plongeant",
    "plongeants": "plongeant",
    "plongeas": "plonger",
    "plongeasse": "plonger",
    "plongeassent": "plonger",
    "plongeasses": "plonger",
    "plongeassiez": "plonger",
    "plongeassions": "plonger",
    "plongent": "plonger",
    "plongeoirs": "plongeoir",
    "plongeons": "plonger",
    "plongera": "plonger",
    "plongerai": "plonger",
    "plongeraient": "plonger",
    "plongerais": "plonger",
    "plongerait": "plonger",
    "plongeras": "plonger",
    "plongerez": "plonger",
    "plongeriez": "plonger",
    "plongerions": "plonger",
    "plongerons": "plonger",
    "plongeront": "plonger",
    "plonges": "plonger",
    "plongeurs": "plongeur",
    "plongeuse": "plongeur",
    "plongeuses": "plongeur",
    "plongez": "plonger",
    "plongeâmes": "plonger",
    "plongeât": "plonger",
    "plongeâtes": "plonger",
    "plongiez": "plonger",
    "plongions": "plonger",
    "plongèrent": "plonger",
    "plongé": "plonger",
    "plongée": "plonger",
    "plongées": "plonger",
    "plongés": "plonger",
    "plots": "plot",
    "ploucs": "plouc",
    "ploutocrates": "ploutocrate",
    "ploutocraties": "ploutocratie",
    "ploya": "ployer",
    "ployai": "ployer",
    "ployaient": "ployer",
    "ployais": "ployer",
    "ployait": "ployer",
    "ployant": "ployer",
    "ployante": "ployant",
    "ployas": "ployer",
    "ployasse": "ployer",
    "ployassent": "ployer",
    "ployasses": "ployer",
    "ployassiez": "ployer",
    "ployassions": "ployer",
    "ployez": "ployer",
    "ployiez": "ployer",
    "ployions": "ployer",
    "ployons": "ployer",
    "ployâmes": "ployer",
    "ployât": "ployer",
    "ployâtes": "ployer",
    "ployèrent": "ployer",
    "ployé": "ployer",
    "ployée": "ployer",
    "ployées": "ployer",
    "ployés": "ployer",
    "plu": "pleuvoir",
    "pluche": "plucher",
    "pluies": "pluie",
    "plum": "plume",
    "plum-puddings": "plum-pudding",
    "pluma": "plumer",
    "plumages": "plumage",
    "plumaient": "plumer",
    "plumait": "plumer",
    "plumant": "plumer",
    "plumards": "plumard",
    "plumassiers": "plumassier",
    "plumassière": "plumassier",
    "plumassières": "plumassier",
    "plume": "plumer",
    "plumeaux": "plumeau",
    "plument": "plumer",
    "plumes": "plumer",
    "plumets": "plumet",
    "plumeuse": "plumeux",
    "plumeuses": "plumeux",
    "plumez": "plumer",
    "plumiers": "plumier",
    "plumitifs": "plumitif",
    "plumitives": "plumitive",
    "plumules": "plumule",
    "plumé": "plumer",
    "plumée": "plumer",
    "plumées": "plumer",
    "plumés": "plumer",
    "plurale": "plural",
    "plurales": "plural",
    "pluralismes": "pluralisme",
    "pluralistes": "pluraliste",
    "pluralités": "pluralité",
    "pluraux": "plural",
    "plurent": "pleuvoir",
    "pluriannuelle": "pluriannuel",
    "pluriannuelles": "pluriannuel",
    "pluriannuels": "pluriannuel",
    "pluricausale": "pluricausal",
    "pluricausales": "pluricausal",
    "pluricausals": "pluricausal",
    "pluricausaux": "pluricausal",
    "pluridimensionnelle": "pluridimensionnel",
    "pluridimensionnelles": "pluridimensionnel",
    "pluridimensionnels": "pluridimensionnel",
    "pluridisciplinaires": "pluridisciplinaire",
    "plurielle": "pluriel",
    "plurielles": "pluriel",
    "pluriels": "pluriel",
    "plurilatérale": "plurilatéral",
    "plurilatérales": "plurilatéral",
    "plurilatéraux": "plurilatéral",
    "pluripartismes": "pluripartisme",
    "plurirégionale": "plurirégional",
    "plurirégionales": "plurirégional",
    "plurirégionaux": "plurirégional",
    "plurisectorielle": "plurisectoriel",
    "plurisectorielles": "plurisectoriel",
    "plurisectoriels": "plurisectoriel",
    "plus": "plaire",
    "plus-que-parfaits": "plus-que-parfait",
    "plus-values": "plus-value",
    "plusse": "plaire",
    "plussent": "pleuvoir",
    "plusses": "plaire",
    "plussiez": "plaire",
    "plussions": "plaire",
    "plut": "pleuvoir",
    "plutonienne": "plutonien",
    "plutoniums": "plutonium",
    "pluviale": "pluvial",
    "pluviales": "pluvial",
    "pluviaux": "pluvial",
    "pluviers": "pluvier",
    "pluvieuse": "pluvieux",
    "pluvieuses": "pluvieux",
    "pluviomètres": "pluviomètre",
    "pluviôses": "pluviôse",
    "plâtra": "plâtrer",
    "plâtrai": "plâtrer",
    "plâtraient": "plâtrer",
    "plâtrais": "plâtrer",
    "plâtrait": "plâtrer",
    "plâtrant": "plâtrer",
    "plâtras": "plâtrer",
    "plâtrasse": "plâtrer",
    "plâtrassent": "plâtrer",
    "plâtrasses": "plâtrer",
    "plâtrassiez": "plâtrer",
    "plâtrassions": "plâtrer",
    "plâtre": "plâtrer",
    "plâtrent": "plâtrer",
    "plâtrera": "plâtrer",
    "plâtrerai": "plâtrer",
    "plâtreraient": "plâtrer",
    "plâtrerais": "plâtrer",
    "plâtrerait": "plâtrer",
    "plâtreras": "plâtrer",
    "plâtrerez": "plâtrer",
    "plâtreriez": "plâtrer",
    "plâtrerions": "plâtrer",
    "plâtrerons": "plâtrer",
    "plâtreront": "plâtrer",
    "plâtres": "plâtrer",
    "plâtreuse": "plâtreux",
    "plâtreuses": "plâtreux",
    "plâtrez": "plâtrer",
    "plâtriers": "plâtrier",
    "plâtriez": "plâtrer",
    "plâtrions": "plâtrer",
    "plâtrons": "plâtrer",
    "plâtrâmes": "plâtrer",
    "plâtrât": "plâtrer",
    "plâtrâtes": "plâtrer",
    "plâtrèrent": "plâtrer",
    "plâtré": "plâtrer",
    "plâtrée": "plâtrer",
    "plâtrées": "plâtrer",
    "plâtrés": "plâtrer",
    "plèbes": "plèbe",
    "plèvres": "plèvre",
    "plébiscite": "plébisciter",
    "plébiscites": "plébiscite",
    "plébiscité": "plébisciter",
    "plébiscitée": "plébiscité",
    "plébiscitées": "plébiscité",
    "plébiscités": "plébisciter",
    "plébéienne": "plébéien",
    "plébéiennes": "plébéien",
    "plébéiens": "plébéien",
    "pléiades": "pléiade",
    "pléniers": "plénier",
    "plénipotentiaires": "plénipotentiaire",
    "plénitudes": "plénitude",
    "plénière": "plénier",
    "plénières": "plénier",
    "pléonasmes": "pléonasme",
    "pléonastiques": "pléonastique",
    "plésiosaures": "plésiosaure",
    "pléthores": "pléthore",
    "pléthoriques": "pléthorique",
    "plûmes": "plaire",
    "plût": "pleuvoir",
    "plûtes": "plaire",
    "pneumatiques": "pneumatique",
    "pneumocoques": "pneumocoque",
    "pneumologies": "pneumologie",
    "pneumologiques": "pneumologique",
    "pneumonies": "pneumonie",
    "pneumos": "pneumo",
    "pneus": "pneu",
    "pocha": "pocher",
    "pochades": "pochade",
    "pochai": "pocher",
    "pochaient": "pocher",
    "pochais": "pocher",
    "pochait": "pocher",
    "pochant": "pocher",
    "pocharde": "pochard",
    "pochardes": "pochard",
    "pochards": "pochard",
    "pochas": "pocher",
    "pochasse": "pocher",
    "pochassent": "pocher",
    "pochasses": "pocher",
    "pochassiez": "pocher",
    "pochassions": "pocher",
    "poche": "pocher",
    "pochent": "pocher",
    "pochera": "pocher",
    "pocherai": "pocher",
    "pocheraient": "pocher",
    "pocherais": "pocher",
    "pocherait": "pocher",
    "pocheras": "pocher",
    "pocherez": "pocher",
    "pocheriez": "pocher",
    "pocherions": "pocher",
    "pocherons": "pocher",
    "pocheront": "pocher",
    "poches": "pocher",
    "pochetrons": "pochetron",
    "pochettes": "pochette",
    "pochettes-surprises": "pochette-surprise",
    "pochetée": "pocheté",
    "pochetées": "pochetée",
    "pochez": "pocher",
    "pochiez": "pocher",
    "pochions": "pocher",
    "pochoirs": "pochoir",
    "pochons": "pochon",
    "pochtrons": "pochtron",
    "pochâmes": "pocher",
    "pochât": "pocher",
    "pochâtes": "pocher",
    "pochèrent": "pocher",
    "poché": "pocher",
    "pochée": "pocher",
    "pochées": "pocher",
    "pochés": "pocher",
    "podagres": "podagre",
    "podestats": "podestat",
    "podiums": "podium",
    "podomètres": "podomètre",
    "podzols": "podzol",
    "poeciles": "poecile",
    "pognes": "pogne",
    "pognons": "pognon",
    "pogromes": "pogrome",
    "pogromistes": "pogromiste",
    "pogroms": "pogrom",
    "poignaient": "poigner",
    "poignait": "poigner",
    "poignant": "poigner",
    "poignante": "poignant",
    "poignantes": "poignant",
    "poignants": "poignant",
    "poignarda": "poignarder",
    "poignardai": "poignarder",
    "poignardaient": "poignarder",
    "poignardais": "poignarder",
    "poignardait": "poignarder",
    "poignardant": "poignarder",
    "poignardas": "poignarder",
    "poignardasse": "poignarder",
    "poignardassent": "poignarder",
    "poignardasses": "poignarder",
    "poignardassiez": "poignarder",
    "poignardassions": "poignarder",
    "poignarde": "poignarder",
    "poignardent": "poignarder",
    "poignardera": "poignarder",
    "poignarderai": "poignarder",
    "poignarderaient": "poignarder",
    "poignarderais": "poignarder",
    "poignarderait": "poignarder",
    "poignarderas": "poignarder",
    "poignarderez": "poignarder",
    "poignarderiez": "poignarder",
    "poignarderions": "poignarder",
    "poignarderons": "poignarder",
    "poignarderont": "poignarder",
    "poignardes": "poignarder",
    "poignardez": "poignarder",
    "poignardiez": "poignarder",
    "poignardions": "poignarder",
    "poignardons": "poignarder",
    "poignards": "poignard",
    "poignardâmes": "poignarder",
    "poignardât": "poignarder",
    "poignardâtes": "poignarder",
    "poignardèrent": "poignarder",
    "poignardé": "poignarder",
    "poignardée": "poignarder",
    "poignardées": "poignarder",
    "poignardés": "poignarder",
    "poignent": "poigner",
    "poignerait": "poigner",
    "poignes": "poigne",
    "poignets": "poignet",
    "poignons": "poigner",
    "poignées": "poignée",
    "poilaient": "poiler",
    "poilais": "poiler",
    "poilait": "poiler",
    "poilant": "poiler",
    "poile": "poiler",
    "poils": "poil",
    "poilue": "poilu",
    "poilues": "poilu",
    "poilus": "poilu",
    "poilé": "poiler",
    "poilés": "poiler",
    "poindra": "poindre",
    "poindrait": "poindre",
    "poings": "poing",
    "point": "poindre",
    "pointa": "pointer",
    "pointages": "pointage",
    "pointai": "pointer",
    "pointaient": "pointer",
    "pointais": "pointer",
    "pointait": "pointer",
    "pointant": "pointer",
    "pointas": "pointer",
    "pointasse": "pointer",
    "pointassent": "pointer",
    "pointasses": "pointer",
    "pointassiez": "pointer",
    "pointassions": "pointer",
    "pointe": "pointer",
    "pointeaux": "pointeau",
    "pointent": "pointer",
    "pointera": "pointer",
    "pointerai": "pointer",
    "pointeraient": "pointer",
    "pointerais": "pointer",
    "pointerait": "pointer",
    "pointeras": "pointer",
    "pointerez": "pointer",
    "pointeriez": "pointer",
    "pointerions": "pointer",
    "pointerons": "pointer",
    "pointeront": "pointer",
    "pointers": "pointer",
    "pointes": "pointer",
    "pointeurs": "pointeur",
    "pointeuse": "pointeur",
    "pointeuses": "pointeur",
    "pointez": "pointer",
    "pointiez": "pointer",
    "pointilla": "pointiller",
    "pointillai": "pointiller",
    "pointillaient": "pointiller",
    "pointillais": "pointiller",
    "pointillait": "pointiller",
    "pointillant": "pointiller",
    "pointillas": "pointiller",
    "pointillasse": "pointiller",
    "pointillassent": "pointiller",
    "pointillasses": "pointiller",
    "pointillassiez": "pointiller",
    "pointillassions": "pointiller",
    "pointille": "pointiller",
    "pointillent": "pointiller",
    "pointillera": "pointiller",
    "pointillerai": "pointiller",
    "pointilleraient": "pointiller",
    "pointillerais": "pointiller",
    "pointillerait": "pointiller",
    "pointilleras": "pointiller",
    "pointillerez": "pointiller",
    "pointilleriez": "pointiller",
    "pointillerions": "pointiller",
    "pointillerons": "pointiller",
    "pointilleront": "pointiller",
    "pointilles": "pointiller",
    "pointilleuse": "pointilleux",
    "pointilleuses": "pointilleux",
    "pointillez": "pointiller",
    "pointilliez": "pointiller",
    "pointillions": "pointiller",
    "pointillistes": "pointilliste",
    "pointillons": "pointiller",
    "pointillâmes": "pointiller",
    "pointillât": "pointiller",
    "pointillâtes": "pointiller",
    "pointillèrent": "pointiller",
    "pointillé": "pointiller",
    "pointillée": "pointiller",
    "pointillées": "pointiller",
    "pointillés": "pointiller",
    "pointions": "pointer",
    "pointons": "pointer",
    "points": "point",
    "points-virgules": "point-virgule",
    "pointue": "pointu",
    "pointues": "pointu",
    "pointures": "pointure",
    "pointus": "pointu",
    "pointâmes": "pointer",
    "pointât": "pointer",
    "pointâtes": "pointer",
    "pointèrent": "pointer",
    "pointé": "pointer",
    "pointée": "pointer",
    "pointées": "pointer",
    "pointés": "pointer",
    "poinçonna": "poinçonner",
    "poinçonnages": "poinçonnage",
    "poinçonnai": "poinçonner",
    "poinçonnaient": "poinçonner",
    "poinçonnais": "poinçonner",
    "poinçonnait": "poinçonner",
    "poinçonnant": "poinçonner",
    "poinçonnas": "poinçonner",
    "poinçonnasse": "poinçonner",
    "poinçonnassent": "poinçonner",
    "poinçonnasses": "poinçonner",
    "poinçonnassiez": "poinçonner",
    "poinçonnassions": "poinçonner",
    "poinçonne": "poinçonner",
    "poinçonnent": "poinçonner",
    "poinçonnera": "poinçonner",
    "poinçonnerai": "poinçonner",
    "poinçonneraient": "poinçonner",
    "poinçonnerais": "poinçonner",
    "poinçonnerait": "poinçonner",
    "poinçonneras": "poinçonner",
    "poinçonnerez": "poinçonner",
    "poinçonneriez": "poinçonner",
    "poinçonnerions": "poinçonner",
    "poinçonnerons": "poinçonner",
    "poinçonneront": "poinçonner",
    "poinçonnes": "poinçonner",
    "poinçonneurs": "poinçonneur",
    "poinçonnez": "poinçonner",
    "poinçonniez": "poinçonner",
    "poinçonnions": "poinçonner",
    "poinçonnons": "poinçonner",
    "poinçonnâmes": "poinçonner",
    "poinçonnât": "poinçonner",
    "poinçonnâtes": "poinçonner",
    "poinçonnèrent": "poinçonner",
    "poinçonné": "poinçonner",
    "poinçonnée": "poinçonner",
    "poinçonnées": "poinçonner",
    "poinçonnés": "poinçonner",
    "poinçons": "poinçon",
    "poireautai": "poireauter",
    "poireautaient": "poireauter",
    "poireautais": "poireauter",
    "poireautait": "poireauter",
    "poireaute": "poireauter",
    "poireautes": "poireauter",
    "poireautions": "poireauter",
    "poireauté": "poireauter",
    "poireaux": "poireau",
    "poires": "poire",
    "poiriers": "poirier",
    "poirota": "poiroter",
    "poirotait": "poiroter",
    "poirée": "poiré",
    "poiscailles": "poiscaille",
    "poisons": "poison",
    "poissa": "poisser",
    "poissai": "poisser",
    "poissaient": "poisser",
    "poissais": "poisser",
    "poissait": "poisser",
    "poissant": "poisser",
    "poissarde": "poissard",
    "poissardes": "poissard",
    "poissards": "poissard",
    "poissas": "poisser",
    "poissasse": "poisser",
    "poissassent": "poisser",
    "poissasses": "poisser",
    "poissassiez": "poisser",
    "poissassions": "poisser",
    "poisse": "poisser",
    "poissent": "poisser",
    "poissera": "poisser",
    "poisserai": "poisser",
    "poisseraient": "poisser",
    "poisserais": "poisser",
    "poisserait": "poisser",
    "poisseras": "poisser",
    "poisserez": "poisser",
    "poisseriez": "poisser",
    "poisserions": "poisser",
    "poisserons": "poisser",
    "poisseront": "poisser",
    "poisses": "poisser",
    "poisseuse": "poisseux",
    "poisseuses": "poisseux",
    "poissez": "poisser",
    "poissiez": "poisser",
    "poissions": "poisser",
    "poissonneries": "poissonnerie",
    "poissonneuse": "poissonneux",
    "poissonneuses": "poissonneux",
    "poissonniers": "poissonnier",
    "poissonnières": "poissonnier",
    "poissons": "poisson",
    "poissons-chats": "poisson-chat",
    "poissons-lunes": "poisson-lune",
    "poissons-scies": "poisson-scie",
    "poissâmes": "poisser",
    "poissât": "poisser",
    "poissâtes": "poisser",
    "poissèrent": "poisser",
    "poissé": "poisser",
    "poissée": "poisser",
    "poissées": "poisser",
    "poissés": "poisser",
    "poitevins": "poitevin",
    "poitrails": "poitrail",
    "poitrinaires": "poitrinaire",
    "poitrinant": "poitriner",
    "poitrines": "poitrine",
    "poitrinières": "poitrinière",
    "poivra": "poivrer",
    "poivrades": "poivrade",
    "poivrai": "poivrer",
    "poivraient": "poivrer",
    "poivrais": "poivrer",
    "poivrait": "poivrer",
    "poivrant": "poivrer",
    "poivras": "poivrer",
    "poivrasse": "poivrer",
    "poivrassent": "poivrer",
    "poivrasses": "poivrer",
    "poivrassiez": "poivrer",
    "poivrassions": "poivrer",
    "poivre": "poivrer",
    "poivrent": "poivrer",
    "poivrera": "poivrer",
    "poivrerai": "poivrer",
    "poivreraient": "poivrer",
    "poivrerais": "poivrer",
    "poivrerait": "poivrer",
    "poivreras": "poivrer",
    "poivrerez": "poivrer",
    "poivreriez": "poivrer",
    "poivrerions": "poivrer",
    "poivrerons": "poivrer",
    "poivreront": "poivrer",
    "poivres": "poivrer",
    "poivrez": "poivrer",
    "poivriers": "poivrier",
    "poivriez": "poivrer",
    "poivrions": "poivrer",
    "poivrières": "poivrière",
    "poivrons": "poivron",
    "poivrote": "poivrot",
    "poivrotes": "poivrot",
    "poivrots": "poivrot",
    "poivrâmes": "poivrer",
    "poivrât": "poivrer",
    "poivrâtes": "poivrer",
    "poivrèrent": "poivrer",
    "poivré": "poivrer",
    "poivrée": "poivrer",
    "poivrées": "poivrer",
    "poivrés": "poivrer",
    "pokers": "poker",
    "polacks": "polack",
    "polaires": "polaire",
    "polaks": "polak",
    "polaques": "polaque",
    "polarde": "polard",
    "polardes": "polard",
    "polards": "polard",
    "polarisaient": "polariser",
    "polarisait": "polariser",
    "polarisant": "polariser",
    "polarisants": "polarisant",
    "polarisations": "polarisation",
    "polarise": "polariser",
    "polarisent": "polariser",
    "polarisé": "polariser",
    "polarisée": "polariser",
    "polaroïds": "polaroïd",
    "polars": "polar",
    "polders": "polder",
    "polentas": "polenta",
    "poli": "polir",
    "police": "policer",
    "policemans": "policeman",
    "policemen": "policeman",
    "polices": "police",
    "polichinelles": "polichinelle",
    "policiers": "policier",
    "policière": "policier",
    "policières": "policier",
    "policé": "policer",
    "policée": "policer",
    "policées": "policer",
    "policés": "policer",
    "polie": "polir",
    "polies": "polir",
    "poliomyélites": "poliomyélite",
    "poliomyélitiques": "poliomyélitique",
    "polios": "polio",
    "polira": "polir",
    "polirai": "polir",
    "poliraient": "polir",
    "polirais": "polir",
    "polirait": "polir",
    "poliras": "polir",
    "polirent": "polir",
    "polirez": "polir",
    "poliriez": "polir",
    "polirions": "polir",
    "polirons": "polir",
    "poliront": "polir",
    "polis": "polir",
    "polissages": "polissage",
    "polissaient": "polir",
    "polissais": "polir",
    "polissait": "polir",
    "polissant": "polir",
    "polisse": "polir",
    "polissent": "polir",
    "polisses": "polir",
    "polisseurs": "polisseur",
    "polisseuse": "polisseur",
    "polissez": "polir",
    "polissiez": "polir",
    "polissions": "polir",
    "polissonnait": "polissonner",
    "polissonne": "polisson",
    "polissonneries": "polissonnerie",
    "polissonnes": "polisson",
    "polissons": "polisson",
    "polit": "polir",
    "politesses": "politesse",
    "politicards": "politicard",
    "politicienne": "politicien",
    "politiciennes": "politicien",
    "politiciens": "politicien",
    "politico-religieuse": "politico-religieux",
    "politiques": "politique",
    "politisa": "politiser",
    "politisai": "politiser",
    "politisaient": "politiser",
    "politisais": "politiser",
    "politisait": "politiser",
    "politisant": "politiser",
    "politisas": "politiser",
    "politisasse": "politiser",
    "politisassent": "politiser",
    "politisasses": "politiser",
    "politisassiez": "politiser",
    "politisassions": "politiser",
    "politisations": "politisation",
    "politise": "politiser",
    "politisent": "politiser",
    "politisera": "politiser",
    "politiserai": "politiser",
    "politiseraient": "politiser",
    "politiserais": "politiser",
    "politiserait": "politiser",
    "politiseras": "politiser",
    "politiserez": "politiser",
    "politiseriez": "politiser",
    "politiserions": "politiser",
    "politiserons": "politiser",
    "politiseront": "politiser",
    "politises": "politiser",
    "politisez": "politiser",
    "politisiez": "politiser",
    "politisions": "politiser",
    "politisons": "politiser",
    "politisâmes": "politiser",
    "politisât": "politiser",
    "politisâtes": "politiser",
    "politisèrent": "politiser",
    "politisé": "politiser",
    "politisée": "politiser",
    "politisées": "politiser",
    "politisés": "politiser",
    "poljés": "poljé",
    "polkas": "polka",
    "pollens": "pollen",
    "pollinies": "pollinie",
    "pollinisations": "pollinisation",
    "pollinisé": "polliniser",
    "pollua": "polluer",
    "polluai": "polluer",
    "polluaient": "polluer",
    "polluais": "polluer",
    "polluait": "polluer",
    "polluant": "polluer",
    "polluante": "polluant",
    "polluantes": "polluant",
    "polluants": "polluant",
    "polluas": "polluer",
    "polluasse": "polluer",
    "polluassent": "polluer",
    "polluasses": "polluer",
    "polluassiez": "polluer",
    "polluassions": "polluer",
    "pollue": "polluer",
    "polluent": "polluer",
    "polluera": "polluer",
    "polluerai": "polluer",
    "pollueraient": "polluer",
    "polluerais": "polluer",
    "polluerait": "polluer",
    "pollueras": "polluer",
    "polluerez": "polluer",
    "pollueriez": "polluer",
    "polluerions": "polluer",
    "polluerons": "polluer",
    "pollueront": "polluer",
    "pollues": "polluer",
    "pollueurs": "pollueur",
    "pollueuse": "pollueur",
    "pollueuses": "pollueur",
    "polluez": "polluer",
    "polluiez": "polluer",
    "polluions": "polluer",
    "polluons": "polluer",
    "pollutions": "pollution",
    "polluâmes": "polluer",
    "polluât": "polluer",
    "polluâtes": "polluer",
    "polluèrent": "polluer",
    "pollué": "polluer",
    "polluée": "polluer",
    "polluées": "polluer",
    "pollués": "polluer",
    "polochons": "polochon",
    "polonaise": "polonais",
    "polonaises": "polonais",
    "polos": "polo",
    "poltronne": "poltron",
    "poltronneries": "poltronnerie",
    "poltronnes": "poltron",
    "poltrons": "poltron",
    "poly-sexuelle": "poly-sexuel",
    "polyamides": "polyamide",
    "polybutadiènes": "polybutadiène",
    "polychlorobiphényles": "polychlorobiphényle",
    "polychromes": "polychrome",
    "polychromées": "polychromé",
    "polycliniques": "polyclinique",
    "polycopia": "polycopier",
    "polycopiai": "polycopier",
    "polycopiaient": "polycopier",
    "polycopiais": "polycopier",
    "polycopiait": "polycopier",
    "polycopiant": "polycopier",
    "polycopias": "polycopier",
    "polycopiasse": "polycopier",
    "polycopiassent": "polycopier",
    "polycopiasses": "polycopier",
    "polycopiassiez": "polycopier",
    "polycopiassions": "polycopier",
    "polycopie": "polycopier",
    "polycopient": "polycopier",
    "polycopiera": "polycopier",
    "polycopierai": "polycopier",
    "polycopieraient": "polycopier",
    "polycopierais": "polycopier",
    "polycopierait": "polycopier",
    "polycopieras": "polycopier",
    "polycopierez": "polycopier",
    "polycopieriez": "polycopier",
    "polycopierions": "polycopier",
    "polycopierons": "polycopier",
    "polycopieront": "polycopier",
    "polycopies": "polycopier",
    "polycopiez": "polycopier",
    "polycopiiez": "polycopier",
    "polycopiions": "polycopier",
    "polycopions": "polycopier",
    "polycopiâmes": "polycopier",
    "polycopiât": "polycopier",
    "polycopiâtes": "polycopier",
    "polycopièrent": "polycopier",
    "polycopié": "polycopier",
    "polycopiée": "polycopier",
    "polycopiées": "polycopier",
    "polycopiés": "polycopier",
    "polycultures": "polyculture",
    "polycycliques": "polycyclique",
    "polyesters": "polyester",
    "polygamies": "polygamie",
    "polyglottes": "polyglotte",
    "polygonale": "polygonal",
    "polygonales": "polygonal",
    "polygonaux": "polygonal",
    "polygones": "polygone",
    "polygraphes": "polygraphe",
    "polymorphes": "polymorphe",
    "polymorphismes": "polymorphisme",
    "polymères": "polymère",
    "polymérases": "polymérase",
    "polymériques": "polymérique",
    "polynomiale": "polynomial",
    "polynomiales": "polynomial",
    "polynomiaux": "polynomial",
    "polynésienne": "polynésien",
    "polynésiennes": "polynésien",
    "polynésiens": "polynésien",
    "polynômes": "polynôme",
    "polypes": "polype",
    "polyphonies": "polyphonie",
    "polyphoniques": "polyphonique",
    "polypiers": "polypier",
    "polypropylènes": "polypropylène",
    "polyprènes": "polyprène",
    "polyptyques": "polyptyque",
    "polysaccharides": "polysaccharide",
    "polystyrènes": "polystyrène",
    "polysyllabes": "polysyllabe",
    "polytechnicienne": "polytechnicien",
    "polytechniciennes": "polytechnicien",
    "polytechniciens": "polytechnicien",
    "polytechniques": "polytechnique",
    "polythéismes": "polythéisme",
    "polyvalences": "polyvalence",
    "polyvalente": "polyvalent",
    "polyvalentes": "polyvalent",
    "polyvalents": "polyvalent",
    "polyèdres": "polyèdre",
    "polyéthylènes": "polyéthylène",
    "polémiqua": "polémiquer",
    "polémiquai": "polémiquer",
    "polémiquaient": "polémiquer",
    "polémiquais": "polémiquer",
    "polémiquait": "polémiquer",
    "polémiquant": "polémiquer",
    "polémiquas": "polémiquer",
    "polémiquasse": "polémiquer",
    "polémiquassent": "polémiquer",
    "polémiquasses": "polémiquer",
    "polémiquassiez": "polémiquer",
    "polémiquassions": "polémiquer",
    "polémique": "polémiquer",
    "polémiquent": "polémiquer",
    "polémiquera": "polémiquer",
    "polémiquerai": "polémiquer",
    "polémiqueraient": "polémiquer",
    "polémiquerais": "polémiquer",
    "polémiquerait": "polémiquer",
    "polémiqueras": "polémiquer",
    "polémiquerez": "polémiquer",
    "polémiqueriez": "polémiquer",
    "polémiquerions": "polémiquer",
    "polémiquerons": "polémiquer",
    "polémiqueront": "polémiquer",
    "polémiques": "polémiquer",
    "polémiquez": "polémiquer",
    "polémiquiez": "polémiquer",
    "polémiquions": "polémiquer",
    "polémiquons": "polémiquer",
    "polémiquâmes": "polémiquer",
    "polémiquât": "polémiquer",
    "polémiquâtes": "polémiquer",
    "polémiquèrent": "polémiquer",
    "polémiqué": "polémiquer",
    "polémiquée": "polémiquer",
    "polémiquées": "polémiquer",
    "polémiqués": "polémiquer",
    "polémistes": "polémiste",
    "polîmes": "polir",
    "polît": "polir",
    "polîtes": "polir",
    "pom-pom girl": "pom-pom-girl",
    "pom-pom girls": "pom-pom-girl",
    "pomerols": "pomerol",
    "pomma": "pommer",
    "pommade": "pommader",
    "pommades": "pommade",
    "pommadé": "pommader",
    "pommadées": "pommadé",
    "pommadés": "pommader",
    "pommai": "pommer",
    "pommaient": "pommer",
    "pommais": "pommer",
    "pommait": "pommer",
    "pommant": "pommer",
    "pommards": "pommard",
    "pommas": "pommer",
    "pommasse": "pommer",
    "pommassent": "pommer",
    "pommasses": "pommer",
    "pommassiez": "pommer",
    "pommassions": "pommer",
    "pomme": "pommer",
    "pommeaux": "pommeau",
    "pommela": "pommeler",
    "pommelai": "pommeler",
    "pommelaient": "pommeler",
    "pommelais": "pommeler",
    "pommelait": "pommeler",
    "pommelant": "pommeler",
    "pommelas": "pommeler",
    "pommelasse": "pommeler",
    "pommelassent": "pommeler",
    "pommelasses": "pommeler",
    "pommelassiez": "pommeler",
    "pommelassions": "pommeler",
    "pommelez": "pommeler",
    "pommeliez": "pommeler",
    "pommelions": "pommeler",
    "pommelle": "pommeler",
    "pommellent": "pommeler",
    "pommellera": "pommeler",
    "pommellerai": "pommeler",
    "pommelleraient": "pommeler",
    "pommellerais": "pommeler",
    "pommellerait": "pommeler",
    "pommelleras": "pommeler",
    "pommellerez": "pommeler",
    "pommelleriez": "pommeler",
    "pommellerions": "pommeler",
    "pommellerons": "pommeler",
    "pommelleront": "pommeler",
    "pommelles": "pommelle",
    "pommelons": "pommeler",
    "pommelâmes": "pommeler",
    "pommelât": "pommeler",
    "pommelâtes": "pommeler",
    "pommelèrent": "pommeler",
    "pommelé": "pommeler",
    "pommelée": "pommeler",
    "pommelées": "pommeler",
    "pommelés": "pommeler",
    "pomment": "pommer",
    "pommera": "pommer",
    "pommerai": "pommer",
    "pommeraient": "pommer",
    "pommerais": "pommer",
    "pommerait": "pommer",
    "pommeras": "pommer",
    "pommerez": "pommer",
    "pommeriez": "pommer",
    "pommerions": "pommer",
    "pommerons": "pommer",
    "pommeront": "pommer",
    "pommes": "pommer",
    "pommettes": "pommette",
    "pommez": "pommer",
    "pommiers": "pommier",
    "pommiez": "pommer",
    "pommions": "pommer",
    "pommons": "pommer",
    "pommâmes": "pommer",
    "pommât": "pommer",
    "pommâtes": "pommer",
    "pommèrent": "pommer",
    "pommé": "pommer",
    "pommée": "pommer",
    "pommées": "pommer",
    "pommés": "pommer",
    "pompa": "pomper",
    "pompages": "pompage",
    "pompai": "pomper",
    "pompaient": "pomper",
    "pompais": "pomper",
    "pompait": "pomper",
    "pompant": "pomper",
    "pompas": "pomper",
    "pompasse": "pomper",
    "pompassent": "pomper",
    "pompasses": "pomper",
    "pompassiez": "pomper",
    "pompassions": "pomper",
    "pompe": "pomper",
    "pompent": "pomper",
    "pompera": "pomper",
    "pomperai": "pomper",
    "pomperaient": "pomper",
    "pomperais": "pomper",
    "pomperait": "pomper",
    "pomperas": "pomper",
    "pomperez": "pomper",
    "pomperiez": "pomper",
    "pomperions": "pomper",
    "pomperons": "pomper",
    "pomperont": "pomper",
    "pompes": "pomper",
    "pompeuse": "pompeux",
    "pompeuses": "pompeux",
    "pompez": "pomper",
    "pompidoliens": "pompidolien",
    "pompiers": "pompier",
    "pompiez": "pomper",
    "pompions": "pomper",
    "pompistes": "pompiste",
    "pomponna": "pomponner",
    "pomponnai": "pomponner",
    "pomponnaient": "pomponner",
    "pomponnais": "pomponner",
    "pomponnait": "pomponner",
    "pomponnant": "pomponner",
    "pomponnas": "pomponner",
    "pomponnasse": "pomponner",
    "pomponnassent": "pomponner",
    "pomponnasses": "pomponner",
    "pomponnassiez": "pomponner",
    "pomponnassions": "pomponner",
    "pomponne": "pomponner",
    "pomponnent": "pomponner",
    "pomponnera": "pomponner",
    "pomponnerai": "pomponner",
    "pomponneraient": "pomponner",
    "pomponnerais": "pomponner",
    "pomponnerait": "pomponner",
    "pomponneras": "pomponner",
    "pomponnerez": "pomponner",
    "pomponneriez": "pomponner",
    "pomponnerions": "pomponner",
    "pomponnerons": "pomponner",
    "pomponneront": "pomponner",
    "pomponnes": "pomponner",
    "pomponnez": "pomponner",
    "pomponniez": "pomponner",
    "pomponnions": "pomponner",
    "pomponnons": "pomponner",
    "pomponnâmes": "pomponner",
    "pomponnât": "pomponner",
    "pomponnâtes": "pomponner",
    "pomponnèrent": "pomponner",
    "pomponné": "pomponner",
    "pomponnée": "pomponner",
    "pomponnées": "pomponner",
    "pomponnés": "pomponner",
    "pompons": "pompon",
    "pompâmes": "pomper",
    "pompât": "pomper",
    "pompâtes": "pomper",
    "pompèrent": "pomper",
    "pompé": "pomper",
    "pompée": "pomper",
    "pompées": "pomper",
    "pompéienne": "pompéien",
    "pompéiennes": "pompéien",
    "pompéiens": "pompéien",
    "pompés": "pomper",
    "poméranienne": "poméranien",
    "poméraniennes": "poméranien",
    "poméraniens": "poméranien",
    "ponants": "ponant",
    "ponce": "poncer",
    "ponceaux": "ponceau",
    "poncent": "poncer",
    "poncera": "poncer",
    "poncerai": "poncer",
    "ponceraient": "poncer",
    "poncerais": "poncer",
    "poncerait": "poncer",
    "ponceras": "poncer",
    "poncerez": "poncer",
    "ponceriez": "poncer",
    "poncerions": "poncer",
    "poncerons": "poncer",
    "ponceront": "poncer",
    "ponces": "poncer",
    "ponceuse": "ponceur",
    "poncez": "poncer",
    "ponchos": "poncho",
    "ponciez": "poncer",
    "poncifs": "poncif",
    "poncions": "poncer",
    "ponctionna": "ponctionner",
    "ponctionnai": "ponctionner",
    "ponctionnaient": "ponctionner",
    "ponctionnais": "ponctionner",
    "ponctionnait": "ponctionner",
    "ponctionnant": "ponctionner",
    "ponctionnas": "ponctionner",
    "ponctionnasse": "ponctionner",
    "ponctionnassent": "ponctionner",
    "ponctionnasses": "ponctionner",
    "ponctionnassiez": "ponctionner",
    "ponctionnassions": "ponctionner",
    "ponctionne": "ponctionner",
    "ponctionnent": "ponctionner",
    "ponctionnera": "ponctionner",
    "ponctionnerai": "ponctionner",
    "ponctionneraient": "ponctionner",
    "ponctionnerais": "ponctionner",
    "ponctionnerait": "ponctionner",
    "ponctionneras": "ponctionner",
    "ponctionnerez": "ponctionner",
    "ponctionneriez": "ponctionner",
    "ponctionnerions": "ponctionner",
    "ponctionnerons": "ponctionner",
    "ponctionneront": "ponctionner",
    "ponctionnes": "ponctionner",
    "ponctionnez": "ponctionner",
    "ponctionniez": "ponctionner",
    "ponctionnions": "ponctionner",
    "ponctionnons": "ponctionner",
    "ponctionnâmes": "ponctionner",
    "ponctionnât": "ponctionner",
    "ponctionnâtes": "ponctionner",
    "ponctionnèrent": "ponctionner",
    "ponctionné": "ponctionner",
    "ponctionnée": "ponctionner",
    "ponctionnées": "ponctionner",
    "ponctionnés": "ponctionner",
    "ponctions": "ponction",
    "ponctua": "ponctuer",
    "ponctuai": "ponctuer",
    "ponctuaient": "ponctuer",
    "ponctuais": "ponctuer",
    "ponctuait": "ponctuer",
    "ponctualités": "ponctualité",
    "ponctuant": "ponctuer",
    "ponctuas": "ponctuer",
    "ponctuasse": "ponctuer",
    "ponctuassent": "ponctuer",
    "ponctuasses": "ponctuer",
    "ponctuassiez": "ponctuer",
    "ponctuassions": "ponctuer",
    "ponctuations": "ponctuation",
    "ponctue": "ponctuer",
    "ponctuelle": "ponctuel",
    "ponctuelles": "ponctuel",
    "ponctuels": "ponctuel",
    "ponctuent": "ponctuer",
    "ponctuera": "ponctuer",
    "ponctuerai": "ponctuer",
    "ponctueraient": "ponctuer",
    "ponctuerais": "ponctuer",
    "ponctuerait": "ponctuer",
    "ponctueras": "ponctuer",
    "ponctuerez": "ponctuer",
    "ponctueriez": "ponctuer",
    "ponctuerions": "ponctuer",
    "ponctuerons": "ponctuer",
    "ponctueront": "ponctuer",
    "ponctues": "ponctuer",
    "ponctuez": "ponctuer",
    "ponctuiez": "ponctuer",
    "ponctuions": "ponctuer",
    "ponctuons": "ponctuer",
    "ponctuâmes": "ponctuer",
    "ponctuât": "ponctuer",
    "ponctuâtes": "ponctuer",
    "ponctuèrent": "ponctuer",
    "ponctué": "ponctuer",
    "ponctuée": "ponctuer",
    "ponctuées": "ponctuer",
    "ponctués": "ponctuer",
    "poncèrent": "poncer",
    "poncé": "poncer",
    "poncée": "poncer",
    "poncées": "poncer",
    "poncés": "poncer",
    "pond": "pondre",
    "pondaient": "pondre",
    "pondais": "pondre",
    "pondait": "pondre",
    "pondant": "pondre",
    "ponde": "pondre",
    "pondent": "pondre",
    "pondes": "pondre",
    "pondeurs": "pondeur",
    "pondeuse": "pondeur",
    "pondeuses": "pondeur",
    "pondez": "pondre",
    "pondiez": "pondre",
    "pondions": "pondre",
    "pondirent": "pondre",
    "pondis": "pondre",
    "pondisse": "pondre",
    "pondissent": "pondre",
    "pondisses": "pondre",
    "pondissiez": "pondre",
    "pondissions": "pondre",
    "pondit": "pondre",
    "pondoirs": "pondoir",
    "pondons": "pondre",
    "pondra": "pondre",
    "pondrai": "pondre",
    "pondraient": "pondre",
    "pondrais": "pondre",
    "pondrait": "pondre",
    "pondras": "pondre",
    "pondrez": "pondre",
    "pondriez": "pondre",
    "pondrions": "pondre",
    "pondrons": "pondre",
    "pondront": "pondre",
    "ponds": "pondre",
    "pondu": "pondre",
    "pondue": "pondre",
    "pondues": "pondre",
    "pondus": "pondre",
    "pondère": "pondérer",
    "pondèrent": "pondérer",
    "pondères": "pondérer",
    "pondéra": "pondérer",
    "pondérables": "pondérable",
    "pondérai": "pondérer",
    "pondéraient": "pondérer",
    "pondérais": "pondérer",
    "pondérait": "pondérer",
    "pondérale": "pondéral",
    "pondérales": "pondéral",
    "pondérant": "pondérer",
    "pondéras": "pondérer",
    "pondérasse": "pondérer",
    "pondérassent": "pondérer",
    "pondérasses": "pondérer",
    "pondérassiez": "pondérer",
    "pondérassions": "pondérer",
    "pondérations": "pondération",
    "pondéraux": "pondéral",
    "pondérera": "pondérer",
    "pondérerai": "pondérer",
    "pondéreraient": "pondérer",
    "pondérerais": "pondérer",
    "pondérerait": "pondérer",
    "pondéreras": "pondérer",
    "pondérerez": "pondérer",
    "pondéreriez": "pondérer",
    "pondérerions": "pondérer",
    "pondérerons": "pondérer",
    "pondéreront": "pondérer",
    "pondérez": "pondérer",
    "pondériez": "pondérer",
    "pondérions": "pondérer",
    "pondérons": "pondérer",
    "pondérâmes": "pondérer",
    "pondérât": "pondérer",
    "pondérâtes": "pondérer",
    "pondérèrent": "pondérer",
    "pondéré": "pondérer",
    "pondérée": "pondérer",
    "pondérées": "pondérer",
    "pondérés": "pondérer",
    "pondîmes": "pondre",
    "pondît": "pondre",
    "pondîtes": "pondre",
    "ponettes": "ponette",
    "poneys": "poney",
    "pongistes": "pongiste",
    "pontages": "pontage",
    "ponte": "ponter",
    "pontes": "ponte",
    "pontets": "pontet",
    "pontifes": "pontife",
    "pontifia": "pontifier",
    "pontifiai": "pontifier",
    "pontifiaient": "pontifier",
    "pontifiais": "pontifier",
    "pontifiait": "pontifier",
    "pontifiant": "pontifier",
    "pontifiante": "pontifiant",
    "pontifiants": "pontifiant",
    "pontifias": "pontifier",
    "pontifiasse": "pontifier",
    "pontifiassent": "pontifier",
    "pontifiasses": "pontifier",
    "pontifiassiez": "pontifier",
    "pontifiassions": "pontifier",
    "pontificale": "pontifical",
    "pontificales": "pontifical",
    "pontificaux": "pontifical",
    "pontifie": "pontifier",
    "pontifient": "pontifier",
    "pontifiera": "pontifier",
    "pontifierai": "pontifier",
    "pontifieraient": "pontifier",
    "pontifierais": "pontifier",
    "pontifierait": "pontifier",
    "pontifieras": "pontifier",
    "pontifierez": "pontifier",
    "pontifieriez": "pontifier",
    "pontifierions": "pontifier",
    "pontifierons": "pontifier",
    "pontifieront": "pontifier",
    "pontifies": "pontifier",
    "pontifiez": "pontifier",
    "pontifiiez": "pontifier",
    "pontifiions": "pontifier",
    "pontifions": "pontifier",
    "pontifiâmes": "pontifier",
    "pontifiât": "pontifier",
    "pontifiâtes": "pontifier",
    "pontifièrent": "pontifier",
    "pontifié": "pontifier",
    "pontins": "pontin",
    "pontonniers": "pontonnier",
    "pontons": "ponton",
    "pontons-grues": "ponton-grue",
    "ponts": "pont",
    "ponts-levis": "pont-levis",
    "ponts-promenade": "pont-promenade",
    "ponts-rail": "pont-rail",
    "ponts-route": "pont-route",
    "ponté": "ponter",
    "ponça": "poncer",
    "ponçages": "ponçage",
    "ponçai": "poncer",
    "ponçaient": "poncer",
    "ponçais": "poncer",
    "ponçait": "poncer",
    "ponçant": "poncer",
    "ponças": "poncer",
    "ponçasse": "poncer",
    "ponçassent": "poncer",
    "ponçasses": "poncer",
    "ponçassiez": "poncer",
    "ponçassions": "poncer",
    "ponçons": "poncer",
    "ponçâmes": "poncer",
    "ponçât": "poncer",
    "ponçâtes": "poncer",
    "pools": "pool",
    "popelines": "popeline",
    "poperénistes": "poperéniste",
    "popes": "pope",
    "popistes": "popiste",
    "poplitée": "poplité",
    "popotes": "popote",
    "pops": "pop",
    "populaces": "populace",
    "populacière": "populacier",
    "populacières": "populacier",
    "populaires": "populaire",
    "popularisa": "populariser",
    "popularisai": "populariser",
    "popularisaient": "populariser",
    "popularisais": "populariser",
    "popularisait": "populariser",
    "popularisant": "populariser",
    "popularisas": "populariser",
    "popularisasse": "populariser",
    "popularisassent": "populariser",
    "popularisasses": "populariser",
    "popularisassiez": "populariser",
    "popularisassions": "populariser",
    "popularise": "populariser",
    "popularisent": "populariser",
    "popularisera": "populariser",
    "populariserai": "populariser",
    "populariseraient": "populariser",
    "populariserais": "populariser",
    "populariserait": "populariser",
    "populariseras": "populariser",
    "populariserez": "populariser",
    "populariseriez": "populariser",
    "populariserions": "populariser",
    "populariserons": "populariser",
    "populariseront": "populariser",
    "popularises": "populariser",
    "popularisez": "populariser",
    "popularisiez": "populariser",
    "popularisions": "populariser",
    "popularisons": "populariser",
    "popularisâmes": "populariser",
    "popularisât": "populariser",
    "popularisâtes": "populariser",
    "popularisèrent": "populariser",
    "popularisé": "populariser",
    "popularisée": "populariser",
    "popularisées": "populariser",
    "popularisés": "populariser",
    "popularités": "popularité",
    "populations": "population",
    "populeuse": "populeux",
    "populeuses": "populeux",
    "populismes": "populisme",
    "populistes": "populiste",
    "poquait": "poquer",
    "porcelaines": "porcelaine",
    "porcelainiers": "porcelainier",
    "porcelainière": "porcelainier",
    "porcelainières": "porcelainier",
    "porcelets": "porcelet",
    "porcheries": "porcherie",
    "porches": "porche",
    "porchère": "porcher",
    "porchères": "porcher",
    "porcifs": "porcif",
    "porcine": "porcin",
    "porcines": "porcin",
    "porcins": "porcin",
    "porcs": "porc",
    "porcs-épics": "porc-épic",
    "pores": "pore",
    "poreuse": "poreux",
    "poreuses": "poreux",
    "porions": "porion",
    "pornocrates": "pornocrate",
    "pornographes": "pornographe",
    "pornographies": "pornographie",
    "pornographiques": "pornographique",
    "pornos": "porno",
    "porphyres": "porphyre",
    "porta": "porter",
    "portables": "portable",
    "portai": "porter",
    "portaient": "porter",
    "portails": "portail",
    "portais": "porter",
    "portait": "porter",
    "portant": "porter",
    "portante": "portant",
    "portantes": "portant",
    "portants": "portant",
    "portas": "porter",
    "portasse": "porter",
    "portassent": "porter",
    "portasses": "porter",
    "portassiez": "porter",
    "portassions": "porter",
    "portatifs": "portatif",
    "portative": "portatif",
    "portatives": "portatif",
    "porte": "porter",
    "porte-affiches": "porte-affiche",
    "porte-bébés": "porte-bébé",
    "porte-couteaux": "porte-couteau",
    "porte-cravates": "porte-cravate",
    "porte-crayons": "porte-crayon",
    "porte-drapeaux": "porte-drapeau",
    "porte-flingues": "porte-flingue",
    "porte-forets": "porte-foret",
    "porte-mines": "porte-mine",
    "porte-outils": "porte-outil",
    "porte-plumes": "porte-plume",
    "porte-savons": "porte-savon",
    "porte-étendards": "porte-étendard",
    "portefeuilles": "portefeuille",
    "portemanteaux": "portemanteau",
    "portemines": "portemine",
    "portent": "porter",
    "portera": "porter",
    "porterai": "porter",
    "porteraient": "porter",
    "porterais": "porter",
    "porterait": "porter",
    "porteras": "porter",
    "porterez": "porter",
    "porteriez": "porter",
    "porterions": "porter",
    "porterons": "porter",
    "porteront": "porter",
    "porters": "porter",
    "portes": "porter",
    "portes-fenêtres": "porte-fenêtre",
    "porteurs": "porteur",
    "porteuse": "porteur",
    "porteuses": "porteur",
    "portez": "porter",
    "portiers": "portier",
    "portiez": "porter",
    "portillons": "portillon",
    "portions": "portion",
    "portiques": "portique",
    "portière": "portier",
    "portières": "portière",
    "portons": "porter",
    "portoricaine": "portoricain",
    "portoricaines": "portoricain",
    "portoricains": "portoricain",
    "portos": "porto",
    "portrait": "portraire",
    "portraitistes": "portraitiste",
    "portraits": "portrait",
    "portraits-robots": "portrait-robot",
    "portraiturant": "portraiturer",
    "portraiture": "portraiturer",
    "portraituré": "portraiturer",
    "portraiturés": "portraiturer",
    "ports": "port",
    "portuaires": "portuaire",
    "portugaise": "portugais",
    "portugaises": "portugais",
    "portuguaise": "portuguais",
    "portuguaises": "portuguais",
    "portulans": "portulan",
    "portâmes": "porter",
    "portât": "porter",
    "portâtes": "porter",
    "portèrent": "porter",
    "porté": "porter",
    "portée": "porter",
    "portées": "porter",
    "portés": "porter",
    "posa": "poser",
    "posadas": "posada",
    "posai": "poser",
    "posaient": "poser",
    "posais": "poser",
    "posait": "poser",
    "posant": "poser",
    "posas": "poser",
    "posasse": "poser",
    "posassent": "poser",
    "posasses": "poser",
    "posassiez": "poser",
    "posassions": "poser",
    "pose": "poser",
    "posent": "poser",
    "posera": "poser",
    "poserai": "poser",
    "poseraient": "poser",
    "poserais": "poser",
    "poserait": "poser",
    "poseras": "poser",
    "poserez": "poser",
    "poseriez": "poser",
    "poserions": "poser",
    "poserons": "poser",
    "poseront": "poser",
    "poses": "poser",
    "poseurs": "poseur",
    "poseuse": "poseur",
    "poseuses": "poseur",
    "posez": "poser",
    "posiez": "poser",
    "posions": "poser",
    "positifs": "positif",
    "positionna": "positionner",
    "positionnai": "positionner",
    "positionnaient": "positionner",
    "positionnais": "positionner",
    "positionnait": "positionner",
    "positionnant": "positionner",
    "positionnas": "positionner",
    "positionnasse": "positionner",
    "positionnassent": "positionner",
    "positionnasses": "positionner",
    "positionnassiez": "positionner",
    "positionnassions": "positionner",
    "positionne": "positionner",
    "positionnements": "positionnement",
    "positionnent": "positionner",
    "positionnera": "positionner",
    "positionnerai": "positionner",
    "positionneraient": "positionner",
    "positionnerais": "positionner",
    "positionnerait": "positionner",
    "positionneras": "positionner",
    "positionnerez": "positionner",
    "positionneriez": "positionner",
    "positionnerions": "positionner",
    "positionnerons": "positionner",
    "positionneront": "positionner",
    "positionnes": "positionner",
    "positionnez": "positionner",
    "positionniez": "positionner",
    "positionnions": "positionner",
    "positionnons": "positionner",
    "positionnâmes": "positionner",
    "positionnât": "positionner",
    "positionnâtes": "positionner",
    "positionnèrent": "positionner",
    "positionné": "positionner",
    "positionnée": "positionner",
    "positionnées": "positionner",
    "positionnés": "positionner",
    "positions": "position",
    "positive": "positif",
    "positives": "positif",
    "positivistes": "positiviste",
    "positrons": "positron",
    "posologies": "posologie",
    "posons": "poser",
    "possesseurs": "possesseur",
    "possessifs": "possessif",
    "possessions": "possession",
    "possessive": "possessif",
    "possessives": "possessif",
    "possibilités": "possibilité",
    "possibles": "possible",
    "possède": "posséder",
    "possèdent": "posséder",
    "possèdes": "posséder",
    "posséda": "posséder",
    "possédai": "posséder",
    "possédaient": "posséder",
    "possédais": "posséder",
    "possédait": "posséder",
    "possédant": "posséder",
    "possédante": "possédant",
    "possédants": "possédant",
    "possédas": "posséder",
    "possédasse": "posséder",
    "possédassent": "posséder",
    "possédasses": "posséder",
    "possédassiez": "posséder",
    "possédassions": "posséder",
    "possédera": "posséder",
    "posséderai": "posséder",
    "posséderaient": "posséder",
    "posséderais": "posséder",
    "posséderait": "posséder",
    "posséderas": "posséder",
    "posséderez": "posséder",
    "posséderiez": "posséder",
    "posséderions": "posséder",
    "posséderons": "posséder",
    "posséderont": "posséder",
    "possédez": "posséder",
    "possédiez": "posséder",
    "possédions": "posséder",
    "possédons": "posséder",
    "possédâmes": "posséder",
    "possédât": "posséder",
    "possédâtes": "posséder",
    "possédèrent": "posséder",
    "possédé": "posséder",
    "possédée": "posséder",
    "possédées": "posséder",
    "possédés": "posséder",
    "post it": "post-it",
    "post-natale": "post-natal",
    "post-opératoires": "post-opératoire",
    "post-surréalistes": "post-surréaliste",
    "post-traumatiques": "post-traumatique",
    "posta": "poster",
    "postai": "poster",
    "postaient": "poster",
    "postais": "poster",
    "postait": "poster",
    "postale": "postal",
    "postales": "postal",
    "postant": "poster",
    "postas": "poster",
    "postasse": "poster",
    "postassent": "poster",
    "postasses": "poster",
    "postassiez": "poster",
    "postassions": "poster",
    "postaux": "postal",
    "postdata": "postdater",
    "postdatai": "postdater",
    "postdataient": "postdater",
    "postdatais": "postdater",
    "postdatait": "postdater",
    "postdatant": "postdater",
    "postdatas": "postdater",
    "postdatasse": "postdater",
    "postdatassent": "postdater",
    "postdatasses": "postdater",
    "postdatassiez": "postdater",
    "postdatassions": "postdater",
    "postdate": "postdater",
    "postdatent": "postdater",
    "postdatera": "postdater",
    "postdaterai": "postdater",
    "postdateraient": "postdater",
    "postdaterais": "postdater",
    "postdaterait": "postdater",
    "postdateras": "postdater",
    "postdaterez": "postdater",
    "postdateriez": "postdater",
    "postdaterions": "postdater",
    "postdaterons": "postdater",
    "postdateront": "postdater",
    "postdates": "postdater",
    "postdatez": "postdater",
    "postdatiez": "postdater",
    "postdations": "postdater",
    "postdatons": "postdater",
    "postdatâmes": "postdater",
    "postdatât": "postdater",
    "postdatâtes": "postdater",
    "postdatèrent": "postdater",
    "postdaté": "postdater",
    "postdatée": "postdater",
    "postdatées": "postdater",
    "postdatés": "postdater",
    "postdoctorale": "postdoctoral",
    "postdoctorales": "postdoctoral",
    "postdoctoraux": "postdoctoral",
    "poste": "poster",
    "postent": "poster",
    "postera": "poster",
    "posterai": "poster",
    "posteraient": "poster",
    "posterais": "poster",
    "posterait": "poster",
    "posteras": "poster",
    "posterez": "poster",
    "posteriez": "poster",
    "posterions": "poster",
    "posterons": "poster",
    "posteront": "poster",
    "posters": "poster",
    "postes": "poster",
    "postes-clés": "postes-clé",
    "postez": "poster",
    "postfaces": "postface",
    "posthumes": "posthume",
    "postiches": "postiche",
    "postiers": "postier",
    "postiez": "poster",
    "postillonna": "postillonner",
    "postillonnai": "postillonner",
    "postillonnaient": "postillonner",
    "postillonnais": "postillonner",
    "postillonnait": "postillonner",
    "postillonnant": "postillonner",
    "postillonnas": "postillonner",
    "postillonnasse": "postillonner",
    "postillonnassent": "postillonner",
    "postillonnasses": "postillonner",
    "postillonnassiez": "postillonner",
    "postillonnassions": "postillonner",
    "postillonne": "postillonner",
    "postillonnent": "postillonner",
    "postillonnera": "postillonner",
    "postillonnerai": "postillonner",
    "postillonneraient": "postillonner",
    "postillonnerais": "postillonner",
    "postillonnerait": "postillonner",
    "postillonneras": "postillonner",
    "postillonnerez": "postillonner",
    "postillonneriez": "postillonner",
    "postillonnerions": "postillonner",
    "postillonnerons": "postillonner",
    "postillonneront": "postillonner",
    "postillonnes": "postillonner",
    "postillonneurs": "postillonneur",
    "postillonnez": "postillonner",
    "postillonniez": "postillonner",
    "postillonnions": "postillonner",
    "postillonnons": "postillonner",
    "postillonnâmes": "postillonner",
    "postillonnât": "postillonner",
    "postillonnâtes": "postillonner",
    "postillonnèrent": "postillonner",
    "postillonné": "postillonner",
    "postillons": "postillon",
    "postions": "poster",
    "postière": "postier",
    "postières": "postier",
    "postministérielle": "postministériel",
    "postministérielles": "postministériel",
    "postministériels": "postministériel",
    "postnatale": "postnatal",
    "postnatales": "postnatal",
    "postnatals": "postnatal",
    "postnataux": "postnatal",
    "postons": "poster",
    "postopératoires": "postopératoire",
    "postposa": "postposer",
    "postposai": "postposer",
    "postposaient": "postposer",
    "postposais": "postposer",
    "postposait": "postposer",
    "postposant": "postposer",
    "postposas": "postposer",
    "postposasse": "postposer",
    "postposassent": "postposer",
    "postposasses": "postposer",
    "postposassiez": "postposer",
    "postposassions": "postposer",
    "postpose": "postposer",
    "postposent": "postposer",
    "postposera": "postposer",
    "postposerai": "postposer",
    "postposeraient": "postposer",
    "postposerais": "postposer",
    "postposerait": "postposer",
    "postposeras": "postposer",
    "postposerez": "postposer",
    "postposeriez": "postposer",
    "postposerions": "postposer",
    "postposerons": "postposer",
    "postposeront": "postposer",
    "postposes": "postposer",
    "postposez": "postposer",
    "postposiez": "postposer",
    "postposions": "postposer",
    "postposons": "postposer",
    "postposâmes": "postposer",
    "postposât": "postposer",
    "postposâtes": "postposer",
    "postposèrent": "postposer",
    "postposé": "postposer",
    "postposée": "postposer",
    "postposées": "postposer",
    "postposés": "postposer",
    "postprandiale": "postprandial",
    "postprandiales": "postprandial",
    "postprandiaux": "postprandial",
    "postscolaires": "postscolaire",
    "postsynchronisa": "postsynchroniser",
    "postsynchronisai": "postsynchroniser",
    "postsynchronisaient": "postsynchroniser",
    "postsynchronisais": "postsynchroniser",
    "postsynchronisait": "postsynchroniser",
    "postsynchronisant": "postsynchroniser",
    "postsynchronisas": "postsynchroniser",
    "postsynchronisasse": "postsynchroniser",
    "postsynchronisassent": "postsynchroniser",
    "postsynchronisasses": "postsynchroniser",
    "postsynchronisassiez": "postsynchroniser",
    "postsynchronisassions": "postsynchroniser",
    "postsynchronise": "postsynchroniser",
    "postsynchronisent": "postsynchroniser",
    "postsynchronisera": "postsynchroniser",
    "postsynchroniserai": "postsynchroniser",
    "postsynchroniseraient": "postsynchroniser",
    "postsynchroniserais": "postsynchroniser",
    "postsynchroniserait": "postsynchroniser",
    "postsynchroniseras": "postsynchroniser",
    "postsynchroniserez": "postsynchroniser",
    "postsynchroniseriez": "postsynchroniser",
    "postsynchroniserions": "postsynchroniser",
    "postsynchroniserons": "postsynchroniser",
    "postsynchroniseront": "postsynchroniser",
    "postsynchronises": "postsynchroniser",
    "postsynchronisez": "postsynchroniser",
    "postsynchronisiez": "postsynchroniser",
    "postsynchronisions": "postsynchroniser",
    "postsynchronisons": "postsynchroniser",
    "postsynchronisâmes": "postsynchroniser",
    "postsynchronisât": "postsynchroniser",
    "postsynchronisâtes": "postsynchroniser",
    "postsynchronisèrent": "postsynchroniser",
    "postsynchronisé": "postsynchroniser",
    "postsynchronisée": "postsynchroniser",
    "postsynchronisées": "postsynchroniser",
    "postsynchronisés": "postsynchroniser",
    "postula": "postuler",
    "postulai": "postuler",
    "postulaient": "postuler",
    "postulais": "postuler",
    "postulait": "postuler",
    "postulant": "postuler",
    "postulante": "postulant",
    "postulantes": "postulant",
    "postulants": "postulant",
    "postulas": "postuler",
    "postulasse": "postuler",
    "postulassent": "postuler",
    "postulasses": "postuler",
    "postulassiez": "postuler",
    "postulassions": "postuler",
    "postulations": "postulation",
    "postulats": "postulat",
    "postule": "postuler",
    "postulent": "postuler",
    "postulera": "postuler",
    "postulerai": "postuler",
    "postuleraient": "postuler",
    "postulerais": "postuler",
    "postulerait": "postuler",
    "postuleras": "postuler",
    "postulerez": "postuler",
    "postuleriez": "postuler",
    "postulerions": "postuler",
    "postulerons": "postuler",
    "postuleront": "postuler",
    "postules": "postuler",
    "postulez": "postuler",
    "postuliez": "postuler",
    "postulions": "postuler",
    "postulons": "postuler",
    "postulâmes": "postuler",
    "postulât": "postuler",
    "postulâtes": "postuler",
    "postulèrent": "postuler",
    "postulé": "postuler",
    "postulée": "postuler",
    "postulées": "postuler",
    "postulés": "postuler",
    "postuniversitaires": "postuniversitaire",
    "posturale": "postural",
    "posturales": "postural",
    "posturaux": "postural",
    "postures": "posture",
    "postâmes": "poster",
    "postât": "poster",
    "postâtes": "poster",
    "postèrent": "poster",
    "posté": "poster",
    "postée": "poster",
    "postées": "poster",
    "postérieure": "postérieur",
    "postérieures": "postérieur",
    "postérieurs": "postérieur",
    "postérités": "postérité",
    "postés": "poster",
    "posâmes": "poser",
    "posât": "poser",
    "posâtes": "poser",
    "posèrent": "poser",
    "posé": "poser",
    "posée": "poser",
    "posées": "poser",
    "posés": "poser",
    "potables": "potable",
    "potaches": "potache",
    "potagers": "potager",
    "potages": "potage",
    "potagère": "potager",
    "potagères": "potager",
    "potards": "potard",
    "potassa": "potasser",
    "potassai": "potasser",
    "potassaient": "potasser",
    "potassais": "potasser",
    "potassait": "potasser",
    "potassant": "potasser",
    "potassas": "potasser",
    "potassasse": "potasser",
    "potassassent": "potasser",
    "potassasses": "potasser",
    "potassassiez": "potasser",
    "potassassions": "potasser",
    "potasse": "potasser",
    "potassent": "potasser",
    "potassera": "potasser",
    "potasserai": "potasser",
    "potasseraient": "potasser",
    "potasserais": "potasser",
    "potasserait": "potasser",
    "potasseras": "potasser",
    "potasserez": "potasser",
    "potasseriez": "potasser",
    "potasserions": "potasser",
    "potasserons": "potasser",
    "potasseront": "potasser",
    "potasses": "potasser",
    "potassez": "potasser",
    "potassiez": "potasser",
    "potassions": "potasser",
    "potassiums": "potassium",
    "potassons": "potasser",
    "potassâmes": "potasser",
    "potassât": "potasser",
    "potassâtes": "potasser",
    "potassèrent": "potasser",
    "potassé": "potasser",
    "potassée": "potasser",
    "potassées": "potasser",
    "potassés": "potasser",
    "poteaux": "poteau",
    "potelée": "potelé",
    "potelées": "potelé",
    "potelés": "potelé",
    "potences": "potence",
    "potencée": "potencé",
    "potentats": "potentat",
    "potentialités": "potentialité",
    "potentielle": "potentiel",
    "potentielles": "potentiel",
    "potentiels": "potentiel",
    "potentiomètres": "potentiomètre",
    "poteries": "poterie",
    "poternes": "poterne",
    "potes": "pote",
    "potiches": "potiche",
    "potiers": "potier",
    "potina": "potiner",
    "potinai": "potiner",
    "potinaient": "potiner",
    "potinais": "potiner",
    "potinait": "potiner",
    "potinant": "potiner",
    "potinas": "potiner",
    "potinasse": "potiner",
    "potinassent": "potiner",
    "potinasses": "potiner",
    "potinassiez": "potiner",
    "potinassions": "potiner",
    "potine": "potiner",
    "potinent": "potiner",
    "potinera": "potiner",
    "potinerai": "potiner",
    "potineraient": "potiner",
    "potinerais": "potiner",
    "potinerait": "potiner",
    "potineras": "potiner",
    "potinerez": "potiner",
    "potineriez": "potiner",
    "potinerions": "potiner",
    "potinerons": "potiner",
    "potineront": "potiner",
    "potines": "potiner",
    "potinez": "potiner",
    "potiniez": "potiner",
    "potinions": "potiner",
    "potinons": "potiner",
    "potins": "potin",
    "potinâmes": "potiner",
    "potinât": "potiner",
    "potinâtes": "potiner",
    "potinèrent": "potiner",
    "potiné": "potiner",
    "potions": "potion",
    "potirons": "potiron",
    "potière": "potier",
    "pots": "pot",
    "pots-de-vin": "pot-de-vin",
    "pots-pourris": "pot-pourri",
    "potées": "potée",
    "poubelles": "poubelle",
    "pouces": "pouce",
    "pouces-pieds": "pouce-pied",
    "poucets": "poucet",
    "poucettes": "poucette",
    "poudings": "pouding",
    "poudra": "poudrer",
    "poudrai": "poudrer",
    "poudraient": "poudrer",
    "poudrais": "poudrer",
    "poudrait": "poudrer",
    "poudrant": "poudrer",
    "poudras": "poudrer",
    "poudrasse": "poudrer",
    "poudrassent": "poudrer",
    "poudrasses": "poudrer",
    "poudrassiez": "poudrer",
    "poudrassions": "poudrer",
    "poudre": "poudrer",
    "poudrent": "poudrer",
    "poudrera": "poudrer",
    "poudrerai": "poudrer",
    "poudreraient": "poudrer",
    "poudrerais": "poudrer",
    "poudrerait": "poudrer",
    "poudreras": "poudrer",
    "poudrerez": "poudrer",
    "poudreriez": "poudrer",
    "poudrerions": "poudrer",
    "poudrerons": "poudrer",
    "poudreront": "poudrer",
    "poudres": "poudrer",
    "poudreuse": "poudreux",
    "poudreuses": "poudreux",
    "poudrez": "poudrer",
    "poudriers": "poudrier",
    "poudriez": "poudrer",
    "poudrions": "poudrer",
    "poudrières": "poudrière",
    "poudroie": "poudroyer",
    "poudroiements": "poudroiement",
    "poudroient": "poudroyer",
    "poudroiera": "poudroyer",
    "poudroierai": "poudroyer",
    "poudroieraient": "poudroyer",
    "poudroierais": "poudroyer",
    "poudroierait": "poudroyer",
    "poudroieras": "poudroyer",
    "poudroierez": "poudroyer",
    "poudroieriez": "poudroyer",
    "poudroierions": "poudroyer",
    "poudroierons": "poudroyer",
    "poudroieront": "poudroyer",
    "poudroies": "poudroyer",
    "poudrons": "poudrer",
    "poudroya": "poudroyer",
    "poudroyai": "poudroyer",
    "poudroyaient": "poudroyer",
    "poudroyais": "poudroyer",
    "poudroyait": "poudroyer",
    "poudroyant": "poudroyer",
    "poudroyante": "poudroyant",
    "poudroyantes": "poudroyant",
    "poudroyas": "poudroyer",
    "poudroyasse": "poudroyer",
    "poudroyassent": "poudroyer",
    "poudroyasses": "poudroyer",
    "poudroyassiez": "poudroyer",
    "poudroyassions": "poudroyer",
    "poudroyez": "poudroyer",
    "poudroyiez": "poudroyer",
    "poudroyions": "poudroyer",
    "poudroyons": "poudroyer",
    "poudroyâmes": "poudroyer",
    "poudroyât": "poudroyer",
    "poudroyâtes": "poudroyer",
    "poudroyèrent": "poudroyer",
    "poudroyé": "poudroyer",
    "poudroyée": "poudroyer",
    "poudroyées": "poudroyer",
    "poudroyés": "poudroyer",
    "poudrâmes": "poudrer",
    "poudrât": "poudrer",
    "poudrâtes": "poudrer",
    "poudrèrent": "poudrer",
    "poudré": "poudrer",
    "poudrée": "poudrer",
    "poudrées": "poudrer",
    "poudrés": "poudrer",
    "pouffa": "pouffer",
    "pouffai": "pouffer",
    "pouffaient": "pouffer",
    "pouffais": "pouffer",
    "pouffait": "pouffer",
    "pouffant": "pouffer",
    "pouffante": "pouffant",
    "pouffantes": "pouffant",
    "pouffas": "pouffer",
    "pouffasse": "pouffer",
    "pouffassent": "pouffer",
    "pouffasses": "pouffer",
    "pouffassiez": "pouffer",
    "pouffassions": "pouffer",
    "pouffe": "pouffer",
    "pouffements": "pouffement",
    "pouffent": "pouffer",
    "pouffera": "pouffer",
    "poufferai": "pouffer",
    "poufferaient": "pouffer",
    "poufferais": "pouffer",
    "poufferait": "pouffer",
    "poufferas": "pouffer",
    "poufferez": "pouffer",
    "poufferiez": "pouffer",
    "poufferions": "pouffer",
    "poufferons": "pouffer",
    "poufferont": "pouffer",
    "pouffes": "pouffer",
    "pouffez": "pouffer",
    "pouffiasses": "pouffiasse",
    "pouffiez": "pouffer",
    "pouffions": "pouffer",
    "pouffons": "pouffer",
    "pouffâmes": "pouffer",
    "pouffât": "pouffer",
    "pouffâtes": "pouffer",
    "pouffèrent": "pouffer",
    "pouffé": "pouffer",
    "poufiasses": "poufiasse",
    "poufs": "pouf",
    "pouilleries": "pouillerie",
    "pouilles": "pouille",
    "pouilleuse": "pouilleux",
    "pouilleuses": "pouilleux",
    "pouillots": "pouillot",
    "pouillys": "pouilly",
    "pouillés": "pouillé",
    "poujadistes": "poujadiste",
    "poulagas": "poulaga",
    "poulaillers": "poulailler",
    "poulaine": "poulain",
    "poulaines": "poulaine",
    "poulains": "poulain",
    "poularde": "poulard",
    "poulardes": "poulard",
    "poulardins": "poulardin",
    "poulbots": "poulbot",
    "poules": "poule",
    "poulets": "poulet",
    "poulettes": "poulette",
    "pouliche": "poulain",
    "pouliches": "pouliche",
    "poulies": "poulie",
    "poulina": "pouliner",
    "poulinai": "pouliner",
    "poulinaient": "pouliner",
    "poulinais": "pouliner",
    "poulinait": "pouliner",
    "poulinant": "pouliner",
    "poulinas": "pouliner",
    "poulinasse": "pouliner",
    "poulinassent": "pouliner",
    "poulinasses": "pouliner",
    "poulinassiez": "pouliner",
    "poulinassions": "pouliner",
    "pouline": "pouliner",
    "poulinent": "pouliner",
    "poulinera": "pouliner",
    "poulinerai": "pouliner",
    "poulineraient": "pouliner",
    "poulinerais": "pouliner",
    "poulinerait": "pouliner",
    "poulineras": "pouliner",
    "poulinerez": "pouliner",
    "poulineriez": "pouliner",
    "poulinerions": "pouliner",
    "poulinerons": "pouliner",
    "poulineront": "pouliner",
    "poulines": "pouliner",
    "poulinez": "pouliner",
    "pouliniez": "pouliner",
    "poulinions": "pouliner",
    "poulinons": "pouliner",
    "poulinâmes": "pouliner",
    "poulinât": "pouliner",
    "poulinâtes": "pouliner",
    "poulinèrent": "pouliner",
    "pouliné": "pouliner",
    "poulots": "poulot",
    "poulottant": "poulotter",
    "poulpes": "poulpe",
    "poults-de-soie": "poult-de-soie",
    "poumons": "poumon",
    "pounds": "pound",
    "pouparde": "poupard",
    "poupardes": "poupard",
    "poupards": "poupard",
    "poupes": "poupe",
    "poupine": "poupin",
    "poupines": "poupin",
    "poupins": "poupin",
    "pouponna": "pouponner",
    "pouponnai": "pouponner",
    "pouponnaient": "pouponner",
    "pouponnais": "pouponner",
    "pouponnait": "pouponner",
    "pouponnant": "pouponner",
    "pouponnas": "pouponner",
    "pouponnasse": "pouponner",
    "pouponnassent": "pouponner",
    "pouponnasses": "pouponner",
    "pouponnassiez": "pouponner",
    "pouponnassions": "pouponner",
    "pouponne": "pouponner",
    "pouponnent": "pouponner",
    "pouponnera": "pouponner",
    "pouponnerai": "pouponner",
    "pouponneraient": "pouponner",
    "pouponnerais": "pouponner",
    "pouponnerait": "pouponner",
    "pouponneras": "pouponner",
    "pouponnerez": "pouponner",
    "pouponneriez": "pouponner",
    "pouponnerions": "pouponner",
    "pouponnerons": "pouponner",
    "pouponneront": "pouponner",
    "pouponnes": "pouponner",
    "pouponnez": "pouponner",
    "pouponniez": "pouponner",
    "pouponnions": "pouponner",
    "pouponnières": "pouponnière",
    "pouponnons": "pouponner",
    "pouponnâmes": "pouponner",
    "pouponnât": "pouponner",
    "pouponnâtes": "pouponner",
    "pouponnèrent": "pouponner",
    "pouponné": "pouponner",
    "pouponnée": "pouponner",
    "pouponnées": "pouponner",
    "pouponnés": "pouponner",
    "poupons": "poupon",
    "poupées": "poupée",
    "pourboires": "pourboire",
    "pourceaux": "pourceau",
    "pourcentages": "pourcentage",
    "pourcents": "pourcent",
    "pourchassa": "pourchasser",
    "pourchassai": "pourchasser",
    "pourchassaient": "pourchasser",
    "pourchassais": "pourchasser",
    "pourchassait": "pourchasser",
    "pourchassant": "pourchasser",
    "pourchassas": "pourchasser",
    "pourchassasse": "pourchasser",
    "pourchassassent": "pourchasser",
    "pourchassasses": "pourchasser",
    "pourchassassiez": "pourchasser",
    "pourchassassions": "pourchasser",
    "pourchasse": "pourchasser",
    "pourchassent": "pourchasser",
    "pourchassera": "pourchasser",
    "pourchasserai": "pourchasser",
    "pourchasseraient": "pourchasser",
    "pourchasserais": "pourchasser",
    "pourchasserait": "pourchasser",
    "pourchasseras": "pourchasser",
    "pourchasserez": "pourchasser",
    "pourchasseriez": "pourchasser",
    "pourchasserions": "pourchasser",
    "pourchasserons": "pourchasser",
    "pourchasseront": "pourchasser",
    "pourchasses": "pourchasser",
    "pourchassez": "pourchasser",
    "pourchassiez": "pourchasser",
    "pourchassions": "pourchasser",
    "pourchassons": "pourchasser",
    "pourchassâmes": "pourchasser",
    "pourchassât": "pourchasser",
    "pourchassâtes": "pourchasser",
    "pourchassèrent": "pourchasser",
    "pourchassé": "pourchasser",
    "pourchassée": "pourchasser",
    "pourchassées": "pourchasser",
    "pourchassés": "pourchasser",
    "pourfend": "pourfendre",
    "pourfendaient": "pourfendre",
    "pourfendais": "pourfendre",
    "pourfendait": "pourfendre",
    "pourfendant": "pourfendre",
    "pourfende": "pourfendre",
    "pourfendent": "pourfendre",
    "pourfendes": "pourfendre",
    "pourfendeurs": "pourfendeur",
    "pourfendez": "pourfendre",
    "pourfendiez": "pourfendre",
    "pourfendions": "pourfendre",
    "pourfendirent": "pourfendre",
    "pourfendis": "pourfendre",
    "pourfendisse": "pourfendre",
    "pourfendissent": "pourfendre",
    "pourfendisses": "pourfendre",
    "pourfendissiez": "pourfendre",
    "pourfendissions": "pourfendre",
    "pourfendit": "pourfendre",
    "pourfendons": "pourfendre",
    "pourfendra": "pourfendre",
    "pourfendrai": "pourfendre",
    "pourfendraient": "pourfendre",
    "pourfendrais": "pourfendre",
    "pourfendrait": "pourfendre",
    "pourfendras": "pourfendre",
    "pourfendrez": "pourfendre",
    "pourfendriez": "pourfendre",
    "pourfendrions": "pourfendre",
    "pourfendrons": "pourfendre",
    "pourfendront": "pourfendre",
    "pourfends": "pourfendre",
    "pourfendu": "pourfendre",
    "pourfendue": "pourfendre",
    "pourfendues": "pourfendre",
    "pourfendus": "pourfendre",
    "pourfendîmes": "pourfendre",
    "pourfendît": "pourfendre",
    "pourfendîtes": "pourfendre",
    "pourliches": "pourliche",
    "pourlèche": "pourlécher",
    "pourlèchent": "pourlécher",
    "pourlèches": "pourlécher",
    "pourlécha": "pourlécher",
    "pourléchai": "pourlécher",
    "pourléchaient": "pourlécher",
    "pourléchais": "pourlécher",
    "pourléchait": "pourlécher",
    "pourléchant": "pourlécher",
    "pourléchas": "pourlécher",
    "pourléchasse": "pourlécher",
    "pourléchassent": "pourlécher",
    "pourléchasses": "pourlécher",
    "pourléchassiez": "pourlécher",
    "pourléchassions": "pourlécher",
    "pourléchera": "pourlécher",
    "pourlécherai": "pourlécher",
    "pourlécheraient": "pourlécher",
    "pourlécherais": "pourlécher",
    "pourlécherait": "pourlécher",
    "pourlécheras": "pourlécher",
    "pourlécherez": "pourlécher",
    "pourlécheriez": "pourlécher",
    "pourlécherions": "pourlécher",
    "pourlécherons": "pourlécher",
    "pourlécheront": "pourlécher",
    "pourléchez": "pourlécher",
    "pourléchiez": "pourlécher",
    "pourléchions": "pourlécher",
    "pourléchons": "pourlécher",
    "pourléchâmes": "pourlécher",
    "pourléchât": "pourlécher",
    "pourléchâtes": "pourlécher",
    "pourléchèrent": "pourlécher",
    "pourléché": "pourlécher",
    "pourléchée": "pourlécher",
    "pourléchées": "pourlécher",
    "pourléchés": "pourlécher",
    "pourparlers": "pourparler",
    "pourpiers": "pourpier",
    "pourpoints": "pourpoint",
    "pourpres": "pourpre",
    "pourprée": "pourprer",
    "pourprées": "pourprer",
    "pourra": "pouvoir",
    "pourrai": "pouvoir",
    "pourraient": "pouvoir",
    "pourrais": "pouvoir",
    "pourrait": "pouvoir",
    "pourras": "pouvoir",
    "pourrez": "pouvoir",
    "pourri": "pourrir",
    "pourrie": "pourrir",
    "pourries": "pourrir",
    "pourriez": "pouvoir",
    "pourrions": "pouvoir",
    "pourrira": "pourrir",
    "pourrirai": "pourrir",
    "pourriraient": "pourrir",
    "pourrirais": "pourrir",
    "pourrirait": "pourrir",
    "pourriras": "pourrir",
    "pourrirent": "pourrir",
    "pourrirez": "pourrir",
    "pourririez": "pourrir",
    "pourririons": "pourrir",
    "pourrirons": "pourrir",
    "pourriront": "pourrir",
    "pourris": "pourrir",
    "pourrissaient": "pourrir",
    "pourrissais": "pourrir",
    "pourrissait": "pourrir",
    "pourrissant": "pourrir",
    "pourrissante": "pourrissant",
    "pourrissantes": "pourrissant",
    "pourrissants": "pourrissant",
    "pourrisse": "pourrir",
    "pourrissements": "pourrissement",
    "pourrissent": "pourrir",
    "pourrisses": "pourrir",
    "pourrissez": "pourrir",
    "pourrissiez": "pourrir",
    "pourrissions": "pourrir",
    "pourrissons": "pourrir",
    "pourrit": "pourrir",
    "pourritures": "pourriture",
    "pourrons": "pouvoir",
    "pourront": "pouvoir",
    "pourrîmes": "pourrir",
    "pourrît": "pourrir",
    "pourrîtes": "pourrir",
    "poursuis": "poursuivre",
    "poursuit": "poursuivre",
    "poursuites": "poursuite",
    "poursuivaient": "poursuivre",
    "poursuivais": "poursuivre",
    "poursuivait": "poursuivre",
    "poursuivant": "poursuivre",
    "poursuivante": "poursuivant",
    "poursuivantes": "poursuivant",
    "poursuivants": "poursuivant",
    "poursuive": "poursuivre",
    "poursuivent": "poursuivre",
    "poursuives": "poursuivre",
    "poursuiveurs": "poursuiveur",
    "poursuivez": "poursuivre",
    "poursuivi": "poursuivre",
    "poursuivie": "poursuivre",
    "poursuivies": "poursuivre",
    "poursuiviez": "poursuivre",
    "poursuivions": "poursuivre",
    "poursuivirent": "poursuivre",
    "poursuivis": "poursuivre",
    "poursuivisse": "poursuivre",
    "poursuivissent": "poursuivre",
    "poursuivisses": "poursuivre",
    "poursuivissiez": "poursuivre",
    "poursuivissions": "poursuivre",
    "poursuivit": "poursuivre",
    "poursuivons": "poursuivre",
    "poursuivra": "poursuivre",
    "poursuivrai": "poursuivre",
    "poursuivraient": "poursuivre",
    "poursuivrais": "poursuivre",
    "poursuivrait": "poursuivre",
    "poursuivras": "poursuivre",
    "poursuivrez": "poursuivre",
    "poursuivriez": "poursuivre",
    "poursuivrions": "poursuivre",
    "poursuivrons": "poursuivre",
    "poursuivront": "poursuivre",
    "poursuivîmes": "poursuivre",
    "poursuivît": "poursuivre",
    "poursuivîtes": "poursuivre",
    "pourtours": "pourtour",
    "pourvoie": "pourvoir",
    "pourvoient": "pourvoir",
    "pourvoies": "pourvoir",
    "pourvoira": "pourvoir",
    "pourvoirai": "pourvoir",
    "pourvoiraient": "pourvoir",
    "pourvoirais": "pourvoir",
    "pourvoirait": "pourvoir",
    "pourvoiras": "pourvoir",
    "pourvoirez": "pourvoir",
    "pourvoiriez": "pourvoir",
    "pourvoirions": "pourvoir",
    "pourvoirons": "pourvoir",
    "pourvoiront": "pourvoir",
    "pourvois": "pourvoir",
    "pourvoit": "pourvoir",
    "pourvoyaient": "pourvoir",
    "pourvoyais": "pourvoir",
    "pourvoyait": "pourvoir",
    "pourvoyant": "pourvoir",
    "pourvoyeurs": "pourvoyeur",
    "pourvoyeuse": "pourvoyeur",
    "pourvoyeuses": "pourvoyeur",
    "pourvoyez": "pourvoir",
    "pourvoyiez": "pourvoir",
    "pourvoyions": "pourvoir",
    "pourvoyons": "pourvoir",
    "pourvu": "pourvoir",
    "pourvue": "pourvoir",
    "pourvues": "pourvoir",
    "pourvurent": "pourvoir",
    "pourvus": "pourvoir",
    "pourvusse": "pourvoir",
    "pourvussent": "pourvoir",
    "pourvusses": "pourvoir",
    "pourvussiez": "pourvoir",
    "pourvussions": "pourvoir",
    "pourvut": "pourvoir",
    "pourvûmes": "pourvoir",
    "pourvût": "pourvoir",
    "pourvûtes": "pourvoir",
    "pous-de-soie": "pou-de-soie",
    "poussa": "pousser",
    "poussages": "poussage",
    "poussahs": "poussah",
    "poussai": "pousser",
    "poussaient": "pousser",
    "poussais": "pousser",
    "poussait": "pousser",
    "poussant": "pousser",
    "poussas": "pousser",
    "poussasse": "pousser",
    "poussassent": "pousser",
    "poussasses": "pousser",
    "poussassiez": "pousser",
    "poussassions": "pousser",
    "pousse": "pousser",
    "pousse-pieds": "pousse-pied",
    "poussent": "pousser",
    "poussera": "pousser",
    "pousserai": "pousser",
    "pousseraient": "pousser",
    "pousserais": "pousser",
    "pousserait": "pousser",
    "pousseras": "pousser",
    "pousserez": "pousser",
    "pousseriez": "pousser",
    "pousserions": "pousser",
    "pousserons": "pousser",
    "pousseront": "pousser",
    "pousses": "pousser",
    "poussettes": "poussette",
    "pousseurs": "pousseur",
    "poussez": "pousser",
    "poussiers": "poussier",
    "poussiez": "pousser",
    "poussifs": "poussif",
    "poussinières": "poussinière",
    "poussins": "poussin",
    "poussions": "pousser",
    "poussive": "poussif",
    "poussives": "poussif",
    "poussières": "poussière",
    "poussiéreuse": "poussiéreux",
    "poussiéreuses": "poussiéreux",
    "poussons": "pousser",
    "poussâmes": "pousser",
    "poussât": "pousser",
    "poussâtes": "pousser",
    "poussèrent": "pousser",
    "poussé": "pousser",
    "poussée": "pousser",
    "poussées": "pousser",
    "poussés": "pousser",
    "poutrages": "poutrage",
    "poutrelles": "poutrelle",
    "poutres": "poutre",
    "pouts-de-soie": "pout-de-soie",
    "pouvaient": "pouvoir",
    "pouvais": "pouvoir",
    "pouvait": "pouvoir",
    "pouvant": "pouvoir",
    "pouvez": "pouvoir",
    "pouviez": "pouvoir",
    "pouvions": "pouvoir",
    "pouvoirs": "pouvoir",
    "pouvons": "pouvoir",
    "poux": "pou",
    "pouzzolanes": "pouzzolane",
    "poèmes": "poème",
    "poètes": "poète",
    "poésies": "poésie",
    "poétesse": "poète",
    "poétesses": "poète",
    "poétiques": "poétique",
    "poétisait": "poétiser",
    "poétisant": "poétiser",
    "poétise": "poétiser",
    "poétisez": "poétiser",
    "poêla": "poêler",
    "poêlai": "poêler",
    "poêlaient": "poêler",
    "poêlais": "poêler",
    "poêlait": "poêler",
    "poêlant": "poêler",
    "poêlas": "poêler",
    "poêlasse": "poêler",
    "poêlassent": "poêler",
    "poêlasses": "poêler",
    "poêlassiez": "poêler",
    "poêlassions": "poêler",
    "poêle": "poêler",
    "poêlent": "poêler",
    "poêlera": "poêler",
    "poêlerai": "poêler",
    "poêleraient": "poêler",
    "poêlerais": "poêler",
    "poêlerait": "poêler",
    "poêleras": "poêler",
    "poêlerez": "poêler",
    "poêleriez": "poêler",
    "poêlerions": "poêler",
    "poêlerons": "poêler",
    "poêleront": "poêler",
    "poêles": "poêler",
    "poêlez": "poêler",
    "poêliez": "poêler",
    "poêlions": "poêler",
    "poêlons": "poêlon",
    "poêlâmes": "poêler",
    "poêlât": "poêler",
    "poêlâtes": "poêler",
    "poêlèrent": "poêler",
    "poêlé": "poêler",
    "poêlée": "poêler",
    "poêlées": "poêler",
    "poêlés": "poêler",
    "pradelle": "pradel",
    "praesidiums": "praesidium",
    "pragmatiques": "pragmatique",
    "pragmatismes": "pragmatisme",
    "praires": "praire",
    "prairials": "prairial",
    "prairies": "prairie",
    "pralines": "praline",
    "pralinés": "praliner",
    "prandiale": "prandial",
    "prandiales": "prandial",
    "prandiaux": "prandial",
    "praticables": "praticable",
    "praticienne": "praticien",
    "praticiennes": "praticien",
    "praticiens": "praticien",
    "pratiqua": "pratiquer",
    "pratiquai": "pratiquer",
    "pratiquaient": "pratiquer",
    "pratiquais": "pratiquer",
    "pratiquait": "pratiquer",
    "pratiquant": "pratiquer",
    "pratiquante": "pratiquant",
    "pratiquantes": "pratiquant",
    "pratiquants": "pratiquant",
    "pratiquas": "pratiquer",
    "pratiquasse": "pratiquer",
    "pratiquassent": "pratiquer",
    "pratiquasses": "pratiquer",
    "pratiquassiez": "pratiquer",
    "pratiquassions": "pratiquer",
    "pratique": "pratiquer",
    "pratiquent": "pratiquer",
    "pratiquera": "pratiquer",
    "pratiquerai": "pratiquer",
    "pratiqueraient": "pratiquer",
    "pratiquerais": "pratiquer",
    "pratiquerait": "pratiquer",
    "pratiqueras": "pratiquer",
    "pratiquerez": "pratiquer",
    "pratiqueriez": "pratiquer",
    "pratiquerions": "pratiquer",
    "pratiquerons": "pratiquer",
    "pratiqueront": "pratiquer",
    "pratiques": "pratiquer",
    "pratiquez": "pratiquer",
    "pratiquiez": "pratiquer",
    "pratiquions": "pratiquer",
    "pratiquons": "pratiquer",
    "pratiquâmes": "pratiquer",
    "pratiquât": "pratiquer",
    "pratiquâtes": "pratiquer",
    "pratiquèrent": "pratiquer",
    "pratiqué": "pratiquer",
    "pratiquée": "pratiquer",
    "pratiquées": "pratiquer",
    "pratiqués": "pratiquer",
    "premiers": "premier",
    "premiers-nés": "premier-né",
    "première": "premier",
    "première-née": "premier-né",
    "premières": "premier",
    "premières-nées": "premier-né",
    "prenables": "prenable",
    "prenaient": "prendre",
    "prenais": "prendre",
    "prenait": "prendre",
    "prenant": "prendre",
    "prenante": "prenant",
    "prenantes": "prenant",
    "prenants": "prenant",
    "prend": "prendre",
    "prendra": "prendre",
    "prendrai": "prendre",
    "prendraient": "prendre",
    "prendrais": "prendre",
    "prendrait": "prendre",
    "prendras": "prendre",
    "prendrez": "prendre",
    "prendriez": "prendre",
    "prendrions": "prendre",
    "prendrons": "prendre",
    "prendront": "prendre",
    "prends": "prendre",
    "preneurs": "preneur",
    "preneuse": "preneur",
    "preneuses": "preneur",
    "prenez": "prendre",
    "preniez": "prendre",
    "prenions": "prendre",
    "prenne": "prendre",
    "prennent": "prendre",
    "prennes": "prendre",
    "prenons": "prendre",
    "presbytes": "presbyte",
    "presbyties": "presbytie",
    "presbytères": "presbytère",
    "presbytérale": "presbytéral",
    "presbytérales": "presbytéral",
    "presbytéraux": "presbytéral",
    "presbytérienne": "presbytérien",
    "presbytériennes": "presbytérien",
    "presciences": "prescience",
    "presciente": "prescient",
    "prescripteurs": "prescripteur",
    "prescriptions": "prescription",
    "prescrira": "prescrire",
    "prescrirai": "prescrire",
    "prescriraient": "prescrire",
    "prescrirais": "prescrire",
    "prescrirait": "prescrire",
    "prescriras": "prescrire",
    "prescrirez": "prescrire",
    "prescririez": "prescrire",
    "prescririons": "prescrire",
    "prescrirons": "prescrire",
    "prescriront": "prescrire",
    "prescris": "prescrire",
    "prescrit": "prescrire",
    "prescrite": "prescrire",
    "prescrites": "prescrire",
    "prescrits": "prescrire",
    "prescrivaient": "prescrire",
    "prescrivais": "prescrire",
    "prescrivait": "prescrire",
    "prescrivant": "prescrire",
    "prescrive": "prescrire",
    "prescrivent": "prescrire",
    "prescrives": "prescrire",
    "prescrivez": "prescrire",
    "prescriviez": "prescrire",
    "prescrivions": "prescrire",
    "prescrivirent": "prescrire",
    "prescrivis": "prescrire",
    "prescrivisse": "prescrire",
    "prescrivissent": "prescrire",
    "prescrivisses": "prescrire",
    "prescrivissiez": "prescrire",
    "prescrivissions": "prescrire",
    "prescrivit": "prescrire",
    "prescrivons": "prescrire",
    "prescrivîmes": "prescrire",
    "prescrivît": "prescrire",
    "prescrivîtes": "prescrire",
    "presqu'": "presque",
    "presqu'îles": "presqu'île",
    "pressa": "presser",
    "pressai": "presser",
    "pressaient": "presser",
    "pressais": "presser",
    "pressait": "presser",
    "pressant": "presser",
    "pressante": "pressant",
    "pressantes": "pressant",
    "pressants": "pressant",
    "pressas": "presser",
    "pressasse": "presser",
    "pressassent": "presser",
    "pressasses": "presser",
    "pressassiez": "presser",
    "pressassions": "presser",
    "presse": "presser",
    "presse-citrons": "presse-citron",
    "presse-papiers": "presse-papier",
    "pressements": "pressement",
    "pressens": "pressentir",
    "pressent": "presser",
    "pressentaient": "pressentir",
    "pressentais": "pressentir",
    "pressentait": "pressentir",
    "pressentant": "pressentir",
    "pressente": "pressentir",
    "pressentent": "pressentir",
    "pressentes": "pressentir",
    "pressentez": "pressentir",
    "pressenti": "pressentir",
    "pressentie": "pressentir",
    "pressenties": "pressentir",
    "pressentiez": "pressentir",
    "pressentiments": "pressentiment",
    "pressentions": "pressentir",
    "pressentira": "pressentir",
    "pressentirai": "pressentir",
    "pressentiraient": "pressentir",
    "pressentirais": "pressentir",
    "pressentirait": "pressentir",
    "pressentiras": "pressentir",
    "pressentirent": "pressentir",
    "pressentirez": "pressentir",
    "pressentiriez": "pressentir",
    "pressentirions": "pressentir",
    "pressentirons": "pressentir",
    "pressentiront": "pressentir",
    "pressentis": "pressentir",
    "pressentisse": "pressentir",
    "pressentissent": "pressentir",
    "pressentisses": "pressentir",
    "pressentissiez": "pressentir",
    "pressentissions": "pressentir",
    "pressentit": "pressentir",
    "pressentons": "pressentir",
    "pressentîmes": "pressentir",
    "pressentît": "pressentir",
    "pressentîtes": "pressentir",
    "pressera": "presser",
    "presserai": "presser",
    "presseraient": "presser",
    "presserais": "presser",
    "presserait": "presser",
    "presseras": "presser",
    "presserez": "presser",
    "presseriez": "presser",
    "presserions": "presser",
    "presserons": "presser",
    "presseront": "presser",
    "presses": "presser",
    "pressez": "presser",
    "pressiez": "presser",
    "pressings": "pressing",
    "pressionnée": "pressionné",
    "pressions": "pression",
    "pressoirs": "pressoir",
    "pressons": "presser",
    "pressura": "pressurer",
    "pressurai": "pressurer",
    "pressuraient": "pressurer",
    "pressurais": "pressurer",
    "pressurait": "pressurer",
    "pressurant": "pressurer",
    "pressuras": "pressurer",
    "pressurasse": "pressurer",
    "pressurassent": "pressurer",
    "pressurasses": "pressurer",
    "pressurassiez": "pressurer",
    "pressurassions": "pressurer",
    "pressure": "pressurer",
    "pressurent": "pressurer",
    "pressurera": "pressurer",
    "pressurerai": "pressurer",
    "pressureraient": "pressurer",
    "pressurerais": "pressurer",
    "pressurerait": "pressurer",
    "pressureras": "pressurer",
    "pressurerez": "pressurer",
    "pressureriez": "pressurer",
    "pressurerions": "pressurer",
    "pressurerons": "pressurer",
    "pressureront": "pressurer",
    "pressures": "pressurer",
    "pressurez": "pressurer",
    "pressuriez": "pressurer",
    "pressurions": "pressurer",
    "pressurisa": "pressuriser",
    "pressurisai": "pressuriser",
    "pressurisaient": "pressuriser",
    "pressurisais": "pressuriser",
    "pressurisait": "pressuriser",
    "pressurisant": "pressuriser",
    "pressurisas": "pressuriser",
    "pressurisasse": "pressuriser",
    "pressurisassent": "pressuriser",
    "pressurisasses": "pressuriser",
    "pressurisassiez": "pressuriser",
    "pressurisassions": "pressuriser",
    "pressurise": "pressuriser",
    "pressurisent": "pressuriser",
    "pressurisera": "pressuriser",
    "pressuriserai": "pressuriser",
    "pressuriseraient": "pressuriser",
    "pressuriserais": "pressuriser",
    "pressuriserait": "pressuriser",
    "pressuriseras": "pressuriser",
    "pressuriserez": "pressuriser",
    "pressuriseriez": "pressuriser",
    "pressuriserions": "pressuriser",
    "pressuriserons": "pressuriser",
    "pressuriseront": "pressuriser",
    "pressurises": "pressuriser",
    "pressurisez": "pressuriser",
    "pressurisiez": "pressuriser",
    "pressurisions": "pressuriser",
    "pressurisons": "pressuriser",
    "pressurisâmes": "pressuriser",
    "pressurisât": "pressuriser",
    "pressurisâtes": "pressuriser",
    "pressurisèrent": "pressuriser",
    "pressurisé": "pressuriser",
    "pressurisée": "pressuriser",
    "pressurisées": "pressuriser",
    "pressurisés": "pressuriser",
    "pressurons": "pressurer",
    "pressurâmes": "pressurer",
    "pressurât": "pressurer",
    "pressurâtes": "pressurer",
    "pressurèrent": "pressurer",
    "pressuré": "pressurer",
    "pressurée": "pressurer",
    "pressurées": "pressurer",
    "pressurés": "pressurer",
    "pressâmes": "presser",
    "pressât": "presser",
    "pressâtes": "presser",
    "pressèrent": "presser",
    "pressé": "presser",
    "pressée": "presser",
    "pressées": "presser",
    "pressés": "presser",
    "prestances": "prestance",
    "prestataires": "prestataire",
    "prestations": "prestation",
    "prestes": "preste",
    "prestidigitateurs": "prestidigitateur",
    "prestidigitations": "prestidigitation",
    "prestidigitatrice": "prestidigitateur",
    "prestidigitatrices": "prestidigitateur",
    "prestiges": "prestige",
    "prestigieuse": "prestigieux",
    "prestigieuses": "prestigieux",
    "preuves": "preuve",
    "pria": "prier",
    "priai": "prier",
    "priaient": "prier",
    "priais": "prier",
    "priait": "prier",
    "priant": "prier",
    "priapiques": "priapique",
    "prias": "prier",
    "priasse": "prier",
    "priassent": "prier",
    "priasses": "prier",
    "priassiez": "prier",
    "priassions": "prier",
    "prie": "prier",
    "prient": "prier",
    "priera": "prier",
    "prierai": "prier",
    "prieraient": "prier",
    "prierais": "prier",
    "prierait": "prier",
    "prieras": "prier",
    "prierez": "prier",
    "prieriez": "prier",
    "prierions": "prier",
    "prierons": "prier",
    "prieront": "prier",
    "pries": "prier",
    "prieure": "prieur",
    "prieures": "prieur",
    "prieurs": "prieur",
    "prieurés": "prieuré",
    "priez": "prier",
    "priiez": "prier",
    "priions": "prier",
    "prima": "primer",
    "primables": "primable",
    "primai": "primer",
    "primaient": "primer",
    "primaires": "primaire",
    "primais": "primer",
    "primait": "primer",
    "primale": "primal",
    "primant": "primer",
    "primas": "primer",
    "primasse": "primer",
    "primassent": "primer",
    "primasses": "primer",
    "primassiez": "primer",
    "primassions": "primer",
    "primates": "primate",
    "primats": "primat",
    "primautés": "primauté",
    "prime": "primer",
    "priment": "primer",
    "primera": "primer",
    "primerai": "primer",
    "primeraient": "primer",
    "primerais": "primer",
    "primerait": "primer",
    "primeras": "primer",
    "primerez": "primer",
    "primeriez": "primer",
    "primerions": "primer",
    "primerons": "primer",
    "primeront": "primer",
    "primeroses": "primerose",
    "primes": "primer",
    "primesautiers": "primesautier",
    "primesautière": "primesautier",
    "primesautières": "primesautier",
    "primeurs": "primeur",
    "primevères": "primevère",
    "primez": "primer",
    "primiez": "primer",
    "primions": "primer",
    "primipares": "primipare",
    "primitifs": "primitif",
    "primitive": "primitif",
    "primitives": "primitif",
    "primitivismes": "primitivisme",
    "primo-infections": "primo-infection",
    "primogénitures": "primogéniture",
    "primons": "primer",
    "primordiale": "primordial",
    "primordiales": "primordial",
    "primordiaux": "primordial",
    "primâmes": "primer",
    "primât": "primer",
    "primâtes": "primer",
    "primèrent": "primer",
    "primé": "primer",
    "primée": "primer",
    "primées": "primer",
    "primés": "primer",
    "princes": "prince",
    "princesse": "prince",
    "princesses": "prince",
    "princiers": "princier",
    "principale": "principal",
    "principales": "principal",
    "principautés": "principauté",
    "principaux": "principal",
    "principes": "principe",
    "princière": "princier",
    "princières": "princier",
    "printaniers": "printanier",
    "printanière": "printanier",
    "printanières": "printanier",
    "prions": "prion",
    "prioritaires": "prioritaire",
    "priorités": "priorité",
    "prirent": "prendre",
    "pris": "prendre",
    "prisa": "priser",
    "prisai": "priser",
    "prisaient": "priser",
    "prisais": "priser",
    "prisait": "priser",
    "prisant": "priser",
    "prisas": "priser",
    "prisasse": "priser",
    "prisassent": "priser",
    "prisasses": "priser",
    "prisassiez": "priser",
    "prisassions": "priser",
    "prise": "priser",
    "prisent": "priser",
    "prisera": "priser",
    "priserai": "priser",
    "priseraient": "priser",
    "priserais": "priser",
    "priserait": "priser",
    "priseras": "priser",
    "priserez": "priser",
    "priseriez": "priser",
    "priserions": "priser",
    "priserons": "priser",
    "priseront": "priser",
    "prises": "priser",
    "priseurs": "priseur",
    "prisez": "priser",
    "prisiez": "priser",
    "prisions": "priser",
    "prismatiques": "prismatique",
    "prismes": "prisme",
    "prisonniers": "prisonnier",
    "prisonnière": "prisonnier",
    "prisonnières": "prisonnier",
    "prisons": "prison",
    "prisons-écoles": "prisons-école",
    "prisse": "prendre",
    "prissent": "prendre",
    "prisses": "prendre",
    "prissiez": "prendre",
    "prissions": "prendre",
    "prisâmes": "priser",
    "prisât": "priser",
    "prisâtes": "priser",
    "prisèrent": "priser",
    "prisé": "priser",
    "prisée": "priser",
    "prisées": "priser",
    "prisés": "priser",
    "prit": "prendre",
    "priva": "priver",
    "privai": "priver",
    "privaient": "priver",
    "privais": "priver",
    "privait": "priver",
    "privant": "priver",
    "privas": "priver",
    "privasse": "priver",
    "privassent": "priver",
    "privasses": "priver",
    "privassiez": "priver",
    "privassions": "priver",
    "privatdocents": "privatdocent",
    "privatdozents": "privatdozent",
    "privatifs": "privatif",
    "privations": "privation",
    "privatisa": "privatiser",
    "privatisai": "privatiser",
    "privatisaient": "privatiser",
    "privatisais": "privatiser",
    "privatisait": "privatiser",
    "privatisant": "privatiser",
    "privatisas": "privatiser",
    "privatisasse": "privatiser",
    "privatisassent": "privatiser",
    "privatisasses": "privatiser",
    "privatisassiez": "privatiser",
    "privatisassions": "privatiser",
    "privatisations": "privatisation",
    "privatise": "privatiser",
    "privatisent": "privatiser",
    "privatisera": "privatiser",
    "privatiserai": "privatiser",
    "privatiseraient": "privatiser",
    "privatiserais": "privatiser",
    "privatiserait": "privatiser",
    "privatiseras": "privatiser",
    "privatiserez": "privatiser",
    "privatiseriez": "privatiser",
    "privatiserions": "privatiser",
    "privatiserons": "privatiser",
    "privatiseront": "privatiser",
    "privatises": "privatiser",
    "privatisez": "privatiser",
    "privatisiez": "privatiser",
    "privatisions": "privatiser",
    "privatisons": "privatiser",
    "privatisâmes": "privatiser",
    "privatisât": "privatiser",
    "privatisâtes": "privatiser",
    "privatisèrent": "privatiser",
    "privatisé": "privatiser",
    "privatisée": "privatiser",
    "privatisées": "privatiser",
    "privatisés": "privatiser",
    "privative": "privatif",
    "privatives": "privatif",
    "privautés": "privauté",
    "prive": "priver",
    "privent": "priver",
    "privera": "priver",
    "priverai": "priver",
    "priveraient": "priver",
    "priverais": "priver",
    "priverait": "priver",
    "priveras": "priver",
    "priverez": "priver",
    "priveriez": "priver",
    "priverions": "priver",
    "priverons": "priver",
    "priveront": "priver",
    "prives": "priver",
    "privez": "priver",
    "priviez": "priver",
    "privilèges": "privilège",
    "privilégia": "privilégier",
    "privilégiai": "privilégier",
    "privilégiaient": "privilégier",
    "privilégiais": "privilégier",
    "privilégiait": "privilégier",
    "privilégiant": "privilégier",
    "privilégias": "privilégier",
    "privilégiasse": "privilégier",
    "privilégiassent": "privilégier",
    "privilégiasses": "privilégier",
    "privilégiassiez": "privilégier",
    "privilégiassions": "privilégier",
    "privilégie": "privilégier",
    "privilégient": "privilégier",
    "privilégiera": "privilégier",
    "privilégierai": "privilégier",
    "privilégieraient": "privilégier",
    "privilégierais": "privilégier",
    "privilégierait": "privilégier",
    "privilégieras": "privilégier",
    "privilégierez": "privilégier",
    "privilégieriez": "privilégier",
    "privilégierions": "privilégier",
    "privilégierons": "privilégier",
    "privilégieront": "privilégier",
    "privilégies": "privilégier",
    "privilégiez": "privilégier",
    "privilégiiez": "privilégier",
    "privilégiions": "privilégier",
    "privilégions": "privilégier",
    "privilégiâmes": "privilégier",
    "privilégiât": "privilégier",
    "privilégiâtes": "privilégier",
    "privilégièrent": "privilégier",
    "privilégié": "privilégier",
    "privilégiée": "privilégier",
    "privilégiées": "privilégier",
    "privilégiés": "privilégier",
    "privions": "priver",
    "privons": "priver",
    "privâmes": "priver",
    "privât": "priver",
    "privâtes": "priver",
    "privèrent": "priver",
    "privé": "priver",
    "privée": "priver",
    "privées": "priver",
    "privés": "priver",
    "priâmes": "prier",
    "priât": "prier",
    "priâtes": "prier",
    "prièrent": "prier",
    "prières": "prière",
    "prié": "prier",
    "priée": "prier",
    "priées": "prier",
    "priés": "prier",
    "probabilistes": "probabiliste",
    "probabilités": "probabilité",
    "probables": "probable",
    "probante": "probant",
    "probantes": "probant",
    "probants": "probant",
    "probatoires": "probatoire",
    "probes": "probe",
    "probités": "probité",
    "problocs": "probloc",
    "probloques": "probloque",
    "problèmes": "problème",
    "problématiques": "problématique",
    "proboscidiens": "proboscidien",
    "processeurs": "processeur",
    "processionnaient": "processionner",
    "processionnaires": "processionnaire",
    "processionnant": "processionner",
    "processionnelle": "processionnel",
    "processionnelles": "processionnel",
    "processions": "procession",
    "processuelle": "processuel",
    "processuelles": "processuel",
    "processuels": "processuel",
    "prochaine": "prochain",
    "prochaines": "prochain",
    "prochains": "prochain",
    "proches": "proche",
    "prochinoise": "prochinois",
    "proclama": "proclamer",
    "proclamai": "proclamer",
    "proclamaient": "proclamer",
    "proclamais": "proclamer",
    "proclamait": "proclamer",
    "proclamant": "proclamer",
    "proclamas": "proclamer",
    "proclamasse": "proclamer",
    "proclamassent": "proclamer",
    "proclamasses": "proclamer",
    "proclamassiez": "proclamer",
    "proclamassions": "proclamer",
    "proclamations": "proclamation",
    "proclamatrices": "proclamateur",
    "proclame": "proclamer",
    "proclament": "proclamer",
    "proclamera": "proclamer",
    "proclamerai": "proclamer",
    "proclameraient": "proclamer",
    "proclamerais": "proclamer",
    "proclamerait": "proclamer",
    "proclameras": "proclamer",
    "proclamerez": "proclamer",
    "proclameriez": "proclamer",
    "proclamerions": "proclamer",
    "proclamerons": "proclamer",
    "proclameront": "proclamer",
    "proclames": "proclamer",
    "proclamez": "proclamer",
    "proclamiez": "proclamer",
    "proclamions": "proclamer",
    "proclamons": "proclamer",
    "proclamâmes": "proclamer",
    "proclamât": "proclamer",
    "proclamâtes": "proclamer",
    "proclamèrent": "proclamer",
    "proclamé": "proclamer",
    "proclamée": "proclamer",
    "proclamées": "proclamer",
    "proclamés": "proclamer",
    "proconsulats": "proconsulat",
    "proconsuls": "proconsul",
    "procréa": "procréer",
    "procréai": "procréer",
    "procréaient": "procréer",
    "procréais": "procréer",
    "procréait": "procréer",
    "procréant": "procréer",
    "procréas": "procréer",
    "procréasse": "procréer",
    "procréassent": "procréer",
    "procréasses": "procréer",
    "procréassiez": "procréer",
    "procréassions": "procréer",
    "procréateurs": "procréateur",
    "procréations": "procréation",
    "procréative": "procréatif",
    "procréatrice": "procréateur",
    "procréatrices": "procréateur",
    "procrée": "procréer",
    "procréent": "procréer",
    "procréera": "procréer",
    "procréerai": "procréer",
    "procréeraient": "procréer",
    "procréerais": "procréer",
    "procréerait": "procréer",
    "procréeras": "procréer",
    "procréerez": "procréer",
    "procréeriez": "procréer",
    "procréerions": "procréer",
    "procréerons": "procréer",
    "procréeront": "procréer",
    "procrées": "procréer",
    "procréez": "procréer",
    "procréiez": "procréer",
    "procréions": "procréer",
    "procréons": "procréer",
    "procréâmes": "procréer",
    "procréât": "procréer",
    "procréâtes": "procréer",
    "procréèrent": "procréer",
    "procréé": "procréer",
    "procréée": "procréer",
    "procréées": "procréer",
    "procréés": "procréer",
    "procs": "proc",
    "proctologues": "proctologue",
    "procura": "procurer",
    "procurai": "procurer",
    "procuraient": "procurer",
    "procurais": "procurer",
    "procurait": "procurer",
    "procurant": "procurer",
    "procuras": "procurer",
    "procurasse": "procurer",
    "procurassent": "procurer",
    "procurasses": "procurer",
    "procurassiez": "procurer",
    "procurassions": "procurer",
    "procurateurs": "procurateur",
    "procuraties": "procuratie",
    "procurations": "procuration",
    "procuratrice": "procurateur",
    "procure": "procurer",
    "procurent": "procurer",
    "procurera": "procurer",
    "procurerai": "procurer",
    "procureraient": "procurer",
    "procurerais": "procurer",
    "procurerait": "procurer",
    "procureras": "procurer",
    "procurerez": "procurer",
    "procureriez": "procurer",
    "procurerions": "procurer",
    "procurerons": "procurer",
    "procureront": "procurer",
    "procures": "procurer",
    "procureurs": "procureur",
    "procureuse": "procureur",
    "procureuses": "procureur",
    "procurez": "procurer",
    "procuriez": "procurer",
    "procurions": "procurer",
    "procurons": "procurer",
    "procurâmes": "procurer",
    "procurât": "procurer",
    "procurâtes": "procurer",
    "procurèrent": "procurer",
    "procuré": "procurer",
    "procurée": "procurer",
    "procurées": "procurer",
    "procurés": "procurer",
    "procède": "procéder",
    "procèdent": "procéder",
    "procèdes": "procéder",
    "procès-verbaux": "procès-verbal",
    "procéda": "procéder",
    "procédai": "procéder",
    "procédaient": "procéder",
    "procédais": "procéder",
    "procédait": "procéder",
    "procédant": "procéder",
    "procédas": "procéder",
    "procédasse": "procéder",
    "procédassent": "procéder",
    "procédasses": "procéder",
    "procédassiez": "procéder",
    "procédassions": "procéder",
    "procédera": "procéder",
    "procéderai": "procéder",
    "procéderaient": "procéder",
    "procéderais": "procéder",
    "procéderait": "procéder",
    "procéderas": "procéder",
    "procéderez": "procéder",
    "procéderiez": "procéder",
    "procéderions": "procéder",
    "procéderons": "procéder",
    "procéderont": "procéder",
    "procédez": "procéder",
    "procédiez": "procéder",
    "procédions": "procéder",
    "procédons": "procéder",
    "procédurale": "procédural",
    "procédurales": "procédural",
    "procéduraux": "procédural",
    "procédures": "procédure",
    "procéduriers": "procédurier",
    "procédurière": "procédurier",
    "procédurières": "procédurier",
    "procédâmes": "procéder",
    "procédât": "procéder",
    "procédâtes": "procéder",
    "procédèrent": "procéder",
    "procédé": "procéder",
    "procédés": "procéder",
    "prodigalités": "prodigalité",
    "prodiges": "prodige",
    "prodigieuse": "prodigieux",
    "prodigieuses": "prodigieux",
    "prodigua": "prodiguer",
    "prodiguai": "prodiguer",
    "prodiguaient": "prodiguer",
    "prodiguais": "prodiguer",
    "prodiguait": "prodiguer",
    "prodiguant": "prodiguer",
    "prodiguas": "prodiguer",
    "prodiguasse": "prodiguer",
    "prodiguassent": "prodiguer",
    "prodiguasses": "prodiguer",
    "prodiguassiez": "prodiguer",
    "prodiguassions": "prodiguer",
    "prodigue": "prodiguer",
    "prodiguent": "prodiguer",
    "prodiguera": "prodiguer",
    "prodiguerai": "prodiguer",
    "prodigueraient": "prodiguer",
    "prodiguerais": "prodiguer",
    "prodiguerait": "prodiguer",
    "prodigueras": "prodiguer",
    "prodiguerez": "prodiguer",
    "prodigueriez": "prodiguer",
    "prodiguerions": "prodiguer",
    "prodiguerons": "prodiguer",
    "prodigueront": "prodiguer",
    "prodigues": "prodiguer",
    "prodiguez": "prodiguer",
    "prodiguiez": "prodiguer",
    "prodiguions": "prodiguer",
    "prodiguons": "prodiguer",
    "prodiguâmes": "prodiguer",
    "prodiguât": "prodiguer",
    "prodiguâtes": "prodiguer",
    "prodiguèrent": "prodiguer",
    "prodigué": "prodiguer",
    "prodiguée": "prodiguer",
    "prodiguées": "prodiguer",
    "prodigués": "prodiguer",
    "prodromes": "prodrome",
    "producteurs": "producteur",
    "productifs": "productif",
    "productions": "production",
    "productive": "productif",
    "productives": "productif",
    "productivismes": "productivisme",
    "productivistes": "productiviste",
    "productivités": "productivité",
    "productrice": "producteur",
    "productrices": "producteur",
    "produira": "produire",
    "produirai": "produire",
    "produiraient": "produire",
    "produirais": "produire",
    "produirait": "produire",
    "produiras": "produire",
    "produirez": "produire",
    "produiriez": "produire",
    "produirions": "produire",
    "produirons": "produire",
    "produiront": "produire",
    "produis": "produire",
    "produisaient": "produire",
    "produisais": "produire",
    "produisait": "produire",
    "produisant": "produire",
    "produise": "produire",
    "produisent": "produire",
    "produises": "produire",
    "produisez": "produire",
    "produisiez": "produire",
    "produisions": "produire",
    "produisirent": "produire",
    "produisis": "produire",
    "produisisse": "produire",
    "produisissent": "produire",
    "produisisses": "produire",
    "produisissiez": "produire",
    "produisissions": "produire",
    "produisit": "produire",
    "produisons": "produire",
    "produisîmes": "produire",
    "produisît": "produire",
    "produisîtes": "produire",
    "produit": "produire",
    "produite": "produit",
    "produites": "produit",
    "produits": "produit",
    "profana": "profaner",
    "profanai": "profaner",
    "profanaient": "profaner",
    "profanais": "profaner",
    "profanait": "profaner",
    "profanant": "profaner",
    "profanas": "profaner",
    "profanasse": "profaner",
    "profanassent": "profaner",
    "profanasses": "profaner",
    "profanassiez": "profaner",
    "profanassions": "profaner",
    "profanateurs": "profanateur",
    "profanations": "profanation",
    "profane": "profaner",
    "profanent": "profaner",
    "profanera": "profaner",
    "profanerai": "profaner",
    "profaneraient": "profaner",
    "profanerais": "profaner",
    "profanerait": "profaner",
    "profaneras": "profaner",
    "profanerez": "profaner",
    "profaneriez": "profaner",
    "profanerions": "profaner",
    "profanerons": "profaner",
    "profaneront": "profaner",
    "profanes": "profaner",
    "profanez": "profaner",
    "profaniez": "profaner",
    "profanions": "profaner",
    "profanons": "profaner",
    "profanâmes": "profaner",
    "profanât": "profaner",
    "profanâtes": "profaner",
    "profanèrent": "profaner",
    "profané": "profaner",
    "profanée": "profaner",
    "profanées": "profaner",
    "profanés": "profaner",
    "professa": "professer",
    "professai": "professer",
    "professaient": "professer",
    "professais": "professer",
    "professait": "professer",
    "professant": "professer",
    "professas": "professer",
    "professasse": "professer",
    "professassent": "professer",
    "professasses": "professer",
    "professassiez": "professer",
    "professassions": "professer",
    "professe": "professer",
    "professent": "professer",
    "professera": "professer",
    "professerai": "professer",
    "professeraient": "professer",
    "professerais": "professer",
    "professerait": "professer",
    "professeras": "professer",
    "professerez": "professer",
    "professeriez": "professer",
    "professerions": "professer",
    "professerons": "professer",
    "professeront": "professer",
    "professes": "professer",
    "professeure": "professeur",
    "professeurs": "professeur",
    "professez": "professer",
    "professiez": "professer",
    "professionnalisations": "professionnalisation",
    "professionnalismes": "professionnalisme",
    "professionnelle": "professionnel",
    "professionnelles": "professionnel",
    "professionnels": "professionnel",
    "professions": "profession",
    "professons": "professer",
    "professorale": "professoral",
    "professorales": "professoral",
    "professoraux": "professoral",
    "professâmes": "professer",
    "professât": "professer",
    "professâtes": "professer",
    "professèrent": "professer",
    "professé": "professer",
    "professée": "professer",
    "professées": "professer",
    "professés": "professer",
    "profila": "profiler",
    "profilai": "profiler",
    "profilaient": "profiler",
    "profilais": "profiler",
    "profilait": "profiler",
    "profilant": "profiler",
    "profilas": "profiler",
    "profilasse": "profiler",
    "profilassent": "profiler",
    "profilasses": "profiler",
    "profilassiez": "profiler",
    "profilassions": "profiler",
    "profile": "profiler",
    "profilent": "profiler",
    "profilera": "profiler",
    "profilerai": "profiler",
    "profileraient": "profiler",
    "profilerais": "profiler",
    "profilerait": "profiler",
    "profileras": "profiler",
    "profilerez": "profiler",
    "profileriez": "profiler",
    "profilerions": "profiler",
    "profilerons": "profiler",
    "profileront": "profiler",
    "profiles": "profiler",
    "profileuse": "profileur",
    "profilez": "profiler",
    "profiliez": "profiler",
    "profilions": "profiler",
    "profilons": "profiler",
    "profils": "profil",
    "profilâmes": "profiler",
    "profilât": "profiler",
    "profilâtes": "profiler",
    "profilèrent": "profiler",
    "profilé": "profiler",
    "profilée": "profiler",
    "profilées": "profiler",
    "profilés": "profiler",
    "profita": "profiter",
    "profitables": "profitable",
    "profitai": "profiter",
    "profitaient": "profiter",
    "profitais": "profiter",
    "profitait": "profiter",
    "profitant": "profiter",
    "profitas": "profiter",
    "profitasse": "profiter",
    "profitassent": "profiter",
    "profitasses": "profiter",
    "profitassiez": "profiter",
    "profitassions": "profiter",
    "profite": "profiter",
    "profitent": "profiter",
    "profitera": "profiter",
    "profiterai": "profiter",
    "profiteraient": "profiter",
    "profiterais": "profiter",
    "profiterait": "profiter",
    "profiteras": "profiter",
    "profiterez": "profiter",
    "profiteriez": "profiter",
    "profiterions": "profiter",
    "profiteroles": "profiterole",
    "profiterons": "profiter",
    "profiteront": "profiter",
    "profites": "profiter",
    "profiteurs": "profiteur",
    "profiteuse": "profiteur",
    "profiteuses": "profiteur",
    "profitez": "profiter",
    "profitiez": "profiter",
    "profitions": "profiter",
    "profitons": "profiter",
    "profits": "profit",
    "profitâmes": "profiter",
    "profitât": "profiter",
    "profitâtes": "profiter",
    "profitèrent": "profiter",
    "profité": "profiter",
    "profitée": "profiter",
    "profonde": "profond",
    "profondes": "profond",
    "profondeurs": "profondeur",
    "profonds": "profond",
    "profs": "prof",
    "profuse": "profus",
    "profuses": "profus",
    "profusions": "profusion",
    "profère": "proférer",
    "profèrent": "proférer",
    "profères": "proférer",
    "proféra": "proférer",
    "proférai": "proférer",
    "proféraient": "proférer",
    "proférais": "proférer",
    "proférait": "proférer",
    "proférant": "proférer",
    "proféras": "proférer",
    "proférasse": "proférer",
    "proférassent": "proférer",
    "proférasses": "proférer",
    "proférassiez": "proférer",
    "proférassions": "proférer",
    "proférations": "profération",
    "proférera": "proférer",
    "proférerai": "proférer",
    "proféreraient": "proférer",
    "proférerais": "proférer",
    "proférerait": "proférer",
    "proféreras": "proférer",
    "proférerez": "proférer",
    "proféreriez": "proférer",
    "proférerions": "proférer",
    "proférerons": "proférer",
    "proféreront": "proférer",
    "proférez": "proférer",
    "profériez": "proférer",
    "proférions": "proférer",
    "proférons": "proférer",
    "proférâmes": "proférer",
    "proférât": "proférer",
    "proférâtes": "proférer",
    "proférèrent": "proférer",
    "proféré": "proférer",
    "proférée": "proférer",
    "proférées": "proférer",
    "proférés": "proférer",
    "prognathes": "prognathe",
    "prognathismes": "prognathisme",
    "programma": "programmer",
    "programmables": "programmable",
    "programmai": "programmer",
    "programmaient": "programmer",
    "programmais": "programmer",
    "programmait": "programmer",
    "programmant": "programmer",
    "programmas": "programmer",
    "programmasse": "programmer",
    "programmassent": "programmer",
    "programmasses": "programmer",
    "programmassiez": "programmer",
    "programmassions": "programmer",
    "programmateurs": "programmateur",
    "programmations": "programmation",
    "programmatiques": "programmatique",
    "programmatrice": "programmateur",
    "programmatrices": "programmateur",
    "programme": "programmer",
    "programment": "programmer",
    "programmera": "programmer",
    "programmerai": "programmer",
    "programmeraient": "programmer",
    "programmerais": "programmer",
    "programmerait": "programmer",
    "programmeras": "programmer",
    "programmerez": "programmer",
    "programmeriez": "programmer",
    "programmerions": "programmer",
    "programmerons": "programmer",
    "programmeront": "programmer",
    "programmes": "programmer",
    "programmes-cadres": "programme-cadre",
    "programmeurs": "programmeur",
    "programmeuse": "programmeur",
    "programmez": "programmer",
    "programmiez": "programmer",
    "programmions": "programmer",
    "programmons": "programmer",
    "programmâmes": "programmer",
    "programmât": "programmer",
    "programmâtes": "programmer",
    "programmèrent": "programmer",
    "programmé": "programmer",
    "programmée": "programmer",
    "programmées": "programmer",
    "programmés": "programmer",
    "progressa": "progresser",
    "progressai": "progresser",
    "progressaient": "progresser",
    "progressais": "progresser",
    "progressait": "progresser",
    "progressant": "progresser",
    "progressas": "progresser",
    "progressasse": "progresser",
    "progressassent": "progresser",
    "progressasses": "progresser",
    "progressassiez": "progresser",
    "progressassions": "progresser",
    "progresse": "progresser",
    "progressent": "progresser",
    "progressera": "progresser",
    "progresserai": "progresser",
    "progresseraient": "progresser",
    "progresserais": "progresser",
    "progresserait": "progresser",
    "progresseras": "progresser",
    "progresserez": "progresser",
    "progresseriez": "progresser",
    "progresserions": "progresser",
    "progresserons": "progresser",
    "progresseront": "progresser",
    "progresses": "progresser",
    "progressez": "progresser",
    "progressiez": "progresser",
    "progressifs": "progressif",
    "progressions": "progression",
    "progressistes": "progressiste",
    "progressive": "progressif",
    "progressives": "progressif",
    "progressons": "progresser",
    "progressâmes": "progresser",
    "progressât": "progresser",
    "progressâtes": "progresser",
    "progressèrent": "progresser",
    "progressé": "progresser",
    "progressée": "progresser",
    "progénitures": "progéniture",
    "prohiba": "prohiber",
    "prohibai": "prohiber",
    "prohibaient": "prohiber",
    "prohibais": "prohiber",
    "prohibait": "prohiber",
    "prohibant": "prohiber",
    "prohibas": "prohiber",
    "prohibasse": "prohiber",
    "prohibassent": "prohiber",
    "prohibasses": "prohiber",
    "prohibassiez": "prohiber",
    "prohibassions": "prohiber",
    "prohibe": "prohiber",
    "prohibent": "prohiber",
    "prohibera": "prohiber",
    "prohiberai": "prohiber",
    "prohiberaient": "prohiber",
    "prohiberais": "prohiber",
    "prohiberait": "prohiber",
    "prohiberas": "prohiber",
    "prohiberez": "prohiber",
    "prohiberiez": "prohiber",
    "prohiberions": "prohiber",
    "prohiberons": "prohiber",
    "prohiberont": "prohiber",
    "prohibes": "prohiber",
    "prohibez": "prohiber",
    "prohibiez": "prohiber",
    "prohibions": "prohiber",
    "prohibitifs": "prohibitif",
    "prohibitionnismes": "prohibitionnisme",
    "prohibitions": "prohibition",
    "prohibitive": "prohibitif",
    "prohibitives": "prohibitif",
    "prohibons": "prohiber",
    "prohibâmes": "prohiber",
    "prohibât": "prohiber",
    "prohibâtes": "prohiber",
    "prohibèrent": "prohiber",
    "prohibé": "prohiber",
    "prohibée": "prohiber",
    "prohibées": "prohiber",
    "prohibés": "prohiber",
    "proies": "proie",
    "projecteurs": "projecteur",
    "projectiles": "projectile",
    "projectionnistes": "projectionniste",
    "projections": "projection",
    "projeta": "projeter",
    "projetai": "projeter",
    "projetaient": "projeter",
    "projetais": "projeter",
    "projetait": "projeter",
    "projetant": "projeter",
    "projetas": "projeter",
    "projetasse": "projeter",
    "projetassent": "projeter",
    "projetasses": "projeter",
    "projetassiez": "projeter",
    "projetassions": "projeter",
    "projetez": "projeter",
    "projetiez": "projeter",
    "projetions": "projeter",
    "projetons": "projeter",
    "projets": "projet",
    "projette": "projeter",
    "projettent": "projeter",
    "projettera": "projeter",
    "projetterai": "projeter",
    "projetteraient": "projeter",
    "projetterais": "projeter",
    "projetterait": "projeter",
    "projetteras": "projeter",
    "projetterez": "projeter",
    "projetteriez": "projeter",
    "projetterions": "projeter",
    "projetterons": "projeter",
    "projetteront": "projeter",
    "projettes": "projeter",
    "projetâmes": "projeter",
    "projetât": "projeter",
    "projetâtes": "projeter",
    "projetèrent": "projeter",
    "projeté": "projeter",
    "projetée": "projeter",
    "projetées": "projeter",
    "projetés": "projeter",
    "projos": "projo",
    "prolepses": "prolepse",
    "prolifiques": "prolifique",
    "prolifère": "proliférer",
    "prolifèrent": "proliférer",
    "prolifères": "proliférer",
    "proliféra": "proliférer",
    "proliférai": "proliférer",
    "proliféraient": "proliférer",
    "proliférais": "proliférer",
    "proliférait": "proliférer",
    "proliférant": "proliférer",
    "proliférante": "proliférant",
    "proliférantes": "proliférant",
    "proliférants": "proliférant",
    "proliféras": "proliférer",
    "proliférasse": "proliférer",
    "proliférassent": "proliférer",
    "proliférasses": "proliférer",
    "proliférassiez": "proliférer",
    "proliférassions": "proliférer",
    "proliférations": "prolifération",
    "proliférera": "proliférer",
    "proliférerai": "proliférer",
    "proliféreraient": "proliférer",
    "proliférerais": "proliférer",
    "proliférerait": "proliférer",
    "proliféreras": "proliférer",
    "proliférerez": "proliférer",
    "proliféreriez": "proliférer",
    "proliférerions": "proliférer",
    "proliférerons": "proliférer",
    "proliféreront": "proliférer",
    "proliférez": "proliférer",
    "prolifériez": "proliférer",
    "proliférions": "proliférer",
    "proliférons": "proliférer",
    "proliférâmes": "proliférer",
    "proliférât": "proliférer",
    "proliférâtes": "proliférer",
    "proliférèrent": "proliférer",
    "proliféré": "proliférer",
    "prolixes": "prolixe",
    "prologues": "prologue",
    "prolongations": "prolongation",
    "prolonge": "prolonger",
    "prolongea": "prolonger",
    "prolongeai": "prolonger",
    "prolongeaient": "prolonger",
    "prolongeais": "prolonger",
    "prolongeait": "prolonger",
    "prolongeant": "prolonger",
    "prolongeas": "prolonger",
    "prolongeasse": "prolonger",
    "prolongeassent": "prolonger",
    "prolongeasses": "prolonger",
    "prolongeassiez": "prolonger",
    "prolongeassions": "prolonger",
    "prolongements": "prolongement",
    "prolongent": "prolonger",
    "prolongeons": "prolonger",
    "prolongera": "prolonger",
    "prolongerai": "prolonger",
    "prolongeraient": "prolonger",
    "prolongerais": "prolonger",
    "prolongerait": "prolonger",
    "prolongeras": "prolonger",
    "prolongerez": "prolonger",
    "prolongeriez": "prolonger",
    "prolongerions": "prolonger",
    "prolongerons": "prolonger",
    "prolongeront": "prolonger",
    "prolonges": "prolonger",
    "prolongez": "prolonger",
    "prolongeâmes": "prolonger",
    "prolongeât": "prolonger",
    "prolongeâtes": "prolonger",
    "prolongiez": "prolonger",
    "prolongions": "prolonger",
    "prolongèrent": "prolonger",
    "prolongé": "prolonger",
    "prolongée": "prolonger",
    "prolongées": "prolonger",
    "prolongés": "prolonger",
    "prolos": "prolo",
    "prolétaires": "prolétaire",
    "prolétariats": "prolétariat",
    "prolétarienne": "prolétarien",
    "prolétariennes": "prolétarien",
    "prolétariens": "prolétarien",
    "promena": "promener",
    "promenades": "promenade",
    "promenai": "promener",
    "promenaient": "promener",
    "promenais": "promener",
    "promenait": "promener",
    "promenant": "promener",
    "promenas": "promener",
    "promenasse": "promener",
    "promenassent": "promener",
    "promenasses": "promener",
    "promenassiez": "promener",
    "promenassions": "promener",
    "promeneurs": "promeneur",
    "promeneuse": "promeneur",
    "promeneuses": "promeneur",
    "promenez": "promener",
    "promeniez": "promener",
    "promenions": "promener",
    "promenons": "promener",
    "promenâmes": "promener",
    "promenât": "promener",
    "promenâtes": "promener",
    "promenèrent": "promener",
    "promené": "promener",
    "promenée": "promener",
    "promenées": "promener",
    "promenés": "promener",
    "promesses": "promesse",
    "promet": "promettre",
    "promets": "promettre",
    "promettaient": "promettre",
    "promettais": "promettre",
    "promettait": "promettre",
    "promettant": "promettre",
    "promette": "promettre",
    "promettent": "promettre",
    "promettes": "promettre",
    "prometteurs": "prometteur",
    "prometteuse": "prometteur",
    "prometteuses": "prometteur",
    "promettez": "promettre",
    "promettiez": "promettre",
    "promettions": "promettre",
    "promettons": "promettre",
    "promettra": "promettre",
    "promettrai": "promettre",
    "promettraient": "promettre",
    "promettrais": "promettre",
    "promettrait": "promettre",
    "promettras": "promettre",
    "promettrez": "promettre",
    "promettriez": "promettre",
    "promettrions": "promettre",
    "promettrons": "promettre",
    "promettront": "promettre",
    "promeus": "promouvoir",
    "promeut": "promouvoir",
    "promeuve": "promouvoir",
    "promeuvent": "promouvoir",
    "promeuves": "promouvoir",
    "promirent": "promettre",
    "promis": "promettre",
    "promiscuités": "promiscuité",
    "promise": "promis",
    "promises": "promis",
    "promisse": "promettre",
    "promissent": "promettre",
    "promisses": "promettre",
    "promissiez": "promettre",
    "promissions": "promettre",
    "promit": "promettre",
    "promontoires": "promontoire",
    "promos": "promo",
    "promoteurs": "promoteur",
    "promotionnait": "promotionner",
    "promotionnelle": "promotionnel",
    "promotionnelles": "promotionnel",
    "promotionnels": "promotionnel",
    "promotions": "promotion",
    "promotrice": "promoteur",
    "promotrices": "promoteur",
    "promouvaient": "promouvoir",
    "promouvais": "promouvoir",
    "promouvait": "promouvoir",
    "promouvant": "promouvoir",
    "promouvez": "promouvoir",
    "promouviez": "promouvoir",
    "promouvions": "promouvoir",
    "promouvons": "promouvoir",
    "promouvra": "promouvoir",
    "promouvrai": "promouvoir",
    "promouvraient": "promouvoir",
    "promouvrais": "promouvoir",
    "promouvrait": "promouvoir",
    "promouvras": "promouvoir",
    "promouvrez": "promouvoir",
    "promouvriez": "promouvoir",
    "promouvrions": "promouvoir",
    "promouvrons": "promouvoir",
    "promouvront": "promouvoir",
    "prompte": "prompt",
    "promptes": "prompt",
    "prompteurs": "prompteur",
    "promptitudes": "promptitude",
    "prompts": "prompt",
    "promu": "promouvoir",
    "promue": "promu",
    "promues": "promu",
    "promulgations": "promulgation",
    "promulgua": "promulguer",
    "promulguai": "promulguer",
    "promulguaient": "promulguer",
    "promulguais": "promulguer",
    "promulguait": "promulguer",
    "promulguant": "promulguer",
    "promulguas": "promulguer",
    "promulguasse": "promulguer",
    "promulguassent": "promulguer",
    "promulguasses": "promulguer",
    "promulguassiez": "promulguer",
    "promulguassions": "promulguer",
    "promulgue": "promulguer",
    "promulguent": "promulguer",
    "promulguera": "promulguer",
    "promulguerai": "promulguer",
    "promulgueraient": "promulguer",
    "promulguerais": "promulguer",
    "promulguerait": "promulguer",
    "promulgueras": "promulguer",
    "promulguerez": "promulguer",
    "promulgueriez": "promulguer",
    "promulguerions": "promulguer",
    "promulguerons": "promulguer",
    "promulgueront": "promulguer",
    "promulgues": "promulguer",
    "promulguez": "promulguer",
    "promulguiez": "promulguer",
    "promulguions": "promulguer",
    "promulguons": "promulguer",
    "promulguâmes": "promulguer",
    "promulguât": "promulguer",
    "promulguâtes": "promulguer",
    "promulguèrent": "promulguer",
    "promulgué": "promulguer",
    "promulguée": "promulguer",
    "promulguées": "promulguer",
    "promulgués": "promulguer",
    "promurent": "promouvoir",
    "promus": "promu",
    "promusse": "promouvoir",
    "promussent": "promouvoir",
    "promusses": "promouvoir",
    "promussiez": "promouvoir",
    "promussions": "promouvoir",
    "promut": "promouvoir",
    "promène": "promener",
    "promènent": "promener",
    "promènera": "promener",
    "promènerai": "promener",
    "promèneraient": "promener",
    "promènerais": "promener",
    "promènerait": "promener",
    "promèneras": "promener",
    "promènerez": "promener",
    "promèneriez": "promener",
    "promènerions": "promener",
    "promènerons": "promener",
    "promèneront": "promener",
    "promènes": "promener",
    "prométhéenne": "prométhéen",
    "promîmes": "promettre",
    "promît": "promettre",
    "promîtes": "promettre",
    "promû": "promouvoir",
    "promûmes": "promouvoir",
    "promût": "promouvoir",
    "promûtes": "promouvoir",
    "pronateurs": "pronateur",
    "pronations": "pronation",
    "pronazie": "pronazi",
    "pronazies": "pronazi",
    "pronazis": "pronazi",
    "pronominale": "pronominal",
    "pronominales": "pronominal",
    "pronominaux": "pronominal",
    "pronoms": "pronom",
    "prononce": "prononcer",
    "prononcent": "prononcer",
    "prononcera": "prononcer",
    "prononcerai": "prononcer",
    "prononceraient": "prononcer",
    "prononcerais": "prononcer",
    "prononcerait": "prononcer",
    "prononceras": "prononcer",
    "prononcerez": "prononcer",
    "prononceriez": "prononcer",
    "prononcerions": "prononcer",
    "prononcerons": "prononcer",
    "prononceront": "prononcer",
    "prononces": "prononcer",
    "prononcez": "prononcer",
    "prononciations": "prononciation",
    "prononciez": "prononcer",
    "prononcions": "prononcer",
    "prononcèrent": "prononcer",
    "prononcé": "prononcer",
    "prononcée": "prononcer",
    "prononcées": "prononcer",
    "prononcés": "prononcer",
    "prononça": "prononcer",
    "prononçai": "prononcer",
    "prononçaient": "prononcer",
    "prononçais": "prononcer",
    "prononçait": "prononcer",
    "prononçant": "prononcer",
    "prononças": "prononcer",
    "prononçasse": "prononcer",
    "prononçassent": "prononcer",
    "prononçasses": "prononcer",
    "prononçassiez": "prononcer",
    "prononçassions": "prononcer",
    "prononçons": "prononcer",
    "prononçâmes": "prononcer",
    "prononçât": "prononcer",
    "prononçâtes": "prononcer",
    "pronostics": "pronostic",
    "pronostiqua": "pronostiquer",
    "pronostiquai": "pronostiquer",
    "pronostiquaient": "pronostiquer",
    "pronostiquais": "pronostiquer",
    "pronostiquait": "pronostiquer",
    "pronostiquant": "pronostiquer",
    "pronostiquas": "pronostiquer",
    "pronostiquasse": "pronostiquer",
    "pronostiquassent": "pronostiquer",
    "pronostiquasses": "pronostiquer",
    "pronostiquassiez": "pronostiquer",
    "pronostiquassions": "pronostiquer",
    "pronostique": "pronostiquer",
    "pronostiquent": "pronostiquer",
    "pronostiquera": "pronostiquer",
    "pronostiquerai": "pronostiquer",
    "pronostiqueraient": "pronostiquer",
    "pronostiquerais": "pronostiquer",
    "pronostiquerait": "pronostiquer",
    "pronostiqueras": "pronostiquer",
    "pronostiquerez": "pronostiquer",
    "pronostiqueriez": "pronostiquer",
    "pronostiquerions": "pronostiquer",
    "pronostiquerons": "pronostiquer",
    "pronostiqueront": "pronostiquer",
    "pronostiques": "pronostiquer",
    "pronostiquez": "pronostiquer",
    "pronostiquiez": "pronostiquer",
    "pronostiquions": "pronostiquer",
    "pronostiquons": "pronostiquer",
    "pronostiquâmes": "pronostiquer",
    "pronostiquât": "pronostiquer",
    "pronostiquâtes": "pronostiquer",
    "pronostiquèrent": "pronostiquer",
    "pronostiqué": "pronostiquer",
    "pronostiquée": "pronostiquer",
    "pronostiquées": "pronostiquer",
    "pronostiqués": "pronostiquer",
    "pronunciamientos": "pronunciamiento",
    "propagandes": "propagande",
    "propagandistes": "propagandiste",
    "propagateurs": "propagateur",
    "propagations": "propagation",
    "propage": "propager",
    "propagea": "propager",
    "propageai": "propager",
    "propageaient": "propager",
    "propageais": "propager",
    "propageait": "propager",
    "propageant": "propager",
    "propageas": "propager",
    "propageasse": "propager",
    "propageassent": "propager",
    "propageasses": "propager",
    "propageassiez": "propager",
    "propageassions": "propager",
    "propagent": "propager",
    "propageons": "propager",
    "propagera": "propager",
    "propagerai": "propager",
    "propageraient": "propager",
    "propagerais": "propager",
    "propagerait": "propager",
    "propageras": "propager",
    "propagerez": "propager",
    "propageriez": "propager",
    "propagerions": "propager",
    "propagerons": "propager",
    "propageront": "propager",
    "propages": "propager",
    "propagez": "propager",
    "propageâmes": "propager",
    "propageât": "propager",
    "propageâtes": "propager",
    "propagiez": "propager",
    "propagions": "propager",
    "propagèrent": "propager",
    "propagé": "propager",
    "propagée": "propager",
    "propagées": "propager",
    "propagés": "propager",
    "propensions": "propension",
    "propergols": "propergol",
    "prophylactiques": "prophylactique",
    "prophylaxies": "prophylaxie",
    "prophètes": "prophète",
    "prophétesse": "prophète",
    "prophétesses": "prophète",
    "prophéties": "prophétie",
    "prophétiques": "prophétique",
    "prophétisaient": "prophétiser",
    "prophétisait": "prophétiser",
    "prophétisant": "prophétiser",
    "prophétise": "prophétiser",
    "prophétisent": "prophétiser",
    "prophétisez": "prophétiser",
    "prophétisé": "prophétiser",
    "propices": "propice",
    "propitiations": "propitiation",
    "propitiatoires": "propitiatoire",
    "proportionnalités": "proportionnalité",
    "proportionnelle": "proportionnel",
    "proportionnelles": "proportionnel",
    "proportionnels": "proportionnel",
    "proportionné": "proportionner",
    "proportionnée": "proportionner",
    "proportionnées": "proportionner",
    "proportionnés": "proportionner",
    "proportions": "proportion",
    "proposa": "proposer",
    "proposai": "proposer",
    "proposaient": "proposer",
    "proposais": "proposer",
    "proposait": "proposer",
    "proposant": "proposer",
    "proposas": "proposer",
    "proposasse": "proposer",
    "proposassent": "proposer",
    "proposasses": "proposer",
    "proposassiez": "proposer",
    "proposassions": "proposer",
    "propose": "proposer",
    "proposent": "proposer",
    "proposera": "proposer",
    "proposerai": "proposer",
    "proposeraient": "proposer",
    "proposerais": "proposer",
    "proposerait": "proposer",
    "proposeras": "proposer",
    "proposerez": "proposer",
    "proposeriez": "proposer",
    "proposerions": "proposer",
    "proposerons": "proposer",
    "proposeront": "proposer",
    "proposes": "proposer",
    "proposez": "proposer",
    "proposiez": "proposer",
    "proposions": "proposer",
    "propositions": "proposition",
    "proposons": "proposer",
    "proposâmes": "proposer",
    "proposât": "proposer",
    "proposâtes": "proposer",
    "proposèrent": "proposer",
    "proposé": "proposer",
    "proposée": "proposer",
    "proposées": "proposer",
    "proposés": "proposer",
    "propres": "propre",
    "propres-à-rien": "propre-à-rien",
    "proprets": "propret",
    "proprette": "propret",
    "proprettes": "propret",
    "propretés": "propreté",
    "proprios": "proprio",
    "propriétaires": "propriétaire",
    "propriétés": "propriété",
    "propulsa": "propulser",
    "propulsai": "propulser",
    "propulsaient": "propulser",
    "propulsais": "propulser",
    "propulsait": "propulser",
    "propulsant": "propulser",
    "propulsas": "propulser",
    "propulsasse": "propulser",
    "propulsassent": "propulser",
    "propulsasses": "propulser",
    "propulsassiez": "propulser",
    "propulsassions": "propulser",
    "propulse": "propulser",
    "propulsent": "propulser",
    "propulsera": "propulser",
    "propulserai": "propulser",
    "propulseraient": "propulser",
    "propulserais": "propulser",
    "propulserait": "propulser",
    "propulseras": "propulser",
    "propulserez": "propulser",
    "propulseriez": "propulser",
    "propulserions": "propulser",
    "propulserons": "propulser",
    "propulseront": "propulser",
    "propulses": "propulser",
    "propulseurs": "propulseur",
    "propulsez": "propulser",
    "propulsiez": "propulser",
    "propulsions": "propulsion",
    "propulsons": "propulser",
    "propulsâmes": "propulser",
    "propulsât": "propulser",
    "propulsâtes": "propulser",
    "propulsèrent": "propulser",
    "propulsé": "propulser",
    "propulsée": "propulser",
    "propulsées": "propulser",
    "propulsés": "propulser",
    "propylées": "propylée",
    "propédeutiques": "propédeutique",
    "prorogations": "prorogation",
    "proroge": "proroger",
    "prorogea": "proroger",
    "prorogeai": "proroger",
    "prorogeaient": "proroger",
    "prorogeais": "proroger",
    "prorogeait": "proroger",
    "prorogeant": "proroger",
    "prorogeas": "proroger",
    "prorogeasse": "proroger",
    "prorogeassent": "proroger",
    "prorogeasses": "proroger",
    "prorogeassiez": "proroger",
    "prorogeassions": "proroger",
    "prorogent": "proroger",
    "prorogeons": "proroger",
    "prorogera": "proroger",
    "prorogerai": "proroger",
    "prorogeraient": "proroger",
    "prorogerais": "proroger",
    "prorogerait": "proroger",
    "prorogeras": "proroger",
    "prorogerez": "proroger",
    "prorogeriez": "proroger",
    "prorogerions": "proroger",
    "prorogerons": "proroger",
    "prorogeront": "proroger",
    "proroges": "proroger",
    "prorogez": "proroger",
    "prorogeâmes": "proroger",
    "prorogeât": "proroger",
    "prorogeâtes": "proroger",
    "prorogiez": "proroger",
    "prorogions": "proroger",
    "prorogèrent": "proroger",
    "prorogé": "proroger",
    "prorogée": "proroger",
    "prorogées": "proroger",
    "prorogés": "proroger",
    "pros": "pro",
    "prosateurs": "prosateur",
    "prosaïques": "prosaïque",
    "prosaïsmes": "prosaïsme",
    "prosceniums": "proscenium",
    "proscriptions": "proscription",
    "proscrira": "proscrire",
    "proscrirai": "proscrire",
    "proscriraient": "proscrire",
    "proscrirais": "proscrire",
    "proscrirait": "proscrire",
    "proscriras": "proscrire",
    "proscrirez": "proscrire",
    "proscririez": "proscrire",
    "proscririons": "proscrire",
    "proscrirons": "proscrire",
    "proscriront": "proscrire",
    "proscris": "proscrire",
    "proscrit": "proscrire",
    "proscrite": "proscrit",
    "proscrites": "proscrit",
    "proscrits": "proscrit",
    "proscrivaient": "proscrire",
    "proscrivais": "proscrire",
    "proscrivait": "proscrire",
    "proscrivant": "proscrire",
    "proscrive": "proscrire",
    "proscrivent": "proscrire",
    "proscrives": "proscrire",
    "proscrivez": "proscrire",
    "proscriviez": "proscrire",
    "proscrivions": "proscrire",
    "proscrivirent": "proscrire",
    "proscrivis": "proscrire",
    "proscrivisse": "proscrire",
    "proscrivissent": "proscrire",
    "proscrivisses": "proscrire",
    "proscrivissiez": "proscrire",
    "proscrivissions": "proscrire",
    "proscrivit": "proscrire",
    "proscrivons": "proscrire",
    "proscrivîmes": "proscrire",
    "proscrivît": "proscrire",
    "proscrivîtes": "proscrire",
    "proses": "prose",
    "prosodies": "prosodie",
    "prosopopées": "prosopopée",
    "prospecta": "prospecter",
    "prospectai": "prospecter",
    "prospectaient": "prospecter",
    "prospectais": "prospecter",
    "prospectait": "prospecter",
    "prospectant": "prospecter",
    "prospectas": "prospecter",
    "prospectasse": "prospecter",
    "prospectassent": "prospecter",
    "prospectasses": "prospecter",
    "prospectassiez": "prospecter",
    "prospectassions": "prospecter",
    "prospecte": "prospecter",
    "prospectent": "prospecter",
    "prospectera": "prospecter",
    "prospecterai": "prospecter",
    "prospecteraient": "prospecter",
    "prospecterais": "prospecter",
    "prospecterait": "prospecter",
    "prospecteras": "prospecter",
    "prospecterez": "prospecter",
    "prospecteriez": "prospecter",
    "prospecterions": "prospecter",
    "prospecterons": "prospecter",
    "prospecteront": "prospecter",
    "prospectes": "prospecter",
    "prospecteurs": "prospecteur",
    "prospectez": "prospecter",
    "prospectiez": "prospecter",
    "prospectifs": "prospectif",
    "prospections": "prospection",
    "prospective": "prospectif",
    "prospectives": "prospective",
    "prospectons": "prospecter",
    "prospectrice": "prospecteur",
    "prospectrices": "prospecteur",
    "prospectâmes": "prospecter",
    "prospectât": "prospecter",
    "prospectâtes": "prospecter",
    "prospectèrent": "prospecter",
    "prospecté": "prospecter",
    "prospectée": "prospecter",
    "prospectées": "prospecter",
    "prospectés": "prospecter",
    "prospère": "prospérer",
    "prospèrent": "prospérer",
    "prospères": "prospérer",
    "prospéra": "prospérer",
    "prospérai": "prospérer",
    "prospéraient": "prospérer",
    "prospérais": "prospérer",
    "prospérait": "prospérer",
    "prospérant": "prospérer",
    "prospéras": "prospérer",
    "prospérasse": "prospérer",
    "prospérassent": "prospérer",
    "prospérasses": "prospérer",
    "prospérassiez": "prospérer",
    "prospérassions": "prospérer",
    "prospérera": "prospérer",
    "prospérerai": "prospérer",
    "prospéreraient": "prospérer",
    "prospérerais": "prospérer",
    "prospérerait": "prospérer",
    "prospéreras": "prospérer",
    "prospérerez": "prospérer",
    "prospéreriez": "prospérer",
    "prospérerions": "prospérer",
    "prospérerons": "prospérer",
    "prospéreront": "prospérer",
    "prospérez": "prospérer",
    "prospériez": "prospérer",
    "prospérions": "prospérer",
    "prospérités": "prospérité",
    "prospérons": "prospérer",
    "prospérâmes": "prospérer",
    "prospérât": "prospérer",
    "prospérâtes": "prospérer",
    "prospérèrent": "prospérer",
    "prospéré": "prospérer",
    "prostates": "prostate",
    "prosterna": "prosterner",
    "prosternai": "prosterner",
    "prosternaient": "prosterner",
    "prosternais": "prosterner",
    "prosternait": "prosterner",
    "prosternant": "prosterner",
    "prosternas": "prosterner",
    "prosternasse": "prosterner",
    "prosternassent": "prosterner",
    "prosternasses": "prosterner",
    "prosternassiez": "prosterner",
    "prosternassions": "prosterner",
    "prosternations": "prosternation",
    "prosterne": "prosterner",
    "prosternent": "prosterner",
    "prosternera": "prosterner",
    "prosternerai": "prosterner",
    "prosterneraient": "prosterner",
    "prosternerais": "prosterner",
    "prosternerait": "prosterner",
    "prosterneras": "prosterner",
    "prosternerez": "prosterner",
    "prosterneriez": "prosterner",
    "prosternerions": "prosterner",
    "prosternerons": "prosterner",
    "prosterneront": "prosterner",
    "prosternes": "prosterner",
    "prosternez": "prosterner",
    "prosterniez": "prosterner",
    "prosternions": "prosterner",
    "prosternons": "prosterner",
    "prosternâmes": "prosterner",
    "prosternât": "prosterner",
    "prosternâtes": "prosterner",
    "prosternèrent": "prosterner",
    "prosterné": "prosterner",
    "prosternée": "prosterner",
    "prosternées": "prosterner",
    "prosternés": "prosterner",
    "prostitua": "prostituer",
    "prostituai": "prostituer",
    "prostituaient": "prostituer",
    "prostituais": "prostituer",
    "prostituait": "prostituer",
    "prostituant": "prostituer",
    "prostituas": "prostituer",
    "prostituasse": "prostituer",
    "prostituassent": "prostituer",
    "prostituasses": "prostituer",
    "prostituassiez": "prostituer",
    "prostituassions": "prostituer",
    "prostitue": "prostituer",
    "prostituent": "prostituer",
    "prostituera": "prostituer",
    "prostituerai": "prostituer",
    "prostitueraient": "prostituer",
    "prostituerais": "prostituer",
    "prostituerait": "prostituer",
    "prostitueras": "prostituer",
    "prostituerez": "prostituer",
    "prostitueriez": "prostituer",
    "prostituerions": "prostituer",
    "prostituerons": "prostituer",
    "prostitueront": "prostituer",
    "prostitues": "prostituer",
    "prostituez": "prostituer",
    "prostituiez": "prostituer",
    "prostituions": "prostituer",
    "prostituons": "prostituer",
    "prostitutions": "prostitution",
    "prostituâmes": "prostituer",
    "prostituât": "prostituer",
    "prostituâtes": "prostituer",
    "prostituèrent": "prostituer",
    "prostitué": "prostituer",
    "prostituée": "prostituer",
    "prostituées": "prostituer",
    "prostitués": "prostituer",
    "prostrant": "prostrer",
    "prostrations": "prostration",
    "prostrée": "prostré",
    "prostrées": "prostré",
    "prostrés": "prostré",
    "prosyrienne": "prosyrien",
    "prosyriennes": "prosyrien",
    "prosyriens": "prosyrien",
    "prosélytes": "prosélyte",
    "prosélytismes": "prosélytisme",
    "protagonistes": "protagoniste",
    "protases": "protase",
    "protecteurs": "protecteur",
    "protectionnismes": "protectionnisme",
    "protectionnistes": "protectionniste",
    "protections": "protection",
    "protectons": "protecton",
    "protectorats": "protectorat",
    "protectrice": "protecteur",
    "protectrices": "protecteur",
    "protes": "prote",
    "protesta": "protester",
    "protestai": "protester",
    "protestaient": "protester",
    "protestais": "protester",
    "protestait": "protester",
    "protestant": "protester",
    "protestante": "protestant",
    "protestantes": "protestant",
    "protestantismes": "protestantisme",
    "protestants": "protestant",
    "protestas": "protester",
    "protestasse": "protester",
    "protestassent": "protester",
    "protestasses": "protester",
    "protestassiez": "protester",
    "protestassions": "protester",
    "protestataires": "protestataire",
    "protestations": "protestation",
    "proteste": "protester",
    "protestent": "protester",
    "protestera": "protester",
    "protesterai": "protester",
    "protesteraient": "protester",
    "protesterais": "protester",
    "protesterait": "protester",
    "protesteras": "protester",
    "protesterez": "protester",
    "protesteriez": "protester",
    "protesterions": "protester",
    "protesterons": "protester",
    "protesteront": "protester",
    "protestes": "protester",
    "protestez": "protester",
    "protestiez": "protester",
    "protestions": "protester",
    "protestons": "protester",
    "protestâmes": "protester",
    "protestât": "protester",
    "protestâtes": "protester",
    "protestèrent": "protester",
    "protesté": "protester",
    "protestée": "protester",
    "protestées": "protester",
    "protestés": "protester",
    "prothèses": "prothèse",
    "prothésistes": "prothésiste",
    "prothétiques": "prothétique",
    "protides": "protide",
    "protistes": "protiste",
    "protocolaires": "protocolaire",
    "protocoles": "protocole",
    "protocoques": "protocoque",
    "protons": "proton",
    "protoplasmes": "protoplasme",
    "prototypes": "prototype",
    "protoxydes": "protoxyde",
    "protozoaires": "protozoaire",
    "protubérances": "protubérance",
    "protubérante": "protubérant",
    "protubérantes": "protubérant",
    "protubérants": "protubérant",
    "protège": "protéger",
    "protège-cahiers": "protège-cahier",
    "protège-tibias": "protège-tibia",
    "protègent": "protéger",
    "protèges": "protéger",
    "protéagineuse": "protéagineux",
    "protéagineuses": "protéagineux",
    "protées": "protée",
    "protégea": "protéger",
    "protégeai": "protéger",
    "protégeaient": "protéger",
    "protégeais": "protéger",
    "protégeait": "protéger",
    "protégeant": "protéger",
    "protégeas": "protéger",
    "protégeasse": "protéger",
    "protégeassent": "protéger",
    "protégeasses": "protéger",
    "protégeassiez": "protéger",
    "protégeassions": "protéger",
    "protégeons": "protéger",
    "protégera": "protéger",
    "protégerai": "protéger",
    "protégeraient": "protéger",
    "protégerais": "protéger",
    "protégerait": "protéger",
    "protégeras": "protéger",
    "protégerez": "protéger",
    "protégeriez": "protéger",
    "protégerions": "protéger",
    "protégerons": "protéger",
    "protégeront": "protéger",
    "protégez": "protéger",
    "protégeâmes": "protéger",
    "protégeât": "protéger",
    "protégeâtes": "protéger",
    "protégiez": "protéger",
    "protégions": "protéger",
    "protégèrent": "protéger",
    "protégé": "protéger",
    "protégée": "protéger",
    "protégées": "protéger",
    "protégés": "protéger",
    "protéiformes": "protéiforme",
    "protéines": "protéine",
    "protéinée": "protéiné",
    "protêts": "protêt",
    "proues": "proue",
    "prouesses": "prouesse",
    "proustienne": "proustien",
    "proustiennes": "proustien",
    "proustiens": "proustien",
    "prouts": "prout",
    "prouva": "prouver",
    "prouvai": "prouver",
    "prouvaient": "prouver",
    "prouvais": "prouver",
    "prouvait": "prouver",
    "prouvant": "prouver",
    "prouvas": "prouver",
    "prouvasse": "prouver",
    "prouvassent": "prouver",
    "prouvasses": "prouver",
    "prouvassiez": "prouver",
    "prouvassions": "prouver",
    "prouve": "prouver",
    "prouvent": "prouver",
    "prouvera": "prouver",
    "prouverai": "prouver",
    "prouveraient": "prouver",
    "prouverais": "prouver",
    "prouverait": "prouver",
    "prouveras": "prouver",
    "prouverez": "prouver",
    "prouveriez": "prouver",
    "prouverions": "prouver",
    "prouverons": "prouver",
    "prouveront": "prouver",
    "prouves": "prouver",
    "prouvez": "prouver",
    "prouviez": "prouver",
    "prouvions": "prouver",
    "prouvons": "prouver",
    "prouvâmes": "prouver",
    "prouvât": "prouver",
    "prouvâtes": "prouver",
    "prouvèrent": "prouver",
    "prouvé": "prouver",
    "prouvée": "prouver",
    "prouvées": "prouver",
    "prouvés": "prouver",
    "provenaient": "provenir",
    "provenais": "provenir",
    "provenait": "provenir",
    "provenances": "provenance",
    "provenant": "provenir",
    "provendes": "provende",
    "provenez": "provenir",
    "proveniez": "provenir",
    "provenions": "provenir",
    "provenons": "provenir",
    "provenu": "provenir",
    "provenue": "provenir",
    "provenues": "provenir",
    "provenus": "provenir",
    "provençale": "provençal",
    "provençales": "provençal",
    "provençaux": "provençal",
    "provençauxs": "provençal",
    "proverbes": "proverbe",
    "proverbiale": "proverbial",
    "proverbiales": "proverbial",
    "proverbiaux": "proverbial",
    "providences": "providence",
    "providentielle": "providentiel",
    "providentielles": "providentiel",
    "providentiels": "providentiel",
    "proviendra": "provenir",
    "proviendrai": "provenir",
    "proviendraient": "provenir",
    "proviendrais": "provenir",
    "proviendrait": "provenir",
    "proviendras": "provenir",
    "proviendrez": "provenir",
    "proviendriez": "provenir",
    "proviendrions": "provenir",
    "proviendrons": "provenir",
    "proviendront": "provenir",
    "provienne": "provenir",
    "proviennent": "provenir",
    "proviennes": "provenir",
    "proviens": "provenir",
    "provient": "provenir",
    "provinces": "province",
    "provinciale": "provincial",
    "provinciales": "provincial",
    "provincialismes": "provincialisme",
    "provinciaux": "provincial",
    "provinrent": "provenir",
    "provins": "provenir",
    "provinsse": "provenir",
    "provinssent": "provenir",
    "provinsses": "provenir",
    "provinssiez": "provenir",
    "provinssions": "provenir",
    "provint": "provenir",
    "proviseurs": "proviseur",
    "provisionnelle": "provisionnel",
    "provisionnelles": "provisionnel",
    "provisionnels": "provisionnel",
    "provisionnons": "provisionner",
    "provisions": "provision",
    "provisoires": "provisoire",
    "provocante": "provocant",
    "provocantes": "provocant",
    "provocants": "provocant",
    "provocateurs": "provocateur",
    "provocations": "provocation",
    "provocatrice": "provocateur",
    "provocatrices": "provocateur",
    "provoqua": "provoquer",
    "provoquai": "provoquer",
    "provoquaient": "provoquer",
    "provoquais": "provoquer",
    "provoquait": "provoquer",
    "provoquant": "provoquer",
    "provoquas": "provoquer",
    "provoquasse": "provoquer",
    "provoquassent": "provoquer",
    "provoquasses": "provoquer",
    "provoquassiez": "provoquer",
    "provoquassions": "provoquer",
    "provoque": "provoquer",
    "provoquent": "provoquer",
    "provoquera": "provoquer",
    "provoquerai": "provoquer",
    "provoqueraient": "provoquer",
    "provoquerais": "provoquer",
    "provoquerait": "provoquer",
    "provoqueras": "provoquer",
    "provoquerez": "provoquer",
    "provoqueriez": "provoquer",
    "provoquerions": "provoquer",
    "provoquerons": "provoquer",
    "provoqueront": "provoquer",
    "provoques": "provoquer",
    "provoquez": "provoquer",
    "provoquiez": "provoquer",
    "provoquions": "provoquer",
    "provoquons": "provoquer",
    "provoquâmes": "provoquer",
    "provoquât": "provoquer",
    "provoquâtes": "provoquer",
    "provoquèrent": "provoquer",
    "provoqué": "provoquer",
    "provoquée": "provoquer",
    "provoquées": "provoquer",
    "provoqués": "provoquer",
    "provos": "provo",
    "provéditeurs": "provéditeur",
    "provînmes": "provenir",
    "provînt": "provenir",
    "provîntes": "provenir",
    "proximale": "proximal",
    "proximales": "proximal",
    "proximaux": "proximal",
    "proximités": "proximité",
    "proxos": "proxo",
    "proxénètes": "proxénète",
    "proxénétismes": "proxénétisme",
    "proéminait": "proéminer",
    "proémine": "proéminer",
    "proéminences": "proéminence",
    "proéminente": "proéminent",
    "proéminentes": "proéminent",
    "proéminents": "proéminent",
    "prud'homale": "prud'homal",
    "prud'homales": "prud'homal",
    "prud'homaux": "prud'homal",
    "prud'homies": "prud'homie",
    "prud'hommes": "prud'homme",
    "prudences": "prudence",
    "prudente": "prudent",
    "prudentes": "prudent",
    "prudents": "prudent",
    "pruderies": "pruderie",
    "prudes": "prude",
    "prudhommesques": "prudhommesque",
    "pruneaux": "pruneau",
    "prunelles": "prunelle",
    "prunelliers": "prunellier",
    "prunes": "prune",
    "pruniers": "prunier",
    "prurigineuse": "prurigineux",
    "prurigineuses": "prurigineux",
    "prurigos": "prurigo",
    "prurits": "prurit",
    "prussianisé": "prussianiser",
    "prussienne": "prussien",
    "prussiennes": "prussien",
    "prussiens": "prussien",
    "prussiques": "prussique",
    "prytanées": "prytanée",
    "prèles": "prèle",
    "préaccords": "préaccord",
    "préacheta": "préacheter",
    "préachetai": "préacheter",
    "préachetaient": "préacheter",
    "préachetais": "préacheter",
    "préachetait": "préacheter",
    "préachetant": "préacheter",
    "préachetas": "préacheter",
    "préachetasse": "préacheter",
    "préachetassent": "préacheter",
    "préachetasses": "préacheter",
    "préachetassiez": "préacheter",
    "préachetassions": "préacheter",
    "préachetez": "préacheter",
    "préachetiez": "préacheter",
    "préachetions": "préacheter",
    "préachetons": "préacheter",
    "préachetâmes": "préacheter",
    "préachetât": "préacheter",
    "préachetâtes": "préacheter",
    "préachetèrent": "préacheter",
    "préacheté": "préacheter",
    "préachetée": "préacheter",
    "préachetées": "préacheter",
    "préachetés": "préacheter",
    "préachète": "préacheter",
    "préachètent": "préacheter",
    "préachètera": "préacheter",
    "préachèterai": "préacheter",
    "préachèteraient": "préacheter",
    "préachèterais": "préacheter",
    "préachèterait": "préacheter",
    "préachèteras": "préacheter",
    "préachèterez": "préacheter",
    "préachèteriez": "préacheter",
    "préachèterions": "préacheter",
    "préachèterons": "préacheter",
    "préachèteront": "préacheter",
    "préachètes": "préacheter",
    "préadolescente": "préadolescent",
    "préalables": "préalable",
    "préambules": "préambule",
    "préaux": "préau",
    "préavisa": "préaviser",
    "préavisai": "préaviser",
    "préavisaient": "préaviser",
    "préavisais": "préaviser",
    "préavisait": "préaviser",
    "préavisant": "préaviser",
    "préavisas": "préaviser",
    "préavisasse": "préaviser",
    "préavisassent": "préaviser",
    "préavisasses": "préaviser",
    "préavisassiez": "préaviser",
    "préavisassions": "préaviser",
    "préavise": "préaviser",
    "préavisent": "préaviser",
    "préavisera": "préaviser",
    "préaviserai": "préaviser",
    "préaviseraient": "préaviser",
    "préaviserais": "préaviser",
    "préaviserait": "préaviser",
    "préaviseras": "préaviser",
    "préaviserez": "préaviser",
    "préaviseriez": "préaviser",
    "préaviserions": "préaviser",
    "préaviserons": "préaviser",
    "préaviseront": "préaviser",
    "préavises": "préaviser",
    "préavisez": "préaviser",
    "préavisiez": "préaviser",
    "préavisions": "préaviser",
    "préavisons": "préaviser",
    "préavisâmes": "préaviser",
    "préavisât": "préaviser",
    "préavisâtes": "préaviser",
    "préavisèrent": "préaviser",
    "préavisé": "préaviser",
    "préavisée": "préaviser",
    "préavisées": "préaviser",
    "préavisés": "préaviser",
    "prébendes": "prébende",
    "précaires": "précaire",
    "précambrienne": "précambrien",
    "précarisations": "précarisation",
    "précarités": "précarité",
    "précautionna": "précautionner",
    "précautionnai": "précautionner",
    "précautionnaient": "précautionner",
    "précautionnais": "précautionner",
    "précautionnait": "précautionner",
    "précautionnant": "précautionner",
    "précautionnas": "précautionner",
    "précautionnasse": "précautionner",
    "précautionnassent": "précautionner",
    "précautionnasses": "précautionner",
    "précautionnassiez": "précautionner",
    "précautionnassions": "précautionner",
    "précautionne": "précautionner",
    "précautionnent": "précautionner",
    "précautionnera": "précautionner",
    "précautionnerai": "précautionner",
    "précautionneraient": "précautionner",
    "précautionnerais": "précautionner",
    "précautionnerait": "précautionner",
    "précautionneras": "précautionner",
    "précautionnerez": "précautionner",
    "précautionneriez": "précautionner",
    "précautionnerions": "précautionner",
    "précautionnerons": "précautionner",
    "précautionneront": "précautionner",
    "précautionnes": "précautionner",
    "précautionneuse": "précautionneux",
    "précautionneuses": "précautionneux",
    "précautionnez": "précautionner",
    "précautionniez": "précautionner",
    "précautionnions": "précautionner",
    "précautionnons": "précautionner",
    "précautionnâmes": "précautionner",
    "précautionnât": "précautionner",
    "précautionnâtes": "précautionner",
    "précautionnèrent": "précautionner",
    "précautionné": "précautionner",
    "précautionnée": "précautionner",
    "précautionnées": "précautionner",
    "précautionnés": "précautionner",
    "précautions": "précaution",
    "préceptes": "précepte",
    "précepteurs": "précepteur",
    "préceptrice": "précepteur",
    "préceptrices": "précepteur",
    "précieuse": "précieux",
    "précieuses": "précieux",
    "préciosités": "préciosité",
    "précipices": "précipice",
    "précipita": "précipiter",
    "précipitai": "précipiter",
    "précipitaient": "précipiter",
    "précipitais": "précipiter",
    "précipitait": "précipiter",
    "précipitant": "précipiter",
    "précipitas": "précipiter",
    "précipitasse": "précipiter",
    "précipitassent": "précipiter",
    "précipitasses": "précipiter",
    "précipitassiez": "précipiter",
    "précipitassions": "précipiter",
    "précipitations": "précipitation",
    "précipite": "précipiter",
    "précipitent": "précipiter",
    "précipitera": "précipiter",
    "précipiterai": "précipiter",
    "précipiteraient": "précipiter",
    "précipiterais": "précipiter",
    "précipiterait": "précipiter",
    "précipiteras": "précipiter",
    "précipiterez": "précipiter",
    "précipiteriez": "précipiter",
    "précipiterions": "précipiter",
    "précipiterons": "précipiter",
    "précipiteront": "précipiter",
    "précipites": "précipiter",
    "précipitez": "précipiter",
    "précipitiez": "précipiter",
    "précipitions": "précipiter",
    "précipitons": "précipiter",
    "précipitâmes": "précipiter",
    "précipitât": "précipiter",
    "précipitâtes": "précipiter",
    "précipitèrent": "précipiter",
    "précipité": "précipiter",
    "précipitée": "précipiter",
    "précipitées": "précipiter",
    "précipités": "précipiter",
    "préciputs": "préciput",
    "précisa": "préciser",
    "précisai": "préciser",
    "précisaient": "préciser",
    "précisais": "préciser",
    "précisait": "préciser",
    "précisant": "préciser",
    "précisas": "préciser",
    "précisasse": "préciser",
    "précisassent": "préciser",
    "précisasses": "préciser",
    "précisassiez": "préciser",
    "précisassions": "préciser",
    "précise": "préciser",
    "précisent": "préciser",
    "précisera": "préciser",
    "préciserai": "préciser",
    "préciseraient": "préciser",
    "préciserais": "préciser",
    "préciserait": "préciser",
    "préciseras": "préciser",
    "préciserez": "préciser",
    "préciseriez": "préciser",
    "préciserions": "préciser",
    "préciserons": "préciser",
    "préciseront": "préciser",
    "précises": "préciser",
    "précisez": "préciser",
    "précisiez": "préciser",
    "précisions": "précision",
    "précisons": "préciser",
    "précisâmes": "préciser",
    "précisât": "préciser",
    "précisâtes": "préciser",
    "précisèrent": "préciser",
    "précisé": "préciser",
    "précisée": "préciser",
    "précisées": "préciser",
    "précisés": "préciser",
    "précitée": "précité",
    "précitées": "précité",
    "précités": "précité",
    "précoces": "précoce",
    "précocités": "précocité",
    "précolombienne": "précolombien",
    "précolombiennes": "précolombien",
    "précompta": "précompter",
    "précomptai": "précompter",
    "précomptaient": "précompter",
    "précomptais": "précompter",
    "précomptait": "précompter",
    "précomptant": "précompter",
    "précomptas": "précompter",
    "précomptasse": "précompter",
    "précomptassent": "précompter",
    "précomptasses": "précompter",
    "précomptassiez": "précompter",
    "précomptassions": "précompter",
    "précompte": "précompter",
    "précomptent": "précompter",
    "précomptera": "précompter",
    "précompterai": "précompter",
    "précompteraient": "précompter",
    "précompterais": "précompter",
    "précompterait": "précompter",
    "précompteras": "précompter",
    "précompterez": "précompter",
    "précompteriez": "précompter",
    "précompterions": "précompter",
    "précompterons": "précompter",
    "précompteront": "précompter",
    "précomptes": "précompter",
    "précomptez": "précompter",
    "précomptiez": "précompter",
    "précomptions": "précompter",
    "précomptons": "précompter",
    "précomptâmes": "précompter",
    "précomptât": "précompter",
    "précomptâtes": "précompter",
    "précomptèrent": "précompter",
    "précompté": "précompter",
    "précomptée": "précompter",
    "précomptées": "précompter",
    "précomptés": "précompter",
    "précompétitifs": "précompétitif",
    "précompétitive": "précompétitif",
    "précompétitives": "précompétitif",
    "préconisa": "préconiser",
    "préconisai": "préconiser",
    "préconisaient": "préconiser",
    "préconisais": "préconiser",
    "préconisait": "préconiser",
    "préconisant": "préconiser",
    "préconisas": "préconiser",
    "préconisasse": "préconiser",
    "préconisassent": "préconiser",
    "préconisasses": "préconiser",
    "préconisassiez": "préconiser",
    "préconisassions": "préconiser",
    "préconise": "préconiser",
    "préconisent": "préconiser",
    "préconisera": "préconiser",
    "préconiserai": "préconiser",
    "préconiseraient": "préconiser",
    "préconiserais": "préconiser",
    "préconiserait": "préconiser",
    "préconiseras": "préconiser",
    "préconiserez": "préconiser",
    "préconiseriez": "préconiser",
    "préconiserions": "préconiser",
    "préconiserons": "préconiser",
    "préconiseront": "préconiser",
    "préconises": "préconiser",
    "préconisez": "préconiser",
    "préconisiez": "préconiser",
    "préconisions": "préconiser",
    "préconisons": "préconiser",
    "préconisâmes": "préconiser",
    "préconisât": "préconiser",
    "préconisâtes": "préconiser",
    "préconisèrent": "préconiser",
    "préconisé": "préconiser",
    "préconisée": "préconiser",
    "préconisées": "préconiser",
    "préconisés": "préconiser",
    "précontentieuse": "précontentieux",
    "précontentieuses": "précontentieux",
    "précontractuelle": "précontractuel",
    "précontractuelles": "précontractuel",
    "précontractuels": "précontractuel",
    "préconçue": "préconçu",
    "préconçues": "préconçu",
    "préconçus": "préconçu",
    "précuites": "précuit",
    "précurseurs": "précurseur",
    "précède": "précéder",
    "précèdent": "précéder",
    "précèdes": "précéder",
    "précéda": "précéder",
    "précédai": "précéder",
    "précédaient": "précéder",
    "précédais": "précéder",
    "précédait": "précéder",
    "précédant": "précéder",
    "précédas": "précéder",
    "précédasse": "précéder",
    "précédassent": "précéder",
    "précédasses": "précéder",
    "précédassiez": "précéder",
    "précédassions": "précéder",
    "précédente": "précédent",
    "précédentes": "précédent",
    "précédents": "précédent",
    "précédera": "précéder",
    "précéderai": "précéder",
    "précéderaient": "précéder",
    "précéderais": "précéder",
    "précéderait": "précéder",
    "précéderas": "précéder",
    "précéderez": "précéder",
    "précéderiez": "précéder",
    "précéderions": "précéder",
    "précéderons": "précéder",
    "précéderont": "précéder",
    "précédez": "précéder",
    "précédiez": "précéder",
    "précédions": "précéder",
    "précédons": "précéder",
    "précédâmes": "précéder",
    "précédât": "précéder",
    "précédâtes": "précéder",
    "précédèrent": "précéder",
    "précédé": "précéder",
    "précédée": "précéder",
    "précédées": "précéder",
    "précédés": "précéder",
    "prédateurs": "prédateur",
    "prédations": "prédation",
    "prédatrice": "prédateur",
    "prédatrices": "prédateur",
    "prédestina": "prédestiner",
    "prédestinai": "prédestiner",
    "prédestinaient": "prédestiner",
    "prédestinais": "prédestiner",
    "prédestinait": "prédestiner",
    "prédestinant": "prédestiner",
    "prédestinas": "prédestiner",
    "prédestinasse": "prédestiner",
    "prédestinassent": "prédestiner",
    "prédestinasses": "prédestiner",
    "prédestinassiez": "prédestiner",
    "prédestinassions": "prédestiner",
    "prédestinations": "prédestination",
    "prédestine": "prédestiner",
    "prédestinent": "prédestiner",
    "prédestinera": "prédestiner",
    "prédestinerai": "prédestiner",
    "prédestineraient": "prédestiner",
    "prédestinerais": "prédestiner",
    "prédestinerait": "prédestiner",
    "prédestineras": "prédestiner",
    "prédestinerez": "prédestiner",
    "prédestineriez": "prédestiner",
    "prédestinerions": "prédestiner",
    "prédestinerons": "prédestiner",
    "prédestineront": "prédestiner",
    "prédestines": "prédestiner",
    "prédestinez": "prédestiner",
    "prédestiniez": "prédestiner",
    "prédestinions": "prédestiner",
    "prédestinons": "prédestiner",
    "prédestinâmes": "prédestiner",
    "prédestinât": "prédestiner",
    "prédestinâtes": "prédestiner",
    "prédestinèrent": "prédestiner",
    "prédestiné": "prédestiner",
    "prédestinée": "prédestiner",
    "prédestinées": "prédestiner",
    "prédestinés": "prédestiner",
    "prédicants": "prédicant",
    "prédicateurs": "prédicateur",
    "prédications": "prédication",
    "prédicatrice": "prédicateur",
    "prédicatrices": "prédicateur",
    "prédicats": "prédicat",
    "prédictions": "prédiction",
    "prédictive": "prédictif",
    "prédilections": "prédilection",
    "prédira": "prédire",
    "prédirai": "prédire",
    "prédiraient": "prédire",
    "prédirais": "prédire",
    "prédirait": "prédire",
    "prédiras": "prédire",
    "prédirent": "prédire",
    "prédirez": "prédire",
    "prédiriez": "prédire",
    "prédirions": "prédire",
    "prédirons": "prédire",
    "prédiront": "prédire",
    "prédis": "prédire",
    "prédisaient": "prédire",
    "prédisais": "prédire",
    "prédisait": "prédire",
    "prédisant": "prédire",
    "prédise": "prédire",
    "prédisent": "prédire",
    "prédises": "prédire",
    "prédisez": "prédire",
    "prédisiez": "prédire",
    "prédisions": "prédire",
    "prédisons": "prédire",
    "prédisposa": "prédisposer",
    "prédisposai": "prédisposer",
    "prédisposaient": "prédisposer",
    "prédisposais": "prédisposer",
    "prédisposait": "prédisposer",
    "prédisposant": "prédisposer",
    "prédisposas": "prédisposer",
    "prédisposasse": "prédisposer",
    "prédisposassent": "prédisposer",
    "prédisposasses": "prédisposer",
    "prédisposassiez": "prédisposer",
    "prédisposassions": "prédisposer",
    "prédispose": "prédisposer",
    "prédisposent": "prédisposer",
    "prédisposera": "prédisposer",
    "prédisposerai": "prédisposer",
    "prédisposeraient": "prédisposer",
    "prédisposerais": "prédisposer",
    "prédisposerait": "prédisposer",
    "prédisposeras": "prédisposer",
    "prédisposerez": "prédisposer",
    "prédisposeriez": "prédisposer",
    "prédisposerions": "prédisposer",
    "prédisposerons": "prédisposer",
    "prédisposeront": "prédisposer",
    "prédisposes": "prédisposer",
    "prédisposez": "prédisposer",
    "prédisposiez": "prédisposer",
    "prédisposions": "prédisposer",
    "prédispositions": "prédisposition",
    "prédisposons": "prédisposer",
    "prédisposâmes": "prédisposer",
    "prédisposât": "prédisposer",
    "prédisposâtes": "prédisposer",
    "prédisposèrent": "prédisposer",
    "prédisposé": "prédisposer",
    "prédisposée": "prédisposer",
    "prédisposées": "prédisposer",
    "prédisposés": "prédisposer",
    "prédisse": "prédire",
    "prédissent": "prédire",
    "prédisses": "prédire",
    "prédissiez": "prédire",
    "prédissions": "prédire",
    "prédit": "prédire",
    "prédite": "prédit",
    "prédites": "prédire",
    "prédits": "prédire",
    "prédomina": "prédominer",
    "prédominai": "prédominer",
    "prédominaient": "prédominer",
    "prédominais": "prédominer",
    "prédominait": "prédominer",
    "prédominances": "prédominance",
    "prédominant": "prédominer",
    "prédominante": "prédominant",
    "prédominantes": "prédominant",
    "prédominants": "prédominant",
    "prédominas": "prédominer",
    "prédominasse": "prédominer",
    "prédominassent": "prédominer",
    "prédominasses": "prédominer",
    "prédominassiez": "prédominer",
    "prédominassions": "prédominer",
    "prédomine": "prédominer",
    "prédominent": "prédominer",
    "prédominera": "prédominer",
    "prédominerai": "prédominer",
    "prédomineraient": "prédominer",
    "prédominerais": "prédominer",
    "prédominerait": "prédominer",
    "prédomineras": "prédominer",
    "prédominerez": "prédominer",
    "prédomineriez": "prédominer",
    "prédominerions": "prédominer",
    "prédominerons": "prédominer",
    "prédomineront": "prédominer",
    "prédomines": "prédominer",
    "prédominez": "prédominer",
    "prédominiez": "prédominer",
    "prédominions": "prédominer",
    "prédominons": "prédominer",
    "prédominâmes": "prédominer",
    "prédominât": "prédominer",
    "prédominâtes": "prédominer",
    "prédominèrent": "prédominer",
    "prédominé": "prédominer",
    "prédécesseurs": "prédécesseur",
    "prédécoupée": "prédécoupé",
    "prédéfini": "prédéfinir",
    "prédéfinies": "prédéfinir",
    "prédétermina": "prédéterminer",
    "prédéterminai": "prédéterminer",
    "prédéterminaient": "prédéterminer",
    "prédéterminais": "prédéterminer",
    "prédéterminait": "prédéterminer",
    "prédéterminant": "prédéterminer",
    "prédéterminas": "prédéterminer",
    "prédéterminasse": "prédéterminer",
    "prédéterminassent": "prédéterminer",
    "prédéterminasses": "prédéterminer",
    "prédéterminassiez": "prédéterminer",
    "prédéterminassions": "prédéterminer",
    "prédétermine": "prédéterminer",
    "prédéterminent": "prédéterminer",
    "prédéterminera": "prédéterminer",
    "prédéterminerai": "prédéterminer",
    "prédétermineraient": "prédéterminer",
    "prédéterminerais": "prédéterminer",
    "prédéterminerait": "prédéterminer",
    "prédétermineras": "prédéterminer",
    "prédéterminerez": "prédéterminer",
    "prédétermineriez": "prédéterminer",
    "prédéterminerions": "prédéterminer",
    "prédéterminerons": "prédéterminer",
    "prédétermineront": "prédéterminer",
    "prédétermines": "prédéterminer",
    "prédéterminez": "prédéterminer",
    "prédéterminiez": "prédéterminer",
    "prédéterminions": "prédéterminer",
    "prédéterminons": "prédéterminer",
    "prédéterminâmes": "prédéterminer",
    "prédéterminât": "prédéterminer",
    "prédéterminâtes": "prédéterminer",
    "prédéterminèrent": "prédéterminer",
    "prédéterminé": "prédéterminer",
    "prédéterminée": "prédéterminer",
    "prédéterminées": "prédéterminer",
    "prédéterminés": "prédéterminer",
    "prédîmes": "prédire",
    "prédît": "prédire",
    "prédîtes": "prédire",
    "préemptions": "préemption",
    "préemptive": "préemptif",
    "préencollée": "préencollé",
    "préencollées": "préencollé",
    "préencollés": "préencollé",
    "préexcellences": "préexcellence",
    "préexista": "préexister",
    "préexistai": "préexister",
    "préexistaient": "préexister",
    "préexistais": "préexister",
    "préexistait": "préexister",
    "préexistant": "préexister",
    "préexistante": "préexistant",
    "préexistantes": "préexistant",
    "préexistants": "préexistant",
    "préexistas": "préexister",
    "préexistasse": "préexister",
    "préexistassent": "préexister",
    "préexistasses": "préexister",
    "préexistassiez": "préexister",
    "préexistassions": "préexister",
    "préexiste": "préexister",
    "préexistences": "préexistence",
    "préexistent": "préexister",
    "préexistera": "préexister",
    "préexisterai": "préexister",
    "préexisteraient": "préexister",
    "préexisterais": "préexister",
    "préexisterait": "préexister",
    "préexisteras": "préexister",
    "préexisterez": "préexister",
    "préexisteriez": "préexister",
    "préexisterions": "préexister",
    "préexisterons": "préexister",
    "préexisteront": "préexister",
    "préexistes": "préexister",
    "préexistez": "préexister",
    "préexistiez": "préexister",
    "préexistions": "préexister",
    "préexistons": "préexister",
    "préexistâmes": "préexister",
    "préexistât": "préexister",
    "préexistâtes": "préexister",
    "préexistèrent": "préexister",
    "préexisté": "préexister",
    "préfabriquée": "préfabriqué",
    "préfabriquées": "préfabriqué",
    "préfabriqués": "préfabriqué",
    "préface": "préfacer",
    "préfacent": "préfacer",
    "préfacera": "préfacer",
    "préfacerai": "préfacer",
    "préfaceraient": "préfacer",
    "préfacerais": "préfacer",
    "préfacerait": "préfacer",
    "préfaceras": "préfacer",
    "préfacerez": "préfacer",
    "préfaceriez": "préfacer",
    "préfacerions": "préfacer",
    "préfacerons": "préfacer",
    "préfaceront": "préfacer",
    "préfaces": "préfacer",
    "préfacez": "préfacer",
    "préfaciez": "préfacer",
    "préfacions": "préfacer",
    "préfacèrent": "préfacer",
    "préfacé": "préfacer",
    "préfacée": "préfacer",
    "préfacées": "préfacer",
    "préfacés": "préfacer",
    "préfaisabilités": "préfaisabilité",
    "préfaça": "préfacer",
    "préfaçai": "préfacer",
    "préfaçaient": "préfacer",
    "préfaçais": "préfacer",
    "préfaçait": "préfacer",
    "préfaçant": "préfacer",
    "préfaças": "préfacer",
    "préfaçasse": "préfacer",
    "préfaçassent": "préfacer",
    "préfaçasses": "préfacer",
    "préfaçassiez": "préfacer",
    "préfaçassions": "préfacer",
    "préfaçons": "préfacer",
    "préfaçâmes": "préfacer",
    "préfaçât": "préfacer",
    "préfaçâtes": "préfacer",
    "préfectorale": "préfectoral",
    "préfectorales": "préfectoral",
    "préfectoraux": "préfectoral",
    "préfectures": "préfecture",
    "préfets": "préfet",
    "préfigura": "préfigurer",
    "préfigurai": "préfigurer",
    "préfiguraient": "préfigurer",
    "préfigurais": "préfigurer",
    "préfigurait": "préfigurer",
    "préfigurant": "préfigurer",
    "préfiguras": "préfigurer",
    "préfigurasse": "préfigurer",
    "préfigurassent": "préfigurer",
    "préfigurasses": "préfigurer",
    "préfigurassiez": "préfigurer",
    "préfigurassions": "préfigurer",
    "préfigurations": "préfiguration",
    "préfigure": "préfigurer",
    "préfigurent": "préfigurer",
    "préfigurera": "préfigurer",
    "préfigurerai": "préfigurer",
    "préfigureraient": "préfigurer",
    "préfigurerais": "préfigurer",
    "préfigurerait": "préfigurer",
    "préfigureras": "préfigurer",
    "préfigurerez": "préfigurer",
    "préfigureriez": "préfigurer",
    "préfigurerions": "préfigurer",
    "préfigurerons": "préfigurer",
    "préfigureront": "préfigurer",
    "préfigures": "préfigurer",
    "préfigurez": "préfigurer",
    "préfiguriez": "préfigurer",
    "préfigurions": "préfigurer",
    "préfigurons": "préfigurer",
    "préfigurâmes": "préfigurer",
    "préfigurât": "préfigurer",
    "préfigurâtes": "préfigurer",
    "préfigurèrent": "préfigurer",
    "préfiguré": "préfigurer",
    "préfigurée": "préfigurer",
    "préfigurées": "préfigurer",
    "préfigurés": "préfigurer",
    "préfinancements": "préfinancement",
    "préfixa": "préfixer",
    "préfixai": "préfixer",
    "préfixaient": "préfixer",
    "préfixais": "préfixer",
    "préfixait": "préfixer",
    "préfixant": "préfixer",
    "préfixas": "préfixer",
    "préfixasse": "préfixer",
    "préfixassent": "préfixer",
    "préfixasses": "préfixer",
    "préfixassiez": "préfixer",
    "préfixassions": "préfixer",
    "préfixe": "préfixer",
    "préfixent": "préfixer",
    "préfixera": "préfixer",
    "préfixerai": "préfixer",
    "préfixeraient": "préfixer",
    "préfixerais": "préfixer",
    "préfixerait": "préfixer",
    "préfixeras": "préfixer",
    "préfixerez": "préfixer",
    "préfixeriez": "préfixer",
    "préfixerions": "préfixer",
    "préfixerons": "préfixer",
    "préfixeront": "préfixer",
    "préfixes": "préfixer",
    "préfixez": "préfixer",
    "préfixiez": "préfixer",
    "préfixions": "préfixer",
    "préfixons": "préfixer",
    "préfixâmes": "préfixer",
    "préfixât": "préfixer",
    "préfixâtes": "préfixer",
    "préfixèrent": "préfixer",
    "préfixé": "préfixer",
    "préfixée": "préfixer",
    "préfixées": "préfixer",
    "préfixés": "préfixer",
    "préforma": "préformer",
    "préformai": "préformer",
    "préformaient": "préformer",
    "préformais": "préformer",
    "préformait": "préformer",
    "préformant": "préformer",
    "préformas": "préformer",
    "préformasse": "préformer",
    "préformassent": "préformer",
    "préformasses": "préformer",
    "préformassiez": "préformer",
    "préformassions": "préformer",
    "préformations": "préformation",
    "préforme": "préformer",
    "préforment": "préformer",
    "préformera": "préformer",
    "préformerai": "préformer",
    "préformeraient": "préformer",
    "préformerais": "préformer",
    "préformerait": "préformer",
    "préformeras": "préformer",
    "préformerez": "préformer",
    "préformeriez": "préformer",
    "préformerions": "préformer",
    "préformerons": "préformer",
    "préformeront": "préformer",
    "préformes": "préformer",
    "préformez": "préformer",
    "préformiez": "préformer",
    "préformions": "préformer",
    "préformons": "préformer",
    "préformâmes": "préformer",
    "préformât": "préformer",
    "préformâtes": "préformer",
    "préformèrent": "préformer",
    "préformé": "préformer",
    "préformée": "préformer",
    "préformées": "préformer",
    "préformés": "préformer",
    "préfrontale": "préfrontal",
    "préfère": "préférer",
    "préfèrent": "préférer",
    "préfères": "préférer",
    "préfète": "préfet",
    "préfètes": "préfet",
    "préféra": "préférer",
    "préférables": "préférable",
    "préférai": "préférer",
    "préféraient": "préférer",
    "préférais": "préférer",
    "préférait": "préférer",
    "préférant": "préférer",
    "préféras": "préférer",
    "préférasse": "préférer",
    "préférassent": "préférer",
    "préférasses": "préférer",
    "préférassiez": "préférer",
    "préférassions": "préférer",
    "préférences": "préférence",
    "préférentielle": "préférentiel",
    "préférentielles": "préférentiel",
    "préférentiels": "préférentiel",
    "préférera": "préférer",
    "préférerai": "préférer",
    "préféreraient": "préférer",
    "préférerais": "préférer",
    "préférerait": "préférer",
    "préféreras": "préférer",
    "préférerez": "préférer",
    "préféreriez": "préférer",
    "préférerions": "préférer",
    "préférerons": "préférer",
    "préféreront": "préférer",
    "préférez": "préférer",
    "préfériez": "préférer",
    "préférions": "préférer",
    "préférons": "préférer",
    "préférâmes": "préférer",
    "préférât": "préférer",
    "préférâtes": "préférer",
    "préférèrent": "préférer",
    "préféré": "préférer",
    "préférée": "préférer",
    "préférées": "préférer",
    "préférés": "préférer",
    "prégnances": "prégnance",
    "prégnante": "prégnant",
    "prégnantes": "prégnant",
    "prégnants": "prégnant",
    "préhensions": "préhension",
    "préhensives": "préhensif",
    "préhistoires": "préhistoire",
    "préhistoriques": "préhistorique",
    "préjudices": "préjudice",
    "préjudiciables": "préjudiciable",
    "préjudicielle": "préjudiciel",
    "préjudicielles": "préjudiciel",
    "préjudiciels": "préjudiciel",
    "préjuge": "préjuger",
    "préjugea": "préjuger",
    "préjugeai": "préjuger",
    "préjugeaient": "préjuger",
    "préjugeais": "préjuger",
    "préjugeait": "préjuger",
    "préjugeant": "préjuger",
    "préjugeas": "préjuger",
    "préjugeasse": "préjuger",
    "préjugeassent": "préjuger",
    "préjugeasses": "préjuger",
    "préjugeassiez": "préjuger",
    "préjugeassions": "préjuger",
    "préjugent": "préjuger",
    "préjugeons": "préjuger",
    "préjugera": "préjuger",
    "préjugerai": "préjuger",
    "préjugeraient": "préjuger",
    "préjugerais": "préjuger",
    "préjugerait": "préjuger",
    "préjugeras": "préjuger",
    "préjugerez": "préjuger",
    "préjugeriez": "préjuger",
    "préjugerions": "préjuger",
    "préjugerons": "préjuger",
    "préjugeront": "préjuger",
    "préjuges": "préjuger",
    "préjugez": "préjuger",
    "préjugeâmes": "préjuger",
    "préjugeât": "préjuger",
    "préjugeâtes": "préjuger",
    "préjugiez": "préjuger",
    "préjugions": "préjuger",
    "préjugèrent": "préjuger",
    "préjugé": "préjuger",
    "préjugée": "préjuger",
    "préjugées": "préjuger",
    "préjugés": "préjuger",
    "prélassa": "prélasser",
    "prélassai": "prélasser",
    "prélassaient": "prélasser",
    "prélassais": "prélasser",
    "prélassait": "prélasser",
    "prélassant": "prélasser",
    "prélassas": "prélasser",
    "prélassasse": "prélasser",
    "prélassassent": "prélasser",
    "prélassasses": "prélasser",
    "prélassassiez": "prélasser",
    "prélassassions": "prélasser",
    "prélasse": "prélasser",
    "prélassent": "prélasser",
    "prélassera": "prélasser",
    "prélasserai": "prélasser",
    "prélasseraient": "prélasser",
    "prélasserais": "prélasser",
    "prélasserait": "prélasser",
    "prélasseras": "prélasser",
    "prélasserez": "prélasser",
    "prélasseriez": "prélasser",
    "prélasserions": "prélasser",
    "prélasserons": "prélasser",
    "prélasseront": "prélasser",
    "prélasses": "prélasser",
    "prélassez": "prélasser",
    "prélassiez": "prélasser",
    "prélassions": "prélasser",
    "prélassons": "prélasser",
    "prélassâmes": "prélasser",
    "prélassât": "prélasser",
    "prélassâtes": "prélasser",
    "prélassèrent": "prélasser",
    "prélassé": "prélasser",
    "prélassée": "prélasser",
    "prélassées": "prélasser",
    "prélassés": "prélasser",
    "prélats": "prélat",
    "préleva": "prélever",
    "prélevai": "prélever",
    "prélevaient": "prélever",
    "prélevais": "prélever",
    "prélevait": "prélever",
    "prélevant": "prélever",
    "prélevas": "prélever",
    "prélevasse": "prélever",
    "prélevassent": "prélever",
    "prélevasses": "prélever",
    "prélevassiez": "prélever",
    "prélevassions": "prélever",
    "prélevez": "prélever",
    "préleviez": "prélever",
    "prélevions": "prélever",
    "prélevons": "prélever",
    "prélevâmes": "prélever",
    "prélevât": "prélever",
    "prélevâtes": "prélever",
    "prélevèrent": "prélever",
    "prélevé": "prélever",
    "prélevée": "prélever",
    "prélevées": "prélever",
    "prélevés": "prélever",
    "préliminaires": "préliminaire",
    "préluda": "préluder",
    "préludai": "préluder",
    "préludaient": "préluder",
    "préludais": "préluder",
    "préludait": "préluder",
    "préludant": "préluder",
    "préludas": "préluder",
    "préludasse": "préluder",
    "préludassent": "préluder",
    "préludasses": "préluder",
    "préludassiez": "préluder",
    "préludassions": "préluder",
    "prélude": "préluder",
    "préludent": "préluder",
    "préludera": "préluder",
    "préluderai": "préluder",
    "préluderaient": "préluder",
    "préluderais": "préluder",
    "préluderait": "préluder",
    "préluderas": "préluder",
    "préluderez": "préluder",
    "préluderiez": "préluder",
    "préluderions": "préluder",
    "préluderons": "préluder",
    "préluderont": "préluder",
    "préludes": "préluder",
    "préludez": "préluder",
    "préludiez": "préluder",
    "préludions": "préluder",
    "préludons": "préluder",
    "préludâmes": "préluder",
    "préludât": "préluder",
    "préludâtes": "préluder",
    "préludèrent": "préluder",
    "préludé": "préluder",
    "prélève": "prélever",
    "prélèvements": "prélèvement",
    "prélèvent": "prélever",
    "prélèvera": "prélever",
    "prélèverai": "prélever",
    "prélèveraient": "prélever",
    "prélèverais": "prélever",
    "prélèverait": "prélever",
    "prélèveras": "prélever",
    "prélèverez": "prélever",
    "prélèveriez": "prélever",
    "prélèverions": "prélever",
    "prélèverons": "prélever",
    "prélèveront": "prélever",
    "prélèves": "prélever",
    "prématurée": "prématuré",
    "prématurées": "prématuré",
    "prématurés": "prématuré",
    "prémenstruelle": "prémenstruel",
    "prémisses": "prémisse",
    "prémolaires": "prémolaire",
    "prémonitions": "prémonition",
    "prémonitoires": "prémonitoire",
    "prémontrés": "prémontré",
    "prémuni": "prémunir",
    "prémunie": "prémunir",
    "prémunies": "prémunir",
    "prémunira": "prémunir",
    "prémunirai": "prémunir",
    "prémuniraient": "prémunir",
    "prémunirais": "prémunir",
    "prémunirait": "prémunir",
    "prémuniras": "prémunir",
    "prémunirent": "prémunir",
    "prémunirez": "prémunir",
    "prémuniriez": "prémunir",
    "prémunirions": "prémunir",
    "prémunirons": "prémunir",
    "prémuniront": "prémunir",
    "prémunis": "prémunir",
    "prémunissaient": "prémunir",
    "prémunissais": "prémunir",
    "prémunissait": "prémunir",
    "prémunissant": "prémunir",
    "prémunisse": "prémunir",
    "prémunissent": "prémunir",
    "prémunisses": "prémunir",
    "prémunissez": "prémunir",
    "prémunissiez": "prémunir",
    "prémunissions": "prémunir",
    "prémunissons": "prémunir",
    "prémunit": "prémunir",
    "prémunîmes": "prémunir",
    "prémunît": "prémunir",
    "prémunîtes": "prémunir",
    "prémédita": "préméditer",
    "préméditai": "préméditer",
    "préméditaient": "préméditer",
    "préméditais": "préméditer",
    "préméditait": "préméditer",
    "préméditant": "préméditer",
    "préméditas": "préméditer",
    "préméditasse": "préméditer",
    "préméditassent": "préméditer",
    "préméditasses": "préméditer",
    "préméditassiez": "préméditer",
    "préméditassions": "préméditer",
    "préméditations": "préméditation",
    "prémédite": "préméditer",
    "préméditent": "préméditer",
    "préméditera": "préméditer",
    "préméditerai": "préméditer",
    "préméditeraient": "préméditer",
    "préméditerais": "préméditer",
    "préméditerait": "préméditer",
    "préméditeras": "préméditer",
    "préméditerez": "préméditer",
    "préméditeriez": "préméditer",
    "préméditerions": "préméditer",
    "préméditerons": "préméditer",
    "préméditeront": "préméditer",
    "prémédites": "préméditer",
    "préméditez": "préméditer",
    "préméditiez": "préméditer",
    "préméditions": "préméditer",
    "préméditons": "préméditer",
    "préméditâmes": "préméditer",
    "préméditât": "préméditer",
    "préméditâtes": "préméditer",
    "préméditèrent": "préméditer",
    "prémédité": "préméditer",
    "préméditée": "préméditer",
    "préméditées": "préméditer",
    "prémédités": "préméditer",
    "prénatale": "prénatal",
    "prénatales": "prénatal",
    "prénatals": "prénatal",
    "prénataux": "prénatal",
    "prénomma": "prénommer",
    "prénommai": "prénommer",
    "prénommaient": "prénommer",
    "prénommais": "prénommer",
    "prénommait": "prénommer",
    "prénommant": "prénommer",
    "prénommas": "prénommer",
    "prénommasse": "prénommer",
    "prénommassent": "prénommer",
    "prénommasses": "prénommer",
    "prénommassiez": "prénommer",
    "prénommassions": "prénommer",
    "prénomme": "prénommer",
    "prénomment": "prénommer",
    "prénommera": "prénommer",
    "prénommerai": "prénommer",
    "prénommeraient": "prénommer",
    "prénommerais": "prénommer",
    "prénommerait": "prénommer",
    "prénommeras": "prénommer",
    "prénommerez": "prénommer",
    "prénommeriez": "prénommer",
    "prénommerions": "prénommer",
    "prénommerons": "prénommer",
    "prénommeront": "prénommer",
    "prénommes": "prénommer",
    "prénommez": "prénommer",
    "prénommiez": "prénommer",
    "prénommions": "prénommer",
    "prénommons": "prénommer",
    "prénommâmes": "prénommer",
    "prénommât": "prénommer",
    "prénommâtes": "prénommer",
    "prénommèrent": "prénommer",
    "prénommé": "prénommer",
    "prénommée": "prénommer",
    "prénommées": "prénommer",
    "prénommés": "prénommer",
    "prénoms": "prénom",
    "prénormatifs": "prénormatif",
    "prénormatives": "prénormatif",
    "prénormes": "prénorme",
    "prénuptiale": "prénuptial",
    "prénuptiales": "prénuptial",
    "prénuptiaux": "prénuptial",
    "préoccupa": "préoccuper",
    "préoccupai": "préoccuper",
    "préoccupaient": "préoccuper",
    "préoccupais": "préoccuper",
    "préoccupait": "préoccuper",
    "préoccupant": "préoccuper",
    "préoccupante": "préoccupant",
    "préoccupantes": "préoccupant",
    "préoccupants": "préoccupant",
    "préoccupas": "préoccuper",
    "préoccupasse": "préoccuper",
    "préoccupassent": "préoccuper",
    "préoccupasses": "préoccuper",
    "préoccupassiez": "préoccuper",
    "préoccupassions": "préoccuper",
    "préoccupations": "préoccupation",
    "préoccupe": "préoccuper",
    "préoccupent": "préoccuper",
    "préoccupera": "préoccuper",
    "préoccuperai": "préoccuper",
    "préoccuperaient": "préoccuper",
    "préoccuperais": "préoccuper",
    "préoccuperait": "préoccuper",
    "préoccuperas": "préoccuper",
    "préoccuperez": "préoccuper",
    "préoccuperiez": "préoccuper",
    "préoccuperions": "préoccuper",
    "préoccuperons": "préoccuper",
    "préoccuperont": "préoccuper",
    "préoccupes": "préoccuper",
    "préoccupez": "préoccuper",
    "préoccupiez": "préoccuper",
    "préoccupions": "préoccuper",
    "préoccupons": "préoccuper",
    "préoccupâmes": "préoccuper",
    "préoccupât": "préoccuper",
    "préoccupâtes": "préoccuper",
    "préoccupèrent": "préoccuper",
    "préoccupé": "préoccuper",
    "préoccupée": "préoccuper",
    "préoccupées": "préoccuper",
    "préoccupés": "préoccuper",
    "préopératoires": "préopératoire",
    "prépara": "préparer",
    "préparai": "préparer",
    "préparaient": "préparer",
    "préparais": "préparer",
    "préparait": "préparer",
    "préparant": "préparer",
    "préparas": "préparer",
    "préparasse": "préparer",
    "préparassent": "préparer",
    "préparasses": "préparer",
    "préparassiez": "préparer",
    "préparassions": "préparer",
    "préparateurs": "préparateur",
    "préparatifs": "préparatif",
    "préparations": "préparation",
    "préparatoires": "préparatoire",
    "préparatrice": "préparateur",
    "préparatrices": "préparateur",
    "prépare": "préparer",
    "préparent": "préparer",
    "préparera": "préparer",
    "préparerai": "préparer",
    "prépareraient": "préparer",
    "préparerais": "préparer",
    "préparerait": "préparer",
    "prépareras": "préparer",
    "préparerez": "préparer",
    "prépareriez": "préparer",
    "préparerions": "préparer",
    "préparerons": "préparer",
    "prépareront": "préparer",
    "prépares": "préparer",
    "préparez": "préparer",
    "prépariez": "préparer",
    "préparions": "préparer",
    "préparons": "préparer",
    "préparâmes": "préparer",
    "préparât": "préparer",
    "préparâtes": "préparer",
    "préparèrent": "préparer",
    "préparé": "préparer",
    "préparée": "préparer",
    "préparées": "préparer",
    "préparés": "préparer",
    "prépayée": "prépayer",
    "prépondérances": "prépondérance",
    "prépondérante": "prépondérant",
    "prépondérantes": "prépondérant",
    "prépondérants": "prépondérant",
    "préposa": "préposer",
    "préposai": "préposer",
    "préposaient": "préposer",
    "préposais": "préposer",
    "préposait": "préposer",
    "préposant": "préposer",
    "préposas": "préposer",
    "préposasse": "préposer",
    "préposassent": "préposer",
    "préposasses": "préposer",
    "préposassiez": "préposer",
    "préposassions": "préposer",
    "prépose": "préposer",
    "préposent": "préposer",
    "préposera": "préposer",
    "préposerai": "préposer",
    "préposeraient": "préposer",
    "préposerais": "préposer",
    "préposerait": "préposer",
    "préposeras": "préposer",
    "préposerez": "préposer",
    "préposeriez": "préposer",
    "préposerions": "préposer",
    "préposerons": "préposer",
    "préposeront": "préposer",
    "préposes": "préposer",
    "préposez": "préposer",
    "préposiez": "préposer",
    "préposions": "préposer",
    "prépositions": "préposition",
    "préposons": "préposer",
    "préposâmes": "préposer",
    "préposât": "préposer",
    "préposâtes": "préposer",
    "préposèrent": "préposer",
    "préposé": "préposer",
    "préposée": "préposer",
    "préposées": "préposer",
    "préposés": "préposer",
    "préprogrammée": "préprogrammé",
    "prépuces": "prépuce",
    "préretraites": "préretraite",
    "préretraités": "préretraité",
    "prérogatives": "prérogative",
    "préréglé": "prérégler",
    "prérévolutionnaires": "prérévolutionnaire",
    "prés": "pré",
    "prés-salés": "pré-salé",
    "présage": "présager",
    "présagea": "présager",
    "présageai": "présager",
    "présageaient": "présager",
    "présageais": "présager",
    "présageait": "présager",
    "présageant": "présager",
    "présageas": "présager",
    "présageasse": "présager",
    "présageassent": "présager",
    "présageasses": "présager",
    "présageassiez": "présager",
    "présageassions": "présager",
    "présagent": "présager",
    "présageons": "présager",
    "présagera": "présager",
    "présagerai": "présager",
    "présageraient": "présager",
    "présagerais": "présager",
    "présagerait": "présager",
    "présageras": "présager",
    "présagerez": "présager",
    "présageriez": "présager",
    "présagerions": "présager",
    "présagerons": "présager",
    "présageront": "présager",
    "présages": "présager",
    "présagez": "présager",
    "présageâmes": "présager",
    "présageât": "présager",
    "présageâtes": "présager",
    "présagiez": "présager",
    "présagions": "présager",
    "présagèrent": "présager",
    "présagé": "présager",
    "présagée": "présager",
    "présagées": "présager",
    "présagés": "présager",
    "préscolaires": "préscolaire",
    "présences": "présence",
    "présenta": "présenter",
    "présentables": "présentable",
    "présentai": "présenter",
    "présentaient": "présenter",
    "présentais": "présenter",
    "présentait": "présenter",
    "présentant": "présenter",
    "présentas": "présenter",
    "présentasse": "présenter",
    "présentassent": "présenter",
    "présentasses": "présenter",
    "présentassiez": "présenter",
    "présentassions": "présenter",
    "présentateurs": "présentateur",
    "présentations": "présentation",
    "présentatrice": "présentateur",
    "présentatrices": "présentateur",
    "présente": "présenter",
    "présentent": "présenter",
    "présenter": "poster",
    "présentera": "présenter",
    "présenterai": "présenter",
    "présenteraient": "présenter",
    "présenterais": "présenter",
    "présenterait": "présenter",
    "présenteras": "présenter",
    "présenterez": "présenter",
    "présenteriez": "présenter",
    "présenterions": "présenter",
    "présenterons": "présenter",
    "présenteront": "présenter",
    "présentes": "présenter",
    "présentez": "présenter",
    "présentiez": "présenter",
    "présentions": "présenter",
    "présentoirs": "présentoir",
    "présentons": "présenter",
    "présents": "présent",
    "présentâmes": "présenter",
    "présentât": "présenter",
    "présentâtes": "présenter",
    "présentèrent": "présenter",
    "présenté": "présenter",
    "présentée": "présenter",
    "présentées": "présenter",
    "présentés": "présenter",
    "préserva": "préserver",
    "préservai": "préserver",
    "préservaient": "préserver",
    "préservais": "préserver",
    "préservait": "préserver",
    "préservant": "préserver",
    "préservas": "préserver",
    "préservasse": "préserver",
    "préservassent": "préserver",
    "préservasses": "préserver",
    "préservassiez": "préserver",
    "préservassions": "préserver",
    "préservatifs": "préservatif",
    "préservations": "préservation",
    "préserve": "préserver",
    "préservent": "préserver",
    "préservera": "préserver",
    "préserverai": "préserver",
    "préserveraient": "préserver",
    "préserverais": "préserver",
    "préserverait": "préserver",
    "préserveras": "préserver",
    "préserverez": "préserver",
    "préserveriez": "préserver",
    "préserverions": "préserver",
    "préserverons": "préserver",
    "préserveront": "préserver",
    "préserves": "préserver",
    "préservez": "préserver",
    "préserviez": "préserver",
    "préservions": "préserver",
    "préservons": "préserver",
    "préservâmes": "préserver",
    "préservât": "préserver",
    "préservâtes": "préserver",
    "préservèrent": "préserver",
    "préservé": "préserver",
    "préservée": "préserver",
    "préservées": "préserver",
    "préservés": "préserver",
    "présida": "présider",
    "présidai": "présider",
    "présidaient": "présider",
    "présidais": "présider",
    "présidait": "présider",
    "présidant": "présider",
    "présidas": "présider",
    "présidasse": "présider",
    "présidassent": "présider",
    "présidasses": "présider",
    "présidassiez": "présider",
    "présidassions": "présider",
    "préside": "présider",
    "présidences": "présidence",
    "président": "présider",
    "présidente": "président",
    "présidentes": "président",
    "présidentiabilités": "présidentiabilité",
    "présidentiables": "présidentiable",
    "présidentialisations": "présidentialisation",
    "présidentielle": "présidentiel",
    "présidentielles": "présidentiel",
    "présidentiels": "présidentiel",
    "présidents": "président",
    "présidents-directeurs": "président-directeur",
    "présidera": "présider",
    "présiderai": "présider",
    "présideraient": "présider",
    "présiderais": "présider",
    "présiderait": "présider",
    "présideras": "présider",
    "présiderez": "présider",
    "présideriez": "présider",
    "présiderions": "présider",
    "présiderons": "présider",
    "présideront": "présider",
    "présides": "présider",
    "présidez": "présider",
    "présidiaux": "présidial",
    "présidiez": "présider",
    "présidions": "présider",
    "présidons": "présider",
    "présidâmes": "présider",
    "présidât": "présider",
    "présidâtes": "présider",
    "présidèrent": "présider",
    "présidé": "présider",
    "présidée": "présider",
    "présidées": "présider",
    "présidés": "présider",
    "présocratiques": "présocratique",
    "présomptifs": "présomptif",
    "présomptions": "présomption",
    "présomptive": "présomptif",
    "présomptives": "présomptif",
    "présomptueuse": "présomptueux",
    "présomptueuses": "présomptueux",
    "présuma": "présumer",
    "présumables": "présumable",
    "présumai": "présumer",
    "présumaient": "présumer",
    "présumais": "présumer",
    "présumait": "présumer",
    "présumant": "présumer",
    "présumas": "présumer",
    "présumasse": "présumer",
    "présumassent": "présumer",
    "présumasses": "présumer",
    "présumassiez": "présumer",
    "présumassions": "présumer",
    "présume": "présumer",
    "présument": "présumer",
    "présumera": "présumer",
    "présumerai": "présumer",
    "présumeraient": "présumer",
    "présumerais": "présumer",
    "présumerait": "présumer",
    "présumeras": "présumer",
    "présumerez": "présumer",
    "présumeriez": "présumer",
    "présumerions": "présumer",
    "présumerons": "présumer",
    "présumeront": "présumer",
    "présumes": "présumer",
    "présumez": "présumer",
    "présumiez": "présumer",
    "présumions": "présumer",
    "présumons": "présumer",
    "présumâmes": "présumer",
    "présumât": "présumer",
    "présumâtes": "présumer",
    "présumèrent": "présumer",
    "présumé": "présumer",
    "présumée": "présumer",
    "présumées": "présumer",
    "présumés": "présumer",
    "présupposa": "présupposer",
    "présupposai": "présupposer",
    "présupposaient": "présupposer",
    "présupposais": "présupposer",
    "présupposait": "présupposer",
    "présupposant": "présupposer",
    "présupposas": "présupposer",
    "présupposasse": "présupposer",
    "présupposassent": "présupposer",
    "présupposasses": "présupposer",
    "présupposassiez": "présupposer",
    "présupposassions": "présupposer",
    "présuppose": "présupposer",
    "présupposent": "présupposer",
    "présupposera": "présupposer",
    "présupposerai": "présupposer",
    "présupposeraient": "présupposer",
    "présupposerais": "présupposer",
    "présupposerait": "présupposer",
    "présupposeras": "présupposer",
    "présupposerez": "présupposer",
    "présupposeriez": "présupposer",
    "présupposerions": "présupposer",
    "présupposerons": "présupposer",
    "présupposeront": "présupposer",
    "présupposes": "présupposer",
    "présupposez": "présupposer",
    "présupposiez": "présupposer",
    "présupposions": "présupposer",
    "présupposons": "présupposer",
    "présupposâmes": "présupposer",
    "présupposât": "présupposer",
    "présupposâtes": "présupposer",
    "présupposèrent": "présupposer",
    "présupposé": "présupposer",
    "présupposée": "présupposer",
    "présupposées": "présupposer",
    "présupposés": "présupposer",
    "présures": "présure",
    "préséances": "préséance",
    "présélectionné": "présélectionner",
    "présélectionnée": "présélectionner",
    "présélectionnées": "présélectionné",
    "présélectionnés": "présélectionné",
    "présélections": "présélection",
    "préséniles": "présénile",
    "prétend": "prétendre",
    "prétendaient": "prétendre",
    "prétendais": "prétendre",
    "prétendait": "prétendre",
    "prétendant": "prétendre",
    "prétendante": "prétendant",
    "prétendantes": "prétendant",
    "prétendants": "prétendant",
    "prétende": "prétendre",
    "prétendent": "prétendre",
    "prétendes": "prétendre",
    "prétendez": "prétendre",
    "prétendiez": "prétendre",
    "prétendions": "prétendre",
    "prétendirent": "prétendre",
    "prétendis": "prétendre",
    "prétendisse": "prétendre",
    "prétendissent": "prétendre",
    "prétendisses": "prétendre",
    "prétendissiez": "prétendre",
    "prétendissions": "prétendre",
    "prétendit": "prétendre",
    "prétendons": "prétendre",
    "prétendra": "prétendre",
    "prétendrai": "prétendre",
    "prétendraient": "prétendre",
    "prétendrais": "prétendre",
    "prétendrait": "prétendre",
    "prétendras": "prétendre",
    "prétendrez": "prétendre",
    "prétendriez": "prétendre",
    "prétendrions": "prétendre",
    "prétendrons": "prétendre",
    "prétendront": "prétendre",
    "prétends": "prétendre",
    "prétendu": "prétendre",
    "prétendue": "prétendu",
    "prétendues": "prétendu",
    "prétendus": "prétendu",
    "prétendîmes": "prétendre",
    "prétendît": "prétendre",
    "prétendîtes": "prétendre",
    "prétentaines": "prétentaine",
    "prétentiarde": "prétentiard",
    "prétentiards": "prétentiard",
    "prétentieuse": "prétentieux",
    "prétentieuses": "prétentieux",
    "prétentions": "prétention",
    "préteurs": "préteur",
    "prétexta": "prétexter",
    "prétextai": "prétexter",
    "prétextaient": "prétexter",
    "prétextais": "prétexter",
    "prétextait": "prétexter",
    "prétextant": "prétexter",
    "prétextas": "prétexter",
    "prétextasse": "prétexter",
    "prétextassent": "prétexter",
    "prétextasses": "prétexter",
    "prétextassiez": "prétexter",
    "prétextassions": "prétexter",
    "prétexte": "prétexter",
    "prétextent": "prétexter",
    "prétextera": "prétexter",
    "prétexterai": "prétexter",
    "prétexteraient": "prétexter",
    "prétexterais": "prétexter",
    "prétexterait": "prétexter",
    "prétexteras": "prétexter",
    "prétexterez": "prétexter",
    "prétexteriez": "prétexter",
    "prétexterions": "prétexter",
    "prétexterons": "prétexter",
    "prétexteront": "prétexter",
    "prétextes": "prétexter",
    "prétextez": "prétexter",
    "prétextiez": "prétexter",
    "prétextions": "prétexter",
    "prétextons": "prétexter",
    "prétextâmes": "prétexter",
    "prétextât": "prétexter",
    "prétextâtes": "prétexter",
    "prétextèrent": "prétexter",
    "prétexté": "prétexter",
    "prétextée": "prétexter",
    "prétextées": "prétexter",
    "prétextés": "prétexter",
    "prétoires": "prétoire",
    "prétorienne": "prétorien",
    "prétoriennes": "prétorien",
    "prétoriens": "prétorien",
    "prétraitements": "prétraitement",
    "prétéritions": "prétérition",
    "prétérits": "prétérit",
    "prévalaient": "prévaloir",
    "prévalais": "prévaloir",
    "prévalait": "prévaloir",
    "prévalant": "prévaloir",
    "prévale": "prévaloir",
    "prévalences": "prévalence",
    "prévalent": "prévaloir",
    "prévales": "prévaloir",
    "prévalez": "prévaloir",
    "prévaliez": "prévaloir",
    "prévalions": "prévaloir",
    "prévalons": "prévaloir",
    "prévalu": "prévaloir",
    "prévalue": "prévaloir",
    "prévalues": "prévaloir",
    "prévalurent": "prévaloir",
    "prévalus": "prévaloir",
    "prévalusse": "prévaloir",
    "prévalussent": "prévaloir",
    "prévalusses": "prévaloir",
    "prévalussiez": "prévaloir",
    "prévalussions": "prévaloir",
    "prévalut": "prévaloir",
    "prévalûmes": "prévaloir",
    "prévalût": "prévaloir",
    "prévalûtes": "prévaloir",
    "prévarications": "prévarication",
    "prévariqua": "prévariquer",
    "prévariquai": "prévariquer",
    "prévariquaient": "prévariquer",
    "prévariquais": "prévariquer",
    "prévariquait": "prévariquer",
    "prévariquant": "prévariquer",
    "prévariquas": "prévariquer",
    "prévariquasse": "prévariquer",
    "prévariquassent": "prévariquer",
    "prévariquasses": "prévariquer",
    "prévariquassiez": "prévariquer",
    "prévariquassions": "prévariquer",
    "prévarique": "prévariquer",
    "prévariquent": "prévariquer",
    "prévariquera": "prévariquer",
    "prévariquerai": "prévariquer",
    "prévariqueraient": "prévariquer",
    "prévariquerais": "prévariquer",
    "prévariquerait": "prévariquer",
    "prévariqueras": "prévariquer",
    "prévariquerez": "prévariquer",
    "prévariqueriez": "prévariquer",
    "prévariquerions": "prévariquer",
    "prévariquerons": "prévariquer",
    "prévariqueront": "prévariquer",
    "prévariques": "prévariquer",
    "prévariquez": "prévariquer",
    "prévariquiez": "prévariquer",
    "prévariquions": "prévariquer",
    "prévariquons": "prévariquer",
    "prévariquâmes": "prévariquer",
    "prévariquât": "prévariquer",
    "prévariquâtes": "prévariquer",
    "prévariquèrent": "prévariquer",
    "prévariqué": "prévariquer",
    "prévaudra": "prévaloir",
    "prévaudrai": "prévaloir",
    "prévaudraient": "prévaloir",
    "prévaudrais": "prévaloir",
    "prévaudrait": "prévaloir",
    "prévaudras": "prévaloir",
    "prévaudrez": "prévaloir",
    "prévaudriez": "prévaloir",
    "prévaudrions": "prévaloir",
    "prévaudrons": "prévaloir",
    "prévaudront": "prévaloir",
    "prévaut": "prévaloir",
    "prévaux": "prévaloir",
    "prévenaient": "prévenir",
    "prévenais": "prévenir",
    "prévenait": "prévenir",
    "prévenances": "prévenance",
    "prévenant": "prévenir",
    "prévenante": "prévenant",
    "prévenantes": "prévenant",
    "prévenants": "prévenant",
    "prévenez": "prévenir",
    "préveniez": "prévenir",
    "prévenions": "prévenir",
    "prévenons": "prévenir",
    "préventifs": "préventif",
    "préventions": "prévention",
    "préventive": "préventif",
    "préventives": "préventif",
    "préventoriums": "préventorium",
    "prévenu": "prévenir",
    "prévenue": "prévenu",
    "prévenues": "prévenu",
    "prévenus": "prévenu",
    "préviendra": "prévenir",
    "préviendrai": "prévenir",
    "préviendraient": "prévenir",
    "préviendrais": "prévenir",
    "préviendrait": "prévenir",
    "préviendras": "prévenir",
    "préviendrez": "prévenir",
    "préviendriez": "prévenir",
    "préviendrions": "prévenir",
    "préviendrons": "prévenir",
    "préviendront": "prévenir",
    "prévienne": "prévenir",
    "préviennent": "prévenir",
    "préviennes": "prévenir",
    "préviens": "prévenir",
    "prévient": "prévenir",
    "prévinrent": "prévenir",
    "prévins": "prévenir",
    "prévinsse": "prévenir",
    "prévinssent": "prévenir",
    "prévinsses": "prévenir",
    "prévinssiez": "prévenir",
    "prévinssions": "prévenir",
    "prévint": "prévenir",
    "prévirent": "prévoir",
    "prévis": "prévoir",
    "prévisibles": "prévisible",
    "prévisionnelle": "prévisionnel",
    "prévisionnelles": "prévisionnel",
    "prévisionnels": "prévisionnel",
    "prévisions": "prévision",
    "prévisse": "prévoir",
    "prévissent": "prévoir",
    "prévisses": "prévoir",
    "prévissiez": "prévoir",
    "prévissions": "prévoir",
    "prévit": "prévoir",
    "prévoie": "prévoir",
    "prévoient": "prévoir",
    "prévoies": "prévoir",
    "prévoira": "prévoir",
    "prévoirai": "prévoir",
    "prévoiraient": "prévoir",
    "prévoirais": "prévoir",
    "prévoirait": "prévoir",
    "prévoiras": "prévoir",
    "prévoirez": "prévoir",
    "prévoiriez": "prévoir",
    "prévoirions": "prévoir",
    "prévoirons": "prévoir",
    "prévoiront": "prévoir",
    "prévois": "prévoir",
    "prévoit": "prévoir",
    "prévoyaient": "prévoir",
    "prévoyais": "prévoir",
    "prévoyait": "prévoir",
    "prévoyances": "prévoyance",
    "prévoyant": "prévoir",
    "prévoyante": "prévoyant",
    "prévoyantes": "prévoyant",
    "prévoyants": "prévoyant",
    "prévoyez": "prévoir",
    "prévoyiez": "prévoir",
    "prévoyions": "prévoir",
    "prévoyons": "prévoir",
    "prévu": "prévoir",
    "prévue": "prévoir",
    "prévues": "prévoir",
    "prévus": "prévoir",
    "prévîmes": "prévoir",
    "prévînmes": "prévenir",
    "prévînt": "prévenir",
    "prévîntes": "prévenir",
    "prévît": "prévoir",
    "prévîtes": "prévoir",
    "prévôts": "prévôt",
    "préélectorale": "préélectoral",
    "préélectorales": "préélectoral",
    "préélectoraux": "préélectoral",
    "prééminences": "prééminence",
    "prééminente": "prééminent",
    "prééminentes": "prééminent",
    "prééminents": "prééminent",
    "préétabli": "préétablir",
    "préétablie": "préétablir",
    "préétablies": "préétablir",
    "préétablira": "préétablir",
    "préétablirai": "préétablir",
    "préétabliraient": "préétablir",
    "préétablirais": "préétablir",
    "préétablirait": "préétablir",
    "préétabliras": "préétablir",
    "préétablirent": "préétablir",
    "préétablirez": "préétablir",
    "préétabliriez": "préétablir",
    "préétablirions": "préétablir",
    "préétablirons": "préétablir",
    "préétabliront": "préétablir",
    "préétablis": "préétablir",
    "préétablissaient": "préétablir",
    "préétablissais": "préétablir",
    "préétablissait": "préétablir",
    "préétablissant": "préétablir",
    "préétablisse": "préétablir",
    "préétablissent": "préétablir",
    "préétablisses": "préétablir",
    "préétablissez": "préétablir",
    "préétablissiez": "préétablir",
    "préétablissions": "préétablir",
    "préétablissons": "préétablir",
    "préétablit": "préétablir",
    "préétablîmes": "préétablir",
    "préétablît": "préétablir",
    "préétablîtes": "préétablir",
    "prêcha": "prêcher",
    "prêchai": "prêcher",
    "prêchaient": "prêcher",
    "prêchais": "prêcher",
    "prêchait": "prêcher",
    "prêchant": "prêcher",
    "prêchas": "prêcher",
    "prêchasse": "prêcher",
    "prêchassent": "prêcher",
    "prêchasses": "prêcher",
    "prêchassiez": "prêcher",
    "prêchassions": "prêcher",
    "prêche": "prêcher",
    "prêchent": "prêcher",
    "prêchera": "prêcher",
    "prêcherai": "prêcher",
    "prêcheraient": "prêcher",
    "prêcherais": "prêcher",
    "prêcherait": "prêcher",
    "prêcheras": "prêcher",
    "prêcherez": "prêcher",
    "prêcheriez": "prêcher",
    "prêcherions": "prêcher",
    "prêcherons": "prêcher",
    "prêcheront": "prêcher",
    "prêches": "prêcher",
    "prêcheurs": "prêcheur",
    "prêcheuse": "prêcheur",
    "prêchez": "prêcher",
    "prêchiez": "prêcher",
    "prêchions": "prêcher",
    "prêchons": "prêcher",
    "prêchâmes": "prêcher",
    "prêchât": "prêcher",
    "prêchâtes": "prêcher",
    "prêchèrent": "prêcher",
    "prêché": "prêcher",
    "prêchée": "prêcher",
    "prêchées": "prêcher",
    "prêchés": "prêcher",
    "prêles": "prêle",
    "prêta": "prêter",
    "prêtai": "prêter",
    "prêtaient": "prêter",
    "prêtais": "prêter",
    "prêtait": "prêter",
    "prêtant": "prêter",
    "prêtas": "prêter",
    "prêtasse": "prêter",
    "prêtassent": "prêter",
    "prêtasses": "prêter",
    "prêtassiez": "prêter",
    "prêtassions": "prêter",
    "prête": "prêter",
    "prête-noms": "prête-nom",
    "prêtent": "prêter",
    "prêtera": "prêter",
    "prêterai": "prêter",
    "prêteraient": "prêter",
    "prêterais": "prêter",
    "prêterait": "prêter",
    "prêteras": "prêter",
    "prêterez": "prêter",
    "prêteriez": "prêter",
    "prêterions": "prêter",
    "prêterons": "prêter",
    "prêteront": "prêter",
    "prêtes": "prêter",
    "prêteurs": "prêteur",
    "prêteuse": "prêteur",
    "prêteuses": "prêteur",
    "prêtez": "prêter",
    "prêtiez": "prêter",
    "prêtions": "prêter",
    "prêtons": "prêter",
    "prêtres": "prêtre",
    "prêtresse": "prêtre",
    "prêtresses": "prêtre",
    "prêtrises": "prêtrise",
    "prêts": "prêt",
    "prêts-à-porter": "prêt-à-porter",
    "prêtâmes": "prêter",
    "prêtât": "prêter",
    "prêtâtes": "prêter",
    "prêtèrent": "prêter",
    "prêté": "prêter",
    "prêtée": "prêter",
    "prêtées": "prêter",
    "prêtés": "prêter",
    "prîmes": "prendre",
    "prît": "prendre",
    "prîtes": "prendre",
    "prôna": "prôner",
    "prônai": "prôner",
    "prônaient": "prôner",
    "prônais": "prôner",
    "prônait": "prôner",
    "prônant": "prôner",
    "prônas": "prôner",
    "prônasse": "prôner",
    "prônassent": "prôner",
    "prônasses": "prôner",
    "prônassiez": "prôner",
    "prônassions": "prôner",
    "prône": "prôner",
    "prônent": "prôner",
    "prônera": "prôner",
    "prônerai": "prôner",
    "prôneraient": "prôner",
    "prônerais": "prôner",
    "prônerait": "prôner",
    "prôneras": "prôner",
    "prônerez": "prôner",
    "prôneriez": "prôner",
    "prônerions": "prôner",
    "prônerons": "prôner",
    "prôneront": "prôner",
    "prônes": "prôner",
    "prônez": "prôner",
    "prôniez": "prôner",
    "prônions": "prôner",
    "prônons": "prôner",
    "prônâmes": "prôner",
    "prônât": "prôner",
    "prônâtes": "prôner",
    "prônèrent": "prôner",
    "prôné": "prôner",
    "prônée": "prôner",
    "prônées": "prôner",
    "prônés": "prôner",
    "psalliotes": "psalliote",
    "psalmodia": "psalmodier",
    "psalmodiaient": "psalmodier",
    "psalmodiais": "psalmodier",
    "psalmodiait": "psalmodier",
    "psalmodiant": "psalmodier",
    "psalmodie": "psalmodier",
    "psalmodient": "psalmodier",
    "psalmodies": "psalmodier",
    "psalmodié": "psalmodier",
    "psalmodiés": "psalmodier",
    "psaumes": "psaume",
    "psautiers": "psautier",
    "pschents": "pschent",
    "pseudonymes": "pseudonyme",
    "pseudonymies": "pseudonymie",
    "pseudopodes": "pseudopode",
    "pseudos": "pseudo",
    "psittacismes": "psittacisme",
    "psychanalysa": "psychanalyser",
    "psychanalysai": "psychanalyser",
    "psychanalysaient": "psychanalyser",
    "psychanalysais": "psychanalyser",
    "psychanalysait": "psychanalyser",
    "psychanalysant": "psychanalyser",
    "psychanalysas": "psychanalyser",
    "psychanalysasse": "psychanalyser",
    "psychanalysassent": "psychanalyser",
    "psychanalysasses": "psychanalyser",
    "psychanalysassiez": "psychanalyser",
    "psychanalysassions": "psychanalyser",
    "psychanalyse": "psychanalyser",
    "psychanalysent": "psychanalyser",
    "psychanalysera": "psychanalyser",
    "psychanalyserai": "psychanalyser",
    "psychanalyseraient": "psychanalyser",
    "psychanalyserais": "psychanalyser",
    "psychanalyserait": "psychanalyser",
    "psychanalyseras": "psychanalyser",
    "psychanalyserez": "psychanalyser",
    "psychanalyseriez": "psychanalyser",
    "psychanalyserions": "psychanalyser",
    "psychanalyserons": "psychanalyser",
    "psychanalyseront": "psychanalyser",
    "psychanalyses": "psychanalyser",
    "psychanalysez": "psychanalyser",
    "psychanalysiez": "psychanalyser",
    "psychanalysions": "psychanalyser",
    "psychanalysons": "psychanalyser",
    "psychanalystes": "psychanalyste",
    "psychanalysâmes": "psychanalyser",
    "psychanalysât": "psychanalyser",
    "psychanalysâtes": "psychanalyser",
    "psychanalysèrent": "psychanalyser",
    "psychanalysé": "psychanalyser",
    "psychanalysée": "psychanalyser",
    "psychanalysées": "psychanalyser",
    "psychanalysés": "psychanalyser",
    "psychanalytiques": "psychanalytique",
    "psychasthénies": "psychasthénie",
    "psychasthéniques": "psychasthénique",
    "psychiatres": "psychiatre",
    "psychiatries": "psychiatrie",
    "psychiatriques": "psychiatrique",
    "psychiques": "psychique",
    "psychismes": "psychisme",
    "psychodrames": "psychodrame",
    "psychogènes": "psychogène",
    "psycholinguistes": "psycholinguiste",
    "psychologies": "psychologie",
    "psychologiques": "psychologique",
    "psychologues": "psychologue",
    "psychomotrice": "psychomoteur",
    "psychopathes": "psychopathe",
    "psychopathies": "psychopathie",
    "psychopathologies": "psychopathologie",
    "psychophysiologies": "psychophysiologie",
    "psychoses": "psychose",
    "psychosociale": "psychosocial",
    "psychosociales": "psychosocial",
    "psychosociaux": "psychosocial",
    "psychosomatiques": "psychosomatique",
    "psychotechniciens": "psychotechnicien",
    "psychothérapies": "psychothérapie",
    "psychotiques": "psychotique",
    "psychotoniques": "psychotonique",
    "psychotropes": "psychotrope",
    "psychédéliques": "psychédélique",
    "psychés": "psyché",
    "psylliums": "psyllium",
    "psys": "psy",
    "ptérodactyles": "ptérodactyle",
    "ptôses": "ptôse",
    "pu": "pouvoir",
    "pua": "puer",
    "puai": "puer",
    "puaient": "puer",
    "puais": "puer",
    "puait": "puer",
    "puant": "puer",
    "puante": "puant",
    "puantes": "puant",
    "puanteurs": "puanteur",
    "puants": "puant",
    "puas": "puer",
    "puasse": "puer",
    "puassent": "puer",
    "puasses": "puer",
    "puassiez": "puer",
    "puassions": "puer",
    "pubertaires": "pubertaire",
    "pubertés": "puberté",
    "pubescente": "pubescent",
    "pubescentes": "pubescent",
    "pubescents": "pubescent",
    "pubienne": "pubien",
    "pubiennes": "pubien",
    "pubiens": "pubien",
    "publia": "publier",
    "publiables": "publiable",
    "publiai": "publier",
    "publiaient": "publier",
    "publiais": "publier",
    "publiait": "publier",
    "publiant": "publier",
    "publias": "publier",
    "publiasse": "publier",
    "publiassent": "publier",
    "publiasses": "publier",
    "publiassiez": "publier",
    "publiassions": "publier",
    "public schools": "public school",
    "publicains": "publicain",
    "publications": "publication",
    "publicistes": "publiciste",
    "publicitaires": "publicitaire",
    "publicités": "publicité",
    "publics": "public",
    "publie": "publier",
    "publient": "publier",
    "publiera": "publier",
    "publierai": "publier",
    "publieraient": "publier",
    "publierais": "publier",
    "publierait": "publier",
    "publieras": "publier",
    "publierez": "publier",
    "publieriez": "publier",
    "publierions": "publier",
    "publierons": "publier",
    "publieront": "publier",
    "publies": "publier",
    "publiez": "publier",
    "publiiez": "publier",
    "publiions": "publier",
    "publions": "publier",
    "publiphones": "publiphone",
    "publique": "public",
    "publiques": "public",
    "publiâmes": "publier",
    "publiât": "publier",
    "publiâtes": "publier",
    "publièrent": "publier",
    "publié": "publier",
    "publiée": "publier",
    "publiées": "publier",
    "publiés": "publier",
    "pubs": "pub",
    "pubères": "pubère",
    "puceaux": "puceau",
    "pucelages": "pucelage",
    "pucelle": "puceau",
    "pucelles": "puceau",
    "pucerons": "puceron",
    "puces": "puce",
    "puciers": "pucier",
    "puddings": "pudding",
    "puddla": "puddler",
    "puddlai": "puddler",
    "puddlaient": "puddler",
    "puddlais": "puddler",
    "puddlait": "puddler",
    "puddlant": "puddler",
    "puddlas": "puddler",
    "puddlasse": "puddler",
    "puddlassent": "puddler",
    "puddlasses": "puddler",
    "puddlassiez": "puddler",
    "puddlassions": "puddler",
    "puddle": "puddler",
    "puddlent": "puddler",
    "puddlera": "puddler",
    "puddlerai": "puddler",
    "puddleraient": "puddler",
    "puddlerais": "puddler",
    "puddlerait": "puddler",
    "puddleras": "puddler",
    "puddlerez": "puddler",
    "puddleriez": "puddler",
    "puddlerions": "puddler",
    "puddlerons": "puddler",
    "puddleront": "puddler",
    "puddles": "puddler",
    "puddlez": "puddler",
    "puddliez": "puddler",
    "puddlions": "puddler",
    "puddlons": "puddler",
    "puddlâmes": "puddler",
    "puddlât": "puddler",
    "puddlâtes": "puddler",
    "puddlèrent": "puddler",
    "puddlé": "puddler",
    "puddlée": "puddler",
    "puddlées": "puddler",
    "puddlés": "puddler",
    "pudeurs": "pudeur",
    "pudibonde": "pudibond",
    "pudibonderies": "pudibonderie",
    "pudibondes": "pudibond",
    "pudibonds": "pudibond",
    "pudiques": "pudique",
    "pue": "puer",
    "puent": "puer",
    "puera": "puer",
    "puerai": "puer",
    "pueraient": "puer",
    "puerais": "puer",
    "puerait": "puer",
    "pueras": "puer",
    "puerez": "puer",
    "pueriez": "puer",
    "puerions": "puer",
    "puerons": "puer",
    "pueront": "puer",
    "puerpérale": "puerpéral",
    "puerpérales": "puerpéral",
    "puerpéraux": "puerpéral",
    "pues": "puer",
    "puez": "puer",
    "pugilats": "pugilat",
    "pugilistes": "pugiliste",
    "pugnaces": "pugnace",
    "pugnacités": "pugnacité",
    "puiez": "puer",
    "puions": "puer",
    "puis": "pouvoir",
    "puisa": "puiser",
    "puisai": "puiser",
    "puisaient": "puiser",
    "puisais": "puiser",
    "puisait": "puiser",
    "puisant": "puiser",
    "puisards": "puisard",
    "puisas": "puiser",
    "puisasse": "puiser",
    "puisassent": "puiser",
    "puisasses": "puiser",
    "puisassiez": "puiser",
    "puisassions": "puiser",
    "puisatiers": "puisatier",
    "puise": "puiser",
    "puisent": "puiser",
    "puisera": "puiser",
    "puiserai": "puiser",
    "puiseraient": "puiser",
    "puiserais": "puiser",
    "puiserait": "puiser",
    "puiseras": "puiser",
    "puiserez": "puiser",
    "puiseriez": "puiser",
    "puiserions": "puiser",
    "puiserons": "puiser",
    "puiseront": "puiser",
    "puises": "puiser",
    "puisez": "puiser",
    "puisiez": "puiser",
    "puisions": "puiser",
    "puisons": "puiser",
    "puisqu'": "puisque",
    "puissances": "puissance",
    "puissante": "puissant",
    "puissantes": "puissant",
    "puissants": "puissant",
    "puisse": "pouvoir",
    "puissent": "pouvoir",
    "puisses": "pouvoir",
    "puissiez": "pouvoir",
    "puissions": "pouvoir",
    "puisâmes": "puiser",
    "puisât": "puiser",
    "puisâtes": "puiser",
    "puisèrent": "puiser",
    "puisé": "puiser",
    "puisée": "puiser",
    "puisées": "puiser",
    "puisés": "puiser",
    "pull-overs": "pull-over",
    "pullmans": "pullman",
    "pulls": "pull",
    "pullula": "pulluler",
    "pullulai": "pulluler",
    "pullulaient": "pulluler",
    "pullulais": "pulluler",
    "pullulait": "pulluler",
    "pullulant": "pulluler",
    "pullulantes": "pullulant",
    "pullulants": "pullulant",
    "pullulas": "pulluler",
    "pullulasse": "pulluler",
    "pullulassent": "pulluler",
    "pullulasses": "pulluler",
    "pullulassiez": "pulluler",
    "pullulassions": "pulluler",
    "pullulations": "pullulation",
    "pullule": "pulluler",
    "pullulements": "pullulement",
    "pullulent": "pulluler",
    "pullulera": "pulluler",
    "pullulerai": "pulluler",
    "pulluleraient": "pulluler",
    "pullulerais": "pulluler",
    "pullulerait": "pulluler",
    "pulluleras": "pulluler",
    "pullulerez": "pulluler",
    "pulluleriez": "pulluler",
    "pullulerions": "pulluler",
    "pullulerons": "pulluler",
    "pulluleront": "pulluler",
    "pullules": "pulluler",
    "pullulez": "pulluler",
    "pulluliez": "pulluler",
    "pullulions": "pulluler",
    "pullulons": "pulluler",
    "pullulâmes": "pulluler",
    "pullulât": "pulluler",
    "pullulâtes": "pulluler",
    "pullulèrent": "pulluler",
    "pullulé": "pulluler",
    "pulmonaires": "pulmonaire",
    "pulpes": "pulpe",
    "pulpeuse": "pulpeux",
    "pulpeuses": "pulpeux",
    "pulsa": "pulser",
    "pulsai": "pulser",
    "pulsaient": "pulser",
    "pulsais": "pulser",
    "pulsait": "pulser",
    "pulsant": "pulser",
    "pulsars": "pulsar",
    "pulsas": "pulser",
    "pulsasse": "pulser",
    "pulsassent": "pulser",
    "pulsasses": "pulser",
    "pulsassiez": "pulser",
    "pulsassions": "pulser",
    "pulsations": "pulsation",
    "pulsative": "pulsatif",
    "pulse": "pulser",
    "pulsent": "pulser",
    "pulsera": "pulser",
    "pulserai": "pulser",
    "pulseraient": "pulser",
    "pulserais": "pulser",
    "pulserait": "pulser",
    "pulseras": "pulser",
    "pulserez": "pulser",
    "pulseriez": "pulser",
    "pulserions": "pulser",
    "pulserons": "pulser",
    "pulseront": "pulser",
    "pulses": "pulser",
    "pulsez": "pulser",
    "pulsiez": "pulser",
    "pulsions": "pulsion",
    "pulso-réacteurs": "pulso-réacteur",
    "pulsons": "pulser",
    "pulsoréacteurs": "pulsoréacteur",
    "pulsâmes": "pulser",
    "pulsât": "pulser",
    "pulsâtes": "pulser",
    "pulsèrent": "pulser",
    "pulsé": "pulser",
    "pulsée": "pulser",
    "pulsées": "pulser",
    "pulsés": "pulser",
    "pulvérisa": "pulvériser",
    "pulvérisai": "pulvériser",
    "pulvérisaient": "pulvériser",
    "pulvérisais": "pulvériser",
    "pulvérisait": "pulvériser",
    "pulvérisant": "pulvériser",
    "pulvérisas": "pulvériser",
    "pulvérisasse": "pulvériser",
    "pulvérisassent": "pulvériser",
    "pulvérisasses": "pulvériser",
    "pulvérisassiez": "pulvériser",
    "pulvérisassions": "pulvériser",
    "pulvérisateurs": "pulvérisateur",
    "pulvérisations": "pulvérisation",
    "pulvérise": "pulvériser",
    "pulvérisent": "pulvériser",
    "pulvérisera": "pulvériser",
    "pulvériserai": "pulvériser",
    "pulvériseraient": "pulvériser",
    "pulvériserais": "pulvériser",
    "pulvériserait": "pulvériser",
    "pulvériseras": "pulvériser",
    "pulvériserez": "pulvériser",
    "pulvériseriez": "pulvériser",
    "pulvériserions": "pulvériser",
    "pulvériserons": "pulvériser",
    "pulvériseront": "pulvériser",
    "pulvérises": "pulvériser",
    "pulvérisez": "pulvériser",
    "pulvérisiez": "pulvériser",
    "pulvérisions": "pulvériser",
    "pulvérisons": "pulvériser",
    "pulvérisâmes": "pulvériser",
    "pulvérisât": "pulvériser",
    "pulvérisâtes": "pulvériser",
    "pulvérisèrent": "pulvériser",
    "pulvérisé": "pulvériser",
    "pulvérisée": "pulvériser",
    "pulvérisées": "pulvériser",
    "pulvérisés": "pulvériser",
    "pulvérulente": "pulvérulent",
    "pulvérulentes": "pulvérulent",
    "pulvérulents": "pulvérulent",
    "pumas": "puma",
    "punaisait": "punaiser",
    "punaises": "punaise",
    "punaisé": "punaiser",
    "punaisée": "punaiser",
    "punaisées": "punaiser",
    "punaisés": "punaiser",
    "punching ball": "punching-ball",
    "punching-balls": "punching-ball",
    "punchs": "punch",
    "puni": "punir",
    "punie": "punir",
    "punies": "punir",
    "puniques": "punique",
    "punira": "punir",
    "punirai": "punir",
    "puniraient": "punir",
    "punirais": "punir",
    "punirait": "punir",
    "puniras": "punir",
    "punirent": "punir",
    "punirez": "punir",
    "puniriez": "punir",
    "punirions": "punir",
    "punirons": "punir",
    "puniront": "punir",
    "punis": "punir",
    "punissables": "punissable",
    "punissaient": "punir",
    "punissais": "punir",
    "punissait": "punir",
    "punissant": "punir",
    "punisse": "punir",
    "punissent": "punir",
    "punisses": "punir",
    "punissez": "punir",
    "punissiez": "punir",
    "punissions": "punir",
    "punissons": "punir",
    "punit": "punir",
    "punitifs": "punitif",
    "punitions": "punition",
    "punitive": "punitif",
    "punitives": "punitif",
    "punks": "punk",
    "punîmes": "punir",
    "punît": "punir",
    "punîtes": "punir",
    "puons": "puer",
    "pupazzos": "pupazzo",
    "pupillaires": "pupillaire",
    "pupilles": "pupille",
    "pupitres": "pupitre",
    "pure": "pur",
    "purent": "pouvoir",
    "pures": "pur",
    "puretés": "pureté",
    "purgations": "purgation",
    "purgative": "purgatif",
    "purgatoires": "purgatoire",
    "purge": "purger",
    "purgea": "purger",
    "purgeai": "purger",
    "purgeaient": "purger",
    "purgeais": "purger",
    "purgeait": "purger",
    "purgeant": "purger",
    "purgeas": "purger",
    "purgeasse": "purger",
    "purgeassent": "purger",
    "purgeasses": "purger",
    "purgeassiez": "purger",
    "purgeassions": "purger",
    "purgent": "purger",
    "purgeons": "purger",
    "purgera": "purger",
    "purgerai": "purger",
    "purgeraient": "purger",
    "purgerais": "purger",
    "purgerait": "purger",
    "purgeras": "purger",
    "purgerez": "purger",
    "purgeriez": "purger",
    "purgerions": "purger",
    "purgerons": "purger",
    "purgeront": "purger",
    "purges": "purger",
    "purgez": "purger",
    "purgeâmes": "purger",
    "purgeât": "purger",
    "purgeâtes": "purger",
    "purgiez": "purger",
    "purgions": "purger",
    "purgèrent": "purger",
    "purgé": "purger",
    "purgée": "purger",
    "purgées": "purger",
    "purgés": "purger",
    "purifia": "purifier",
    "purifiai": "purifier",
    "purifiaient": "purifier",
    "purifiais": "purifier",
    "purifiait": "purifier",
    "purifiant": "purifier",
    "purifias": "purifier",
    "purifiasse": "purifier",
    "purifiassent": "purifier",
    "purifiasses": "purifier",
    "purifiassiez": "purifier",
    "purifiassions": "purifier",
    "purificateurs": "purificateur",
    "purifications": "purification",
    "purificatrice": "purificateur",
    "purificatrices": "purificateur",
    "purifie": "purifier",
    "purifient": "purifier",
    "purifiera": "purifier",
    "purifierai": "purifier",
    "purifieraient": "purifier",
    "purifierais": "purifier",
    "purifierait": "purifier",
    "purifieras": "purifier",
    "purifierez": "purifier",
    "purifieriez": "purifier",
    "purifierions": "purifier",
    "purifierons": "purifier",
    "purifieront": "purifier",
    "purifies": "purifier",
    "purifiez": "purifier",
    "purifiiez": "purifier",
    "purifiions": "purifier",
    "purifions": "purifier",
    "purifiâmes": "purifier",
    "purifiât": "purifier",
    "purifiâtes": "purifier",
    "purifièrent": "purifier",
    "purifié": "purifier",
    "purifiée": "purifier",
    "purifiées": "purifier",
    "purifiés": "purifier",
    "purins": "purin",
    "puristes": "puriste",
    "puritaine": "puritain",
    "puritaines": "puritain",
    "puritains": "puritain",
    "puritanismes": "puritanisme",
    "purotins": "purotin",
    "purpurine": "purpurin",
    "purpurines": "purpurin",
    "purpurins": "purpurin",
    "purs": "pur",
    "purs-sangs": "pur-sang",
    "purulences": "purulence",
    "purulente": "purulent",
    "purulentes": "purulent",
    "purulents": "purulent",
    "purées": "purée",
    "pus": "pouvoir",
    "pusillanimes": "pusillanime",
    "pusillanimités": "pusillanimité",
    "pusse": "pouvoir",
    "pussent": "pouvoir",
    "pusses": "pouvoir",
    "pussiez": "pouvoir",
    "pussions": "pouvoir",
    "pustules": "pustule",
    "pustuleuse": "pustuleux",
    "put": "pouvoir",
    "putains": "putain",
    "putasse": "putasser",
    "putasseries": "putasserie",
    "putasses": "putasser",
    "putassiers": "putassier",
    "putassière": "putassier",
    "putassières": "putassier",
    "putatifs": "putatif",
    "putative": "putatif",
    "putatives": "putatif",
    "putes": "pute",
    "putrescences": "putrescence",
    "putrescents": "putrescent",
    "putrescibles": "putrescible",
    "putrides": "putride",
    "putréfia": "putréfier",
    "putréfiai": "putréfier",
    "putréfiaient": "putréfier",
    "putréfiais": "putréfier",
    "putréfiait": "putréfier",
    "putréfiant": "putréfier",
    "putréfias": "putréfier",
    "putréfiasse": "putréfier",
    "putréfiassent": "putréfier",
    "putréfiasses": "putréfier",
    "putréfiassiez": "putréfier",
    "putréfiassions": "putréfier",
    "putréfie": "putréfier",
    "putréfient": "putréfier",
    "putréfiera": "putréfier",
    "putréfierai": "putréfier",
    "putréfieraient": "putréfier",
    "putréfierais": "putréfier",
    "putréfierait": "putréfier",
    "putréfieras": "putréfier",
    "putréfierez": "putréfier",
    "putréfieriez": "putréfier",
    "putréfierions": "putréfier",
    "putréfierons": "putréfier",
    "putréfieront": "putréfier",
    "putréfies": "putréfier",
    "putréfiez": "putréfier",
    "putréfiiez": "putréfier",
    "putréfiions": "putréfier",
    "putréfions": "putréfier",
    "putréfiâmes": "putréfier",
    "putréfiât": "putréfier",
    "putréfiâtes": "putréfier",
    "putréfièrent": "putréfier",
    "putréfié": "putréfier",
    "putréfiée": "putréfier",
    "putréfiées": "putréfier",
    "putréfiés": "putréfier",
    "putschistes": "putschiste",
    "putschs": "putsch",
    "putti": "putto",
    "puttos": "putto",
    "puys": "puy",
    "puzzles": "puzzle",
    "puâmes": "puer",
    "puât": "puer",
    "puâtes": "puer",
    "puèrent": "puer",
    "pué": "puer",
    "puériculteurs": "puériculteur",
    "puéricultrice": "puériculteur",
    "puéricultrices": "puériculteur",
    "puéricultures": "puériculture",
    "puérile": "puéril",
    "puériles": "puéril",
    "puérilités": "puérilité",
    "puérils": "puéril",
    "puînée": "puîné",
    "puînées": "puîné",
    "puînés": "puîné",
    "pygmées": "pygmée",
    "pyjamas": "pyjama",
    "pylores": "pylore",
    "pylônes": "pylône",
    "pyorrhées": "pyorrhée",
    "pyramidages": "pyramidage",
    "pyramidale": "pyramidal",
    "pyramidales": "pyramidal",
    "pyramidaux": "pyramidal",
    "pyramides": "pyramide",
    "pyridines": "pyridine",
    "pyrites": "pyrite",
    "pyroclastiques": "pyroclastique",
    "pyrogravées": "pyrograver",
    "pyrolyses": "pyrolyse",
    "pyrolytiques": "pyrolytique",
    "pyromanes": "pyromane",
    "pyrotechnies": "pyrotechnie",
    "pyroxènes": "pyroxène",
    "pythagoriques": "pythagorique",
    "pythies": "pythie",
    "pythonisses": "pythonisse",
    "pythons": "python",
    "pyxides": "pyxide",
    "pâles": "pâle",
    "pâleurs": "pâleur",
    "pâli": "pâlir",
    "pâlichonne": "pâlichon",
    "pâlichons": "pâlichon",
    "pâlie": "pâlir",
    "pâlies": "pâlir",
    "pâlira": "pâlir",
    "pâlirai": "pâlir",
    "pâliraient": "pâlir",
    "pâlirais": "pâlir",
    "pâlirait": "pâlir",
    "pâliras": "pâlir",
    "pâlirent": "pâlir",
    "pâlirez": "pâlir",
    "pâliriez": "pâlir",
    "pâlirions": "pâlir",
    "pâlirons": "pâlir",
    "pâliront": "pâlir",
    "pâlis": "pâlir",
    "pâlissaient": "pâlir",
    "pâlissais": "pâlir",
    "pâlissait": "pâlir",
    "pâlissant": "pâlir",
    "pâlissante": "pâlissant",
    "pâlissantes": "pâlissant",
    "pâlissants": "pâlissant",
    "pâlisse": "pâlir",
    "pâlissent": "pâlir",
    "pâlisses": "pâlir",
    "pâlissez": "pâlir",
    "pâlissiez": "pâlir",
    "pâlissions": "pâlir",
    "pâlissons": "pâlir",
    "pâlit": "pâlir",
    "pâlots": "pâlot",
    "pâlotte": "pâlot",
    "pâlottes": "pâlot",
    "pâlîmes": "pâlir",
    "pâlît": "pâlir",
    "pâlîtes": "pâlir",
    "pâma": "pâmer",
    "pâmai": "pâmer",
    "pâmaient": "pâmer",
    "pâmais": "pâmer",
    "pâmait": "pâmer",
    "pâmant": "pâmer",
    "pâmas": "pâmer",
    "pâmasse": "pâmer",
    "pâmassent": "pâmer",
    "pâmasses": "pâmer",
    "pâmassiez": "pâmer",
    "pâmassions": "pâmer",
    "pâme": "pâmer",
    "pâment": "pâmer",
    "pâmera": "pâmer",
    "pâmerai": "pâmer",
    "pâmeraient": "pâmer",
    "pâmerais": "pâmer",
    "pâmerait": "pâmer",
    "pâmeras": "pâmer",
    "pâmerez": "pâmer",
    "pâmeriez": "pâmer",
    "pâmerions": "pâmer",
    "pâmerons": "pâmer",
    "pâmeront": "pâmer",
    "pâmes": "pâmer",
    "pâmez": "pâmer",
    "pâmiez": "pâmer",
    "pâmions": "pâmer",
    "pâmoisons": "pâmoison",
    "pâmons": "pâmer",
    "pâmâmes": "pâmer",
    "pâmât": "pâmer",
    "pâmâtes": "pâmer",
    "pâmèrent": "pâmer",
    "pâmé": "pâmer",
    "pâmée": "pâmer",
    "pâmées": "pâmer",
    "pâmés": "pâmer",
    "pâquerettes": "pâquerette",
    "pâques": "pâque",
    "pât": "pâte",
    "pâtes": "pâte",
    "pâteuse": "pâteux",
    "pâteuses": "pâteux",
    "pâti": "pâtir",
    "pâtira": "pâtir",
    "pâtirai": "pâtir",
    "pâtiraient": "pâtir",
    "pâtirais": "pâtir",
    "pâtirait": "pâtir",
    "pâtiras": "pâtir",
    "pâtirent": "pâtir",
    "pâtirez": "pâtir",
    "pâtiriez": "pâtir",
    "pâtirions": "pâtir",
    "pâtirons": "pâtir",
    "pâtiront": "pâtir",
    "pâtis": "pâtir",
    "pâtissa": "pâtisser",
    "pâtissai": "pâtisser",
    "pâtissaient": "pâtisser",
    "pâtissais": "pâtisser",
    "pâtissait": "pâtisser",
    "pâtissant": "pâtisser",
    "pâtissas": "pâtisser",
    "pâtissasse": "pâtisser",
    "pâtissassent": "pâtisser",
    "pâtissasses": "pâtisser",
    "pâtissassiez": "pâtisser",
    "pâtissassions": "pâtisser",
    "pâtisse": "pâtisser",
    "pâtissent": "pâtisser",
    "pâtissera": "pâtisser",
    "pâtisserai": "pâtisser",
    "pâtisseraient": "pâtisser",
    "pâtisserais": "pâtisser",
    "pâtisserait": "pâtisser",
    "pâtisseras": "pâtisser",
    "pâtisserez": "pâtisser",
    "pâtisseries": "pâtisserie",
    "pâtisseriez": "pâtisser",
    "pâtisserions": "pâtisser",
    "pâtisserons": "pâtisser",
    "pâtisseront": "pâtisser",
    "pâtisses": "pâtisser",
    "pâtissez": "pâtisser",
    "pâtissiers": "pâtissier",
    "pâtissiez": "pâtisser",
    "pâtissions": "pâtisser",
    "pâtissière": "pâtissier",
    "pâtissières": "pâtissier",
    "pâtissons": "pâtisser",
    "pâtissâmes": "pâtisser",
    "pâtissât": "pâtisser",
    "pâtissâtes": "pâtisser",
    "pâtissèrent": "pâtisser",
    "pâtissé": "pâtisser",
    "pâtissée": "pâtisser",
    "pâtissées": "pâtisser",
    "pâtissés": "pâtisser",
    "pâtit": "pâtir",
    "pâtons": "pâton",
    "pâtres": "pâtre",
    "pâturages": "pâturage",
    "pâturaient": "pâturer",
    "pâturent": "pâturer",
    "pâtures": "pâture",
    "pâturé": "pâturer",
    "pâtées": "pâtée",
    "pâtés": "pâté",
    "pâtîmes": "pâtir",
    "pâtît": "pâtir",
    "pâtîtes": "pâtir",
    "pèche": "pécher",
    "pèchent": "pécher",
    "pèches": "pécher",
    "pègres": "pègre",
    "pèle": "peler",
    "pèlent": "peler",
    "pèlera": "peler",
    "pèlerai": "peler",
    "pèleraient": "peler",
    "pèlerais": "peler",
    "pèlerait": "peler",
    "pèleras": "peler",
    "pèlerez": "peler",
    "pèleriez": "peler",
    "pèlerinages": "pèlerinage",
    "pèlerine": "pèlerin",
    "pèlerines": "pèlerine",
    "pèlerins": "pèlerin",
    "pèlerions": "peler",
    "pèlerons": "peler",
    "pèleront": "peler",
    "pèles": "peler",
    "pères": "père",
    "pèse": "peser",
    "pèse-alcools": "pèse-alcool",
    "pèse-bébés": "pèse-bébé",
    "pèse-laits": "pèse-lait",
    "pèse-lettres": "pèse-lettre",
    "pèse-liqueurs": "pèse-liqueur",
    "pèse-personnes": "pèse-personne",
    "pèse-sirops": "pèse-sirop",
    "pèsent": "peser",
    "pèsera": "peser",
    "pèserai": "peser",
    "pèseraient": "peser",
    "pèserais": "peser",
    "pèserait": "peser",
    "pèseras": "peser",
    "pèserez": "peser",
    "pèseriez": "peser",
    "pèserions": "peser",
    "pèserons": "peser",
    "pèseront": "peser",
    "pèses": "peser",
    "pète": "péter",
    "pètent": "péter",
    "pètes": "péter",
    "péages": "péage",
    "péans": "péan",
    "pébroques": "pébroque",
    "pécaris": "pécari",
    "pécha": "pécher",
    "péchai": "pécher",
    "péchaient": "pécher",
    "péchais": "pécher",
    "péchait": "pécher",
    "péchant": "pécher",
    "péchas": "pécher",
    "péchasse": "pécher",
    "péchassent": "pécher",
    "péchasses": "pécher",
    "péchassiez": "pécher",
    "péchassions": "pécher",
    "péchera": "pécher",
    "pécherai": "pécher",
    "pécheraient": "pécher",
    "pécherais": "pécher",
    "pécherait": "pécher",
    "pécheras": "pécher",
    "pécheresse": "pécheur",
    "pécheresses": "pécheur",
    "pécherez": "pécher",
    "pécheriez": "pécher",
    "pécherions": "pécher",
    "pécherons": "pécher",
    "pécheront": "pécher",
    "pécheurs": "pécheur",
    "péchez": "pécher",
    "péchiez": "pécher",
    "péchions": "pécher",
    "péchons": "péchon",
    "péchâmes": "pécher",
    "péchât": "pécher",
    "péchâtes": "pécher",
    "péchèrent": "pécher",
    "péché": "pécher",
    "péchés": "pécher",
    "pécores": "pécore",
    "péculats": "péculat",
    "pécules": "pécule",
    "pécuniaires": "pécuniaire",
    "pédagogies": "pédagogie",
    "pédagogiques": "pédagogique",
    "pédagogues": "pédagogue",
    "pédala": "pédaler",
    "pédalai": "pédaler",
    "pédalaient": "pédaler",
    "pédalais": "pédaler",
    "pédalait": "pédaler",
    "pédalant": "pédaler",
    "pédalas": "pédaler",
    "pédalasse": "pédaler",
    "pédalassent": "pédaler",
    "pédalasses": "pédaler",
    "pédalassiez": "pédaler",
    "pédalassions": "pédaler",
    "pédale": "pédaler",
    "pédalent": "pédaler",
    "pédalera": "pédaler",
    "pédalerai": "pédaler",
    "pédaleraient": "pédaler",
    "pédalerais": "pédaler",
    "pédalerait": "pédaler",
    "pédaleras": "pédaler",
    "pédalerez": "pédaler",
    "pédaleriez": "pédaler",
    "pédalerions": "pédaler",
    "pédalerons": "pédaler",
    "pédaleront": "pédaler",
    "pédales": "pédaler",
    "pédaleuses": "pédaleur",
    "pédalez": "pédaler",
    "pédaliers": "pédalier",
    "pédaliez": "pédaler",
    "pédalions": "pédaler",
    "pédalons": "pédaler",
    "pédalos": "pédalo",
    "pédalâmes": "pédaler",
    "pédalât": "pédaler",
    "pédalâtes": "pédaler",
    "pédalèrent": "pédaler",
    "pédalé": "pédaler",
    "pédalée": "pédaler",
    "pédalées": "pédaler",
    "pédalés": "pédaler",
    "pédante": "pédant",
    "pédanteries": "pédanterie",
    "pédantes": "pédant",
    "pédants": "pédant",
    "pédestres": "pédestre",
    "pédiatres": "pédiatre",
    "pédiatries": "pédiatrie",
    "pédiatriques": "pédiatrique",
    "pédicules": "pédicule",
    "pédicures": "pédicure",
    "pédieuse": "pédieux",
    "pédologies": "pédologie",
    "pédoncules": "pédoncule",
    "pédophiles": "pédophile",
    "pédophiliques": "pédophilique",
    "pédérastes": "pédéraste",
    "pédés": "pédé",
    "pégriots": "pégriot",
    "péjoratifs": "péjoratif",
    "péjorative": "péjoratif",
    "péjoratives": "péjoratif",
    "pékinoise": "pékinois",
    "pékinoises": "pékinois",
    "pékins": "pékin",
    "pélagiques": "pélagique",
    "pélasgienne": "pélasgien",
    "pélasgiennes": "pélasgien",
    "pélasgiens": "pélasgien",
    "pélasgiques": "pélasgique",
    "pélicans": "pélican",
    "pénale": "pénal",
    "pénales": "pénal",
    "pénalisa": "pénaliser",
    "pénalisai": "pénaliser",
    "pénalisaient": "pénaliser",
    "pénalisais": "pénaliser",
    "pénalisait": "pénaliser",
    "pénalisant": "pénaliser",
    "pénalisante": "pénalisant",
    "pénalisantes": "pénalisant",
    "pénalisants": "pénalisant",
    "pénalisas": "pénaliser",
    "pénalisasse": "pénaliser",
    "pénalisassent": "pénaliser",
    "pénalisasses": "pénaliser",
    "pénalisassiez": "pénaliser",
    "pénalisassions": "pénaliser",
    "pénalisations": "pénalisation",
    "pénalise": "pénaliser",
    "pénalisent": "pénaliser",
    "pénalisera": "pénaliser",
    "pénaliserai": "pénaliser",
    "pénaliseraient": "pénaliser",
    "pénaliserais": "pénaliser",
    "pénaliserait": "pénaliser",
    "pénaliseras": "pénaliser",
    "pénaliserez": "pénaliser",
    "pénaliseriez": "pénaliser",
    "pénaliserions": "pénaliser",
    "pénaliserons": "pénaliser",
    "pénaliseront": "pénaliser",
    "pénalises": "pénaliser",
    "pénalisez": "pénaliser",
    "pénalisiez": "pénaliser",
    "pénalisions": "pénaliser",
    "pénalisons": "pénaliser",
    "pénalistes": "pénaliste",
    "pénalisâmes": "pénaliser",
    "pénalisât": "pénaliser",
    "pénalisâtes": "pénaliser",
    "pénalisèrent": "pénaliser",
    "pénalisé": "pénaliser",
    "pénalisée": "pénaliser",
    "pénalisées": "pénaliser",
    "pénalisés": "pénaliser",
    "pénalités": "pénalité",
    "pénarde": "pénard",
    "pénardes": "pénard",
    "pénards": "pénard",
    "pénaux": "pénal",
    "pénibles": "pénible",
    "péniches": "péniche",
    "pénicillines": "pénicilline",
    "pénienne": "pénien",
    "péninsulaires": "péninsulaire",
    "péninsules": "péninsule",
    "pénitences": "pénitence",
    "pénitenciers": "pénitencier",
    "pénitente": "pénitent",
    "pénitentes": "pénitent",
    "pénitentiaires": "pénitentiaire",
    "pénitentielle": "pénitentiel",
    "pénitents": "pénitent",
    "pénombres": "pénombre",
    "pénultièmes": "pénultième",
    "pénuries": "pénurie",
    "pénètre": "pénétrer",
    "pénètrent": "pénétrer",
    "pénètres": "pénétrer",
    "pénéplaines": "pénéplaine",
    "pénétra": "pénétrer",
    "pénétrables": "pénétrable",
    "pénétrai": "pénétrer",
    "pénétraient": "pénétrer",
    "pénétrais": "pénétrer",
    "pénétrait": "pénétrer",
    "pénétrant": "pénétrer",
    "pénétrante": "pénétrant",
    "pénétrantes": "pénétrant",
    "pénétrants": "pénétrant",
    "pénétras": "pénétrer",
    "pénétrasse": "pénétrer",
    "pénétrassent": "pénétrer",
    "pénétrasses": "pénétrer",
    "pénétrassiez": "pénétrer",
    "pénétrassions": "pénétrer",
    "pénétrations": "pénétration",
    "pénétrera": "pénétrer",
    "pénétrerai": "pénétrer",
    "pénétreraient": "pénétrer",
    "pénétrerais": "pénétrer",
    "pénétrerait": "pénétrer",
    "pénétreras": "pénétrer",
    "pénétrerez": "pénétrer",
    "pénétreriez": "pénétrer",
    "pénétrerions": "pénétrer",
    "pénétrerons": "pénétrer",
    "pénétreront": "pénétrer",
    "pénétrez": "pénétrer",
    "pénétriez": "pénétrer",
    "pénétrions": "pénétrer",
    "pénétrons": "pénétrer",
    "pénétrâmes": "pénétrer",
    "pénétrât": "pénétrer",
    "pénétrâtes": "pénétrer",
    "pénétrèrent": "pénétrer",
    "pénétré": "pénétrer",
    "pénétrée": "pénétrer",
    "pénétrées": "pénétrer",
    "pénétrés": "pénétrer",
    "péons": "péon",
    "péottes": "péotte",
    "pépia": "pépier",
    "pépiai": "pépier",
    "pépiaient": "pépier",
    "pépiais": "pépier",
    "pépiait": "pépier",
    "pépiant": "pépier",
    "pépias": "pépier",
    "pépiasse": "pépier",
    "pépiassent": "pépier",
    "pépiasses": "pépier",
    "pépiassiez": "pépier",
    "pépiassions": "pépier",
    "pépie": "pépier",
    "pépiements": "pépiement",
    "pépient": "pépier",
    "pépiera": "pépier",
    "pépierai": "pépier",
    "pépieraient": "pépier",
    "pépierais": "pépier",
    "pépierait": "pépier",
    "pépieras": "pépier",
    "pépierez": "pépier",
    "pépieriez": "pépier",
    "pépierions": "pépier",
    "pépierons": "pépier",
    "pépieront": "pépier",
    "pépies": "pépier",
    "pépiez": "pépier",
    "pépiiez": "pépier",
    "pépiions": "pépier",
    "pépinières": "pépinière",
    "pépiniéristes": "pépiniériste",
    "pépins": "pépin",
    "pépions": "pépier",
    "pépites": "pépite",
    "pépiâmes": "pépier",
    "pépiât": "pépier",
    "pépiâtes": "pépier",
    "pépièrent": "pépier",
    "pépié": "pépier",
    "pépiés": "pépier",
    "péplums": "péplum",
    "pépères": "pépère",
    "pépées": "pépée",
    "pépés": "pépé",
    "péquenaude": "péquenaud",
    "péquenaudes": "péquenaud",
    "péquenauds": "péquenaud",
    "péquenots": "péquenot",
    "péquins": "péquin",
    "péremptions": "péremption",
    "péremptoires": "péremptoire",
    "pérennes": "pérenne",
    "pérennisa": "pérenniser",
    "pérennisai": "pérenniser",
    "pérennisaient": "pérenniser",
    "pérennisais": "pérenniser",
    "pérennisait": "pérenniser",
    "pérennisant": "pérenniser",
    "pérennisas": "pérenniser",
    "pérennisasse": "pérenniser",
    "pérennisassent": "pérenniser",
    "pérennisasses": "pérenniser",
    "pérennisassiez": "pérenniser",
    "pérennisassions": "pérenniser",
    "pérennise": "pérenniser",
    "pérennisent": "pérenniser",
    "pérennisera": "pérenniser",
    "pérenniserai": "pérenniser",
    "pérenniseraient": "pérenniser",
    "pérenniserais": "pérenniser",
    "pérenniserait": "pérenniser",
    "pérenniseras": "pérenniser",
    "pérenniserez": "pérenniser",
    "pérenniseriez": "pérenniser",
    "pérenniserions": "pérenniser",
    "pérenniserons": "pérenniser",
    "pérenniseront": "pérenniser",
    "pérennises": "pérenniser",
    "pérennisez": "pérenniser",
    "pérennisiez": "pérenniser",
    "pérennisions": "pérenniser",
    "pérennisons": "pérenniser",
    "pérennisâmes": "pérenniser",
    "pérennisât": "pérenniser",
    "pérennisâtes": "pérenniser",
    "pérennisèrent": "pérenniser",
    "pérennisé": "pérenniser",
    "pérennisée": "pérenniser",
    "pérennisées": "pérenniser",
    "pérennisés": "pérenniser",
    "pérennités": "pérennité",
    "péri": "périr",
    "périanthes": "périanthe",
    "péricardes": "péricarde",
    "péricarpes": "péricarpe",
    "périclita": "péricliter",
    "périclitai": "péricliter",
    "périclitaient": "péricliter",
    "périclitais": "péricliter",
    "périclitait": "péricliter",
    "périclitant": "péricliter",
    "périclitas": "péricliter",
    "périclitasse": "péricliter",
    "périclitassent": "péricliter",
    "périclitasses": "péricliter",
    "périclitassiez": "péricliter",
    "périclitassions": "péricliter",
    "périclite": "péricliter",
    "périclitent": "péricliter",
    "périclitera": "péricliter",
    "péricliterai": "péricliter",
    "péricliteraient": "péricliter",
    "péricliterais": "péricliter",
    "péricliterait": "péricliter",
    "péricliteras": "péricliter",
    "péricliterez": "péricliter",
    "péricliteriez": "péricliter",
    "péricliterions": "péricliter",
    "péricliterons": "péricliter",
    "péricliteront": "péricliter",
    "périclites": "péricliter",
    "périclitez": "péricliter",
    "périclitiez": "péricliter",
    "périclitions": "péricliter",
    "périclitons": "péricliter",
    "périclitâmes": "péricliter",
    "périclitât": "péricliter",
    "périclitâtes": "péricliter",
    "périclitèrent": "péricliter",
    "périclité": "péricliter",
    "péridurale": "péridural",
    "péridurales": "péridurale",
    "périduraux": "péridural",
    "périe": "périr",
    "péries": "périr",
    "périgourdine": "périgourdin",
    "périgourdins": "périgourdin",
    "périgées": "périgée",
    "périhélies": "périhélie",
    "périlleuse": "périlleux",
    "périlleuses": "périlleux",
    "périls": "péril",
    "périma": "périmer",
    "périmai": "périmer",
    "périmaient": "périmer",
    "périmais": "périmer",
    "périmait": "périmer",
    "périmant": "périmer",
    "périmas": "périmer",
    "périmasse": "périmer",
    "périmassent": "périmer",
    "périmasses": "périmer",
    "périmassiez": "périmer",
    "périmassions": "périmer",
    "périme": "périmer",
    "périment": "périmer",
    "périmera": "périmer",
    "périmerai": "périmer",
    "périmeraient": "périmer",
    "périmerais": "périmer",
    "périmerait": "périmer",
    "périmeras": "périmer",
    "périmerez": "périmer",
    "périmeriez": "périmer",
    "périmerions": "périmer",
    "périmerons": "périmer",
    "périmeront": "périmer",
    "périmes": "périmer",
    "périmez": "périmer",
    "périmiez": "périmer",
    "périmions": "périmer",
    "périmons": "périmer",
    "périmâmes": "périmer",
    "périmât": "périmer",
    "périmâtes": "périmer",
    "périmèrent": "périmer",
    "périmètres": "périmètre",
    "périmé": "périmer",
    "périmée": "périmer",
    "périmées": "périmer",
    "périmés": "périmer",
    "périnatale": "périnatal",
    "périnatales": "périnatal",
    "périnataux": "périnatal",
    "périnéale": "périnéal",
    "périnéales": "périnéal",
    "périnéaux": "périnéal",
    "périnées": "périnée",
    "périodes": "période",
    "périodicités": "périodicité",
    "périodiques": "périodique",
    "périostes": "périoste",
    "péripatéticienne": "péripatéticien",
    "péripatéticiennes": "péripatéticienne",
    "péripatéticiens": "péripatéticien",
    "périphrases": "périphrase",
    "périphéricités": "périphéricité",
    "périphéries": "périphérie",
    "périphériques": "périphérique",
    "périples": "périple",
    "péripéties": "péripétie",
    "périra": "périr",
    "périrai": "périr",
    "périraient": "périr",
    "périrais": "périr",
    "périrait": "périr",
    "périras": "périr",
    "périrent": "périr",
    "périrez": "périr",
    "péririez": "périr",
    "péririons": "périr",
    "périrons": "périr",
    "périront": "périr",
    "péris": "périr",
    "périscopes": "périscope",
    "périssables": "périssable",
    "périssaient": "périr",
    "périssais": "périr",
    "périssait": "périr",
    "périssant": "périr",
    "périsse": "périr",
    "périssent": "périr",
    "périsses": "périr",
    "périssez": "périr",
    "périssiez": "périr",
    "périssions": "périr",
    "périssoires": "périssoire",
    "périssons": "périr",
    "péristaltiques": "péristaltique",
    "péristyles": "péristyle",
    "périt": "périr",
    "péritoines": "péritoine",
    "péritonites": "péritonite",
    "péritonéale": "péritonéal",
    "périurbaines": "périurbain",
    "péronistes": "péroniste",
    "péronnelles": "péronnelle",
    "péronés": "péroné",
    "pérora": "pérorer",
    "pérorai": "pérorer",
    "péroraient": "pérorer",
    "pérorais": "pérorer",
    "péroraisons": "péroraison",
    "pérorait": "pérorer",
    "pérorant": "pérorer",
    "péroras": "pérorer",
    "pérorasse": "pérorer",
    "pérorassent": "pérorer",
    "pérorasses": "pérorer",
    "pérorassiez": "pérorer",
    "pérorassions": "pérorer",
    "pérore": "pérorer",
    "pérorent": "pérorer",
    "pérorera": "pérorer",
    "pérorerai": "pérorer",
    "péroreraient": "pérorer",
    "pérorerais": "pérorer",
    "pérorerait": "pérorer",
    "péroreras": "pérorer",
    "pérorerez": "pérorer",
    "péroreriez": "pérorer",
    "pérorerions": "pérorer",
    "pérorerons": "pérorer",
    "péroreront": "pérorer",
    "pérores": "pérorer",
    "pérorez": "pérorer",
    "péroriez": "pérorer",
    "pérorions": "pérorer",
    "pérorons": "pérorer",
    "pérorâmes": "pérorer",
    "pérorât": "pérorer",
    "pérorâtes": "pérorer",
    "pérorèrent": "pérorer",
    "péroré": "pérorer",
    "péruvienne": "péruvien",
    "péruviennes": "péruvien",
    "péruviens": "péruvien",
    "pérégrinant": "pérégriner",
    "pérégrinations": "pérégrination",
    "pérégrine": "pérégriner",
    "pérégrines": "pérégriner",
    "péréquations": "péréquation",
    "pérîmes": "périr",
    "pérît": "périr",
    "pérîtes": "périr",
    "péta": "péter",
    "pétai": "péter",
    "pétaient": "péter",
    "pétainistes": "pétainiste",
    "pétais": "péter",
    "pétait": "péter",
    "pétales": "pétale",
    "pétaloïdes": "pétaloïde",
    "pétanques": "pétanque",
    "pétant": "péter",
    "pétante": "pétant",
    "pétantes": "pétant",
    "pétants": "pétant",
    "pétaradaient": "pétarader",
    "pétaradait": "pétarader",
    "pétaradant": "pétarader",
    "pétaradante": "pétaradant",
    "pétaradantes": "pétaradant",
    "pétaradants": "pétaradant",
    "pétarade": "pétarader",
    "pétarades": "pétarader",
    "pétaradé": "pétarader",
    "pétarda": "pétarder",
    "pétardai": "pétarder",
    "pétardaient": "pétarder",
    "pétardais": "pétarder",
    "pétardait": "pétarder",
    "pétardant": "pétarder",
    "pétardas": "pétarder",
    "pétardasse": "pétarder",
    "pétardassent": "pétarder",
    "pétardasses": "pétarder",
    "pétardassiez": "pétarder",
    "pétardassions": "pétarder",
    "pétarde": "pétarder",
    "pétardent": "pétarder",
    "pétardera": "pétarder",
    "pétarderai": "pétarder",
    "pétarderaient": "pétarder",
    "pétarderais": "pétarder",
    "pétarderait": "pétarder",
    "pétarderas": "pétarder",
    "pétarderez": "pétarder",
    "pétarderiez": "pétarder",
    "pétarderions": "pétarder",
    "pétarderons": "pétarder",
    "pétarderont": "pétarder",
    "pétardes": "pétarder",
    "pétardez": "pétarder",
    "pétardiez": "pétarder",
    "pétardions": "pétarder",
    "pétardière": "pétardier",
    "pétardons": "pétarder",
    "pétards": "pétard",
    "pétardâmes": "pétarder",
    "pétardât": "pétarder",
    "pétardâtes": "pétarder",
    "pétardèrent": "pétarder",
    "pétardé": "pétarder",
    "pétardée": "pétarder",
    "pétardées": "pétarder",
    "pétardés": "pétarder",
    "pétas": "péter",
    "pétasse": "péter",
    "pétassent": "péter",
    "pétasses": "péter",
    "pétassiez": "péter",
    "pétassions": "péter",
    "pétaudières": "pétaudière",
    "pétera": "péter",
    "péterai": "péter",
    "péteraient": "péter",
    "péterais": "péter",
    "péterait": "péter",
    "péteras": "péter",
    "péterez": "péter",
    "péteriez": "péter",
    "péterions": "péter",
    "péterons": "péter",
    "péteront": "péter",
    "péteuse": "péteux",
    "pétez": "péter",
    "pétiez": "péter",
    "pétilla": "pétiller",
    "pétillai": "pétiller",
    "pétillaient": "pétiller",
    "pétillais": "pétiller",
    "pétillait": "pétiller",
    "pétillant": "pétiller",
    "pétillante": "pétillant",
    "pétillantes": "pétillant",
    "pétillants": "pétillant",
    "pétillas": "pétiller",
    "pétillasse": "pétiller",
    "pétillassent": "pétiller",
    "pétillasses": "pétiller",
    "pétillassiez": "pétiller",
    "pétillassions": "pétiller",
    "pétille": "pétiller",
    "pétillements": "pétillement",
    "pétillent": "pétiller",
    "pétillera": "pétiller",
    "pétillerai": "pétiller",
    "pétilleraient": "pétiller",
    "pétillerais": "pétiller",
    "pétillerait": "pétiller",
    "pétilleras": "pétiller",
    "pétillerez": "pétiller",
    "pétilleriez": "pétiller",
    "pétillerions": "pétiller",
    "pétillerons": "pétiller",
    "pétilleront": "pétiller",
    "pétilles": "pétiller",
    "pétillez": "pétiller",
    "pétilliez": "pétiller",
    "pétillions": "pétiller",
    "pétillons": "pétiller",
    "pétillâmes": "pétiller",
    "pétillât": "pétiller",
    "pétillâtes": "pétiller",
    "pétillèrent": "pétiller",
    "pétillé": "pétiller",
    "pétioles": "pétiole",
    "pétions": "péter",
    "pétitionna": "pétitionner",
    "pétitionnai": "pétitionner",
    "pétitionnaient": "pétitionner",
    "pétitionnaires": "pétitionnaire",
    "pétitionnais": "pétitionner",
    "pétitionnait": "pétitionner",
    "pétitionnant": "pétitionner",
    "pétitionnas": "pétitionner",
    "pétitionnasse": "pétitionner",
    "pétitionnassent": "pétitionner",
    "pétitionnasses": "pétitionner",
    "pétitionnassiez": "pétitionner",
    "pétitionnassions": "pétitionner",
    "pétitionne": "pétitionner",
    "pétitionnent": "pétitionner",
    "pétitionnera": "pétitionner",
    "pétitionnerai": "pétitionner",
    "pétitionneraient": "pétitionner",
    "pétitionnerais": "pétitionner",
    "pétitionnerait": "pétitionner",
    "pétitionneras": "pétitionner",
    "pétitionnerez": "pétitionner",
    "pétitionneriez": "pétitionner",
    "pétitionnerions": "pétitionner",
    "pétitionnerons": "pétitionner",
    "pétitionneront": "pétitionner",
    "pétitionnes": "pétitionner",
    "pétitionnez": "pétitionner",
    "pétitionniez": "pétitionner",
    "pétitionnions": "pétitionner",
    "pétitionnons": "pétitionner",
    "pétitionnâmes": "pétitionner",
    "pétitionnât": "pétitionner",
    "pétitionnâtes": "pétitionner",
    "pétitionnèrent": "pétitionner",
    "pétitionné": "pétitionner",
    "pétitionnée": "pétitionner",
    "pétitionnées": "pétitionner",
    "pétitionnés": "pétitionner",
    "pétitions": "pétition",
    "pétochais": "pétocher",
    "pétochait": "pétocher",
    "pétoches": "pétoche",
    "pétoires": "pétoire",
    "pétomanes": "pétomane",
    "pétoncles": "pétoncle",
    "pétons": "péter",
    "pétouille": "pétouiller",
    "pétrarquistes": "pétrarquiste",
    "pétrels": "pétrel",
    "pétri": "pétrir",
    "pétrie": "pétrir",
    "pétries": "pétrir",
    "pétrifia": "pétrifier",
    "pétrifiai": "pétrifier",
    "pétrifiaient": "pétrifier",
    "pétrifiais": "pétrifier",
    "pétrifiait": "pétrifier",
    "pétrifiant": "pétrifier",
    "pétrifiante": "pétrifiant",
    "pétrifiantes": "pétrifiant",
    "pétrifias": "pétrifier",
    "pétrifiasse": "pétrifier",
    "pétrifiassent": "pétrifier",
    "pétrifiasses": "pétrifier",
    "pétrifiassiez": "pétrifier",
    "pétrifiassions": "pétrifier",
    "pétrifie": "pétrifier",
    "pétrifient": "pétrifier",
    "pétrifiera": "pétrifier",
    "pétrifierai": "pétrifier",
    "pétrifieraient": "pétrifier",
    "pétrifierais": "pétrifier",
    "pétrifierait": "pétrifier",
    "pétrifieras": "pétrifier",
    "pétrifierez": "pétrifier",
    "pétrifieriez": "pétrifier",
    "pétrifierions": "pétrifier",
    "pétrifierons": "pétrifier",
    "pétrifieront": "pétrifier",
    "pétrifies": "pétrifier",
    "pétrifiez": "pétrifier",
    "pétrifiiez": "pétrifier",
    "pétrifiions": "pétrifier",
    "pétrifions": "pétrifier",
    "pétrifiâmes": "pétrifier",
    "pétrifiât": "pétrifier",
    "pétrifiâtes": "pétrifier",
    "pétrifièrent": "pétrifier",
    "pétrifié": "pétrifier",
    "pétrifiée": "pétrifier",
    "pétrifiées": "pétrifier",
    "pétrifiés": "pétrifier",
    "pétrins": "pétrin",
    "pétrira": "pétrir",
    "pétrirai": "pétrir",
    "pétriraient": "pétrir",
    "pétrirais": "pétrir",
    "pétrirait": "pétrir",
    "pétriras": "pétrir",
    "pétrirent": "pétrir",
    "pétrirez": "pétrir",
    "pétririez": "pétrir",
    "pétririons": "pétrir",
    "pétrirons": "pétrir",
    "pétriront": "pétrir",
    "pétris": "pétrir",
    "pétrissaient": "pétrir",
    "pétrissais": "pétrir",
    "pétrissait": "pétrir",
    "pétrissant": "pétrir",
    "pétrisse": "pétrir",
    "pétrissent": "pétrir",
    "pétrisses": "pétrir",
    "pétrissez": "pétrir",
    "pétrissiez": "pétrir",
    "pétrissions": "pétrir",
    "pétrissons": "pétrir",
    "pétrit": "pétrir",
    "pétrochimies": "pétrochimie",
    "pétrochimiques": "pétrochimique",
    "pétrodollars": "pétrodollar",
    "pétrographies": "pétrographie",
    "pétroles": "pétrole",
    "pétroleuse": "pétroleur",
    "pétroleuses": "pétroleur",
    "pétroliers": "pétrolier",
    "pétrolifères": "pétrolifère",
    "pétrolière": "pétrolier",
    "pétrolières": "pétrolier",
    "pétrée": "pétré",
    "pétrîmes": "pétrir",
    "pétrît": "pétrir",
    "pétrîtes": "pétrir",
    "pétulances": "pétulance",
    "pétulante": "pétulant",
    "pétulantes": "pétulant",
    "pétulants": "pétulant",
    "pétunant": "pétuner",
    "pétunez": "pétuner",
    "pétunias": "pétunia",
    "pétuns": "pétun",
    "pétuné": "pétuner",
    "pétâmes": "péter",
    "pétât": "péter",
    "pétâtes": "péter",
    "pétèrent": "péter",
    "pété": "péter",
    "pétéchiale": "pétéchial",
    "pétéchies": "pétéchie",
    "pétée": "péter",
    "pétées": "péter",
    "pétés": "péter",
    "pêcha": "pêcher",
    "pêchai": "pêcher",
    "pêchaient": "pêcher",
    "pêchais": "pêcher",
    "pêchait": "pêcher",
    "pêchant": "pêcher",
    "pêchas": "pêcher",
    "pêchasse": "pêcher",
    "pêchassent": "pêcher",
    "pêchasses": "pêcher",
    "pêchassiez": "pêcher",
    "pêchassions": "pêcher",
    "pêche": "pêcher",
    "pêchent": "pêcher",
    "pêchera": "pêcher",
    "pêcherai": "pêcher",
    "pêcheraient": "pêcher",
    "pêcherais": "pêcher",
    "pêcherait": "pêcher",
    "pêcheras": "pêcher",
    "pêcherez": "pêcher",
    "pêcheries": "pêcherie",
    "pêcheriez": "pêcher",
    "pêcherions": "pêcher",
    "pêcherons": "pêcher",
    "pêcheront": "pêcher",
    "pêchers": "pêcher",
    "pêches": "pêcher",
    "pêcheurs": "pêcheur",
    "pêcheuse": "pêcheur",
    "pêcheuses": "pêcheur",
    "pêchez": "pêcher",
    "pêchiez": "pêcher",
    "pêchions": "pêcher",
    "pêchons": "pêcher",
    "pêchâmes": "pêcher",
    "pêchât": "pêcher",
    "pêchâtes": "pêcher",
    "pêchèrent": "pêcher",
    "pêché": "pêcher",
    "pêchée": "pêcher",
    "pêchées": "pêcher",
    "pêchés": "pêcher",
    "pênes": "pêne",
    "pôles": "pôle",
    "pûmes": "pouvoir",
    "pût": "pouvoir",
    "pûtes": "pouvoir",
    "qu'": "que",
    "quadragénaires": "quadragénaire",
    "quadragésimale": "quadragésimal",
    "quadragésimales": "quadragésimal",
    "quadragésimaux": "quadragésimal",
    "quadragésimes": "quadragésime",
    "quadrangulaires": "quadrangulaire",
    "quadrants": "quadrant",
    "quadras": "quadra",
    "quadratures": "quadrature",
    "quadrichromies": "quadrichromie",
    "quadriennale": "quadriennal",
    "quadriennales": "quadriennal",
    "quadriennaux": "quadriennal",
    "quadriges": "quadrige",
    "quadrilatères": "quadrilatère",
    "quadrilatérale": "quadrilatéral",
    "quadrilatérales": "quadrilatéral",
    "quadrilatéraux": "quadrilatéral",
    "quadrilla": "quadriller",
    "quadrillages": "quadrillage",
    "quadrillai": "quadriller",
    "quadrillaient": "quadriller",
    "quadrillais": "quadriller",
    "quadrillait": "quadriller",
    "quadrillant": "quadriller",
    "quadrillas": "quadriller",
    "quadrillasse": "quadriller",
    "quadrillassent": "quadriller",
    "quadrillasses": "quadriller",
    "quadrillassiez": "quadriller",
    "quadrillassions": "quadriller",
    "quadrille": "quadriller",
    "quadrillent": "quadriller",
    "quadrillera": "quadriller",
    "quadrillerai": "quadriller",
    "quadrilleraient": "quadriller",
    "quadrillerais": "quadriller",
    "quadrillerait": "quadriller",
    "quadrilleras": "quadriller",
    "quadrillerez": "quadriller",
    "quadrilleriez": "quadriller",
    "quadrillerions": "quadriller",
    "quadrillerons": "quadriller",
    "quadrilleront": "quadriller",
    "quadrilles": "quadriller",
    "quadrillez": "quadriller",
    "quadrilliez": "quadriller",
    "quadrillions": "quadriller",
    "quadrillons": "quadriller",
    "quadrillâmes": "quadriller",
    "quadrillât": "quadriller",
    "quadrillâtes": "quadriller",
    "quadrillèrent": "quadriller",
    "quadrillé": "quadriller",
    "quadrillée": "quadriller",
    "quadrillées": "quadriller",
    "quadrillés": "quadriller",
    "quadrimoteurs": "quadrimoteur",
    "quadripartites": "quadripartite",
    "quadriplaces": "quadriplace",
    "quadriréacteurs": "quadriréacteur",
    "quadrisyllabes": "quadrisyllabe",
    "quadrupla": "quadrupler",
    "quadruplait": "quadrupler",
    "quadruple": "quadrupler",
    "quadruples": "quadruple",
    "quadruplé": "quadrupler",
    "quadruplée": "quadruplé",
    "quadruplées": "quadruplée",
    "quadruplés": "quadrupler",
    "quadrupèdes": "quadrupède",
    "quais": "quai",
    "quakers": "quaker",
    "quakresse": "quaker",
    "quakresses": "quaker",
    "qualifia": "qualifier",
    "qualifiables": "qualifiable",
    "qualifiai": "qualifier",
    "qualifiaient": "qualifier",
    "qualifiais": "qualifier",
    "qualifiait": "qualifier",
    "qualifiant": "qualifier",
    "qualifiante": "qualifiant",
    "qualifiantes": "qualifiant",
    "qualifiants": "qualifiant",
    "qualifias": "qualifier",
    "qualifiasse": "qualifier",
    "qualifiassent": "qualifier",
    "qualifiasses": "qualifier",
    "qualifiassiez": "qualifier",
    "qualifiassions": "qualifier",
    "qualificatifs": "qualificatif",
    "qualifications": "qualification",
    "qualificative": "qualificatif",
    "qualificatives": "qualificatif",
    "qualifie": "qualifier",
    "qualifient": "qualifier",
    "qualifiera": "qualifier",
    "qualifierai": "qualifier",
    "qualifieraient": "qualifier",
    "qualifierais": "qualifier",
    "qualifierait": "qualifier",
    "qualifieras": "qualifier",
    "qualifierez": "qualifier",
    "qualifieriez": "qualifier",
    "qualifierions": "qualifier",
    "qualifierons": "qualifier",
    "qualifieront": "qualifier",
    "qualifies": "qualifier",
    "qualifiez": "qualifier",
    "qualifiiez": "qualifier",
    "qualifiions": "qualifier",
    "qualifions": "qualifier",
    "qualifiâmes": "qualifier",
    "qualifiât": "qualifier",
    "qualifiâtes": "qualifier",
    "qualifièrent": "qualifier",
    "qualifié": "qualifier",
    "qualifiée": "qualifier",
    "qualifiées": "qualifier",
    "qualifiés": "qualifier",
    "qualitatifs": "qualitatif",
    "qualitative": "qualitatif",
    "qualitatives": "qualitatif",
    "qualités": "qualité",
    "quanta": "quantum",
    "quantifia": "quantifier",
    "quantifiai": "quantifier",
    "quantifiaient": "quantifier",
    "quantifiais": "quantifier",
    "quantifiait": "quantifier",
    "quantifiant": "quantifier",
    "quantifias": "quantifier",
    "quantifiasse": "quantifier",
    "quantifiassent": "quantifier",
    "quantifiasses": "quantifier",
    "quantifiassiez": "quantifier",
    "quantifiassions": "quantifier",
    "quantifie": "quantifier",
    "quantifient": "quantifier",
    "quantifiera": "quantifier",
    "quantifierai": "quantifier",
    "quantifieraient": "quantifier",
    "quantifierais": "quantifier",
    "quantifierait": "quantifier",
    "quantifieras": "quantifier",
    "quantifierez": "quantifier",
    "quantifieriez": "quantifier",
    "quantifierions": "quantifier",
    "quantifierons": "quantifier",
    "quantifieront": "quantifier",
    "quantifies": "quantifier",
    "quantifiez": "quantifier",
    "quantifiiez": "quantifier",
    "quantifiions": "quantifier",
    "quantifions": "quantifier",
    "quantifiâmes": "quantifier",
    "quantifiât": "quantifier",
    "quantifiâtes": "quantifier",
    "quantifièrent": "quantifier",
    "quantifié": "quantifier",
    "quantifiée": "quantifier",
    "quantifiées": "quantifier",
    "quantifiés": "quantifier",
    "quantiques": "quantique",
    "quantitatifs": "quantitatif",
    "quantitative": "quantitatif",
    "quantitatives": "quantitatif",
    "quantités": "quantité",
    "quantièmes": "quantième",
    "quantums": "quantum",
    "quarantaines": "quarantaine",
    "quarante-cinquièmes": "quarante-cinquième",
    "quarante-deuxièmes": "quarante-deuxième",
    "quarante-et-unièmes": "quarante-et-unième",
    "quarante-huitards": "quarante-huitard",
    "quarante-huitièmes": "quarante-huitième",
    "quarante-neuvièmes": "quarante-neuvième",
    "quarante-quatrièmes": "quarante-quatrième",
    "quarante-septièmes": "quarante-septième",
    "quarante-sixièmes": "quarante-sixième",
    "quarante-troisièmes": "quarante-troisième",
    "quarantenaires": "quarantenaire",
    "quarantièmes": "quarantième",
    "quarks": "quark",
    "quarrez": "quarrer",
    "quarteronne": "quarteron",
    "quarteronnes": "quarteron",
    "quarterons": "quarteron",
    "quartes": "quarte",
    "quartettes": "quartette",
    "quartiers": "quartier",
    "quartiers-maîtres": "quartier-maître",
    "quarts": "quart",
    "quarts-de-pouce": "quart-de-pouce",
    "quarts-de-rond": "quart-de-rond",
    "quasi-contrats": "quasi-contrat",
    "quasi-délits": "quasi-délit",
    "quasi-fiancée": "quasi-fiancé",
    "quasi-futuristes": "quasi-futuriste",
    "quasimodos": "quasimodo",
    "quaternaires": "quaternaire",
    "quatorzièmes": "quatorzième",
    "quatrains": "quatrain",
    "quatre-vingt-cinquièmes": "quatre-vingt-cinquième",
    "quatre-vingt-deuxièmes": "quatre-vingt-deuxième",
    "quatre-vingt-dix-huitièmes": "quatre-vingt-dix-huitième",
    "quatre-vingt-dix-neuvièmes": "quatre-vingt-dix-neuvième",
    "quatre-vingt-dix-septièmes": "quatre-vingt-dix-septième",
    "quatre-vingt-douzièmes": "quatre-vingt-douzième",
    "quatre-vingt-huitièmes": "quatre-vingt-huitième",
    "quatre-vingt-neuvièmes": "quatre-vingt-neuvième",
    "quatre-vingt-onzièmes": "quatre-vingt-onzième",
    "quatre-vingt-quatorzièmes": "quatre-vingt-quatorzième",
    "quatre-vingt-quatrièmes": "quatre-vingt-quatrième",
    "quatre-vingt-quinzièmes": "quatre-vingt-quinzième",
    "quatre-vingt-seizièmes": "quatre-vingt-seizième",
    "quatre-vingt-septièmes": "quatre-vingt-septième",
    "quatre-vingt-sixièmes": "quatre-vingt-sixième",
    "quatre-vingt-treizièmes": "quatre-vingt-treizième",
    "quatre-vingt-troisièmes": "quatre-vingt-troisième",
    "quatre-vingt-une": "quatre-vingt-un",
    "quatre-vingt-unièmes": "quatre-vingt-unième",
    "quatre-vingts": "quatre-vingt",
    "quatrillions": "quatrillion",
    "quatrièmes": "quatrième",
    "quattrocentos": "quattrocento",
    "quatuors": "quatuor",
    "quelconques": "quelconque",
    "quelle": "quel",
    "quelles": "quel",
    "quelqu'": "quelque",
    "quelqu'une": "quelqu'un",
    "quelques": "quelque",
    "quelques-unes": "quelqu'un",
    "quelques-uns": "quelqu'un",
    "quels": "quel",
    "quenelles": "quenelle",
    "quenottes": "quenotte",
    "quenouilles": "quenouille",
    "querella": "quereller",
    "querellai": "quereller",
    "querellaient": "quereller",
    "querellais": "quereller",
    "querellait": "quereller",
    "querellant": "quereller",
    "querellas": "quereller",
    "querellasse": "quereller",
    "querellassent": "quereller",
    "querellasses": "quereller",
    "querellassiez": "quereller",
    "querellassions": "quereller",
    "querelle": "quereller",
    "querellent": "quereller",
    "querellera": "quereller",
    "querellerai": "quereller",
    "querelleraient": "quereller",
    "querellerais": "quereller",
    "querellerait": "quereller",
    "querelleras": "quereller",
    "querellerez": "quereller",
    "querelleriez": "quereller",
    "querellerions": "quereller",
    "querellerons": "quereller",
    "querelleront": "quereller",
    "querelles": "quereller",
    "querelleurs": "querelleur",
    "querelleuse": "querelleux",
    "querellez": "quereller",
    "querelliez": "quereller",
    "querellions": "quereller",
    "querellons": "quereller",
    "querellâmes": "quereller",
    "querellât": "quereller",
    "querellâtes": "quereller",
    "querellèrent": "quereller",
    "querellé": "quereller",
    "querellée": "quereller",
    "querellées": "quereller",
    "querellés": "quereller",
    "questeurs": "questeur",
    "questionna": "questionner",
    "questionnai": "questionner",
    "questionnaient": "questionner",
    "questionnaires": "questionnaire",
    "questionnais": "questionner",
    "questionnait": "questionner",
    "questionnant": "questionner",
    "questionnas": "questionner",
    "questionnasse": "questionner",
    "questionnassent": "questionner",
    "questionnasses": "questionner",
    "questionnassiez": "questionner",
    "questionnassions": "questionner",
    "questionne": "questionner",
    "questionnements": "questionnement",
    "questionnent": "questionner",
    "questionnera": "questionner",
    "questionnerai": "questionner",
    "questionneraient": "questionner",
    "questionnerais": "questionner",
    "questionnerait": "questionner",
    "questionneras": "questionner",
    "questionnerez": "questionner",
    "questionneriez": "questionner",
    "questionnerions": "questionner",
    "questionnerons": "questionner",
    "questionneront": "questionner",
    "questionnes": "questionner",
    "questionneurs": "questionneur",
    "questionneuse": "questionneur",
    "questionnez": "questionner",
    "questionniez": "questionner",
    "questionnions": "questionner",
    "questionnons": "questionner",
    "questionnâmes": "questionner",
    "questionnât": "questionner",
    "questionnâtes": "questionner",
    "questionnèrent": "questionner",
    "questionné": "questionner",
    "questionnée": "questionner",
    "questionnées": "questionner",
    "questionnés": "questionner",
    "questions": "question",
    "questions-réponses": "question-réponse",
    "quetsches": "quetsche",
    "quetzals": "quetzal",
    "queues": "queue",
    "queues-d'aronde": "queue-d'aronde",
    "queues-de-cheval": "queue-de-cheval",
    "queues-de-morue": "queue-de-morue",
    "queues-de-pie": "queue-de-pie",
    "queues-de-rat": "queue-de-rat",
    "queues-de-renard": "queue-de-renard",
    "queuta": "queuter",
    "queutai": "queuter",
    "queutaient": "queuter",
    "queutais": "queuter",
    "queutait": "queuter",
    "queutant": "queuter",
    "queutas": "queuter",
    "queutasse": "queuter",
    "queutassent": "queuter",
    "queutasses": "queuter",
    "queutassiez": "queuter",
    "queutassions": "queuter",
    "queute": "queuter",
    "queutent": "queuter",
    "queutera": "queuter",
    "queuterai": "queuter",
    "queuteraient": "queuter",
    "queuterais": "queuter",
    "queuterait": "queuter",
    "queuteras": "queuter",
    "queuterez": "queuter",
    "queuteriez": "queuter",
    "queuterions": "queuter",
    "queuterons": "queuter",
    "queuteront": "queuter",
    "queutes": "queuter",
    "queutez": "queuter",
    "queutiez": "queuter",
    "queutions": "queuter",
    "queutons": "queuter",
    "queutâmes": "queuter",
    "queutât": "queuter",
    "queutâtes": "queuter",
    "queutèrent": "queuter",
    "queuté": "queuter",
    "queutée": "queuter",
    "quiches": "quiche",
    "quidams": "quidam",
    "quiets": "quiet",
    "quignons": "quignon",
    "quillai": "quiller",
    "quillards": "quillard",
    "quilles": "quille",
    "quillons": "quillon",
    "quillée": "quiller",
    "quimpe": "quimper",
    "quimpent": "quimper",
    "quimpé": "quimper",
    "quinaude": "quinaud",
    "quinaudes": "quinaud",
    "quinauds": "quinaud",
    "quincailleries": "quincaillerie",
    "quincailliers": "quincaillier",
    "quincaillière": "quincaillier",
    "quincaillières": "quincaillier",
    "quinconces": "quinconce",
    "quines": "quine",
    "quinines": "quinine",
    "quinquagénaires": "quinquagénaire",
    "quinquennale": "quinquennal",
    "quinquennales": "quinquennal",
    "quinquennaux": "quinquennal",
    "quinquets": "quinquet",
    "quinquinas": "quinquina",
    "quintaux": "quintal",
    "quintes": "quinte",
    "quintessences": "quintessence",
    "quintessencié": "quintessencier",
    "quintessenciée": "quintessencié",
    "quintessenciées": "quintessencié",
    "quintettes": "quintette",
    "quinteuse": "quinteux",
    "quinteuses": "quinteux",
    "quintupla": "quintupler",
    "quintuples": "quintuple",
    "quintuplé": "quintupler",
    "quintuplée": "quintuplé",
    "quintuplées": "quintupler",
    "quintuplés": "quintupler",
    "quinzaines": "quinzaine",
    "quinzièmes": "quinzième",
    "quipos": "quipo",
    "quiproquos": "quiproquo",
    "quitta": "quitter",
    "quittai": "quitter",
    "quittaient": "quitter",
    "quittais": "quitter",
    "quittait": "quitter",
    "quittances": "quittance",
    "quittant": "quitter",
    "quittas": "quitter",
    "quittasse": "quitter",
    "quittassent": "quitter",
    "quittasses": "quitter",
    "quittassiez": "quitter",
    "quittassions": "quitter",
    "quitte": "quitter",
    "quittent": "quitter",
    "quittera": "quitter",
    "quitterai": "quitter",
    "quitteraient": "quitter",
    "quitterais": "quitter",
    "quitterait": "quitter",
    "quitteras": "quitter",
    "quitterez": "quitter",
    "quitteriez": "quitter",
    "quitterions": "quitter",
    "quitterons": "quitter",
    "quitteront": "quitter",
    "quittes": "quitter",
    "quittez": "quitter",
    "quittiez": "quitter",
    "quittions": "quitter",
    "quittons": "quitter",
    "quittâmes": "quitter",
    "quittât": "quitter",
    "quittâtes": "quitter",
    "quittèrent": "quitter",
    "quitté": "quitter",
    "quittée": "quitter",
    "quittées": "quitter",
    "quittés": "quitter",
    "quiète": "quiet",
    "quiètes": "quiet",
    "quiétismes": "quiétisme",
    "quiétudes": "quiétude",
    "quoaillant": "quoailler",
    "quoiqu'": "quoique",
    "quolibets": "quolibet",
    "quorums": "quorum",
    "quotas": "quota",
    "quotes-parts": "quote-part",
    "quotidienne": "quotidien",
    "quotidiennes": "quotidien",
    "quotidiennetés": "quotidienneté",
    "quotidiens": "quotidien",
    "quotients": "quotient",
    "quotités": "quotité",
    "québecoise": "québecois",
    "québecoises": "québecois",
    "québécoise": "québécois",
    "québécoises": "québécois",
    "quémanda": "quémander",
    "quémandai": "quémander",
    "quémandaient": "quémander",
    "quémandais": "quémander",
    "quémandait": "quémander",
    "quémandant": "quémander",
    "quémandas": "quémander",
    "quémandasse": "quémander",
    "quémandassent": "quémander",
    "quémandasses": "quémander",
    "quémandassiez": "quémander",
    "quémandassions": "quémander",
    "quémande": "quémander",
    "quémandent": "quémander",
    "quémandera": "quémander",
    "quémanderai": "quémander",
    "quémanderaient": "quémander",
    "quémanderais": "quémander",
    "quémanderait": "quémander",
    "quémanderas": "quémander",
    "quémanderez": "quémander",
    "quémanderiez": "quémander",
    "quémanderions": "quémander",
    "quémanderons": "quémander",
    "quémanderont": "quémander",
    "quémandes": "quémander",
    "quémandeurs": "quémandeur",
    "quémandeuse": "quémandeur",
    "quémandeuses": "quémandeur",
    "quémandez": "quémander",
    "quémandiez": "quémander",
    "quémandions": "quémander",
    "quémandons": "quémander",
    "quémandâmes": "quémander",
    "quémandât": "quémander",
    "quémandâtes": "quémander",
    "quémandèrent": "quémander",
    "quémandé": "quémander",
    "quémandée": "quémander",
    "quémandées": "quémander",
    "quémandés": "quémander",
    "quéquettes": "quéquette",
    "quêta": "quêter",
    "quêtai": "quêter",
    "quêtaient": "quêter",
    "quêtais": "quêter",
    "quêtait": "quêter",
    "quêtant": "quêter",
    "quêtas": "quêter",
    "quêtasse": "quêter",
    "quêtassent": "quêter",
    "quêtasses": "quêter",
    "quêtassiez": "quêter",
    "quêtassions": "quêter",
    "quête": "quêter",
    "quêtent": "quêter",
    "quêtera": "quêter",
    "quêterai": "quêter",
    "quêteraient": "quêter",
    "quêterais": "quêter",
    "quêterait": "quêter",
    "quêteras": "quêter",
    "quêterez": "quêter",
    "quêteriez": "quêter",
    "quêterions": "quêter",
    "quêterons": "quêter",
    "quêteront": "quêter",
    "quêtes": "quêter",
    "quêteurs": "quêteur",
    "quêteuse": "quêteur",
    "quêtez": "quêter",
    "quêtiez": "quêter",
    "quêtions": "quêter",
    "quêtons": "quêter",
    "quêtâmes": "quêter",
    "quêtât": "quêter",
    "quêtâtes": "quêter",
    "quêtèrent": "quêter",
    "quêté": "quêter",
    "quêtée": "quêter",
    "quêtées": "quêter",
    "quêtés": "quêter",
    "rabaissa": "rabaisser",
    "rabaissai": "rabaisser",
    "rabaissaient": "rabaisser",
    "rabaissais": "rabaisser",
    "rabaissait": "rabaisser",
    "rabaissant": "rabaisser",
    "rabaissas": "rabaisser",
    "rabaissasse": "rabaisser",
    "rabaissassent": "rabaisser",
    "rabaissasses": "rabaisser",
    "rabaissassiez": "rabaisser",
    "rabaissassions": "rabaisser",
    "rabaisse": "rabaisser",
    "rabaissent": "rabaisser",
    "rabaissera": "rabaisser",
    "rabaisserai": "rabaisser",
    "rabaisseraient": "rabaisser",
    "rabaisserais": "rabaisser",
    "rabaisserait": "rabaisser",
    "rabaisseras": "rabaisser",
    "rabaisserez": "rabaisser",
    "rabaisseriez": "rabaisser",
    "rabaisserions": "rabaisser",
    "rabaisserons": "rabaisser",
    "rabaisseront": "rabaisser",
    "rabaisses": "rabaisser",
    "rabaissez": "rabaisser",
    "rabaissiez": "rabaisser",
    "rabaissions": "rabaisser",
    "rabaissons": "rabaisser",
    "rabaissâmes": "rabaisser",
    "rabaissât": "rabaisser",
    "rabaissâtes": "rabaisser",
    "rabaissèrent": "rabaisser",
    "rabaissé": "rabaisser",
    "rabaissée": "rabaisser",
    "rabaissées": "rabaisser",
    "rabaissés": "rabaisser",
    "rabanes": "rabane",
    "rabans": "raban",
    "rabat": "rabattre",
    "rabats": "rabattre",
    "rabattages": "rabattage",
    "rabattaient": "rabattre",
    "rabattais": "rabattre",
    "rabattait": "rabattre",
    "rabattant": "rabattre",
    "rabatte": "rabattre",
    "rabattent": "rabattre",
    "rabattes": "rabattre",
    "rabatteurs": "rabatteur",
    "rabatteuse": "rabatteur",
    "rabatteuses": "rabatteur",
    "rabattez": "rabattre",
    "rabattiez": "rabattre",
    "rabattions": "rabattre",
    "rabattirent": "rabattre",
    "rabattis": "rabattre",
    "rabattisse": "rabattre",
    "rabattissent": "rabattre",
    "rabattisses": "rabattre",
    "rabattissiez": "rabattre",
    "rabattissions": "rabattre",
    "rabattit": "rabattre",
    "rabattons": "rabattre",
    "rabattra": "rabattre",
    "rabattrai": "rabattre",
    "rabattraient": "rabattre",
    "rabattrais": "rabattre",
    "rabattrait": "rabattre",
    "rabattras": "rabattre",
    "rabattrez": "rabattre",
    "rabattriez": "rabattre",
    "rabattrions": "rabattre",
    "rabattrons": "rabattre",
    "rabattront": "rabattre",
    "rabattu": "rabattre",
    "rabattue": "rabattu",
    "rabattues": "rabattu",
    "rabattus": "rabattu",
    "rabattîmes": "rabattre",
    "rabattît": "rabattre",
    "rabattîtes": "rabattre",
    "rabbiniques": "rabbinique",
    "rabbins": "rabbin",
    "rabelaisienne": "rabelaisien",
    "rabelaisiennes": "rabelaisien",
    "rabelaisiens": "rabelaisien",
    "rabes": "rabe",
    "rabibocha": "rabibocher",
    "rabibochai": "rabibocher",
    "rabibochaient": "rabibocher",
    "rabibochais": "rabibocher",
    "rabibochait": "rabibocher",
    "rabibochant": "rabibocher",
    "rabibochas": "rabibocher",
    "rabibochasse": "rabibocher",
    "rabibochassent": "rabibocher",
    "rabibochasses": "rabibocher",
    "rabibochassiez": "rabibocher",
    "rabibochassions": "rabibocher",
    "rabiboche": "rabibocher",
    "rabibochent": "rabibocher",
    "rabibochera": "rabibocher",
    "rabibocherai": "rabibocher",
    "rabibocheraient": "rabibocher",
    "rabibocherais": "rabibocher",
    "rabibocherait": "rabibocher",
    "rabibocheras": "rabibocher",
    "rabibocherez": "rabibocher",
    "rabibocheriez": "rabibocher",
    "rabibocherions": "rabibocher",
    "rabibocherons": "rabibocher",
    "rabibocheront": "rabibocher",
    "rabiboches": "rabibocher",
    "rabibochez": "rabibocher",
    "rabibochiez": "rabibocher",
    "rabibochions": "rabibocher",
    "rabibochons": "rabibocher",
    "rabibochâmes": "rabibocher",
    "rabibochât": "rabibocher",
    "rabibochâtes": "rabibocher",
    "rabibochèrent": "rabibocher",
    "rabiboché": "rabibocher",
    "rabibochée": "rabibocher",
    "rabibochées": "rabibocher",
    "rabibochés": "rabibocher",
    "rabiotait": "rabioter",
    "rabiots": "rabiot",
    "rabiques": "rabique",
    "rabonni": "rabonnir",
    "rabonnie": "rabonnir",
    "rabonnies": "rabonnir",
    "rabonnira": "rabonnir",
    "rabonnirai": "rabonnir",
    "rabonniraient": "rabonnir",
    "rabonnirais": "rabonnir",
    "rabonnirait": "rabonnir",
    "rabonniras": "rabonnir",
    "rabonnirent": "rabonnir",
    "rabonnirez": "rabonnir",
    "rabonniriez": "rabonnir",
    "rabonnirions": "rabonnir",
    "rabonnirons": "rabonnir",
    "rabonniront": "rabonnir",
    "rabonnis": "rabonnir",
    "rabonnissaient": "rabonnir",
    "rabonnissais": "rabonnir",
    "rabonnissait": "rabonnir",
    "rabonnissant": "rabonnir",
    "rabonnisse": "rabonnir",
    "rabonnissent": "rabonnir",
    "rabonnisses": "rabonnir",
    "rabonnissez": "rabonnir",
    "rabonnissiez": "rabonnir",
    "rabonnissions": "rabonnir",
    "rabonnissons": "rabonnir",
    "rabonnit": "rabonnir",
    "rabonnîmes": "rabonnir",
    "rabonnît": "rabonnir",
    "rabonnîtes": "rabonnir",
    "rabota": "raboter",
    "rabotai": "raboter",
    "rabotaient": "raboter",
    "rabotais": "raboter",
    "rabotait": "raboter",
    "rabotant": "raboter",
    "rabotas": "raboter",
    "rabotasse": "raboter",
    "rabotassent": "raboter",
    "rabotasses": "raboter",
    "rabotassiez": "raboter",
    "rabotassions": "raboter",
    "rabote": "raboter",
    "rabotent": "raboter",
    "rabotera": "raboter",
    "raboterai": "raboter",
    "raboteraient": "raboter",
    "raboterais": "raboter",
    "raboterait": "raboter",
    "raboteras": "raboter",
    "raboterez": "raboter",
    "raboteriez": "raboter",
    "raboterions": "raboter",
    "raboterons": "raboter",
    "raboteront": "raboter",
    "rabotes": "raboter",
    "raboteuse": "raboteux",
    "raboteuses": "raboteux",
    "rabotez": "raboter",
    "rabotiez": "raboter",
    "rabotions": "raboter",
    "rabotons": "raboter",
    "rabots": "rabot",
    "rabotâmes": "raboter",
    "rabotât": "raboter",
    "rabotâtes": "raboter",
    "rabotèrent": "raboter",
    "raboté": "raboter",
    "rabotée": "raboter",
    "rabotées": "raboter",
    "rabotés": "raboter",
    "rabougri": "rabougrir",
    "rabougrie": "rabougrir",
    "rabougries": "rabougrir",
    "rabougrira": "rabougrir",
    "rabougrirai": "rabougrir",
    "rabougriraient": "rabougrir",
    "rabougrirais": "rabougrir",
    "rabougrirait": "rabougrir",
    "rabougriras": "rabougrir",
    "rabougrirent": "rabougrir",
    "rabougrirez": "rabougrir",
    "rabougririez": "rabougrir",
    "rabougririons": "rabougrir",
    "rabougrirons": "rabougrir",
    "rabougriront": "rabougrir",
    "rabougris": "rabougrir",
    "rabougrissaient": "rabougrir",
    "rabougrissais": "rabougrir",
    "rabougrissait": "rabougrir",
    "rabougrissant": "rabougrir",
    "rabougrisse": "rabougrir",
    "rabougrissent": "rabougrir",
    "rabougrisses": "rabougrir",
    "rabougrissez": "rabougrir",
    "rabougrissiez": "rabougrir",
    "rabougrissions": "rabougrir",
    "rabougrissons": "rabougrir",
    "rabougrit": "rabougrir",
    "rabougrîmes": "rabougrir",
    "rabougrît": "rabougrir",
    "rabougrîtes": "rabougrir",
    "rabouilleurs": "rabouilleur",
    "rabouilleuse": "rabouilleur",
    "rabouilleuses": "rabouilleur",
    "rabouillères": "rabouiller",
    "rabouta": "rabouter",
    "raboutai": "rabouter",
    "raboutaient": "rabouter",
    "raboutais": "rabouter",
    "raboutait": "rabouter",
    "raboutant": "rabouter",
    "raboutas": "rabouter",
    "raboutasse": "rabouter",
    "raboutassent": "rabouter",
    "raboutasses": "rabouter",
    "raboutassiez": "rabouter",
    "raboutassions": "rabouter",
    "raboute": "rabouter",
    "raboutent": "rabouter",
    "raboutera": "rabouter",
    "rabouterai": "rabouter",
    "rabouteraient": "rabouter",
    "rabouterais": "rabouter",
    "rabouterait": "rabouter",
    "rabouteras": "rabouter",
    "rabouterez": "rabouter",
    "rabouteriez": "rabouter",
    "rabouterions": "rabouter",
    "rabouterons": "rabouter",
    "rabouteront": "rabouter",
    "raboutes": "rabouter",
    "raboutez": "rabouter",
    "rabouti": "raboutir",
    "raboutie": "raboutir",
    "rabouties": "raboutir",
    "raboutiez": "rabouter",
    "raboutions": "rabouter",
    "raboutira": "raboutir",
    "raboutirai": "raboutir",
    "raboutiraient": "raboutir",
    "raboutirais": "raboutir",
    "raboutirait": "raboutir",
    "raboutiras": "raboutir",
    "raboutirent": "raboutir",
    "raboutirez": "raboutir",
    "raboutiriez": "raboutir",
    "raboutirions": "raboutir",
    "raboutirons": "raboutir",
    "raboutiront": "raboutir",
    "raboutis": "raboutir",
    "raboutissaient": "raboutir",
    "raboutissais": "raboutir",
    "raboutissait": "raboutir",
    "raboutissant": "raboutir",
    "raboutisse": "raboutir",
    "raboutissent": "raboutir",
    "raboutisses": "raboutir",
    "raboutissez": "raboutir",
    "raboutissiez": "raboutir",
    "raboutissions": "raboutir",
    "raboutissons": "raboutir",
    "raboutit": "raboutir",
    "raboutons": "rabouter",
    "raboutâmes": "rabouter",
    "raboutât": "rabouter",
    "raboutâtes": "rabouter",
    "raboutèrent": "rabouter",
    "rabouté": "rabouter",
    "raboutée": "rabouter",
    "raboutées": "rabouter",
    "raboutés": "rabouter",
    "raboutîmes": "raboutir",
    "raboutît": "raboutir",
    "raboutîtes": "raboutir",
    "rabroua": "rabrouer",
    "rabrouai": "rabrouer",
    "rabrouaient": "rabrouer",
    "rabrouais": "rabrouer",
    "rabrouait": "rabrouer",
    "rabrouant": "rabrouer",
    "rabrouas": "rabrouer",
    "rabrouasse": "rabrouer",
    "rabrouassent": "rabrouer",
    "rabrouasses": "rabrouer",
    "rabrouassiez": "rabrouer",
    "rabrouassions": "rabrouer",
    "rabroue": "rabrouer",
    "rabrouent": "rabrouer",
    "rabrouera": "rabrouer",
    "rabrouerai": "rabrouer",
    "rabroueraient": "rabrouer",
    "rabrouerais": "rabrouer",
    "rabrouerait": "rabrouer",
    "rabroueras": "rabrouer",
    "rabrouerez": "rabrouer",
    "rabroueriez": "rabrouer",
    "rabrouerions": "rabrouer",
    "rabrouerons": "rabrouer",
    "rabroueront": "rabrouer",
    "rabroues": "rabrouer",
    "rabrouez": "rabrouer",
    "rabrouiez": "rabrouer",
    "rabrouions": "rabrouer",
    "rabrouons": "rabrouer",
    "rabrouâmes": "rabrouer",
    "rabrouât": "rabrouer",
    "rabrouâtes": "rabrouer",
    "rabrouèrent": "rabrouer",
    "rabroué": "rabrouer",
    "rabrouée": "rabrouer",
    "rabrouées": "rabrouer",
    "rabroués": "rabrouer",
    "rabs": "rab",
    "rabâcha": "rabâcher",
    "rabâchages": "rabâchage",
    "rabâchai": "rabâcher",
    "rabâchaient": "rabâcher",
    "rabâchais": "rabâcher",
    "rabâchait": "rabâcher",
    "rabâchant": "rabâcher",
    "rabâchas": "rabâcher",
    "rabâchasse": "rabâcher",
    "rabâchassent": "rabâcher",
    "rabâchasses": "rabâcher",
    "rabâchassiez": "rabâcher",
    "rabâchassions": "rabâcher",
    "rabâche": "rabâcher",
    "rabâchent": "rabâcher",
    "rabâchera": "rabâcher",
    "rabâcherai": "rabâcher",
    "rabâcheraient": "rabâcher",
    "rabâcherais": "rabâcher",
    "rabâcherait": "rabâcher",
    "rabâcheras": "rabâcher",
    "rabâcherez": "rabâcher",
    "rabâcheriez": "rabâcher",
    "rabâcherions": "rabâcher",
    "rabâcherons": "rabâcher",
    "rabâcheront": "rabâcher",
    "rabâches": "rabâcher",
    "rabâchez": "rabâcher",
    "rabâchiez": "rabâcher",
    "rabâchions": "rabâcher",
    "rabâchons": "rabâcher",
    "rabâchâmes": "rabâcher",
    "rabâchât": "rabâcher",
    "rabâchâtes": "rabâcher",
    "rabâchèrent": "rabâcher",
    "rabâché": "rabâcher",
    "rabâchée": "rabâcher",
    "rabâchées": "rabâcher",
    "rabâchés": "rabâcher",
    "rabêti": "rabêtir",
    "rabêtie": "rabêtir",
    "rabêties": "rabêtir",
    "rabêtira": "rabêtir",
    "rabêtirai": "rabêtir",
    "rabêtiraient": "rabêtir",
    "rabêtirais": "rabêtir",
    "rabêtirait": "rabêtir",
    "rabêtiras": "rabêtir",
    "rabêtirent": "rabêtir",
    "rabêtirez": "rabêtir",
    "rabêtiriez": "rabêtir",
    "rabêtirions": "rabêtir",
    "rabêtirons": "rabêtir",
    "rabêtiront": "rabêtir",
    "rabêtis": "rabêtir",
    "rabêtissaient": "rabêtir",
    "rabêtissais": "rabêtir",
    "rabêtissait": "rabêtir",
    "rabêtissant": "rabêtir",
    "rabêtisse": "rabêtir",
    "rabêtissent": "rabêtir",
    "rabêtisses": "rabêtir",
    "rabêtissez": "rabêtir",
    "rabêtissiez": "rabêtir",
    "rabêtissions": "rabêtir",
    "rabêtissons": "rabêtir",
    "rabêtit": "rabêtir",
    "rabêtîmes": "rabêtir",
    "rabêtît": "rabêtir",
    "rabêtîtes": "rabêtir",
    "racailles": "racaille",
    "raccommoda": "raccommoder",
    "raccommodages": "raccommodage",
    "raccommodai": "raccommoder",
    "raccommodaient": "raccommoder",
    "raccommodais": "raccommoder",
    "raccommodait": "raccommoder",
    "raccommodant": "raccommoder",
    "raccommodas": "raccommoder",
    "raccommodasse": "raccommoder",
    "raccommodassent": "raccommoder",
    "raccommodasses": "raccommoder",
    "raccommodassiez": "raccommoder",
    "raccommodassions": "raccommoder",
    "raccommode": "raccommoder",
    "raccommodements": "raccommodement",
    "raccommodent": "raccommoder",
    "raccommodera": "raccommoder",
    "raccommoderai": "raccommoder",
    "raccommoderaient": "raccommoder",
    "raccommoderais": "raccommoder",
    "raccommoderait": "raccommoder",
    "raccommoderas": "raccommoder",
    "raccommoderez": "raccommoder",
    "raccommoderiez": "raccommoder",
    "raccommoderions": "raccommoder",
    "raccommoderons": "raccommoder",
    "raccommoderont": "raccommoder",
    "raccommodes": "raccommoder",
    "raccommodeurs": "raccommodeur",
    "raccommodez": "raccommoder",
    "raccommodiez": "raccommoder",
    "raccommodions": "raccommoder",
    "raccommodons": "raccommoder",
    "raccommodâmes": "raccommoder",
    "raccommodât": "raccommoder",
    "raccommodâtes": "raccommoder",
    "raccommodèrent": "raccommoder",
    "raccommodé": "raccommoder",
    "raccommodée": "raccommoder",
    "raccommodées": "raccommoder",
    "raccommodés": "raccommoder",
    "raccompagna": "raccompagner",
    "raccompagnai": "raccompagner",
    "raccompagnaient": "raccompagner",
    "raccompagnais": "raccompagner",
    "raccompagnait": "raccompagner",
    "raccompagnant": "raccompagner",
    "raccompagnas": "raccompagner",
    "raccompagnasse": "raccompagner",
    "raccompagnassent": "raccompagner",
    "raccompagnasses": "raccompagner",
    "raccompagnassiez": "raccompagner",
    "raccompagnassions": "raccompagner",
    "raccompagne": "raccompagner",
    "raccompagnent": "raccompagner",
    "raccompagnera": "raccompagner",
    "raccompagnerai": "raccompagner",
    "raccompagneraient": "raccompagner",
    "raccompagnerais": "raccompagner",
    "raccompagnerait": "raccompagner",
    "raccompagneras": "raccompagner",
    "raccompagnerez": "raccompagner",
    "raccompagneriez": "raccompagner",
    "raccompagnerions": "raccompagner",
    "raccompagnerons": "raccompagner",
    "raccompagneront": "raccompagner",
    "raccompagnes": "raccompagner",
    "raccompagnez": "raccompagner",
    "raccompagniez": "raccompagner",
    "raccompagnions": "raccompagner",
    "raccompagnons": "raccompagner",
    "raccompagnâmes": "raccompagner",
    "raccompagnât": "raccompagner",
    "raccompagnâtes": "raccompagner",
    "raccompagnèrent": "raccompagner",
    "raccompagné": "raccompagner",
    "raccompagnée": "raccompagner",
    "raccompagnées": "raccompagner",
    "raccompagnés": "raccompagner",
    "raccorda": "raccorder",
    "raccordai": "raccorder",
    "raccordaient": "raccorder",
    "raccordais": "raccorder",
    "raccordait": "raccorder",
    "raccordant": "raccorder",
    "raccordas": "raccorder",
    "raccordasse": "raccorder",
    "raccordassent": "raccorder",
    "raccordasses": "raccorder",
    "raccordassiez": "raccorder",
    "raccordassions": "raccorder",
    "raccorde": "raccorder",
    "raccordements": "raccordement",
    "raccordent": "raccorder",
    "raccordera": "raccorder",
    "raccorderai": "raccorder",
    "raccorderaient": "raccorder",
    "raccorderais": "raccorder",
    "raccorderait": "raccorder",
    "raccorderas": "raccorder",
    "raccorderez": "raccorder",
    "raccorderiez": "raccorder",
    "raccorderions": "raccorder",
    "raccorderons": "raccorder",
    "raccorderont": "raccorder",
    "raccordes": "raccorder",
    "raccordez": "raccorder",
    "raccordiez": "raccorder",
    "raccordions": "raccorder",
    "raccordons": "raccorder",
    "raccords": "raccord",
    "raccordâmes": "raccorder",
    "raccordât": "raccorder",
    "raccordâtes": "raccorder",
    "raccordèrent": "raccorder",
    "raccordé": "raccorder",
    "raccordée": "raccorder",
    "raccordées": "raccorder",
    "raccordés": "raccorder",
    "raccourci": "raccourcir",
    "raccourcie": "raccourcir",
    "raccourcies": "raccourcir",
    "raccourcira": "raccourcir",
    "raccourcirai": "raccourcir",
    "raccourciraient": "raccourcir",
    "raccourcirais": "raccourcir",
    "raccourcirait": "raccourcir",
    "raccourciras": "raccourcir",
    "raccourcirent": "raccourcir",
    "raccourcirez": "raccourcir",
    "raccourciriez": "raccourcir",
    "raccourcirions": "raccourcir",
    "raccourcirons": "raccourcir",
    "raccourciront": "raccourcir",
    "raccourcis": "raccourcir",
    "raccourcissaient": "raccourcir",
    "raccourcissais": "raccourcir",
    "raccourcissait": "raccourcir",
    "raccourcissant": "raccourcir",
    "raccourcisse": "raccourcir",
    "raccourcissements": "raccourcissement",
    "raccourcissent": "raccourcir",
    "raccourcisses": "raccourcir",
    "raccourcissez": "raccourcir",
    "raccourcissiez": "raccourcir",
    "raccourcissions": "raccourcir",
    "raccourcissons": "raccourcir",
    "raccourcit": "raccourcir",
    "raccourcîmes": "raccourcir",
    "raccourcît": "raccourcir",
    "raccourcîtes": "raccourcir",
    "raccrocha": "raccrocher",
    "raccrochages": "raccrochage",
    "raccrochai": "raccrocher",
    "raccrochaient": "raccrocher",
    "raccrochais": "raccrocher",
    "raccrochait": "raccrocher",
    "raccrochant": "raccrocher",
    "raccrochas": "raccrocher",
    "raccrochasse": "raccrocher",
    "raccrochassent": "raccrocher",
    "raccrochasses": "raccrocher",
    "raccrochassiez": "raccrocher",
    "raccrochassions": "raccrocher",
    "raccroche": "raccrocher",
    "raccrochent": "raccrocher",
    "raccrochera": "raccrocher",
    "raccrocherai": "raccrocher",
    "raccrocheraient": "raccrocher",
    "raccrocherais": "raccrocher",
    "raccrocherait": "raccrocher",
    "raccrocheras": "raccrocher",
    "raccrocherez": "raccrocher",
    "raccrocheriez": "raccrocher",
    "raccrocherions": "raccrocher",
    "raccrocherons": "raccrocher",
    "raccrocheront": "raccrocher",
    "raccroches": "raccrocher",
    "raccrocheurs": "raccrocheur",
    "raccrochez": "raccrocher",
    "raccrochiez": "raccrocher",
    "raccrochions": "raccrocher",
    "raccrochons": "raccrocher",
    "raccrochâmes": "raccrocher",
    "raccrochât": "raccrocher",
    "raccrochâtes": "raccrocher",
    "raccrochèrent": "raccrocher",
    "raccroché": "raccrocher",
    "raccrochée": "raccrocher",
    "raccrochées": "raccrocher",
    "raccrochés": "raccrocher",
    "raccrocs": "raccroc",
    "raccusa": "raccuser",
    "racers": "racer",
    "races": "race",
    "rachats": "rachat",
    "racheta": "racheter",
    "rachetai": "racheter",
    "rachetaient": "racheter",
    "rachetais": "racheter",
    "rachetait": "racheter",
    "rachetant": "racheter",
    "rachetas": "racheter",
    "rachetasse": "racheter",
    "rachetassent": "racheter",
    "rachetasses": "racheter",
    "rachetassiez": "racheter",
    "rachetassions": "racheter",
    "rachetez": "racheter",
    "rachetiez": "racheter",
    "rachetions": "racheter",
    "rachetons": "racheter",
    "rachetâmes": "racheter",
    "rachetât": "racheter",
    "rachetâtes": "racheter",
    "rachetèrent": "racheter",
    "racheté": "racheter",
    "rachetée": "racheter",
    "rachetées": "racheter",
    "rachetés": "racheter",
    "rachidienne": "rachidien",
    "rachidiennes": "rachidien",
    "rachidiens": "rachidien",
    "rachitiques": "rachitique",
    "rachète": "racheter",
    "rachètent": "racheter",
    "rachètera": "racheter",
    "rachèterai": "racheter",
    "rachèteraient": "racheter",
    "rachèterais": "racheter",
    "rachèterait": "racheter",
    "rachèteras": "racheter",
    "rachèterez": "racheter",
    "rachèteriez": "racheter",
    "rachèterions": "racheter",
    "rachèterons": "racheter",
    "rachèteront": "racheter",
    "rachètes": "racheter",
    "raciale": "racial",
    "raciales": "racial",
    "raciaux": "racial",
    "racinait": "raciner",
    "racinaux": "racinal",
    "racines": "racine",
    "racinienne": "racinien",
    "raciniennes": "racinien",
    "raciniens": "racinien",
    "racinée": "raciner",
    "racinées": "raciner",
    "racinés": "raciner",
    "racismes": "racisme",
    "racistes": "raciste",
    "rackets": "racket",
    "rackette": "racketter",
    "racketteurs": "racketteur",
    "racketteuse": "racketteur",
    "racketteuses": "racketteur",
    "rackettez": "racketter",
    "rackettons": "racketter",
    "racketté": "racketter",
    "racla": "racler",
    "raclages": "raclage",
    "raclai": "racler",
    "raclaient": "racler",
    "raclais": "racler",
    "raclait": "racler",
    "raclant": "racler",
    "raclante": "raclant",
    "raclas": "racler",
    "raclasse": "racler",
    "raclassent": "racler",
    "raclasses": "racler",
    "raclassiez": "racler",
    "raclassions": "racler",
    "racle": "racler",
    "raclements": "raclement",
    "raclent": "racler",
    "raclera": "racler",
    "raclerai": "racler",
    "racleraient": "racler",
    "raclerais": "racler",
    "raclerait": "racler",
    "racleras": "racler",
    "raclerez": "racler",
    "racleriez": "racler",
    "raclerions": "racler",
    "raclerons": "racler",
    "racleront": "racler",
    "racles": "racler",
    "racleuse": "racleur",
    "raclez": "racler",
    "racliez": "racler",
    "raclions": "racler",
    "raclons": "raclon",
    "raclures": "raclure",
    "raclâmes": "racler",
    "raclât": "racler",
    "raclâtes": "racler",
    "raclèrent": "racler",
    "raclé": "racler",
    "raclée": "racler",
    "raclées": "racler",
    "raclés": "racler",
    "racola": "racoler",
    "racolages": "racolage",
    "racolai": "racoler",
    "racolaient": "racoler",
    "racolais": "racoler",
    "racolait": "racoler",
    "racolant": "racoler",
    "racolas": "racoler",
    "racolasse": "racoler",
    "racolassent": "racoler",
    "racolasses": "racoler",
    "racolassiez": "racoler",
    "racolassions": "racoler",
    "racole": "racoler",
    "racolent": "racoler",
    "racolera": "racoler",
    "racolerai": "racoler",
    "racoleraient": "racoler",
    "racolerais": "racoler",
    "racolerait": "racoler",
    "racoleras": "racoler",
    "racolerez": "racoler",
    "racoleriez": "racoler",
    "racolerions": "racoler",
    "racolerons": "racoler",
    "racoleront": "racoler",
    "racoles": "racoler",
    "racoleurs": "racoleur",
    "racoleuse": "racoleur",
    "racoleuses": "racoleur",
    "racolez": "racoler",
    "racoliez": "racoler",
    "racolions": "racoler",
    "racolons": "racoler",
    "racolâmes": "racoler",
    "racolât": "racoler",
    "racolâtes": "racoler",
    "racolèrent": "racoler",
    "racolé": "racoler",
    "racolée": "racoler",
    "racolées": "racoler",
    "racolés": "racoler",
    "raconta": "raconter",
    "racontables": "racontable",
    "racontai": "raconter",
    "racontaient": "raconter",
    "racontais": "raconter",
    "racontait": "raconter",
    "racontant": "raconter",
    "racontars": "racontar",
    "racontas": "raconter",
    "racontasse": "raconter",
    "racontassent": "raconter",
    "racontasses": "raconter",
    "racontassiez": "raconter",
    "racontassions": "raconter",
    "raconte": "raconter",
    "racontent": "raconter",
    "racontera": "raconter",
    "raconterai": "raconter",
    "raconteraient": "raconter",
    "raconterais": "raconter",
    "raconterait": "raconter",
    "raconteras": "raconter",
    "raconterez": "raconter",
    "raconteriez": "raconter",
    "raconterions": "raconter",
    "raconterons": "raconter",
    "raconteront": "raconter",
    "racontes": "raconter",
    "raconteuse": "raconteur",
    "racontez": "raconter",
    "racontiez": "raconter",
    "racontions": "raconter",
    "racontons": "raconter",
    "racontâmes": "raconter",
    "racontât": "raconter",
    "racontâtes": "raconter",
    "racontèrent": "raconter",
    "raconté": "raconter",
    "racontée": "raconter",
    "racontées": "raconter",
    "racontés": "raconter",
    "racorni": "racornir",
    "racornie": "racornir",
    "racornies": "racornir",
    "racornira": "racornir",
    "racornirai": "racornir",
    "racorniraient": "racornir",
    "racornirais": "racornir",
    "racornirait": "racornir",
    "racorniras": "racornir",
    "racornirent": "racornir",
    "racornirez": "racornir",
    "racorniriez": "racornir",
    "racornirions": "racornir",
    "racornirons": "racornir",
    "racorniront": "racornir",
    "racornis": "racornir",
    "racornissaient": "racornir",
    "racornissais": "racornir",
    "racornissait": "racornir",
    "racornissant": "racornir",
    "racornisse": "racornir",
    "racornissent": "racornir",
    "racornisses": "racornir",
    "racornissez": "racornir",
    "racornissiez": "racornir",
    "racornissions": "racornir",
    "racornissons": "racornir",
    "racornit": "racornir",
    "racornîmes": "racornir",
    "racornît": "racornir",
    "racornîtes": "racornir",
    "racée": "racé",
    "racémiques": "racémique",
    "racés": "racé",
    "rada": "rader",
    "radai": "rader",
    "radaient": "rader",
    "radais": "rader",
    "radait": "rader",
    "radant": "rader",
    "radars": "radar",
    "radas": "rader",
    "radasse": "rader",
    "radassent": "rader",
    "radasses": "rader",
    "radassiez": "rader",
    "radassions": "rader",
    "rade": "rader",
    "radeaux": "radeau",
    "radent": "rader",
    "radera": "rader",
    "raderai": "rader",
    "raderaient": "rader",
    "raderais": "rader",
    "raderait": "rader",
    "raderas": "rader",
    "raderez": "rader",
    "raderiez": "rader",
    "raderions": "rader",
    "raderons": "rader",
    "raderont": "rader",
    "rades": "rader",
    "radeuses": "radeuse",
    "radez": "rader",
    "radia": "radier",
    "radiai": "radier",
    "radiaient": "radier",
    "radiais": "radier",
    "radiait": "radier",
    "radiale": "radial",
    "radiales": "radial",
    "radians": "radian",
    "radiant": "radier",
    "radiante": "radiant",
    "radiantes": "radiant",
    "radiants": "radiant",
    "radias": "radier",
    "radiasse": "radier",
    "radiassent": "radier",
    "radiasses": "radier",
    "radiassiez": "radier",
    "radiassions": "radier",
    "radiateurs": "radiateur",
    "radiations": "radiation",
    "radiative": "radiatif",
    "radiaux": "radial",
    "radicale": "radical",
    "radicales": "radical",
    "radicalisa": "radicaliser",
    "radicalisai": "radicaliser",
    "radicalisaient": "radicaliser",
    "radicalisais": "radicaliser",
    "radicalisait": "radicaliser",
    "radicalisant": "radicaliser",
    "radicalisas": "radicaliser",
    "radicalisasse": "radicaliser",
    "radicalisassent": "radicaliser",
    "radicalisasses": "radicaliser",
    "radicalisassiez": "radicaliser",
    "radicalisassions": "radicaliser",
    "radicalisations": "radicalisation",
    "radicalise": "radicaliser",
    "radicalisent": "radicaliser",
    "radicalisera": "radicaliser",
    "radicaliserai": "radicaliser",
    "radicaliseraient": "radicaliser",
    "radicaliserais": "radicaliser",
    "radicaliserait": "radicaliser",
    "radicaliseras": "radicaliser",
    "radicaliserez": "radicaliser",
    "radicaliseriez": "radicaliser",
    "radicaliserions": "radicaliser",
    "radicaliserons": "radicaliser",
    "radicaliseront": "radicaliser",
    "radicalises": "radicaliser",
    "radicalisez": "radicaliser",
    "radicalisiez": "radicaliser",
    "radicalisions": "radicaliser",
    "radicalisons": "radicaliser",
    "radicalisâmes": "radicaliser",
    "radicalisât": "radicaliser",
    "radicalisâtes": "radicaliser",
    "radicalisèrent": "radicaliser",
    "radicalisé": "radicaliser",
    "radicalisée": "radicaliser",
    "radicalisées": "radicaliser",
    "radicalisés": "radicaliser",
    "radicante": "radicant",
    "radicantes": "radicant",
    "radicants": "radicant",
    "radicaux": "radical",
    "radicaux-socialistes": "radical-socialiste",
    "radicelles": "radicelle",
    "radicules": "radicule",
    "radie": "radier",
    "radient": "radier",
    "radiera": "radier",
    "radierai": "radier",
    "radieraient": "radier",
    "radierais": "radier",
    "radierait": "radier",
    "radieras": "radier",
    "radierez": "radier",
    "radieriez": "radier",
    "radierions": "radier",
    "radierons": "radier",
    "radieront": "radier",
    "radiers": "radier",
    "radies": "radier",
    "radiesthésies": "radiesthésie",
    "radieuse": "radieux",
    "radieuses": "radieux",
    "radiez": "radier",
    "radiiez": "radier",
    "radiions": "radier",
    "radinait": "radiner",
    "radine": "radiner",
    "radinent": "radiner",
    "radines": "radiner",
    "radinez": "radiner",
    "radins": "radin",
    "radiné": "radiner",
    "radinée": "radiner",
    "radio-taxis": "radio-taxi",
    "radioactifs": "radioactif",
    "radioactive": "radioactif",
    "radioactives": "radioactif",
    "radioactivités": "radioactivité",
    "radiocommunications": "radiocommunication",
    "radiodiffusa": "radiodiffuser",
    "radiodiffusai": "radiodiffuser",
    "radiodiffusaient": "radiodiffuser",
    "radiodiffusais": "radiodiffuser",
    "radiodiffusait": "radiodiffuser",
    "radiodiffusant": "radiodiffuser",
    "radiodiffusas": "radiodiffuser",
    "radiodiffusasse": "radiodiffuser",
    "radiodiffusassent": "radiodiffuser",
    "radiodiffusasses": "radiodiffuser",
    "radiodiffusassiez": "radiodiffuser",
    "radiodiffusassions": "radiodiffuser",
    "radiodiffuse": "radiodiffuser",
    "radiodiffusent": "radiodiffuser",
    "radiodiffusera": "radiodiffuser",
    "radiodiffuserai": "radiodiffuser",
    "radiodiffuseraient": "radiodiffuser",
    "radiodiffuserais": "radiodiffuser",
    "radiodiffuserait": "radiodiffuser",
    "radiodiffuseras": "radiodiffuser",
    "radiodiffuserez": "radiodiffuser",
    "radiodiffuseriez": "radiodiffuser",
    "radiodiffuserions": "radiodiffuser",
    "radiodiffuserons": "radiodiffuser",
    "radiodiffuseront": "radiodiffuser",
    "radiodiffuses": "radiodiffuser",
    "radiodiffuseurs": "radiodiffuseur",
    "radiodiffusez": "radiodiffuser",
    "radiodiffusiez": "radiodiffuser",
    "radiodiffusions": "radiodiffusion",
    "radiodiffusons": "radiodiffuser",
    "radiodiffusâmes": "radiodiffuser",
    "radiodiffusât": "radiodiffuser",
    "radiodiffusâtes": "radiodiffuser",
    "radiodiffusèrent": "radiodiffuser",
    "radiodiffusé": "radiodiffuser",
    "radiodiffusée": "radiodiffuser",
    "radiodiffusées": "radiodiffuser",
    "radiodiffusés": "radiodiffuser",
    "radiogrammes": "radiogramme",
    "radiographia": "radiographier",
    "radiographiai": "radiographier",
    "radiographiaient": "radiographier",
    "radiographiais": "radiographier",
    "radiographiait": "radiographier",
    "radiographiant": "radiographier",
    "radiographias": "radiographier",
    "radiographiasse": "radiographier",
    "radiographiassent": "radiographier",
    "radiographiasses": "radiographier",
    "radiographiassiez": "radiographier",
    "radiographiassions": "radiographier",
    "radiographie": "radiographier",
    "radiographient": "radiographier",
    "radiographiera": "radiographier",
    "radiographierai": "radiographier",
    "radiographieraient": "radiographier",
    "radiographierais": "radiographier",
    "radiographierait": "radiographier",
    "radiographieras": "radiographier",
    "radiographierez": "radiographier",
    "radiographieriez": "radiographier",
    "radiographierions": "radiographier",
    "radiographierons": "radiographier",
    "radiographieront": "radiographier",
    "radiographies": "radiographier",
    "radiographiez": "radiographier",
    "radiographiiez": "radiographier",
    "radiographiions": "radiographier",
    "radiographions": "radiographier",
    "radiographiâmes": "radiographier",
    "radiographiât": "radiographier",
    "radiographiâtes": "radiographier",
    "radiographièrent": "radiographier",
    "radiographié": "radiographier",
    "radiographiée": "radiographier",
    "radiographiées": "radiographier",
    "radiographiés": "radiographier",
    "radioguida": "radioguider",
    "radioguidai": "radioguider",
    "radioguidaient": "radioguider",
    "radioguidais": "radioguider",
    "radioguidait": "radioguider",
    "radioguidant": "radioguider",
    "radioguidas": "radioguider",
    "radioguidasse": "radioguider",
    "radioguidassent": "radioguider",
    "radioguidasses": "radioguider",
    "radioguidassiez": "radioguider",
    "radioguidassions": "radioguider",
    "radioguide": "radioguider",
    "radioguident": "radioguider",
    "radioguidera": "radioguider",
    "radioguiderai": "radioguider",
    "radioguideraient": "radioguider",
    "radioguiderais": "radioguider",
    "radioguiderait": "radioguider",
    "radioguideras": "radioguider",
    "radioguiderez": "radioguider",
    "radioguideriez": "radioguider",
    "radioguiderions": "radioguider",
    "radioguiderons": "radioguider",
    "radioguideront": "radioguider",
    "radioguides": "radioguider",
    "radioguidez": "radioguider",
    "radioguidiez": "radioguider",
    "radioguidions": "radioguider",
    "radioguidons": "radioguider",
    "radioguidâmes": "radioguider",
    "radioguidât": "radioguider",
    "radioguidâtes": "radioguider",
    "radioguidèrent": "radioguider",
    "radioguidé": "radioguider",
    "radioguidée": "radioguider",
    "radioguidées": "radioguider",
    "radioguidés": "radioguider",
    "radiologies": "radiologie",
    "radiologiques": "radiologique",
    "radiologues": "radiologue",
    "radiomètres": "radiomètre",
    "radions": "radier",
    "radionucléides": "radionucléide",
    "radiophonies": "radiophonie",
    "radiophoniques": "radiophonique",
    "radioprotections": "radioprotection",
    "radios": "radio",
    "radioscopies": "radioscopie",
    "radioscopiques": "radioscopique",
    "radiothérapies": "radiothérapie",
    "radiotoxiques": "radiotoxique",
    "radiotélescopes": "radiotélescope",
    "radiotélégraphia": "radiotélégraphier",
    "radiotélégraphiai": "radiotélégraphier",
    "radiotélégraphiaient": "radiotélégraphier",
    "radiotélégraphiais": "radiotélégraphier",
    "radiotélégraphiait": "radiotélégraphier",
    "radiotélégraphiant": "radiotélégraphier",
    "radiotélégraphias": "radiotélégraphier",
    "radiotélégraphiasse": "radiotélégraphier",
    "radiotélégraphiassent": "radiotélégraphier",
    "radiotélégraphiasses": "radiotélégraphier",
    "radiotélégraphiassiez": "radiotélégraphier",
    "radiotélégraphiassions": "radiotélégraphier",
    "radiotélégraphie": "radiotélégraphier",
    "radiotélégraphient": "radiotélégraphier",
    "radiotélégraphiera": "radiotélégraphier",
    "radiotélégraphierai": "radiotélégraphier",
    "radiotélégraphieraient": "radiotélégraphier",
    "radiotélégraphierais": "radiotélégraphier",
    "radiotélégraphierait": "radiotélégraphier",
    "radiotélégraphieras": "radiotélégraphier",
    "radiotélégraphierez": "radiotélégraphier",
    "radiotélégraphieriez": "radiotélégraphier",
    "radiotélégraphierions": "radiotélégraphier",
    "radiotélégraphierons": "radiotélégraphier",
    "radiotélégraphieront": "radiotélégraphier",
    "radiotélégraphies": "radiotélégraphier",
    "radiotélégraphiez": "radiotélégraphier",
    "radiotélégraphiiez": "radiotélégraphier",
    "radiotélégraphiions": "radiotélégraphier",
    "radiotélégraphions": "radiotélégraphier",
    "radiotélégraphiâmes": "radiotélégraphier",
    "radiotélégraphiât": "radiotélégraphier",
    "radiotélégraphiâtes": "radiotélégraphier",
    "radiotélégraphièrent": "radiotélégraphier",
    "radiotélégraphié": "radiotélégraphier",
    "radiotélégraphiée": "radiotélégraphier",
    "radiotélégraphiées": "radiotélégraphier",
    "radiotélégraphiés": "radiotélégraphier",
    "radiotéléphones": "radiotéléphone",
    "radiotéléphoniques": "radiotéléphonique",
    "radiotélévisions": "radiotélévision",
    "radiotélévisée": "radiotélévisé",
    "radiotélévisées": "radiotélévisé",
    "radiotélévisés": "radiotélévisé",
    "radioélectronicienne": "radioélectronicien",
    "radioélectroniciennes": "radioélectronicien",
    "radioélectroniciens": "radioélectronicien",
    "radiums": "radium",
    "radiâmes": "radier",
    "radiât": "radier",
    "radiâtes": "radier",
    "radièrent": "radier",
    "radié": "radier",
    "radiée": "radier",
    "radiées": "radier",
    "radiés": "radier",
    "radjahs": "radjah",
    "radons": "rader",
    "radota": "radoter",
    "radotages": "radotage",
    "radotai": "radoter",
    "radotaient": "radoter",
    "radotais": "radoter",
    "radotait": "radoter",
    "radotant": "radoter",
    "radotas": "radoter",
    "radotasse": "radoter",
    "radotassent": "radoter",
    "radotasses": "radoter",
    "radotassiez": "radoter",
    "radotassions": "radoter",
    "radote": "radoter",
    "radotent": "radoter",
    "radotera": "radoter",
    "radoterai": "radoter",
    "radoteraient": "radoter",
    "radoterais": "radoter",
    "radoterait": "radoter",
    "radoteras": "radoter",
    "radoterez": "radoter",
    "radoteriez": "radoter",
    "radoterions": "radoter",
    "radoterons": "radoter",
    "radoteront": "radoter",
    "radotes": "radoter",
    "radoteurs": "radoteur",
    "radoteuses": "radoteur",
    "radotez": "radoter",
    "radotiez": "radoter",
    "radotions": "radoter",
    "radotons": "radoter",
    "radotâmes": "radoter",
    "radotât": "radoter",
    "radotâtes": "radoter",
    "radotèrent": "radoter",
    "radoté": "radoter",
    "radoubait": "radouber",
    "radoubs": "radoub",
    "radouci": "radoucir",
    "radoucie": "radoucir",
    "radoucies": "radoucir",
    "radoucira": "radoucir",
    "radoucirai": "radoucir",
    "radouciraient": "radoucir",
    "radoucirais": "radoucir",
    "radoucirait": "radoucir",
    "radouciras": "radoucir",
    "radoucirent": "radoucir",
    "radoucirez": "radoucir",
    "radouciriez": "radoucir",
    "radoucirions": "radoucir",
    "radoucirons": "radoucir",
    "radouciront": "radoucir",
    "radoucis": "radoucir",
    "radoucissaient": "radoucir",
    "radoucissais": "radoucir",
    "radoucissait": "radoucir",
    "radoucissant": "radoucir",
    "radoucisse": "radoucir",
    "radoucissent": "radoucir",
    "radoucisses": "radoucir",
    "radoucissez": "radoucir",
    "radoucissiez": "radoucir",
    "radoucissions": "radoucir",
    "radoucissons": "radoucir",
    "radoucit": "radoucir",
    "radoucîmes": "radoucir",
    "radoucît": "radoucir",
    "radoucîtes": "radoucir",
    "rads": "rad",
    "radâmes": "rader",
    "radât": "rader",
    "radâtes": "rader",
    "radèrent": "rader",
    "radé": "rader",
    "radée": "rader",
    "radées": "rader",
    "radés": "rader",
    "rafa": "rafer",
    "rafales": "rafale",
    "rafe": "rafer",
    "raffermi": "raffermir",
    "raffermie": "raffermir",
    "raffermies": "raffermir",
    "raffermira": "raffermir",
    "raffermirai": "raffermir",
    "raffermiraient": "raffermir",
    "raffermirais": "raffermir",
    "raffermirait": "raffermir",
    "raffermiras": "raffermir",
    "raffermirent": "raffermir",
    "raffermirez": "raffermir",
    "raffermiriez": "raffermir",
    "raffermirions": "raffermir",
    "raffermirons": "raffermir",
    "raffermiront": "raffermir",
    "raffermis": "raffermir",
    "raffermissaient": "raffermir",
    "raffermissais": "raffermir",
    "raffermissait": "raffermir",
    "raffermissant": "raffermir",
    "raffermisse": "raffermir",
    "raffermissements": "raffermissement",
    "raffermissent": "raffermir",
    "raffermisses": "raffermir",
    "raffermissez": "raffermir",
    "raffermissiez": "raffermir",
    "raffermissions": "raffermir",
    "raffermissons": "raffermir",
    "raffermit": "raffermir",
    "raffermîmes": "raffermir",
    "raffermît": "raffermir",
    "raffermîtes": "raffermir",
    "raffina": "raffiner",
    "raffinages": "raffinage",
    "raffinai": "raffiner",
    "raffinaient": "raffiner",
    "raffinais": "raffiner",
    "raffinait": "raffiner",
    "raffinant": "raffiner",
    "raffinas": "raffiner",
    "raffinasse": "raffiner",
    "raffinassent": "raffiner",
    "raffinasses": "raffiner",
    "raffinassiez": "raffiner",
    "raffinassions": "raffiner",
    "raffine": "raffiner",
    "raffinements": "raffinement",
    "raffinent": "raffiner",
    "raffinera": "raffiner",
    "raffinerai": "raffiner",
    "raffineraient": "raffiner",
    "raffinerais": "raffiner",
    "raffinerait": "raffiner",
    "raffineras": "raffiner",
    "raffinerez": "raffiner",
    "raffineries": "raffinerie",
    "raffineriez": "raffiner",
    "raffinerions": "raffiner",
    "raffinerons": "raffiner",
    "raffineront": "raffiner",
    "raffines": "raffiner",
    "raffineurs": "raffineur",
    "raffineuse": "raffineur",
    "raffineuses": "raffineur",
    "raffinez": "raffiner",
    "raffiniez": "raffiner",
    "raffinions": "raffiner",
    "raffinons": "raffiner",
    "raffinâmes": "raffiner",
    "raffinât": "raffiner",
    "raffinâtes": "raffiner",
    "raffinèrent": "raffiner",
    "raffiné": "raffiner",
    "raffinée": "raffiner",
    "raffinées": "raffiner",
    "raffinés": "raffiner",
    "raffola": "raffoler",
    "raffolai": "raffoler",
    "raffolaient": "raffoler",
    "raffolais": "raffoler",
    "raffolait": "raffoler",
    "raffolant": "raffoler",
    "raffolas": "raffoler",
    "raffolasse": "raffoler",
    "raffolassent": "raffoler",
    "raffolasses": "raffoler",
    "raffolassiez": "raffoler",
    "raffolassions": "raffoler",
    "raffole": "raffoler",
    "raffolent": "raffoler",
    "raffolera": "raffoler",
    "raffolerai": "raffoler",
    "raffoleraient": "raffoler",
    "raffolerais": "raffoler",
    "raffolerait": "raffoler",
    "raffoleras": "raffoler",
    "raffolerez": "raffoler",
    "raffoleriez": "raffoler",
    "raffolerions": "raffoler",
    "raffolerons": "raffoler",
    "raffoleront": "raffoler",
    "raffoles": "raffoler",
    "raffolez": "raffoler",
    "raffoliez": "raffoler",
    "raffolions": "raffoler",
    "raffolons": "raffoler",
    "raffolâmes": "raffoler",
    "raffolât": "raffoler",
    "raffolâtes": "raffoler",
    "raffolèrent": "raffoler",
    "raffolé": "raffoler",
    "raffuts": "raffut",
    "raffûta": "raffûter",
    "raffûtai": "raffûter",
    "raffûtaient": "raffûter",
    "raffûtais": "raffûter",
    "raffûtait": "raffûter",
    "raffûtant": "raffûter",
    "raffûtas": "raffûter",
    "raffûtasse": "raffûter",
    "raffûtassent": "raffûter",
    "raffûtasses": "raffûter",
    "raffûtassiez": "raffûter",
    "raffûtassions": "raffûter",
    "raffûte": "raffûter",
    "raffûtent": "raffûter",
    "raffûtera": "raffûter",
    "raffûterai": "raffûter",
    "raffûteraient": "raffûter",
    "raffûterais": "raffûter",
    "raffûterait": "raffûter",
    "raffûteras": "raffûter",
    "raffûterez": "raffûter",
    "raffûteriez": "raffûter",
    "raffûterions": "raffûter",
    "raffûterons": "raffûter",
    "raffûteront": "raffûter",
    "raffûtes": "raffûter",
    "raffûtez": "raffûter",
    "raffûtiez": "raffûter",
    "raffûtions": "raffûter",
    "raffûtons": "raffûter",
    "raffûtâmes": "raffûter",
    "raffûtât": "raffûter",
    "raffûtâtes": "raffûter",
    "raffûtèrent": "raffûter",
    "raffûté": "raffûter",
    "raffûtée": "raffûter",
    "raffûtées": "raffûter",
    "raffûtés": "raffûter",
    "rafiots": "rafiot",
    "rafistola": "rafistoler",
    "rafistolages": "rafistolage",
    "rafistolai": "rafistoler",
    "rafistolaient": "rafistoler",
    "rafistolais": "rafistoler",
    "rafistolait": "rafistoler",
    "rafistolant": "rafistoler",
    "rafistolas": "rafistoler",
    "rafistolasse": "rafistoler",
    "rafistolassent": "rafistoler",
    "rafistolasses": "rafistoler",
    "rafistolassiez": "rafistoler",
    "rafistolassions": "rafistoler",
    "rafistole": "rafistoler",
    "rafistolent": "rafistoler",
    "rafistolera": "rafistoler",
    "rafistolerai": "rafistoler",
    "rafistoleraient": "rafistoler",
    "rafistolerais": "rafistoler",
    "rafistolerait": "rafistoler",
    "rafistoleras": "rafistoler",
    "rafistolerez": "rafistoler",
    "rafistoleriez": "rafistoler",
    "rafistolerions": "rafistoler",
    "rafistolerons": "rafistoler",
    "rafistoleront": "rafistoler",
    "rafistoles": "rafistoler",
    "rafistolez": "rafistoler",
    "rafistoliez": "rafistoler",
    "rafistolions": "rafistoler",
    "rafistolons": "rafistoler",
    "rafistolâmes": "rafistoler",
    "rafistolât": "rafistoler",
    "rafistolâtes": "rafistoler",
    "rafistolèrent": "rafistoler",
    "rafistolé": "rafistoler",
    "rafistolée": "rafistoler",
    "rafistolées": "rafistoler",
    "rafistolés": "rafistoler",
    "rafla": "rafler",
    "raflai": "rafler",
    "raflaient": "rafler",
    "raflais": "rafler",
    "raflait": "rafler",
    "raflant": "rafler",
    "raflas": "rafler",
    "raflasse": "rafler",
    "raflassent": "rafler",
    "raflasses": "rafler",
    "raflassiez": "rafler",
    "raflassions": "rafler",
    "rafle": "rafler",
    "raflent": "rafler",
    "raflera": "rafler",
    "raflerai": "rafler",
    "rafleraient": "rafler",
    "raflerais": "rafler",
    "raflerait": "rafler",
    "rafleras": "rafler",
    "raflerez": "rafler",
    "rafleriez": "rafler",
    "raflerions": "rafler",
    "raflerons": "rafler",
    "rafleront": "rafler",
    "rafles": "rafler",
    "raflez": "rafler",
    "rafliez": "rafler",
    "raflions": "rafler",
    "raflons": "rafler",
    "raflâmes": "rafler",
    "raflât": "rafler",
    "raflâtes": "rafler",
    "raflèrent": "rafler",
    "raflé": "rafler",
    "raflée": "rafler",
    "raflées": "rafler",
    "raflés": "rafler",
    "rafraîchi": "rafraîchir",
    "rafraîchie": "rafraîchir",
    "rafraîchies": "rafraîchir",
    "rafraîchira": "rafraîchir",
    "rafraîchirai": "rafraîchir",
    "rafraîchiraient": "rafraîchir",
    "rafraîchirais": "rafraîchir",
    "rafraîchirait": "rafraîchir",
    "rafraîchiras": "rafraîchir",
    "rafraîchirent": "rafraîchir",
    "rafraîchirez": "rafraîchir",
    "rafraîchiriez": "rafraîchir",
    "rafraîchirions": "rafraîchir",
    "rafraîchirons": "rafraîchir",
    "rafraîchiront": "rafraîchir",
    "rafraîchis": "rafraîchir",
    "rafraîchissaient": "rafraîchir",
    "rafraîchissais": "rafraîchir",
    "rafraîchissait": "rafraîchir",
    "rafraîchissant": "rafraîchir",
    "rafraîchissante": "rafraîchissant",
    "rafraîchissantes": "rafraîchissant",
    "rafraîchissants": "rafraîchissant",
    "rafraîchisse": "rafraîchir",
    "rafraîchissements": "rafraîchissement",
    "rafraîchissent": "rafraîchir",
    "rafraîchisses": "rafraîchir",
    "rafraîchissez": "rafraîchir",
    "rafraîchissiez": "rafraîchir",
    "rafraîchissions": "rafraîchir",
    "rafraîchissoirs": "rafraîchissoir",
    "rafraîchissons": "rafraîchir",
    "rafraîchit": "rafraîchir",
    "rafraîchîmes": "rafraîchir",
    "rafraîchît": "rafraîchir",
    "rafraîchîtes": "rafraîchir",
    "rag-times": "rag-time",
    "ragaillardi": "ragaillardir",
    "ragaillardie": "ragaillardir",
    "ragaillardies": "ragaillardir",
    "ragaillardira": "ragaillardir",
    "ragaillardirai": "ragaillardir",
    "ragaillardiraient": "ragaillardir",
    "ragaillardirais": "ragaillardir",
    "ragaillardirait": "ragaillardir",
    "ragaillardiras": "ragaillardir",
    "ragaillardirent": "ragaillardir",
    "ragaillardirez": "ragaillardir",
    "ragaillardiriez": "ragaillardir",
    "ragaillardirions": "ragaillardir",
    "ragaillardirons": "ragaillardir",
    "ragaillardiront": "ragaillardir",
    "ragaillardis": "ragaillardir",
    "ragaillardissaient": "ragaillardir",
    "ragaillardissais": "ragaillardir",
    "ragaillardissait": "ragaillardir",
    "ragaillardissant": "ragaillardir",
    "ragaillardisse": "ragaillardir",
    "ragaillardissent": "ragaillardir",
    "ragaillardisses": "ragaillardir",
    "ragaillardissez": "ragaillardir",
    "ragaillardissiez": "ragaillardir",
    "ragaillardissions": "ragaillardir",
    "ragaillardissons": "ragaillardir",
    "ragaillardit": "ragaillardir",
    "ragaillardîmes": "ragaillardir",
    "ragaillardît": "ragaillardir",
    "ragaillardîtes": "ragaillardir",
    "rage": "rager",
    "ragea": "rager",
    "rageai": "rager",
    "rageaient": "rager",
    "rageais": "rager",
    "rageait": "rager",
    "rageant": "rager",
    "rageas": "rager",
    "rageasse": "rager",
    "rageassent": "rager",
    "rageasses": "rager",
    "rageassiez": "rager",
    "rageassions": "rager",
    "ragent": "rager",
    "rageons": "rager",
    "ragera": "rager",
    "ragerai": "rager",
    "rageraient": "rager",
    "ragerais": "rager",
    "ragerait": "rager",
    "rageras": "rager",
    "ragerez": "rager",
    "rageriez": "rager",
    "ragerions": "rager",
    "ragerons": "rager",
    "rageront": "rager",
    "rages": "rager",
    "rageurs": "rageur",
    "rageuse": "rageur",
    "rageuses": "rageur",
    "ragez": "rager",
    "rageâmes": "rager",
    "rageât": "rager",
    "rageâtes": "rager",
    "ragiez": "rager",
    "ragions": "rager",
    "raglans": "raglan",
    "ragondins": "ragondin",
    "ragota": "ragoter",
    "ragotait": "ragoter",
    "ragote": "ragoter",
    "ragotes": "ragot",
    "ragots": "ragot",
    "ragougnasses": "ragougnasse",
    "ragoûtant": "ragoûter",
    "ragoûtante": "ragoûtant",
    "ragoûtantes": "ragoûtant",
    "ragoûtants": "ragoûtant",
    "ragoûts": "ragoût",
    "ragrafait": "ragrafer",
    "ragrafant": "ragrafer",
    "ragrafe": "ragrafer",
    "ragrandi": "ragrandir",
    "ragrandie": "ragrandir",
    "ragrandies": "ragrandir",
    "ragrandira": "ragrandir",
    "ragrandirai": "ragrandir",
    "ragrandiraient": "ragrandir",
    "ragrandirais": "ragrandir",
    "ragrandirait": "ragrandir",
    "ragrandiras": "ragrandir",
    "ragrandirent": "ragrandir",
    "ragrandirez": "ragrandir",
    "ragrandiriez": "ragrandir",
    "ragrandirions": "ragrandir",
    "ragrandirons": "ragrandir",
    "ragrandiront": "ragrandir",
    "ragrandis": "ragrandir",
    "ragrandissaient": "ragrandir",
    "ragrandissais": "ragrandir",
    "ragrandissait": "ragrandir",
    "ragrandissant": "ragrandir",
    "ragrandisse": "ragrandir",
    "ragrandissent": "ragrandir",
    "ragrandisses": "ragrandir",
    "ragrandissez": "ragrandir",
    "ragrandissiez": "ragrandir",
    "ragrandissions": "ragrandir",
    "ragrandissons": "ragrandir",
    "ragrandit": "ragrandir",
    "ragrandîmes": "ragrandir",
    "ragrandît": "ragrandir",
    "ragrandîtes": "ragrandir",
    "ragréa": "ragréer",
    "ragréai": "ragréer",
    "ragréaient": "ragréer",
    "ragréais": "ragréer",
    "ragréait": "ragréer",
    "ragréant": "ragréer",
    "ragréas": "ragréer",
    "ragréasse": "ragréer",
    "ragréassent": "ragréer",
    "ragréasses": "ragréer",
    "ragréassiez": "ragréer",
    "ragréassions": "ragréer",
    "ragrée": "ragréer",
    "ragréent": "ragréer",
    "ragréera": "ragréer",
    "ragréerai": "ragréer",
    "ragréeraient": "ragréer",
    "ragréerais": "ragréer",
    "ragréerait": "ragréer",
    "ragréeras": "ragréer",
    "ragréerez": "ragréer",
    "ragréeriez": "ragréer",
    "ragréerions": "ragréer",
    "ragréerons": "ragréer",
    "ragréeront": "ragréer",
    "ragrées": "ragréer",
    "ragréez": "ragréer",
    "ragréiez": "ragréer",
    "ragréions": "ragréer",
    "ragréons": "ragréer",
    "ragréâmes": "ragréer",
    "ragréât": "ragréer",
    "ragréâtes": "ragréer",
    "ragréèrent": "ragréer",
    "ragréé": "ragréer",
    "ragréée": "ragréer",
    "ragréées": "ragréer",
    "ragréés": "ragréer",
    "ragtimes": "ragtime",
    "ragèrent": "rager",
    "ragé": "rager",
    "ragée": "rager",
    "ragées": "rager",
    "ragés": "rager",
    "rahat-lokoums": "rahat-lokoum",
    "rahat-loukoums": "rahat-loukoum",
    "raiders": "raider",
    "raides": "raide",
    "raideurs": "raideur",
    "raidi": "raidir",
    "raidie": "raidir",
    "raidies": "raidir",
    "raidillons": "raidillon",
    "raidira": "raidir",
    "raidirai": "raidir",
    "raidiraient": "raidir",
    "raidirais": "raidir",
    "raidirait": "raidir",
    "raidiras": "raidir",
    "raidirent": "raidir",
    "raidirez": "raidir",
    "raidiriez": "raidir",
    "raidirions": "raidir",
    "raidirons": "raidir",
    "raidiront": "raidir",
    "raidis": "raidir",
    "raidissaient": "raidir",
    "raidissais": "raidir",
    "raidissait": "raidir",
    "raidissant": "raidir",
    "raidisse": "raidir",
    "raidissements": "raidissement",
    "raidissent": "raidir",
    "raidisses": "raidir",
    "raidissez": "raidir",
    "raidissiez": "raidir",
    "raidissions": "raidir",
    "raidissons": "raidir",
    "raidit": "raidir",
    "raids": "raid",
    "raidîmes": "raidir",
    "raidît": "raidir",
    "raidîtes": "raidir",
    "raie": "rayer",
    "raient": "rayer",
    "raiera": "rayer",
    "raierai": "rayer",
    "raieraient": "rayer",
    "raierais": "rayer",
    "raierait": "rayer",
    "raieras": "rayer",
    "raierez": "rayer",
    "raieriez": "rayer",
    "raierions": "rayer",
    "raierons": "rayer",
    "raieront": "rayer",
    "raies": "rayer",
    "raiforts": "raifort",
    "railla": "railler",
    "raillai": "railler",
    "raillaient": "railler",
    "raillais": "railler",
    "raillait": "railler",
    "raillant": "railler",
    "raillas": "railler",
    "raillasse": "railler",
    "raillassent": "railler",
    "raillasses": "railler",
    "raillassiez": "railler",
    "raillassions": "railler",
    "raille": "railler",
    "raillent": "railler",
    "raillera": "railler",
    "raillerai": "railler",
    "railleraient": "railler",
    "raillerais": "railler",
    "raillerait": "railler",
    "railleras": "railler",
    "raillerez": "railler",
    "railleries": "raillerie",
    "railleriez": "railler",
    "raillerions": "railler",
    "raillerons": "railler",
    "railleront": "railler",
    "railles": "railler",
    "railleurs": "railleur",
    "railleuse": "railleur",
    "railleuses": "railleur",
    "raillez": "railler",
    "railliez": "railler",
    "raillions": "railler",
    "raillons": "railler",
    "raillâmes": "railler",
    "raillât": "railler",
    "raillâtes": "railler",
    "raillèrent": "railler",
    "raillé": "railler",
    "raillée": "railler",
    "raillées": "railler",
    "raillés": "railler",
    "rails": "rail",
    "raina": "rainer",
    "rainai": "rainer",
    "rainaient": "rainer",
    "rainais": "rainer",
    "rainait": "rainer",
    "rainant": "rainer",
    "rainas": "rainer",
    "rainasse": "rainer",
    "rainassent": "rainer",
    "rainasses": "rainer",
    "rainassiez": "rainer",
    "rainassions": "rainer",
    "raine": "rainer",
    "rainent": "rainer",
    "rainera": "rainer",
    "rainerai": "rainer",
    "raineraient": "rainer",
    "rainerais": "rainer",
    "rainerait": "rainer",
    "raineras": "rainer",
    "rainerez": "rainer",
    "raineriez": "rainer",
    "rainerions": "rainer",
    "rainerons": "rainer",
    "raineront": "rainer",
    "raines": "rainer",
    "rainettes": "rainette",
    "rainez": "rainer",
    "rainiez": "rainer",
    "rainions": "rainer",
    "rainons": "rainer",
    "rainures": "rainure",
    "rainuré": "rainurer",
    "rainurés": "rainurer",
    "rainâmes": "rainer",
    "rainât": "rainer",
    "rainâtes": "rainer",
    "rainèrent": "rainer",
    "rainé": "rainer",
    "rainée": "rainer",
    "rainées": "rainer",
    "rainés": "rainer",
    "raiponces": "raiponce",
    "rais": "rai",
    "rais-de-coeurs": "rai-de-coeur",
    "raisinets": "raisinet",
    "raisins": "raisin",
    "raisonna": "raisonner",
    "raisonnables": "raisonnable",
    "raisonnai": "raisonner",
    "raisonnaient": "raisonner",
    "raisonnais": "raisonner",
    "raisonnait": "raisonner",
    "raisonnant": "raisonner",
    "raisonnante": "raisonnant",
    "raisonnas": "raisonner",
    "raisonnasse": "raisonner",
    "raisonnassent": "raisonner",
    "raisonnasses": "raisonner",
    "raisonnassiez": "raisonner",
    "raisonnassions": "raisonner",
    "raisonne": "raisonner",
    "raisonnements": "raisonnement",
    "raisonnent": "raisonner",
    "raisonnera": "raisonner",
    "raisonnerai": "raisonner",
    "raisonneraient": "raisonner",
    "raisonnerais": "raisonner",
    "raisonnerait": "raisonner",
    "raisonneras": "raisonner",
    "raisonnerez": "raisonner",
    "raisonneriez": "raisonner",
    "raisonnerions": "raisonner",
    "raisonnerons": "raisonner",
    "raisonneront": "raisonner",
    "raisonnes": "raisonner",
    "raisonneurs": "raisonneur",
    "raisonneuse": "raisonneur",
    "raisonnez": "raisonner",
    "raisonniez": "raisonner",
    "raisonnions": "raisonner",
    "raisonnons": "raisonner",
    "raisonnâmes": "raisonner",
    "raisonnât": "raisonner",
    "raisonnâtes": "raisonner",
    "raisonnèrent": "raisonner",
    "raisonné": "raisonner",
    "raisonnée": "raisonner",
    "raisonnées": "raisonner",
    "raisonnés": "raisonner",
    "raisons": "raison",
    "rait": "raire",
    "raites": "raire",
    "rajahs": "rajah",
    "rajeuni": "rajeunir",
    "rajeunie": "rajeunir",
    "rajeunies": "rajeunir",
    "rajeunira": "rajeunir",
    "rajeunirai": "rajeunir",
    "rajeuniraient": "rajeunir",
    "rajeunirais": "rajeunir",
    "rajeunirait": "rajeunir",
    "rajeuniras": "rajeunir",
    "rajeunirent": "rajeunir",
    "rajeunirez": "rajeunir",
    "rajeuniriez": "rajeunir",
    "rajeunirions": "rajeunir",
    "rajeunirons": "rajeunir",
    "rajeuniront": "rajeunir",
    "rajeunis": "rajeunir",
    "rajeunissaient": "rajeunir",
    "rajeunissais": "rajeunir",
    "rajeunissait": "rajeunir",
    "rajeunissant": "rajeunir",
    "rajeunissante": "rajeunissant",
    "rajeunisse": "rajeunir",
    "rajeunissements": "rajeunissement",
    "rajeunissent": "rajeunir",
    "rajeunisses": "rajeunir",
    "rajeunisseurs": "rajeunisseur",
    "rajeunissez": "rajeunir",
    "rajeunissiez": "rajeunir",
    "rajeunissions": "rajeunir",
    "rajeunissons": "rajeunir",
    "rajeunit": "rajeunir",
    "rajeunîmes": "rajeunir",
    "rajeunît": "rajeunir",
    "rajeunîtes": "rajeunir",
    "rajouta": "rajouter",
    "rajoutai": "rajouter",
    "rajoutaient": "rajouter",
    "rajoutais": "rajouter",
    "rajoutait": "rajouter",
    "rajoutant": "rajouter",
    "rajoutas": "rajouter",
    "rajoutasse": "rajouter",
    "rajoutassent": "rajouter",
    "rajoutasses": "rajouter",
    "rajoutassiez": "rajouter",
    "rajoutassions": "rajouter",
    "rajoute": "rajouter",
    "rajoutent": "rajouter",
    "rajoutera": "rajouter",
    "rajouterai": "rajouter",
    "rajouteraient": "rajouter",
    "rajouterais": "rajouter",
    "rajouterait": "rajouter",
    "rajouteras": "rajouter",
    "rajouterez": "rajouter",
    "rajouteriez": "rajouter",
    "rajouterions": "rajouter",
    "rajouterons": "rajouter",
    "rajouteront": "rajouter",
    "rajoutes": "rajouter",
    "rajoutez": "rajouter",
    "rajoutiez": "rajouter",
    "rajoutions": "rajouter",
    "rajoutons": "rajouter",
    "rajouts": "rajout",
    "rajoutâmes": "rajouter",
    "rajoutât": "rajouter",
    "rajoutâtes": "rajouter",
    "rajoutèrent": "rajouter",
    "rajouté": "rajouter",
    "rajoutée": "rajouter",
    "rajoutées": "rajouter",
    "rajoutés": "rajouter",
    "rajusta": "rajuster",
    "rajustai": "rajuster",
    "rajustaient": "rajuster",
    "rajustais": "rajuster",
    "rajustait": "rajuster",
    "rajustant": "rajuster",
    "rajustas": "rajuster",
    "rajustasse": "rajuster",
    "rajustassent": "rajuster",
    "rajustasses": "rajuster",
    "rajustassiez": "rajuster",
    "rajustassions": "rajuster",
    "rajuste": "rajuster",
    "rajustent": "rajuster",
    "rajustera": "rajuster",
    "rajusterai": "rajuster",
    "rajusteraient": "rajuster",
    "rajusterais": "rajuster",
    "rajusterait": "rajuster",
    "rajusteras": "rajuster",
    "rajusterez": "rajuster",
    "rajusteriez": "rajuster",
    "rajusterions": "rajuster",
    "rajusterons": "rajuster",
    "rajusteront": "rajuster",
    "rajustes": "rajuster",
    "rajustez": "rajuster",
    "rajustiez": "rajuster",
    "rajustions": "rajuster",
    "rajustons": "rajuster",
    "rajustâmes": "rajuster",
    "rajustât": "rajuster",
    "rajustâtes": "rajuster",
    "rajustèrent": "rajuster",
    "rajusté": "rajuster",
    "rajustée": "rajuster",
    "rajustées": "rajuster",
    "rajustés": "rajuster",
    "rakis": "raki",
    "ralenti": "ralentir",
    "ralentie": "ralentir",
    "ralenties": "ralentir",
    "ralentira": "ralentir",
    "ralentirai": "ralentir",
    "ralentiraient": "ralentir",
    "ralentirais": "ralentir",
    "ralentirait": "ralentir",
    "ralentiras": "ralentir",
    "ralentirent": "ralentir",
    "ralentirez": "ralentir",
    "ralentiriez": "ralentir",
    "ralentirions": "ralentir",
    "ralentirons": "ralentir",
    "ralentiront": "ralentir",
    "ralentis": "ralentir",
    "ralentissaient": "ralentir",
    "ralentissais": "ralentir",
    "ralentissait": "ralentir",
    "ralentissant": "ralentir",
    "ralentisse": "ralentir",
    "ralentissements": "ralentissement",
    "ralentissent": "ralentir",
    "ralentisses": "ralentir",
    "ralentisseurs": "ralentisseur",
    "ralentissez": "ralentir",
    "ralentissiez": "ralentir",
    "ralentissions": "ralentir",
    "ralentissons": "ralentir",
    "ralentit": "ralentir",
    "ralentîmes": "ralentir",
    "ralentît": "ralentir",
    "ralentîtes": "ralentir",
    "ralingues": "ralingue",
    "rallia": "rallier",
    "ralliai": "rallier",
    "ralliaient": "rallier",
    "ralliais": "rallier",
    "ralliait": "rallier",
    "ralliant": "rallier",
    "rallias": "rallier",
    "ralliasse": "rallier",
    "ralliassent": "rallier",
    "ralliasses": "rallier",
    "ralliassiez": "rallier",
    "ralliassions": "rallier",
    "rallie": "rallier",
    "ralliements": "ralliement",
    "rallient": "rallier",
    "ralliera": "rallier",
    "rallierai": "rallier",
    "rallieraient": "rallier",
    "rallierais": "rallier",
    "rallierait": "rallier",
    "rallieras": "rallier",
    "rallierez": "rallier",
    "rallieriez": "rallier",
    "rallierions": "rallier",
    "rallierons": "rallier",
    "rallieront": "rallier",
    "rallies": "rallier",
    "ralliez": "rallier",
    "ralliiez": "rallier",
    "ralliions": "rallier",
    "rallions": "rallier",
    "ralliâmes": "rallier",
    "ralliât": "rallier",
    "ralliâtes": "rallier",
    "rallièrent": "rallier",
    "rallié": "rallier",
    "ralliée": "rallier",
    "ralliées": "rallier",
    "ralliés": "rallier",
    "rallonge": "rallonger",
    "rallongea": "rallonger",
    "rallongeai": "rallonger",
    "rallongeaient": "rallonger",
    "rallongeais": "rallonger",
    "rallongeait": "rallonger",
    "rallongeant": "rallonger",
    "rallongeas": "rallonger",
    "rallongeasse": "rallonger",
    "rallongeassent": "rallonger",
    "rallongeasses": "rallonger",
    "rallongeassiez": "rallonger",
    "rallongeassions": "rallonger",
    "rallongements": "rallongement",
    "rallongent": "rallonger",
    "rallongeons": "rallonger",
    "rallongera": "rallonger",
    "rallongerai": "rallonger",
    "rallongeraient": "rallonger",
    "rallongerais": "rallonger",
    "rallongerait": "rallonger",
    "rallongeras": "rallonger",
    "rallongerez": "rallonger",
    "rallongeriez": "rallonger",
    "rallongerions": "rallonger",
    "rallongerons": "rallonger",
    "rallongeront": "rallonger",
    "rallonges": "rallonger",
    "rallongez": "rallonger",
    "rallongeâmes": "rallonger",
    "rallongeât": "rallonger",
    "rallongeâtes": "rallonger",
    "rallongiez": "rallonger",
    "rallongions": "rallonger",
    "rallongèrent": "rallonger",
    "rallongé": "rallonger",
    "rallongée": "rallonger",
    "rallongées": "rallonger",
    "rallongés": "rallonger",
    "ralluma": "rallumer",
    "rallumages": "rallumage",
    "rallumai": "rallumer",
    "rallumaient": "rallumer",
    "rallumais": "rallumer",
    "rallumait": "rallumer",
    "rallumant": "rallumer",
    "rallumas": "rallumer",
    "rallumasse": "rallumer",
    "rallumassent": "rallumer",
    "rallumasses": "rallumer",
    "rallumassiez": "rallumer",
    "rallumassions": "rallumer",
    "rallume": "rallumer",
    "rallument": "rallumer",
    "rallumera": "rallumer",
    "rallumerai": "rallumer",
    "rallumeraient": "rallumer",
    "rallumerais": "rallumer",
    "rallumerait": "rallumer",
    "rallumeras": "rallumer",
    "rallumerez": "rallumer",
    "rallumeriez": "rallumer",
    "rallumerions": "rallumer",
    "rallumerons": "rallumer",
    "rallumeront": "rallumer",
    "rallumes": "rallumer",
    "rallumez": "rallumer",
    "rallumiez": "rallumer",
    "rallumions": "rallumer",
    "rallumons": "rallumer",
    "rallumâmes": "rallumer",
    "rallumât": "rallumer",
    "rallumâtes": "rallumer",
    "rallumèrent": "rallumer",
    "rallumé": "rallumer",
    "rallumée": "rallumer",
    "rallumées": "rallumer",
    "rallumés": "rallumer",
    "rallyes": "rallye",
    "rallège": "ralléger",
    "rallégé": "ralléger",
    "rama": "ramer",
    "ramadans": "ramadan",
    "ramageait": "ramager",
    "ramages": "ramage",
    "ramai": "ramer",
    "ramaient": "ramer",
    "ramais": "ramer",
    "ramait": "ramer",
    "ramant": "ramer",
    "ramarraient": "ramarrer",
    "ramas": "ramer",
    "ramassa": "ramasser",
    "ramassages": "ramassage",
    "ramassai": "ramasser",
    "ramassaient": "ramasser",
    "ramassais": "ramasser",
    "ramassait": "ramasser",
    "ramassant": "ramasser",
    "ramassas": "ramasser",
    "ramassasse": "ramasser",
    "ramassassent": "ramasser",
    "ramassasses": "ramasser",
    "ramassassiez": "ramasser",
    "ramassassions": "ramasser",
    "ramasse": "ramer",
    "ramassent": "ramer",
    "ramassera": "ramasser",
    "ramasserai": "ramasser",
    "ramasseraient": "ramasser",
    "ramasserais": "ramasser",
    "ramasserait": "ramasser",
    "ramasseras": "ramasser",
    "ramasserez": "ramasser",
    "ramasseriez": "ramasser",
    "ramasserions": "ramasser",
    "ramasserons": "ramasser",
    "ramasseront": "ramasser",
    "ramasses": "ramer",
    "ramasseurs": "ramasseur",
    "ramasseuse": "ramasseur",
    "ramassez": "ramasser",
    "ramassiez": "ramer",
    "ramassions": "ramer",
    "ramassis": "ramassi",
    "ramassons": "ramasser",
    "ramassâmes": "ramasser",
    "ramassât": "ramasser",
    "ramassâtes": "ramasser",
    "ramassèrent": "ramasser",
    "ramassé": "ramasser",
    "ramassée": "ramasser",
    "ramassées": "ramasser",
    "ramassés": "ramasser",
    "rambardes": "rambarde",
    "rambinait": "rambiner",
    "rambine": "rambiner",
    "rambinent": "rambiner",
    "rambiné": "rambiner",
    "ramdams": "ramdam",
    "rame": "ramer",
    "rameaux": "rameau",
    "ramena": "ramener",
    "ramenai": "ramener",
    "ramenaient": "ramener",
    "ramenais": "ramener",
    "ramenait": "ramener",
    "ramenant": "ramener",
    "ramenards": "ramenard",
    "ramenas": "ramener",
    "ramenasse": "ramener",
    "ramenassent": "ramener",
    "ramenasses": "ramener",
    "ramenassiez": "ramener",
    "ramenassions": "ramener",
    "ramendé": "ramender",
    "ramenez": "ramener",
    "rameniez": "ramener",
    "ramenions": "ramener",
    "ramenons": "ramener",
    "rament": "ramer",
    "ramenâmes": "ramener",
    "ramenât": "ramener",
    "ramenâtes": "ramener",
    "ramenèrent": "ramener",
    "ramené": "ramener",
    "ramenée": "ramener",
    "ramenées": "ramener",
    "ramenés": "ramener",
    "ramequins": "ramequin",
    "ramera": "ramer",
    "ramerai": "ramer",
    "rameraient": "ramer",
    "ramerais": "ramer",
    "ramerait": "ramer",
    "rameras": "ramer",
    "ramerez": "ramer",
    "rameriez": "ramer",
    "ramerions": "ramer",
    "ramerons": "ramer",
    "rameront": "ramer",
    "rames": "ramer",
    "rameurs": "rameur",
    "rameuse": "rameux",
    "rameuses": "rameux",
    "rameuta": "rameuter",
    "rameutai": "rameuter",
    "rameutaient": "rameuter",
    "rameutais": "rameuter",
    "rameutait": "rameuter",
    "rameutant": "rameuter",
    "rameutas": "rameuter",
    "rameutasse": "rameuter",
    "rameutassent": "rameuter",
    "rameutasses": "rameuter",
    "rameutassiez": "rameuter",
    "rameutassions": "rameuter",
    "rameute": "rameuter",
    "rameutent": "rameuter",
    "rameutera": "rameuter",
    "rameuterai": "rameuter",
    "rameuteraient": "rameuter",
    "rameuterais": "rameuter",
    "rameuterait": "rameuter",
    "rameuteras": "rameuter",
    "rameuterez": "rameuter",
    "rameuteriez": "rameuter",
    "rameuterions": "rameuter",
    "rameuterons": "rameuter",
    "rameuteront": "rameuter",
    "rameutes": "rameuter",
    "rameutez": "rameuter",
    "rameutiez": "rameuter",
    "rameutions": "rameuter",
    "rameutons": "rameuter",
    "rameutâmes": "rameuter",
    "rameutât": "rameuter",
    "rameutâtes": "rameuter",
    "rameutèrent": "rameuter",
    "rameuté": "rameuter",
    "rameutée": "rameuter",
    "rameutées": "rameuter",
    "rameutés": "rameuter",
    "ramez": "ramer",
    "ramiers": "ramier",
    "ramies": "ramie",
    "ramiez": "ramer",
    "ramifia": "ramifier",
    "ramifiai": "ramifier",
    "ramifiaient": "ramifier",
    "ramifiais": "ramifier",
    "ramifiait": "ramifier",
    "ramifiant": "ramifier",
    "ramifias": "ramifier",
    "ramifiasse": "ramifier",
    "ramifiassent": "ramifier",
    "ramifiasses": "ramifier",
    "ramifiassiez": "ramifier",
    "ramifiassions": "ramifier",
    "ramifications": "ramification",
    "ramifie": "ramifier",
    "ramifient": "ramifier",
    "ramifiera": "ramifier",
    "ramifierai": "ramifier",
    "ramifieraient": "ramifier",
    "ramifierais": "ramifier",
    "ramifierait": "ramifier",
    "ramifieras": "ramifier",
    "ramifierez": "ramifier",
    "ramifieriez": "ramifier",
    "ramifierions": "ramifier",
    "ramifierons": "ramifier",
    "ramifieront": "ramifier",
    "ramifies": "ramifier",
    "ramifiez": "ramifier",
    "ramifiiez": "ramifier",
    "ramifiions": "ramifier",
    "ramifions": "ramifier",
    "ramifiâmes": "ramifier",
    "ramifiât": "ramifier",
    "ramifiâtes": "ramifier",
    "ramifièrent": "ramifier",
    "ramifié": "ramifier",
    "ramifiée": "ramifier",
    "ramifiées": "ramifier",
    "ramifiés": "ramifier",
    "ramilles": "ramille",
    "ramions": "ramer",
    "ramis": "rami",
    "ramolli": "ramollir",
    "ramollie": "ramollir",
    "ramollies": "ramollir",
    "ramollira": "ramollir",
    "ramollirai": "ramollir",
    "ramolliraient": "ramollir",
    "ramollirais": "ramollir",
    "ramollirait": "ramollir",
    "ramolliras": "ramollir",
    "ramollirent": "ramollir",
    "ramollirez": "ramollir",
    "ramolliriez": "ramollir",
    "ramollirions": "ramollir",
    "ramollirons": "ramollir",
    "ramolliront": "ramollir",
    "ramollis": "ramollir",
    "ramollissaient": "ramollir",
    "ramollissais": "ramollir",
    "ramollissait": "ramollir",
    "ramollissant": "ramollir",
    "ramollisse": "ramollir",
    "ramollissent": "ramollir",
    "ramollisses": "ramollir",
    "ramollissez": "ramollir",
    "ramollissiez": "ramollir",
    "ramollissions": "ramollir",
    "ramollissons": "ramollir",
    "ramollit": "ramollir",
    "ramollos": "ramollo",
    "ramollîmes": "ramollir",
    "ramollît": "ramollir",
    "ramollîtes": "ramollir",
    "ramona": "ramoner",
    "ramonages": "ramonage",
    "ramonai": "ramoner",
    "ramonaient": "ramoner",
    "ramonais": "ramoner",
    "ramonait": "ramoner",
    "ramonant": "ramoner",
    "ramonas": "ramoner",
    "ramonasse": "ramoner",
    "ramonassent": "ramoner",
    "ramonasses": "ramoner",
    "ramonassiez": "ramoner",
    "ramonassions": "ramoner",
    "ramone": "ramoner",
    "ramonent": "ramoner",
    "ramonera": "ramoner",
    "ramonerai": "ramoner",
    "ramoneraient": "ramoner",
    "ramonerais": "ramoner",
    "ramonerait": "ramoner",
    "ramoneras": "ramoner",
    "ramonerez": "ramoner",
    "ramoneriez": "ramoner",
    "ramonerions": "ramoner",
    "ramonerons": "ramoner",
    "ramoneront": "ramoner",
    "ramones": "ramoner",
    "ramoneurs": "ramoneur",
    "ramonez": "ramoner",
    "ramoniez": "ramoner",
    "ramonions": "ramoner",
    "ramonons": "ramoner",
    "ramons": "ramer",
    "ramonâmes": "ramoner",
    "ramonât": "ramoner",
    "ramonâtes": "ramoner",
    "ramonèrent": "ramoner",
    "ramoné": "ramoner",
    "ramonée": "ramoner",
    "ramonées": "ramoner",
    "ramonés": "ramoner",
    "rampa": "ramper",
    "rampai": "ramper",
    "rampaient": "ramper",
    "rampais": "ramper",
    "rampait": "ramper",
    "rampant": "ramper",
    "rampante": "rampant",
    "rampantes": "rampant",
    "rampants": "rampant",
    "rampas": "ramper",
    "rampasse": "ramper",
    "rampassent": "ramper",
    "rampasses": "ramper",
    "rampassiez": "ramper",
    "rampassions": "ramper",
    "rampe": "ramper",
    "rampements": "rampement",
    "rampent": "ramper",
    "rampera": "ramper",
    "ramperai": "ramper",
    "ramperaient": "ramper",
    "ramperais": "ramper",
    "ramperait": "ramper",
    "ramperas": "ramper",
    "ramperez": "ramper",
    "ramperiez": "ramper",
    "ramperions": "ramper",
    "ramperons": "ramper",
    "ramperont": "ramper",
    "rampes": "ramper",
    "rampez": "ramper",
    "rampiez": "ramper",
    "rampions": "ramper",
    "ramponneaux": "ramponneau",
    "rampons": "ramper",
    "rampâmes": "ramper",
    "rampât": "ramper",
    "rampâtes": "ramper",
    "rampèrent": "ramper",
    "rampé": "ramper",
    "rampée": "ramper",
    "ramures": "ramure",
    "ramâmes": "ramer",
    "ramât": "ramer",
    "ramâtes": "ramer",
    "ramène": "ramener",
    "ramènent": "ramener",
    "ramènera": "ramener",
    "ramènerai": "ramener",
    "ramèneraient": "ramener",
    "ramènerais": "ramener",
    "ramènerait": "ramener",
    "ramèneras": "ramener",
    "ramènerez": "ramener",
    "ramèneriez": "ramener",
    "ramènerions": "ramener",
    "ramènerons": "ramener",
    "ramèneront": "ramener",
    "ramènes": "ramener",
    "ramèrent": "ramer",
    "ramé": "ramer",
    "ramées": "ramer",
    "ramés": "ramer",
    "ranatres": "ranatre",
    "rancardait": "rancarder",
    "rancarde": "rancarder",
    "rancardez": "rancarder",
    "rancards": "rancard",
    "rancardé": "rancarder",
    "rancardée": "rancarder",
    "rancardés": "rancarder",
    "rancarts": "rancart",
    "rance": "rancer",
    "rances": "rance",
    "ranches": "ranche",
    "ranchs": "ranch",
    "ranci": "rancir",
    "rancie": "rancir",
    "rancies": "rancir",
    "rancira": "rancir",
    "rancirai": "rancir",
    "ranciraient": "rancir",
    "rancirais": "rancir",
    "rancirait": "rancir",
    "ranciras": "rancir",
    "rancirent": "rancir",
    "rancirez": "rancir",
    "ranciriez": "rancir",
    "rancirions": "rancir",
    "rancirons": "rancir",
    "ranciront": "rancir",
    "rancis": "rancir",
    "rancissaient": "rancir",
    "rancissais": "rancir",
    "rancissait": "rancir",
    "rancissant": "rancir",
    "rancisse": "rancir",
    "rancissent": "rancir",
    "rancisses": "rancir",
    "rancissez": "rancir",
    "rancissiez": "rancir",
    "rancissions": "rancir",
    "rancissons": "rancir",
    "rancit": "rancir",
    "rancoeurs": "rancoeur",
    "rancunes": "rancune",
    "rancuneuse": "rancuneux",
    "rancuneuses": "rancuneux",
    "rancuniers": "rancunier",
    "rancunière": "rancunier",
    "rancunières": "rancunier",
    "rancîmes": "rancir",
    "rancît": "rancir",
    "rancîtes": "rancir",
    "randonna": "randonner",
    "randonnai": "randonner",
    "randonnaient": "randonner",
    "randonnais": "randonner",
    "randonnait": "randonner",
    "randonnant": "randonner",
    "randonnas": "randonner",
    "randonnasse": "randonner",
    "randonnassent": "randonner",
    "randonnasses": "randonner",
    "randonnassiez": "randonner",
    "randonnassions": "randonner",
    "randonne": "randonner",
    "randonnent": "randonner",
    "randonnera": "randonner",
    "randonnerai": "randonner",
    "randonneraient": "randonner",
    "randonnerais": "randonner",
    "randonnerait": "randonner",
    "randonneras": "randonner",
    "randonnerez": "randonner",
    "randonneriez": "randonner",
    "randonnerions": "randonner",
    "randonnerons": "randonner",
    "randonneront": "randonner",
    "randonnes": "randonner",
    "randonneurs": "randonneur",
    "randonneuse": "randonneur",
    "randonnez": "randonner",
    "randonniez": "randonner",
    "randonnions": "randonner",
    "randonnons": "randonner",
    "randonnâmes": "randonner",
    "randonnât": "randonner",
    "randonnâtes": "randonner",
    "randonnèrent": "randonner",
    "randonné": "randonner",
    "randonnée": "randonner",
    "randonnées": "randonner",
    "randonnés": "randonner",
    "rands": "rand",
    "range": "ranger",
    "rangea": "ranger",
    "rangeai": "ranger",
    "rangeaient": "ranger",
    "rangeais": "ranger",
    "rangeait": "ranger",
    "rangeant": "ranger",
    "rangeas": "ranger",
    "rangeasse": "ranger",
    "rangeassent": "ranger",
    "rangeasses": "ranger",
    "rangeassiez": "ranger",
    "rangeassions": "ranger",
    "rangements": "rangement",
    "rangent": "ranger",
    "rangeons": "ranger",
    "rangera": "ranger",
    "rangerai": "ranger",
    "rangeraient": "ranger",
    "rangerais": "ranger",
    "rangerait": "ranger",
    "rangeras": "ranger",
    "rangerez": "ranger",
    "rangeriez": "ranger",
    "rangerions": "ranger",
    "rangerons": "ranger",
    "rangeront": "ranger",
    "rangers": "ranger",
    "ranges": "ranger",
    "rangez": "ranger",
    "rangeâmes": "ranger",
    "rangeât": "ranger",
    "rangeâtes": "ranger",
    "rangiez": "ranger",
    "rangions": "ranger",
    "rangs": "rang",
    "rangèrent": "ranger",
    "rangé": "ranger",
    "rangée": "ranger",
    "rangées": "ranger",
    "rangés": "ranger",
    "ranima": "ranimer",
    "ranimai": "ranimer",
    "ranimaient": "ranimer",
    "ranimais": "ranimer",
    "ranimait": "ranimer",
    "ranimant": "ranimer",
    "ranimas": "ranimer",
    "ranimasse": "ranimer",
    "ranimassent": "ranimer",
    "ranimasses": "ranimer",
    "ranimassiez": "ranimer",
    "ranimassions": "ranimer",
    "ranime": "ranimer",
    "raniment": "ranimer",
    "ranimera": "ranimer",
    "ranimerai": "ranimer",
    "ranimeraient": "ranimer",
    "ranimerais": "ranimer",
    "ranimerait": "ranimer",
    "ranimeras": "ranimer",
    "ranimerez": "ranimer",
    "ranimeriez": "ranimer",
    "ranimerions": "ranimer",
    "ranimerons": "ranimer",
    "ranimeront": "ranimer",
    "ranimes": "ranimer",
    "ranimez": "ranimer",
    "ranimiez": "ranimer",
    "ranimions": "ranimer",
    "ranimons": "ranimer",
    "ranimâmes": "ranimer",
    "ranimât": "ranimer",
    "ranimâtes": "ranimer",
    "ranimèrent": "ranimer",
    "ranimé": "ranimer",
    "ranimée": "ranimer",
    "ranimées": "ranimer",
    "ranimés": "ranimer",
    "rançonna": "rançonner",
    "rançonnai": "rançonner",
    "rançonnaient": "rançonner",
    "rançonnais": "rançonner",
    "rançonnait": "rançonner",
    "rançonnant": "rançonner",
    "rançonnas": "rançonner",
    "rançonnasse": "rançonner",
    "rançonnassent": "rançonner",
    "rançonnasses": "rançonner",
    "rançonnassiez": "rançonner",
    "rançonnassions": "rançonner",
    "rançonne": "rançonner",
    "rançonnent": "rançonner",
    "rançonnera": "rançonner",
    "rançonnerai": "rançonner",
    "rançonneraient": "rançonner",
    "rançonnerais": "rançonner",
    "rançonnerait": "rançonner",
    "rançonneras": "rançonner",
    "rançonnerez": "rançonner",
    "rançonneriez": "rançonner",
    "rançonnerions": "rançonner",
    "rançonnerons": "rançonner",
    "rançonneront": "rançonner",
    "rançonnes": "rançonner",
    "rançonneurs": "rançonneur",
    "rançonnez": "rançonner",
    "rançonniez": "rançonner",
    "rançonnions": "rançonner",
    "rançonnons": "rançonner",
    "rançonnâmes": "rançonner",
    "rançonnât": "rançonner",
    "rançonnâtes": "rançonner",
    "rançonnèrent": "rançonner",
    "rançonné": "rançonner",
    "rançonnée": "rançonner",
    "rançonnées": "rançonner",
    "rançonnés": "rançonner",
    "rançons": "rançon",
    "raouts": "raout",
    "rapaces": "rapace",
    "rapatria": "rapatrier",
    "rapatriai": "rapatrier",
    "rapatriaient": "rapatrier",
    "rapatriais": "rapatrier",
    "rapatriait": "rapatrier",
    "rapatriant": "rapatrier",
    "rapatrias": "rapatrier",
    "rapatriasse": "rapatrier",
    "rapatriassent": "rapatrier",
    "rapatriasses": "rapatrier",
    "rapatriassiez": "rapatrier",
    "rapatriassions": "rapatrier",
    "rapatrie": "rapatrier",
    "rapatriements": "rapatriement",
    "rapatrient": "rapatrier",
    "rapatriera": "rapatrier",
    "rapatrierai": "rapatrier",
    "rapatrieraient": "rapatrier",
    "rapatrierais": "rapatrier",
    "rapatrierait": "rapatrier",
    "rapatrieras": "rapatrier",
    "rapatrierez": "rapatrier",
    "rapatrieriez": "rapatrier",
    "rapatrierions": "rapatrier",
    "rapatrierons": "rapatrier",
    "rapatrieront": "rapatrier",
    "rapatries": "rapatrier",
    "rapatriez": "rapatrier",
    "rapatriiez": "rapatrier",
    "rapatriions": "rapatrier",
    "rapatrions": "rapatrier",
    "rapatriâmes": "rapatrier",
    "rapatriât": "rapatrier",
    "rapatriâtes": "rapatrier",
    "rapatrièrent": "rapatrier",
    "rapatrié": "rapatrier",
    "rapatriée": "rapatrier",
    "rapatriées": "rapatrier",
    "rapatriés": "rapatrier",
    "rapetassa": "rapetasser",
    "rapetassages": "rapetassage",
    "rapetassai": "rapetasser",
    "rapetassaient": "rapetasser",
    "rapetassais": "rapetasser",
    "rapetassait": "rapetasser",
    "rapetassant": "rapetasser",
    "rapetassas": "rapetasser",
    "rapetassasse": "rapetasser",
    "rapetassassent": "rapetasser",
    "rapetassasses": "rapetasser",
    "rapetassassiez": "rapetasser",
    "rapetassassions": "rapetasser",
    "rapetasse": "rapetasser",
    "rapetassent": "rapetasser",
    "rapetassera": "rapetasser",
    "rapetasserai": "rapetasser",
    "rapetasseraient": "rapetasser",
    "rapetasserais": "rapetasser",
    "rapetasserait": "rapetasser",
    "rapetasseras": "rapetasser",
    "rapetasserez": "rapetasser",
    "rapetasseriez": "rapetasser",
    "rapetasserions": "rapetasser",
    "rapetasserons": "rapetasser",
    "rapetasseront": "rapetasser",
    "rapetasses": "rapetasser",
    "rapetassez": "rapetasser",
    "rapetassiez": "rapetasser",
    "rapetassions": "rapetasser",
    "rapetassons": "rapetasser",
    "rapetassâmes": "rapetasser",
    "rapetassât": "rapetasser",
    "rapetassâtes": "rapetasser",
    "rapetassèrent": "rapetasser",
    "rapetassé": "rapetasser",
    "rapetassée": "rapetasser",
    "rapetassées": "rapetasser",
    "rapetassés": "rapetasser",
    "rapetissa": "rapetisser",
    "rapetissai": "rapetisser",
    "rapetissaient": "rapetisser",
    "rapetissais": "rapetisser",
    "rapetissait": "rapetisser",
    "rapetissant": "rapetisser",
    "rapetissas": "rapetisser",
    "rapetissasse": "rapetisser",
    "rapetissassent": "rapetisser",
    "rapetissasses": "rapetisser",
    "rapetissassiez": "rapetisser",
    "rapetissassions": "rapetisser",
    "rapetisse": "rapetisser",
    "rapetissent": "rapetisser",
    "rapetissera": "rapetisser",
    "rapetisserai": "rapetisser",
    "rapetisseraient": "rapetisser",
    "rapetisserais": "rapetisser",
    "rapetisserait": "rapetisser",
    "rapetisseras": "rapetisser",
    "rapetisserez": "rapetisser",
    "rapetisseriez": "rapetisser",
    "rapetisserions": "rapetisser",
    "rapetisserons": "rapetisser",
    "rapetisseront": "rapetisser",
    "rapetisses": "rapetisser",
    "rapetissez": "rapetisser",
    "rapetissiez": "rapetisser",
    "rapetissions": "rapetisser",
    "rapetissons": "rapetisser",
    "rapetissâmes": "rapetisser",
    "rapetissât": "rapetisser",
    "rapetissâtes": "rapetisser",
    "rapetissèrent": "rapetisser",
    "rapetissé": "rapetisser",
    "rapetissée": "rapetisser",
    "rapetissées": "rapetisser",
    "rapetissés": "rapetisser",
    "raphias": "raphia",
    "rapiats": "rapiat",
    "rapides": "rapide",
    "rapidités": "rapidité",
    "rapinent": "rapiner",
    "rapines": "rapine",
    "rapins": "rapin",
    "rapinés": "rapiner",
    "rapièce": "rapiécer",
    "rapiècements": "rapiècement",
    "rapiècent": "rapiécer",
    "rapièces": "rapiécer",
    "rapières": "rapière",
    "rapiécera": "rapiécer",
    "rapiécerai": "rapiécer",
    "rapiéceraient": "rapiécer",
    "rapiécerais": "rapiécer",
    "rapiécerait": "rapiécer",
    "rapiéceras": "rapiécer",
    "rapiécerez": "rapiécer",
    "rapiéceriez": "rapiécer",
    "rapiécerions": "rapiécer",
    "rapiécerons": "rapiécer",
    "rapiéceront": "rapiécer",
    "rapiécez": "rapiécer",
    "rapiéciez": "rapiécer",
    "rapiécions": "rapiécer",
    "rapiécèrent": "rapiécer",
    "rapiécé": "rapiécer",
    "rapiécée": "rapiécer",
    "rapiécées": "rapiécer",
    "rapiécés": "rapiécer",
    "rapiéça": "rapiécer",
    "rapiéçages": "rapiéçage",
    "rapiéçai": "rapiécer",
    "rapiéçaient": "rapiécer",
    "rapiéçais": "rapiécer",
    "rapiéçait": "rapiécer",
    "rapiéçant": "rapiécer",
    "rapiéças": "rapiécer",
    "rapiéçasse": "rapiécer",
    "rapiéçassent": "rapiécer",
    "rapiéçasses": "rapiécer",
    "rapiéçassiez": "rapiécer",
    "rapiéçassions": "rapiécer",
    "rapiéçons": "rapiécer",
    "rapiéçâmes": "rapiécer",
    "rapiéçât": "rapiécer",
    "rapiéçâtes": "rapiécer",
    "raplati": "raplatir",
    "raplatie": "raplatir",
    "raplaties": "raplatir",
    "raplatira": "raplatir",
    "raplatirai": "raplatir",
    "raplatiraient": "raplatir",
    "raplatirais": "raplatir",
    "raplatirait": "raplatir",
    "raplatiras": "raplatir",
    "raplatirent": "raplatir",
    "raplatirez": "raplatir",
    "raplatiriez": "raplatir",
    "raplatirions": "raplatir",
    "raplatirons": "raplatir",
    "raplatiront": "raplatir",
    "raplatis": "raplatir",
    "raplatissaient": "raplatir",
    "raplatissais": "raplatir",
    "raplatissait": "raplatir",
    "raplatissant": "raplatir",
    "raplatisse": "raplatir",
    "raplatissent": "raplatir",
    "raplatisses": "raplatir",
    "raplatissez": "raplatir",
    "raplatissiez": "raplatir",
    "raplatissions": "raplatir",
    "raplatissons": "raplatir",
    "raplatit": "raplatir",
    "raplatîmes": "raplatir",
    "raplatît": "raplatir",
    "raplatîtes": "raplatir",
    "rapointi": "rapointir",
    "rapointie": "rapointir",
    "rapointies": "rapointir",
    "rapointira": "rapointir",
    "rapointirai": "rapointir",
    "rapointiraient": "rapointir",
    "rapointirais": "rapointir",
    "rapointirait": "rapointir",
    "rapointiras": "rapointir",
    "rapointirent": "rapointir",
    "rapointirez": "rapointir",
    "rapointiriez": "rapointir",
    "rapointirions": "rapointir",
    "rapointirons": "rapointir",
    "rapointiront": "rapointir",
    "rapointis": "rapointir",
    "rapointissaient": "rapointir",
    "rapointissais": "rapointir",
    "rapointissait": "rapointir",
    "rapointissant": "rapointir",
    "rapointisse": "rapointir",
    "rapointissent": "rapointir",
    "rapointisses": "rapointir",
    "rapointissez": "rapointir",
    "rapointissiez": "rapointir",
    "rapointissions": "rapointir",
    "rapointissons": "rapointir",
    "rapointit": "rapointir",
    "rapointîmes": "rapointir",
    "rapointît": "rapointir",
    "rapointîtes": "rapointir",
    "rappareilla": "rappareiller",
    "rappareillai": "rappareiller",
    "rappareillaient": "rappareiller",
    "rappareillais": "rappareiller",
    "rappareillait": "rappareiller",
    "rappareillant": "rappareiller",
    "rappareillas": "rappareiller",
    "rappareillasse": "rappareiller",
    "rappareillassent": "rappareiller",
    "rappareillasses": "rappareiller",
    "rappareillassiez": "rappareiller",
    "rappareillassions": "rappareiller",
    "rappareille": "rappareiller",
    "rappareillent": "rappareiller",
    "rappareillera": "rappareiller",
    "rappareillerai": "rappareiller",
    "rappareilleraient": "rappareiller",
    "rappareillerais": "rappareiller",
    "rappareillerait": "rappareiller",
    "rappareilleras": "rappareiller",
    "rappareillerez": "rappareiller",
    "rappareilleriez": "rappareiller",
    "rappareillerions": "rappareiller",
    "rappareillerons": "rappareiller",
    "rappareilleront": "rappareiller",
    "rappareilles": "rappareiller",
    "rappareillez": "rappareiller",
    "rappareilliez": "rappareiller",
    "rappareillions": "rappareiller",
    "rappareillons": "rappareiller",
    "rappareillâmes": "rappareiller",
    "rappareillât": "rappareiller",
    "rappareillâtes": "rappareiller",
    "rappareillèrent": "rappareiller",
    "rappareillé": "rappareiller",
    "rappareillée": "rappareiller",
    "rappareillées": "rappareiller",
    "rappareillés": "rappareiller",
    "rapparia": "rapparier",
    "rappariai": "rapparier",
    "rappariaient": "rapparier",
    "rappariais": "rapparier",
    "rappariait": "rapparier",
    "rappariant": "rapparier",
    "rapparias": "rapparier",
    "rappariasse": "rapparier",
    "rappariassent": "rapparier",
    "rappariasses": "rapparier",
    "rappariassiez": "rapparier",
    "rappariassions": "rapparier",
    "rapparie": "rapparier",
    "rapparient": "rapparier",
    "rappariera": "rapparier",
    "rapparierai": "rapparier",
    "rapparieraient": "rapparier",
    "rapparierais": "rapparier",
    "rapparierait": "rapparier",
    "rapparieras": "rapparier",
    "rapparierez": "rapparier",
    "rapparieriez": "rapparier",
    "rapparierions": "rapparier",
    "rapparierons": "rapparier",
    "rapparieront": "rapparier",
    "rapparies": "rapparier",
    "rappariez": "rapparier",
    "rappariiez": "rapparier",
    "rappariions": "rapparier",
    "rapparions": "rapparier",
    "rappariâmes": "rapparier",
    "rappariât": "rapparier",
    "rappariâtes": "rapparier",
    "rapparièrent": "rapparier",
    "rapparié": "rapparier",
    "rappariée": "rapparier",
    "rappariées": "rapparier",
    "rappariés": "rapparier",
    "rappela": "rappeler",
    "rappelai": "rappeler",
    "rappelaient": "rappeler",
    "rappelais": "rappeler",
    "rappelait": "rappeler",
    "rappelant": "rappeler",
    "rappelas": "rappeler",
    "rappelasse": "rappeler",
    "rappelassent": "rappeler",
    "rappelasses": "rappeler",
    "rappelassiez": "rappeler",
    "rappelassions": "rappeler",
    "rappelez": "rappeler",
    "rappeliez": "rappeler",
    "rappelions": "rappeler",
    "rappelle": "rappeler",
    "rappellent": "rappeler",
    "rappellera": "rappeler",
    "rappellerai": "rappeler",
    "rappelleraient": "rappeler",
    "rappellerais": "rappeler",
    "rappellerait": "rappeler",
    "rappelleras": "rappeler",
    "rappellerez": "rappeler",
    "rappelleriez": "rappeler",
    "rappellerions": "rappeler",
    "rappellerons": "rappeler",
    "rappelleront": "rappeler",
    "rappelles": "rappeler",
    "rappelons": "rappeler",
    "rappels": "rappel",
    "rappelâmes": "rappeler",
    "rappelât": "rappeler",
    "rappelâtes": "rappeler",
    "rappelèrent": "rappeler",
    "rappelé": "rappeler",
    "rappelée": "rappeler",
    "rappelées": "rappeler",
    "rappelés": "rappeler",
    "rappers": "rapper",
    "rappeurs": "rappeur",
    "rappeuse": "rappeur",
    "rappeuses": "rapper",
    "rappliqua": "rappliquer",
    "rappliquai": "rappliquer",
    "rappliquaient": "rappliquer",
    "rappliquais": "rappliquer",
    "rappliquait": "rappliquer",
    "rappliquant": "rappliquer",
    "rappliquas": "rappliquer",
    "rappliquasse": "rappliquer",
    "rappliquassent": "rappliquer",
    "rappliquasses": "rappliquer",
    "rappliquassiez": "rappliquer",
    "rappliquassions": "rappliquer",
    "rapplique": "rappliquer",
    "rappliquent": "rappliquer",
    "rappliquera": "rappliquer",
    "rappliquerai": "rappliquer",
    "rappliqueraient": "rappliquer",
    "rappliquerais": "rappliquer",
    "rappliquerait": "rappliquer",
    "rappliqueras": "rappliquer",
    "rappliquerez": "rappliquer",
    "rappliqueriez": "rappliquer",
    "rappliquerions": "rappliquer",
    "rappliquerons": "rappliquer",
    "rappliqueront": "rappliquer",
    "rappliques": "rappliquer",
    "rappliquez": "rappliquer",
    "rappliquiez": "rappliquer",
    "rappliquions": "rappliquer",
    "rappliquons": "rappliquer",
    "rappliquâmes": "rappliquer",
    "rappliquât": "rappliquer",
    "rappliquâtes": "rappliquer",
    "rappliquèrent": "rappliquer",
    "rappliqué": "rappliquer",
    "rapporta": "rapporter",
    "rapportai": "rapporter",
    "rapportaient": "rapporter",
    "rapportais": "rapporter",
    "rapportait": "rapporter",
    "rapportant": "rapporter",
    "rapportas": "rapporter",
    "rapportasse": "rapporter",
    "rapportassent": "rapporter",
    "rapportasses": "rapporter",
    "rapportassiez": "rapporter",
    "rapportassions": "rapporter",
    "rapporte": "rapporter",
    "rapportent": "rapporter",
    "rapportera": "rapporter",
    "rapporterai": "rapporter",
    "rapporteraient": "rapporter",
    "rapporterais": "rapporter",
    "rapporterait": "rapporter",
    "rapporteras": "rapporter",
    "rapporterez": "rapporter",
    "rapporteriez": "rapporter",
    "rapporterions": "rapporter",
    "rapporterons": "rapporter",
    "rapporteront": "rapporter",
    "rapportes": "rapporter",
    "rapporteurs": "rapporteur",
    "rapporteuse": "rapporteur",
    "rapporteuses": "rapporteur",
    "rapportez": "rapporter",
    "rapportiez": "rapporter",
    "rapportions": "rapporter",
    "rapportons": "rapporter",
    "rapports": "rapport",
    "rapportâmes": "rapporter",
    "rapportât": "rapporter",
    "rapportâtes": "rapporter",
    "rapportèrent": "rapporter",
    "rapporté": "rapporter",
    "rapportée": "rapporter",
    "rapportées": "rapporter",
    "rapportés": "rapporter",
    "rapprenaient": "rapprendre",
    "rapprenais": "rapprendre",
    "rapprenait": "rapprendre",
    "rapprenant": "rapprendre",
    "rapprend": "rapprendre",
    "rapprendra": "rapprendre",
    "rapprendrai": "rapprendre",
    "rapprendraient": "rapprendre",
    "rapprendrais": "rapprendre",
    "rapprendrait": "rapprendre",
    "rapprendras": "rapprendre",
    "rapprendrez": "rapprendre",
    "rapprendriez": "rapprendre",
    "rapprendrions": "rapprendre",
    "rapprendrons": "rapprendre",
    "rapprendront": "rapprendre",
    "rapprends": "rapprendre",
    "rapprenez": "rapprendre",
    "rappreniez": "rapprendre",
    "rapprenions": "rapprendre",
    "rapprenne": "rapprendre",
    "rapprennent": "rapprendre",
    "rapprennes": "rapprendre",
    "rapprenons": "rapprendre",
    "rapprirent": "rapprendre",
    "rappris": "rapprendre",
    "rapprise": "rapprendre",
    "rapprises": "rapprendre",
    "rapprisse": "rapprendre",
    "rapprissent": "rapprendre",
    "rapprisses": "rapprendre",
    "rapprissiez": "rapprendre",
    "rapprissions": "rapprendre",
    "rapprit": "rapprendre",
    "rapprocha": "rapprocher",
    "rapprochai": "rapprocher",
    "rapprochaient": "rapprocher",
    "rapprochais": "rapprocher",
    "rapprochait": "rapprocher",
    "rapprochant": "rapprocher",
    "rapprochas": "rapprocher",
    "rapprochasse": "rapprocher",
    "rapprochassent": "rapprocher",
    "rapprochasses": "rapprocher",
    "rapprochassiez": "rapprocher",
    "rapprochassions": "rapprocher",
    "rapproche": "rapprocher",
    "rapprochements": "rapprochement",
    "rapprochent": "rapprocher",
    "rapprochera": "rapprocher",
    "rapprocherai": "rapprocher",
    "rapprocheraient": "rapprocher",
    "rapprocherais": "rapprocher",
    "rapprocherait": "rapprocher",
    "rapprocheras": "rapprocher",
    "rapprocherez": "rapprocher",
    "rapprocheriez": "rapprocher",
    "rapprocherions": "rapprocher",
    "rapprocherons": "rapprocher",
    "rapprocheront": "rapprocher",
    "rapproches": "rapprocher",
    "rapprochez": "rapprocher",
    "rapprochiez": "rapprocher",
    "rapprochions": "rapprocher",
    "rapprochons": "rapprocher",
    "rapprochâmes": "rapprocher",
    "rapprochât": "rapprocher",
    "rapprochâtes": "rapprocher",
    "rapprochèrent": "rapprocher",
    "rapproché": "rapprocher",
    "rapprochée": "rapprocher",
    "rapprochées": "rapprocher",
    "rapprochés": "rapprocher",
    "rappropriait": "rapproprier",
    "rapprovisionna": "rapprovisionner",
    "rapprovisionnai": "rapprovisionner",
    "rapprovisionnaient": "rapprovisionner",
    "rapprovisionnais": "rapprovisionner",
    "rapprovisionnait": "rapprovisionner",
    "rapprovisionnant": "rapprovisionner",
    "rapprovisionnas": "rapprovisionner",
    "rapprovisionnasse": "rapprovisionner",
    "rapprovisionnassent": "rapprovisionner",
    "rapprovisionnasses": "rapprovisionner",
    "rapprovisionnassiez": "rapprovisionner",
    "rapprovisionnassions": "rapprovisionner",
    "rapprovisionne": "rapprovisionner",
    "rapprovisionnent": "rapprovisionner",
    "rapprovisionnera": "rapprovisionner",
    "rapprovisionnerai": "rapprovisionner",
    "rapprovisionneraient": "rapprovisionner",
    "rapprovisionnerais": "rapprovisionner",
    "rapprovisionnerait": "rapprovisionner",
    "rapprovisionneras": "rapprovisionner",
    "rapprovisionnerez": "rapprovisionner",
    "rapprovisionneriez": "rapprovisionner",
    "rapprovisionnerions": "rapprovisionner",
    "rapprovisionnerons": "rapprovisionner",
    "rapprovisionneront": "rapprovisionner",
    "rapprovisionnes": "rapprovisionner",
    "rapprovisionnez": "rapprovisionner",
    "rapprovisionniez": "rapprovisionner",
    "rapprovisionnions": "rapprovisionner",
    "rapprovisionnons": "rapprovisionner",
    "rapprovisionnâmes": "rapprovisionner",
    "rapprovisionnât": "rapprovisionner",
    "rapprovisionnâtes": "rapprovisionner",
    "rapprovisionnèrent": "rapprovisionner",
    "rapprovisionné": "rapprovisionner",
    "rapprovisionnée": "rapprovisionner",
    "rapprovisionnées": "rapprovisionner",
    "rapprovisionnés": "rapprovisionner",
    "rapprîmes": "rapprendre",
    "rapprît": "rapprendre",
    "rapprîtes": "rapprendre",
    "rapts": "rapt",
    "raquaient": "raquer",
    "raquait": "raquer",
    "raque": "raquer",
    "raquent": "raquer",
    "raques": "raquer",
    "raquettes": "raquette",
    "raquez": "raquer",
    "raquons": "raquer",
    "raqué": "raquer",
    "raquée": "raquer",
    "raquées": "raquer",
    "rares": "rare",
    "raretés": "rareté",
    "rarissimes": "rarissime",
    "raréfactions": "raréfaction",
    "raréfia": "raréfier",
    "raréfiai": "raréfier",
    "raréfiaient": "raréfier",
    "raréfiais": "raréfier",
    "raréfiait": "raréfier",
    "raréfiant": "raréfier",
    "raréfias": "raréfier",
    "raréfiasse": "raréfier",
    "raréfiassent": "raréfier",
    "raréfiasses": "raréfier",
    "raréfiassiez": "raréfier",
    "raréfiassions": "raréfier",
    "raréfie": "raréfier",
    "raréfient": "raréfier",
    "raréfiera": "raréfier",
    "raréfierai": "raréfier",
    "raréfieraient": "raréfier",
    "raréfierais": "raréfier",
    "raréfierait": "raréfier",
    "raréfieras": "raréfier",
    "raréfierez": "raréfier",
    "raréfieriez": "raréfier",
    "raréfierions": "raréfier",
    "raréfierons": "raréfier",
    "raréfieront": "raréfier",
    "raréfies": "raréfier",
    "raréfiez": "raréfier",
    "raréfiiez": "raréfier",
    "raréfiions": "raréfier",
    "raréfions": "raréfier",
    "raréfiâmes": "raréfier",
    "raréfiât": "raréfier",
    "raréfiâtes": "raréfier",
    "raréfièrent": "raréfier",
    "raréfié": "raréfier",
    "raréfiée": "raréfier",
    "raréfiées": "raréfier",
    "raréfiés": "raréfier",
    "rasa": "raser",
    "rasades": "rasade",
    "rasages": "rasage",
    "rasai": "raser",
    "rasaient": "raser",
    "rasais": "raser",
    "rasait": "raser",
    "rasant": "raser",
    "rasante": "rasant",
    "rasantes": "rasant",
    "rasants": "rasant",
    "rasas": "raser",
    "rasasse": "raser",
    "rasassent": "raser",
    "rasasses": "raser",
    "rasassiez": "raser",
    "rasassions": "raser",
    "rascasses": "rascasse",
    "rase": "raser",
    "rase-pets": "rase-pet",
    "rasent": "raser",
    "rasera": "raser",
    "raserai": "raser",
    "raseraient": "raser",
    "raserais": "raser",
    "raserait": "raser",
    "raseras": "raser",
    "raserez": "raser",
    "raseriez": "raser",
    "raserions": "raser",
    "raserons": "raser",
    "raseront": "raser",
    "rases": "raser",
    "raseurs": "raseur",
    "raseuse": "raseur",
    "raseuses": "raseur",
    "rasez": "raser",
    "rasiez": "raser",
    "rasifs": "rasif",
    "rasions": "raser",
    "rasoirs": "rasoir",
    "rasons": "raser",
    "rassasia": "rassasier",
    "rassasiai": "rassasier",
    "rassasiaient": "rassasier",
    "rassasiais": "rassasier",
    "rassasiait": "rassasier",
    "rassasiant": "rassasier",
    "rassasiantes": "rassasiant",
    "rassasias": "rassasier",
    "rassasiasse": "rassasier",
    "rassasiassent": "rassasier",
    "rassasiasses": "rassasier",
    "rassasiassiez": "rassasier",
    "rassasiassions": "rassasier",
    "rassasie": "rassasier",
    "rassasiements": "rassasiement",
    "rassasient": "rassasier",
    "rassasiera": "rassasier",
    "rassasierai": "rassasier",
    "rassasieraient": "rassasier",
    "rassasierais": "rassasier",
    "rassasierait": "rassasier",
    "rassasieras": "rassasier",
    "rassasierez": "rassasier",
    "rassasieriez": "rassasier",
    "rassasierions": "rassasier",
    "rassasierons": "rassasier",
    "rassasieront": "rassasier",
    "rassasies": "rassasier",
    "rassasiez": "rassasier",
    "rassasiiez": "rassasier",
    "rassasiions": "rassasier",
    "rassasions": "rassasier",
    "rassasiâmes": "rassasier",
    "rassasiât": "rassasier",
    "rassasiâtes": "rassasier",
    "rassasièrent": "rassasier",
    "rassasié": "rassasier",
    "rassasiée": "rassasier",
    "rassasiées": "rassasier",
    "rassasiés": "rassasier",
    "rassembla": "rassembler",
    "rassemblai": "rassembler",
    "rassemblaient": "rassembler",
    "rassemblais": "rassembler",
    "rassemblait": "rassembler",
    "rassemblant": "rassembler",
    "rassemblas": "rassembler",
    "rassemblasse": "rassembler",
    "rassemblassent": "rassembler",
    "rassemblasses": "rassembler",
    "rassemblassiez": "rassembler",
    "rassemblassions": "rassembler",
    "rassemble": "rassembler",
    "rassemblements": "rassemblement",
    "rassemblent": "rassembler",
    "rassemblera": "rassembler",
    "rassemblerai": "rassembler",
    "rassembleraient": "rassembler",
    "rassemblerais": "rassembler",
    "rassemblerait": "rassembler",
    "rassembleras": "rassembler",
    "rassemblerez": "rassembler",
    "rassembleriez": "rassembler",
    "rassemblerions": "rassembler",
    "rassemblerons": "rassembler",
    "rassembleront": "rassembler",
    "rassembles": "rassembler",
    "rassembleurs": "rassembleur",
    "rassemblez": "rassembler",
    "rassembliez": "rassembler",
    "rassemblions": "rassembler",
    "rassemblons": "rassembler",
    "rassemblâmes": "rassembler",
    "rassemblât": "rassembler",
    "rassemblâtes": "rassembler",
    "rassemblèrent": "rassembler",
    "rassemblé": "rassembler",
    "rassemblée": "rassembler",
    "rassemblées": "rassembler",
    "rassemblés": "rassembler",
    "rasseyaient": "rasseoir",
    "rasseyais": "rasseoir",
    "rasseyait": "rasseoir",
    "rasseyant": "rasseoir",
    "rasseye": "rasseoir",
    "rasseyent": "rasseoir",
    "rasseyes": "rasseoir",
    "rasseyez": "rasseoir",
    "rasseyiez": "rasseoir",
    "rasseyions": "rasseoir",
    "rasseyons": "rasseoir",
    "rassie": "rassi",
    "rassied": "rasseoir",
    "rassieds": "rasseoir",
    "rassies": "rassi",
    "rassirent": "rasseoir",
    "rassis": "rassir",
    "rassise": "rassis",
    "rassises": "rassis",
    "rassisse": "rasseoir",
    "rassissent": "rasseoir",
    "rassisses": "rasseoir",
    "rassissiez": "rasseoir",
    "rassissions": "rasseoir",
    "rassit": "rasseoir",
    "rassiéra": "rasseoir",
    "rassiérai": "rasseoir",
    "rassiéraient": "rasseoir",
    "rassiérais": "rasseoir",
    "rassiérait": "rasseoir",
    "rassiéras": "rasseoir",
    "rassiérez": "rasseoir",
    "rassiériez": "rasseoir",
    "rassiérions": "rasseoir",
    "rassiérons": "rasseoir",
    "rassiéront": "rasseoir",
    "rassoie": "rasseoir",
    "rassoient": "rasseoir",
    "rassoies": "rasseoir",
    "rassoira": "rasseoir",
    "rassoirai": "rasseoir",
    "rassoiraient": "rasseoir",
    "rassoirais": "rasseoir",
    "rassoirait": "rasseoir",
    "rassoiras": "rasseoir",
    "rassoirez": "rasseoir",
    "rassoiriez": "rasseoir",
    "rassoirions": "rasseoir",
    "rassoirons": "rasseoir",
    "rassoiront": "rasseoir",
    "rassois": "rasseoir",
    "rassoit": "rasseoir",
    "rassorti": "rassortir",
    "rassortie": "rassortir",
    "rassorties": "rassortir",
    "rassortiments": "rassortiment",
    "rassortira": "rassortir",
    "rassortirai": "rassortir",
    "rassortiraient": "rassortir",
    "rassortirais": "rassortir",
    "rassortirait": "rassortir",
    "rassortiras": "rassortir",
    "rassortirent": "rassortir",
    "rassortirez": "rassortir",
    "rassortiriez": "rassortir",
    "rassortirions": "rassortir",
    "rassortirons": "rassortir",
    "rassortiront": "rassortir",
    "rassortis": "rassortir",
    "rassortissaient": "rassortir",
    "rassortissais": "rassortir",
    "rassortissait": "rassortir",
    "rassortissant": "rassortir",
    "rassortisse": "rassortir",
    "rassortissent": "rassortir",
    "rassortisses": "rassortir",
    "rassortissez": "rassortir",
    "rassortissiez": "rassortir",
    "rassortissions": "rassortir",
    "rassortissons": "rassortir",
    "rassortit": "rassortir",
    "rassortîmes": "rassortir",
    "rassortît": "rassortir",
    "rassortîtes": "rassortir",
    "rassoté": "rassoter",
    "rassoyaient": "rasseoir",
    "rassoyais": "rasseoir",
    "rassoyait": "rasseoir",
    "rassoyant": "rasseoir",
    "rassoyez": "rasseoir",
    "rassoyiez": "rasseoir",
    "rassoyions": "rasseoir",
    "rassoyons": "rasseoir",
    "rassura": "rassurer",
    "rassurai": "rassurer",
    "rassuraient": "rassurer",
    "rassurais": "rassurer",
    "rassurait": "rassurer",
    "rassurant": "rassurer",
    "rassurante": "rassurant",
    "rassurantes": "rassurant",
    "rassurants": "rassurant",
    "rassuras": "rassurer",
    "rassurasse": "rassurer",
    "rassurassent": "rassurer",
    "rassurasses": "rassurer",
    "rassurassiez": "rassurer",
    "rassurassions": "rassurer",
    "rassure": "rassurer",
    "rassurent": "rassurer",
    "rassurera": "rassurer",
    "rassurerai": "rassurer",
    "rassureraient": "rassurer",
    "rassurerais": "rassurer",
    "rassurerait": "rassurer",
    "rassureras": "rassurer",
    "rassurerez": "rassurer",
    "rassureriez": "rassurer",
    "rassurerions": "rassurer",
    "rassurerons": "rassurer",
    "rassureront": "rassurer",
    "rassures": "rassurer",
    "rassurez": "rassurer",
    "rassuriez": "rassurer",
    "rassurions": "rassurer",
    "rassurons": "rassurer",
    "rassurâmes": "rassurer",
    "rassurât": "rassurer",
    "rassurâtes": "rassurer",
    "rassurèrent": "rassurer",
    "rassuré": "rassurer",
    "rassurée": "rassurer",
    "rassurées": "rassurer",
    "rassurés": "rassurer",
    "rassérène": "rasséréner",
    "rassérènent": "rasséréner",
    "rassérènes": "rasséréner",
    "rasséréna": "rasséréner",
    "rassérénai": "rasséréner",
    "rassérénaient": "rasséréner",
    "rassérénais": "rasséréner",
    "rassérénait": "rasséréner",
    "rassérénant": "rasséréner",
    "rassérénas": "rasséréner",
    "rassérénasse": "rasséréner",
    "rassérénassent": "rasséréner",
    "rassérénasses": "rasséréner",
    "rassérénassiez": "rasséréner",
    "rassérénassions": "rasséréner",
    "rassérénera": "rasséréner",
    "rassérénerai": "rasséréner",
    "rasséréneraient": "rasséréner",
    "rassérénerais": "rasséréner",
    "rassérénerait": "rasséréner",
    "rasséréneras": "rasséréner",
    "rassérénerez": "rasséréner",
    "rasséréneriez": "rasséréner",
    "rassérénerions": "rasséréner",
    "rassérénerons": "rasséréner",
    "rasséréneront": "rasséréner",
    "rassérénez": "rasséréner",
    "rasséréniez": "rasséréner",
    "rassérénions": "rasséréner",
    "rassérénons": "rasséréner",
    "rassérénâmes": "rasséréner",
    "rassérénât": "rasséréner",
    "rassérénâtes": "rasséréner",
    "rassérénèrent": "rasséréner",
    "rasséréné": "rasséréner",
    "rassérénée": "rasséréner",
    "rassérénées": "rasséréner",
    "rassérénés": "rasséréner",
    "rassîmes": "rasseoir",
    "rassît": "rasseoir",
    "rassîtes": "rasseoir",
    "rastaquouères": "rastaquouère",
    "rastas": "rasta",
    "rasâmes": "raser",
    "rasât": "raser",
    "rasâtes": "raser",
    "rasèrent": "raser",
    "rasé": "raser",
    "rasée": "raser",
    "rasées": "raser",
    "rasés": "raser",
    "rata": "rater",
    "ratafias": "ratafia",
    "ratages": "ratage",
    "ratai": "rater",
    "rataient": "rater",
    "ratais": "rater",
    "ratait": "rater",
    "ratant": "rater",
    "ratas": "rater",
    "ratasse": "rater",
    "ratassent": "rater",
    "ratasses": "rater",
    "ratassiez": "rater",
    "ratassions": "rater",
    "ratatina": "ratatiner",
    "ratatinai": "ratatiner",
    "ratatinaient": "ratatiner",
    "ratatinais": "ratatiner",
    "ratatinait": "ratatiner",
    "ratatinant": "ratatiner",
    "ratatinas": "ratatiner",
    "ratatinasse": "ratatiner",
    "ratatinassent": "ratatiner",
    "ratatinasses": "ratatiner",
    "ratatinassiez": "ratatiner",
    "ratatinassions": "ratatiner",
    "ratatine": "ratatiner",
    "ratatinent": "ratatiner",
    "ratatinera": "ratatiner",
    "ratatinerai": "ratatiner",
    "ratatineraient": "ratatiner",
    "ratatinerais": "ratatiner",
    "ratatinerait": "ratatiner",
    "ratatineras": "ratatiner",
    "ratatinerez": "ratatiner",
    "ratatineriez": "ratatiner",
    "ratatinerions": "ratatiner",
    "ratatinerons": "ratatiner",
    "ratatineront": "ratatiner",
    "ratatines": "ratatiner",
    "ratatinez": "ratatiner",
    "ratatiniez": "ratatiner",
    "ratatinions": "ratatiner",
    "ratatinons": "ratatiner",
    "ratatinâmes": "ratatiner",
    "ratatinât": "ratatiner",
    "ratatinâtes": "ratatiner",
    "ratatinèrent": "ratatiner",
    "ratatiné": "ratatiner",
    "ratatinée": "ratatiner",
    "ratatinées": "ratatiner",
    "ratatinés": "ratatiner",
    "ratatouilles": "ratatouille",
    "rate": "rater",
    "ratent": "rater",
    "ratera": "rater",
    "raterai": "rater",
    "rateraient": "rater",
    "raterais": "rater",
    "raterait": "rater",
    "rateras": "rater",
    "raterez": "rater",
    "rateriez": "rater",
    "raterions": "rater",
    "raterons": "rater",
    "rateront": "rater",
    "rates": "rater",
    "ratez": "rater",
    "ratiboisa": "ratiboiser",
    "ratiboisai": "ratiboiser",
    "ratiboisaient": "ratiboiser",
    "ratiboisais": "ratiboiser",
    "ratiboisait": "ratiboiser",
    "ratiboisant": "ratiboiser",
    "ratiboisas": "ratiboiser",
    "ratiboisasse": "ratiboiser",
    "ratiboisassent": "ratiboiser",
    "ratiboisasses": "ratiboiser",
    "ratiboisassiez": "ratiboiser",
    "ratiboisassions": "ratiboiser",
    "ratiboise": "ratiboiser",
    "ratiboisent": "ratiboiser",
    "ratiboisera": "ratiboiser",
    "ratiboiserai": "ratiboiser",
    "ratiboiseraient": "ratiboiser",
    "ratiboiserais": "ratiboiser",
    "ratiboiserait": "ratiboiser",
    "ratiboiseras": "ratiboiser",
    "ratiboiserez": "ratiboiser",
    "ratiboiseriez": "ratiboiser",
    "ratiboiserions": "ratiboiser",
    "ratiboiserons": "ratiboiser",
    "ratiboiseront": "ratiboiser",
    "ratiboises": "ratiboiser",
    "ratiboisez": "ratiboiser",
    "ratiboisiez": "ratiboiser",
    "ratiboisions": "ratiboiser",
    "ratiboisons": "ratiboiser",
    "ratiboisâmes": "ratiboiser",
    "ratiboisât": "ratiboiser",
    "ratiboisâtes": "ratiboiser",
    "ratiboisèrent": "ratiboiser",
    "ratiboisé": "ratiboiser",
    "ratiboisée": "ratiboiser",
    "ratiboisées": "ratiboiser",
    "ratiboisés": "ratiboiser",
    "ratiches": "ratiche",
    "ratichons": "ratichon",
    "ratiez": "rater",
    "ratifia": "ratifier",
    "ratifiai": "ratifier",
    "ratifiaient": "ratifier",
    "ratifiais": "ratifier",
    "ratifiait": "ratifier",
    "ratifiant": "ratifier",
    "ratifias": "ratifier",
    "ratifiasse": "ratifier",
    "ratifiassent": "ratifier",
    "ratifiasses": "ratifier",
    "ratifiassiez": "ratifier",
    "ratifiassions": "ratifier",
    "ratifications": "ratification",
    "ratifie": "ratifier",
    "ratifient": "ratifier",
    "ratifiera": "ratifier",
    "ratifierai": "ratifier",
    "ratifieraient": "ratifier",
    "ratifierais": "ratifier",
    "ratifierait": "ratifier",
    "ratifieras": "ratifier",
    "ratifierez": "ratifier",
    "ratifieriez": "ratifier",
    "ratifierions": "ratifier",
    "ratifierons": "ratifier",
    "ratifieront": "ratifier",
    "ratifies": "ratifier",
    "ratifiez": "ratifier",
    "ratifiiez": "ratifier",
    "ratifiions": "ratifier",
    "ratifions": "ratifier",
    "ratifiâmes": "ratifier",
    "ratifiât": "ratifier",
    "ratifiâtes": "ratifier",
    "ratifièrent": "ratifier",
    "ratifié": "ratifier",
    "ratifiée": "ratifier",
    "ratifiées": "ratifier",
    "ratifiés": "ratifier",
    "ratines": "ratine",
    "ratiocina": "ratiociner",
    "ratiocinai": "ratiociner",
    "ratiocinaient": "ratiociner",
    "ratiocinais": "ratiociner",
    "ratiocinait": "ratiociner",
    "ratiocinant": "ratiociner",
    "ratiocinas": "ratiociner",
    "ratiocinasse": "ratiociner",
    "ratiocinassent": "ratiociner",
    "ratiocinasses": "ratiociner",
    "ratiocinassiez": "ratiociner",
    "ratiocinassions": "ratiociner",
    "ratiocinations": "ratiocination",
    "ratiocine": "ratiociner",
    "ratiocinent": "ratiociner",
    "ratiocinera": "ratiociner",
    "ratiocinerai": "ratiociner",
    "ratiocineraient": "ratiociner",
    "ratiocinerais": "ratiociner",
    "ratiocinerait": "ratiociner",
    "ratiocineras": "ratiociner",
    "ratiocinerez": "ratiociner",
    "ratiocineriez": "ratiociner",
    "ratiocinerions": "ratiociner",
    "ratiocinerons": "ratiociner",
    "ratiocineront": "ratiociner",
    "ratiocines": "ratiociner",
    "ratiocinez": "ratiociner",
    "ratiociniez": "ratiociner",
    "ratiocinions": "ratiociner",
    "ratiocinons": "ratiociner",
    "ratiocinâmes": "ratiociner",
    "ratiocinât": "ratiociner",
    "ratiocinâtes": "ratiociner",
    "ratiocinèrent": "ratiociner",
    "ratiociné": "ratiociner",
    "rationalisa": "rationaliser",
    "rationalisai": "rationaliser",
    "rationalisaient": "rationaliser",
    "rationalisais": "rationaliser",
    "rationalisait": "rationaliser",
    "rationalisant": "rationaliser",
    "rationalisas": "rationaliser",
    "rationalisasse": "rationaliser",
    "rationalisassent": "rationaliser",
    "rationalisasses": "rationaliser",
    "rationalisassiez": "rationaliser",
    "rationalisassions": "rationaliser",
    "rationalisations": "rationalisation",
    "rationalise": "rationaliser",
    "rationalisent": "rationaliser",
    "rationalisera": "rationaliser",
    "rationaliserai": "rationaliser",
    "rationaliseraient": "rationaliser",
    "rationaliserais": "rationaliser",
    "rationaliserait": "rationaliser",
    "rationaliseras": "rationaliser",
    "rationaliserez": "rationaliser",
    "rationaliseriez": "rationaliser",
    "rationaliserions": "rationaliser",
    "rationaliserons": "rationaliser",
    "rationaliseront": "rationaliser",
    "rationalises": "rationaliser",
    "rationalisez": "rationaliser",
    "rationalisiez": "rationaliser",
    "rationalisions": "rationaliser",
    "rationalismes": "rationalisme",
    "rationalisons": "rationaliser",
    "rationalistes": "rationaliste",
    "rationalisâmes": "rationaliser",
    "rationalisât": "rationaliser",
    "rationalisâtes": "rationaliser",
    "rationalisèrent": "rationaliser",
    "rationalisé": "rationaliser",
    "rationalisée": "rationaliser",
    "rationalisées": "rationaliser",
    "rationalisés": "rationaliser",
    "rationalités": "rationalité",
    "rationna": "rationner",
    "rationnai": "rationner",
    "rationnaient": "rationner",
    "rationnais": "rationner",
    "rationnait": "rationner",
    "rationnant": "rationner",
    "rationnas": "rationner",
    "rationnasse": "rationner",
    "rationnassent": "rationner",
    "rationnasses": "rationner",
    "rationnassiez": "rationner",
    "rationnassions": "rationner",
    "rationne": "rationner",
    "rationnelle": "rationnel",
    "rationnelles": "rationnel",
    "rationnels": "rationnel",
    "rationnements": "rationnement",
    "rationnent": "rationner",
    "rationnera": "rationner",
    "rationnerai": "rationner",
    "rationneraient": "rationner",
    "rationnerais": "rationner",
    "rationnerait": "rationner",
    "rationneras": "rationner",
    "rationnerez": "rationner",
    "rationneriez": "rationner",
    "rationnerions": "rationner",
    "rationnerons": "rationner",
    "rationneront": "rationner",
    "rationnes": "rationner",
    "rationnez": "rationner",
    "rationniez": "rationner",
    "rationnions": "rationner",
    "rationnons": "rationner",
    "rationnâmes": "rationner",
    "rationnât": "rationner",
    "rationnâtes": "rationner",
    "rationnèrent": "rationner",
    "rationné": "rationner",
    "rationnée": "rationner",
    "rationnées": "rationner",
    "rationnés": "rationner",
    "rations": "ration",
    "ratios": "ratio",
    "ratissa": "ratisser",
    "ratissages": "ratissage",
    "ratissai": "ratisser",
    "ratissaient": "ratisser",
    "ratissais": "ratisser",
    "ratissait": "ratisser",
    "ratissant": "ratisser",
    "ratissas": "ratisser",
    "ratissasse": "ratisser",
    "ratissassent": "ratisser",
    "ratissasses": "ratisser",
    "ratissassiez": "ratisser",
    "ratissassions": "ratisser",
    "ratisse": "ratisser",
    "ratissent": "ratisser",
    "ratissera": "ratisser",
    "ratisserai": "ratisser",
    "ratisseraient": "ratisser",
    "ratisserais": "ratisser",
    "ratisserait": "ratisser",
    "ratisseras": "ratisser",
    "ratisserez": "ratisser",
    "ratisseriez": "ratisser",
    "ratisserions": "ratisser",
    "ratisserons": "ratisser",
    "ratisseront": "ratisser",
    "ratisses": "ratisser",
    "ratissez": "ratisser",
    "ratissiez": "ratisser",
    "ratissions": "ratisser",
    "ratissons": "ratisser",
    "ratissâmes": "ratisser",
    "ratissât": "ratisser",
    "ratissâtes": "ratisser",
    "ratissèrent": "ratisser",
    "ratissé": "ratisser",
    "ratissée": "ratisser",
    "ratissées": "ratisser",
    "ratissés": "ratisser",
    "ratites": "ratite",
    "ratières": "ratière",
    "ratonnades": "ratonnade",
    "ratonnent": "ratonner",
    "ratons": "raton",
    "rats": "rat",
    "rats-de-cave": "rat-de-cave",
    "rattacha": "rattacher",
    "rattachai": "rattacher",
    "rattachaient": "rattacher",
    "rattachais": "rattacher",
    "rattachait": "rattacher",
    "rattachant": "rattacher",
    "rattachas": "rattacher",
    "rattachasse": "rattacher",
    "rattachassent": "rattacher",
    "rattachasses": "rattacher",
    "rattachassiez": "rattacher",
    "rattachassions": "rattacher",
    "rattache": "rattacher",
    "rattachements": "rattachement",
    "rattachent": "rattacher",
    "rattachera": "rattacher",
    "rattacherai": "rattacher",
    "rattacheraient": "rattacher",
    "rattacherais": "rattacher",
    "rattacherait": "rattacher",
    "rattacheras": "rattacher",
    "rattacherez": "rattacher",
    "rattacheriez": "rattacher",
    "rattacherions": "rattacher",
    "rattacherons": "rattacher",
    "rattacheront": "rattacher",
    "rattaches": "rattacher",
    "rattachez": "rattacher",
    "rattachiez": "rattacher",
    "rattachions": "rattacher",
    "rattachons": "rattacher",
    "rattachâmes": "rattacher",
    "rattachât": "rattacher",
    "rattachâtes": "rattacher",
    "rattachèrent": "rattacher",
    "rattaché": "rattacher",
    "rattachée": "rattacher",
    "rattachées": "rattacher",
    "rattachés": "rattacher",
    "rattrapa": "rattraper",
    "rattrapages": "rattrapage",
    "rattrapai": "rattraper",
    "rattrapaient": "rattraper",
    "rattrapais": "rattraper",
    "rattrapait": "rattraper",
    "rattrapant": "rattraper",
    "rattrapas": "rattraper",
    "rattrapasse": "rattraper",
    "rattrapassent": "rattraper",
    "rattrapasses": "rattraper",
    "rattrapassiez": "rattraper",
    "rattrapassions": "rattraper",
    "rattrape": "rattraper",
    "rattrapent": "rattraper",
    "rattrapera": "rattraper",
    "rattraperai": "rattraper",
    "rattraperaient": "rattraper",
    "rattraperais": "rattraper",
    "rattraperait": "rattraper",
    "rattraperas": "rattraper",
    "rattraperez": "rattraper",
    "rattraperiez": "rattraper",
    "rattraperions": "rattraper",
    "rattraperons": "rattraper",
    "rattraperont": "rattraper",
    "rattrapes": "rattraper",
    "rattrapez": "rattraper",
    "rattrapiez": "rattraper",
    "rattrapions": "rattraper",
    "rattrapons": "rattraper",
    "rattrappa": "rattraper",
    "rattrapâmes": "rattraper",
    "rattrapât": "rattraper",
    "rattrapâtes": "rattraper",
    "rattrapèrent": "rattraper",
    "rattrapé": "rattraper",
    "rattrapée": "rattraper",
    "rattrapées": "rattraper",
    "rattrapés": "rattraper",
    "ratura": "raturer",
    "raturai": "raturer",
    "raturais": "raturer",
    "raturait": "raturer",
    "rature": "raturer",
    "ratures": "rature",
    "raturé": "raturer",
    "raturée": "raturer",
    "raturées": "raturer",
    "raturés": "raturer",
    "ratâmes": "rater",
    "ratât": "rater",
    "ratâtes": "rater",
    "ratèrent": "rater",
    "raté": "rater",
    "ratée": "rater",
    "ratées": "rater",
    "ratés": "rater",
    "raucités": "raucité",
    "raugmenta": "raugmenter",
    "raugmentai": "raugmenter",
    "raugmentaient": "raugmenter",
    "raugmentais": "raugmenter",
    "raugmentait": "raugmenter",
    "raugmentant": "raugmenter",
    "raugmentas": "raugmenter",
    "raugmentasse": "raugmenter",
    "raugmentassent": "raugmenter",
    "raugmentasses": "raugmenter",
    "raugmentassiez": "raugmenter",
    "raugmentassions": "raugmenter",
    "raugmente": "raugmenter",
    "raugmentent": "raugmenter",
    "raugmentera": "raugmenter",
    "raugmenterai": "raugmenter",
    "raugmenteraient": "raugmenter",
    "raugmenterais": "raugmenter",
    "raugmenterait": "raugmenter",
    "raugmenteras": "raugmenter",
    "raugmenterez": "raugmenter",
    "raugmenteriez": "raugmenter",
    "raugmenterions": "raugmenter",
    "raugmenterons": "raugmenter",
    "raugmenteront": "raugmenter",
    "raugmentes": "raugmenter",
    "raugmentez": "raugmenter",
    "raugmentiez": "raugmenter",
    "raugmentions": "raugmenter",
    "raugmentons": "raugmenter",
    "raugmentâmes": "raugmenter",
    "raugmentât": "raugmenter",
    "raugmentâtes": "raugmenter",
    "raugmentèrent": "raugmenter",
    "raugmenté": "raugmenter",
    "raugmentée": "raugmenter",
    "raugmentées": "raugmenter",
    "raugmentés": "raugmenter",
    "rauqua": "rauquer",
    "rauque": "rauquer",
    "rauques": "rauque",
    "ravage": "ravager",
    "ravagea": "ravager",
    "ravageai": "ravager",
    "ravageaient": "ravager",
    "ravageais": "ravager",
    "ravageait": "ravager",
    "ravageant": "ravager",
    "ravageante": "ravageant",
    "ravageas": "ravager",
    "ravageasse": "ravager",
    "ravageassent": "ravager",
    "ravageasses": "ravager",
    "ravageassiez": "ravager",
    "ravageassions": "ravager",
    "ravagent": "ravager",
    "ravageons": "ravager",
    "ravagera": "ravager",
    "ravagerai": "ravager",
    "ravageraient": "ravager",
    "ravagerais": "ravager",
    "ravagerait": "ravager",
    "ravageras": "ravager",
    "ravagerez": "ravager",
    "ravageriez": "ravager",
    "ravagerions": "ravager",
    "ravagerons": "ravager",
    "ravageront": "ravager",
    "ravages": "ravager",
    "ravageurs": "ravageur",
    "ravageuse": "ravageur",
    "ravageuses": "ravageur",
    "ravagez": "ravager",
    "ravageâmes": "ravager",
    "ravageât": "ravager",
    "ravageâtes": "ravager",
    "ravagiez": "ravager",
    "ravagions": "ravager",
    "ravagèrent": "ravager",
    "ravagé": "ravager",
    "ravagée": "ravager",
    "ravagées": "ravager",
    "ravagés": "ravager",
    "ravala": "ravaler",
    "ravalai": "ravaler",
    "ravalaient": "ravaler",
    "ravalais": "ravaler",
    "ravalait": "ravaler",
    "ravalant": "ravaler",
    "ravalas": "ravaler",
    "ravalasse": "ravaler",
    "ravalassent": "ravaler",
    "ravalasses": "ravaler",
    "ravalassiez": "ravaler",
    "ravalassions": "ravaler",
    "ravale": "ravaler",
    "ravalements": "ravalement",
    "ravalent": "ravaler",
    "ravalera": "ravaler",
    "ravalerai": "ravaler",
    "ravaleraient": "ravaler",
    "ravalerais": "ravaler",
    "ravalerait": "ravaler",
    "ravaleras": "ravaler",
    "ravalerez": "ravaler",
    "ravaleriez": "ravaler",
    "ravalerions": "ravaler",
    "ravalerons": "ravaler",
    "ravaleront": "ravaler",
    "ravales": "ravaler",
    "ravalez": "ravaler",
    "ravaliez": "ravaler",
    "ravalions": "ravaler",
    "ravalons": "ravaler",
    "ravals": "raval",
    "ravalâmes": "ravaler",
    "ravalât": "ravaler",
    "ravalâtes": "ravaler",
    "ravalèrent": "ravaler",
    "ravalé": "ravaler",
    "ravalée": "ravaler",
    "ravalées": "ravaler",
    "ravalés": "ravaler",
    "ravauda": "ravauder",
    "ravaudai": "ravauder",
    "ravaudaient": "ravauder",
    "ravaudais": "ravauder",
    "ravaudait": "ravauder",
    "ravaudant": "ravauder",
    "ravaudas": "ravauder",
    "ravaudasse": "ravauder",
    "ravaudassent": "ravauder",
    "ravaudasses": "ravauder",
    "ravaudassiez": "ravauder",
    "ravaudassions": "ravauder",
    "ravaude": "ravauder",
    "ravaudent": "ravauder",
    "ravaudera": "ravauder",
    "ravauderai": "ravauder",
    "ravauderaient": "ravauder",
    "ravauderais": "ravauder",
    "ravauderait": "ravauder",
    "ravauderas": "ravauder",
    "ravauderez": "ravauder",
    "ravauderiez": "ravauder",
    "ravauderions": "ravauder",
    "ravauderons": "ravauder",
    "ravauderont": "ravauder",
    "ravaudes": "ravauder",
    "ravaudez": "ravauder",
    "ravaudiez": "ravauder",
    "ravaudions": "ravauder",
    "ravaudons": "ravauder",
    "ravaudâmes": "ravauder",
    "ravaudât": "ravauder",
    "ravaudâtes": "ravauder",
    "ravaudèrent": "ravauder",
    "ravaudé": "ravauder",
    "ravaudée": "ravauder",
    "ravaudées": "ravauder",
    "ravaudés": "ravauder",
    "ravenelles": "ravenelle",
    "raves": "rave",
    "ravi": "ravir",
    "ravie": "ravir",
    "raviers": "ravier",
    "ravies": "ravir",
    "ravigota": "ravigoter",
    "ravigotai": "ravigoter",
    "ravigotaient": "ravigoter",
    "ravigotais": "ravigoter",
    "ravigotait": "ravigoter",
    "ravigotant": "ravigoter",
    "ravigotants": "ravigotant",
    "ravigotas": "ravigoter",
    "ravigotasse": "ravigoter",
    "ravigotassent": "ravigoter",
    "ravigotasses": "ravigoter",
    "ravigotassiez": "ravigoter",
    "ravigotassions": "ravigoter",
    "ravigote": "ravigoter",
    "ravigotent": "ravigoter",
    "ravigotera": "ravigoter",
    "ravigoterai": "ravigoter",
    "ravigoteraient": "ravigoter",
    "ravigoterais": "ravigoter",
    "ravigoterait": "ravigoter",
    "ravigoteras": "ravigoter",
    "ravigoterez": "ravigoter",
    "ravigoteriez": "ravigoter",
    "ravigoterions": "ravigoter",
    "ravigoterons": "ravigoter",
    "ravigoteront": "ravigoter",
    "ravigotes": "ravigoter",
    "ravigotez": "ravigoter",
    "ravigotiez": "ravigoter",
    "ravigotions": "ravigoter",
    "ravigotons": "ravigoter",
    "ravigotâmes": "ravigoter",
    "ravigotât": "ravigoter",
    "ravigotâtes": "ravigoter",
    "ravigotèrent": "ravigoter",
    "ravigoté": "ravigoter",
    "ravigotée": "ravigoter",
    "ravigotées": "ravigoter",
    "ravigotés": "ravigoter",
    "ravili": "ravilir",
    "ravilie": "ravilir",
    "ravilies": "ravilir",
    "ravilira": "ravilir",
    "ravilirai": "ravilir",
    "raviliraient": "ravilir",
    "ravilirais": "ravilir",
    "ravilirait": "ravilir",
    "raviliras": "ravilir",
    "ravilirent": "ravilir",
    "ravilirez": "ravilir",
    "raviliriez": "ravilir",
    "ravilirions": "ravilir",
    "ravilirons": "ravilir",
    "raviliront": "ravilir",
    "ravilis": "ravilir",
    "ravilissaient": "ravilir",
    "ravilissais": "ravilir",
    "ravilissait": "ravilir",
    "ravilissant": "ravilir",
    "ravilisse": "ravilir",
    "ravilissent": "ravilir",
    "ravilisses": "ravilir",
    "ravilissez": "ravilir",
    "ravilissiez": "ravilir",
    "ravilissions": "ravilir",
    "ravilissons": "ravilir",
    "ravilit": "ravilir",
    "ravilîmes": "ravilir",
    "ravilît": "ravilir",
    "ravilîtes": "ravilir",
    "ravina": "raviner",
    "ravinai": "raviner",
    "ravinaient": "raviner",
    "ravinais": "raviner",
    "ravinait": "raviner",
    "ravinant": "raviner",
    "ravinas": "raviner",
    "ravinasse": "raviner",
    "ravinassent": "raviner",
    "ravinasses": "raviner",
    "ravinassiez": "raviner",
    "ravinassions": "raviner",
    "ravine": "raviner",
    "ravinements": "ravinement",
    "ravinent": "raviner",
    "ravinera": "raviner",
    "ravinerai": "raviner",
    "ravineraient": "raviner",
    "ravinerais": "raviner",
    "ravinerait": "raviner",
    "ravineras": "raviner",
    "ravinerez": "raviner",
    "ravineriez": "raviner",
    "ravinerions": "raviner",
    "ravinerons": "raviner",
    "ravineront": "raviner",
    "ravines": "raviner",
    "ravinez": "raviner",
    "raviniez": "raviner",
    "ravinions": "raviner",
    "ravinons": "raviner",
    "ravins": "ravin",
    "ravinâmes": "raviner",
    "ravinât": "raviner",
    "ravinâtes": "raviner",
    "ravinèrent": "raviner",
    "raviné": "raviner",
    "ravinée": "raviner",
    "ravinées": "raviner",
    "ravinés": "raviner",
    "ravioles": "raviole",
    "raviolis": "ravioli",
    "ravira": "ravir",
    "ravirai": "ravir",
    "raviraient": "ravir",
    "ravirais": "ravir",
    "ravirait": "ravir",
    "raviras": "ravir",
    "ravirent": "ravir",
    "ravirez": "ravir",
    "raviriez": "ravir",
    "ravirions": "ravir",
    "ravirons": "ravir",
    "raviront": "ravir",
    "ravis": "ravir",
    "ravisa": "raviser",
    "ravisai": "raviser",
    "ravisaient": "raviser",
    "ravisais": "raviser",
    "ravisait": "raviser",
    "ravisant": "raviser",
    "ravisas": "raviser",
    "ravisasse": "raviser",
    "ravisassent": "raviser",
    "ravisasses": "raviser",
    "ravisassiez": "raviser",
    "ravisassions": "raviser",
    "ravise": "raviser",
    "ravisent": "raviser",
    "ravisera": "raviser",
    "raviserai": "raviser",
    "raviseraient": "raviser",
    "raviserais": "raviser",
    "raviserait": "raviser",
    "raviseras": "raviser",
    "raviserez": "raviser",
    "raviseriez": "raviser",
    "raviserions": "raviser",
    "raviserons": "raviser",
    "raviseront": "raviser",
    "ravises": "raviser",
    "ravisez": "raviser",
    "ravisiez": "raviser",
    "ravisions": "raviser",
    "ravisons": "raviser",
    "ravissaient": "ravir",
    "ravissais": "ravir",
    "ravissait": "ravir",
    "ravissant": "ravir",
    "ravissante": "ravissant",
    "ravissantes": "ravissant",
    "ravissants": "ravissant",
    "ravisse": "ravir",
    "ravissements": "ravissement",
    "ravissent": "ravir",
    "ravisses": "ravir",
    "ravisseurs": "ravisseur",
    "ravisseuse": "ravisseur",
    "ravisseuses": "ravisseur",
    "ravissez": "ravir",
    "ravissiez": "ravir",
    "ravissions": "ravir",
    "ravissons": "ravir",
    "ravisâmes": "raviser",
    "ravisât": "raviser",
    "ravisâtes": "raviser",
    "ravisèrent": "raviser",
    "ravisé": "raviser",
    "ravisée": "raviser",
    "ravisées": "raviser",
    "ravisés": "raviser",
    "ravit": "ravir",
    "ravitailla": "ravitailler",
    "ravitaillai": "ravitailler",
    "ravitaillaient": "ravitailler",
    "ravitaillais": "ravitailler",
    "ravitaillait": "ravitailler",
    "ravitaillant": "ravitailler",
    "ravitaillas": "ravitailler",
    "ravitaillasse": "ravitailler",
    "ravitaillassent": "ravitailler",
    "ravitaillasses": "ravitailler",
    "ravitaillassiez": "ravitailler",
    "ravitaillassions": "ravitailler",
    "ravitaille": "ravitailler",
    "ravitaillements": "ravitaillement",
    "ravitaillent": "ravitailler",
    "ravitaillera": "ravitailler",
    "ravitaillerai": "ravitailler",
    "ravitailleraient": "ravitailler",
    "ravitaillerais": "ravitailler",
    "ravitaillerait": "ravitailler",
    "ravitailleras": "ravitailler",
    "ravitaillerez": "ravitailler",
    "ravitailleriez": "ravitailler",
    "ravitaillerions": "ravitailler",
    "ravitaillerons": "ravitailler",
    "ravitailleront": "ravitailler",
    "ravitailles": "ravitailler",
    "ravitailleurs": "ravitailleur",
    "ravitailleuse": "ravitailleur",
    "ravitaillez": "ravitailler",
    "ravitailliez": "ravitailler",
    "ravitaillions": "ravitailler",
    "ravitaillons": "ravitailler",
    "ravitaillâmes": "ravitailler",
    "ravitaillât": "ravitailler",
    "ravitaillâtes": "ravitailler",
    "ravitaillèrent": "ravitailler",
    "ravitaillé": "ravitailler",
    "ravitaillée": "ravitailler",
    "ravitaillées": "ravitailler",
    "ravitaillés": "ravitailler",
    "raviva": "raviver",
    "ravivai": "raviver",
    "ravivaient": "raviver",
    "ravivais": "raviver",
    "ravivait": "raviver",
    "ravivant": "raviver",
    "ravivas": "raviver",
    "ravivasse": "raviver",
    "ravivassent": "raviver",
    "ravivasses": "raviver",
    "ravivassiez": "raviver",
    "ravivassions": "raviver",
    "ravive": "raviver",
    "ravivent": "raviver",
    "ravivera": "raviver",
    "raviverai": "raviver",
    "raviveraient": "raviver",
    "raviverais": "raviver",
    "raviverait": "raviver",
    "raviveras": "raviver",
    "raviverez": "raviver",
    "raviveriez": "raviver",
    "raviverions": "raviver",
    "raviverons": "raviver",
    "raviveront": "raviver",
    "ravives": "raviver",
    "ravivez": "raviver",
    "raviviez": "raviver",
    "ravivions": "raviver",
    "ravivons": "raviver",
    "ravivâmes": "raviver",
    "ravivât": "raviver",
    "ravivâtes": "raviver",
    "ravivèrent": "raviver",
    "ravivé": "raviver",
    "ravivée": "raviver",
    "ravivées": "raviver",
    "ravivés": "raviver",
    "ravîmes": "ravir",
    "ravît": "ravir",
    "ravîtes": "ravir",
    "raya": "rayer",
    "rayables": "rayable",
    "rayai": "rayer",
    "rayaient": "rayer",
    "rayais": "rayer",
    "rayait": "rayer",
    "rayant": "rayer",
    "rayas": "rayer",
    "rayasse": "rayer",
    "rayassent": "rayer",
    "rayasses": "rayer",
    "rayassiez": "rayer",
    "rayassions": "rayer",
    "raye": "rayer",
    "rayent": "rayer",
    "rayera": "rayer",
    "rayerai": "rayer",
    "rayeraient": "rayer",
    "rayerais": "rayer",
    "rayerait": "rayer",
    "rayeras": "rayer",
    "rayerez": "rayer",
    "rayeriez": "rayer",
    "rayerions": "rayer",
    "rayerons": "rayer",
    "rayeront": "rayer",
    "rayes": "rayer",
    "rayez": "rayer",
    "rayiez": "rayer",
    "rayions": "rayer",
    "rayonna": "rayonner",
    "rayonnages": "rayonnage",
    "rayonnai": "rayonner",
    "rayonnaient": "rayonner",
    "rayonnais": "rayonner",
    "rayonnait": "rayonner",
    "rayonnant": "rayonner",
    "rayonnante": "rayonnant",
    "rayonnantes": "rayonnant",
    "rayonnants": "rayonnant",
    "rayonnas": "rayonner",
    "rayonnasse": "rayonner",
    "rayonnassent": "rayonner",
    "rayonnasses": "rayonner",
    "rayonnassiez": "rayonner",
    "rayonnassions": "rayonner",
    "rayonne": "rayonner",
    "rayonnements": "rayonnement",
    "rayonnent": "rayonner",
    "rayonnera": "rayonner",
    "rayonnerai": "rayonner",
    "rayonneraient": "rayonner",
    "rayonnerais": "rayonner",
    "rayonnerait": "rayonner",
    "rayonneras": "rayonner",
    "rayonnerez": "rayonner",
    "rayonneriez": "rayonner",
    "rayonnerions": "rayonner",
    "rayonnerons": "rayonner",
    "rayonneront": "rayonner",
    "rayonnes": "rayonner",
    "rayonnez": "rayonner",
    "rayonniez": "rayonner",
    "rayonnions": "rayonner",
    "rayonnons": "rayonner",
    "rayonnâmes": "rayonner",
    "rayonnât": "rayonner",
    "rayonnâtes": "rayonner",
    "rayonnèrent": "rayonner",
    "rayonné": "rayonner",
    "rayonnée": "rayonné",
    "rayonnées": "rayonné",
    "rayonnés": "rayonné",
    "rayons": "rayon",
    "rayures": "rayure",
    "rayâmes": "rayer",
    "rayât": "rayer",
    "rayâtes": "rayer",
    "rayèrent": "rayer",
    "rayé": "rayer",
    "rayée": "rayer",
    "rayées": "rayer",
    "rayés": "rayer",
    "razzia": "razzier",
    "razziai": "razzier",
    "razziaient": "razzier",
    "razziais": "razzier",
    "razziait": "razzier",
    "razziant": "razzier",
    "razzias": "razzier",
    "razziasse": "razzier",
    "razziassent": "razzier",
    "razziasses": "razzier",
    "razziassiez": "razzier",
    "razziassions": "razzier",
    "razzie": "razzier",
    "razzient": "razzier",
    "razziera": "razzier",
    "razzierai": "razzier",
    "razzieraient": "razzier",
    "razzierais": "razzier",
    "razzierait": "razzier",
    "razzieras": "razzier",
    "razzierez": "razzier",
    "razzieriez": "razzier",
    "razzierions": "razzier",
    "razzierons": "razzier",
    "razzieront": "razzier",
    "razzies": "razzier",
    "razziez": "razzier",
    "razziiez": "razzier",
    "razziions": "razzier",
    "razzions": "razzier",
    "razziâmes": "razzier",
    "razziât": "razzier",
    "razziâtes": "razzier",
    "razzièrent": "razzier",
    "razzié": "razzier",
    "razziée": "razzier",
    "razziées": "razzier",
    "razziés": "razzier",
    "re": "r",
    "re-aboie": "reaboyer",
    "re-balbutiant": "rebalbutiant",
    "re-baptême": "rebaptême",
    "re-biberonner": "rebiberonner",
    "re-bide": "rebide",
    "re-blinder": "reblinder",
    "re-bombardons": "rebombardon",
    "re-boucler": "reboucler",
    "re-cabossé": "recabosser",
    "re-café": "recafé",
    "re-cailloux": "recailloux",
    "re-calibrais": "recalibrer",
    "re-cassée": "recasser",
    "re-chanteur": "rechanteur",
    "re-chiader": "rechiader",
    "re-cisèle": "reciseler",
    "re-classe": "reclasser",
    "re-classer": "reclasser",
    "re-connaître": "reconnaître",
    "re-contacte": "recontacter",
    "re-contactent": "recontacter",
    "re-contacter": "recontacter",
    "re-contacterai": "recontacter",
    "re-convaincra": "reconvaincre",
    "re-coup": "recoup",
    "re-crac": "recrac",
    "re-creusés": "recreuser",
    "re-croquis": "recroquis",
    "re-création": "recréation",
    "re-créée": "recréer",
    "re-cul": "recul",
    "re-diffuses": "rediffuser",
    "re-dose": "redose",
    "re-drapeau": "redrapeau",
    "re-déchire": "redéchirer",
    "re-déclic": "redéclic",
    "re-décore": "redécorer",
    "re-décorer": "redécorer",
    "re-déménager": "redéménager",
    "re-explique": "reexpliquer",
    "re-faim": "refaim",
    "re-frappe": "refrapper",
    "re-frappé": "refrapper",
    "re-fuse": "refuser",
    "re-gomme": "regomme",
    "re-histoires": "rehistoire",
    "re-hygiène": "rehygiène",
    "re-kidnappais": "rekidnapper",
    "re-lettre": "relettre",
    "re-main": "remain",
    "re-matérialisation": "rematérialisation",
    "re-morphine": "remorphine",
    "re-nés": "rené",
    "re-paye": "repayer",
    "re-penser": "repenser",
    "re-potassé": "repotasser",
    "re-programmation": "reprogrammation",
    "re-programmée": "reprogrammer",
    "re-raconte": "reraconter",
    "re-racontées": "reraconter",
    "re-remplir": "reremplir",
    "re-rentrer": "rerentrer",
    "re-respirer": "rerespirer",
    "re-ressortait": "reressortir",
    "re-retirent": "reretirer",
    "re-rigole": "rerigole",
    "re-récurait": "rerécurer",
    "re-réparer": "reréparer",
    "re-rêvé": "rerêvé",
    "re-salué": "resaluer",
    "re-savaté": "resavater",
    "re-sculpte": "resculpter",
    "re-sevrage": "resevrage",
    "re-signer": "resigner",
    "re-sommeil": "resommeil",
    "re-sonne": "resonner",
    "re-structuration": "restructuration",
    "re-séparés": "reséparé",
    "re-taloche": "retaloche",
    "re-titille": "retitiller",
    "re-traitée": "retraité",
    "re-travail": "retravail",
    "re-tuage": "retuage",
    "re-tuer": "retuer",
    "re-tues": "retu",
    "re-veux": "revouloir",
    "re-vie": "revie",
    "re-visite": "revisiter",
    "re-vit": "revivre",
    "re-vérifier": "revérifier",
    "re-vérifié": "revérifié",
    "re-ébranlés": "reébranler",
    "re-échanger": "reéchanger",
    "realisations": "realisation",
    "reationalisations": "reationalisation",
    "rebaise": "rebaiser",
    "rebaisent": "rebaiser",
    "rebaissa": "rebaisser",
    "rebaissai": "rebaisser",
    "rebaissaient": "rebaisser",
    "rebaissais": "rebaisser",
    "rebaissait": "rebaisser",
    "rebaissant": "rebaisser",
    "rebaissas": "rebaisser",
    "rebaissasse": "rebaisser",
    "rebaissassent": "rebaisser",
    "rebaissasses": "rebaisser",
    "rebaissassiez": "rebaisser",
    "rebaissassions": "rebaisser",
    "rebaisse": "rebaisser",
    "rebaissent": "rebaisser",
    "rebaissera": "rebaisser",
    "rebaisserai": "rebaisser",
    "rebaisseraient": "rebaisser",
    "rebaisserais": "rebaisser",
    "rebaisserait": "rebaisser",
    "rebaisseras": "rebaisser",
    "rebaisserez": "rebaisser",
    "rebaisseriez": "rebaisser",
    "rebaisserions": "rebaisser",
    "rebaisserons": "rebaisser",
    "rebaisseront": "rebaisser",
    "rebaisses": "rebaisser",
    "rebaissez": "rebaisser",
    "rebaissiez": "rebaisser",
    "rebaissions": "rebaisser",
    "rebaissons": "rebaisser",
    "rebaissâmes": "rebaisser",
    "rebaissât": "rebaisser",
    "rebaissâtes": "rebaisser",
    "rebaissèrent": "rebaisser",
    "rebaissé": "rebaisser",
    "rebaissée": "rebaisser",
    "rebaissées": "rebaisser",
    "rebaissés": "rebaisser",
    "rebaisé": "rebaiser",
    "rebaptisa": "rebaptiser",
    "rebaptisai": "rebaptiser",
    "rebaptisaient": "rebaptiser",
    "rebaptisais": "rebaptiser",
    "rebaptisait": "rebaptiser",
    "rebaptisant": "rebaptiser",
    "rebaptisas": "rebaptiser",
    "rebaptisasse": "rebaptiser",
    "rebaptisassent": "rebaptiser",
    "rebaptisasses": "rebaptiser",
    "rebaptisassiez": "rebaptiser",
    "rebaptisassions": "rebaptiser",
    "rebaptise": "rebaptiser",
    "rebaptisent": "rebaptiser",
    "rebaptisera": "rebaptiser",
    "rebaptiserai": "rebaptiser",
    "rebaptiseraient": "rebaptiser",
    "rebaptiserais": "rebaptiser",
    "rebaptiserait": "rebaptiser",
    "rebaptiseras": "rebaptiser",
    "rebaptiserez": "rebaptiser",
    "rebaptiseriez": "rebaptiser",
    "rebaptiserions": "rebaptiser",
    "rebaptiserons": "rebaptiser",
    "rebaptiseront": "rebaptiser",
    "rebaptises": "rebaptiser",
    "rebaptisez": "rebaptiser",
    "rebaptisiez": "rebaptiser",
    "rebaptisions": "rebaptiser",
    "rebaptisons": "rebaptiser",
    "rebaptisâmes": "rebaptiser",
    "rebaptisât": "rebaptiser",
    "rebaptisâtes": "rebaptiser",
    "rebaptisèrent": "rebaptiser",
    "rebaptisé": "rebaptiser",
    "rebaptisée": "rebaptiser",
    "rebaptisées": "rebaptiser",
    "rebaptisés": "rebaptiser",
    "rebasculait": "rebasculer",
    "rebascule": "rebasculer",
    "rebasculera": "rebasculer",
    "rebat": "rebattre",
    "rebats": "rebattre",
    "rebattaient": "rebattre",
    "rebattais": "rebattre",
    "rebattait": "rebattre",
    "rebattant": "rebattre",
    "rebatte": "rebattre",
    "rebattent": "rebattre",
    "rebattes": "rebattre",
    "rebattez": "rebattre",
    "rebattiez": "rebattre",
    "rebattions": "rebattre",
    "rebattirent": "rebattre",
    "rebattis": "rebattre",
    "rebattisse": "rebattre",
    "rebattissent": "rebattre",
    "rebattisses": "rebattre",
    "rebattissiez": "rebattre",
    "rebattissions": "rebattre",
    "rebattit": "rebattre",
    "rebattons": "rebattre",
    "rebattra": "rebattre",
    "rebattrai": "rebattre",
    "rebattraient": "rebattre",
    "rebattrais": "rebattre",
    "rebattrait": "rebattre",
    "rebattras": "rebattre",
    "rebattrez": "rebattre",
    "rebattriez": "rebattre",
    "rebattrions": "rebattre",
    "rebattrons": "rebattre",
    "rebattront": "rebattre",
    "rebattu": "rebattre",
    "rebattue": "rebattu",
    "rebattues": "rebattu",
    "rebattus": "rebattu",
    "rebattîmes": "rebattre",
    "rebattît": "rebattre",
    "rebattîtes": "rebattre",
    "rebecs": "rebec",
    "rebecté": "rebecter",
    "rebella": "rebeller",
    "rebellai": "rebeller",
    "rebellaient": "rebeller",
    "rebellais": "rebeller",
    "rebellait": "rebeller",
    "rebellant": "rebeller",
    "rebellas": "rebeller",
    "rebellasse": "rebeller",
    "rebellassent": "rebeller",
    "rebellasses": "rebeller",
    "rebellassiez": "rebeller",
    "rebellassions": "rebeller",
    "rebelle": "rebeller",
    "rebellent": "rebeller",
    "rebellera": "rebeller",
    "rebellerai": "rebeller",
    "rebelleraient": "rebeller",
    "rebellerais": "rebeller",
    "rebellerait": "rebeller",
    "rebelleras": "rebeller",
    "rebellerez": "rebeller",
    "rebelleriez": "rebeller",
    "rebellerions": "rebeller",
    "rebellerons": "rebeller",
    "rebelleront": "rebeller",
    "rebelles": "rebeller",
    "rebellez": "rebeller",
    "rebelliez": "rebeller",
    "rebellions": "rebeller",
    "rebellons": "rebeller",
    "rebellâmes": "rebeller",
    "rebellât": "rebeller",
    "rebellâtes": "rebeller",
    "rebellèrent": "rebeller",
    "rebellé": "rebeller",
    "rebellée": "rebeller",
    "rebellées": "rebeller",
    "rebellés": "rebeller",
    "rebiffa": "rebiffer",
    "rebiffai": "rebiffer",
    "rebiffaient": "rebiffer",
    "rebiffais": "rebiffer",
    "rebiffait": "rebiffer",
    "rebiffant": "rebiffer",
    "rebiffas": "rebiffer",
    "rebiffasse": "rebiffer",
    "rebiffassent": "rebiffer",
    "rebiffasses": "rebiffer",
    "rebiffassiez": "rebiffer",
    "rebiffassions": "rebiffer",
    "rebiffe": "rebiffer",
    "rebiffent": "rebiffer",
    "rebiffera": "rebiffer",
    "rebifferai": "rebiffer",
    "rebifferaient": "rebiffer",
    "rebifferais": "rebiffer",
    "rebifferait": "rebiffer",
    "rebifferas": "rebiffer",
    "rebifferez": "rebiffer",
    "rebifferiez": "rebiffer",
    "rebifferions": "rebiffer",
    "rebifferons": "rebiffer",
    "rebifferont": "rebiffer",
    "rebiffes": "rebiffer",
    "rebiffez": "rebiffer",
    "rebiffiez": "rebiffer",
    "rebiffions": "rebiffer",
    "rebiffons": "rebiffer",
    "rebiffâmes": "rebiffer",
    "rebiffât": "rebiffer",
    "rebiffâtes": "rebiffer",
    "rebiffèrent": "rebiffer",
    "rebiffé": "rebiffer",
    "rebiffée": "rebiffer",
    "rebiffées": "rebiffer",
    "rebiffés": "rebiffer",
    "rebiquaient": "rebiquer",
    "rebiquait": "rebiquer",
    "rebique": "rebiquer",
    "rebiquée": "rebiquer",
    "reblanchi": "reblanchir",
    "reblanchie": "reblanchir",
    "reblanchies": "reblanchir",
    "reblanchira": "reblanchir",
    "reblanchirai": "reblanchir",
    "reblanchiraient": "reblanchir",
    "reblanchirais": "reblanchir",
    "reblanchirait": "reblanchir",
    "reblanchiras": "reblanchir",
    "reblanchirent": "reblanchir",
    "reblanchirez": "reblanchir",
    "reblanchiriez": "reblanchir",
    "reblanchirions": "reblanchir",
    "reblanchirons": "reblanchir",
    "reblanchiront": "reblanchir",
    "reblanchis": "reblanchir",
    "reblanchissaient": "reblanchir",
    "reblanchissais": "reblanchir",
    "reblanchissait": "reblanchir",
    "reblanchissant": "reblanchir",
    "reblanchisse": "reblanchir",
    "reblanchissent": "reblanchir",
    "reblanchisses": "reblanchir",
    "reblanchissez": "reblanchir",
    "reblanchissiez": "reblanchir",
    "reblanchissions": "reblanchir",
    "reblanchissons": "reblanchir",
    "reblanchit": "reblanchir",
    "reblanchîmes": "reblanchir",
    "reblanchît": "reblanchir",
    "reblanchîtes": "reblanchir",
    "reblochons": "reblochon",
    "rebois": "reboire",
    "reboisa": "reboiser",
    "reboisai": "reboiser",
    "reboisaient": "reboiser",
    "reboisais": "reboiser",
    "reboisait": "reboiser",
    "reboisant": "reboiser",
    "reboisas": "reboiser",
    "reboisasse": "reboiser",
    "reboisassent": "reboiser",
    "reboisasses": "reboiser",
    "reboisassiez": "reboiser",
    "reboisassions": "reboiser",
    "reboise": "reboiser",
    "reboisements": "reboisement",
    "reboisent": "reboiser",
    "reboisera": "reboiser",
    "reboiserai": "reboiser",
    "reboiseraient": "reboiser",
    "reboiserais": "reboiser",
    "reboiserait": "reboiser",
    "reboiseras": "reboiser",
    "reboiserez": "reboiser",
    "reboiseriez": "reboiser",
    "reboiserions": "reboiser",
    "reboiserons": "reboiser",
    "reboiseront": "reboiser",
    "reboises": "reboiser",
    "reboisez": "reboiser",
    "reboisiez": "reboiser",
    "reboisions": "reboiser",
    "reboisons": "reboiser",
    "reboisâmes": "reboiser",
    "reboisât": "reboiser",
    "reboisâtes": "reboiser",
    "reboisèrent": "reboiser",
    "reboisé": "reboiser",
    "reboisée": "reboiser",
    "reboisées": "reboiser",
    "reboisés": "reboiser",
    "reboit": "reboire",
    "rebondi": "rebondir",
    "rebondie": "rebondir",
    "rebondies": "rebondir",
    "rebondira": "rebondir",
    "rebondirai": "rebondir",
    "rebondiraient": "rebondir",
    "rebondirais": "rebondir",
    "rebondirait": "rebondir",
    "rebondiras": "rebondir",
    "rebondirent": "rebondir",
    "rebondirez": "rebondir",
    "rebondiriez": "rebondir",
    "rebondirions": "rebondir",
    "rebondirons": "rebondir",
    "rebondiront": "rebondir",
    "rebondis": "rebondir",
    "rebondissaient": "rebondir",
    "rebondissais": "rebondir",
    "rebondissait": "rebondir",
    "rebondissant": "rebondir",
    "rebondissante": "rebondissant",
    "rebondissantes": "rebondissant",
    "rebondissants": "rebondissant",
    "rebondisse": "rebondir",
    "rebondissements": "rebondissement",
    "rebondissent": "rebondir",
    "rebondisses": "rebondir",
    "rebondissez": "rebondir",
    "rebondissiez": "rebondir",
    "rebondissions": "rebondir",
    "rebondissons": "rebondir",
    "rebondit": "rebondir",
    "rebonds": "rebond",
    "rebondîmes": "rebondir",
    "rebondît": "rebondir",
    "rebondîtes": "rebondir",
    "reborda": "reborder",
    "rebordai": "reborder",
    "rebordaient": "reborder",
    "rebordais": "reborder",
    "rebordait": "reborder",
    "rebordant": "reborder",
    "rebordas": "reborder",
    "rebordasse": "reborder",
    "rebordassent": "reborder",
    "rebordasses": "reborder",
    "rebordassiez": "reborder",
    "rebordassions": "reborder",
    "reborde": "reborder",
    "rebordent": "reborder",
    "rebordera": "reborder",
    "reborderai": "reborder",
    "reborderaient": "reborder",
    "reborderais": "reborder",
    "reborderait": "reborder",
    "reborderas": "reborder",
    "reborderez": "reborder",
    "reborderiez": "reborder",
    "reborderions": "reborder",
    "reborderons": "reborder",
    "reborderont": "reborder",
    "rebordes": "reborder",
    "rebordez": "reborder",
    "rebordiez": "reborder",
    "rebordions": "reborder",
    "rebordons": "reborder",
    "rebords": "rebord",
    "rebordâmes": "reborder",
    "rebordât": "reborder",
    "rebordâtes": "reborder",
    "rebordèrent": "reborder",
    "rebordé": "reborder",
    "rebordée": "reborder",
    "rebordées": "reborder",
    "rebordés": "reborder",
    "reboucha": "reboucher",
    "rebouchai": "reboucher",
    "rebouchaient": "reboucher",
    "rebouchais": "reboucher",
    "rebouchait": "reboucher",
    "rebouchant": "reboucher",
    "rebouchas": "reboucher",
    "rebouchasse": "reboucher",
    "rebouchassent": "reboucher",
    "rebouchasses": "reboucher",
    "rebouchassiez": "reboucher",
    "rebouchassions": "reboucher",
    "rebouche": "reboucher",
    "rebouchent": "reboucher",
    "rebouchera": "reboucher",
    "reboucherai": "reboucher",
    "reboucheraient": "reboucher",
    "reboucherais": "reboucher",
    "reboucherait": "reboucher",
    "reboucheras": "reboucher",
    "reboucherez": "reboucher",
    "reboucheriez": "reboucher",
    "reboucherions": "reboucher",
    "reboucherons": "reboucher",
    "reboucheront": "reboucher",
    "rebouches": "reboucher",
    "rebouchez": "reboucher",
    "rebouchiez": "reboucher",
    "rebouchions": "reboucher",
    "rebouchons": "reboucher",
    "rebouchâmes": "reboucher",
    "rebouchât": "reboucher",
    "rebouchâtes": "reboucher",
    "rebouchèrent": "reboucher",
    "rebouché": "reboucher",
    "rebouchée": "reboucher",
    "rebouchées": "reboucher",
    "rebouchés": "reboucher",
    "reboucla": "reboucler",
    "reboucle": "reboucler",
    "rebouclé": "reboucler",
    "rebouclée": "reboucler",
    "rebouillaient": "rebouillir",
    "rebouillais": "rebouillir",
    "rebouillait": "rebouillir",
    "rebouillant": "rebouillir",
    "rebouille": "rebouillir",
    "rebouillent": "rebouillir",
    "rebouilles": "rebouillir",
    "rebouillez": "rebouillir",
    "rebouilli": "rebouillir",
    "rebouillie": "rebouillir",
    "rebouillies": "rebouillir",
    "rebouilliez": "rebouillir",
    "rebouillions": "rebouillir",
    "rebouillira": "rebouillir",
    "rebouillirai": "rebouillir",
    "rebouilliraient": "rebouillir",
    "rebouillirais": "rebouillir",
    "rebouillirait": "rebouillir",
    "rebouilliras": "rebouillir",
    "rebouillirent": "rebouillir",
    "rebouillirez": "rebouillir",
    "rebouilliriez": "rebouillir",
    "rebouillirions": "rebouillir",
    "rebouillirons": "rebouillir",
    "rebouilliront": "rebouillir",
    "rebouillis": "rebouillir",
    "rebouillisse": "rebouillir",
    "rebouillissent": "rebouillir",
    "rebouillisses": "rebouillir",
    "rebouillissiez": "rebouillir",
    "rebouillissions": "rebouillir",
    "rebouillit": "rebouillir",
    "rebouillons": "rebouillir",
    "rebouillîmes": "rebouillir",
    "rebouillît": "rebouillir",
    "rebouillîtes": "rebouillir",
    "rebous": "rebouillir",
    "rebout": "rebouillir",
    "rebouta": "rebouter",
    "reboutai": "rebouter",
    "reboutaient": "rebouter",
    "reboutais": "rebouter",
    "reboutait": "rebouter",
    "reboutant": "rebouter",
    "reboutas": "rebouter",
    "reboutasse": "rebouter",
    "reboutassent": "rebouter",
    "reboutasses": "rebouter",
    "reboutassiez": "rebouter",
    "reboutassions": "rebouter",
    "reboute": "rebouter",
    "reboutent": "rebouter",
    "reboutera": "rebouter",
    "rebouterai": "rebouter",
    "rebouteraient": "rebouter",
    "rebouterais": "rebouter",
    "rebouterait": "rebouter",
    "rebouteras": "rebouter",
    "rebouterez": "rebouter",
    "rebouteriez": "rebouter",
    "rebouterions": "rebouter",
    "rebouterons": "rebouter",
    "rebouteront": "rebouter",
    "reboutes": "rebouter",
    "rebouteuse": "rebouteux",
    "rebouteuses": "rebouteux",
    "reboutez": "rebouter",
    "reboutiez": "rebouter",
    "reboutions": "rebouter",
    "reboutonna": "reboutonner",
    "reboutonnai": "reboutonner",
    "reboutonnaient": "reboutonner",
    "reboutonnais": "reboutonner",
    "reboutonnait": "reboutonner",
    "reboutonnant": "reboutonner",
    "reboutonnas": "reboutonner",
    "reboutonnasse": "reboutonner",
    "reboutonnassent": "reboutonner",
    "reboutonnasses": "reboutonner",
    "reboutonnassiez": "reboutonner",
    "reboutonnassions": "reboutonner",
    "reboutonne": "reboutonner",
    "reboutonnent": "reboutonner",
    "reboutonnera": "reboutonner",
    "reboutonnerai": "reboutonner",
    "reboutonneraient": "reboutonner",
    "reboutonnerais": "reboutonner",
    "reboutonnerait": "reboutonner",
    "reboutonneras": "reboutonner",
    "reboutonnerez": "reboutonner",
    "reboutonneriez": "reboutonner",
    "reboutonnerions": "reboutonner",
    "reboutonnerons": "reboutonner",
    "reboutonneront": "reboutonner",
    "reboutonnes": "reboutonner",
    "reboutonnez": "reboutonner",
    "reboutonniez": "reboutonner",
    "reboutonnions": "reboutonner",
    "reboutonnons": "reboutonner",
    "reboutonnâmes": "reboutonner",
    "reboutonnât": "reboutonner",
    "reboutonnâtes": "reboutonner",
    "reboutonnèrent": "reboutonner",
    "reboutonné": "reboutonner",
    "reboutonnée": "reboutonner",
    "reboutonnées": "reboutonner",
    "reboutonnés": "reboutonner",
    "reboutons": "rebouter",
    "reboutâmes": "rebouter",
    "reboutât": "rebouter",
    "reboutâtes": "rebouter",
    "reboutèrent": "rebouter",
    "rebouté": "rebouter",
    "reboutée": "rebouter",
    "reboutées": "rebouter",
    "reboutés": "rebouter",
    "rebraguetté": "rebraguetter",
    "rebrancha": "rebrancher",
    "rebranche": "rebrancher",
    "rebranchez": "rebrancher",
    "rebranché": "rebrancher",
    "rebranchée": "rebrancher",
    "rebroda": "rebroder",
    "rebrodai": "rebroder",
    "rebrodaient": "rebroder",
    "rebrodais": "rebroder",
    "rebrodait": "rebroder",
    "rebrodant": "rebroder",
    "rebrodas": "rebroder",
    "rebrodasse": "rebroder",
    "rebrodassent": "rebroder",
    "rebrodasses": "rebroder",
    "rebrodassiez": "rebroder",
    "rebrodassions": "rebroder",
    "rebrode": "rebroder",
    "rebrodent": "rebroder",
    "rebrodera": "rebroder",
    "rebroderai": "rebroder",
    "rebroderaient": "rebroder",
    "rebroderais": "rebroder",
    "rebroderait": "rebroder",
    "rebroderas": "rebroder",
    "rebroderez": "rebroder",
    "rebroderiez": "rebroder",
    "rebroderions": "rebroder",
    "rebroderons": "rebroder",
    "rebroderont": "rebroder",
    "rebrodes": "rebroder",
    "rebrodez": "rebroder",
    "rebrodiez": "rebroder",
    "rebrodions": "rebroder",
    "rebrodons": "rebroder",
    "rebrodâmes": "rebroder",
    "rebrodât": "rebroder",
    "rebrodâtes": "rebroder",
    "rebrodèrent": "rebroder",
    "rebrodé": "rebroder",
    "rebrodée": "rebroder",
    "rebrodées": "rebroder",
    "rebrodés": "rebroder",
    "rebroussa": "rebrousser",
    "rebroussai": "rebrousser",
    "rebroussaient": "rebrousser",
    "rebroussais": "rebrousser",
    "rebroussait": "rebrousser",
    "rebroussant": "rebrousser",
    "rebroussas": "rebrousser",
    "rebroussasse": "rebrousser",
    "rebroussassent": "rebrousser",
    "rebroussasses": "rebrousser",
    "rebroussassiez": "rebrousser",
    "rebroussassions": "rebrousser",
    "rebrousse": "rebrousser",
    "rebroussements": "rebroussement",
    "rebroussent": "rebrousser",
    "rebroussera": "rebrousser",
    "rebrousserai": "rebrousser",
    "rebrousseraient": "rebrousser",
    "rebrousserais": "rebrousser",
    "rebrousserait": "rebrousser",
    "rebrousseras": "rebrousser",
    "rebrousserez": "rebrousser",
    "rebrousseriez": "rebrousser",
    "rebrousserions": "rebrousser",
    "rebrousserons": "rebrousser",
    "rebrousseront": "rebrousser",
    "rebrousses": "rebrousser",
    "rebroussez": "rebrousser",
    "rebroussiez": "rebrousser",
    "rebroussions": "rebrousser",
    "rebroussons": "rebrousser",
    "rebroussâmes": "rebrousser",
    "rebroussât": "rebrousser",
    "rebroussâtes": "rebrousser",
    "rebroussèrent": "rebrousser",
    "rebroussé": "rebrousser",
    "rebroussée": "rebrousser",
    "rebroussées": "rebrousser",
    "rebroussés": "rebrousser",
    "rebrûlé": "rebrûler",
    "rebu": "reboire",
    "rebuffades": "rebuffade",
    "rebus": "reboire",
    "rebut": "reboire",
    "rebuta": "rebuter",
    "rebutai": "rebuter",
    "rebutaient": "rebuter",
    "rebutais": "rebuter",
    "rebutait": "rebuter",
    "rebutant": "rebuter",
    "rebutante": "rebutant",
    "rebutantes": "rebutant",
    "rebutants": "rebutant",
    "rebutas": "rebuter",
    "rebutasse": "rebuter",
    "rebutassent": "rebuter",
    "rebutasses": "rebuter",
    "rebutassiez": "rebuter",
    "rebutassions": "rebuter",
    "rebute": "rebuter",
    "rebutent": "rebuter",
    "rebutera": "rebuter",
    "rebuterai": "rebuter",
    "rebuteraient": "rebuter",
    "rebuterais": "rebuter",
    "rebuterait": "rebuter",
    "rebuteras": "rebuter",
    "rebuterez": "rebuter",
    "rebuteriez": "rebuter",
    "rebuterions": "rebuter",
    "rebuterons": "rebuter",
    "rebuteront": "rebuter",
    "rebutes": "rebuter",
    "rebutez": "rebuter",
    "rebutiez": "rebuter",
    "rebutions": "rebuter",
    "rebutons": "rebuter",
    "rebuts": "rebut",
    "rebutâmes": "rebuter",
    "rebutât": "rebuter",
    "rebutâtes": "rebuter",
    "rebutèrent": "rebuter",
    "rebuté": "rebuter",
    "rebutée": "rebuter",
    "rebutées": "rebuter",
    "rebutés": "rebuter",
    "rebuvait": "reboire",
    "rebâti": "rebâtir",
    "rebâtie": "rebâtir",
    "rebâties": "rebâtir",
    "rebâtira": "rebâtir",
    "rebâtirai": "rebâtir",
    "rebâtiraient": "rebâtir",
    "rebâtirais": "rebâtir",
    "rebâtirait": "rebâtir",
    "rebâtiras": "rebâtir",
    "rebâtirent": "rebâtir",
    "rebâtirez": "rebâtir",
    "rebâtiriez": "rebâtir",
    "rebâtirions": "rebâtir",
    "rebâtirons": "rebâtir",
    "rebâtiront": "rebâtir",
    "rebâtis": "rebâtir",
    "rebâtissaient": "rebâtir",
    "rebâtissais": "rebâtir",
    "rebâtissait": "rebâtir",
    "rebâtissant": "rebâtir",
    "rebâtisse": "rebâtir",
    "rebâtissent": "rebâtir",
    "rebâtisses": "rebâtir",
    "rebâtissez": "rebâtir",
    "rebâtissiez": "rebâtir",
    "rebâtissions": "rebâtir",
    "rebâtissons": "rebâtir",
    "rebâtit": "rebâtir",
    "rebâtîmes": "rebâtir",
    "rebâtît": "rebâtir",
    "rebâtîtes": "rebâtir",
    "recache": "recacher",
    "recacheta": "recacheter",
    "recachetai": "recacheter",
    "recachetaient": "recacheter",
    "recachetais": "recacheter",
    "recachetait": "recacheter",
    "recachetant": "recacheter",
    "recachetas": "recacheter",
    "recachetasse": "recacheter",
    "recachetassent": "recacheter",
    "recachetasses": "recacheter",
    "recachetassiez": "recacheter",
    "recachetassions": "recacheter",
    "recachetez": "recacheter",
    "recachetiez": "recacheter",
    "recachetions": "recacheter",
    "recachetons": "recacheter",
    "recachette": "recacheter",
    "recachettent": "recacheter",
    "recachettera": "recacheter",
    "recachetterai": "recacheter",
    "recachetteraient": "recacheter",
    "recachetterais": "recacheter",
    "recachetterait": "recacheter",
    "recachetteras": "recacheter",
    "recachetterez": "recacheter",
    "recachetteriez": "recacheter",
    "recachetterions": "recacheter",
    "recachetterons": "recacheter",
    "recachetteront": "recacheter",
    "recachettes": "recacheter",
    "recachetâmes": "recacheter",
    "recachetât": "recacheter",
    "recachetâtes": "recacheter",
    "recachetèrent": "recacheter",
    "recacheté": "recacheter",
    "recachetée": "recacheter",
    "recachetées": "recacheter",
    "recachetés": "recacheter",
    "recadre": "recadrer",
    "recadrez": "recadrer",
    "recala": "recaler",
    "recalai": "recaler",
    "recalaient": "recaler",
    "recalais": "recaler",
    "recalait": "recaler",
    "recalant": "recaler",
    "recalas": "recaler",
    "recalasse": "recaler",
    "recalassent": "recaler",
    "recalasses": "recaler",
    "recalassiez": "recaler",
    "recalassions": "recaler",
    "recalculant": "recalculer",
    "recalcule": "recalculer",
    "recalculez": "recalculer",
    "recalculé": "recalculer",
    "recale": "recaler",
    "recalent": "recaler",
    "recalera": "recaler",
    "recalerai": "recaler",
    "recaleraient": "recaler",
    "recalerais": "recaler",
    "recalerait": "recaler",
    "recaleras": "recaler",
    "recalerez": "recaler",
    "recaleriez": "recaler",
    "recalerions": "recaler",
    "recalerons": "recaler",
    "recaleront": "recaler",
    "recales": "recaler",
    "recalez": "recaler",
    "recaliez": "recaler",
    "recalions": "recaler",
    "recalons": "recaler",
    "recalâmes": "recaler",
    "recalât": "recaler",
    "recalâtes": "recaler",
    "recalèrent": "recaler",
    "recalé": "recaler",
    "recalée": "recaler",
    "recalées": "recaler",
    "recalés": "recaler",
    "recapitalisations": "recapitalisation",
    "recarrela": "recarreler",
    "recarrelai": "recarreler",
    "recarrelaient": "recarreler",
    "recarrelais": "recarreler",
    "recarrelait": "recarreler",
    "recarrelant": "recarreler",
    "recarrelas": "recarreler",
    "recarrelasse": "recarreler",
    "recarrelassent": "recarreler",
    "recarrelasses": "recarreler",
    "recarrelassiez": "recarreler",
    "recarrelassions": "recarreler",
    "recarrelez": "recarreler",
    "recarreliez": "recarreler",
    "recarrelions": "recarreler",
    "recarrelle": "recarreler",
    "recarrellent": "recarreler",
    "recarrellera": "recarreler",
    "recarrellerai": "recarreler",
    "recarrelleraient": "recarreler",
    "recarrellerais": "recarreler",
    "recarrellerait": "recarreler",
    "recarrelleras": "recarreler",
    "recarrellerez": "recarreler",
    "recarrelleriez": "recarreler",
    "recarrellerions": "recarreler",
    "recarrellerons": "recarreler",
    "recarrelleront": "recarreler",
    "recarrelles": "recarreler",
    "recarrelons": "recarreler",
    "recarrelâmes": "recarreler",
    "recarrelât": "recarreler",
    "recarrelâtes": "recarreler",
    "recarrelèrent": "recarreler",
    "recarrelé": "recarreler",
    "recarrelée": "recarreler",
    "recarrelées": "recarreler",
    "recarrelés": "recarreler",
    "recasa": "recaser",
    "recasai": "recaser",
    "recasaient": "recaser",
    "recasais": "recaser",
    "recasait": "recaser",
    "recasant": "recaser",
    "recasas": "recaser",
    "recasasse": "recaser",
    "recasassent": "recaser",
    "recasasses": "recaser",
    "recasassiez": "recaser",
    "recasassions": "recaser",
    "recase": "recaser",
    "recasent": "recaser",
    "recasera": "recaser",
    "recaserai": "recaser",
    "recaseraient": "recaser",
    "recaserais": "recaser",
    "recaserait": "recaser",
    "recaseras": "recaser",
    "recaserez": "recaser",
    "recaseriez": "recaser",
    "recaserions": "recaser",
    "recaserons": "recaser",
    "recaseront": "recaser",
    "recases": "recaser",
    "recasez": "recaser",
    "recasiez": "recaser",
    "recasions": "recaser",
    "recasons": "recaser",
    "recasses": "recasser",
    "recassé": "recasser",
    "recassée": "recasser",
    "recasâmes": "recaser",
    "recasât": "recaser",
    "recasâtes": "recaser",
    "recasèrent": "recaser",
    "recasé": "recaser",
    "recasée": "recaser",
    "recasées": "recaser",
    "recasés": "recaser",
    "recausa": "recauser",
    "recausai": "recauser",
    "recausaient": "recauser",
    "recausais": "recauser",
    "recausait": "recauser",
    "recausant": "recauser",
    "recausas": "recauser",
    "recausasse": "recauser",
    "recausassent": "recauser",
    "recausasses": "recauser",
    "recausassiez": "recauser",
    "recausassions": "recauser",
    "recause": "recauser",
    "recausent": "recauser",
    "recausera": "recauser",
    "recauserai": "recauser",
    "recauseraient": "recauser",
    "recauserais": "recauser",
    "recauserait": "recauser",
    "recauseras": "recauser",
    "recauserez": "recauser",
    "recauseriez": "recauser",
    "recauserions": "recauser",
    "recauserons": "recauser",
    "recauseront": "recauser",
    "recauses": "recauser",
    "recausez": "recauser",
    "recausiez": "recauser",
    "recausions": "recauser",
    "recausons": "recauser",
    "recausâmes": "recauser",
    "recausât": "recauser",
    "recausâtes": "recauser",
    "recausèrent": "recauser",
    "recausé": "recauser",
    "recela": "receler",
    "recelai": "receler",
    "recelaient": "receler",
    "recelais": "receler",
    "recelait": "receler",
    "recelant": "receler",
    "recelas": "receler",
    "recelasse": "receler",
    "recelassent": "receler",
    "recelasses": "receler",
    "recelassiez": "receler",
    "recelassions": "receler",
    "receleurs": "receleur",
    "receleuse": "receleur",
    "receleuses": "receleur",
    "recelez": "receler",
    "receliez": "receler",
    "recelions": "receler",
    "recelons": "receler",
    "recels": "recel",
    "recelâmes": "receler",
    "recelât": "receler",
    "recelâtes": "receler",
    "recelèrent": "receler",
    "recelé": "receler",
    "recelée": "receler",
    "recelées": "receler",
    "recelés": "receler",
    "recensa": "recenser",
    "recensai": "recenser",
    "recensaient": "recenser",
    "recensais": "recenser",
    "recensait": "recenser",
    "recensant": "recenser",
    "recensas": "recenser",
    "recensasse": "recenser",
    "recensassent": "recenser",
    "recensasses": "recenser",
    "recensassiez": "recenser",
    "recensassions": "recenser",
    "recense": "recenser",
    "recensements": "recensement",
    "recensent": "recenser",
    "recensera": "recenser",
    "recenserai": "recenser",
    "recenseraient": "recenser",
    "recenserais": "recenser",
    "recenserait": "recenser",
    "recenseras": "recenser",
    "recenserez": "recenser",
    "recenseriez": "recenser",
    "recenserions": "recenser",
    "recenserons": "recenser",
    "recenseront": "recenser",
    "recenses": "recenser",
    "recensez": "recenser",
    "recensiez": "recenser",
    "recensions": "recension",
    "recensons": "recenser",
    "recensâmes": "recenser",
    "recensât": "recenser",
    "recensâtes": "recenser",
    "recensèrent": "recenser",
    "recensé": "recenser",
    "recensée": "recenser",
    "recensées": "recenser",
    "recensés": "recenser",
    "recentra": "recentrer",
    "recentrages": "recentrage",
    "recentrai": "recentrer",
    "recentraient": "recentrer",
    "recentrais": "recentrer",
    "recentrait": "recentrer",
    "recentrant": "recentrer",
    "recentras": "recentrer",
    "recentrasse": "recentrer",
    "recentrassent": "recentrer",
    "recentrasses": "recentrer",
    "recentrassiez": "recentrer",
    "recentrassions": "recentrer",
    "recentre": "recentrer",
    "recentrent": "recentrer",
    "recentrera": "recentrer",
    "recentrerai": "recentrer",
    "recentreraient": "recentrer",
    "recentrerais": "recentrer",
    "recentrerait": "recentrer",
    "recentreras": "recentrer",
    "recentrerez": "recentrer",
    "recentreriez": "recentrer",
    "recentrerions": "recentrer",
    "recentrerons": "recentrer",
    "recentreront": "recentrer",
    "recentres": "recentrer",
    "recentrez": "recentrer",
    "recentriez": "recentrer",
    "recentrions": "recentrer",
    "recentrons": "recentrer",
    "recentrâmes": "recentrer",
    "recentrât": "recentrer",
    "recentrâtes": "recentrer",
    "recentrèrent": "recentrer",
    "recentré": "recentrer",
    "recentrée": "recentrer",
    "recentrées": "recentrer",
    "recentrés": "recentrer",
    "recepa": "receper",
    "recepai": "receper",
    "recepaient": "receper",
    "recepais": "receper",
    "recepait": "receper",
    "recepant": "receper",
    "recepas": "receper",
    "recepasse": "receper",
    "recepassent": "receper",
    "recepasses": "receper",
    "recepassiez": "receper",
    "recepassions": "receper",
    "recepez": "receper",
    "recepiez": "receper",
    "recepions": "receper",
    "recepons": "receper",
    "recepâmes": "receper",
    "recepât": "receper",
    "recepâtes": "receper",
    "recepèrent": "receper",
    "recepé": "receper",
    "recepée": "receper",
    "recepées": "receper",
    "recepés": "receper",
    "recercla": "recercler",
    "recerclai": "recercler",
    "recerclaient": "recercler",
    "recerclais": "recercler",
    "recerclait": "recercler",
    "recerclant": "recercler",
    "recerclas": "recercler",
    "recerclasse": "recercler",
    "recerclassent": "recercler",
    "recerclasses": "recercler",
    "recerclassiez": "recercler",
    "recerclassions": "recercler",
    "recercle": "recercler",
    "recerclent": "recercler",
    "recerclera": "recercler",
    "recerclerai": "recercler",
    "recercleraient": "recercler",
    "recerclerais": "recercler",
    "recerclerait": "recercler",
    "recercleras": "recercler",
    "recerclerez": "recercler",
    "recercleriez": "recercler",
    "recerclerions": "recercler",
    "recerclerons": "recercler",
    "recercleront": "recercler",
    "recercles": "recercler",
    "recerclez": "recercler",
    "recercliez": "recercler",
    "recerclions": "recercler",
    "recerclons": "recercler",
    "recerclâmes": "recercler",
    "recerclât": "recercler",
    "recerclâtes": "recercler",
    "recerclèrent": "recercler",
    "recerclé": "recercler",
    "recerclée": "recercler",
    "recerclées": "recercler",
    "recerclés": "recercler",
    "recettes": "recette",
    "recevables": "recevable",
    "recevaient": "recevoir",
    "recevais": "recevoir",
    "recevait": "recevoir",
    "recevant": "recevoir",
    "receveurs": "receveur",
    "receveuse": "receveur",
    "receveuses": "receveur",
    "recevez": "recevoir",
    "receviez": "recevoir",
    "recevions": "recevoir",
    "recevons": "recevoir",
    "recevra": "recevoir",
    "recevrai": "recevoir",
    "recevraient": "recevoir",
    "recevrais": "recevoir",
    "recevrait": "recevoir",
    "recevras": "recevoir",
    "recevrez": "recevoir",
    "recevriez": "recevoir",
    "recevrions": "recevoir",
    "recevrons": "recevoir",
    "recevront": "recevoir",
    "rechampis": "rechampir",
    "rechampit": "rechampir",
    "rechange": "rechanger",
    "rechangea": "rechanger",
    "rechangeai": "rechanger",
    "rechangeaient": "rechanger",
    "rechangeais": "rechanger",
    "rechangeait": "rechanger",
    "rechangeant": "rechanger",
    "rechangeas": "rechanger",
    "rechangeasse": "rechanger",
    "rechangeassent": "rechanger",
    "rechangeasses": "rechanger",
    "rechangeassiez": "rechanger",
    "rechangeassions": "rechanger",
    "rechangent": "rechanger",
    "rechangeons": "rechanger",
    "rechangera": "rechanger",
    "rechangerai": "rechanger",
    "rechangeraient": "rechanger",
    "rechangerais": "rechanger",
    "rechangerait": "rechanger",
    "rechangeras": "rechanger",
    "rechangerez": "rechanger",
    "rechangeriez": "rechanger",
    "rechangerions": "rechanger",
    "rechangerons": "rechanger",
    "rechangeront": "rechanger",
    "rechanges": "rechanger",
    "rechangez": "rechanger",
    "rechangeâmes": "rechanger",
    "rechangeât": "rechanger",
    "rechangeâtes": "rechanger",
    "rechangiez": "rechanger",
    "rechangions": "rechanger",
    "rechangèrent": "rechanger",
    "rechangé": "rechanger",
    "rechangée": "rechanger",
    "rechangées": "rechanger",
    "rechangés": "rechanger",
    "rechanta": "rechanter",
    "rechantai": "rechanter",
    "rechantaient": "rechanter",
    "rechantais": "rechanter",
    "rechantait": "rechanter",
    "rechantant": "rechanter",
    "rechantas": "rechanter",
    "rechantasse": "rechanter",
    "rechantassent": "rechanter",
    "rechantasses": "rechanter",
    "rechantassiez": "rechanter",
    "rechantassions": "rechanter",
    "rechante": "rechanter",
    "rechantent": "rechanter",
    "rechantera": "rechanter",
    "rechanterai": "rechanter",
    "rechanteraient": "rechanter",
    "rechanterais": "rechanter",
    "rechanterait": "rechanter",
    "rechanteras": "rechanter",
    "rechanterez": "rechanter",
    "rechanteriez": "rechanter",
    "rechanterions": "rechanter",
    "rechanterons": "rechanter",
    "rechanteront": "rechanter",
    "rechantes": "rechanter",
    "rechantez": "rechanter",
    "rechantiez": "rechanter",
    "rechantions": "rechanter",
    "rechantons": "rechanter",
    "rechantâmes": "rechanter",
    "rechantât": "rechanter",
    "rechantâtes": "rechanter",
    "rechantèrent": "rechanter",
    "rechanté": "rechanter",
    "rechantée": "rechanter",
    "rechantées": "rechanter",
    "rechantés": "rechanter",
    "rechapa": "rechaper",
    "rechapai": "rechaper",
    "rechapaient": "rechaper",
    "rechapais": "rechaper",
    "rechapait": "rechaper",
    "rechapant": "rechaper",
    "rechapas": "rechaper",
    "rechapasse": "rechaper",
    "rechapassent": "rechaper",
    "rechapasses": "rechaper",
    "rechapassiez": "rechaper",
    "rechapassions": "rechaper",
    "rechape": "rechaper",
    "rechapent": "rechaper",
    "rechapera": "rechaper",
    "rechaperai": "rechaper",
    "rechaperaient": "rechaper",
    "rechaperais": "rechaper",
    "rechaperait": "rechaper",
    "rechaperas": "rechaper",
    "rechaperez": "rechaper",
    "rechaperiez": "rechaper",
    "rechaperions": "rechaper",
    "rechaperons": "rechaper",
    "rechaperont": "rechaper",
    "rechapes": "rechaper",
    "rechapez": "rechaper",
    "rechapiez": "rechaper",
    "rechapions": "rechaper",
    "rechapons": "rechaper",
    "rechapâmes": "rechaper",
    "rechapât": "rechaper",
    "rechapâtes": "rechaper",
    "rechapèrent": "rechaper",
    "rechapé": "rechaper",
    "rechapée": "rechaper",
    "rechapées": "rechaper",
    "rechapés": "rechaper",
    "recharge": "recharger",
    "rechargea": "recharger",
    "rechargeai": "recharger",
    "rechargeaient": "recharger",
    "rechargeais": "recharger",
    "rechargeait": "recharger",
    "rechargeant": "recharger",
    "rechargeas": "recharger",
    "rechargeasse": "recharger",
    "rechargeassent": "recharger",
    "rechargeasses": "recharger",
    "rechargeassiez": "recharger",
    "rechargeassions": "recharger",
    "rechargent": "recharger",
    "rechargeons": "recharger",
    "rechargera": "recharger",
    "rechargerai": "recharger",
    "rechargeraient": "recharger",
    "rechargerais": "recharger",
    "rechargerait": "recharger",
    "rechargeras": "recharger",
    "rechargerez": "recharger",
    "rechargeriez": "recharger",
    "rechargerions": "recharger",
    "rechargerons": "recharger",
    "rechargeront": "recharger",
    "recharges": "recharger",
    "rechargez": "recharger",
    "rechargeâmes": "recharger",
    "rechargeât": "recharger",
    "rechargeâtes": "recharger",
    "rechargiez": "recharger",
    "rechargions": "recharger",
    "rechargèrent": "recharger",
    "rechargé": "recharger",
    "rechargée": "recharger",
    "rechargées": "recharger",
    "rechargés": "recharger",
    "rechassa": "rechasser",
    "rechassai": "rechasser",
    "rechassaient": "rechasser",
    "rechassais": "rechasser",
    "rechassait": "rechasser",
    "rechassant": "rechasser",
    "rechassas": "rechasser",
    "rechassasse": "rechasser",
    "rechassassent": "rechasser",
    "rechassasses": "rechasser",
    "rechassassiez": "rechasser",
    "rechassassions": "rechasser",
    "rechasse": "rechasser",
    "rechassent": "rechasser",
    "rechassera": "rechasser",
    "rechasserai": "rechasser",
    "rechasseraient": "rechasser",
    "rechasserais": "rechasser",
    "rechasserait": "rechasser",
    "rechasseras": "rechasser",
    "rechasserez": "rechasser",
    "rechasseriez": "rechasser",
    "rechasserions": "rechasser",
    "rechasserons": "rechasser",
    "rechasseront": "rechasser",
    "rechasses": "rechasser",
    "rechassez": "rechasser",
    "rechassiez": "rechasser",
    "rechassions": "rechasser",
    "rechassons": "rechasser",
    "rechassâmes": "rechasser",
    "rechassât": "rechasser",
    "rechassâtes": "rechasser",
    "rechassèrent": "rechasser",
    "rechassé": "rechasser",
    "rechassée": "rechasser",
    "rechassées": "rechasser",
    "rechassés": "rechasser",
    "rechaussa": "rechausser",
    "rechaussai": "rechausser",
    "rechaussaient": "rechausser",
    "rechaussais": "rechausser",
    "rechaussait": "rechausser",
    "rechaussant": "rechausser",
    "rechaussas": "rechausser",
    "rechaussasse": "rechausser",
    "rechaussassent": "rechausser",
    "rechaussasses": "rechausser",
    "rechaussassiez": "rechausser",
    "rechaussassions": "rechausser",
    "rechausse": "rechausser",
    "rechaussent": "rechausser",
    "rechaussera": "rechausser",
    "rechausserai": "rechausser",
    "rechausseraient": "rechausser",
    "rechausserais": "rechausser",
    "rechausserait": "rechausser",
    "rechausseras": "rechausser",
    "rechausserez": "rechausser",
    "rechausseriez": "rechausser",
    "rechausserions": "rechausser",
    "rechausserons": "rechausser",
    "rechausseront": "rechausser",
    "rechausses": "rechausser",
    "rechaussez": "rechausser",
    "rechaussiez": "rechausser",
    "rechaussions": "rechausser",
    "rechaussons": "rechausser",
    "rechaussâmes": "rechausser",
    "rechaussât": "rechausser",
    "rechaussâtes": "rechausser",
    "rechaussèrent": "rechausser",
    "rechaussé": "rechausser",
    "rechaussée": "rechausser",
    "rechaussées": "rechausser",
    "rechaussés": "rechausser",
    "rechercha": "rechercher",
    "recherchai": "rechercher",
    "recherchaient": "rechercher",
    "recherchais": "rechercher",
    "recherchait": "rechercher",
    "recherchant": "rechercher",
    "recherchas": "rechercher",
    "recherchasse": "rechercher",
    "recherchassent": "rechercher",
    "recherchasses": "rechercher",
    "recherchassiez": "rechercher",
    "recherchassions": "rechercher",
    "recherche": "rechercher",
    "recherchent": "rechercher",
    "recherchera": "rechercher",
    "rechercherai": "rechercher",
    "rechercheraient": "rechercher",
    "rechercherais": "rechercher",
    "rechercherait": "rechercher",
    "rechercheras": "rechercher",
    "rechercherez": "rechercher",
    "rechercheriez": "rechercher",
    "rechercherions": "rechercher",
    "rechercherons": "rechercher",
    "rechercheront": "rechercher",
    "recherches": "rechercher",
    "recherchez": "rechercher",
    "recherchiez": "rechercher",
    "recherchions": "rechercher",
    "recherchons": "rechercher",
    "recherchâmes": "rechercher",
    "recherchât": "rechercher",
    "recherchâtes": "rechercher",
    "recherchèrent": "rechercher",
    "recherché": "rechercher",
    "recherchée": "rechercher",
    "recherchées": "rechercher",
    "recherchés": "rechercher",
    "rechigna": "rechigner",
    "rechignai": "rechigner",
    "rechignaient": "rechigner",
    "rechignais": "rechigner",
    "rechignait": "rechigner",
    "rechignant": "rechigner",
    "rechignas": "rechigner",
    "rechignasse": "rechigner",
    "rechignassent": "rechigner",
    "rechignasses": "rechigner",
    "rechignassiez": "rechigner",
    "rechignassions": "rechigner",
    "rechigne": "rechigner",
    "rechignent": "rechigner",
    "rechignera": "rechigner",
    "rechignerai": "rechigner",
    "rechigneraient": "rechigner",
    "rechignerais": "rechigner",
    "rechignerait": "rechigner",
    "rechigneras": "rechigner",
    "rechignerez": "rechigner",
    "rechigneriez": "rechigner",
    "rechignerions": "rechigner",
    "rechignerons": "rechigner",
    "rechigneront": "rechigner",
    "rechignes": "rechigner",
    "rechignez": "rechigner",
    "rechigniez": "rechigner",
    "rechignions": "rechigner",
    "rechignons": "rechigner",
    "rechignâmes": "rechigner",
    "rechignât": "rechigner",
    "rechignâtes": "rechigner",
    "rechignèrent": "rechigner",
    "rechigné": "rechigner",
    "rechignée": "rechigner",
    "rechignées": "rechigner",
    "rechuta": "rechuter",
    "rechutai": "rechuter",
    "rechutaient": "rechuter",
    "rechutais": "rechuter",
    "rechutait": "rechuter",
    "rechutant": "rechuter",
    "rechutas": "rechuter",
    "rechutasse": "rechuter",
    "rechutassent": "rechuter",
    "rechutasses": "rechuter",
    "rechutassiez": "rechuter",
    "rechutassions": "rechuter",
    "rechute": "rechuter",
    "rechutent": "rechuter",
    "rechutera": "rechuter",
    "rechuterai": "rechuter",
    "rechuteraient": "rechuter",
    "rechuterais": "rechuter",
    "rechuterait": "rechuter",
    "rechuteras": "rechuter",
    "rechuterez": "rechuter",
    "rechuteriez": "rechuter",
    "rechuterions": "rechuter",
    "rechuterons": "rechuter",
    "rechuteront": "rechuter",
    "rechutes": "rechuter",
    "rechutez": "rechuter",
    "rechutiez": "rechuter",
    "rechutions": "rechuter",
    "rechutons": "rechuter",
    "rechutâmes": "rechuter",
    "rechutât": "rechuter",
    "rechutâtes": "rechuter",
    "rechutèrent": "rechuter",
    "rechuté": "rechuter",
    "rechutée": "rechuter",
    "rechutées": "rechuter",
    "rechutés": "rechuter",
    "reclassa": "reclasser",
    "reclassai": "reclasser",
    "reclassaient": "reclasser",
    "reclassais": "reclasser",
    "reclassait": "reclasser",
    "reclassant": "reclasser",
    "reclassas": "reclasser",
    "reclassasse": "reclasser",
    "reclassassent": "reclasser",
    "reclassasses": "reclasser",
    "reclassassiez": "reclasser",
    "reclassassions": "reclasser",
    "reclasse": "reclasser",
    "reclassements": "reclassement",
    "reclassent": "reclasser",
    "reclassera": "reclasser",
    "reclasserai": "reclasser",
    "reclasseraient": "reclasser",
    "reclasserais": "reclasser",
    "reclasserait": "reclasser",
    "reclasseras": "reclasser",
    "reclasserez": "reclasser",
    "reclasseriez": "reclasser",
    "reclasserions": "reclasser",
    "reclasserons": "reclasser",
    "reclasseront": "reclasser",
    "reclasses": "reclasser",
    "reclassez": "reclasser",
    "reclassiez": "reclasser",
    "reclassions": "reclasser",
    "reclassons": "reclasser",
    "reclassâmes": "reclasser",
    "reclassât": "reclasser",
    "reclassâtes": "reclasser",
    "reclassèrent": "reclasser",
    "reclassé": "reclasser",
    "reclassée": "reclasser",
    "reclassées": "reclasser",
    "reclassés": "reclasser",
    "recloua": "reclouer",
    "reclouai": "reclouer",
    "reclouaient": "reclouer",
    "reclouais": "reclouer",
    "reclouait": "reclouer",
    "reclouant": "reclouer",
    "reclouas": "reclouer",
    "reclouasse": "reclouer",
    "reclouassent": "reclouer",
    "reclouasses": "reclouer",
    "reclouassiez": "reclouer",
    "reclouassions": "reclouer",
    "recloue": "reclouer",
    "reclouent": "reclouer",
    "reclouera": "reclouer",
    "reclouerai": "reclouer",
    "recloueraient": "reclouer",
    "reclouerais": "reclouer",
    "reclouerait": "reclouer",
    "recloueras": "reclouer",
    "reclouerez": "reclouer",
    "recloueriez": "reclouer",
    "reclouerions": "reclouer",
    "reclouerons": "reclouer",
    "recloueront": "reclouer",
    "recloues": "reclouer",
    "reclouez": "reclouer",
    "reclouiez": "reclouer",
    "reclouions": "reclouer",
    "reclouons": "reclouer",
    "reclouâmes": "reclouer",
    "reclouât": "reclouer",
    "reclouâtes": "reclouer",
    "reclouèrent": "reclouer",
    "recloué": "reclouer",
    "reclouée": "reclouer",
    "reclouées": "reclouer",
    "recloués": "reclouer",
    "reclus": "reclure",
    "recluse": "reclus",
    "recluses": "reclus",
    "recoiffa": "recoiffer",
    "recoiffai": "recoiffer",
    "recoiffaient": "recoiffer",
    "recoiffais": "recoiffer",
    "recoiffait": "recoiffer",
    "recoiffant": "recoiffer",
    "recoiffas": "recoiffer",
    "recoiffasse": "recoiffer",
    "recoiffassent": "recoiffer",
    "recoiffasses": "recoiffer",
    "recoiffassiez": "recoiffer",
    "recoiffassions": "recoiffer",
    "recoiffe": "recoiffer",
    "recoiffent": "recoiffer",
    "recoiffera": "recoiffer",
    "recoifferai": "recoiffer",
    "recoifferaient": "recoiffer",
    "recoifferais": "recoiffer",
    "recoifferait": "recoiffer",
    "recoifferas": "recoiffer",
    "recoifferez": "recoiffer",
    "recoifferiez": "recoiffer",
    "recoifferions": "recoiffer",
    "recoifferons": "recoiffer",
    "recoifferont": "recoiffer",
    "recoiffes": "recoiffer",
    "recoiffez": "recoiffer",
    "recoiffiez": "recoiffer",
    "recoiffions": "recoiffer",
    "recoiffons": "recoiffer",
    "recoiffâmes": "recoiffer",
    "recoiffât": "recoiffer",
    "recoiffâtes": "recoiffer",
    "recoiffèrent": "recoiffer",
    "recoiffé": "recoiffer",
    "recoiffée": "recoiffer",
    "recoiffées": "recoiffer",
    "recoiffés": "recoiffer",
    "recoins": "recoin",
    "recolla": "recoller",
    "recollai": "recoller",
    "recollaient": "recoller",
    "recollais": "recoller",
    "recollait": "recoller",
    "recollant": "recoller",
    "recollas": "recoller",
    "recollasse": "recoller",
    "recollassent": "recoller",
    "recollasses": "recoller",
    "recollassiez": "recoller",
    "recollassions": "recoller",
    "recolle": "recoller",
    "recollent": "recoller",
    "recollera": "recoller",
    "recollerai": "recoller",
    "recolleraient": "recoller",
    "recollerais": "recoller",
    "recollerait": "recoller",
    "recolleras": "recoller",
    "recollerez": "recoller",
    "recolleriez": "recoller",
    "recollerions": "recoller",
    "recollerons": "recoller",
    "recolleront": "recoller",
    "recolles": "recoller",
    "recollez": "recoller",
    "recolliez": "recoller",
    "recollions": "recoller",
    "recollons": "recoller",
    "recollâmes": "recoller",
    "recollât": "recoller",
    "recollâtes": "recoller",
    "recollèrent": "recoller",
    "recollé": "recoller",
    "recollée": "recoller",
    "recollées": "recoller",
    "recollés": "recoller",
    "recolora": "recolorer",
    "recolorai": "recolorer",
    "recoloraient": "recolorer",
    "recolorais": "recolorer",
    "recolorait": "recolorer",
    "recolorant": "recolorer",
    "recoloras": "recolorer",
    "recolorasse": "recolorer",
    "recolorassent": "recolorer",
    "recolorasses": "recolorer",
    "recolorassiez": "recolorer",
    "recolorassions": "recolorer",
    "recolore": "recolorer",
    "recolorent": "recolorer",
    "recolorera": "recolorer",
    "recolorerai": "recolorer",
    "recoloreraient": "recolorer",
    "recolorerais": "recolorer",
    "recolorerait": "recolorer",
    "recoloreras": "recolorer",
    "recolorerez": "recolorer",
    "recoloreriez": "recolorer",
    "recolorerions": "recolorer",
    "recolorerons": "recolorer",
    "recoloreront": "recolorer",
    "recolores": "recolorer",
    "recolorez": "recolorer",
    "recoloriez": "recolorer",
    "recolorions": "recolorer",
    "recolorons": "recolorer",
    "recolorâmes": "recolorer",
    "recolorât": "recolorer",
    "recolorâtes": "recolorer",
    "recolorèrent": "recolorer",
    "recoloré": "recolorer",
    "recolorée": "recolorer",
    "recolorées": "recolorer",
    "recolorés": "recolorer",
    "recombinant": "recombiner",
    "recombiné": "recombiner",
    "recommanda": "recommander",
    "recommandables": "recommandable",
    "recommandai": "recommander",
    "recommandaient": "recommander",
    "recommandais": "recommander",
    "recommandait": "recommander",
    "recommandant": "recommander",
    "recommandas": "recommander",
    "recommandasse": "recommander",
    "recommandassent": "recommander",
    "recommandasses": "recommander",
    "recommandassiez": "recommander",
    "recommandassions": "recommander",
    "recommandations": "recommandation",
    "recommande": "recommander",
    "recommandent": "recommander",
    "recommandera": "recommander",
    "recommanderai": "recommander",
    "recommanderaient": "recommander",
    "recommanderais": "recommander",
    "recommanderait": "recommander",
    "recommanderas": "recommander",
    "recommanderez": "recommander",
    "recommanderiez": "recommander",
    "recommanderions": "recommander",
    "recommanderons": "recommander",
    "recommanderont": "recommander",
    "recommandes": "recommander",
    "recommandeurs": "recommandeur",
    "recommandez": "recommander",
    "recommandiez": "recommander",
    "recommandions": "recommander",
    "recommandons": "recommander",
    "recommandâmes": "recommander",
    "recommandât": "recommander",
    "recommandâtes": "recommander",
    "recommandèrent": "recommander",
    "recommandé": "recommander",
    "recommandée": "recommander",
    "recommandées": "recommander",
    "recommandés": "recommander",
    "recommence": "recommencer",
    "recommencements": "recommencement",
    "recommencent": "recommencer",
    "recommencera": "recommencer",
    "recommencerai": "recommencer",
    "recommenceraient": "recommencer",
    "recommencerais": "recommencer",
    "recommencerait": "recommencer",
    "recommenceras": "recommencer",
    "recommencerez": "recommencer",
    "recommenceriez": "recommencer",
    "recommencerions": "recommencer",
    "recommencerons": "recommencer",
    "recommenceront": "recommencer",
    "recommences": "recommencer",
    "recommencez": "recommencer",
    "recommenciez": "recommencer",
    "recommencions": "recommencer",
    "recommencèrent": "recommencer",
    "recommencé": "recommencer",
    "recommencée": "recommencer",
    "recommencées": "recommencer",
    "recommencés": "recommencer",
    "recommendations": "recommendation",
    "recommença": "recommencer",
    "recommençai": "recommencer",
    "recommençaient": "recommencer",
    "recommençais": "recommencer",
    "recommençait": "recommencer",
    "recommençant": "recommencer",
    "recommenças": "recommencer",
    "recommençasse": "recommencer",
    "recommençassent": "recommencer",
    "recommençasses": "recommencer",
    "recommençassiez": "recommencer",
    "recommençassions": "recommencer",
    "recommençons": "recommencer",
    "recommençâmes": "recommencer",
    "recommençât": "recommencer",
    "recommençâtes": "recommencer",
    "recomparais": "recomparaître",
    "recomparaissaient": "recomparaître",
    "recomparaissais": "recomparaître",
    "recomparaissait": "recomparaître",
    "recomparaissant": "recomparaître",
    "recomparaisse": "recomparaître",
    "recomparaissent": "recomparaître",
    "recomparaisses": "recomparaître",
    "recomparaissez": "recomparaître",
    "recomparaissiez": "recomparaître",
    "recomparaissions": "recomparaître",
    "recomparaissons": "recomparaître",
    "recomparaît": "recomparaître",
    "recomparaîtra": "recomparaître",
    "recomparaîtrai": "recomparaître",
    "recomparaîtraient": "recomparaître",
    "recomparaîtrais": "recomparaître",
    "recomparaîtrait": "recomparaître",
    "recomparaîtras": "recomparaître",
    "recomparaîtrez": "recomparaître",
    "recomparaîtriez": "recomparaître",
    "recomparaîtrions": "recomparaître",
    "recomparaîtrons": "recomparaître",
    "recomparaîtront": "recomparaître",
    "recomparu": "recomparaître",
    "recomparue": "recomparaître",
    "recomparues": "recomparaître",
    "recomparurent": "recomparaître",
    "recomparus": "recomparaître",
    "recomparusse": "recomparaître",
    "recomparussent": "recomparaître",
    "recomparusses": "recomparaître",
    "recomparussiez": "recomparaître",
    "recomparussions": "recomparaître",
    "recomparut": "recomparaître",
    "recomparûmes": "recomparaître",
    "recomparût": "recomparaître",
    "recomparûtes": "recomparaître",
    "recomplété": "recompléter",
    "recomposa": "recomposer",
    "recomposai": "recomposer",
    "recomposaient": "recomposer",
    "recomposais": "recomposer",
    "recomposait": "recomposer",
    "recomposant": "recomposer",
    "recomposas": "recomposer",
    "recomposasse": "recomposer",
    "recomposassent": "recomposer",
    "recomposasses": "recomposer",
    "recomposassiez": "recomposer",
    "recomposassions": "recomposer",
    "recompose": "recomposer",
    "recomposent": "recomposer",
    "recomposera": "recomposer",
    "recomposerai": "recomposer",
    "recomposeraient": "recomposer",
    "recomposerais": "recomposer",
    "recomposerait": "recomposer",
    "recomposeras": "recomposer",
    "recomposerez": "recomposer",
    "recomposeriez": "recomposer",
    "recomposerions": "recomposer",
    "recomposerons": "recomposer",
    "recomposeront": "recomposer",
    "recomposes": "recomposer",
    "recomposez": "recomposer",
    "recomposiez": "recomposer",
    "recomposions": "recomposer",
    "recompositions": "recomposition",
    "recomposons": "recomposer",
    "recomposâmes": "recomposer",
    "recomposât": "recomposer",
    "recomposâtes": "recomposer",
    "recomposèrent": "recomposer",
    "recomposé": "recomposer",
    "recomposée": "recomposer",
    "recomposées": "recomposer",
    "recomposés": "recomposer",
    "recompta": "recompter",
    "recomptai": "recompter",
    "recomptaient": "recompter",
    "recomptais": "recompter",
    "recomptait": "recompter",
    "recomptant": "recompter",
    "recomptas": "recompter",
    "recomptasse": "recompter",
    "recomptassent": "recompter",
    "recomptasses": "recompter",
    "recomptassiez": "recompter",
    "recomptassions": "recompter",
    "recompte": "recompter",
    "recomptent": "recompter",
    "recomptera": "recompter",
    "recompterai": "recompter",
    "recompteraient": "recompter",
    "recompterais": "recompter",
    "recompterait": "recompter",
    "recompteras": "recompter",
    "recompterez": "recompter",
    "recompteriez": "recompter",
    "recompterions": "recompter",
    "recompterons": "recompter",
    "recompteront": "recompter",
    "recomptes": "recompter",
    "recomptez": "recompter",
    "recomptiez": "recompter",
    "recomptions": "recompter",
    "recomptons": "recompter",
    "recomptâmes": "recompter",
    "recomptât": "recompter",
    "recomptâtes": "recompter",
    "recomptèrent": "recompter",
    "recompté": "recompter",
    "recomptée": "recompter",
    "recomptées": "recompter",
    "recomptés": "recompter",
    "recondamna": "recondamner",
    "recondamnai": "recondamner",
    "recondamnaient": "recondamner",
    "recondamnais": "recondamner",
    "recondamnait": "recondamner",
    "recondamnant": "recondamner",
    "recondamnas": "recondamner",
    "recondamnasse": "recondamner",
    "recondamnassent": "recondamner",
    "recondamnasses": "recondamner",
    "recondamnassiez": "recondamner",
    "recondamnassions": "recondamner",
    "recondamne": "recondamner",
    "recondamnent": "recondamner",
    "recondamnera": "recondamner",
    "recondamnerai": "recondamner",
    "recondamneraient": "recondamner",
    "recondamnerais": "recondamner",
    "recondamnerait": "recondamner",
    "recondamneras": "recondamner",
    "recondamnerez": "recondamner",
    "recondamneriez": "recondamner",
    "recondamnerions": "recondamner",
    "recondamnerons": "recondamner",
    "recondamneront": "recondamner",
    "recondamnes": "recondamner",
    "recondamnez": "recondamner",
    "recondamniez": "recondamner",
    "recondamnions": "recondamner",
    "recondamnons": "recondamner",
    "recondamnâmes": "recondamner",
    "recondamnât": "recondamner",
    "recondamnâtes": "recondamner",
    "recondamnèrent": "recondamner",
    "recondamné": "recondamner",
    "recondamnée": "recondamner",
    "recondamnées": "recondamner",
    "recondamnés": "recondamner",
    "reconditionne": "reconditionner",
    "reconditionnons": "reconditionner",
    "reconditionné": "reconditionner",
    "reconditionnée": "reconditionner",
    "reconductibles": "reconductible",
    "reconductions": "reconduction",
    "reconduira": "reconduire",
    "reconduirai": "reconduire",
    "reconduiraient": "reconduire",
    "reconduirais": "reconduire",
    "reconduirait": "reconduire",
    "reconduiras": "reconduire",
    "reconduirez": "reconduire",
    "reconduiriez": "reconduire",
    "reconduirions": "reconduire",
    "reconduirons": "reconduire",
    "reconduiront": "reconduire",
    "reconduis": "reconduire",
    "reconduisaient": "reconduire",
    "reconduisais": "reconduire",
    "reconduisait": "reconduire",
    "reconduisant": "reconduire",
    "reconduise": "reconduire",
    "reconduisent": "reconduire",
    "reconduises": "reconduire",
    "reconduisez": "reconduire",
    "reconduisiez": "reconduire",
    "reconduisions": "reconduire",
    "reconduisirent": "reconduire",
    "reconduisis": "reconduire",
    "reconduisisse": "reconduire",
    "reconduisissent": "reconduire",
    "reconduisisses": "reconduire",
    "reconduisissiez": "reconduire",
    "reconduisissions": "reconduire",
    "reconduisit": "reconduire",
    "reconduisons": "reconduire",
    "reconduisîmes": "reconduire",
    "reconduisît": "reconduire",
    "reconduisîtes": "reconduire",
    "reconduit": "reconduire",
    "reconduite": "reconduire",
    "reconduites": "reconduire",
    "reconduits": "reconduire",
    "reconfigure": "reconfigurer",
    "reconfigurez": "reconfigurer",
    "reconfiguré": "reconfigurer",
    "reconfigurés": "reconfigurer",
    "reconnais": "reconnaître",
    "reconnaissables": "reconnaissable",
    "reconnaissaient": "reconnaître",
    "reconnaissais": "reconnaître",
    "reconnaissait": "reconnaître",
    "reconnaissances": "reconnaissance",
    "reconnaissant": "reconnaître",
    "reconnaissante": "reconnaissant",
    "reconnaissantes": "reconnaissant",
    "reconnaissants": "reconnaissant",
    "reconnaisse": "reconnaître",
    "reconnaissent": "reconnaître",
    "reconnaisses": "reconnaître",
    "reconnaissez": "reconnaître",
    "reconnaissiez": "reconnaître",
    "reconnaissions": "reconnaître",
    "reconnaissons": "reconnaître",
    "reconnaît": "reconnaître",
    "reconnaîtra": "reconnaître",
    "reconnaîtrai": "reconnaître",
    "reconnaîtraient": "reconnaître",
    "reconnaîtrais": "reconnaître",
    "reconnaîtrait": "reconnaître",
    "reconnaîtras": "reconnaître",
    "reconnaîtrez": "reconnaître",
    "reconnaîtriez": "reconnaître",
    "reconnaîtrions": "reconnaître",
    "reconnaîtrons": "reconnaître",
    "reconnaîtront": "reconnaître",
    "reconnecte": "reconnecter",
    "reconnectez": "reconnecter",
    "reconnecté": "reconnecter",
    "reconnectés": "reconnecter",
    "reconnu": "reconnaître",
    "reconnue": "reconnu",
    "reconnues": "reconnu",
    "reconnurent": "reconnaître",
    "reconnus": "reconnu",
    "reconnusse": "reconnaître",
    "reconnussent": "reconnaître",
    "reconnusses": "reconnaître",
    "reconnussiez": "reconnaître",
    "reconnussions": "reconnaître",
    "reconnut": "reconnaître",
    "reconnûmes": "reconnaître",
    "reconnût": "reconnaître",
    "reconnûtes": "reconnaître",
    "reconquerra": "reconquérir",
    "reconquerrai": "reconquérir",
    "reconquerraient": "reconquérir",
    "reconquerrais": "reconquérir",
    "reconquerrait": "reconquérir",
    "reconquerras": "reconquérir",
    "reconquerrez": "reconquérir",
    "reconquerriez": "reconquérir",
    "reconquerrions": "reconquérir",
    "reconquerrons": "reconquérir",
    "reconquerront": "reconquérir",
    "reconquiers": "reconquérir",
    "reconquiert": "reconquérir",
    "reconquirent": "reconquérir",
    "reconquis": "reconquérir",
    "reconquise": "reconquis",
    "reconquises": "reconquis",
    "reconquisse": "reconquérir",
    "reconquissent": "reconquérir",
    "reconquisses": "reconquérir",
    "reconquissiez": "reconquérir",
    "reconquissions": "reconquérir",
    "reconquit": "reconquérir",
    "reconquière": "reconquérir",
    "reconquièrent": "reconquérir",
    "reconquières": "reconquérir",
    "reconquéraient": "reconquérir",
    "reconquérais": "reconquérir",
    "reconquérait": "reconquérir",
    "reconquérant": "reconquérir",
    "reconquérez": "reconquérir",
    "reconquériez": "reconquérir",
    "reconquérions": "reconquérir",
    "reconquérons": "reconquérir",
    "reconquêtes": "reconquête",
    "reconquîmes": "reconquérir",
    "reconquît": "reconquérir",
    "reconquîtes": "reconquérir",
    "reconsidère": "reconsidérer",
    "reconsidèrent": "reconsidérer",
    "reconsidères": "reconsidérer",
    "reconsidéra": "reconsidérer",
    "reconsidérai": "reconsidérer",
    "reconsidéraient": "reconsidérer",
    "reconsidérais": "reconsidérer",
    "reconsidérait": "reconsidérer",
    "reconsidérant": "reconsidérer",
    "reconsidéras": "reconsidérer",
    "reconsidérasse": "reconsidérer",
    "reconsidérassent": "reconsidérer",
    "reconsidérasses": "reconsidérer",
    "reconsidérassiez": "reconsidérer",
    "reconsidérassions": "reconsidérer",
    "reconsidérations": "reconsidération",
    "reconsidérera": "reconsidérer",
    "reconsidérerai": "reconsidérer",
    "reconsidéreraient": "reconsidérer",
    "reconsidérerais": "reconsidérer",
    "reconsidérerait": "reconsidérer",
    "reconsidéreras": "reconsidérer",
    "reconsidérerez": "reconsidérer",
    "reconsidéreriez": "reconsidérer",
    "reconsidérerions": "reconsidérer",
    "reconsidérerons": "reconsidérer",
    "reconsidéreront": "reconsidérer",
    "reconsidérez": "reconsidérer",
    "reconsidériez": "reconsidérer",
    "reconsidérions": "reconsidérer",
    "reconsidérons": "reconsidérer",
    "reconsidérâmes": "reconsidérer",
    "reconsidérât": "reconsidérer",
    "reconsidérâtes": "reconsidérer",
    "reconsidérèrent": "reconsidérer",
    "reconsidéré": "reconsidérer",
    "reconsidérée": "reconsidérer",
    "reconsidérées": "reconsidérer",
    "reconsidérés": "reconsidérer",
    "reconstitua": "reconstituer",
    "reconstituai": "reconstituer",
    "reconstituaient": "reconstituer",
    "reconstituais": "reconstituer",
    "reconstituait": "reconstituer",
    "reconstituant": "reconstituer",
    "reconstituante": "reconstituant",
    "reconstituantes": "reconstituant",
    "reconstituants": "reconstituant",
    "reconstituas": "reconstituer",
    "reconstituasse": "reconstituer",
    "reconstituassent": "reconstituer",
    "reconstituasses": "reconstituer",
    "reconstituassiez": "reconstituer",
    "reconstituassions": "reconstituer",
    "reconstitue": "reconstituer",
    "reconstituent": "reconstituer",
    "reconstituera": "reconstituer",
    "reconstituerai": "reconstituer",
    "reconstitueraient": "reconstituer",
    "reconstituerais": "reconstituer",
    "reconstituerait": "reconstituer",
    "reconstitueras": "reconstituer",
    "reconstituerez": "reconstituer",
    "reconstitueriez": "reconstituer",
    "reconstituerions": "reconstituer",
    "reconstituerons": "reconstituer",
    "reconstitueront": "reconstituer",
    "reconstitues": "reconstituer",
    "reconstituez": "reconstituer",
    "reconstituiez": "reconstituer",
    "reconstituions": "reconstituer",
    "reconstituons": "reconstituer",
    "reconstitutions": "reconstitution",
    "reconstituâmes": "reconstituer",
    "reconstituât": "reconstituer",
    "reconstituâtes": "reconstituer",
    "reconstituèrent": "reconstituer",
    "reconstitué": "reconstituer",
    "reconstituée": "reconstituer",
    "reconstituées": "reconstituer",
    "reconstitués": "reconstituer",
    "reconstructeurs": "reconstructeur",
    "reconstructions": "reconstruction",
    "reconstructrice": "reconstructeur",
    "reconstructrices": "reconstructeur",
    "reconstruira": "reconstruire",
    "reconstruirai": "reconstruire",
    "reconstruiraient": "reconstruire",
    "reconstruirais": "reconstruire",
    "reconstruirait": "reconstruire",
    "reconstruiras": "reconstruire",
    "reconstruirez": "reconstruire",
    "reconstruiriez": "reconstruire",
    "reconstruirions": "reconstruire",
    "reconstruirons": "reconstruire",
    "reconstruiront": "reconstruire",
    "reconstruis": "reconstruire",
    "reconstruisaient": "reconstruire",
    "reconstruisais": "reconstruire",
    "reconstruisait": "reconstruire",
    "reconstruisant": "reconstruire",
    "reconstruise": "reconstruire",
    "reconstruisent": "reconstruire",
    "reconstruises": "reconstruire",
    "reconstruisez": "reconstruire",
    "reconstruisiez": "reconstruire",
    "reconstruisions": "reconstruire",
    "reconstruisirent": "reconstruire",
    "reconstruisis": "reconstruire",
    "reconstruisisse": "reconstruire",
    "reconstruisissent": "reconstruire",
    "reconstruisisses": "reconstruire",
    "reconstruisissiez": "reconstruire",
    "reconstruisissions": "reconstruire",
    "reconstruisit": "reconstruire",
    "reconstruisons": "reconstruire",
    "reconstruisîmes": "reconstruire",
    "reconstruisît": "reconstruire",
    "reconstruisîtes": "reconstruire",
    "reconstruit": "reconstruire",
    "reconstruite": "reconstruire",
    "reconstruites": "reconstruire",
    "reconstruits": "reconstruire",
    "reconventionnelle": "reconventionnel",
    "reconventionnelles": "reconventionnel",
    "reconventionnels": "reconventionnel",
    "reconventions": "reconvention",
    "reconversions": "reconversion",
    "reconverti": "reconvertir",
    "reconvertie": "reconvertir",
    "reconverties": "reconvertir",
    "reconvertira": "reconvertir",
    "reconvertirai": "reconvertir",
    "reconvertiraient": "reconvertir",
    "reconvertirais": "reconvertir",
    "reconvertirait": "reconvertir",
    "reconvertiras": "reconvertir",
    "reconvertirent": "reconvertir",
    "reconvertirez": "reconvertir",
    "reconvertiriez": "reconvertir",
    "reconvertirions": "reconvertir",
    "reconvertirons": "reconvertir",
    "reconvertiront": "reconvertir",
    "reconvertis": "reconvertir",
    "reconvertissaient": "reconvertir",
    "reconvertissais": "reconvertir",
    "reconvertissait": "reconvertir",
    "reconvertissant": "reconvertir",
    "reconvertisse": "reconvertir",
    "reconvertissent": "reconvertir",
    "reconvertisses": "reconvertir",
    "reconvertissez": "reconvertir",
    "reconvertissiez": "reconvertir",
    "reconvertissions": "reconvertir",
    "reconvertissons": "reconvertir",
    "reconvertit": "reconvertir",
    "reconvertîmes": "reconvertir",
    "reconvertît": "reconvertir",
    "reconvertîtes": "reconvertir",
    "recopia": "recopier",
    "recopiai": "recopier",
    "recopiaient": "recopier",
    "recopiais": "recopier",
    "recopiait": "recopier",
    "recopiant": "recopier",
    "recopias": "recopier",
    "recopiasse": "recopier",
    "recopiassent": "recopier",
    "recopiasses": "recopier",
    "recopiassiez": "recopier",
    "recopiassions": "recopier",
    "recopie": "recopier",
    "recopient": "recopier",
    "recopiera": "recopier",
    "recopierai": "recopier",
    "recopieraient": "recopier",
    "recopierais": "recopier",
    "recopierait": "recopier",
    "recopieras": "recopier",
    "recopierez": "recopier",
    "recopieriez": "recopier",
    "recopierions": "recopier",
    "recopierons": "recopier",
    "recopieront": "recopier",
    "recopies": "recopier",
    "recopiez": "recopier",
    "recopiiez": "recopier",
    "recopiions": "recopier",
    "recopions": "recopier",
    "recopiâmes": "recopier",
    "recopiât": "recopier",
    "recopiâtes": "recopier",
    "recopièrent": "recopier",
    "recopié": "recopier",
    "recopiée": "recopier",
    "recopiées": "recopier",
    "recopiés": "recopier",
    "recorda": "recorder",
    "recordai": "recorder",
    "recordaient": "recorder",
    "recordais": "recorder",
    "recordait": "recorder",
    "recordant": "recorder",
    "recordas": "recorder",
    "recordasse": "recorder",
    "recordassent": "recorder",
    "recordasses": "recorder",
    "recordassiez": "recorder",
    "recordassions": "recorder",
    "recorde": "recorder",
    "recordent": "recorder",
    "recordera": "recorder",
    "recorderai": "recorder",
    "recorderaient": "recorder",
    "recorderais": "recorder",
    "recorderait": "recorder",
    "recorderas": "recorder",
    "recorderez": "recorder",
    "recorderiez": "recorder",
    "recorderions": "recorder",
    "recorderons": "recorder",
    "recorderont": "recorder",
    "recordes": "recorder",
    "recordez": "recorder",
    "recordiez": "recorder",
    "recordions": "recorder",
    "recordmans": "recordman",
    "recordmen": "recordman",
    "recordons": "recorder",
    "records": "record",
    "recordâmes": "recorder",
    "recordât": "recorder",
    "recordâtes": "recorder",
    "recordèrent": "recorder",
    "recordé": "recorder",
    "recordée": "recorder",
    "recordées": "recorder",
    "recordés": "recorder",
    "recorrige": "recorriger",
    "recorrigea": "recorriger",
    "recorrigeai": "recorriger",
    "recorrigeaient": "recorriger",
    "recorrigeais": "recorriger",
    "recorrigeait": "recorriger",
    "recorrigeant": "recorriger",
    "recorrigeas": "recorriger",
    "recorrigeasse": "recorriger",
    "recorrigeassent": "recorriger",
    "recorrigeasses": "recorriger",
    "recorrigeassiez": "recorriger",
    "recorrigeassions": "recorriger",
    "recorrigent": "recorriger",
    "recorrigeons": "recorriger",
    "recorrigera": "recorriger",
    "recorrigerai": "recorriger",
    "recorrigeraient": "recorriger",
    "recorrigerais": "recorriger",
    "recorrigerait": "recorriger",
    "recorrigeras": "recorriger",
    "recorrigerez": "recorriger",
    "recorrigeriez": "recorriger",
    "recorrigerions": "recorriger",
    "recorrigerons": "recorriger",
    "recorrigeront": "recorriger",
    "recorriges": "recorriger",
    "recorrigez": "recorriger",
    "recorrigeâmes": "recorriger",
    "recorrigeât": "recorriger",
    "recorrigeâtes": "recorriger",
    "recorrigiez": "recorriger",
    "recorrigions": "recorriger",
    "recorrigèrent": "recorriger",
    "recorrigé": "recorriger",
    "recorrigée": "recorriger",
    "recorrigées": "recorriger",
    "recorrigés": "recorriger",
    "recoucha": "recoucher",
    "recouchai": "recoucher",
    "recouchaient": "recoucher",
    "recouchais": "recoucher",
    "recouchait": "recoucher",
    "recouchant": "recoucher",
    "recouchas": "recoucher",
    "recouchasse": "recoucher",
    "recouchassent": "recoucher",
    "recouchasses": "recoucher",
    "recouchassiez": "recoucher",
    "recouchassions": "recoucher",
    "recouche": "recoucher",
    "recouchent": "recoucher",
    "recouchera": "recoucher",
    "recoucherai": "recoucher",
    "recoucheraient": "recoucher",
    "recoucherais": "recoucher",
    "recoucherait": "recoucher",
    "recoucheras": "recoucher",
    "recoucherez": "recoucher",
    "recoucheriez": "recoucher",
    "recoucherions": "recoucher",
    "recoucherons": "recoucher",
    "recoucheront": "recoucher",
    "recouches": "recoucher",
    "recouchez": "recoucher",
    "recouchiez": "recoucher",
    "recouchions": "recoucher",
    "recouchons": "recoucher",
    "recouchâmes": "recoucher",
    "recouchât": "recoucher",
    "recouchâtes": "recoucher",
    "recouchèrent": "recoucher",
    "recouché": "recoucher",
    "recouchée": "recoucher",
    "recouchées": "recoucher",
    "recouchés": "recoucher",
    "recoud": "recoudre",
    "recoudra": "recoudre",
    "recoudrai": "recoudre",
    "recoudraient": "recoudre",
    "recoudrais": "recoudre",
    "recoudrait": "recoudre",
    "recoudras": "recoudre",
    "recoudrez": "recoudre",
    "recoudriez": "recoudre",
    "recoudrions": "recoudre",
    "recoudrons": "recoudre",
    "recoudront": "recoudre",
    "recouds": "recoudre",
    "recoupa": "recouper",
    "recoupai": "recouper",
    "recoupaient": "recouper",
    "recoupais": "recouper",
    "recoupait": "recouper",
    "recoupant": "recouper",
    "recoupas": "recouper",
    "recoupasse": "recouper",
    "recoupassent": "recouper",
    "recoupasses": "recouper",
    "recoupassiez": "recouper",
    "recoupassions": "recouper",
    "recoupe": "recouper",
    "recoupements": "recoupement",
    "recoupent": "recouper",
    "recoupera": "recouper",
    "recouperai": "recouper",
    "recouperaient": "recouper",
    "recouperais": "recouper",
    "recouperait": "recouper",
    "recouperas": "recouper",
    "recouperez": "recouper",
    "recouperiez": "recouper",
    "recouperions": "recouper",
    "recouperons": "recouper",
    "recouperont": "recouper",
    "recoupes": "recouper",
    "recoupez": "recouper",
    "recoupiez": "recouper",
    "recoupions": "recouper",
    "recoupons": "recouper",
    "recoupâmes": "recouper",
    "recoupât": "recouper",
    "recoupâtes": "recouper",
    "recoupèrent": "recouper",
    "recoupé": "recouper",
    "recoupée": "recouper",
    "recoupées": "recouper",
    "recoupés": "recouper",
    "recouraient": "recourir",
    "recourais": "recourir",
    "recourait": "recourir",
    "recourant": "recourir",
    "recourba": "recourber",
    "recourbai": "recourber",
    "recourbaient": "recourber",
    "recourbais": "recourber",
    "recourbait": "recourber",
    "recourbant": "recourber",
    "recourbas": "recourber",
    "recourbasse": "recourber",
    "recourbassent": "recourber",
    "recourbasses": "recourber",
    "recourbassiez": "recourber",
    "recourbassions": "recourber",
    "recourbe": "recourber",
    "recourbent": "recourber",
    "recourbera": "recourber",
    "recourberai": "recourber",
    "recourberaient": "recourber",
    "recourberais": "recourber",
    "recourberait": "recourber",
    "recourberas": "recourber",
    "recourberez": "recourber",
    "recourberiez": "recourber",
    "recourberions": "recourber",
    "recourberons": "recourber",
    "recourberont": "recourber",
    "recourbes": "recourber",
    "recourbez": "recourber",
    "recourbiez": "recourber",
    "recourbions": "recourber",
    "recourbons": "recourber",
    "recourbâmes": "recourber",
    "recourbât": "recourber",
    "recourbâtes": "recourber",
    "recourbèrent": "recourber",
    "recourbé": "recourber",
    "recourbée": "recourber",
    "recourbées": "recourber",
    "recourbés": "recourber",
    "recoure": "recourir",
    "recourent": "recourir",
    "recoures": "recourir",
    "recourez": "recourir",
    "recouriez": "recourir",
    "recourions": "recourir",
    "recourons": "recourir",
    "recourra": "recourir",
    "recourrai": "recourir",
    "recourraient": "recourir",
    "recourrais": "recourir",
    "recourrait": "recourir",
    "recourras": "recourir",
    "recourrez": "recourir",
    "recourriez": "recourir",
    "recourrions": "recourir",
    "recourrons": "recourir",
    "recourront": "recourir",
    "recours": "recourir",
    "recourt": "recourir",
    "recouru": "recourir",
    "recourue": "recourir",
    "recourues": "recourir",
    "recoururent": "recourir",
    "recourus": "recourir",
    "recourusse": "recourir",
    "recourussent": "recourir",
    "recourusses": "recourir",
    "recourussiez": "recourir",
    "recourussions": "recourir",
    "recourut": "recourir",
    "recourûmes": "recourir",
    "recourût": "recourir",
    "recourûtes": "recourir",
    "recousaient": "recoudre",
    "recousais": "recoudre",
    "recousait": "recoudre",
    "recousant": "recoudre",
    "recouse": "recoudre",
    "recousent": "recoudre",
    "recouses": "recoudre",
    "recousez": "recoudre",
    "recousiez": "recoudre",
    "recousions": "recoudre",
    "recousirent": "recoudre",
    "recousis": "recoudre",
    "recousisse": "recoudre",
    "recousissent": "recoudre",
    "recousisses": "recoudre",
    "recousissiez": "recoudre",
    "recousissions": "recoudre",
    "recousit": "recoudre",
    "recousons": "recoudre",
    "recousu": "recoudre",
    "recousue": "recoudre",
    "recousues": "recoudre",
    "recousus": "recoudre",
    "recousîmes": "recoudre",
    "recousît": "recoudre",
    "recousîtes": "recoudre",
    "recouvert": "recouvrir",
    "recouverte": "recouvrir",
    "recouvertes": "recouvrir",
    "recouverts": "recouvrir",
    "recouvra": "recouvrer",
    "recouvrables": "recouvrable",
    "recouvrai": "recouvrer",
    "recouvraient": "recouvrir",
    "recouvrais": "recouvrir",
    "recouvrait": "recouvrir",
    "recouvrant": "recouvrir",
    "recouvras": "recouvrer",
    "recouvrasse": "recouvrer",
    "recouvrassent": "recouvrer",
    "recouvrasses": "recouvrer",
    "recouvrassiez": "recouvrer",
    "recouvrassions": "recouvrer",
    "recouvre": "recouvrir",
    "recouvrements": "recouvrement",
    "recouvrent": "recouvrir",
    "recouvrera": "recouvrer",
    "recouvrerai": "recouvrer",
    "recouvreraient": "recouvrer",
    "recouvrerais": "recouvrer",
    "recouvrerait": "recouvrer",
    "recouvreras": "recouvrer",
    "recouvrerez": "recouvrer",
    "recouvreriez": "recouvrer",
    "recouvrerions": "recouvrer",
    "recouvrerons": "recouvrer",
    "recouvreront": "recouvrer",
    "recouvres": "recouvrir",
    "recouvrez": "recouvrir",
    "recouvriez": "recouvrir",
    "recouvrions": "recouvrir",
    "recouvrira": "recouvrir",
    "recouvrirai": "recouvrir",
    "recouvriraient": "recouvrir",
    "recouvrirais": "recouvrir",
    "recouvrirait": "recouvrir",
    "recouvriras": "recouvrir",
    "recouvrirent": "recouvrir",
    "recouvrirez": "recouvrir",
    "recouvririez": "recouvrir",
    "recouvririons": "recouvrir",
    "recouvrirons": "recouvrir",
    "recouvriront": "recouvrir",
    "recouvris": "recouvrir",
    "recouvrisse": "recouvrir",
    "recouvrissent": "recouvrir",
    "recouvrisses": "recouvrir",
    "recouvrissiez": "recouvrir",
    "recouvrissions": "recouvrir",
    "recouvrit": "recouvrir",
    "recouvrons": "recouvrir",
    "recouvrâmes": "recouvrer",
    "recouvrât": "recouvrer",
    "recouvrâtes": "recouvrer",
    "recouvrèrent": "recouvrer",
    "recouvré": "recouvrer",
    "recouvrée": "recouvrer",
    "recouvrées": "recouvrer",
    "recouvrés": "recouvrer",
    "recouvrîmes": "recouvrir",
    "recouvrît": "recouvrir",
    "recouvrîtes": "recouvrir",
    "recracha": "recracher",
    "recrachai": "recracher",
    "recrachaient": "recracher",
    "recrachais": "recracher",
    "recrachait": "recracher",
    "recrachant": "recracher",
    "recrachas": "recracher",
    "recrachasse": "recracher",
    "recrachassent": "recracher",
    "recrachasses": "recracher",
    "recrachassiez": "recracher",
    "recrachassions": "recracher",
    "recrache": "recracher",
    "recrachent": "recracher",
    "recrachera": "recracher",
    "recracherai": "recracher",
    "recracheraient": "recracher",
    "recracherais": "recracher",
    "recracherait": "recracher",
    "recracheras": "recracher",
    "recracherez": "recracher",
    "recracheriez": "recracher",
    "recracherions": "recracher",
    "recracherons": "recracher",
    "recracheront": "recracher",
    "recraches": "recracher",
    "recrachez": "recracher",
    "recrachiez": "recracher",
    "recrachions": "recracher",
    "recrachons": "recracher",
    "recrachâmes": "recracher",
    "recrachât": "recracher",
    "recrachâtes": "recracher",
    "recrachèrent": "recracher",
    "recraché": "recracher",
    "recrachée": "recracher",
    "recrachées": "recracher",
    "recrachés": "recracher",
    "recreusa": "recreuser",
    "recreusai": "recreuser",
    "recreusaient": "recreuser",
    "recreusais": "recreuser",
    "recreusait": "recreuser",
    "recreusant": "recreuser",
    "recreusas": "recreuser",
    "recreusasse": "recreuser",
    "recreusassent": "recreuser",
    "recreusasses": "recreuser",
    "recreusassiez": "recreuser",
    "recreusassions": "recreuser",
    "recreuse": "recreuser",
    "recreusent": "recreuser",
    "recreusera": "recreuser",
    "recreuserai": "recreuser",
    "recreuseraient": "recreuser",
    "recreuserais": "recreuser",
    "recreuserait": "recreuser",
    "recreuseras": "recreuser",
    "recreuserez": "recreuser",
    "recreuseriez": "recreuser",
    "recreuserions": "recreuser",
    "recreuserons": "recreuser",
    "recreuseront": "recreuser",
    "recreuses": "recreuser",
    "recreusez": "recreuser",
    "recreusiez": "recreuser",
    "recreusions": "recreuser",
    "recreusons": "recreuser",
    "recreusâmes": "recreuser",
    "recreusât": "recreuser",
    "recreusâtes": "recreuser",
    "recreusèrent": "recreuser",
    "recreusé": "recreuser",
    "recreusée": "recreuser",
    "recreusées": "recreuser",
    "recreusés": "recreuser",
    "recrois": "recroître",
    "recroisa": "recroiser",
    "recroisai": "recroiser",
    "recroisaient": "recroiser",
    "recroisais": "recroiser",
    "recroisait": "recroiser",
    "recroisant": "recroiser",
    "recroisas": "recroiser",
    "recroisasse": "recroiser",
    "recroisassent": "recroiser",
    "recroisasses": "recroiser",
    "recroisassiez": "recroiser",
    "recroisassions": "recroiser",
    "recroise": "recroiser",
    "recroisent": "recroiser",
    "recroisera": "recroiser",
    "recroiserai": "recroiser",
    "recroiseraient": "recroiser",
    "recroiserais": "recroiser",
    "recroiserait": "recroiser",
    "recroiseras": "recroiser",
    "recroiserez": "recroiser",
    "recroiseriez": "recroiser",
    "recroiserions": "recroiser",
    "recroiserons": "recroiser",
    "recroiseront": "recroiser",
    "recroises": "recroiser",
    "recroisez": "recroiser",
    "recroisiez": "recroiser",
    "recroisions": "recroiser",
    "recroisons": "recroiser",
    "recroissaient": "recroître",
    "recroissais": "recroître",
    "recroissait": "recroître",
    "recroissant": "recroître",
    "recroisse": "recroître",
    "recroissent": "recroître",
    "recroisses": "recroître",
    "recroissez": "recroître",
    "recroissiez": "recroître",
    "recroissions": "recroître",
    "recroissons": "recroître",
    "recroisâmes": "recroiser",
    "recroisât": "recroiser",
    "recroisâtes": "recroiser",
    "recroisèrent": "recroiser",
    "recroisé": "recroiser",
    "recroisée": "recroiser",
    "recroisées": "recroiser",
    "recroisés": "recroiser",
    "recroquevilla": "recroqueviller",
    "recroquevillai": "recroqueviller",
    "recroquevillaient": "recroqueviller",
    "recroquevillais": "recroqueviller",
    "recroquevillait": "recroqueviller",
    "recroquevillant": "recroqueviller",
    "recroquevillas": "recroqueviller",
    "recroquevillasse": "recroqueviller",
    "recroquevillassent": "recroqueviller",
    "recroquevillasses": "recroqueviller",
    "recroquevillassiez": "recroqueviller",
    "recroquevillassions": "recroqueviller",
    "recroqueville": "recroqueviller",
    "recroquevillent": "recroqueviller",
    "recroquevillera": "recroqueviller",
    "recroquevillerai": "recroqueviller",
    "recroquevilleraient": "recroqueviller",
    "recroquevillerais": "recroqueviller",
    "recroquevillerait": "recroqueviller",
    "recroquevilleras": "recroqueviller",
    "recroquevillerez": "recroqueviller",
    "recroquevilleriez": "recroqueviller",
    "recroquevillerions": "recroqueviller",
    "recroquevillerons": "recroqueviller",
    "recroquevilleront": "recroqueviller",
    "recroquevilles": "recroqueviller",
    "recroquevillez": "recroqueviller",
    "recroquevilliez": "recroqueviller",
    "recroquevillions": "recroqueviller",
    "recroquevillons": "recroqueviller",
    "recroquevillâmes": "recroqueviller",
    "recroquevillât": "recroqueviller",
    "recroquevillâtes": "recroqueviller",
    "recroquevillèrent": "recroqueviller",
    "recroquevillé": "recroqueviller",
    "recroquevillée": "recroqueviller",
    "recroquevillées": "recroqueviller",
    "recroquevillés": "recroqueviller",
    "recroît": "recroître",
    "recroîtra": "recroître",
    "recroîtrai": "recroître",
    "recroîtraient": "recroître",
    "recroîtrais": "recroître",
    "recroîtrait": "recroître",
    "recroîtras": "recroître",
    "recroîtrez": "recroître",
    "recroîtriez": "recroître",
    "recroîtrions": "recroître",
    "recroîtrons": "recroître",
    "recroîtront": "recroître",
    "recru": "recroître",
    "recrudescences": "recrudescence",
    "recrudescente": "recrudescent",
    "recrudescentes": "recrudescent",
    "recrudescents": "recrudescent",
    "recrue": "recru",
    "recrues": "recrue",
    "recrurent": "recroître",
    "recrus": "recru",
    "recrusse": "recroître",
    "recrussent": "recroître",
    "recrusses": "recroître",
    "recrussiez": "recroître",
    "recrussions": "recroître",
    "recrut": "recroître",
    "recruta": "recruter",
    "recrutai": "recruter",
    "recrutaient": "recruter",
    "recrutais": "recruter",
    "recrutait": "recruter",
    "recrutant": "recruter",
    "recrutas": "recruter",
    "recrutasse": "recruter",
    "recrutassent": "recruter",
    "recrutasses": "recruter",
    "recrutassiez": "recruter",
    "recrutassions": "recruter",
    "recrute": "recruter",
    "recrutements": "recrutement",
    "recrutent": "recruter",
    "recrutera": "recruter",
    "recruterai": "recruter",
    "recruteraient": "recruter",
    "recruterais": "recruter",
    "recruterait": "recruter",
    "recruteras": "recruter",
    "recruterez": "recruter",
    "recruteriez": "recruter",
    "recruterions": "recruter",
    "recruterons": "recruter",
    "recruteront": "recruter",
    "recrutes": "recruter",
    "recruteurs": "recruteur",
    "recruteuse": "recruteur",
    "recruteuses": "recruteur",
    "recrutez": "recruter",
    "recrutiez": "recruter",
    "recrutions": "recruter",
    "recrutons": "recruter",
    "recrutâmes": "recruter",
    "recrutât": "recruter",
    "recrutâtes": "recruter",
    "recrutèrent": "recruter",
    "recruté": "recruter",
    "recrutée": "recruter",
    "recrutées": "recruter",
    "recrutés": "recruter",
    "recréa": "recréer",
    "recréai": "recréer",
    "recréaient": "recréer",
    "recréais": "recréer",
    "recréait": "recréer",
    "recréant": "recréer",
    "recréas": "recréer",
    "recréasse": "recréer",
    "recréassent": "recréer",
    "recréasses": "recréer",
    "recréassiez": "recréer",
    "recréassions": "recréer",
    "recréations": "recréation",
    "recrée": "recréer",
    "recréent": "recréer",
    "recréera": "recréer",
    "recréerai": "recréer",
    "recréeraient": "recréer",
    "recréerais": "recréer",
    "recréerait": "recréer",
    "recréeras": "recréer",
    "recréerez": "recréer",
    "recréeriez": "recréer",
    "recréerions": "recréer",
    "recréerons": "recréer",
    "recréeront": "recréer",
    "recrées": "recréer",
    "recréez": "recréer",
    "recréiez": "recréer",
    "recréions": "recréer",
    "recréons": "recréer",
    "recrépi": "recrépir",
    "recrépie": "recrépir",
    "recrépies": "recrépir",
    "recrépira": "recrépir",
    "recrépirai": "recrépir",
    "recrépiraient": "recrépir",
    "recrépirais": "recrépir",
    "recrépirait": "recrépir",
    "recrépiras": "recrépir",
    "recrépirent": "recrépir",
    "recrépirez": "recrépir",
    "recrépiriez": "recrépir",
    "recrépirions": "recrépir",
    "recrépirons": "recrépir",
    "recrépiront": "recrépir",
    "recrépis": "recrépir",
    "recrépissaient": "recrépir",
    "recrépissais": "recrépir",
    "recrépissait": "recrépir",
    "recrépissant": "recrépir",
    "recrépisse": "recrépir",
    "recrépissent": "recrépir",
    "recrépisses": "recrépir",
    "recrépissez": "recrépir",
    "recrépissiez": "recrépir",
    "recrépissions": "recrépir",
    "recrépissons": "recrépir",
    "recrépit": "recrépir",
    "recrépîmes": "recrépir",
    "recrépît": "recrépir",
    "recrépîtes": "recrépir",
    "recréâmes": "recréer",
    "recréât": "recréer",
    "recréâtes": "recréer",
    "recréèrent": "recréer",
    "recréé": "recréer",
    "recréée": "recréer",
    "recréées": "recréer",
    "recréés": "recréer",
    "recrû": "recroître",
    "recrûe": "recroître",
    "recrûes": "recroître",
    "recrûmes": "recroître",
    "recrûs": "recroître",
    "recrût": "recroître",
    "recrûtes": "recroître",
    "rectale": "rectal",
    "rectales": "rectal",
    "rectangles": "rectangle",
    "rectangulaires": "rectangulaire",
    "rectaux": "rectal",
    "recteurs": "recteur",
    "rectifia": "rectifier",
    "rectifiai": "rectifier",
    "rectifiaient": "rectifier",
    "rectifiais": "rectifier",
    "rectifiait": "rectifier",
    "rectifiant": "rectifier",
    "rectifias": "rectifier",
    "rectifiasse": "rectifier",
    "rectifiassent": "rectifier",
    "rectifiasses": "rectifier",
    "rectifiassiez": "rectifier",
    "rectifiassions": "rectifier",
    "rectificatifs": "rectificatif",
    "rectifications": "rectification",
    "rectificative": "rectificatif",
    "rectificatives": "rectificatif",
    "rectifie": "rectifier",
    "rectifient": "rectifier",
    "rectifiera": "rectifier",
    "rectifierai": "rectifier",
    "rectifieraient": "rectifier",
    "rectifierais": "rectifier",
    "rectifierait": "rectifier",
    "rectifieras": "rectifier",
    "rectifierez": "rectifier",
    "rectifieriez": "rectifier",
    "rectifierions": "rectifier",
    "rectifierons": "rectifier",
    "rectifieront": "rectifier",
    "rectifies": "rectifier",
    "rectifiez": "rectifier",
    "rectifiiez": "rectifier",
    "rectifiions": "rectifier",
    "rectifions": "rectifier",
    "rectifiâmes": "rectifier",
    "rectifiât": "rectifier",
    "rectifiâtes": "rectifier",
    "rectifièrent": "rectifier",
    "rectifié": "rectifier",
    "rectifiée": "rectifier",
    "rectifiées": "rectifier",
    "rectifiés": "rectifier",
    "rectilignes": "rectiligne",
    "rections": "rection",
    "rectitudes": "rectitude",
    "rectorale": "rectoral",
    "rectorales": "rectoral",
    "rectorats": "rectorat",
    "rectoraux": "rectoral",
    "rectos": "recto",
    "rectrice": "recteur",
    "rectrices": "recteur",
    "rectums": "rectum",
    "recueillaient": "recueillir",
    "recueillais": "recueillir",
    "recueillait": "recueillir",
    "recueillant": "recueillir",
    "recueille": "recueillir",
    "recueillements": "recueillement",
    "recueillent": "recueillir",
    "recueillera": "recueillir",
    "recueillerai": "recueillir",
    "recueilleraient": "recueillir",
    "recueillerais": "recueillir",
    "recueillerait": "recueillir",
    "recueilleras": "recueillir",
    "recueillerez": "recueillir",
    "recueilleriez": "recueillir",
    "recueillerions": "recueillir",
    "recueillerons": "recueillir",
    "recueilleront": "recueillir",
    "recueilles": "recueillir",
    "recueillez": "recueillir",
    "recueilli": "recueillir",
    "recueillie": "recueillir",
    "recueillies": "recueillir",
    "recueilliez": "recueillir",
    "recueillions": "recueillir",
    "recueillirent": "recueillir",
    "recueillis": "recueillir",
    "recueillisse": "recueillir",
    "recueillissent": "recueillir",
    "recueillisses": "recueillir",
    "recueillissiez": "recueillir",
    "recueillissions": "recueillir",
    "recueillit": "recueillir",
    "recueillons": "recueillir",
    "recueillîmes": "recueillir",
    "recueillît": "recueillir",
    "recueillîtes": "recueillir",
    "recueils": "recueil",
    "recuira": "recuire",
    "recuirai": "recuire",
    "recuiraient": "recuire",
    "recuirais": "recuire",
    "recuirait": "recuire",
    "recuiras": "recuire",
    "recuirez": "recuire",
    "recuiriez": "recuire",
    "recuirions": "recuire",
    "recuirons": "recuire",
    "recuiront": "recuire",
    "recuis": "recuire",
    "recuisaient": "recuire",
    "recuisais": "recuire",
    "recuisait": "recuire",
    "recuisant": "recuire",
    "recuise": "recuire",
    "recuisent": "recuire",
    "recuises": "recuire",
    "recuisez": "recuire",
    "recuisiez": "recuire",
    "recuisions": "recuire",
    "recuisirent": "recuire",
    "recuisis": "recuire",
    "recuisisse": "recuire",
    "recuisissent": "recuire",
    "recuisisses": "recuire",
    "recuisissiez": "recuire",
    "recuisissions": "recuire",
    "recuisit": "recuire",
    "recuisons": "recuire",
    "recuisîmes": "recuire",
    "recuisît": "recuire",
    "recuisîtes": "recuire",
    "recuit": "recuire",
    "recuite": "recuit",
    "recuites": "recuit",
    "recuits": "recuit",
    "recula": "reculer",
    "reculades": "reculade",
    "reculai": "reculer",
    "reculaient": "reculer",
    "reculais": "reculer",
    "reculait": "reculer",
    "reculant": "reculer",
    "reculas": "reculer",
    "reculasse": "reculer",
    "reculassent": "reculer",
    "reculasses": "reculer",
    "reculassiez": "reculer",
    "reculassions": "reculer",
    "recule": "reculer",
    "reculent": "reculer",
    "reculera": "reculer",
    "reculerai": "reculer",
    "reculeraient": "reculer",
    "reculerais": "reculer",
    "reculerait": "reculer",
    "reculeras": "reculer",
    "reculerez": "reculer",
    "reculeriez": "reculer",
    "reculerions": "reculer",
    "reculerons": "reculer",
    "reculeront": "reculer",
    "recules": "reculer",
    "reculez": "reculer",
    "reculiez": "reculer",
    "reculions": "reculer",
    "reculons": "reculer",
    "reculotta": "reculotter",
    "reculotte": "reculotter",
    "reculotté": "reculotter",
    "reculottée": "reculotter",
    "reculs": "recul",
    "reculâmes": "reculer",
    "reculât": "reculer",
    "reculâtes": "reculer",
    "reculèrent": "reculer",
    "reculé": "reculer",
    "reculée": "reculer",
    "reculées": "reculer",
    "reculés": "reculer",
    "recycla": "recycler",
    "recyclables": "recyclable",
    "recyclages": "recyclage",
    "recyclai": "recycler",
    "recyclaient": "recycler",
    "recyclais": "recycler",
    "recyclait": "recycler",
    "recyclant": "recycler",
    "recyclas": "recycler",
    "recyclasse": "recycler",
    "recyclassent": "recycler",
    "recyclasses": "recycler",
    "recyclassiez": "recycler",
    "recyclassions": "recycler",
    "recycle": "recycler",
    "recyclent": "recycler",
    "recyclera": "recycler",
    "recyclerai": "recycler",
    "recycleraient": "recycler",
    "recyclerais": "recycler",
    "recyclerait": "recycler",
    "recycleras": "recycler",
    "recyclerez": "recycler",
    "recycleriez": "recycler",
    "recyclerions": "recycler",
    "recyclerons": "recycler",
    "recycleront": "recycler",
    "recycles": "recycler",
    "recyclez": "recycler",
    "recycliez": "recycler",
    "recyclions": "recycler",
    "recyclons": "recycler",
    "recyclâmes": "recycler",
    "recyclât": "recycler",
    "recyclâtes": "recycler",
    "recyclèrent": "recycler",
    "recyclé": "recycler",
    "recyclée": "recycler",
    "recyclées": "recycler",
    "recyclés": "recycler",
    "recède": "recéder",
    "recèdent": "recéder",
    "recèdes": "recéder",
    "recèle": "receler",
    "recèlent": "receler",
    "recèlera": "receler",
    "recèlerai": "receler",
    "recèleraient": "receler",
    "recèlerais": "receler",
    "recèlerait": "receler",
    "recèleras": "receler",
    "recèlerez": "receler",
    "recèleriez": "receler",
    "recèlerions": "receler",
    "recèlerons": "receler",
    "recèleront": "receler",
    "recèles": "receler",
    "recèpe": "recéper",
    "recèpent": "recéper",
    "recèpera": "receper",
    "recèperai": "receper",
    "recèperaient": "receper",
    "recèperais": "receper",
    "recèperait": "receper",
    "recèperas": "receper",
    "recèperez": "receper",
    "recèperiez": "receper",
    "recèperions": "receper",
    "recèperons": "receper",
    "recèperont": "receper",
    "recèpes": "recéper",
    "recéda": "recéder",
    "recédai": "recéder",
    "recédaient": "recéder",
    "recédais": "recéder",
    "recédait": "recéder",
    "recédant": "recéder",
    "recédas": "recéder",
    "recédasse": "recéder",
    "recédassent": "recéder",
    "recédasses": "recéder",
    "recédassiez": "recéder",
    "recédassions": "recéder",
    "recédera": "recéder",
    "recéderai": "recéder",
    "recéderaient": "recéder",
    "recéderais": "recéder",
    "recéderait": "recéder",
    "recéderas": "recéder",
    "recéderez": "recéder",
    "recéderiez": "recéder",
    "recéderions": "recéder",
    "recéderons": "recéder",
    "recéderont": "recéder",
    "recédez": "recéder",
    "recédiez": "recéder",
    "recédions": "recéder",
    "recédons": "recéder",
    "recédâmes": "recéder",
    "recédât": "recéder",
    "recédâtes": "recéder",
    "recédèrent": "recéder",
    "recédé": "recéder",
    "recédée": "recéder",
    "recédées": "recéder",
    "recédés": "recéder",
    "recélait": "recéler",
    "recélant": "recéler",
    "recépa": "recéper",
    "recépages": "recépage",
    "recépai": "recéper",
    "recépaient": "recéper",
    "recépais": "recéper",
    "recépait": "recéper",
    "recépant": "recéper",
    "recépas": "recéper",
    "recépasse": "recéper",
    "recépassent": "recéper",
    "recépasses": "recéper",
    "recépassiez": "recéper",
    "recépassions": "recéper",
    "recépera": "recéper",
    "recéperai": "recéper",
    "recéperaient": "recéper",
    "recéperais": "recéper",
    "recéperait": "recéper",
    "recéperas": "recéper",
    "recéperez": "recéper",
    "recéperiez": "recéper",
    "recéperions": "recéper",
    "recéperons": "recéper",
    "recéperont": "recéper",
    "recépez": "recéper",
    "recépiez": "recéper",
    "recépions": "recéper",
    "recépons": "recéper",
    "recépâmes": "recéper",
    "recépât": "recéper",
    "recépâtes": "recéper",
    "recépèrent": "recéper",
    "recépé": "recéper",
    "recépée": "recéper",
    "recépées": "recéper",
    "recépés": "recéper",
    "redans": "redan",
    "redditions": "reddition",
    "redemanda": "redemander",
    "redemandai": "redemander",
    "redemandaient": "redemander",
    "redemandais": "redemander",
    "redemandait": "redemander",
    "redemandant": "redemander",
    "redemandas": "redemander",
    "redemandasse": "redemander",
    "redemandassent": "redemander",
    "redemandasses": "redemander",
    "redemandassiez": "redemander",
    "redemandassions": "redemander",
    "redemande": "redemander",
    "redemandent": "redemander",
    "redemandera": "redemander",
    "redemanderai": "redemander",
    "redemanderaient": "redemander",
    "redemanderais": "redemander",
    "redemanderait": "redemander",
    "redemanderas": "redemander",
    "redemanderez": "redemander",
    "redemanderiez": "redemander",
    "redemanderions": "redemander",
    "redemanderons": "redemander",
    "redemanderont": "redemander",
    "redemandes": "redemander",
    "redemandez": "redemander",
    "redemandiez": "redemander",
    "redemandions": "redemander",
    "redemandons": "redemander",
    "redemandâmes": "redemander",
    "redemandât": "redemander",
    "redemandâtes": "redemander",
    "redemandèrent": "redemander",
    "redemandé": "redemander",
    "redemandée": "redemander",
    "redemandées": "redemander",
    "redemandés": "redemander",
    "redents": "redent",
    "redescend": "redescendre",
    "redescendaient": "redescendre",
    "redescendais": "redescendre",
    "redescendait": "redescendre",
    "redescendant": "redescendre",
    "redescende": "redescendre",
    "redescendent": "redescendre",
    "redescendes": "redescendre",
    "redescendez": "redescendre",
    "redescendiez": "redescendre",
    "redescendions": "redescendre",
    "redescendirent": "redescendre",
    "redescendis": "redescendre",
    "redescendisse": "redescendre",
    "redescendissent": "redescendre",
    "redescendisses": "redescendre",
    "redescendissiez": "redescendre",
    "redescendissions": "redescendre",
    "redescendit": "redescendre",
    "redescendons": "redescendre",
    "redescendra": "redescendre",
    "redescendrai": "redescendre",
    "redescendraient": "redescendre",
    "redescendrais": "redescendre",
    "redescendrait": "redescendre",
    "redescendras": "redescendre",
    "redescendrez": "redescendre",
    "redescendriez": "redescendre",
    "redescendrions": "redescendre",
    "redescendrons": "redescendre",
    "redescendront": "redescendre",
    "redescends": "redescendre",
    "redescendu": "redescendre",
    "redescendue": "redescendre",
    "redescendues": "redescendre",
    "redescendus": "redescendre",
    "redescendîmes": "redescendre",
    "redescendît": "redescendre",
    "redescendîtes": "redescendre",
    "redessina": "redessiner",
    "redessinaient": "redessiner",
    "redessinait": "redessiner",
    "redessine": "redessiner",
    "redessinent": "redessiner",
    "redessiné": "redessiner",
    "redessinée": "redessiner",
    "redevables": "redevable",
    "redevaient": "redevoir",
    "redevais": "redevoir",
    "redevait": "redevoir",
    "redevances": "redevance",
    "redevant": "redevoir",
    "redevenaient": "redevenir",
    "redevenais": "redevenir",
    "redevenait": "redevenir",
    "redevenant": "redevenir",
    "redevenez": "redevenir",
    "redeveniez": "redevenir",
    "redevenions": "redevenir",
    "redevenons": "redevenir",
    "redevenu": "redevenir",
    "redevenue": "redevenir",
    "redevenues": "redevenir",
    "redevenus": "redevenir",
    "redevez": "redevoir",
    "redeviendra": "redevenir",
    "redeviendrai": "redevenir",
    "redeviendraient": "redevenir",
    "redeviendrais": "redevenir",
    "redeviendrait": "redevenir",
    "redeviendras": "redevenir",
    "redeviendrez": "redevenir",
    "redeviendriez": "redevenir",
    "redeviendrions": "redevenir",
    "redeviendrons": "redevenir",
    "redeviendront": "redevenir",
    "redevienne": "redevenir",
    "redeviennent": "redevenir",
    "redeviennes": "redevenir",
    "redeviens": "redevenir",
    "redevient": "redevenir",
    "redeviez": "redevoir",
    "redevinrent": "redevenir",
    "redevins": "redevenir",
    "redevinsse": "redevenir",
    "redevinssent": "redevenir",
    "redevinsses": "redevenir",
    "redevinssiez": "redevenir",
    "redevinssions": "redevenir",
    "redevint": "redevenir",
    "redevions": "redevoir",
    "redevons": "redevoir",
    "redevra": "redevoir",
    "redevrai": "redevoir",
    "redevraient": "redevoir",
    "redevrais": "redevoir",
    "redevrait": "redevoir",
    "redevras": "redevoir",
    "redevrez": "redevoir",
    "redevriez": "redevoir",
    "redevrions": "redevoir",
    "redevrons": "redevoir",
    "redevront": "redevoir",
    "redevînmes": "redevenir",
    "redevînt": "redevenir",
    "redevîntes": "redevenir",
    "rediffusa": "rediffuser",
    "rediffusai": "rediffuser",
    "rediffusaient": "rediffuser",
    "rediffusais": "rediffuser",
    "rediffusait": "rediffuser",
    "rediffusant": "rediffuser",
    "rediffusas": "rediffuser",
    "rediffusasse": "rediffuser",
    "rediffusassent": "rediffuser",
    "rediffusasses": "rediffuser",
    "rediffusassiez": "rediffuser",
    "rediffusassions": "rediffuser",
    "rediffuse": "rediffuser",
    "rediffusent": "rediffuser",
    "rediffusera": "rediffuser",
    "rediffuserai": "rediffuser",
    "rediffuseraient": "rediffuser",
    "rediffuserais": "rediffuser",
    "rediffuserait": "rediffuser",
    "rediffuseras": "rediffuser",
    "rediffuserez": "rediffuser",
    "rediffuseriez": "rediffuser",
    "rediffuserions": "rediffuser",
    "rediffuserons": "rediffuser",
    "rediffuseront": "rediffuser",
    "rediffuses": "rediffuser",
    "rediffusez": "rediffuser",
    "rediffusiez": "rediffuser",
    "rediffusions": "rediffusion",
    "rediffusons": "rediffuser",
    "rediffusâmes": "rediffuser",
    "rediffusât": "rediffuser",
    "rediffusâtes": "rediffuser",
    "rediffusèrent": "rediffuser",
    "rediffusé": "rediffuser",
    "rediffusée": "rediffuser",
    "rediffusées": "rediffuser",
    "rediffusés": "rediffuser",
    "redimensionnées": "redimensionner",
    "redingotes": "redingote",
    "redira": "redire",
    "redirai": "redire",
    "rediraient": "redire",
    "redirais": "redire",
    "redirait": "redire",
    "rediras": "redire",
    "redirent": "redire",
    "redirez": "redire",
    "rediriez": "redire",
    "redirige": "rediriger",
    "redirigé": "rediriger",
    "redirions": "redire",
    "redirons": "redire",
    "rediront": "redire",
    "redis": "redire",
    "redisaient": "redire",
    "redisais": "redire",
    "redisait": "redire",
    "redisant": "redire",
    "rediscuta": "rediscuter",
    "rediscutai": "rediscuter",
    "rediscutaient": "rediscuter",
    "rediscutais": "rediscuter",
    "rediscutait": "rediscuter",
    "rediscutant": "rediscuter",
    "rediscutas": "rediscuter",
    "rediscutasse": "rediscuter",
    "rediscutassent": "rediscuter",
    "rediscutasses": "rediscuter",
    "rediscutassiez": "rediscuter",
    "rediscutassions": "rediscuter",
    "rediscute": "rediscuter",
    "rediscutent": "rediscuter",
    "rediscutera": "rediscuter",
    "rediscuterai": "rediscuter",
    "rediscuteraient": "rediscuter",
    "rediscuterais": "rediscuter",
    "rediscuterait": "rediscuter",
    "rediscuteras": "rediscuter",
    "rediscuterez": "rediscuter",
    "rediscuteriez": "rediscuter",
    "rediscuterions": "rediscuter",
    "rediscuterons": "rediscuter",
    "rediscuteront": "rediscuter",
    "rediscutes": "rediscuter",
    "rediscutez": "rediscuter",
    "rediscutiez": "rediscuter",
    "rediscutions": "rediscuter",
    "rediscutons": "rediscuter",
    "rediscutâmes": "rediscuter",
    "rediscutât": "rediscuter",
    "rediscutâtes": "rediscuter",
    "rediscutèrent": "rediscuter",
    "rediscuté": "rediscuter",
    "rediscutée": "rediscuter",
    "rediscutées": "rediscuter",
    "rediscutés": "rediscuter",
    "redise": "redire",
    "redisent": "redire",
    "redises": "redire",
    "redisiez": "redire",
    "redisions": "redire",
    "redisons": "redire",
    "redisse": "redire",
    "redissent": "redire",
    "redisses": "redire",
    "redissiez": "redire",
    "redissions": "redire",
    "redistribua": "redistribuer",
    "redistribuai": "redistribuer",
    "redistribuaient": "redistribuer",
    "redistribuais": "redistribuer",
    "redistribuait": "redistribuer",
    "redistribuant": "redistribuer",
    "redistribuas": "redistribuer",
    "redistribuasse": "redistribuer",
    "redistribuassent": "redistribuer",
    "redistribuasses": "redistribuer",
    "redistribuassiez": "redistribuer",
    "redistribuassions": "redistribuer",
    "redistribue": "redistribuer",
    "redistribuent": "redistribuer",
    "redistribuera": "redistribuer",
    "redistribuerai": "redistribuer",
    "redistribueraient": "redistribuer",
    "redistribuerais": "redistribuer",
    "redistribuerait": "redistribuer",
    "redistribueras": "redistribuer",
    "redistribuerez": "redistribuer",
    "redistribueriez": "redistribuer",
    "redistribuerions": "redistribuer",
    "redistribuerons": "redistribuer",
    "redistribueront": "redistribuer",
    "redistribues": "redistribuer",
    "redistribuez": "redistribuer",
    "redistribuiez": "redistribuer",
    "redistribuions": "redistribuer",
    "redistribuons": "redistribuer",
    "redistributions": "redistribution",
    "redistribuâmes": "redistribuer",
    "redistribuât": "redistribuer",
    "redistribuâtes": "redistribuer",
    "redistribuèrent": "redistribuer",
    "redistribué": "redistribuer",
    "redistribuée": "redistribuer",
    "redistribuées": "redistribuer",
    "redistribués": "redistribuer",
    "redit": "redire",
    "redite": "redire",
    "redites": "redite",
    "redits": "redire",
    "redois": "redevoir",
    "redoit": "redevoir",
    "redoive": "redevoir",
    "redoivent": "redevoir",
    "redoives": "redevoir",
    "redondances": "redondance",
    "redondante": "redondant",
    "redondantes": "redondant",
    "redondants": "redondant",
    "redonna": "redonner",
    "redonnai": "redonner",
    "redonnaient": "redonner",
    "redonnais": "redonner",
    "redonnait": "redonner",
    "redonnant": "redonner",
    "redonnas": "redonner",
    "redonnasse": "redonner",
    "redonnassent": "redonner",
    "redonnasses": "redonner",
    "redonnassiez": "redonner",
    "redonnassions": "redonner",
    "redonne": "redonner",
    "redonnent": "redonner",
    "redonnera": "redonner",
    "redonnerai": "redonner",
    "redonneraient": "redonner",
    "redonnerais": "redonner",
    "redonnerait": "redonner",
    "redonneras": "redonner",
    "redonnerez": "redonner",
    "redonneriez": "redonner",
    "redonnerions": "redonner",
    "redonnerons": "redonner",
    "redonneront": "redonner",
    "redonnes": "redonner",
    "redonnez": "redonner",
    "redonniez": "redonner",
    "redonnions": "redonner",
    "redonnons": "redonner",
    "redonnâmes": "redonner",
    "redonnât": "redonner",
    "redonnâtes": "redonner",
    "redonnèrent": "redonner",
    "redonné": "redonner",
    "redonnée": "redonner",
    "redonnées": "redonner",
    "redonnés": "redonner",
    "redora": "redorer",
    "redorai": "redorer",
    "redoraient": "redorer",
    "redorais": "redorer",
    "redorait": "redorer",
    "redorant": "redorer",
    "redoras": "redorer",
    "redorasse": "redorer",
    "redorassent": "redorer",
    "redorasses": "redorer",
    "redorassiez": "redorer",
    "redorassions": "redorer",
    "redore": "redorer",
    "redorent": "redorer",
    "redorera": "redorer",
    "redorerai": "redorer",
    "redoreraient": "redorer",
    "redorerais": "redorer",
    "redorerait": "redorer",
    "redoreras": "redorer",
    "redorerez": "redorer",
    "redoreriez": "redorer",
    "redorerions": "redorer",
    "redorerons": "redorer",
    "redoreront": "redorer",
    "redores": "redorer",
    "redorez": "redorer",
    "redoriez": "redorer",
    "redorions": "redorer",
    "redormaient": "redormir",
    "redormais": "redormir",
    "redormait": "redormir",
    "redormant": "redormir",
    "redorme": "redormir",
    "redorment": "redormir",
    "redormes": "redormir",
    "redormez": "redormir",
    "redormi": "redormir",
    "redormiez": "redormir",
    "redormions": "redormir",
    "redormira": "redormir",
    "redormirai": "redormir",
    "redormiraient": "redormir",
    "redormirais": "redormir",
    "redormirait": "redormir",
    "redormiras": "redormir",
    "redormirent": "redormir",
    "redormirez": "redormir",
    "redormiriez": "redormir",
    "redormirions": "redormir",
    "redormirons": "redormir",
    "redormiront": "redormir",
    "redormis": "redormir",
    "redormisse": "redormir",
    "redormissent": "redormir",
    "redormisses": "redormir",
    "redormissiez": "redormir",
    "redormissions": "redormir",
    "redormit": "redormir",
    "redormons": "redormir",
    "redormîmes": "redormir",
    "redormît": "redormir",
    "redormîtes": "redormir",
    "redorons": "redorer",
    "redors": "redormir",
    "redort": "redormir",
    "redorâmes": "redorer",
    "redorât": "redorer",
    "redorâtes": "redorer",
    "redorèrent": "redorer",
    "redoré": "redorer",
    "redorée": "redorer",
    "redorées": "redorer",
    "redorés": "redorer",
    "redoubla": "redoubler",
    "redoublai": "redoubler",
    "redoublaient": "redoubler",
    "redoublais": "redoubler",
    "redoublait": "redoubler",
    "redoublant": "redoubler",
    "redoublants": "redoublant",
    "redoublas": "redoubler",
    "redoublasse": "redoubler",
    "redoublassent": "redoubler",
    "redoublasses": "redoubler",
    "redoublassiez": "redoubler",
    "redoublassions": "redoubler",
    "redouble": "redoubler",
    "redoublent": "redoubler",
    "redoublera": "redoubler",
    "redoublerai": "redoubler",
    "redoubleraient": "redoubler",
    "redoublerais": "redoubler",
    "redoublerait": "redoubler",
    "redoubleras": "redoubler",
    "redoublerez": "redoubler",
    "redoubleriez": "redoubler",
    "redoublerions": "redoubler",
    "redoublerons": "redoubler",
    "redoubleront": "redoubler",
    "redoubles": "redoubler",
    "redoublez": "redoubler",
    "redoubliez": "redoubler",
    "redoublions": "redoubler",
    "redoublons": "redoubler",
    "redoublâmes": "redoubler",
    "redoublât": "redoubler",
    "redoublâtes": "redoubler",
    "redoublèrent": "redoubler",
    "redoublé": "redoubler",
    "redoublée": "redoubler",
    "redoublées": "redoubler",
    "redoublés": "redoubler",
    "redouta": "redouter",
    "redoutables": "redoutable",
    "redoutai": "redouter",
    "redoutaient": "redouter",
    "redoutais": "redouter",
    "redoutait": "redouter",
    "redoutant": "redouter",
    "redoutas": "redouter",
    "redoutasse": "redouter",
    "redoutassent": "redouter",
    "redoutasses": "redouter",
    "redoutassiez": "redouter",
    "redoutassions": "redouter",
    "redoute": "redouter",
    "redoutent": "redouter",
    "redoutera": "redouter",
    "redouterai": "redouter",
    "redouteraient": "redouter",
    "redouterais": "redouter",
    "redouterait": "redouter",
    "redouteras": "redouter",
    "redouterez": "redouter",
    "redouteriez": "redouter",
    "redouterions": "redouter",
    "redouterons": "redouter",
    "redouteront": "redouter",
    "redoutes": "redouter",
    "redoutez": "redouter",
    "redoutiez": "redouter",
    "redoutions": "redouter",
    "redoutons": "redouter",
    "redoutâmes": "redouter",
    "redoutât": "redouter",
    "redoutâtes": "redouter",
    "redoutèrent": "redouter",
    "redouté": "redouter",
    "redoutée": "redouter",
    "redoutées": "redouter",
    "redoutés": "redouter",
    "redressa": "redresser",
    "redressai": "redresser",
    "redressaient": "redresser",
    "redressais": "redresser",
    "redressait": "redresser",
    "redressant": "redresser",
    "redressas": "redresser",
    "redressasse": "redresser",
    "redressassent": "redresser",
    "redressasses": "redresser",
    "redressassiez": "redresser",
    "redressassions": "redresser",
    "redresse": "redresser",
    "redressements": "redressement",
    "redressent": "redresser",
    "redressera": "redresser",
    "redresserai": "redresser",
    "redresseraient": "redresser",
    "redresserais": "redresser",
    "redresserait": "redresser",
    "redresseras": "redresser",
    "redresserez": "redresser",
    "redresseriez": "redresser",
    "redresserions": "redresser",
    "redresserons": "redresser",
    "redresseront": "redresser",
    "redresses": "redresser",
    "redresseurs": "redresseur",
    "redresseuse": "redresseur",
    "redresseuses": "redresseur",
    "redressez": "redresser",
    "redressiez": "redresser",
    "redressions": "redresser",
    "redressons": "redresser",
    "redressâmes": "redresser",
    "redressât": "redresser",
    "redressâtes": "redresser",
    "redressèrent": "redresser",
    "redressé": "redresser",
    "redressée": "redresser",
    "redressées": "redresser",
    "redressés": "redresser",
    "redurent": "redevoir",
    "redus": "redevoir",
    "redusse": "redevoir",
    "redussent": "redevoir",
    "redusses": "redevoir",
    "redussiez": "redevoir",
    "redussions": "redevoir",
    "redut": "redevoir",
    "redynamisa": "redynamiser",
    "redynamisai": "redynamiser",
    "redynamisaient": "redynamiser",
    "redynamisais": "redynamiser",
    "redynamisait": "redynamiser",
    "redynamisant": "redynamiser",
    "redynamisas": "redynamiser",
    "redynamisasse": "redynamiser",
    "redynamisassent": "redynamiser",
    "redynamisasses": "redynamiser",
    "redynamisassiez": "redynamiser",
    "redynamisassions": "redynamiser",
    "redynamisations": "redynamisation",
    "redynamise": "redynamiser",
    "redynamisent": "redynamiser",
    "redynamisera": "redynamiser",
    "redynamiserai": "redynamiser",
    "redynamiseraient": "redynamiser",
    "redynamiserais": "redynamiser",
    "redynamiserait": "redynamiser",
    "redynamiseras": "redynamiser",
    "redynamiserez": "redynamiser",
    "redynamiseriez": "redynamiser",
    "redynamiserions": "redynamiser",
    "redynamiserons": "redynamiser",
    "redynamiseront": "redynamiser",
    "redynamises": "redynamiser",
    "redynamisez": "redynamiser",
    "redynamisiez": "redynamiser",
    "redynamisions": "redynamiser",
    "redynamisons": "redynamiser",
    "redynamisâmes": "redynamiser",
    "redynamisât": "redynamiser",
    "redynamisâtes": "redynamiser",
    "redynamisèrent": "redynamiser",
    "redynamisé": "redynamiser",
    "redynamisée": "redynamiser",
    "redynamisées": "redynamiser",
    "redynamisés": "redynamiser",
    "redécouvert": "redécouvrir",
    "redécouverte": "redécouvrir",
    "redécouvertes": "redécouvrir",
    "redécouverts": "redécouvrir",
    "redécouvraient": "redécouvrir",
    "redécouvrais": "redécouvrir",
    "redécouvrait": "redécouvrir",
    "redécouvrant": "redécouvrir",
    "redécouvre": "redécouvrir",
    "redécouvrent": "redécouvrir",
    "redécouvres": "redécouvrir",
    "redécouvrez": "redécouvrir",
    "redécouvriez": "redécouvrir",
    "redécouvrions": "redécouvrir",
    "redécouvrira": "redécouvrir",
    "redécouvrirai": "redécouvrir",
    "redécouvriraient": "redécouvrir",
    "redécouvrirais": "redécouvrir",
    "redécouvrirait": "redécouvrir",
    "redécouvriras": "redécouvrir",
    "redécouvrirent": "redécouvrir",
    "redécouvrirez": "redécouvrir",
    "redécouvririez": "redécouvrir",
    "redécouvririons": "redécouvrir",
    "redécouvrirons": "redécouvrir",
    "redécouvriront": "redécouvrir",
    "redécouvris": "redécouvrir",
    "redécouvrisse": "redécouvrir",
    "redécouvrissent": "redécouvrir",
    "redécouvrisses": "redécouvrir",
    "redécouvrissiez": "redécouvrir",
    "redécouvrissions": "redécouvrir",
    "redécouvrit": "redécouvrir",
    "redécouvrons": "redécouvrir",
    "redécouvrîmes": "redécouvrir",
    "redécouvrît": "redécouvrir",
    "redécouvrîtes": "redécouvrir",
    "redéfais": "redéfaire",
    "redéfaisaient": "redéfaire",
    "redéfaisais": "redéfaire",
    "redéfaisait": "redéfaire",
    "redéfaisant": "redéfaire",
    "redéfaisiez": "redéfaire",
    "redéfaisions": "redéfaire",
    "redéfaisons": "redéfaire",
    "redéfait": "redéfaire",
    "redéfaite": "redéfaire",
    "redéfaites": "redéfaire",
    "redéfaits": "redéfaire",
    "redéfasse": "redéfaire",
    "redéfassent": "redéfaire",
    "redéfasses": "redéfaire",
    "redéfassiez": "redéfaire",
    "redéfassions": "redéfaire",
    "redéfera": "redéfaire",
    "redéferai": "redéfaire",
    "redéferaient": "redéfaire",
    "redéferais": "redéfaire",
    "redéferait": "redéfaire",
    "redéferas": "redéfaire",
    "redéferez": "redéfaire",
    "redéferiez": "redéfaire",
    "redéferions": "redéfaire",
    "redéferons": "redéfaire",
    "redéferont": "redéfaire",
    "redéfini": "redéfinir",
    "redéfinie": "redéfinir",
    "redéfinies": "redéfinir",
    "redéfinira": "redéfinir",
    "redéfinirai": "redéfinir",
    "redéfiniraient": "redéfinir",
    "redéfinirais": "redéfinir",
    "redéfinirait": "redéfinir",
    "redéfiniras": "redéfinir",
    "redéfinirent": "redéfinir",
    "redéfinirez": "redéfinir",
    "redéfiniriez": "redéfinir",
    "redéfinirions": "redéfinir",
    "redéfinirons": "redéfinir",
    "redéfiniront": "redéfinir",
    "redéfinis": "redéfinir",
    "redéfinissaient": "redéfinir",
    "redéfinissais": "redéfinir",
    "redéfinissait": "redéfinir",
    "redéfinissant": "redéfinir",
    "redéfinisse": "redéfinir",
    "redéfinissent": "redéfinir",
    "redéfinisses": "redéfinir",
    "redéfinissez": "redéfinir",
    "redéfinissiez": "redéfinir",
    "redéfinissions": "redéfinir",
    "redéfinissons": "redéfinir",
    "redéfinit": "redéfinir",
    "redéfinitions": "redéfinition",
    "redéfinîmes": "redéfinir",
    "redéfinît": "redéfinir",
    "redéfinîtes": "redéfinir",
    "redéfirent": "redéfaire",
    "redéfis": "redéfaire",
    "redéfisse": "redéfaire",
    "redéfissent": "redéfaire",
    "redéfisses": "redéfaire",
    "redéfissiez": "redéfaire",
    "redéfissions": "redéfaire",
    "redéfit": "redéfaire",
    "redéfont": "redéfaire",
    "redéfîmes": "redéfaire",
    "redéfît": "redéfaire",
    "redéfîtes": "redéfaire",
    "redémarra": "redémarrer",
    "redémarrages": "redémarrage",
    "redémarrai": "redémarrer",
    "redémarraient": "redémarrer",
    "redémarrais": "redémarrer",
    "redémarrait": "redémarrer",
    "redémarrant": "redémarrer",
    "redémarras": "redémarrer",
    "redémarrasse": "redémarrer",
    "redémarrassent": "redémarrer",
    "redémarrasses": "redémarrer",
    "redémarrassiez": "redémarrer",
    "redémarrassions": "redémarrer",
    "redémarre": "redémarrer",
    "redémarrent": "redémarrer",
    "redémarrera": "redémarrer",
    "redémarrerai": "redémarrer",
    "redémarreraient": "redémarrer",
    "redémarrerais": "redémarrer",
    "redémarrerait": "redémarrer",
    "redémarreras": "redémarrer",
    "redémarrerez": "redémarrer",
    "redémarreriez": "redémarrer",
    "redémarrerions": "redémarrer",
    "redémarrerons": "redémarrer",
    "redémarreront": "redémarrer",
    "redémarres": "redémarrer",
    "redémarrez": "redémarrer",
    "redémarriez": "redémarrer",
    "redémarrions": "redémarrer",
    "redémarrons": "redémarrer",
    "redémarrâmes": "redémarrer",
    "redémarrât": "redémarrer",
    "redémarrâtes": "redémarrer",
    "redémarrèrent": "redémarrer",
    "redémarré": "redémarrer",
    "redémarrée": "redémarrer",
    "redémarrées": "redémarrer",
    "redémarrés": "redémarrer",
    "redémoli": "redémolir",
    "redémolie": "redémolir",
    "redémolies": "redémolir",
    "redémolira": "redémolir",
    "redémolirai": "redémolir",
    "redémoliraient": "redémolir",
    "redémolirais": "redémolir",
    "redémolirait": "redémolir",
    "redémoliras": "redémolir",
    "redémolirent": "redémolir",
    "redémolirez": "redémolir",
    "redémoliriez": "redémolir",
    "redémolirions": "redémolir",
    "redémolirons": "redémolir",
    "redémoliront": "redémolir",
    "redémolis": "redémolir",
    "redémolissaient": "redémolir",
    "redémolissais": "redémolir",
    "redémolissait": "redémolir",
    "redémolissant": "redémolir",
    "redémolisse": "redémolir",
    "redémolissent": "redémolir",
    "redémolisses": "redémolir",
    "redémolissez": "redémolir",
    "redémolissiez": "redémolir",
    "redémolissions": "redémolir",
    "redémolissons": "redémolir",
    "redémolit": "redémolir",
    "redémolîmes": "redémolir",
    "redémolît": "redémolir",
    "redémolîtes": "redémolir",
    "redéploie": "redéployer",
    "redéploiements": "redéploiement",
    "redéploient": "redéployer",
    "redéploiera": "redéployer",
    "redéploierai": "redéployer",
    "redéploieraient": "redéployer",
    "redéploierais": "redéployer",
    "redéploierait": "redéployer",
    "redéploieras": "redéployer",
    "redéploierez": "redéployer",
    "redéploieriez": "redéployer",
    "redéploierions": "redéployer",
    "redéploierons": "redéployer",
    "redéploieront": "redéployer",
    "redéploies": "redéployer",
    "redéploya": "redéployer",
    "redéployai": "redéployer",
    "redéployaient": "redéployer",
    "redéployais": "redéployer",
    "redéployait": "redéployer",
    "redéployant": "redéployer",
    "redéployas": "redéployer",
    "redéployasse": "redéployer",
    "redéployassent": "redéployer",
    "redéployasses": "redéployer",
    "redéployassiez": "redéployer",
    "redéployassions": "redéployer",
    "redéployez": "redéployer",
    "redéployiez": "redéployer",
    "redéployions": "redéployer",
    "redéployons": "redéployer",
    "redéployâmes": "redéployer",
    "redéployât": "redéployer",
    "redéployâtes": "redéployer",
    "redéployèrent": "redéployer",
    "redéployé": "redéployer",
    "redéployée": "redéployer",
    "redéployées": "redéployer",
    "redéployés": "redéployer",
    "redéposé": "redéposer",
    "redîmes": "redire",
    "redît": "redire",
    "redîtes": "redire",
    "redû": "redevoir",
    "redûe": "redevoir",
    "redûes": "redevoir",
    "redûmes": "redevoir",
    "redûs": "redevoir",
    "redût": "redevoir",
    "redûtes": "redevoir",
    "refais": "refaire",
    "refaisaient": "refaire",
    "refaisais": "refaire",
    "refaisait": "refaire",
    "refaisant": "refaire",
    "refaisiez": "refaire",
    "refaisions": "refaire",
    "refaisons": "refaire",
    "refait": "refaire",
    "refaite": "refait",
    "refaites": "refait",
    "refaits": "refait",
    "refasse": "refaire",
    "refassent": "refaire",
    "refasses": "refaire",
    "refassiez": "refaire",
    "refassions": "refaire",
    "refaufile": "refaufiler",
    "refend": "refendre",
    "refendaient": "refendre",
    "refendais": "refendre",
    "refendait": "refendre",
    "refendant": "refendre",
    "refende": "refendre",
    "refendent": "refendre",
    "refendes": "refendre",
    "refendez": "refendre",
    "refendiez": "refendre",
    "refendions": "refendre",
    "refendirent": "refendre",
    "refendis": "refendre",
    "refendisse": "refendre",
    "refendissent": "refendre",
    "refendisses": "refendre",
    "refendissiez": "refendre",
    "refendissions": "refendre",
    "refendit": "refendre",
    "refendons": "refendre",
    "refendra": "refendre",
    "refendrai": "refendre",
    "refendraient": "refendre",
    "refendrais": "refendre",
    "refendrait": "refendre",
    "refendras": "refendre",
    "refendrez": "refendre",
    "refendriez": "refendre",
    "refendrions": "refendre",
    "refendrons": "refendre",
    "refendront": "refendre",
    "refends": "refendre",
    "refendu": "refendre",
    "refendue": "refendre",
    "refendues": "refendre",
    "refendus": "refendre",
    "refendîmes": "refendre",
    "refendît": "refendre",
    "refendîtes": "refendre",
    "refera": "refaire",
    "referai": "refaire",
    "referaient": "refaire",
    "referais": "refaire",
    "referait": "refaire",
    "referas": "refaire",
    "referenda": "referendum",
    "referez": "refaire",
    "referiez": "refaire",
    "referions": "refaire",
    "referma": "refermer",
    "refermai": "refermer",
    "refermaient": "refermer",
    "refermais": "refermer",
    "refermait": "refermer",
    "refermant": "refermer",
    "refermas": "refermer",
    "refermasse": "refermer",
    "refermassent": "refermer",
    "refermasses": "refermer",
    "refermassiez": "refermer",
    "refermassions": "refermer",
    "referme": "refermer",
    "referment": "refermer",
    "refermera": "refermer",
    "refermerai": "refermer",
    "refermeraient": "refermer",
    "refermerais": "refermer",
    "refermerait": "refermer",
    "refermeras": "refermer",
    "refermerez": "refermer",
    "refermeriez": "refermer",
    "refermerions": "refermer",
    "refermerons": "refermer",
    "refermeront": "refermer",
    "refermes": "refermer",
    "refermez": "refermer",
    "refermiez": "refermer",
    "refermions": "refermer",
    "refermons": "refermer",
    "refermâmes": "refermer",
    "refermât": "refermer",
    "refermâtes": "refermer",
    "refermèrent": "refermer",
    "refermé": "refermer",
    "refermée": "refermer",
    "refermées": "refermer",
    "refermés": "refermer",
    "referons": "refaire",
    "referont": "refaire",
    "reficelai": "reficeler",
    "reficelle": "reficeler",
    "refila": "refiler",
    "refilai": "refiler",
    "refilaient": "refiler",
    "refilais": "refiler",
    "refilait": "refiler",
    "refilant": "refiler",
    "refile": "refiler",
    "refilent": "refiler",
    "refilera": "refiler",
    "refilerait": "refiler",
    "refiles": "refiler",
    "refilez": "refiler",
    "refilé": "refiler",
    "refilée": "refiler",
    "refilées": "refiler",
    "refilés": "refiler",
    "refinancements": "refinancement",
    "refinancée": "refinancer",
    "refirent": "refaire",
    "refis": "refaire",
    "refisse": "refaire",
    "refissent": "refaire",
    "refisses": "refaire",
    "refissiez": "refaire",
    "refissions": "refaire",
    "refit": "refaire",
    "reflets": "reflet",
    "refleuri": "refleurir",
    "refleurie": "refleurir",
    "refleuries": "refleurir",
    "refleurira": "refleurir",
    "refleurirai": "refleurir",
    "refleuriraient": "refleurir",
    "refleurirais": "refleurir",
    "refleurirait": "refleurir",
    "refleuriras": "refleurir",
    "refleurirent": "refleurir",
    "refleurirez": "refleurir",
    "refleuririez": "refleurir",
    "refleuririons": "refleurir",
    "refleurirons": "refleurir",
    "refleuriront": "refleurir",
    "refleuris": "refleurir",
    "refleurissaient": "refleurir",
    "refleurissais": "refleurir",
    "refleurissait": "refleurir",
    "refleurissant": "refleurir",
    "refleurisse": "refleurir",
    "refleurissent": "refleurir",
    "refleurisses": "refleurir",
    "refleurissez": "refleurir",
    "refleurissiez": "refleurir",
    "refleurissions": "refleurir",
    "refleurissons": "refleurir",
    "refleurit": "refleurir",
    "refleurîmes": "refleurir",
    "refleurît": "refleurir",
    "refleurîtes": "refleurir",
    "reflua": "refluer",
    "refluai": "refluer",
    "refluaient": "refluer",
    "refluais": "refluer",
    "refluait": "refluer",
    "refluant": "refluer",
    "refluas": "refluer",
    "refluasse": "refluer",
    "refluassent": "refluer",
    "refluasses": "refluer",
    "refluassiez": "refluer",
    "refluassions": "refluer",
    "reflue": "refluer",
    "refluent": "refluer",
    "refluera": "refluer",
    "refluerai": "refluer",
    "reflueraient": "refluer",
    "refluerais": "refluer",
    "refluerait": "refluer",
    "reflueras": "refluer",
    "refluerez": "refluer",
    "reflueriez": "refluer",
    "refluerions": "refluer",
    "refluerons": "refluer",
    "reflueront": "refluer",
    "reflues": "refluer",
    "refluez": "refluer",
    "refluiez": "refluer",
    "refluions": "refluer",
    "refluons": "refluer",
    "refluâmes": "refluer",
    "refluât": "refluer",
    "refluâtes": "refluer",
    "refluèrent": "refluer",
    "reflué": "refluer",
    "refluée": "refluer",
    "reflète": "refléter",
    "reflètent": "refléter",
    "reflètes": "refléter",
    "refléta": "refléter",
    "reflétai": "refléter",
    "reflétaient": "refléter",
    "reflétais": "refléter",
    "reflétait": "refléter",
    "reflétant": "refléter",
    "reflétas": "refléter",
    "reflétasse": "refléter",
    "reflétassent": "refléter",
    "reflétasses": "refléter",
    "reflétassiez": "refléter",
    "reflétassions": "refléter",
    "reflétera": "refléter",
    "refléterai": "refléter",
    "refléteraient": "refléter",
    "refléterais": "refléter",
    "refléterait": "refléter",
    "refléteras": "refléter",
    "refléterez": "refléter",
    "refléteriez": "refléter",
    "refléterions": "refléter",
    "refléterons": "refléter",
    "refléteront": "refléter",
    "reflétez": "refléter",
    "reflétiez": "refléter",
    "reflétions": "refléter",
    "reflétons": "refléter",
    "reflétâmes": "refléter",
    "reflétât": "refléter",
    "reflétâtes": "refléter",
    "reflétèrent": "refléter",
    "reflété": "refléter",
    "reflétée": "refléter",
    "reflétées": "refléter",
    "reflétés": "refléter",
    "refond": "refondre",
    "refonda": "refonder",
    "refondai": "refonder",
    "refondaient": "refondre",
    "refondais": "refondre",
    "refondait": "refondre",
    "refondant": "refondre",
    "refondas": "refonder",
    "refondasse": "refonder",
    "refondassent": "refonder",
    "refondasses": "refonder",
    "refondassiez": "refonder",
    "refondassions": "refonder",
    "refondateurs": "refondateur",
    "refondations": "refondation",
    "refondatrice": "refondateur",
    "refondatrices": "refondateur",
    "refonde": "refondre",
    "refondent": "refondre",
    "refondera": "refonder",
    "refonderai": "refonder",
    "refonderaient": "refonder",
    "refonderais": "refonder",
    "refonderait": "refonder",
    "refonderas": "refonder",
    "refonderez": "refonder",
    "refonderiez": "refonder",
    "refonderions": "refonder",
    "refonderons": "refonder",
    "refonderont": "refonder",
    "refondes": "refondre",
    "refondez": "refondre",
    "refondiez": "refondre",
    "refondions": "refondre",
    "refondirent": "refondre",
    "refondis": "refondre",
    "refondisse": "refondre",
    "refondissent": "refondre",
    "refondisses": "refondre",
    "refondissiez": "refondre",
    "refondissions": "refondre",
    "refondit": "refondre",
    "refondons": "refondre",
    "refondra": "refondre",
    "refondrai": "refondre",
    "refondraient": "refondre",
    "refondrais": "refondre",
    "refondrait": "refondre",
    "refondras": "refondre",
    "refondrez": "refondre",
    "refondriez": "refondre",
    "refondrions": "refondre",
    "refondrons": "refondre",
    "refondront": "refondre",
    "refonds": "refondre",
    "refondu": "refondre",
    "refondue": "refondre",
    "refondues": "refondre",
    "refondus": "refondre",
    "refondâmes": "refonder",
    "refondât": "refonder",
    "refondâtes": "refonder",
    "refondèrent": "refonder",
    "refondé": "refonder",
    "refondée": "refonder",
    "refondées": "refonder",
    "refondés": "refonder",
    "refondîmes": "refondre",
    "refondît": "refondre",
    "refondîtes": "refondre",
    "refont": "refaire",
    "refontes": "refonte",
    "reforestations": "reforestation",
    "reforge": "reforger",
    "reforgea": "reforger",
    "reforgeai": "reforger",
    "reforgeaient": "reforger",
    "reforgeais": "reforger",
    "reforgeait": "reforger",
    "reforgeant": "reforger",
    "reforgeas": "reforger",
    "reforgeasse": "reforger",
    "reforgeassent": "reforger",
    "reforgeasses": "reforger",
    "reforgeassiez": "reforger",
    "reforgeassions": "reforger",
    "reforgent": "reforger",
    "reforgeons": "reforger",
    "reforgera": "reforger",
    "reforgerai": "reforger",
    "reforgeraient": "reforger",
    "reforgerais": "reforger",
    "reforgerait": "reforger",
    "reforgeras": "reforger",
    "reforgerez": "reforger",
    "reforgeriez": "reforger",
    "reforgerions": "reforger",
    "reforgerons": "reforger",
    "reforgeront": "reforger",
    "reforges": "reforger",
    "reforgez": "reforger",
    "reforgeâmes": "reforger",
    "reforgeât": "reforger",
    "reforgeâtes": "reforger",
    "reforgiez": "reforger",
    "reforgions": "reforger",
    "reforgèrent": "reforger",
    "reforgé": "reforger",
    "reforgée": "reforger",
    "reforgées": "reforger",
    "reforgés": "reforger",
    "reforma": "reformer",
    "reformai": "reformer",
    "reformaient": "reformer",
    "reformais": "reformer",
    "reformait": "reformer",
    "reformant": "reformer",
    "reformas": "reformer",
    "reformasse": "reformer",
    "reformassent": "reformer",
    "reformasses": "reformer",
    "reformassiez": "reformer",
    "reformassions": "reformer",
    "reforme": "reformer",
    "reforment": "reformer",
    "reformera": "reformer",
    "reformerai": "reformer",
    "reformeraient": "reformer",
    "reformerais": "reformer",
    "reformerait": "reformer",
    "reformeras": "reformer",
    "reformerez": "reformer",
    "reformeriez": "reformer",
    "reformerions": "reformer",
    "reformerons": "reformer",
    "reformeront": "reformer",
    "reformes": "reformer",
    "reformez": "reformer",
    "reformiez": "reformer",
    "reformions": "reformer",
    "reformons": "reformer",
    "reformulations": "reformulation",
    "reformulé": "reformuler",
    "reformulée": "reformuler",
    "reformâmes": "reformer",
    "reformât": "reformer",
    "reformâtes": "reformer",
    "reformèrent": "reformer",
    "reformé": "reformer",
    "reformée": "reformer",
    "reformées": "reformer",
    "reformés": "reformer",
    "refouilla": "refouiller",
    "refouillai": "refouiller",
    "refouillaient": "refouiller",
    "refouillais": "refouiller",
    "refouillait": "refouiller",
    "refouillant": "refouiller",
    "refouillas": "refouiller",
    "refouillasse": "refouiller",
    "refouillassent": "refouiller",
    "refouillasses": "refouiller",
    "refouillassiez": "refouiller",
    "refouillassions": "refouiller",
    "refouille": "refouiller",
    "refouillent": "refouiller",
    "refouillera": "refouiller",
    "refouillerai": "refouiller",
    "refouilleraient": "refouiller",
    "refouillerais": "refouiller",
    "refouillerait": "refouiller",
    "refouilleras": "refouiller",
    "refouillerez": "refouiller",
    "refouilleriez": "refouiller",
    "refouillerions": "refouiller",
    "refouillerons": "refouiller",
    "refouilleront": "refouiller",
    "refouilles": "refouiller",
    "refouillez": "refouiller",
    "refouilliez": "refouiller",
    "refouillions": "refouiller",
    "refouillons": "refouiller",
    "refouillâmes": "refouiller",
    "refouillât": "refouiller",
    "refouillâtes": "refouiller",
    "refouillèrent": "refouiller",
    "refouillé": "refouiller",
    "refouillée": "refouiller",
    "refouillées": "refouiller",
    "refouillés": "refouiller",
    "refoula": "refouler",
    "refoulai": "refouler",
    "refoulaient": "refouler",
    "refoulais": "refouler",
    "refoulait": "refouler",
    "refoulant": "refouler",
    "refoulante": "refoulant",
    "refoulas": "refouler",
    "refoulasse": "refouler",
    "refoulassent": "refouler",
    "refoulasses": "refouler",
    "refoulassiez": "refouler",
    "refoulassions": "refouler",
    "refoule": "refouler",
    "refoulements": "refoulement",
    "refoulent": "refouler",
    "refoulera": "refouler",
    "refoulerai": "refouler",
    "refouleraient": "refouler",
    "refoulerais": "refouler",
    "refoulerait": "refouler",
    "refouleras": "refouler",
    "refoulerez": "refouler",
    "refouleriez": "refouler",
    "refoulerions": "refouler",
    "refoulerons": "refouler",
    "refouleront": "refouler",
    "refoules": "refouler",
    "refoulez": "refouler",
    "refouliez": "refouler",
    "refoulions": "refouler",
    "refoulons": "refouler",
    "refoulâmes": "refouler",
    "refoulât": "refouler",
    "refoulâtes": "refouler",
    "refoulèrent": "refouler",
    "refoulé": "refouler",
    "refoulée": "refouler",
    "refoulées": "refouler",
    "refoulés": "refouler",
    "refourgua": "refourguer",
    "refourgue": "refourguer",
    "refourguera": "refourguer",
    "refourguerait": "refourguer",
    "refourguions": "refourguer",
    "refourgué": "refourguer",
    "refourguées": "refourguer",
    "refourgués": "refourguer",
    "refourni": "refournir",
    "refournie": "refournir",
    "refournies": "refournir",
    "refournira": "refournir",
    "refournirai": "refournir",
    "refourniraient": "refournir",
    "refournirais": "refournir",
    "refournirait": "refournir",
    "refourniras": "refournir",
    "refournirent": "refournir",
    "refournirez": "refournir",
    "refourniriez": "refournir",
    "refournirions": "refournir",
    "refournirons": "refournir",
    "refourniront": "refournir",
    "refournis": "refournir",
    "refournissaient": "refournir",
    "refournissais": "refournir",
    "refournissait": "refournir",
    "refournissant": "refournir",
    "refournisse": "refournir",
    "refournissent": "refournir",
    "refournisses": "refournir",
    "refournissez": "refournir",
    "refournissiez": "refournir",
    "refournissions": "refournir",
    "refournissons": "refournir",
    "refournit": "refournir",
    "refournîmes": "refournir",
    "refournît": "refournir",
    "refournîtes": "refournir",
    "refourra": "refourrer",
    "refourrai": "refourrer",
    "refourraient": "refourrer",
    "refourrais": "refourrer",
    "refourrait": "refourrer",
    "refourrant": "refourrer",
    "refourras": "refourrer",
    "refourrasse": "refourrer",
    "refourrassent": "refourrer",
    "refourrasses": "refourrer",
    "refourrassiez": "refourrer",
    "refourrassions": "refourrer",
    "refourre": "refourrer",
    "refourrent": "refourrer",
    "refourrera": "refourrer",
    "refourrerai": "refourrer",
    "refourreraient": "refourrer",
    "refourrerais": "refourrer",
    "refourrerait": "refourrer",
    "refourreras": "refourrer",
    "refourrerez": "refourrer",
    "refourreriez": "refourrer",
    "refourrerions": "refourrer",
    "refourrerons": "refourrer",
    "refourreront": "refourrer",
    "refourres": "refourrer",
    "refourrez": "refourrer",
    "refourriez": "refourrer",
    "refourrions": "refourrer",
    "refourrons": "refourrer",
    "refourrâmes": "refourrer",
    "refourrât": "refourrer",
    "refourrâtes": "refourrer",
    "refourrèrent": "refourrer",
    "refourré": "refourrer",
    "refourrée": "refourrer",
    "refourrées": "refourrer",
    "refourrés": "refourrer",
    "refous": "refoutre",
    "refout": "refoutre",
    "refoutait": "refoutre",
    "refoute": "refoutre",
    "refoutent": "refoutre",
    "refoutes": "refoutre",
    "refoutez": "refoutre",
    "refoutu": "refoutre",
    "refrains": "refrain",
    "refranchies": "refranchir",
    "refrappe": "refrapper",
    "refroidi": "refroidir",
    "refroidie": "refroidir",
    "refroidies": "refroidir",
    "refroidira": "refroidir",
    "refroidirai": "refroidir",
    "refroidiraient": "refroidir",
    "refroidirais": "refroidir",
    "refroidirait": "refroidir",
    "refroidiras": "refroidir",
    "refroidirent": "refroidir",
    "refroidirez": "refroidir",
    "refroidiriez": "refroidir",
    "refroidirions": "refroidir",
    "refroidirons": "refroidir",
    "refroidiront": "refroidir",
    "refroidis": "refroidir",
    "refroidissaient": "refroidir",
    "refroidissais": "refroidir",
    "refroidissait": "refroidir",
    "refroidissant": "refroidir",
    "refroidisse": "refroidir",
    "refroidissements": "refroidissement",
    "refroidissent": "refroidir",
    "refroidisses": "refroidir",
    "refroidissez": "refroidir",
    "refroidissiez": "refroidir",
    "refroidissions": "refroidir",
    "refroidissons": "refroidir",
    "refroidit": "refroidir",
    "refroidîmes": "refroidir",
    "refroidît": "refroidir",
    "refroidîtes": "refroidir",
    "refrène": "refréner",
    "refrènements": "refrènement",
    "refrènent": "refréner",
    "refrènes": "refréner",
    "refréna": "refréner",
    "refrénai": "refréner",
    "refrénaient": "refréner",
    "refrénais": "refréner",
    "refrénait": "refréner",
    "refrénant": "refréner",
    "refrénas": "refréner",
    "refrénasse": "refréner",
    "refrénassent": "refréner",
    "refrénasses": "refréner",
    "refrénassiez": "refréner",
    "refrénassions": "refréner",
    "refrénera": "refréner",
    "refrénerai": "refréner",
    "refréneraient": "refréner",
    "refrénerais": "refréner",
    "refrénerait": "refréner",
    "refréneras": "refréner",
    "refrénerez": "refréner",
    "refréneriez": "refréner",
    "refrénerions": "refréner",
    "refrénerons": "refréner",
    "refréneront": "refréner",
    "refrénez": "refréner",
    "refréniez": "refréner",
    "refrénions": "refréner",
    "refrénons": "refréner",
    "refrénâmes": "refréner",
    "refrénât": "refréner",
    "refrénâtes": "refréner",
    "refrénèrent": "refréner",
    "refréné": "refréner",
    "refrénée": "refréner",
    "refrénées": "refréner",
    "refrénés": "refréner",
    "refuges": "refuge",
    "refui": "refuir",
    "refuie": "refuir",
    "refuient": "refuir",
    "refuies": "refuir",
    "refuira": "refuir",
    "refuirai": "refuir",
    "refuiraient": "refuir",
    "refuirais": "refuir",
    "refuirait": "refuir",
    "refuiras": "refuir",
    "refuirent": "refuir",
    "refuirez": "refuir",
    "refuiriez": "refuir",
    "refuirions": "refuir",
    "refuirons": "refuir",
    "refuiront": "refuir",
    "refuis": "refuir",
    "refuisse": "refuir",
    "refuissent": "refuir",
    "refuisses": "refuir",
    "refuissiez": "refuir",
    "refuissions": "refuir",
    "refuit": "refuir",
    "refuites": "refuite",
    "refusa": "refuser",
    "refusai": "refuser",
    "refusaient": "refuser",
    "refusais": "refuser",
    "refusait": "refuser",
    "refusant": "refuser",
    "refusas": "refuser",
    "refusasse": "refuser",
    "refusassent": "refuser",
    "refusasses": "refuser",
    "refusassiez": "refuser",
    "refusassions": "refuser",
    "refuse": "refuser",
    "refusent": "refuser",
    "refusera": "refuser",
    "refuserai": "refuser",
    "refuseraient": "refuser",
    "refuserais": "refuser",
    "refuserait": "refuser",
    "refuseras": "refuser",
    "refuserez": "refuser",
    "refuseriez": "refuser",
    "refuserions": "refuser",
    "refuserons": "refuser",
    "refuseront": "refuser",
    "refuses": "refuser",
    "refusez": "refuser",
    "refusiez": "refuser",
    "refusions": "refuser",
    "refusons": "refuser",
    "refusâmes": "refuser",
    "refusât": "refuser",
    "refusâtes": "refuser",
    "refusèrent": "refuser",
    "refusé": "refuser",
    "refusée": "refuser",
    "refusées": "refuser",
    "refusés": "refuser",
    "refuyaient": "refuir",
    "refuyais": "refuir",
    "refuyait": "refuir",
    "refuyant": "refuir",
    "refuyez": "refuir",
    "refuyiez": "refuir",
    "refuyions": "refuir",
    "refuyons": "refuir",
    "refuîmes": "refuir",
    "refuît": "refuir",
    "refuîtes": "refuir",
    "refîmes": "refaire",
    "refît": "refaire",
    "refîtes": "refaire",
    "regagna": "regagner",
    "regagnai": "regagner",
    "regagnaient": "regagner",
    "regagnais": "regagner",
    "regagnait": "regagner",
    "regagnant": "regagner",
    "regagnas": "regagner",
    "regagnasse": "regagner",
    "regagnassent": "regagner",
    "regagnasses": "regagner",
    "regagnassiez": "regagner",
    "regagnassions": "regagner",
    "regagne": "regagner",
    "regagnent": "regagner",
    "regagnera": "regagner",
    "regagnerai": "regagner",
    "regagneraient": "regagner",
    "regagnerais": "regagner",
    "regagnerait": "regagner",
    "regagneras": "regagner",
    "regagnerez": "regagner",
    "regagneriez": "regagner",
    "regagnerions": "regagner",
    "regagnerons": "regagner",
    "regagneront": "regagner",
    "regagnes": "regagner",
    "regagnez": "regagner",
    "regagniez": "regagner",
    "regagnions": "regagner",
    "regagnons": "regagner",
    "regagnâmes": "regagner",
    "regagnât": "regagner",
    "regagnâtes": "regagner",
    "regagnèrent": "regagner",
    "regagné": "regagner",
    "regagnée": "regagner",
    "regagnées": "regagner",
    "regagnés": "regagner",
    "regains": "regain",
    "regarda": "regarder",
    "regardables": "regardable",
    "regardai": "regarder",
    "regardaient": "regarder",
    "regardais": "regarder",
    "regardait": "regarder",
    "regardant": "regarder",
    "regardante": "regardant",
    "regardantes": "regardant",
    "regardants": "regardant",
    "regardas": "regarder",
    "regardasse": "regarder",
    "regardassent": "regarder",
    "regardasses": "regarder",
    "regardassiez": "regarder",
    "regardassions": "regarder",
    "regarde": "regarder",
    "regardent": "regarder",
    "regardera": "regarder",
    "regarderai": "regarder",
    "regarderaient": "regarder",
    "regarderais": "regarder",
    "regarderait": "regarder",
    "regarderas": "regarder",
    "regarderez": "regarder",
    "regarderiez": "regarder",
    "regarderions": "regarder",
    "regarderons": "regarder",
    "regarderont": "regarder",
    "regardes": "regarder",
    "regardez": "regarder",
    "regardiez": "regarder",
    "regardions": "regarder",
    "regardons": "regarder",
    "regards": "regard",
    "regardâmes": "regarder",
    "regardât": "regarder",
    "regardâtes": "regarder",
    "regardèrent": "regarder",
    "regardé": "regarder",
    "regardée": "regarder",
    "regardées": "regarder",
    "regardés": "regarder",
    "regarni": "regarnir",
    "regarnie": "regarnir",
    "regarnies": "regarnir",
    "regarnira": "regarnir",
    "regarnirai": "regarnir",
    "regarniraient": "regarnir",
    "regarnirais": "regarnir",
    "regarnirait": "regarnir",
    "regarniras": "regarnir",
    "regarnirent": "regarnir",
    "regarnirez": "regarnir",
    "regarniriez": "regarnir",
    "regarnirions": "regarnir",
    "regarnirons": "regarnir",
    "regarniront": "regarnir",
    "regarnis": "regarnir",
    "regarnissaient": "regarnir",
    "regarnissais": "regarnir",
    "regarnissait": "regarnir",
    "regarnissant": "regarnir",
    "regarnisse": "regarnir",
    "regarnissent": "regarnir",
    "regarnisses": "regarnir",
    "regarnissez": "regarnir",
    "regarnissiez": "regarnir",
    "regarnissions": "regarnir",
    "regarnissons": "regarnir",
    "regarnit": "regarnir",
    "regarnîmes": "regarnir",
    "regarnît": "regarnir",
    "regarnîtes": "regarnir",
    "regela": "regeler",
    "regelai": "regeler",
    "regelaient": "regeler",
    "regelais": "regeler",
    "regelait": "regeler",
    "regelant": "regeler",
    "regelas": "regeler",
    "regelasse": "regeler",
    "regelassent": "regeler",
    "regelasses": "regeler",
    "regelassiez": "regeler",
    "regelassions": "regeler",
    "regelez": "regeler",
    "regeliez": "regeler",
    "regelions": "regeler",
    "regelons": "regeler",
    "regels": "regel",
    "regelâmes": "regeler",
    "regelât": "regeler",
    "regelâtes": "regeler",
    "regelèrent": "regeler",
    "regelé": "regeler",
    "regelée": "regeler",
    "regelées": "regeler",
    "regelés": "regeler",
    "reggaes": "reggae",
    "regimba": "regimber",
    "regimbai": "regimber",
    "regimbaient": "regimber",
    "regimbais": "regimber",
    "regimbait": "regimber",
    "regimbant": "regimber",
    "regimbas": "regimber",
    "regimbasse": "regimber",
    "regimbassent": "regimber",
    "regimbasses": "regimber",
    "regimbassiez": "regimber",
    "regimbassions": "regimber",
    "regimbe": "regimber",
    "regimbements": "regimbement",
    "regimbent": "regimber",
    "regimbera": "regimber",
    "regimberai": "regimber",
    "regimberaient": "regimber",
    "regimberais": "regimber",
    "regimberait": "regimber",
    "regimberas": "regimber",
    "regimberez": "regimber",
    "regimberiez": "regimber",
    "regimberions": "regimber",
    "regimberons": "regimber",
    "regimberont": "regimber",
    "regimbes": "regimber",
    "regimbez": "regimber",
    "regimbiez": "regimber",
    "regimbions": "regimber",
    "regimbons": "regimber",
    "regimbâmes": "regimber",
    "regimbât": "regimber",
    "regimbâtes": "regimber",
    "regimbèrent": "regimber",
    "regimbé": "regimber",
    "registres": "registre",
    "reglissé": "reglisser",
    "regonfla": "regonfler",
    "regonflai": "regonfler",
    "regonflaient": "regonfler",
    "regonflais": "regonfler",
    "regonflait": "regonfler",
    "regonflant": "regonfler",
    "regonflas": "regonfler",
    "regonflasse": "regonfler",
    "regonflassent": "regonfler",
    "regonflasses": "regonfler",
    "regonflassiez": "regonfler",
    "regonflassions": "regonfler",
    "regonfle": "regonfler",
    "regonflent": "regonfler",
    "regonflera": "regonfler",
    "regonflerai": "regonfler",
    "regonfleraient": "regonfler",
    "regonflerais": "regonfler",
    "regonflerait": "regonfler",
    "regonfleras": "regonfler",
    "regonflerez": "regonfler",
    "regonfleriez": "regonfler",
    "regonflerions": "regonfler",
    "regonflerons": "regonfler",
    "regonfleront": "regonfler",
    "regonfles": "regonfler",
    "regonflez": "regonfler",
    "regonfliez": "regonfler",
    "regonflions": "regonfler",
    "regonflons": "regonfler",
    "regonflâmes": "regonfler",
    "regonflât": "regonfler",
    "regonflâtes": "regonfler",
    "regonflèrent": "regonfler",
    "regonflé": "regonfler",
    "regonflée": "regonfler",
    "regonflées": "regonfler",
    "regonflés": "regonfler",
    "regorge": "regorger",
    "regorgea": "regorger",
    "regorgeai": "regorger",
    "regorgeaient": "regorger",
    "regorgeais": "regorger",
    "regorgeait": "regorger",
    "regorgeant": "regorger",
    "regorgeas": "regorger",
    "regorgeasse": "regorger",
    "regorgeassent": "regorger",
    "regorgeasses": "regorger",
    "regorgeassiez": "regorger",
    "regorgeassions": "regorger",
    "regorgent": "regorger",
    "regorgeons": "regorger",
    "regorgera": "regorger",
    "regorgerai": "regorger",
    "regorgeraient": "regorger",
    "regorgerais": "regorger",
    "regorgerait": "regorger",
    "regorgeras": "regorger",
    "regorgerez": "regorger",
    "regorgeriez": "regorger",
    "regorgerions": "regorger",
    "regorgerons": "regorger",
    "regorgeront": "regorger",
    "regorges": "regorger",
    "regorgez": "regorger",
    "regorgeâmes": "regorger",
    "regorgeât": "regorger",
    "regorgeâtes": "regorger",
    "regorgiez": "regorger",
    "regorgions": "regorger",
    "regorgèrent": "regorger",
    "regorgé": "regorger",
    "regoûté": "regoûter",
    "regratta": "regratter",
    "regrattai": "regratter",
    "regrattaient": "regratter",
    "regrattais": "regratter",
    "regrattait": "regratter",
    "regrattant": "regratter",
    "regrattas": "regratter",
    "regrattasse": "regratter",
    "regrattassent": "regratter",
    "regrattasses": "regratter",
    "regrattassiez": "regratter",
    "regrattassions": "regratter",
    "regratte": "regratter",
    "regrattent": "regratter",
    "regrattera": "regratter",
    "regratterai": "regratter",
    "regratteraient": "regratter",
    "regratterais": "regratter",
    "regratterait": "regratter",
    "regratteras": "regratter",
    "regratterez": "regratter",
    "regratteriez": "regratter",
    "regratterions": "regratter",
    "regratterons": "regratter",
    "regratteront": "regratter",
    "regrattes": "regratter",
    "regrattez": "regratter",
    "regrattiez": "regratter",
    "regrattions": "regratter",
    "regrattières": "regrattier",
    "regrattons": "regratter",
    "regrattâmes": "regratter",
    "regrattât": "regratter",
    "regrattâtes": "regratter",
    "regrattèrent": "regratter",
    "regratté": "regratter",
    "regrattée": "regratter",
    "regrattées": "regratter",
    "regrattés": "regratter",
    "regreffe": "regreffer",
    "regrets": "regret",
    "regretta": "regretter",
    "regrettables": "regrettable",
    "regrettai": "regretter",
    "regrettaient": "regretter",
    "regrettais": "regretter",
    "regrettait": "regretter",
    "regrettant": "regretter",
    "regrettas": "regretter",
    "regrettasse": "regretter",
    "regrettassent": "regretter",
    "regrettasses": "regretter",
    "regrettassiez": "regretter",
    "regrettassions": "regretter",
    "regrette": "regretter",
    "regrettent": "regretter",
    "regretter": "rester",
    "regrettera": "regretter",
    "regretterai": "regretter",
    "regretteraient": "regretter",
    "regretterais": "regretter",
    "regretterait": "regretter",
    "regretteras": "regretter",
    "regretterez": "regretter",
    "regretteriez": "regretter",
    "regretterions": "regretter",
    "regretterons": "regretter",
    "regretteront": "regretter",
    "regrettes": "regretter",
    "regrettez": "regretter",
    "regrettiez": "regretter",
    "regrettions": "regretter",
    "regrettons": "regretter",
    "regrettâmes": "regretter",
    "regrettât": "regretter",
    "regrettâtes": "regretter",
    "regrettèrent": "regretter",
    "regretté": "regretter",
    "regrettée": "regretter",
    "regrettées": "regretter",
    "regrettés": "regretter",
    "regrimpa": "regrimper",
    "regrimpai": "regrimper",
    "regrimpaient": "regrimper",
    "regrimpais": "regrimper",
    "regrimpait": "regrimper",
    "regrimpant": "regrimper",
    "regrimpas": "regrimper",
    "regrimpasse": "regrimper",
    "regrimpassent": "regrimper",
    "regrimpasses": "regrimper",
    "regrimpassiez": "regrimper",
    "regrimpassions": "regrimper",
    "regrimpe": "regrimper",
    "regrimpent": "regrimper",
    "regrimpera": "regrimper",
    "regrimperai": "regrimper",
    "regrimperaient": "regrimper",
    "regrimperais": "regrimper",
    "regrimperait": "regrimper",
    "regrimperas": "regrimper",
    "regrimperez": "regrimper",
    "regrimperiez": "regrimper",
    "regrimperions": "regrimper",
    "regrimperons": "regrimper",
    "regrimperont": "regrimper",
    "regrimpes": "regrimper",
    "regrimpez": "regrimper",
    "regrimpiez": "regrimper",
    "regrimpions": "regrimper",
    "regrimpons": "regrimper",
    "regrimpâmes": "regrimper",
    "regrimpât": "regrimper",
    "regrimpâtes": "regrimper",
    "regrimpèrent": "regrimper",
    "regrimpé": "regrimper",
    "regrimpée": "regrimper",
    "regrimpées": "regrimper",
    "regrimpés": "regrimper",
    "regrossi": "regrossir",
    "regrossie": "regrossir",
    "regrossies": "regrossir",
    "regrossira": "regrossir",
    "regrossirai": "regrossir",
    "regrossiraient": "regrossir",
    "regrossirais": "regrossir",
    "regrossirait": "regrossir",
    "regrossiras": "regrossir",
    "regrossirent": "regrossir",
    "regrossirez": "regrossir",
    "regrossiriez": "regrossir",
    "regrossirions": "regrossir",
    "regrossirons": "regrossir",
    "regrossiront": "regrossir",
    "regrossis": "regrossir",
    "regrossissaient": "regrossir",
    "regrossissais": "regrossir",
    "regrossissait": "regrossir",
    "regrossissant": "regrossir",
    "regrossisse": "regrossir",
    "regrossissent": "regrossir",
    "regrossisses": "regrossir",
    "regrossissez": "regrossir",
    "regrossissiez": "regrossir",
    "regrossissions": "regrossir",
    "regrossissons": "regrossir",
    "regrossit": "regrossir",
    "regrossîmes": "regrossir",
    "regrossît": "regrossir",
    "regrossîtes": "regrossir",
    "regroupa": "regrouper",
    "regroupai": "regrouper",
    "regroupaient": "regrouper",
    "regroupais": "regrouper",
    "regroupait": "regrouper",
    "regroupant": "regrouper",
    "regroupas": "regrouper",
    "regroupasse": "regrouper",
    "regroupassent": "regrouper",
    "regroupasses": "regrouper",
    "regroupassiez": "regrouper",
    "regroupassions": "regrouper",
    "regroupe": "regrouper",
    "regroupements": "regroupement",
    "regroupent": "regrouper",
    "regroupera": "regrouper",
    "regrouperai": "regrouper",
    "regrouperaient": "regrouper",
    "regrouperais": "regrouper",
    "regrouperait": "regrouper",
    "regrouperas": "regrouper",
    "regrouperez": "regrouper",
    "regrouperiez": "regrouper",
    "regrouperions": "regrouper",
    "regrouperons": "regrouper",
    "regrouperont": "regrouper",
    "regroupes": "regrouper",
    "regroupez": "regrouper",
    "regroupiez": "regrouper",
    "regroupions": "regrouper",
    "regroupons": "regrouper",
    "regroupâmes": "regrouper",
    "regroupât": "regrouper",
    "regroupâtes": "regrouper",
    "regroupèrent": "regrouper",
    "regroupé": "regrouper",
    "regroupée": "regrouper",
    "regroupées": "regrouper",
    "regroupés": "regrouper",
    "regréaient": "regréer",
    "regréé": "regréer",
    "regèle": "regeler",
    "regèlent": "regeler",
    "regèlera": "regeler",
    "regèlerai": "regeler",
    "regèleraient": "regeler",
    "regèlerais": "regeler",
    "regèlerait": "regeler",
    "regèleras": "regeler",
    "regèlerez": "regeler",
    "regèleriez": "regeler",
    "regèlerions": "regeler",
    "regèlerons": "regeler",
    "regèleront": "regeler",
    "regèles": "regeler",
    "rehaussa": "rehausser",
    "rehaussai": "rehausser",
    "rehaussaient": "rehausser",
    "rehaussais": "rehausser",
    "rehaussait": "rehausser",
    "rehaussant": "rehausser",
    "rehaussas": "rehausser",
    "rehaussasse": "rehausser",
    "rehaussassent": "rehausser",
    "rehaussasses": "rehausser",
    "rehaussassiez": "rehausser",
    "rehaussassions": "rehausser",
    "rehausse": "rehausser",
    "rehaussent": "rehausser",
    "rehaussera": "rehausser",
    "rehausserai": "rehausser",
    "rehausseraient": "rehausser",
    "rehausserais": "rehausser",
    "rehausserait": "rehausser",
    "rehausseras": "rehausser",
    "rehausserez": "rehausser",
    "rehausseriez": "rehausser",
    "rehausserions": "rehausser",
    "rehausserons": "rehausser",
    "rehausseront": "rehausser",
    "rehausses": "rehausser",
    "rehaussez": "rehausser",
    "rehaussiez": "rehausser",
    "rehaussions": "rehausser",
    "rehaussons": "rehausser",
    "rehaussâmes": "rehausser",
    "rehaussât": "rehausser",
    "rehaussâtes": "rehausser",
    "rehaussèrent": "rehausser",
    "rehaussé": "rehausser",
    "rehaussée": "rehausser",
    "rehaussées": "rehausser",
    "rehaussés": "rehausser",
    "rehauts": "rehaut",
    "reines": "reine",
    "reines-claudes": "reine-claude",
    "reines-des-prés": "reine-des-prés",
    "reines-marguerites": "reine-marguerite",
    "reinettes": "reinette",
    "reins": "rein",
    "rejailli": "rejaillir",
    "rejaillie": "rejaillir",
    "rejaillies": "rejaillir",
    "rejaillira": "rejaillir",
    "rejaillirai": "rejaillir",
    "rejailliraient": "rejaillir",
    "rejaillirais": "rejaillir",
    "rejaillirait": "rejaillir",
    "rejailliras": "rejaillir",
    "rejaillirent": "rejaillir",
    "rejaillirez": "rejaillir",
    "rejailliriez": "rejaillir",
    "rejaillirions": "rejaillir",
    "rejaillirons": "rejaillir",
    "rejailliront": "rejaillir",
    "rejaillis": "rejaillir",
    "rejaillissaient": "rejaillir",
    "rejaillissais": "rejaillir",
    "rejaillissait": "rejaillir",
    "rejaillissant": "rejaillir",
    "rejaillisse": "rejaillir",
    "rejaillissements": "rejaillissement",
    "rejaillissent": "rejaillir",
    "rejaillisses": "rejaillir",
    "rejaillissez": "rejaillir",
    "rejaillissiez": "rejaillir",
    "rejaillissions": "rejaillir",
    "rejaillissons": "rejaillir",
    "rejaillit": "rejaillir",
    "rejaillîmes": "rejaillir",
    "rejaillît": "rejaillir",
    "rejaillîtes": "rejaillir",
    "rejeta": "rejeter",
    "rejetai": "rejeter",
    "rejetaient": "rejeter",
    "rejetais": "rejeter",
    "rejetait": "rejeter",
    "rejetant": "rejeter",
    "rejetas": "rejeter",
    "rejetasse": "rejeter",
    "rejetassent": "rejeter",
    "rejetasses": "rejeter",
    "rejetassiez": "rejeter",
    "rejetassions": "rejeter",
    "rejetez": "rejeter",
    "rejetiez": "rejeter",
    "rejetions": "rejeter",
    "rejetons": "rejeton",
    "rejets": "rejet",
    "rejette": "rejeter",
    "rejettent": "rejeter",
    "rejettera": "rejeter",
    "rejetterai": "rejeter",
    "rejetteraient": "rejeter",
    "rejetterais": "rejeter",
    "rejetterait": "rejeter",
    "rejetteras": "rejeter",
    "rejetterez": "rejeter",
    "rejetteriez": "rejeter",
    "rejetterions": "rejeter",
    "rejetterons": "rejeter",
    "rejetteront": "rejeter",
    "rejettes": "rejeter",
    "rejetâmes": "rejeter",
    "rejetât": "rejeter",
    "rejetâtes": "rejeter",
    "rejetèrent": "rejeter",
    "rejeté": "rejeter",
    "rejetée": "rejeter",
    "rejetées": "rejeter",
    "rejetés": "rejeter",
    "rejoignaient": "rejoindre",
    "rejoignais": "rejoindre",
    "rejoignait": "rejoindre",
    "rejoignant": "rejoindre",
    "rejoigne": "rejoindre",
    "rejoignent": "rejoindre",
    "rejoignes": "rejoindre",
    "rejoignez": "rejoindre",
    "rejoigniez": "rejoindre",
    "rejoignions": "rejoindre",
    "rejoignirent": "rejoindre",
    "rejoignis": "rejoindre",
    "rejoignisse": "rejoindre",
    "rejoignissent": "rejoindre",
    "rejoignisses": "rejoindre",
    "rejoignissiez": "rejoindre",
    "rejoignissions": "rejoindre",
    "rejoignit": "rejoindre",
    "rejoignons": "rejoindre",
    "rejoignîmes": "rejoindre",
    "rejoignît": "rejoindre",
    "rejoignîtes": "rejoindre",
    "rejoindra": "rejoindre",
    "rejoindrai": "rejoindre",
    "rejoindraient": "rejoindre",
    "rejoindrais": "rejoindre",
    "rejoindrait": "rejoindre",
    "rejoindras": "rejoindre",
    "rejoindrez": "rejoindre",
    "rejoindriez": "rejoindre",
    "rejoindrions": "rejoindre",
    "rejoindrons": "rejoindre",
    "rejoindront": "rejoindre",
    "rejoins": "rejoindre",
    "rejoint": "rejoindre",
    "rejointe": "rejoindre",
    "rejointes": "rejoindre",
    "rejointoyé": "rejointoyer",
    "rejointoyés": "rejointoyer",
    "rejoints": "rejoint",
    "rejoua": "rejouer",
    "rejouai": "rejouer",
    "rejouaient": "rejouer",
    "rejouais": "rejouer",
    "rejouait": "rejouer",
    "rejouant": "rejouer",
    "rejouas": "rejouer",
    "rejouasse": "rejouer",
    "rejouassent": "rejouer",
    "rejouasses": "rejouer",
    "rejouassiez": "rejouer",
    "rejouassions": "rejouer",
    "rejoue": "rejouer",
    "rejouent": "rejouer",
    "rejouera": "rejouer",
    "rejouerai": "rejouer",
    "rejoueraient": "rejouer",
    "rejouerais": "rejouer",
    "rejouerait": "rejouer",
    "rejoueras": "rejouer",
    "rejouerez": "rejouer",
    "rejoueriez": "rejouer",
    "rejouerions": "rejouer",
    "rejouerons": "rejouer",
    "rejoueront": "rejouer",
    "rejoues": "rejouer",
    "rejouez": "rejouer",
    "rejouiez": "rejouer",
    "rejouions": "rejouer",
    "rejouons": "rejouer",
    "rejouâmes": "rejouer",
    "rejouât": "rejouer",
    "rejouâtes": "rejouer",
    "rejouèrent": "rejouer",
    "rejoué": "rejouer",
    "rejouée": "rejouer",
    "rejouées": "rejouer",
    "rejoués": "rejouer",
    "rejugez": "rejuger",
    "rejugé": "rejuger",
    "rejugés": "rejuger",
    "relacent": "relacer",
    "relaie": "relayer",
    "relaient": "relayer",
    "relaiera": "relayer",
    "relaierai": "relayer",
    "relaieraient": "relayer",
    "relaierais": "relayer",
    "relaierait": "relayer",
    "relaieras": "relayer",
    "relaierez": "relayer",
    "relaieriez": "relayer",
    "relaierions": "relayer",
    "relaierons": "relayer",
    "relaieront": "relayer",
    "relaies": "relayer",
    "relaissa": "relaisser",
    "relaissai": "relaisser",
    "relaissaient": "relaisser",
    "relaissais": "relaisser",
    "relaissait": "relaisser",
    "relaissant": "relaisser",
    "relaissas": "relaisser",
    "relaissasse": "relaisser",
    "relaissassent": "relaisser",
    "relaissasses": "relaisser",
    "relaissassiez": "relaisser",
    "relaissassions": "relaisser",
    "relaisse": "relaisser",
    "relaissent": "relaisser",
    "relaissera": "relaisser",
    "relaisserai": "relaisser",
    "relaisseraient": "relaisser",
    "relaisserais": "relaisser",
    "relaisserait": "relaisser",
    "relaisseras": "relaisser",
    "relaisserez": "relaisser",
    "relaisseriez": "relaisser",
    "relaisserions": "relaisser",
    "relaisserons": "relaisser",
    "relaisseront": "relaisser",
    "relaisses": "relaisser",
    "relaissez": "relaisser",
    "relaissiez": "relaisser",
    "relaissions": "relaisser",
    "relaissons": "relaisser",
    "relaissâmes": "relaisser",
    "relaissât": "relaisser",
    "relaissâtes": "relaisser",
    "relaissèrent": "relaisser",
    "relaissé": "relaisser",
    "relaissée": "relaisser",
    "relaissées": "relaisser",
    "relaissés": "relaisser",
    "relance": "relancer",
    "relancent": "relancer",
    "relancera": "relancer",
    "relancerai": "relancer",
    "relanceraient": "relancer",
    "relancerais": "relancer",
    "relancerait": "relancer",
    "relanceras": "relancer",
    "relancerez": "relancer",
    "relanceriez": "relancer",
    "relancerions": "relancer",
    "relancerons": "relancer",
    "relanceront": "relancer",
    "relances": "relancer",
    "relancez": "relancer",
    "relanciez": "relancer",
    "relancions": "relancer",
    "relancèrent": "relancer",
    "relancé": "relancer",
    "relancée": "relancer",
    "relancées": "relancer",
    "relancés": "relancer",
    "relança": "relancer",
    "relançai": "relancer",
    "relançaient": "relancer",
    "relançais": "relancer",
    "relançait": "relancer",
    "relançant": "relancer",
    "relanças": "relancer",
    "relançasse": "relancer",
    "relançassent": "relancer",
    "relançasses": "relancer",
    "relançassiez": "relancer",
    "relançassions": "relancer",
    "relançons": "relancer",
    "relançâmes": "relancer",
    "relançât": "relancer",
    "relançâtes": "relancer",
    "relapse": "relaps",
    "relapses": "relaps",
    "relata": "relater",
    "relatai": "relater",
    "relataient": "relater",
    "relatais": "relater",
    "relatait": "relater",
    "relatant": "relater",
    "relatas": "relater",
    "relatasse": "relater",
    "relatassent": "relater",
    "relatasses": "relater",
    "relatassiez": "relater",
    "relatassions": "relater",
    "relate": "relater",
    "relatent": "relater",
    "relatera": "relater",
    "relaterai": "relater",
    "relateraient": "relater",
    "relaterais": "relater",
    "relaterait": "relater",
    "relateras": "relater",
    "relaterez": "relater",
    "relateriez": "relater",
    "relaterions": "relater",
    "relaterons": "relater",
    "relateront": "relater",
    "relates": "relater",
    "relatez": "relater",
    "relatiez": "relater",
    "relatifs": "relatif",
    "relationnelle": "relationnel",
    "relationnelles": "relationnel",
    "relationnels": "relationnel",
    "relations": "relation",
    "relative": "relatif",
    "relatives": "relatif",
    "relativisa": "relativiser",
    "relativisai": "relativiser",
    "relativisaient": "relativiser",
    "relativisais": "relativiser",
    "relativisait": "relativiser",
    "relativisant": "relativiser",
    "relativisas": "relativiser",
    "relativisasse": "relativiser",
    "relativisassent": "relativiser",
    "relativisasses": "relativiser",
    "relativisassiez": "relativiser",
    "relativisassions": "relativiser",
    "relativise": "relativiser",
    "relativisent": "relativiser",
    "relativisera": "relativiser",
    "relativiserai": "relativiser",
    "relativiseraient": "relativiser",
    "relativiserais": "relativiser",
    "relativiserait": "relativiser",
    "relativiseras": "relativiser",
    "relativiserez": "relativiser",
    "relativiseriez": "relativiser",
    "relativiserions": "relativiser",
    "relativiserons": "relativiser",
    "relativiseront": "relativiser",
    "relativises": "relativiser",
    "relativisez": "relativiser",
    "relativisiez": "relativiser",
    "relativisions": "relativiser",
    "relativisons": "relativiser",
    "relativisâmes": "relativiser",
    "relativisât": "relativiser",
    "relativisâtes": "relativiser",
    "relativisèrent": "relativiser",
    "relativisé": "relativiser",
    "relativisée": "relativiser",
    "relativisées": "relativiser",
    "relativisés": "relativiser",
    "relatons": "relater",
    "relatâmes": "relater",
    "relatât": "relater",
    "relatâtes": "relater",
    "relatèrent": "relater",
    "relaté": "relater",
    "relatée": "relater",
    "relatées": "relater",
    "relatés": "relater",
    "relava": "relaver",
    "relavai": "relaver",
    "relavaient": "relaver",
    "relavais": "relaver",
    "relavait": "relaver",
    "relavant": "relaver",
    "relavas": "relaver",
    "relavasse": "relaver",
    "relavassent": "relaver",
    "relavasses": "relaver",
    "relavassiez": "relaver",
    "relavassions": "relaver",
    "relave": "relaver",
    "relavent": "relaver",
    "relavera": "relaver",
    "relaverai": "relaver",
    "relaveraient": "relaver",
    "relaverais": "relaver",
    "relaverait": "relaver",
    "relaveras": "relaver",
    "relaverez": "relaver",
    "relaveriez": "relaver",
    "relaverions": "relaver",
    "relaverons": "relaver",
    "relaveront": "relaver",
    "relaves": "relaver",
    "relavez": "relaver",
    "relaviez": "relaver",
    "relavions": "relaver",
    "relavons": "relaver",
    "relavâmes": "relaver",
    "relavât": "relaver",
    "relavâtes": "relaver",
    "relavèrent": "relaver",
    "relavé": "relaver",
    "relavée": "relaver",
    "relavées": "relaver",
    "relavés": "relaver",
    "relaxa": "relaxer",
    "relaxai": "relaxer",
    "relaxaient": "relaxer",
    "relaxais": "relaxer",
    "relaxait": "relaxer",
    "relaxant": "relaxer",
    "relaxante": "relaxant",
    "relaxantes": "relaxant",
    "relaxants": "relaxant",
    "relaxas": "relaxer",
    "relaxasse": "relaxer",
    "relaxassent": "relaxer",
    "relaxasses": "relaxer",
    "relaxassiez": "relaxer",
    "relaxassions": "relaxer",
    "relaxations": "relaxation",
    "relaxe": "relaxer",
    "relaxent": "relaxer",
    "relaxera": "relaxer",
    "relaxerai": "relaxer",
    "relaxeraient": "relaxer",
    "relaxerais": "relaxer",
    "relaxerait": "relaxer",
    "relaxeras": "relaxer",
    "relaxerez": "relaxer",
    "relaxeriez": "relaxer",
    "relaxerions": "relaxer",
    "relaxerons": "relaxer",
    "relaxeront": "relaxer",
    "relaxes": "relaxer",
    "relaxez": "relaxer",
    "relaxiez": "relaxer",
    "relaxions": "relaxer",
    "relaxons": "relaxer",
    "relaxâmes": "relaxer",
    "relaxât": "relaxer",
    "relaxâtes": "relaxer",
    "relaxèrent": "relaxer",
    "relaxé": "relaxer",
    "relaxée": "relaxer",
    "relaxées": "relaxer",
    "relaxés": "relaxer",
    "relaya": "relayer",
    "relayai": "relayer",
    "relayaient": "relayer",
    "relayais": "relayer",
    "relayait": "relayer",
    "relayant": "relayer",
    "relayas": "relayer",
    "relayasse": "relayer",
    "relayassent": "relayer",
    "relayasses": "relayer",
    "relayassiez": "relayer",
    "relayassions": "relayer",
    "relaye": "relayer",
    "relayent": "relayer",
    "relayera": "relayer",
    "relayerai": "relayer",
    "relayeraient": "relayer",
    "relayerais": "relayer",
    "relayerait": "relayer",
    "relayeras": "relayer",
    "relayerez": "relayer",
    "relayeriez": "relayer",
    "relayerions": "relayer",
    "relayerons": "relayer",
    "relayeront": "relayer",
    "relayes": "relayer",
    "relayeurs": "relayeur",
    "relayeuse": "relayeur",
    "relayeuses": "relayeur",
    "relayez": "relayer",
    "relayiez": "relayer",
    "relayions": "relayer",
    "relayons": "relayer",
    "relayâmes": "relayer",
    "relayât": "relayer",
    "relayâtes": "relayer",
    "relayèrent": "relayer",
    "relayé": "relayer",
    "relayée": "relayer",
    "relayées": "relayer",
    "relayés": "relayer",
    "relaça": "relacer",
    "relaçaient": "relacer",
    "relaçait": "relacer",
    "relectures": "relecture",
    "relents": "relent",
    "releva": "relever",
    "relevai": "relever",
    "relevaient": "relever",
    "relevais": "relever",
    "relevait": "relever",
    "relevant": "relever",
    "relevas": "relever",
    "relevasse": "relever",
    "relevassent": "relever",
    "relevasses": "relever",
    "relevassiez": "relever",
    "relevassions": "relever",
    "releveurs": "releveur",
    "relevez": "relever",
    "releviez": "relever",
    "relevions": "relever",
    "relevons": "relever",
    "relevâmes": "relever",
    "relevât": "relever",
    "relevâtes": "relever",
    "relevèrent": "relever",
    "relevé": "relever",
    "relevée": "relever",
    "relevées": "relever",
    "relevés": "relever",
    "relia": "relier",
    "reliai": "relier",
    "reliaient": "relier",
    "reliais": "relier",
    "reliait": "relier",
    "reliant": "relier",
    "relias": "relier",
    "reliasse": "relier",
    "reliassent": "relier",
    "reliasses": "relier",
    "reliassiez": "relier",
    "reliassions": "relier",
    "relie": "relier",
    "reliefs": "relief",
    "relient": "relier",
    "reliera": "relier",
    "relierai": "relier",
    "relieraient": "relier",
    "relierais": "relier",
    "relierait": "relier",
    "relieras": "relier",
    "relierez": "relier",
    "relieriez": "relier",
    "relierions": "relier",
    "relierons": "relier",
    "relieront": "relier",
    "relies": "relier",
    "relieurs": "relieur",
    "reliez": "relier",
    "religieuse": "religieux",
    "religieuses": "religieux",
    "religionnaires": "religionnaire",
    "religions": "religion",
    "religiosités": "religiosité",
    "reliiez": "relier",
    "reliions": "relier",
    "relions": "relier",
    "reliquaires": "reliquaire",
    "reliquats": "reliquat",
    "reliques": "relique",
    "relira": "relire",
    "relirai": "relire",
    "reliraient": "relire",
    "relirais": "relire",
    "relirait": "relire",
    "reliras": "relire",
    "relirez": "relire",
    "reliriez": "relire",
    "relirions": "relire",
    "relirons": "relire",
    "reliront": "relire",
    "relis": "relire",
    "relisaient": "relire",
    "relisais": "relire",
    "relisait": "relire",
    "relisant": "relire",
    "relise": "relire",
    "relisent": "relire",
    "relises": "relire",
    "relisez": "relire",
    "relisiez": "relire",
    "relisions": "relire",
    "relisons": "relire",
    "relit": "relire",
    "reliures": "reliure",
    "reliâmes": "relier",
    "reliât": "relier",
    "reliâtes": "relier",
    "relièrent": "relier",
    "relié": "relier",
    "reliée": "relier",
    "reliées": "relier",
    "reliés": "relier",
    "relocalisations": "relocalisation",
    "reloge": "reloger",
    "relogea": "reloger",
    "relogeai": "reloger",
    "relogeaient": "reloger",
    "relogeais": "reloger",
    "relogeait": "reloger",
    "relogeant": "reloger",
    "relogeas": "reloger",
    "relogeasse": "reloger",
    "relogeassent": "reloger",
    "relogeasses": "reloger",
    "relogeassiez": "reloger",
    "relogeassions": "reloger",
    "relogements": "relogement",
    "relogent": "reloger",
    "relogeons": "reloger",
    "relogera": "reloger",
    "relogerai": "reloger",
    "relogeraient": "reloger",
    "relogerais": "reloger",
    "relogerait": "reloger",
    "relogeras": "reloger",
    "relogerez": "reloger",
    "relogeriez": "reloger",
    "relogerions": "reloger",
    "relogerons": "reloger",
    "relogeront": "reloger",
    "reloges": "reloger",
    "relogez": "reloger",
    "relogeâmes": "reloger",
    "relogeât": "reloger",
    "relogeâtes": "reloger",
    "relogiez": "reloger",
    "relogions": "reloger",
    "relogèrent": "reloger",
    "relogé": "reloger",
    "relogée": "reloger",
    "relogées": "reloger",
    "relogés": "reloger",
    "relookerai": "relooker",
    "relooké": "relooker",
    "relookée": "relooker",
    "reloua": "relouer",
    "relouai": "relouer",
    "relouaient": "relouer",
    "relouais": "relouer",
    "relouait": "relouer",
    "relouant": "relouer",
    "relouas": "relouer",
    "relouasse": "relouer",
    "relouassent": "relouer",
    "relouasses": "relouer",
    "relouassiez": "relouer",
    "relouassions": "relouer",
    "reloue": "relouer",
    "relouent": "relouer",
    "relouera": "relouer",
    "relouerai": "relouer",
    "reloueraient": "relouer",
    "relouerais": "relouer",
    "relouerait": "relouer",
    "reloueras": "relouer",
    "relouerez": "relouer",
    "reloueriez": "relouer",
    "relouerions": "relouer",
    "relouerons": "relouer",
    "reloueront": "relouer",
    "reloues": "relouer",
    "relouez": "relouer",
    "relouiez": "relouer",
    "relouions": "relouer",
    "relouons": "relouer",
    "relourde": "relourder",
    "relourdé": "relourder",
    "relouâmes": "relouer",
    "relouât": "relouer",
    "relouâtes": "relouer",
    "relouèrent": "relouer",
    "reloué": "relouer",
    "relouée": "relouer",
    "relouées": "relouer",
    "reloués": "relouer",
    "relu": "relire",
    "relue": "relu",
    "relues": "relire",
    "relui": "reluire",
    "reluira": "reluire",
    "reluirai": "reluire",
    "reluiraient": "reluire",
    "reluirais": "reluire",
    "reluirait": "reluire",
    "reluiras": "reluire",
    "reluirent": "reluire",
    "reluirez": "reluire",
    "reluiriez": "reluire",
    "reluirions": "reluire",
    "reluirons": "reluire",
    "reluiront": "reluire",
    "reluis": "reluire",
    "reluisaient": "reluire",
    "reluisais": "reluire",
    "reluisait": "reluire",
    "reluisant": "reluire",
    "reluisante": "reluisant",
    "reluisantes": "reluisant",
    "reluisants": "reluisant",
    "reluise": "reluire",
    "reluisent": "reluire",
    "reluises": "reluire",
    "reluisez": "reluire",
    "reluisiez": "reluire",
    "reluisions": "reluire",
    "reluisisse": "reluire",
    "reluisissent": "reluire",
    "reluisisses": "reluire",
    "reluisissiez": "reluire",
    "reluisissions": "reluire",
    "reluisons": "reluire",
    "reluisît": "reluire",
    "reluit": "reluire",
    "reluqua": "reluquer",
    "reluquai": "reluquer",
    "reluquaient": "reluquer",
    "reluquais": "reluquer",
    "reluquait": "reluquer",
    "reluquant": "reluquer",
    "reluquas": "reluquer",
    "reluquasse": "reluquer",
    "reluquassent": "reluquer",
    "reluquasses": "reluquer",
    "reluquassiez": "reluquer",
    "reluquassions": "reluquer",
    "reluque": "reluquer",
    "reluquent": "reluquer",
    "reluquera": "reluquer",
    "reluquerai": "reluquer",
    "reluqueraient": "reluquer",
    "reluquerais": "reluquer",
    "reluquerait": "reluquer",
    "reluqueras": "reluquer",
    "reluquerez": "reluquer",
    "reluqueriez": "reluquer",
    "reluquerions": "reluquer",
    "reluquerons": "reluquer",
    "reluqueront": "reluquer",
    "reluques": "reluquer",
    "reluquez": "reluquer",
    "reluquiez": "reluquer",
    "reluquions": "reluquer",
    "reluquons": "reluquer",
    "reluquâmes": "reluquer",
    "reluquât": "reluquer",
    "reluquâtes": "reluquer",
    "reluquèrent": "reluquer",
    "reluqué": "reluquer",
    "reluquée": "reluquer",
    "reluquées": "reluquer",
    "reluqués": "reluquer",
    "relurent": "relire",
    "relus": "relu",
    "relusse": "relire",
    "relussent": "relire",
    "relusses": "relire",
    "relussiez": "relire",
    "relussions": "relire",
    "relut": "relire",
    "reluîmes": "reluire",
    "reluîtes": "reluire",
    "relâcha": "relâcher",
    "relâchai": "relâcher",
    "relâchaient": "relâcher",
    "relâchais": "relâcher",
    "relâchait": "relâcher",
    "relâchant": "relâcher",
    "relâchas": "relâcher",
    "relâchasse": "relâcher",
    "relâchassent": "relâcher",
    "relâchasses": "relâcher",
    "relâchassiez": "relâcher",
    "relâchassions": "relâcher",
    "relâche": "relâcher",
    "relâchements": "relâchement",
    "relâchent": "relâcher",
    "relâchera": "relâcher",
    "relâcherai": "relâcher",
    "relâcheraient": "relâcher",
    "relâcherais": "relâcher",
    "relâcherait": "relâcher",
    "relâcheras": "relâcher",
    "relâcherez": "relâcher",
    "relâcheriez": "relâcher",
    "relâcherions": "relâcher",
    "relâcherons": "relâcher",
    "relâcheront": "relâcher",
    "relâches": "relâcher",
    "relâchez": "relâcher",
    "relâchiez": "relâcher",
    "relâchions": "relâcher",
    "relâchons": "relâcher",
    "relâchâmes": "relâcher",
    "relâchât": "relâcher",
    "relâchâtes": "relâcher",
    "relâchèrent": "relâcher",
    "relâché": "relâcher",
    "relâchée": "relâcher",
    "relâchées": "relâcher",
    "relâchés": "relâcher",
    "relègue": "reléguer",
    "relèguent": "reléguer",
    "relègues": "reléguer",
    "relève": "relever",
    "relèvements": "relèvement",
    "relèvent": "relever",
    "relèvera": "relever",
    "relèverai": "relever",
    "relèveraient": "relever",
    "relèverais": "relever",
    "relèverait": "relever",
    "relèveras": "relever",
    "relèverez": "relever",
    "relèveriez": "relever",
    "relèverions": "relever",
    "relèverons": "relever",
    "relèveront": "relever",
    "relèves": "relever",
    "relégations": "relégation",
    "relégua": "reléguer",
    "reléguai": "reléguer",
    "reléguaient": "reléguer",
    "reléguais": "reléguer",
    "reléguait": "reléguer",
    "reléguant": "reléguer",
    "reléguas": "reléguer",
    "reléguasse": "reléguer",
    "reléguassent": "reléguer",
    "reléguasses": "reléguer",
    "reléguassiez": "reléguer",
    "reléguassions": "reléguer",
    "reléguera": "reléguer",
    "reléguerai": "reléguer",
    "relégueraient": "reléguer",
    "reléguerais": "reléguer",
    "reléguerait": "reléguer",
    "relégueras": "reléguer",
    "reléguerez": "reléguer",
    "relégueriez": "reléguer",
    "reléguerions": "reléguer",
    "reléguerons": "reléguer",
    "relégueront": "reléguer",
    "reléguez": "reléguer",
    "reléguiez": "reléguer",
    "reléguions": "reléguer",
    "reléguons": "reléguer",
    "reléguâmes": "reléguer",
    "reléguât": "reléguer",
    "reléguâtes": "reléguer",
    "reléguèrent": "reléguer",
    "relégué": "reléguer",
    "reléguée": "reléguer",
    "reléguées": "reléguer",
    "relégués": "reléguer",
    "relûmes": "relire",
    "relût": "relire",
    "relûtes": "relire",
    "remailla": "remailler",
    "remaillages": "remaillage",
    "remaillai": "remailler",
    "remaillaient": "remailler",
    "remaillais": "remailler",
    "remaillait": "remailler",
    "remaillant": "remailler",
    "remaillas": "remailler",
    "remaillasse": "remailler",
    "remaillassent": "remailler",
    "remaillasses": "remailler",
    "remaillassiez": "remailler",
    "remaillassions": "remailler",
    "remaille": "remailler",
    "remaillent": "remailler",
    "remaillera": "remailler",
    "remaillerai": "remailler",
    "remailleraient": "remailler",
    "remaillerais": "remailler",
    "remaillerait": "remailler",
    "remailleras": "remailler",
    "remaillerez": "remailler",
    "remailleriez": "remailler",
    "remaillerions": "remailler",
    "remaillerons": "remailler",
    "remailleront": "remailler",
    "remailles": "remailler",
    "remailleuse": "mailleur",
    "remaillez": "remailler",
    "remailliez": "remailler",
    "remaillions": "remailler",
    "remaillons": "remailler",
    "remaillâmes": "remailler",
    "remaillât": "remailler",
    "remaillâtes": "remailler",
    "remaillèrent": "remailler",
    "remaillé": "remailler",
    "remaillée": "remailler",
    "remaillées": "remailler",
    "remaillés": "remailler",
    "remakes": "remake",
    "remange": "remanger",
    "remangea": "remanger",
    "remangeai": "remanger",
    "remangeaient": "remanger",
    "remangeais": "remanger",
    "remangeait": "remanger",
    "remangeant": "remanger",
    "remangeas": "remanger",
    "remangeasse": "remanger",
    "remangeassent": "remanger",
    "remangeasses": "remanger",
    "remangeassiez": "remanger",
    "remangeassions": "remanger",
    "remangent": "remanger",
    "remangeons": "remanger",
    "remangera": "remanger",
    "remangerai": "remanger",
    "remangeraient": "remanger",
    "remangerais": "remanger",
    "remangerait": "remanger",
    "remangeras": "remanger",
    "remangerez": "remanger",
    "remangeriez": "remanger",
    "remangerions": "remanger",
    "remangerons": "remanger",
    "remangeront": "remanger",
    "remanges": "remanger",
    "remangez": "remanger",
    "remangeâmes": "remanger",
    "remangeât": "remanger",
    "remangeâtes": "remanger",
    "remangiez": "remanger",
    "remangions": "remanger",
    "remangèrent": "remanger",
    "remangé": "remanger",
    "remangée": "remanger",
    "remangées": "remanger",
    "remangés": "remanger",
    "remania": "remanier",
    "remaniai": "remanier",
    "remaniaient": "remanier",
    "remaniais": "remanier",
    "remaniait": "remanier",
    "remaniant": "remanier",
    "remanias": "remanier",
    "remaniasse": "remanier",
    "remaniassent": "remanier",
    "remaniasses": "remanier",
    "remaniassiez": "remanier",
    "remaniassions": "remanier",
    "remanie": "remanier",
    "remaniements": "remaniement",
    "remanient": "remanier",
    "remaniera": "remanier",
    "remanierai": "remanier",
    "remanieraient": "remanier",
    "remanierais": "remanier",
    "remanierait": "remanier",
    "remanieras": "remanier",
    "remanierez": "remanier",
    "remanieriez": "remanier",
    "remanierions": "remanier",
    "remanierons": "remanier",
    "remanieront": "remanier",
    "remanies": "remanier",
    "remaniez": "remanier",
    "remaniiez": "remanier",
    "remaniions": "remanier",
    "remanions": "remanier",
    "remaniâmes": "remanier",
    "remaniât": "remanier",
    "remaniâtes": "remanier",
    "remanièrent": "remanier",
    "remanié": "remanier",
    "remaniée": "remanier",
    "remaniées": "remanier",
    "remaniés": "remanier",
    "remaquilla": "remaquiller",
    "remaquillai": "remaquiller",
    "remaquillaient": "remaquiller",
    "remaquillais": "remaquiller",
    "remaquillait": "remaquiller",
    "remaquillant": "remaquiller",
    "remaquillas": "remaquiller",
    "remaquillasse": "remaquiller",
    "remaquillassent": "remaquiller",
    "remaquillasses": "remaquiller",
    "remaquillassiez": "remaquiller",
    "remaquillassions": "remaquiller",
    "remaquille": "remaquiller",
    "remaquillent": "remaquiller",
    "remaquillera": "remaquiller",
    "remaquillerai": "remaquiller",
    "remaquilleraient": "remaquiller",
    "remaquillerais": "remaquiller",
    "remaquillerait": "remaquiller",
    "remaquilleras": "remaquiller",
    "remaquillerez": "remaquiller",
    "remaquilleriez": "remaquiller",
    "remaquillerions": "remaquiller",
    "remaquillerons": "remaquiller",
    "remaquilleront": "remaquiller",
    "remaquilles": "remaquiller",
    "remaquillez": "remaquiller",
    "remaquilliez": "remaquiller",
    "remaquillions": "remaquiller",
    "remaquillons": "remaquiller",
    "remaquillâmes": "remaquiller",
    "remaquillât": "remaquiller",
    "remaquillâtes": "remaquiller",
    "remaquillèrent": "remaquiller",
    "remaquillé": "remaquiller",
    "remaquillée": "remaquiller",
    "remaquillées": "remaquiller",
    "remaquillés": "remaquiller",
    "remarchait": "remarcher",
    "remarchanda": "remarchander",
    "remarchandai": "remarchander",
    "remarchandaient": "remarchander",
    "remarchandais": "remarchander",
    "remarchandait": "remarchander",
    "remarchandant": "remarchander",
    "remarchandas": "remarchander",
    "remarchandasse": "remarchander",
    "remarchandassent": "remarchander",
    "remarchandasses": "remarchander",
    "remarchandassiez": "remarchander",
    "remarchandassions": "remarchander",
    "remarchande": "remarchander",
    "remarchandent": "remarchander",
    "remarchandera": "remarchander",
    "remarchanderai": "remarchander",
    "remarchanderaient": "remarchander",
    "remarchanderais": "remarchander",
    "remarchanderait": "remarchander",
    "remarchanderas": "remarchander",
    "remarchanderez": "remarchander",
    "remarchanderiez": "remarchander",
    "remarchanderions": "remarchander",
    "remarchanderons": "remarchander",
    "remarchanderont": "remarchander",
    "remarchandes": "remarchander",
    "remarchandez": "remarchander",
    "remarchandiez": "remarchander",
    "remarchandions": "remarchander",
    "remarchandons": "remarchander",
    "remarchandâmes": "remarchander",
    "remarchandât": "remarchander",
    "remarchandâtes": "remarchander",
    "remarchandèrent": "remarchander",
    "remarchandé": "remarchander",
    "remarchandée": "remarchander",
    "remarchandées": "remarchander",
    "remarchandés": "remarchander",
    "remarche": "remarcher",
    "remarchent": "remarcher",
    "remarchera": "remarcher",
    "remarcheras": "remarcher",
    "remaria": "remarier",
    "remariai": "remarier",
    "remariaient": "remarier",
    "remariais": "remarier",
    "remariait": "remarier",
    "remariant": "remarier",
    "remarias": "remarier",
    "remariasse": "remarier",
    "remariassent": "remarier",
    "remariasses": "remarier",
    "remariassiez": "remarier",
    "remariassions": "remarier",
    "remarie": "remarier",
    "remarient": "remarier",
    "remariera": "remarier",
    "remarierai": "remarier",
    "remarieraient": "remarier",
    "remarierais": "remarier",
    "remarierait": "remarier",
    "remarieras": "remarier",
    "remarierez": "remarier",
    "remarieriez": "remarier",
    "remarierions": "remarier",
    "remarierons": "remarier",
    "remarieront": "remarier",
    "remaries": "remarier",
    "remariez": "remarier",
    "remariiez": "remarier",
    "remariions": "remarier",
    "remarions": "remarier",
    "remariâmes": "remarier",
    "remariât": "remarier",
    "remariâtes": "remarier",
    "remarièrent": "remarier",
    "remarié": "remarier",
    "remariée": "remarier",
    "remariées": "remarier",
    "remariés": "remarier",
    "remarqua": "remarquer",
    "remarquables": "remarquable",
    "remarquai": "remarquer",
    "remarquaient": "remarquer",
    "remarquais": "remarquer",
    "remarquait": "remarquer",
    "remarquant": "remarquer",
    "remarquas": "remarquer",
    "remarquasse": "remarquer",
    "remarquassent": "remarquer",
    "remarquasses": "remarquer",
    "remarquassiez": "remarquer",
    "remarquassions": "remarquer",
    "remarque": "remarquer",
    "remarquent": "remarquer",
    "remarquera": "remarquer",
    "remarquerai": "remarquer",
    "remarqueraient": "remarquer",
    "remarquerais": "remarquer",
    "remarquerait": "remarquer",
    "remarqueras": "remarquer",
    "remarquerez": "remarquer",
    "remarqueriez": "remarquer",
    "remarquerions": "remarquer",
    "remarquerons": "remarquer",
    "remarqueront": "remarquer",
    "remarques": "remarquer",
    "remarquez": "remarquer",
    "remarquiez": "remarquer",
    "remarquions": "remarquer",
    "remarquons": "remarquer",
    "remarquâmes": "remarquer",
    "remarquât": "remarquer",
    "remarquâtes": "remarquer",
    "remarquèrent": "remarquer",
    "remarqué": "remarquer",
    "remarquée": "remarquer",
    "remarquées": "remarquer",
    "remarqués": "remarquer",
    "remballa": "remballer",
    "remballai": "remballer",
    "remballaient": "remballer",
    "remballais": "remballer",
    "remballait": "remballer",
    "remballant": "remballer",
    "remballas": "remballer",
    "remballasse": "remballer",
    "remballassent": "remballer",
    "remballasses": "remballer",
    "remballassiez": "remballer",
    "remballassions": "remballer",
    "remballe": "remballer",
    "remballent": "remballer",
    "remballera": "remballer",
    "remballerai": "remballer",
    "remballeraient": "remballer",
    "remballerais": "remballer",
    "remballerait": "remballer",
    "remballeras": "remballer",
    "remballerez": "remballer",
    "remballeriez": "remballer",
    "remballerions": "remballer",
    "remballerons": "remballer",
    "remballeront": "remballer",
    "remballes": "remballer",
    "remballez": "remballer",
    "remballiez": "remballer",
    "remballions": "remballer",
    "remballons": "remballer",
    "remballâmes": "remballer",
    "remballât": "remballer",
    "remballâtes": "remballer",
    "remballèrent": "remballer",
    "remballé": "remballer",
    "remballée": "remballer",
    "remballées": "remballer",
    "remballés": "remballer",
    "rembarqua": "rembarquer",
    "rembarquai": "rembarquer",
    "rembarquaient": "rembarquer",
    "rembarquais": "rembarquer",
    "rembarquait": "rembarquer",
    "rembarquant": "rembarquer",
    "rembarquas": "rembarquer",
    "rembarquasse": "rembarquer",
    "rembarquassent": "rembarquer",
    "rembarquasses": "rembarquer",
    "rembarquassiez": "rembarquer",
    "rembarquassions": "rembarquer",
    "rembarque": "rembarquer",
    "rembarquements": "rembarquement",
    "rembarquent": "rembarquer",
    "rembarquera": "rembarquer",
    "rembarquerai": "rembarquer",
    "rembarqueraient": "rembarquer",
    "rembarquerais": "rembarquer",
    "rembarquerait": "rembarquer",
    "rembarqueras": "rembarquer",
    "rembarquerez": "rembarquer",
    "rembarqueriez": "rembarquer",
    "rembarquerions": "rembarquer",
    "rembarquerons": "rembarquer",
    "rembarqueront": "rembarquer",
    "rembarques": "rembarquer",
    "rembarquez": "rembarquer",
    "rembarquiez": "rembarquer",
    "rembarquions": "rembarquer",
    "rembarquons": "rembarquer",
    "rembarquâmes": "rembarquer",
    "rembarquât": "rembarquer",
    "rembarquâtes": "rembarquer",
    "rembarquèrent": "rembarquer",
    "rembarqué": "rembarquer",
    "rembarquée": "rembarquer",
    "rembarquées": "rembarquer",
    "rembarqués": "rembarquer",
    "rembarra": "rembarrer",
    "rembarrai": "rembarrer",
    "rembarraient": "rembarrer",
    "rembarrais": "rembarrer",
    "rembarrait": "rembarrer",
    "rembarrant": "rembarrer",
    "rembarras": "rembarrer",
    "rembarrasse": "rembarrer",
    "rembarrassent": "rembarrer",
    "rembarrasses": "rembarrer",
    "rembarrassiez": "rembarrer",
    "rembarrassions": "rembarrer",
    "rembarre": "rembarrer",
    "rembarrent": "rembarrer",
    "rembarrera": "rembarrer",
    "rembarrerai": "rembarrer",
    "rembarreraient": "rembarrer",
    "rembarrerais": "rembarrer",
    "rembarrerait": "rembarrer",
    "rembarreras": "rembarrer",
    "rembarrerez": "rembarrer",
    "rembarreriez": "rembarrer",
    "rembarrerions": "rembarrer",
    "rembarrerons": "rembarrer",
    "rembarreront": "rembarrer",
    "rembarres": "rembarrer",
    "rembarrez": "rembarrer",
    "rembarriez": "rembarrer",
    "rembarrions": "rembarrer",
    "rembarrons": "rembarrer",
    "rembarrâmes": "rembarrer",
    "rembarrât": "rembarrer",
    "rembarrâtes": "rembarrer",
    "rembarrèrent": "rembarrer",
    "rembarré": "rembarrer",
    "rembarrée": "rembarrer",
    "rembarrées": "rembarrer",
    "rembarrés": "rembarrer",
    "rembauche": "rembaucher",
    "rembauchés": "rembaucher",
    "remblaie": "remblayer",
    "remblaient": "remblayer",
    "remblaiera": "remblayer",
    "remblaierai": "remblayer",
    "remblaieraient": "remblayer",
    "remblaierais": "remblayer",
    "remblaierait": "remblayer",
    "remblaieras": "remblayer",
    "remblaierez": "remblayer",
    "remblaieriez": "remblayer",
    "remblaierions": "remblayer",
    "remblaierons": "remblayer",
    "remblaieront": "remblayer",
    "remblaies": "remblayer",
    "remblais": "remblai",
    "remblaya": "remblayer",
    "remblayai": "remblayer",
    "remblayaient": "remblayer",
    "remblayais": "remblayer",
    "remblayait": "remblayer",
    "remblayant": "remblayer",
    "remblayas": "remblayer",
    "remblayasse": "remblayer",
    "remblayassent": "remblayer",
    "remblayasses": "remblayer",
    "remblayassiez": "remblayer",
    "remblayassions": "remblayer",
    "remblaye": "remblayer",
    "remblayent": "remblayer",
    "remblayera": "remblayer",
    "remblayerai": "remblayer",
    "remblayeraient": "remblayer",
    "remblayerais": "remblayer",
    "remblayerait": "remblayer",
    "remblayeras": "remblayer",
    "remblayerez": "remblayer",
    "remblayeriez": "remblayer",
    "remblayerions": "remblayer",
    "remblayerons": "remblayer",
    "remblayeront": "remblayer",
    "remblayes": "remblayer",
    "remblayez": "remblayer",
    "remblayiez": "remblayer",
    "remblayions": "remblayer",
    "remblayons": "remblayer",
    "remblayâmes": "remblayer",
    "remblayât": "remblayer",
    "remblayâtes": "remblayer",
    "remblayèrent": "remblayer",
    "remblayé": "remblayer",
    "remblayée": "remblayer",
    "remblayées": "remblayer",
    "remblayés": "remblayer",
    "rembobine": "rembobiner",
    "rembobinez": "rembobiner",
    "rembourra": "rembourrer",
    "rembourrages": "rembourrage",
    "rembourrai": "rembourrer",
    "rembourraient": "rembourrer",
    "rembourrais": "rembourrer",
    "rembourrait": "rembourrer",
    "rembourrant": "rembourrer",
    "rembourras": "rembourrer",
    "rembourrasse": "rembourrer",
    "rembourrassent": "rembourrer",
    "rembourrasses": "rembourrer",
    "rembourrassiez": "rembourrer",
    "rembourrassions": "rembourrer",
    "rembourre": "rembourrer",
    "rembourrent": "rembourrer",
    "rembourrera": "rembourrer",
    "rembourrerai": "rembourrer",
    "rembourreraient": "rembourrer",
    "rembourrerais": "rembourrer",
    "rembourrerait": "rembourrer",
    "rembourreras": "rembourrer",
    "rembourrerez": "rembourrer",
    "rembourreriez": "rembourrer",
    "rembourrerions": "rembourrer",
    "rembourrerons": "rembourrer",
    "rembourreront": "rembourrer",
    "rembourres": "rembourrer",
    "rembourrez": "rembourrer",
    "rembourriez": "rembourrer",
    "rembourrions": "rembourrer",
    "rembourrons": "rembourrer",
    "rembourrâmes": "rembourrer",
    "rembourrât": "rembourrer",
    "rembourrâtes": "rembourrer",
    "rembourrèrent": "rembourrer",
    "rembourré": "rembourrer",
    "rembourrée": "rembourrer",
    "rembourrées": "rembourrer",
    "rembourrés": "rembourrer",
    "remboursa": "rembourser",
    "remboursables": "remboursable",
    "remboursai": "rembourser",
    "remboursaient": "rembourser",
    "remboursais": "rembourser",
    "remboursait": "rembourser",
    "remboursant": "rembourser",
    "remboursas": "rembourser",
    "remboursasse": "rembourser",
    "remboursassent": "rembourser",
    "remboursasses": "rembourser",
    "remboursassiez": "rembourser",
    "remboursassions": "rembourser",
    "rembourse": "rembourser",
    "remboursements": "remboursement",
    "remboursent": "rembourser",
    "remboursera": "rembourser",
    "rembourserai": "rembourser",
    "rembourseraient": "rembourser",
    "rembourserais": "rembourser",
    "rembourserait": "rembourser",
    "rembourseras": "rembourser",
    "rembourserez": "rembourser",
    "rembourseriez": "rembourser",
    "rembourserions": "rembourser",
    "rembourserons": "rembourser",
    "rembourseront": "rembourser",
    "rembourses": "rembourser",
    "remboursez": "rembourser",
    "remboursiez": "rembourser",
    "remboursions": "rembourser",
    "remboursons": "rembourser",
    "remboursâmes": "rembourser",
    "remboursât": "rembourser",
    "remboursâtes": "rembourser",
    "remboursèrent": "rembourser",
    "remboursé": "rembourser",
    "remboursée": "rembourser",
    "remboursées": "rembourser",
    "remboursés": "rembourser",
    "remboîta": "remboîter",
    "remboîtai": "remboîter",
    "remboîtaient": "remboîter",
    "remboîtais": "remboîter",
    "remboîtait": "remboîter",
    "remboîtant": "remboîter",
    "remboîtas": "remboîter",
    "remboîtasse": "remboîter",
    "remboîtassent": "remboîter",
    "remboîtasses": "remboîter",
    "remboîtassiez": "remboîter",
    "remboîtassions": "remboîter",
    "remboîte": "remboîter",
    "remboîtent": "remboîter",
    "remboîtera": "remboîter",
    "remboîterai": "remboîter",
    "remboîteraient": "remboîter",
    "remboîterais": "remboîter",
    "remboîterait": "remboîter",
    "remboîteras": "remboîter",
    "remboîterez": "remboîter",
    "remboîteriez": "remboîter",
    "remboîterions": "remboîter",
    "remboîterons": "remboîter",
    "remboîteront": "remboîter",
    "remboîtes": "remboîter",
    "remboîtez": "remboîter",
    "remboîtiez": "remboîter",
    "remboîtions": "remboîter",
    "remboîtons": "remboîter",
    "remboîtâmes": "remboîter",
    "remboîtât": "remboîter",
    "remboîtâtes": "remboîter",
    "remboîtèrent": "remboîter",
    "remboîté": "remboîter",
    "remboîtée": "remboîter",
    "remboîtées": "remboîter",
    "remboîtés": "remboîter",
    "rembruni": "rembrunir",
    "rembrunie": "rembrunir",
    "rembrunies": "rembrunir",
    "rembrunira": "rembrunir",
    "rembrunirai": "rembrunir",
    "rembruniraient": "rembrunir",
    "rembrunirais": "rembrunir",
    "rembrunirait": "rembrunir",
    "rembruniras": "rembrunir",
    "rembrunirent": "rembrunir",
    "rembrunirez": "rembrunir",
    "rembruniriez": "rembrunir",
    "rembrunirions": "rembrunir",
    "rembrunirons": "rembrunir",
    "rembruniront": "rembrunir",
    "rembrunis": "rembrunir",
    "rembrunissaient": "rembrunir",
    "rembrunissais": "rembrunir",
    "rembrunissait": "rembrunir",
    "rembrunissant": "rembrunir",
    "rembrunisse": "rembrunir",
    "rembrunissent": "rembrunir",
    "rembrunisses": "rembrunir",
    "rembrunissez": "rembrunir",
    "rembrunissiez": "rembrunir",
    "rembrunissions": "rembrunir",
    "rembrunissons": "rembrunir",
    "rembrunit": "rembrunir",
    "rembrunîmes": "rembrunir",
    "rembrunît": "rembrunir",
    "rembrunîtes": "rembrunir",
    "rembucha": "rembucher",
    "rembuchai": "rembucher",
    "rembuchaient": "rembucher",
    "rembuchais": "rembucher",
    "rembuchait": "rembucher",
    "rembuchant": "rembucher",
    "rembuchas": "rembucher",
    "rembuchasse": "rembucher",
    "rembuchassent": "rembucher",
    "rembuchasses": "rembucher",
    "rembuchassiez": "rembucher",
    "rembuchassions": "rembucher",
    "rembuche": "rembucher",
    "rembuchent": "rembucher",
    "rembuchera": "rembucher",
    "rembucherai": "rembucher",
    "rembucheraient": "rembucher",
    "rembucherais": "rembucher",
    "rembucherait": "rembucher",
    "rembucheras": "rembucher",
    "rembucherez": "rembucher",
    "rembucheriez": "rembucher",
    "rembucherions": "rembucher",
    "rembucherons": "rembucher",
    "rembucheront": "rembucher",
    "rembuches": "rembucher",
    "rembuchez": "rembucher",
    "rembuchiez": "rembucher",
    "rembuchions": "rembucher",
    "rembuchons": "rembucher",
    "rembuchâmes": "rembucher",
    "rembuchât": "rembucher",
    "rembuchâtes": "rembucher",
    "rembuchèrent": "rembucher",
    "rembuché": "rembucher",
    "rembuchée": "rembucher",
    "rembuchées": "rembucher",
    "rembuchés": "rembucher",
    "remembra": "remembrer",
    "remembrai": "remembrer",
    "remembraient": "remembrer",
    "remembrais": "remembrer",
    "remembrait": "remembrer",
    "remembrant": "remembrer",
    "remembras": "remembrer",
    "remembrasse": "remembrer",
    "remembrassent": "remembrer",
    "remembrasses": "remembrer",
    "remembrassiez": "remembrer",
    "remembrassions": "remembrer",
    "remembre": "remembrer",
    "remembrent": "remembrer",
    "remembrera": "remembrer",
    "remembrerai": "remembrer",
    "remembreraient": "remembrer",
    "remembrerais": "remembrer",
    "remembrerait": "remembrer",
    "remembreras": "remembrer",
    "remembrerez": "remembrer",
    "remembreriez": "remembrer",
    "remembrerions": "remembrer",
    "remembrerons": "remembrer",
    "remembreront": "remembrer",
    "remembres": "remembrer",
    "remembrez": "remembrer",
    "remembriez": "remembrer",
    "remembrions": "remembrer",
    "remembrons": "remembrer",
    "remembrâmes": "remembrer",
    "remembrât": "remembrer",
    "remembrâtes": "remembrer",
    "remembrèrent": "remembrer",
    "remembré": "remembrer",
    "remembrée": "remembrer",
    "remembrées": "remembrer",
    "remembrés": "remembrer",
    "remercia": "remercier",
    "remerciai": "remercier",
    "remerciaient": "remercier",
    "remerciais": "remercier",
    "remerciait": "remercier",
    "remerciant": "remercier",
    "remercias": "remercier",
    "remerciasse": "remercier",
    "remerciassent": "remercier",
    "remerciasses": "remercier",
    "remerciassiez": "remercier",
    "remerciassions": "remercier",
    "remercie": "remercier",
    "remerciements": "remerciement",
    "remercient": "remercier",
    "remerciera": "remercier",
    "remercierai": "remercier",
    "remercieraient": "remercier",
    "remercierais": "remercier",
    "remercierait": "remercier",
    "remercieras": "remercier",
    "remercierez": "remercier",
    "remercieriez": "remercier",
    "remercierions": "remercier",
    "remercierons": "remercier",
    "remercieront": "remercier",
    "remercies": "remercier",
    "remerciez": "remercier",
    "remerciiez": "remercier",
    "remerciions": "remercier",
    "remercions": "remercier",
    "remerciâmes": "remercier",
    "remerciât": "remercier",
    "remerciâtes": "remercier",
    "remercièrent": "remercier",
    "remercié": "remercier",
    "remerciée": "remercier",
    "remerciées": "remercier",
    "remerciés": "remercier",
    "remet": "remettre",
    "remets": "remettre",
    "remettaient": "remettre",
    "remettais": "remettre",
    "remettait": "remettre",
    "remettant": "remettre",
    "remette": "remettre",
    "remettent": "remettre",
    "remettes": "remettre",
    "remettez": "remettre",
    "remettiez": "remettre",
    "remettions": "remettre",
    "remettons": "remettre",
    "remettra": "remettre",
    "remettrai": "remettre",
    "remettraient": "remettre",
    "remettrais": "remettre",
    "remettrait": "remettre",
    "remettras": "remettre",
    "remettrez": "remettre",
    "remettriez": "remettre",
    "remettrions": "remettre",
    "remettrons": "remettre",
    "remettront": "remettre",
    "remeubla": "remeubler",
    "remeublai": "remeubler",
    "remeublaient": "remeubler",
    "remeublais": "remeubler",
    "remeublait": "remeubler",
    "remeublant": "remeubler",
    "remeublas": "remeubler",
    "remeublasse": "remeubler",
    "remeublassent": "remeubler",
    "remeublasses": "remeubler",
    "remeublassiez": "remeubler",
    "remeublassions": "remeubler",
    "remeuble": "remeubler",
    "remeublent": "remeubler",
    "remeublera": "remeubler",
    "remeublerai": "remeubler",
    "remeubleraient": "remeubler",
    "remeublerais": "remeubler",
    "remeublerait": "remeubler",
    "remeubleras": "remeubler",
    "remeublerez": "remeubler",
    "remeubleriez": "remeubler",
    "remeublerions": "remeubler",
    "remeublerons": "remeubler",
    "remeubleront": "remeubler",
    "remeubles": "remeubler",
    "remeublez": "remeubler",
    "remeubliez": "remeubler",
    "remeublions": "remeubler",
    "remeublons": "remeubler",
    "remeublâmes": "remeubler",
    "remeublât": "remeubler",
    "remeublâtes": "remeubler",
    "remeublèrent": "remeubler",
    "remeublé": "remeubler",
    "remeublée": "remeubler",
    "remeublées": "remeubler",
    "remeublés": "remeubler",
    "remilitarisa": "remilitariser",
    "remilitarisai": "remilitariser",
    "remilitarisaient": "remilitariser",
    "remilitarisais": "remilitariser",
    "remilitarisait": "remilitariser",
    "remilitarisant": "remilitariser",
    "remilitarisas": "remilitariser",
    "remilitarisasse": "remilitariser",
    "remilitarisassent": "remilitariser",
    "remilitarisasses": "remilitariser",
    "remilitarisassiez": "remilitariser",
    "remilitarisassions": "remilitariser",
    "remilitarise": "remilitariser",
    "remilitarisent": "remilitariser",
    "remilitarisera": "remilitariser",
    "remilitariserai": "remilitariser",
    "remilitariseraient": "remilitariser",
    "remilitariserais": "remilitariser",
    "remilitariserait": "remilitariser",
    "remilitariseras": "remilitariser",
    "remilitariserez": "remilitariser",
    "remilitariseriez": "remilitariser",
    "remilitariserions": "remilitariser",
    "remilitariserons": "remilitariser",
    "remilitariseront": "remilitariser",
    "remilitarises": "remilitariser",
    "remilitarisez": "remilitariser",
    "remilitarisiez": "remilitariser",
    "remilitarisions": "remilitariser",
    "remilitarisons": "remilitariser",
    "remilitarisâmes": "remilitariser",
    "remilitarisât": "remilitariser",
    "remilitarisâtes": "remilitariser",
    "remilitarisèrent": "remilitariser",
    "remilitarisé": "remilitariser",
    "remilitarisée": "remilitariser",
    "remilitarisées": "remilitariser",
    "remilitarisés": "remilitariser",
    "remirent": "remettre",
    "remis": "remettre",
    "remisa": "remiser",
    "remisai": "remiser",
    "remisaient": "remiser",
    "remisais": "remiser",
    "remisait": "remiser",
    "remisant": "remiser",
    "remisas": "remiser",
    "remisasse": "remiser",
    "remisassent": "remiser",
    "remisasses": "remiser",
    "remisassiez": "remiser",
    "remisassions": "remiser",
    "remise": "remiser",
    "remisent": "remiser",
    "remisera": "remiser",
    "remiserai": "remiser",
    "remiseraient": "remiser",
    "remiserais": "remiser",
    "remiserait": "remiser",
    "remiseras": "remiser",
    "remiserez": "remiser",
    "remiseriez": "remiser",
    "remiserions": "remiser",
    "remiserons": "remiser",
    "remiseront": "remiser",
    "remises": "remiser",
    "remisez": "remiser",
    "remisiers": "remisier",
    "remisiez": "remiser",
    "remisions": "remiser",
    "remisons": "remiser",
    "remisse": "remettre",
    "remissent": "remettre",
    "remisses": "remettre",
    "remissiez": "remettre",
    "remissions": "remettre",
    "remisâmes": "remiser",
    "remisât": "remiser",
    "remisâtes": "remiser",
    "remisèrent": "remiser",
    "remisé": "remiser",
    "remisée": "remiser",
    "remisées": "remiser",
    "remisés": "remiser",
    "remit": "remettre",
    "remmailla": "remmailler",
    "remmaillages": "remmaillage",
    "remmaillai": "remmailler",
    "remmaillaient": "remmailler",
    "remmaillais": "remmailler",
    "remmaillait": "remmailler",
    "remmaillant": "remmailler",
    "remmaillas": "remmailler",
    "remmaillasse": "remmailler",
    "remmaillassent": "remmailler",
    "remmaillasses": "remmailler",
    "remmaillassiez": "remmailler",
    "remmaillassions": "remmailler",
    "remmaille": "remmailler",
    "remmaillent": "remmailler",
    "remmaillera": "remmailler",
    "remmaillerai": "remmailler",
    "remmailleraient": "remmailler",
    "remmaillerais": "remmailler",
    "remmaillerait": "remmailler",
    "remmailleras": "remmailler",
    "remmaillerez": "remmailler",
    "remmailleriez": "remmailler",
    "remmaillerions": "remmailler",
    "remmaillerons": "remmailler",
    "remmailleront": "remmailler",
    "remmailles": "remmailler",
    "remmailleuses": "remmailleuse",
    "remmaillez": "remmailler",
    "remmailliez": "remmailler",
    "remmaillions": "remmailler",
    "remmaillons": "remmailler",
    "remmaillâmes": "remmailler",
    "remmaillât": "remmailler",
    "remmaillâtes": "remmailler",
    "remmaillèrent": "remmailler",
    "remmaillé": "remmailler",
    "remmaillée": "remmailler",
    "remmaillées": "remmailler",
    "remmaillés": "remmailler",
    "remmena": "remmener",
    "remmenai": "remmener",
    "remmenaient": "remmener",
    "remmenais": "remmener",
    "remmenait": "remmener",
    "remmenant": "remmener",
    "remmenas": "remmener",
    "remmenasse": "remmener",
    "remmenassent": "remmener",
    "remmenasses": "remmener",
    "remmenassiez": "remmener",
    "remmenassions": "remmener",
    "remmenez": "remmener",
    "remmeniez": "remmener",
    "remmenions": "remmener",
    "remmenons": "remmener",
    "remmenâmes": "remmener",
    "remmenât": "remmener",
    "remmenâtes": "remmener",
    "remmenèrent": "remmener",
    "remmené": "remmener",
    "remmenée": "remmener",
    "remmenées": "remmener",
    "remmenés": "remmener",
    "remmoulages": "remmoulage",
    "remmène": "remmener",
    "remmènent": "remmener",
    "remmènera": "remmener",
    "remmènerai": "remmener",
    "remmèneraient": "remmener",
    "remmènerais": "remmener",
    "remmènerait": "remmener",
    "remmèneras": "remmener",
    "remmènerez": "remmener",
    "remmèneriez": "remmener",
    "remmènerions": "remmener",
    "remmènerons": "remmener",
    "remmèneront": "remmener",
    "remmènes": "remmener",
    "remnuançables": "remnuançable",
    "remobilisés": "remobiliser",
    "remodela": "remodeler",
    "remodelages": "remodelage",
    "remodelai": "remodeler",
    "remodelaient": "remodeler",
    "remodelais": "remodeler",
    "remodelait": "remodeler",
    "remodelant": "remodeler",
    "remodelas": "remodeler",
    "remodelasse": "remodeler",
    "remodelassent": "remodeler",
    "remodelasses": "remodeler",
    "remodelassiez": "remodeler",
    "remodelassions": "remodeler",
    "remodelez": "remodeler",
    "remodeliez": "remodeler",
    "remodelions": "remodeler",
    "remodelons": "remodeler",
    "remodelâmes": "remodeler",
    "remodelât": "remodeler",
    "remodelâtes": "remodeler",
    "remodelèrent": "remodeler",
    "remodelé": "remodeler",
    "remodelée": "remodeler",
    "remodelées": "remodeler",
    "remodelés": "remodeler",
    "remodèle": "remodeler",
    "remodèlent": "remodeler",
    "remodèlera": "remodeler",
    "remodèlerai": "remodeler",
    "remodèleraient": "remodeler",
    "remodèlerais": "remodeler",
    "remodèlerait": "remodeler",
    "remodèleras": "remodeler",
    "remodèlerez": "remodeler",
    "remodèleriez": "remodeler",
    "remodèlerions": "remodeler",
    "remodèlerons": "remodeler",
    "remodèleront": "remodeler",
    "remodèles": "remodeler",
    "remonta": "remonter",
    "remontai": "remonter",
    "remontaient": "remonter",
    "remontais": "remonter",
    "remontait": "remonter",
    "remontant": "remonter",
    "remontantes": "remontant",
    "remontants": "remontant",
    "remontas": "remonter",
    "remontasse": "remonter",
    "remontassent": "remonter",
    "remontasses": "remonter",
    "remontassiez": "remonter",
    "remontassions": "remonter",
    "remonte": "remonter",
    "remonte-pentes": "remonte-pente",
    "remontent": "remonter",
    "remontera": "remonter",
    "remonterai": "remonter",
    "remonteraient": "remonter",
    "remonterais": "remonter",
    "remonterait": "remonter",
    "remonteras": "remonter",
    "remonterez": "remonter",
    "remonteriez": "remonter",
    "remonterions": "remonter",
    "remonterons": "remonter",
    "remonteront": "remonter",
    "remontes": "remonter",
    "remontez": "remonter",
    "remontiez": "remonter",
    "remontions": "remonter",
    "remontons": "remonter",
    "remontra": "remontrer",
    "remontrai": "remontrer",
    "remontraient": "remontrer",
    "remontrais": "remontrer",
    "remontrait": "remontrer",
    "remontrances": "remontrance",
    "remontrant": "remontrer",
    "remontras": "remontrer",
    "remontrasse": "remontrer",
    "remontrassent": "remontrer",
    "remontrasses": "remontrer",
    "remontrassiez": "remontrer",
    "remontrassions": "remontrer",
    "remontre": "remontrer",
    "remontrent": "remontrer",
    "remontrera": "remontrer",
    "remontrerai": "remontrer",
    "remontreraient": "remontrer",
    "remontrerais": "remontrer",
    "remontrerait": "remontrer",
    "remontreras": "remontrer",
    "remontrerez": "remontrer",
    "remontreriez": "remontrer",
    "remontrerions": "remontrer",
    "remontrerons": "remontrer",
    "remontreront": "remontrer",
    "remontres": "remontrer",
    "remontrez": "remontrer",
    "remontriez": "remontrer",
    "remontrions": "remontrer",
    "remontrons": "remontrer",
    "remontrâmes": "remontrer",
    "remontrât": "remontrer",
    "remontrâtes": "remontrer",
    "remontrèrent": "remontrer",
    "remontré": "remontrer",
    "remontrée": "remontrer",
    "remontrées": "remontrer",
    "remontrés": "remontrer",
    "remontâmes": "remonter",
    "remontât": "remonter",
    "remontâtes": "remonter",
    "remontèrent": "remonter",
    "remonté": "remonter",
    "remontée": "remonter",
    "remontées": "remonter",
    "remontés": "remonter",
    "remord": "remordre",
    "remordaient": "remordre",
    "remordais": "remordre",
    "remordait": "remordre",
    "remordant": "remordre",
    "remorde": "remordre",
    "remordent": "remordre",
    "remordes": "remordre",
    "remordez": "remordre",
    "remordiez": "remordre",
    "remordions": "remordre",
    "remordirent": "remordre",
    "remordis": "remordre",
    "remordisse": "remordre",
    "remordissent": "remordre",
    "remordisses": "remordre",
    "remordissiez": "remordre",
    "remordissions": "remordre",
    "remordit": "remordre",
    "remordons": "remordre",
    "remordra": "remordre",
    "remordrai": "remordre",
    "remordraient": "remordre",
    "remordrais": "remordre",
    "remordrait": "remordre",
    "remordras": "remordre",
    "remordrez": "remordre",
    "remordriez": "remordre",
    "remordrions": "remordre",
    "remordrons": "remordre",
    "remordront": "remordre",
    "remords": "remordre",
    "remordu": "remordre",
    "remordue": "remordre",
    "remordues": "remordre",
    "remordus": "remordre",
    "remordîmes": "remordre",
    "remordît": "remordre",
    "remordîtes": "remordre",
    "remorqua": "remorquer",
    "remorquages": "remorquage",
    "remorquai": "remorquer",
    "remorquaient": "remorquer",
    "remorquais": "remorquer",
    "remorquait": "remorquer",
    "remorquant": "remorquer",
    "remorquas": "remorquer",
    "remorquasse": "remorquer",
    "remorquassent": "remorquer",
    "remorquasses": "remorquer",
    "remorquassiez": "remorquer",
    "remorquassions": "remorquer",
    "remorque": "remorquer",
    "remorquent": "remorquer",
    "remorquera": "remorquer",
    "remorquerai": "remorquer",
    "remorqueraient": "remorquer",
    "remorquerais": "remorquer",
    "remorquerait": "remorquer",
    "remorqueras": "remorquer",
    "remorquerez": "remorquer",
    "remorqueriez": "remorquer",
    "remorquerions": "remorquer",
    "remorquerons": "remorquer",
    "remorqueront": "remorquer",
    "remorques": "remorquer",
    "remorqueurs": "remorqueur",
    "remorqueuse": "remorqueur",
    "remorquez": "remorquer",
    "remorquiez": "remorquer",
    "remorquions": "remorquer",
    "remorquons": "remorquer",
    "remorquâmes": "remorquer",
    "remorquât": "remorquer",
    "remorquâtes": "remorquer",
    "remorquèrent": "remorquer",
    "remorqué": "remorquer",
    "remorquée": "remorquer",
    "remorquées": "remorquer",
    "remorqués": "remorquer",
    "remotorisations": "remotorisation",
    "remoucha": "remoucher",
    "remouchai": "remoucher",
    "remouchaient": "remoucher",
    "remouchais": "remoucher",
    "remouchait": "remoucher",
    "remouchant": "remoucher",
    "remouchas": "remoucher",
    "remouchasse": "remoucher",
    "remouchassent": "remoucher",
    "remouchasses": "remoucher",
    "remouchassiez": "remoucher",
    "remouchassions": "remoucher",
    "remouche": "remoucher",
    "remouchent": "remoucher",
    "remouchera": "remoucher",
    "remoucherai": "remoucher",
    "remoucheraient": "remoucher",
    "remoucherais": "remoucher",
    "remoucherait": "remoucher",
    "remoucheras": "remoucher",
    "remoucherez": "remoucher",
    "remoucheriez": "remoucher",
    "remoucherions": "remoucher",
    "remoucherons": "remoucher",
    "remoucheront": "remoucher",
    "remouches": "remoucher",
    "remouchez": "remoucher",
    "remouchiez": "remoucher",
    "remouchions": "remoucher",
    "remouchons": "remoucher",
    "remouchâmes": "remoucher",
    "remouchât": "remoucher",
    "remouchâtes": "remoucher",
    "remouchèrent": "remoucher",
    "remouché": "remoucher",
    "remouchée": "remoucher",
    "remouchées": "remoucher",
    "remouchés": "remoucher",
    "remoud": "remoudre",
    "remoudra": "remoudre",
    "remoudrai": "remoudre",
    "remoudraient": "remoudre",
    "remoudrais": "remoudre",
    "remoudrait": "remoudre",
    "remoudras": "remoudre",
    "remoudrez": "remoudre",
    "remoudriez": "remoudre",
    "remoudrions": "remoudre",
    "remoudrons": "remoudre",
    "remoudront": "remoudre",
    "remouds": "remoudre",
    "remouilla": "remouiller",
    "remouillai": "remouiller",
    "remouillaient": "remouiller",
    "remouillais": "remouiller",
    "remouillait": "remouiller",
    "remouillant": "remouiller",
    "remouillas": "remouiller",
    "remouillasse": "remouiller",
    "remouillassent": "remouiller",
    "remouillasses": "remouiller",
    "remouillassiez": "remouiller",
    "remouillassions": "remouiller",
    "remouille": "remouiller",
    "remouillent": "remouiller",
    "remouillera": "remouiller",
    "remouillerai": "remouiller",
    "remouilleraient": "remouiller",
    "remouillerais": "remouiller",
    "remouillerait": "remouiller",
    "remouilleras": "remouiller",
    "remouillerez": "remouiller",
    "remouilleriez": "remouiller",
    "remouillerions": "remouiller",
    "remouillerons": "remouiller",
    "remouilleront": "remouiller",
    "remouilles": "remouiller",
    "remouillez": "remouiller",
    "remouilliez": "remouiller",
    "remouillions": "remouiller",
    "remouillons": "remouiller",
    "remouillâmes": "remouiller",
    "remouillât": "remouiller",
    "remouillâtes": "remouiller",
    "remouillèrent": "remouiller",
    "remouillé": "remouiller",
    "remouillée": "remouiller",
    "remouillées": "remouiller",
    "remouillés": "remouiller",
    "remoula": "remouler",
    "remoulages": "remoulage",
    "remoulai": "remouler",
    "remoulaient": "remouler",
    "remoulais": "remouler",
    "remoulait": "remouler",
    "remoulant": "remouler",
    "remoulas": "remouler",
    "remoulasse": "remouler",
    "remoulassent": "remouler",
    "remoulasses": "remouler",
    "remoulassiez": "remouler",
    "remoulassions": "remouler",
    "remoule": "remouler",
    "remoulent": "remouler",
    "remoulera": "remouler",
    "remoulerai": "remouler",
    "remouleraient": "remouler",
    "remoulerais": "remouler",
    "remoulerait": "remouler",
    "remouleras": "remouler",
    "remoulerez": "remouler",
    "remouleriez": "remouler",
    "remoulerions": "remouler",
    "remoulerons": "remouler",
    "remouleront": "remouler",
    "remoules": "remouler",
    "remoulez": "remouler",
    "remouliez": "remouler",
    "remoulions": "remouler",
    "remoulons": "remouler",
    "remoulu": "remoudre",
    "remoulue": "remoudre",
    "remoulues": "remoudre",
    "remoulurent": "remoudre",
    "remoulus": "remoudre",
    "remoulusse": "remoudre",
    "remoulussent": "remoudre",
    "remoulusses": "remoudre",
    "remoulussiez": "remoudre",
    "remoulussions": "remoudre",
    "remoulut": "remoudre",
    "remoulâmes": "remouler",
    "remoulât": "remouler",
    "remoulâtes": "remouler",
    "remoulèrent": "remouler",
    "remoulé": "remouler",
    "remoulée": "remouler",
    "remoulées": "remouler",
    "remoulés": "remouler",
    "remoulûmes": "remoudre",
    "remoulût": "remoudre",
    "remoulûtes": "remoudre",
    "rempailla": "rempailler",
    "rempaillai": "rempailler",
    "rempaillaient": "rempailler",
    "rempaillais": "rempailler",
    "rempaillait": "rempailler",
    "rempaillant": "rempailler",
    "rempaillas": "rempailler",
    "rempaillasse": "rempailler",
    "rempaillassent": "rempailler",
    "rempaillasses": "rempailler",
    "rempaillassiez": "rempailler",
    "rempaillassions": "rempailler",
    "rempaille": "rempailler",
    "rempaillent": "rempailler",
    "rempaillera": "rempailler",
    "rempaillerai": "rempailler",
    "rempailleraient": "rempailler",
    "rempaillerais": "rempailler",
    "rempaillerait": "rempailler",
    "rempailleras": "rempailler",
    "rempaillerez": "rempailler",
    "rempailleriez": "rempailler",
    "rempaillerions": "rempailler",
    "rempaillerons": "rempailler",
    "rempailleront": "rempailler",
    "rempailles": "rempailler",
    "rempailleurs": "rempailleur",
    "rempailleuses": "rempailleur",
    "rempaillez": "rempailler",
    "rempailliez": "rempailler",
    "rempaillions": "rempailler",
    "rempaillons": "rempailler",
    "rempaillâmes": "rempailler",
    "rempaillât": "rempailler",
    "rempaillâtes": "rempailler",
    "rempaillèrent": "rempailler",
    "rempaillé": "rempailler",
    "rempaillée": "rempailler",
    "rempaillées": "rempailler",
    "rempaillés": "rempailler",
    "rempaqueta": "rempaqueter",
    "rempaquetai": "rempaqueter",
    "rempaquetaient": "rempaqueter",
    "rempaquetais": "rempaqueter",
    "rempaquetait": "rempaqueter",
    "rempaquetant": "rempaqueter",
    "rempaquetas": "rempaqueter",
    "rempaquetasse": "rempaqueter",
    "rempaquetassent": "rempaqueter",
    "rempaquetasses": "rempaqueter",
    "rempaquetassiez": "rempaqueter",
    "rempaquetassions": "rempaqueter",
    "rempaquetez": "rempaqueter",
    "rempaquetiez": "rempaqueter",
    "rempaquetions": "rempaqueter",
    "rempaquetons": "rempaqueter",
    "rempaquette": "rempaqueter",
    "rempaquettent": "rempaqueter",
    "rempaquettera": "rempaqueter",
    "rempaquetterai": "rempaqueter",
    "rempaquetteraient": "rempaqueter",
    "rempaquetterais": "rempaqueter",
    "rempaquetterait": "rempaqueter",
    "rempaquetteras": "rempaqueter",
    "rempaquetterez": "rempaqueter",
    "rempaquetteriez": "rempaqueter",
    "rempaquetterions": "rempaqueter",
    "rempaquetterons": "rempaqueter",
    "rempaquetteront": "rempaqueter",
    "rempaquettes": "rempaqueter",
    "rempaquetâmes": "rempaqueter",
    "rempaquetât": "rempaqueter",
    "rempaquetâtes": "rempaqueter",
    "rempaquetèrent": "rempaqueter",
    "rempaqueté": "rempaqueter",
    "rempaquetée": "rempaqueter",
    "rempaquetées": "rempaqueter",
    "rempaquetés": "rempaqueter",
    "remparts": "rempart",
    "rempila": "rempiler",
    "rempilai": "rempiler",
    "rempilaient": "rempiler",
    "rempilais": "rempiler",
    "rempilait": "rempiler",
    "rempilant": "rempiler",
    "rempilas": "rempiler",
    "rempilasse": "rempiler",
    "rempilassent": "rempiler",
    "rempilasses": "rempiler",
    "rempilassiez": "rempiler",
    "rempilassions": "rempiler",
    "rempile": "rempiler",
    "rempilent": "rempiler",
    "rempilera": "rempiler",
    "rempilerai": "rempiler",
    "rempileraient": "rempiler",
    "rempilerais": "rempiler",
    "rempilerait": "rempiler",
    "rempileras": "rempiler",
    "rempilerez": "rempiler",
    "rempileriez": "rempiler",
    "rempilerions": "rempiler",
    "rempilerons": "rempiler",
    "rempileront": "rempiler",
    "rempiles": "rempiler",
    "rempilez": "rempiler",
    "rempiliez": "rempiler",
    "rempilions": "rempiler",
    "rempilons": "rempiler",
    "rempilâmes": "rempiler",
    "rempilât": "rempiler",
    "rempilâtes": "rempiler",
    "rempilèrent": "rempiler",
    "rempilé": "rempiler",
    "rempilée": "rempiler",
    "rempilées": "rempiler",
    "rempilés": "rempiler",
    "remplace": "remplacer",
    "remplacements": "remplacement",
    "remplacent": "remplacer",
    "remplacera": "remplacer",
    "remplacerai": "remplacer",
    "remplaceraient": "remplacer",
    "remplacerais": "remplacer",
    "remplacerait": "remplacer",
    "remplaceras": "remplacer",
    "remplacerez": "remplacer",
    "remplaceriez": "remplacer",
    "remplacerions": "remplacer",
    "remplacerons": "remplacer",
    "remplaceront": "remplacer",
    "remplaces": "remplacer",
    "remplacez": "remplacer",
    "remplaciez": "remplacer",
    "remplacions": "remplacer",
    "remplacèrent": "remplacer",
    "remplacé": "remplacer",
    "remplacée": "remplacer",
    "remplacées": "remplacer",
    "remplacés": "remplacer",
    "remplaça": "remplacer",
    "remplaçable": "remnuançable",
    "remplaçables": "remplaçable",
    "remplaçai": "remplacer",
    "remplaçaient": "remplacer",
    "remplaçais": "remplacer",
    "remplaçait": "remplacer",
    "remplaçant": "remplacer",
    "remplaçante": "remplaçant",
    "remplaçantes": "remplaçant",
    "remplaçants": "remplaçant",
    "remplaças": "remplacer",
    "remplaçasse": "remplacer",
    "remplaçassent": "remplacer",
    "remplaçasses": "remplacer",
    "remplaçassiez": "remplacer",
    "remplaçassions": "remplacer",
    "remplaçons": "remplacer",
    "remplaçâmes": "remplacer",
    "remplaçât": "remplacer",
    "remplaçâtes": "remplacer",
    "rempli": "remplir",
    "remplia": "remplier",
    "rempliai": "remplier",
    "rempliaient": "remplier",
    "rempliais": "remplier",
    "rempliait": "remplier",
    "rempliant": "remplier",
    "remplias": "remplier",
    "rempliasse": "remplier",
    "rempliassent": "remplier",
    "rempliasses": "remplier",
    "rempliassiez": "remplier",
    "rempliassions": "remplier",
    "remplie": "remplir",
    "remplient": "remplier",
    "rempliera": "remplier",
    "remplierai": "remplier",
    "remplieraient": "remplier",
    "remplierais": "remplier",
    "remplierait": "remplier",
    "remplieras": "remplier",
    "remplierez": "remplier",
    "remplieriez": "remplier",
    "remplierions": "remplier",
    "remplierons": "remplier",
    "remplieront": "remplier",
    "remplies": "remplir",
    "rempliez": "remplier",
    "rempliiez": "remplier",
    "rempliions": "remplier",
    "remplions": "remplier",
    "remplira": "remplir",
    "remplirai": "remplir",
    "rempliraient": "remplir",
    "remplirais": "remplir",
    "remplirait": "remplir",
    "rempliras": "remplir",
    "remplirent": "remplir",
    "remplirez": "remplir",
    "rempliriez": "remplir",
    "remplirions": "remplir",
    "remplirons": "remplir",
    "rempliront": "remplir",
    "remplis": "remplir",
    "remplissages": "remplissage",
    "remplissaient": "remplir",
    "remplissais": "remplir",
    "remplissait": "remplir",
    "remplissant": "remplir",
    "remplisse": "remplir",
    "remplissent": "remplir",
    "remplisses": "remplir",
    "remplissez": "remplir",
    "remplissiez": "remplir",
    "remplissions": "remplir",
    "remplissons": "remplir",
    "remplit": "remplir",
    "rempliâmes": "remplier",
    "rempliât": "remplier",
    "rempliâtes": "remplier",
    "remplièrent": "remplier",
    "remplié": "remplier",
    "rempliée": "remplier",
    "rempliées": "remplier",
    "rempliés": "remplier",
    "remploie": "remployer",
    "remploient": "remployer",
    "remploiera": "remployer",
    "remploierai": "remployer",
    "remploieraient": "remployer",
    "remploierais": "remployer",
    "remploierait": "remployer",
    "remploieras": "remployer",
    "remploierez": "remployer",
    "remploieriez": "remployer",
    "remploierions": "remployer",
    "remploierons": "remployer",
    "remploieront": "remployer",
    "remploies": "remployer",
    "remplois": "remploi",
    "remploya": "remployer",
    "remployai": "remployer",
    "remployaient": "remployer",
    "remployais": "remployer",
    "remployait": "remployer",
    "remployant": "remployer",
    "remployas": "remployer",
    "remployasse": "remployer",
    "remployassent": "remployer",
    "remployasses": "remployer",
    "remployassiez": "remployer",
    "remployassions": "remployer",
    "remployez": "remployer",
    "remployiez": "remployer",
    "remployions": "remployer",
    "remployons": "remployer",
    "remployâmes": "remployer",
    "remployât": "remployer",
    "remployâtes": "remployer",
    "remployèrent": "remployer",
    "remployé": "remployer",
    "remployée": "remployer",
    "remployées": "remployer",
    "remployés": "remployer",
    "rempluma": "remplumer",
    "remplumai": "remplumer",
    "remplumaient": "remplumer",
    "remplumais": "remplumer",
    "remplumait": "remplumer",
    "remplumant": "remplumer",
    "remplumas": "remplumer",
    "remplumasse": "remplumer",
    "remplumassent": "remplumer",
    "remplumasses": "remplumer",
    "remplumassiez": "remplumer",
    "remplumassions": "remplumer",
    "remplume": "remplumer",
    "remplument": "remplumer",
    "remplumera": "remplumer",
    "remplumerai": "remplumer",
    "remplumeraient": "remplumer",
    "remplumerais": "remplumer",
    "remplumerait": "remplumer",
    "remplumeras": "remplumer",
    "remplumerez": "remplumer",
    "remplumeriez": "remplumer",
    "remplumerions": "remplumer",
    "remplumerons": "remplumer",
    "remplumeront": "remplumer",
    "remplumes": "remplumer",
    "remplumez": "remplumer",
    "remplumiez": "remplumer",
    "remplumions": "remplumer",
    "remplumons": "remplumer",
    "remplumâmes": "remplumer",
    "remplumât": "remplumer",
    "remplumâtes": "remplumer",
    "remplumèrent": "remplumer",
    "remplumé": "remplumer",
    "remplumée": "remplumer",
    "remplumées": "remplumer",
    "remplumés": "remplumer",
    "remplîmes": "remplir",
    "remplît": "remplir",
    "remplîtes": "remplir",
    "rempochait": "rempocher",
    "rempoche": "rempocher",
    "remporta": "remporter",
    "remportai": "remporter",
    "remportaient": "remporter",
    "remportais": "remporter",
    "remportait": "remporter",
    "remportant": "remporter",
    "remportas": "remporter",
    "remportasse": "remporter",
    "remportassent": "remporter",
    "remportasses": "remporter",
    "remportassiez": "remporter",
    "remportassions": "remporter",
    "remporte": "remporter",
    "remportent": "remporter",
    "remportera": "remporter",
    "remporterai": "remporter",
    "remporteraient": "remporter",
    "remporterais": "remporter",
    "remporterait": "remporter",
    "remporteras": "remporter",
    "remporterez": "remporter",
    "remporteriez": "remporter",
    "remporterions": "remporter",
    "remporterons": "remporter",
    "remporteront": "remporter",
    "remportes": "remporter",
    "remportez": "remporter",
    "remportiez": "remporter",
    "remportions": "remporter",
    "remportons": "remporter",
    "remportâmes": "remporter",
    "remportât": "remporter",
    "remportâtes": "remporter",
    "remportèrent": "remporter",
    "remporté": "remporter",
    "remportée": "remporter",
    "remportées": "remporter",
    "remportés": "remporter",
    "rempota": "rempoter",
    "rempotai": "rempoter",
    "rempotaient": "rempoter",
    "rempotais": "rempoter",
    "rempotait": "rempoter",
    "rempotant": "rempoter",
    "rempotas": "rempoter",
    "rempotasse": "rempoter",
    "rempotassent": "rempoter",
    "rempotasses": "rempoter",
    "rempotassiez": "rempoter",
    "rempotassions": "rempoter",
    "rempote": "rempoter",
    "rempotent": "rempoter",
    "rempotera": "rempoter",
    "rempoterai": "rempoter",
    "rempoteraient": "rempoter",
    "rempoterais": "rempoter",
    "rempoterait": "rempoter",
    "rempoteras": "rempoter",
    "rempoterez": "rempoter",
    "rempoteriez": "rempoter",
    "rempoterions": "rempoter",
    "rempoterons": "rempoter",
    "rempoteront": "rempoter",
    "rempotes": "rempoter",
    "rempotez": "rempoter",
    "rempotiez": "rempoter",
    "rempotions": "rempoter",
    "rempotons": "rempoter",
    "rempotâmes": "rempoter",
    "rempotât": "rempoter",
    "rempotâtes": "rempoter",
    "rempotèrent": "rempoter",
    "rempoté": "rempoter",
    "rempotée": "rempoter",
    "rempotées": "rempoter",
    "rempotés": "rempoter",
    "remua": "remuer",
    "remuai": "remuer",
    "remuaient": "remuer",
    "remuais": "remuer",
    "remuait": "remuer",
    "remuant": "remuer",
    "remuante": "remuant",
    "remuantes": "remuant",
    "remuants": "remuant",
    "remuas": "remuer",
    "remuasse": "remuer",
    "remuassent": "remuer",
    "remuasses": "remuer",
    "remuassiez": "remuer",
    "remuassions": "remuer",
    "remue": "remuer",
    "remuements": "remuement",
    "remuent": "remuer",
    "remuera": "remuer",
    "remuerai": "remuer",
    "remueraient": "remuer",
    "remuerais": "remuer",
    "remuerait": "remuer",
    "remueras": "remuer",
    "remuerez": "remuer",
    "remueriez": "remuer",
    "remuerions": "remuer",
    "remuerons": "remuer",
    "remueront": "remuer",
    "remues": "remuer",
    "remueurs": "remueur",
    "remuez": "remuer",
    "remugles": "remugle",
    "remuiez": "remuer",
    "remuions": "remuer",
    "remuons": "remuer",
    "remuscle": "remuscler",
    "remuâmes": "remuer",
    "remuât": "remuer",
    "remuâtes": "remuer",
    "remuèrent": "remuer",
    "remué": "remuer",
    "remuée": "remuer",
    "remuées": "remuer",
    "remués": "remuer",
    "remâcha": "remâcher",
    "remâchai": "remâcher",
    "remâchaient": "remâcher",
    "remâchais": "remâcher",
    "remâchait": "remâcher",
    "remâchant": "remâcher",
    "remâchas": "remâcher",
    "remâchasse": "remâcher",
    "remâchassent": "remâcher",
    "remâchasses": "remâcher",
    "remâchassiez": "remâcher",
    "remâchassions": "remâcher",
    "remâche": "remâcher",
    "remâchent": "remâcher",
    "remâchera": "remâcher",
    "remâcherai": "remâcher",
    "remâcheraient": "remâcher",
    "remâcherais": "remâcher",
    "remâcherait": "remâcher",
    "remâcheras": "remâcher",
    "remâcherez": "remâcher",
    "remâcheriez": "remâcher",
    "remâcherions": "remâcher",
    "remâcherons": "remâcher",
    "remâcheront": "remâcher",
    "remâches": "remâcher",
    "remâchez": "remâcher",
    "remâchiez": "remâcher",
    "remâchions": "remâcher",
    "remâchons": "remâcher",
    "remâchâmes": "remâcher",
    "remâchât": "remâcher",
    "remâchâtes": "remâcher",
    "remâchèrent": "remâcher",
    "remâché": "remâcher",
    "remâchée": "remâcher",
    "remâchées": "remâcher",
    "remâchés": "remâcher",
    "remèdes": "remède",
    "remédia": "remédier",
    "remédiables": "remédiable",
    "remédiai": "remédier",
    "remédiaient": "remédier",
    "remédiais": "remédier",
    "remédiait": "remédier",
    "remédiant": "remédier",
    "remédias": "remédier",
    "remédiasse": "remédier",
    "remédiassent": "remédier",
    "remédiasses": "remédier",
    "remédiassiez": "remédier",
    "remédiassions": "remédier",
    "remédie": "remédier",
    "remédient": "remédier",
    "remédiera": "remédier",
    "remédierai": "remédier",
    "remédieraient": "remédier",
    "remédierais": "remédier",
    "remédierait": "remédier",
    "remédieras": "remédier",
    "remédierez": "remédier",
    "remédieriez": "remédier",
    "remédierions": "remédier",
    "remédierons": "remédier",
    "remédieront": "remédier",
    "remédies": "remédier",
    "remédiez": "remédier",
    "remédiiez": "remédier",
    "remédiions": "remédier",
    "remédions": "remédier",
    "remédiâmes": "remédier",
    "remédiât": "remédier",
    "remédiâtes": "remédier",
    "remédièrent": "remédier",
    "remédié": "remédier",
    "remémora": "remémorer",
    "remémorai": "remémorer",
    "remémoraient": "remémorer",
    "remémorais": "remémorer",
    "remémorait": "remémorer",
    "remémorant": "remémorer",
    "remémoras": "remémorer",
    "remémorasse": "remémorer",
    "remémorassent": "remémorer",
    "remémorasses": "remémorer",
    "remémorassiez": "remémorer",
    "remémorassions": "remémorer",
    "remémorative": "remémoratif",
    "remémore": "remémorer",
    "remémorent": "remémorer",
    "remémorera": "remémorer",
    "remémorerai": "remémorer",
    "remémoreraient": "remémorer",
    "remémorerais": "remémorer",
    "remémorerait": "remémorer",
    "remémoreras": "remémorer",
    "remémorerez": "remémorer",
    "remémoreriez": "remémorer",
    "remémorerions": "remémorer",
    "remémorerons": "remémorer",
    "remémoreront": "remémorer",
    "remémores": "remémorer",
    "remémorez": "remémorer",
    "remémoriez": "remémorer",
    "remémorions": "remémorer",
    "remémorons": "remémorer",
    "remémorâmes": "remémorer",
    "remémorât": "remémorer",
    "remémorâtes": "remémorer",
    "remémorèrent": "remémorer",
    "remémoré": "remémorer",
    "remémorée": "remémorer",
    "remémorées": "remémorer",
    "remémorés": "remémorer",
    "remîmes": "remettre",
    "remît": "remettre",
    "remîtes": "remettre",
    "renais": "renaître",
    "renaissaient": "renaître",
    "renaissais": "renaître",
    "renaissait": "renaître",
    "renaissances": "renaissance",
    "renaissant": "renaître",
    "renaissante": "renaissant",
    "renaissantes": "renaissant",
    "renaissants": "renaissant",
    "renaisse": "renaître",
    "renaissent": "renaître",
    "renaisses": "renaître",
    "renaissez": "renaître",
    "renaissiez": "renaître",
    "renaissions": "renaître",
    "renaissons": "renaître",
    "renaquirent": "renaître",
    "renaquis": "renaître",
    "renaquisse": "renaître",
    "renaquissent": "renaître",
    "renaquisses": "renaître",
    "renaquissiez": "renaître",
    "renaquissions": "renaître",
    "renaquit": "renaître",
    "renaquîmes": "renaître",
    "renaquît": "renaître",
    "renaquîtes": "renaître",
    "renarde": "renard",
    "renardeaux": "renardeau",
    "renardes": "renard",
    "renards": "renard",
    "renationalisations": "renationalisation",
    "renaudais": "renauder",
    "renaudait": "renauder",
    "renaudant": "renauder",
    "renaude": "renauder",
    "renaudent": "renauder",
    "renaudé": "renauder",
    "renaît": "renaître",
    "renaîtra": "renaître",
    "renaîtrai": "renaître",
    "renaîtraient": "renaître",
    "renaîtrais": "renaître",
    "renaîtrait": "renaître",
    "renaîtras": "renaître",
    "renaîtrez": "renaître",
    "renaîtriez": "renaître",
    "renaîtrions": "renaître",
    "renaîtrons": "renaître",
    "renaîtront": "renaître",
    "rencardaient": "rencarder",
    "rencardait": "rencarder",
    "rencarde": "rencarder",
    "rencards": "rencard",
    "rencardé": "rencarder",
    "rencardée": "rencarder",
    "rencardées": "rencarder",
    "rencardés": "rencarder",
    "renchaîna": "renchaîner",
    "renchaînai": "renchaîner",
    "renchaînaient": "renchaîner",
    "renchaînais": "renchaîner",
    "renchaînait": "renchaîner",
    "renchaînant": "renchaîner",
    "renchaînas": "renchaîner",
    "renchaînasse": "renchaîner",
    "renchaînassent": "renchaîner",
    "renchaînasses": "renchaîner",
    "renchaînassiez": "renchaîner",
    "renchaînassions": "renchaîner",
    "renchaîne": "renchaîner",
    "renchaînent": "renchaîner",
    "renchaînera": "renchaîner",
    "renchaînerai": "renchaîner",
    "renchaîneraient": "renchaîner",
    "renchaînerais": "renchaîner",
    "renchaînerait": "renchaîner",
    "renchaîneras": "renchaîner",
    "renchaînerez": "renchaîner",
    "renchaîneriez": "renchaîner",
    "renchaînerions": "renchaîner",
    "renchaînerons": "renchaîner",
    "renchaîneront": "renchaîner",
    "renchaînes": "renchaîner",
    "renchaînez": "renchaîner",
    "renchaîniez": "renchaîner",
    "renchaînions": "renchaîner",
    "renchaînons": "renchaîner",
    "renchaînâmes": "renchaîner",
    "renchaînât": "renchaîner",
    "renchaînâtes": "renchaîner",
    "renchaînèrent": "renchaîner",
    "renchaîné": "renchaîner",
    "renchaînée": "renchaîner",
    "renchaînées": "renchaîner",
    "renchaînés": "renchaîner",
    "renchéri": "renchérir",
    "renchérira": "renchérir",
    "renchérirai": "renchérir",
    "renchériraient": "renchérir",
    "renchérirais": "renchérir",
    "renchérirait": "renchérir",
    "renchériras": "renchérir",
    "renchérirent": "renchérir",
    "renchérirez": "renchérir",
    "renchéririez": "renchérir",
    "renchéririons": "renchérir",
    "renchérirons": "renchérir",
    "renchériront": "renchérir",
    "renchéris": "renchérir",
    "renchérissaient": "renchérir",
    "renchérissais": "renchérir",
    "renchérissait": "renchérir",
    "renchérissant": "renchérir",
    "renchérisse": "renchérir",
    "renchérissements": "renchérissement",
    "renchérissent": "renchérir",
    "renchérisses": "renchérir",
    "renchérissez": "renchérir",
    "renchérissiez": "renchérir",
    "renchérissions": "renchérir",
    "renchérissons": "renchérir",
    "renchérit": "renchérir",
    "renchérîmes": "renchérir",
    "renchérît": "renchérir",
    "renchérîtes": "renchérir",
    "rencogna": "rencogner",
    "rencognai": "rencogner",
    "rencognaient": "rencogner",
    "rencognais": "rencogner",
    "rencognait": "rencogner",
    "rencognant": "rencogner",
    "rencognas": "rencogner",
    "rencognasse": "rencogner",
    "rencognassent": "rencogner",
    "rencognasses": "rencogner",
    "rencognassiez": "rencogner",
    "rencognassions": "rencogner",
    "rencogne": "rencogner",
    "rencognent": "rencogner",
    "rencognera": "rencogner",
    "rencognerai": "rencogner",
    "rencogneraient": "rencogner",
    "rencognerais": "rencogner",
    "rencognerait": "rencogner",
    "rencogneras": "rencogner",
    "rencognerez": "rencogner",
    "rencogneriez": "rencogner",
    "rencognerions": "rencogner",
    "rencognerons": "rencogner",
    "rencogneront": "rencogner",
    "rencognes": "rencogner",
    "rencognez": "rencogner",
    "rencogniez": "rencogner",
    "rencognions": "rencogner",
    "rencognons": "rencogner",
    "rencognâmes": "rencogner",
    "rencognât": "rencogner",
    "rencognâtes": "rencogner",
    "rencognèrent": "rencogner",
    "rencogné": "rencogner",
    "rencognée": "rencogner",
    "rencognées": "rencogner",
    "rencognés": "rencogner",
    "rencontra": "rencontrer",
    "rencontrai": "rencontrer",
    "rencontraient": "rencontrer",
    "rencontrais": "rencontrer",
    "rencontrait": "rencontrer",
    "rencontrant": "rencontrer",
    "rencontras": "rencontrer",
    "rencontrasse": "rencontrer",
    "rencontrassent": "rencontrer",
    "rencontrasses": "rencontrer",
    "rencontrassiez": "rencontrer",
    "rencontrassions": "rencontrer",
    "rencontre": "rencontrer",
    "rencontrent": "rencontrer",
    "rencontrera": "rencontrer",
    "rencontrerai": "rencontrer",
    "rencontreraient": "rencontrer",
    "rencontrerais": "rencontrer",
    "rencontrerait": "rencontrer",
    "rencontreras": "rencontrer",
    "rencontrerez": "rencontrer",
    "rencontreriez": "rencontrer",
    "rencontrerions": "rencontrer",
    "rencontrerons": "rencontrer",
    "rencontreront": "rencontrer",
    "rencontres": "rencontrer",
    "rencontrez": "rencontrer",
    "rencontriez": "rencontrer",
    "rencontrions": "rencontrer",
    "rencontrons": "rencontrer",
    "rencontrâmes": "rencontrer",
    "rencontrât": "rencontrer",
    "rencontrâtes": "rencontrer",
    "rencontrèrent": "rencontrer",
    "rencontré": "rencontrer",
    "rencontrée": "rencontrer",
    "rencontrées": "rencontrer",
    "rencontrés": "rencontrer",
    "rend": "rendre",
    "rendaient": "rendre",
    "rendais": "rendre",
    "rendait": "rendre",
    "rendant": "rendre",
    "rende": "rendre",
    "rendements": "rendement",
    "rendent": "rendre",
    "rendes": "rendre",
    "rendez": "rendre",
    "rendiez": "rendre",
    "rendions": "rendre",
    "rendirent": "rendre",
    "rendis": "rendre",
    "rendisse": "rendre",
    "rendissent": "rendre",
    "rendisses": "rendre",
    "rendissiez": "rendre",
    "rendissions": "rendre",
    "rendit": "rendre",
    "rendons": "rendre",
    "rendormaient": "rendormir",
    "rendormais": "rendormir",
    "rendormait": "rendormir",
    "rendormant": "rendormir",
    "rendorme": "rendormir",
    "rendorment": "rendormir",
    "rendormes": "rendormir",
    "rendormez": "rendormir",
    "rendormi": "rendormir",
    "rendormie": "rendormir",
    "rendormies": "rendormir",
    "rendormiez": "rendormir",
    "rendormions": "rendormir",
    "rendormira": "rendormir",
    "rendormirai": "rendormir",
    "rendormiraient": "rendormir",
    "rendormirais": "rendormir",
    "rendormirait": "rendormir",
    "rendormiras": "rendormir",
    "rendormirent": "rendormir",
    "rendormirez": "rendormir",
    "rendormiriez": "rendormir",
    "rendormirions": "rendormir",
    "rendormirons": "rendormir",
    "rendormiront": "rendormir",
    "rendormis": "rendormir",
    "rendormisse": "rendormir",
    "rendormissent": "rendormir",
    "rendormisses": "rendormir",
    "rendormissiez": "rendormir",
    "rendormissions": "rendormir",
    "rendormit": "rendormir",
    "rendormons": "rendormir",
    "rendormîmes": "rendormir",
    "rendormît": "rendormir",
    "rendormîtes": "rendormir",
    "rendors": "rendormir",
    "rendort": "rendormir",
    "rendra": "rendre",
    "rendrai": "rendre",
    "rendraient": "rendre",
    "rendrais": "rendre",
    "rendrait": "rendre",
    "rendras": "rendre",
    "rendrez": "rendre",
    "rendriez": "rendre",
    "rendrions": "rendre",
    "rendrons": "rendre",
    "rendront": "rendre",
    "rends": "rendre",
    "rendu": "rendre",
    "rendue": "rendu",
    "rendues": "rendu",
    "renduira": "renduire",
    "renduirai": "renduire",
    "renduiraient": "renduire",
    "renduirais": "renduire",
    "renduirait": "renduire",
    "renduiras": "renduire",
    "renduirez": "renduire",
    "renduiriez": "renduire",
    "renduirions": "renduire",
    "renduirons": "renduire",
    "renduiront": "renduire",
    "renduis": "renduire",
    "renduisaient": "renduire",
    "renduisais": "renduire",
    "renduisait": "renduire",
    "renduisant": "renduire",
    "renduise": "renduire",
    "renduisent": "renduire",
    "renduises": "renduire",
    "renduisez": "renduire",
    "renduisiez": "renduire",
    "renduisions": "renduire",
    "renduisirent": "renduire",
    "renduisis": "renduire",
    "renduisisse": "renduire",
    "renduisissent": "renduire",
    "renduisisses": "renduire",
    "renduisissiez": "renduire",
    "renduisissions": "renduire",
    "renduisit": "renduire",
    "renduisons": "renduire",
    "renduisîmes": "renduire",
    "renduisît": "renduire",
    "renduisîtes": "renduire",
    "renduit": "renduire",
    "renduite": "renduire",
    "renduites": "renduire",
    "renduits": "renduire",
    "rendurci": "rendurcir",
    "rendurcie": "rendurcir",
    "rendurcies": "rendurcir",
    "rendurcira": "rendurcir",
    "rendurcirai": "rendurcir",
    "rendurciraient": "rendurcir",
    "rendurcirais": "rendurcir",
    "rendurcirait": "rendurcir",
    "rendurciras": "rendurcir",
    "rendurcirent": "rendurcir",
    "rendurcirez": "rendurcir",
    "rendurciriez": "rendurcir",
    "rendurcirions": "rendurcir",
    "rendurcirons": "rendurcir",
    "rendurciront": "rendurcir",
    "rendurcis": "rendurcir",
    "rendurcissaient": "rendurcir",
    "rendurcissais": "rendurcir",
    "rendurcissait": "rendurcir",
    "rendurcissant": "rendurcir",
    "rendurcisse": "rendurcir",
    "rendurcissent": "rendurcir",
    "rendurcisses": "rendurcir",
    "rendurcissez": "rendurcir",
    "rendurcissiez": "rendurcir",
    "rendurcissions": "rendurcir",
    "rendurcissons": "rendurcir",
    "rendurcit": "rendurcir",
    "rendurcîmes": "rendurcir",
    "rendurcît": "rendurcir",
    "rendurcîtes": "rendurcir",
    "rendus": "rendu",
    "rendîmes": "rendre",
    "rendît": "rendre",
    "rendîtes": "rendre",
    "reneige": "reneiger",
    "renferma": "renfermer",
    "renfermai": "renfermer",
    "renfermaient": "renfermer",
    "renfermais": "renfermer",
    "renfermait": "renfermer",
    "renfermant": "renfermer",
    "renfermas": "renfermer",
    "renfermasse": "renfermer",
    "renfermassent": "renfermer",
    "renfermasses": "renfermer",
    "renfermassiez": "renfermer",
    "renfermassions": "renfermer",
    "renferme": "renfermer",
    "renferment": "renfermer",
    "renfermera": "renfermer",
    "renfermerai": "renfermer",
    "renfermeraient": "renfermer",
    "renfermerais": "renfermer",
    "renfermerait": "renfermer",
    "renfermeras": "renfermer",
    "renfermerez": "renfermer",
    "renfermeriez": "renfermer",
    "renfermerions": "renfermer",
    "renfermerons": "renfermer",
    "renfermeront": "renfermer",
    "renfermes": "renfermer",
    "renfermez": "renfermer",
    "renfermiez": "renfermer",
    "renfermions": "renfermer",
    "renfermons": "renfermer",
    "renfermâmes": "renfermer",
    "renfermât": "renfermer",
    "renfermâtes": "renfermer",
    "renfermèrent": "renfermer",
    "renfermé": "renfermer",
    "renfermée": "renfermer",
    "renfermées": "renfermer",
    "renfermés": "renfermer",
    "renfila": "renfiler",
    "renfilai": "renfiler",
    "renfilaient": "renfiler",
    "renfilais": "renfiler",
    "renfilait": "renfiler",
    "renfilant": "renfiler",
    "renfilas": "renfiler",
    "renfilasse": "renfiler",
    "renfilassent": "renfiler",
    "renfilasses": "renfiler",
    "renfilassiez": "renfiler",
    "renfilassions": "renfiler",
    "renfile": "renfiler",
    "renfilent": "renfiler",
    "renfilera": "renfiler",
    "renfilerai": "renfiler",
    "renfileraient": "renfiler",
    "renfilerais": "renfiler",
    "renfilerait": "renfiler",
    "renfileras": "renfiler",
    "renfilerez": "renfiler",
    "renfileriez": "renfiler",
    "renfilerions": "renfiler",
    "renfilerons": "renfiler",
    "renfileront": "renfiler",
    "renfiles": "renfiler",
    "renfilez": "renfiler",
    "renfiliez": "renfiler",
    "renfilions": "renfiler",
    "renfilons": "renfiler",
    "renfilâmes": "renfiler",
    "renfilât": "renfiler",
    "renfilâtes": "renfiler",
    "renfilèrent": "renfiler",
    "renfilé": "renfiler",
    "renfilée": "renfiler",
    "renfilées": "renfiler",
    "renfilés": "renfiler",
    "renfla": "renfler",
    "renflai": "renfler",
    "renflaient": "renfler",
    "renflais": "renfler",
    "renflait": "renfler",
    "renflant": "renfler",
    "renflas": "renfler",
    "renflasse": "renfler",
    "renflassent": "renfler",
    "renflasses": "renfler",
    "renflassiez": "renfler",
    "renflassions": "renfler",
    "renfle": "renfler",
    "renflements": "renflement",
    "renflent": "renfler",
    "renflera": "renfler",
    "renflerai": "renfler",
    "renfleraient": "renfler",
    "renflerais": "renfler",
    "renflerait": "renfler",
    "renfleras": "renfler",
    "renflerez": "renfler",
    "renfleriez": "renfler",
    "renflerions": "renfler",
    "renflerons": "renfler",
    "renfleront": "renfler",
    "renfles": "renfler",
    "renflez": "renfler",
    "renfliez": "renfler",
    "renflions": "renfler",
    "renflons": "renfler",
    "renfloua": "renflouer",
    "renflouages": "renflouage",
    "renflouai": "renflouer",
    "renflouaient": "renflouer",
    "renflouais": "renflouer",
    "renflouait": "renflouer",
    "renflouant": "renflouer",
    "renflouas": "renflouer",
    "renflouasse": "renflouer",
    "renflouassent": "renflouer",
    "renflouasses": "renflouer",
    "renflouassiez": "renflouer",
    "renflouassions": "renflouer",
    "renfloue": "renflouer",
    "renflouements": "renflouement",
    "renflouent": "renflouer",
    "renflouera": "renflouer",
    "renflouerai": "renflouer",
    "renfloueraient": "renflouer",
    "renflouerais": "renflouer",
    "renflouerait": "renflouer",
    "renfloueras": "renflouer",
    "renflouerez": "renflouer",
    "renfloueriez": "renflouer",
    "renflouerions": "renflouer",
    "renflouerons": "renflouer",
    "renfloueront": "renflouer",
    "renfloues": "renflouer",
    "renflouez": "renflouer",
    "renflouiez": "renflouer",
    "renflouions": "renflouer",
    "renflouons": "renflouer",
    "renflouâmes": "renflouer",
    "renflouât": "renflouer",
    "renflouâtes": "renflouer",
    "renflouèrent": "renflouer",
    "renfloué": "renflouer",
    "renflouée": "renflouer",
    "renflouées": "renflouer",
    "renfloués": "renflouer",
    "renflâmes": "renfler",
    "renflât": "renfler",
    "renflâtes": "renfler",
    "renflèrent": "renfler",
    "renflé": "renfler",
    "renflée": "renfler",
    "renflées": "renfler",
    "renflés": "renfler",
    "renfonce": "renfoncer",
    "renfoncements": "renfoncement",
    "renfoncent": "renfoncer",
    "renfoncera": "renfoncer",
    "renfoncerai": "renfoncer",
    "renfonceraient": "renfoncer",
    "renfoncerais": "renfoncer",
    "renfoncerait": "renfoncer",
    "renfonceras": "renfoncer",
    "renfoncerez": "renfoncer",
    "renfonceriez": "renfoncer",
    "renfoncerions": "renfoncer",
    "renfoncerons": "renfoncer",
    "renfonceront": "renfoncer",
    "renfonces": "renfoncer",
    "renfoncez": "renfoncer",
    "renfonciez": "renfoncer",
    "renfoncions": "renfoncer",
    "renfoncèrent": "renfoncer",
    "renfoncé": "renfoncer",
    "renfoncée": "renfoncer",
    "renfoncées": "renfoncer",
    "renfoncés": "renfoncer",
    "renfonça": "renfoncer",
    "renfonçai": "renfoncer",
    "renfonçaient": "renfoncer",
    "renfonçais": "renfoncer",
    "renfonçait": "renfoncer",
    "renfonçant": "renfoncer",
    "renfonças": "renfoncer",
    "renfonçasse": "renfoncer",
    "renfonçassent": "renfoncer",
    "renfonçasses": "renfoncer",
    "renfonçassiez": "renfoncer",
    "renfonçassions": "renfoncer",
    "renfonçons": "renfoncer",
    "renfonçâmes": "renfoncer",
    "renfonçât": "renfoncer",
    "renfonçâtes": "renfoncer",
    "renforce": "renforcer",
    "renforcements": "renforcement",
    "renforcent": "renforcer",
    "renforcera": "renforcer",
    "renforcerai": "renforcer",
    "renforceraient": "renforcer",
    "renforcerais": "renforcer",
    "renforcerait": "renforcer",
    "renforceras": "renforcer",
    "renforcerez": "renforcer",
    "renforceriez": "renforcer",
    "renforcerions": "renforcer",
    "renforcerons": "renforcer",
    "renforceront": "renforcer",
    "renforces": "renforcer",
    "renforcez": "renforcer",
    "renforciez": "renforcer",
    "renforcions": "renforcer",
    "renforcèrent": "renforcer",
    "renforcé": "renforcer",
    "renforcée": "renforcer",
    "renforcées": "renforcer",
    "renforcés": "renforcer",
    "renforts": "renfort",
    "renforça": "renforcer",
    "renforçai": "renforcer",
    "renforçaient": "renforcer",
    "renforçais": "renforcer",
    "renforçait": "renforcer",
    "renforçant": "renforcer",
    "renforças": "renforcer",
    "renforçasse": "renforcer",
    "renforçassent": "renforcer",
    "renforçasses": "renforcer",
    "renforçassiez": "renforcer",
    "renforçassions": "renforcer",
    "renforçateurs": "renforçateur",
    "renforçatrice": "renforçateur",
    "renforçatrices": "renforçateur",
    "renforçons": "renforcer",
    "renforçâmes": "renforcer",
    "renforçât": "renforcer",
    "renforçâtes": "renforcer",
    "renfourché": "renfourcher",
    "renfournait": "renfourner",
    "renfrogna": "renfrogner",
    "renfrognai": "renfrogner",
    "renfrognaient": "renfrogner",
    "renfrognais": "renfrogner",
    "renfrognait": "renfrogner",
    "renfrognant": "renfrogner",
    "renfrognas": "renfrogner",
    "renfrognasse": "renfrogner",
    "renfrognassent": "renfrogner",
    "renfrognasses": "renfrogner",
    "renfrognassiez": "renfrogner",
    "renfrognassions": "renfrogner",
    "renfrogne": "renfrogner",
    "renfrognent": "renfrogner",
    "renfrognera": "renfrogner",
    "renfrognerai": "renfrogner",
    "renfrogneraient": "renfrogner",
    "renfrognerais": "renfrogner",
    "renfrognerait": "renfrogner",
    "renfrogneras": "renfrogner",
    "renfrognerez": "renfrogner",
    "renfrogneriez": "renfrogner",
    "renfrognerions": "renfrogner",
    "renfrognerons": "renfrogner",
    "renfrogneront": "renfrogner",
    "renfrognes": "renfrogner",
    "renfrognez": "renfrogner",
    "renfrogniez": "renfrogner",
    "renfrognions": "renfrogner",
    "renfrognons": "renfrogner",
    "renfrognâmes": "renfrogner",
    "renfrognât": "renfrogner",
    "renfrognâtes": "renfrogner",
    "renfrognèrent": "renfrogner",
    "renfrogné": "renfrogner",
    "renfrognée": "renfrogner",
    "renfrognées": "renfrogner",
    "renfrognés": "renfrogner",
    "rengage": "rengager",
    "rengagea": "rengager",
    "rengageai": "rengager",
    "rengageaient": "rengager",
    "rengageais": "rengager",
    "rengageait": "rengager",
    "rengageant": "rengager",
    "rengageas": "rengager",
    "rengageasse": "rengager",
    "rengageassent": "rengager",
    "rengageasses": "rengager",
    "rengageassiez": "rengager",
    "rengageassions": "rengager",
    "rengagent": "rengager",
    "rengageons": "rengager",
    "rengagera": "rengager",
    "rengagerai": "rengager",
    "rengageraient": "rengager",
    "rengagerais": "rengager",
    "rengagerait": "rengager",
    "rengageras": "rengager",
    "rengagerez": "rengager",
    "rengageriez": "rengager",
    "rengagerions": "rengager",
    "rengagerons": "rengager",
    "rengageront": "rengager",
    "rengages": "rengager",
    "rengagez": "rengager",
    "rengageâmes": "rengager",
    "rengageât": "rengager",
    "rengageâtes": "rengager",
    "rengagiez": "rengager",
    "rengagions": "rengager",
    "rengagèrent": "rengager",
    "rengagé": "rengager",
    "rengagée": "rengager",
    "rengagées": "rengager",
    "rengagés": "rengager",
    "rengaina": "rengainer",
    "rengainait": "rengainer",
    "rengainant": "rengainer",
    "rengaine": "rengainer",
    "rengaines": "rengaine",
    "rengainez": "rengainer",
    "rengainèrent": "rengainer",
    "rengainé": "rengainer",
    "rengainés": "rengainer",
    "rengorge": "rengorger",
    "rengorgea": "rengorger",
    "rengorgeai": "rengorger",
    "rengorgeaient": "rengorger",
    "rengorgeais": "rengorger",
    "rengorgeait": "rengorger",
    "rengorgeant": "rengorger",
    "rengorgeas": "rengorger",
    "rengorgeasse": "rengorger",
    "rengorgeassent": "rengorger",
    "rengorgeasses": "rengorger",
    "rengorgeassiez": "rengorger",
    "rengorgeassions": "rengorger",
    "rengorgements": "rengorgement",
    "rengorgent": "rengorger",
    "rengorgeons": "rengorger",
    "rengorgera": "rengorger",
    "rengorgerai": "rengorger",
    "rengorgeraient": "rengorger",
    "rengorgerais": "rengorger",
    "rengorgerait": "rengorger",
    "rengorgeras": "rengorger",
    "rengorgerez": "rengorger",
    "rengorgeriez": "rengorger",
    "rengorgerions": "rengorger",
    "rengorgerons": "rengorger",
    "rengorgeront": "rengorger",
    "rengorges": "rengorger",
    "rengorgez": "rengorger",
    "rengorgeâmes": "rengorger",
    "rengorgeât": "rengorger",
    "rengorgeâtes": "rengorger",
    "rengorgiez": "rengorger",
    "rengorgions": "rengorger",
    "rengorgèrent": "rengorger",
    "rengorgé": "rengorger",
    "rengorgée": "rengorger",
    "rengorgées": "rengorger",
    "rengorgés": "rengorger",
    "rengracie": "rengracier",
    "rengracié": "rengracier",
    "rengrena": "rengrener",
    "rengrenai": "rengrener",
    "rengrenaient": "rengrener",
    "rengrenais": "rengrener",
    "rengrenait": "rengrener",
    "rengrenant": "rengrener",
    "rengrenas": "rengrener",
    "rengrenasse": "rengrener",
    "rengrenassent": "rengrener",
    "rengrenasses": "rengrener",
    "rengrenassiez": "rengrener",
    "rengrenassions": "rengrener",
    "rengrenez": "rengrener",
    "rengreniez": "rengrener",
    "rengrenions": "rengrener",
    "rengrenons": "rengrener",
    "rengrenâmes": "rengrener",
    "rengrenât": "rengrener",
    "rengrenâtes": "rengrener",
    "rengrenèrent": "rengrener",
    "rengrené": "rengrener",
    "rengrenée": "rengrener",
    "rengrenées": "rengrener",
    "rengrenés": "rengrener",
    "rengrène": "rengréner",
    "rengrènements": "rengrènement",
    "rengrènent": "rengréner",
    "rengrènera": "rengrener",
    "rengrènerai": "rengrener",
    "rengrèneraient": "rengrener",
    "rengrènerais": "rengrener",
    "rengrènerait": "rengrener",
    "rengrèneras": "rengrener",
    "rengrènerez": "rengrener",
    "rengrèneriez": "rengrener",
    "rengrènerions": "rengrener",
    "rengrènerons": "rengrener",
    "rengrèneront": "rengrener",
    "rengrènes": "rengréner",
    "rengréna": "rengréner",
    "rengrénai": "rengréner",
    "rengrénaient": "rengréner",
    "rengrénais": "rengréner",
    "rengrénait": "rengréner",
    "rengrénant": "rengréner",
    "rengrénas": "rengréner",
    "rengrénasse": "rengréner",
    "rengrénassent": "rengréner",
    "rengrénasses": "rengréner",
    "rengrénassiez": "rengréner",
    "rengrénassions": "rengréner",
    "rengrénera": "rengréner",
    "rengrénerai": "rengréner",
    "rengréneraient": "rengréner",
    "rengrénerais": "rengréner",
    "rengrénerait": "rengréner",
    "rengréneras": "rengréner",
    "rengrénerez": "rengréner",
    "rengréneriez": "rengréner",
    "rengrénerions": "rengréner",
    "rengrénerons": "rengréner",
    "rengréneront": "rengréner",
    "rengrénez": "rengréner",
    "rengréniez": "rengréner",
    "rengrénions": "rengréner",
    "rengrénons": "rengréner",
    "rengrénâmes": "rengréner",
    "rengrénât": "rengréner",
    "rengrénâtes": "rengréner",
    "rengrénèrent": "rengréner",
    "rengréné": "rengréner",
    "rengrénée": "rengréner",
    "rengrénées": "rengréner",
    "rengrénés": "rengréner",
    "renia": "renier",
    "reniai": "renier",
    "reniaient": "renier",
    "reniais": "renier",
    "reniait": "renier",
    "reniant": "renier",
    "renias": "renier",
    "reniasse": "renier",
    "reniassent": "renier",
    "reniasses": "renier",
    "reniassiez": "renier",
    "reniassions": "renier",
    "renie": "renier",
    "reniements": "reniement",
    "renient": "renier",
    "reniera": "renier",
    "renierai": "renier",
    "renieraient": "renier",
    "renierais": "renier",
    "renierait": "renier",
    "renieras": "renier",
    "renierez": "renier",
    "renieriez": "renier",
    "renierions": "renier",
    "renierons": "renier",
    "renieront": "renier",
    "renies": "renier",
    "reniez": "renier",
    "renifla": "renifler",
    "reniflai": "renifler",
    "reniflaient": "renifler",
    "reniflais": "renifler",
    "reniflait": "renifler",
    "reniflant": "renifler",
    "reniflas": "renifler",
    "reniflasse": "renifler",
    "reniflassent": "renifler",
    "reniflasses": "renifler",
    "reniflassiez": "renifler",
    "reniflassions": "renifler",
    "renifle": "renifler",
    "reniflements": "reniflement",
    "reniflent": "renifler",
    "reniflera": "renifler",
    "reniflerai": "renifler",
    "renifleraient": "renifler",
    "reniflerais": "renifler",
    "reniflerait": "renifler",
    "renifleras": "renifler",
    "reniflerez": "renifler",
    "renifleries": "reniflerie",
    "renifleriez": "renifler",
    "reniflerions": "renifler",
    "reniflerons": "renifler",
    "renifleront": "renifler",
    "renifles": "renifler",
    "renifleurs": "renifleur",
    "renifleuse": "renifleur",
    "reniflez": "renifler",
    "renifliez": "renifler",
    "reniflions": "renifler",
    "reniflons": "renifler",
    "reniflâmes": "renifler",
    "reniflât": "renifler",
    "reniflâtes": "renifler",
    "reniflèrent": "renifler",
    "reniflé": "renifler",
    "reniflée": "renifler",
    "reniflées": "renifler",
    "reniflés": "renifler",
    "reniiez": "renier",
    "reniions": "renier",
    "renions": "renier",
    "reniâmes": "renier",
    "reniât": "renier",
    "reniâtes": "renier",
    "renièrent": "renier",
    "renié": "renier",
    "reniée": "renier",
    "reniées": "renier",
    "reniés": "renier",
    "rennaises": "rennais",
    "rennes": "renne",
    "renoirci": "renoircir",
    "renoircie": "renoircir",
    "renoircies": "renoircir",
    "renoircira": "renoircir",
    "renoircirai": "renoircir",
    "renoirciraient": "renoircir",
    "renoircirais": "renoircir",
    "renoircirait": "renoircir",
    "renoirciras": "renoircir",
    "renoircirent": "renoircir",
    "renoircirez": "renoircir",
    "renoirciriez": "renoircir",
    "renoircirions": "renoircir",
    "renoircirons": "renoircir",
    "renoirciront": "renoircir",
    "renoircis": "renoircir",
    "renoircissaient": "renoircir",
    "renoircissais": "renoircir",
    "renoircissait": "renoircir",
    "renoircissant": "renoircir",
    "renoircisse": "renoircir",
    "renoircissent": "renoircir",
    "renoircisses": "renoircir",
    "renoircissez": "renoircir",
    "renoircissiez": "renoircir",
    "renoircissions": "renoircir",
    "renoircissons": "renoircir",
    "renoircit": "renoircir",
    "renoircîmes": "renoircir",
    "renoircît": "renoircir",
    "renoircîtes": "renoircir",
    "renomma": "renommer",
    "renommai": "renommer",
    "renommaient": "renommer",
    "renommais": "renommer",
    "renommait": "renommer",
    "renommant": "renommer",
    "renommas": "renommer",
    "renommasse": "renommer",
    "renommassent": "renommer",
    "renommasses": "renommer",
    "renommassiez": "renommer",
    "renommassions": "renommer",
    "renomme": "renommer",
    "renomment": "renommer",
    "renommera": "renommer",
    "renommerai": "renommer",
    "renommeraient": "renommer",
    "renommerais": "renommer",
    "renommerait": "renommer",
    "renommeras": "renommer",
    "renommerez": "renommer",
    "renommeriez": "renommer",
    "renommerions": "renommer",
    "renommerons": "renommer",
    "renommeront": "renommer",
    "renommes": "renommer",
    "renommez": "renommer",
    "renommiez": "renommer",
    "renommions": "renommer",
    "renommons": "renommer",
    "renommâmes": "renommer",
    "renommât": "renommer",
    "renommâtes": "renommer",
    "renommèrent": "renommer",
    "renommé": "renommer",
    "renommée": "renommer",
    "renommées": "renommer",
    "renommés": "renommer",
    "renoms": "renom",
    "renonce": "renoncer",
    "renoncements": "renoncement",
    "renoncent": "renoncer",
    "renoncera": "renoncer",
    "renoncerai": "renoncer",
    "renonceraient": "renoncer",
    "renoncerais": "renoncer",
    "renoncerait": "renoncer",
    "renonceras": "renoncer",
    "renoncerez": "renoncer",
    "renonceriez": "renoncer",
    "renoncerions": "renoncer",
    "renoncerons": "renoncer",
    "renonceront": "renoncer",
    "renonces": "renoncer",
    "renoncez": "renoncer",
    "renonciations": "renonciation",
    "renonciez": "renoncer",
    "renoncions": "renoncer",
    "renonculacées": "renonculacée",
    "renoncules": "renoncule",
    "renoncèrent": "renoncer",
    "renoncé": "renoncer",
    "renoncée": "renoncer",
    "renoncées": "renoncer",
    "renoncés": "renoncer",
    "renonça": "renoncer",
    "renonçai": "renoncer",
    "renonçaient": "renoncer",
    "renonçais": "renoncer",
    "renonçait": "renoncer",
    "renonçant": "renoncer",
    "renonças": "renoncer",
    "renonçasse": "renoncer",
    "renonçassent": "renoncer",
    "renonçasses": "renoncer",
    "renonçassiez": "renoncer",
    "renonçassions": "renoncer",
    "renonçons": "renoncer",
    "renonçâmes": "renoncer",
    "renonçât": "renoncer",
    "renonçâtes": "renoncer",
    "renoua": "renouer",
    "renouai": "renouer",
    "renouaient": "renouer",
    "renouais": "renouer",
    "renouait": "renouer",
    "renouant": "renouer",
    "renouas": "renouer",
    "renouasse": "renouer",
    "renouassent": "renouer",
    "renouasses": "renouer",
    "renouassiez": "renouer",
    "renouassions": "renouer",
    "renoue": "renouer",
    "renouent": "renouer",
    "renouera": "renouer",
    "renouerai": "renouer",
    "renoueraient": "renouer",
    "renouerais": "renouer",
    "renouerait": "renouer",
    "renoueras": "renouer",
    "renouerez": "renouer",
    "renoueriez": "renouer",
    "renouerions": "renouer",
    "renouerons": "renouer",
    "renoueront": "renouer",
    "renoues": "renouer",
    "renouez": "renouer",
    "renouiez": "renouer",
    "renouions": "renouer",
    "renouons": "renouer",
    "renouveaux": "renouveau",
    "renouvela": "renouveler",
    "renouvelables": "renouvelable",
    "renouvelai": "renouveler",
    "renouvelaient": "renouveler",
    "renouvelais": "renouveler",
    "renouvelait": "renouveler",
    "renouvelant": "renouveler",
    "renouvelas": "renouveler",
    "renouvelasse": "renouveler",
    "renouvelassent": "renouveler",
    "renouvelasses": "renouveler",
    "renouvelassiez": "renouveler",
    "renouvelassions": "renouveler",
    "renouvelez": "renouveler",
    "renouveliez": "renouveler",
    "renouvelions": "renouveler",
    "renouvelle": "renouveler",
    "renouvellements": "renouvellement",
    "renouvellent": "renouveler",
    "renouvellera": "renouveler",
    "renouvellerai": "renouveler",
    "renouvelleraient": "renouveler",
    "renouvellerais": "renouveler",
    "renouvellerait": "renouveler",
    "renouvelleras": "renouveler",
    "renouvellerez": "renouveler",
    "renouvelleriez": "renouveler",
    "renouvellerions": "renouveler",
    "renouvellerons": "renouveler",
    "renouvelleront": "renouveler",
    "renouvelles": "renouveler",
    "renouvelons": "renouveler",
    "renouvelâmes": "renouveler",
    "renouvelât": "renouveler",
    "renouvelâtes": "renouveler",
    "renouvelèrent": "renouveler",
    "renouvelé": "renouveler",
    "renouvelée": "renouveler",
    "renouvelées": "renouveler",
    "renouvelés": "renouveler",
    "renouâmes": "renouer",
    "renouât": "renouer",
    "renouâtes": "renouer",
    "renouèrent": "renouer",
    "renoué": "renouer",
    "renouée": "renouer",
    "renouées": "renouer",
    "renoués": "renouer",
    "renquillait": "renquiller",
    "renquille": "renquiller",
    "renquillé": "renquiller",
    "renseigna": "renseigner",
    "renseignai": "renseigner",
    "renseignaient": "renseigner",
    "renseignais": "renseigner",
    "renseignait": "renseigner",
    "renseignant": "renseigner",
    "renseignas": "renseigner",
    "renseignasse": "renseigner",
    "renseignassent": "renseigner",
    "renseignasses": "renseigner",
    "renseignassiez": "renseigner",
    "renseignassions": "renseigner",
    "renseigne": "renseigner",
    "renseignements": "renseignement",
    "renseignent": "renseigner",
    "renseignera": "renseigner",
    "renseignerai": "renseigner",
    "renseigneraient": "renseigner",
    "renseignerais": "renseigner",
    "renseignerait": "renseigner",
    "renseigneras": "renseigner",
    "renseignerez": "renseigner",
    "renseigneriez": "renseigner",
    "renseignerions": "renseigner",
    "renseignerons": "renseigner",
    "renseigneront": "renseigner",
    "renseignes": "renseigner",
    "renseignez": "renseigner",
    "renseigniez": "renseigner",
    "renseignions": "renseigner",
    "renseignons": "renseigner",
    "renseignâmes": "renseigner",
    "renseignât": "renseigner",
    "renseignâtes": "renseigner",
    "renseignèrent": "renseigner",
    "renseigné": "renseigner",
    "renseignée": "renseigner",
    "renseignées": "renseigner",
    "renseignés": "renseigner",
    "renta": "renter",
    "rentabilisa": "rentabiliser",
    "rentabilisai": "rentabiliser",
    "rentabilisaient": "rentabiliser",
    "rentabilisais": "rentabiliser",
    "rentabilisait": "rentabiliser",
    "rentabilisant": "rentabiliser",
    "rentabilisas": "rentabiliser",
    "rentabilisasse": "rentabiliser",
    "rentabilisassent": "rentabiliser",
    "rentabilisasses": "rentabiliser",
    "rentabilisassiez": "rentabiliser",
    "rentabilisassions": "rentabiliser",
    "rentabilisations": "rentabilisation",
    "rentabilise": "rentabiliser",
    "rentabilisent": "rentabiliser",
    "rentabilisera": "rentabiliser",
    "rentabiliserai": "rentabiliser",
    "rentabiliseraient": "rentabiliser",
    "rentabiliserais": "rentabiliser",
    "rentabiliserait": "rentabiliser",
    "rentabiliseras": "rentabiliser",
    "rentabiliserez": "rentabiliser",
    "rentabiliseriez": "rentabiliser",
    "rentabiliserions": "rentabiliser",
    "rentabiliserons": "rentabiliser",
    "rentabiliseront": "rentabiliser",
    "rentabilises": "rentabiliser",
    "rentabilisez": "rentabiliser",
    "rentabilisiez": "rentabiliser",
    "rentabilisions": "rentabiliser",
    "rentabilisons": "rentabiliser",
    "rentabilisâmes": "rentabiliser",
    "rentabilisât": "rentabiliser",
    "rentabilisâtes": "rentabiliser",
    "rentabilisèrent": "rentabiliser",
    "rentabilisé": "rentabiliser",
    "rentabilisée": "rentabiliser",
    "rentabilisées": "rentabiliser",
    "rentabilisés": "rentabiliser",
    "rentabilités": "rentabilité",
    "rentables": "rentable",
    "rentama": "rentamer",
    "rentamai": "rentamer",
    "rentamaient": "rentamer",
    "rentamais": "rentamer",
    "rentamait": "rentamer",
    "rentamant": "rentamer",
    "rentamas": "rentamer",
    "rentamasse": "rentamer",
    "rentamassent": "rentamer",
    "rentamasses": "rentamer",
    "rentamassiez": "rentamer",
    "rentamassions": "rentamer",
    "rentame": "rentamer",
    "rentament": "rentamer",
    "rentamera": "rentamer",
    "rentamerai": "rentamer",
    "rentameraient": "rentamer",
    "rentamerais": "rentamer",
    "rentamerait": "rentamer",
    "rentameras": "rentamer",
    "rentamerez": "rentamer",
    "rentameriez": "rentamer",
    "rentamerions": "rentamer",
    "rentamerons": "rentamer",
    "rentameront": "rentamer",
    "rentames": "rentamer",
    "rentamez": "rentamer",
    "rentamiez": "rentamer",
    "rentamions": "rentamer",
    "rentamons": "rentamer",
    "rentamâmes": "rentamer",
    "rentamât": "rentamer",
    "rentamâtes": "rentamer",
    "rentamèrent": "rentamer",
    "rentamé": "rentamer",
    "rentamée": "rentamer",
    "rentamées": "rentamer",
    "rentamés": "rentamer",
    "rentes": "rente",
    "rentiers": "rentier",
    "rentière": "rentier",
    "rentières": "rentier",
    "rentoila": "rentoiler",
    "rentoilages": "rentoilage",
    "rentoilai": "rentoiler",
    "rentoilaient": "rentoiler",
    "rentoilais": "rentoiler",
    "rentoilait": "rentoiler",
    "rentoilant": "rentoiler",
    "rentoilas": "rentoiler",
    "rentoilasse": "rentoiler",
    "rentoilassent": "rentoiler",
    "rentoilasses": "rentoiler",
    "rentoilassiez": "rentoiler",
    "rentoilassions": "rentoiler",
    "rentoile": "rentoiler",
    "rentoilent": "rentoiler",
    "rentoilera": "rentoiler",
    "rentoilerai": "rentoiler",
    "rentoileraient": "rentoiler",
    "rentoilerais": "rentoiler",
    "rentoilerait": "rentoiler",
    "rentoileras": "rentoiler",
    "rentoilerez": "rentoiler",
    "rentoileriez": "rentoiler",
    "rentoilerions": "rentoiler",
    "rentoilerons": "rentoiler",
    "rentoileront": "rentoiler",
    "rentoiles": "rentoiler",
    "rentoilez": "rentoiler",
    "rentoiliez": "rentoiler",
    "rentoilions": "rentoiler",
    "rentoilons": "rentoiler",
    "rentoilâmes": "rentoiler",
    "rentoilât": "rentoiler",
    "rentoilâtes": "rentoiler",
    "rentoilèrent": "rentoiler",
    "rentoilé": "rentoiler",
    "rentoilée": "rentoiler",
    "rentoilées": "rentoiler",
    "rentoilés": "rentoiler",
    "rentra": "rentrer",
    "rentrai": "rentrer",
    "rentraie": "rentrayer",
    "rentraient": "rentrer",
    "rentraiera": "rentrayer",
    "rentraierai": "rentrayer",
    "rentraieraient": "rentrayer",
    "rentraierais": "rentrayer",
    "rentraierait": "rentrayer",
    "rentraieras": "rentrayer",
    "rentraierez": "rentrayer",
    "rentraieriez": "rentrayer",
    "rentraierions": "rentrayer",
    "rentraierons": "rentrayer",
    "rentraieront": "rentrayer",
    "rentraies": "rentrayer",
    "rentrais": "rentrer",
    "rentrait": "rentrer",
    "rentrant": "rentrer",
    "rentrante": "rentrant",
    "rentrantes": "rentrant",
    "rentrants": "rentrant",
    "rentras": "rentrer",
    "rentrasse": "rentrer",
    "rentrassent": "rentrer",
    "rentrasses": "rentrer",
    "rentrassiez": "rentrer",
    "rentrassions": "rentrer",
    "rentraya": "rentrayer",
    "rentrayai": "rentrayer",
    "rentrayaient": "rentrayer",
    "rentrayais": "rentrayer",
    "rentrayait": "rentrayer",
    "rentrayant": "rentrayer",
    "rentrayas": "rentrayer",
    "rentrayasse": "rentrayer",
    "rentrayassent": "rentrayer",
    "rentrayasses": "rentrayer",
    "rentrayassiez": "rentrayer",
    "rentrayassions": "rentrayer",
    "rentraye": "rentrayer",
    "rentrayent": "rentrayer",
    "rentrayera": "rentrayer",
    "rentrayerai": "rentrayer",
    "rentrayeraient": "rentrayer",
    "rentrayerais": "rentrayer",
    "rentrayerait": "rentrayer",
    "rentrayeras": "rentrayer",
    "rentrayerez": "rentrayer",
    "rentrayeriez": "rentrayer",
    "rentrayerions": "rentrayer",
    "rentrayerons": "rentrayer",
    "rentrayeront": "rentrayer",
    "rentrayes": "rentrayer",
    "rentrayez": "rentrayer",
    "rentrayiez": "rentrayer",
    "rentrayions": "rentrayer",
    "rentrayons": "rentrayer",
    "rentrayâmes": "rentrayer",
    "rentrayât": "rentrayer",
    "rentrayâtes": "rentrayer",
    "rentrayèrent": "rentrayer",
    "rentrayé": "rentrayer",
    "rentrayée": "rentrayer",
    "rentrayées": "rentrayer",
    "rentrayés": "rentrayer",
    "rentre": "rentrer",
    "rentrent": "rentrer",
    "rentrera": "rentrer",
    "rentrerai": "rentrer",
    "rentreraient": "rentrer",
    "rentrerais": "rentrer",
    "rentrerait": "rentrer",
    "rentreras": "rentrer",
    "rentrerez": "rentrer",
    "rentreriez": "rentrer",
    "rentrerions": "rentrer",
    "rentrerons": "rentrer",
    "rentreront": "rentrer",
    "rentres": "rentrer",
    "rentrez": "rentrer",
    "rentriez": "rentrer",
    "rentrions": "rentrer",
    "rentrons": "rentrer",
    "rentrouvert": "rentrouvrir",
    "rentrouverte": "rentrouvrir",
    "rentrouvertes": "rentrouvrir",
    "rentrouverts": "rentrouvrir",
    "rentrouvraient": "rentrouvrir",
    "rentrouvrais": "rentrouvrir",
    "rentrouvrait": "rentrouvrir",
    "rentrouvrant": "rentrouvrir",
    "rentrouvre": "rentrouvrir",
    "rentrouvrent": "rentrouvrir",
    "rentrouvres": "rentrouvrir",
    "rentrouvrez": "rentrouvrir",
    "rentrouvriez": "rentrouvrir",
    "rentrouvrions": "rentrouvrir",
    "rentrouvrira": "rentrouvrir",
    "rentrouvrirai": "rentrouvrir",
    "rentrouvriraient": "rentrouvrir",
    "rentrouvrirais": "rentrouvrir",
    "rentrouvrirait": "rentrouvrir",
    "rentrouvriras": "rentrouvrir",
    "rentrouvrirent": "rentrouvrir",
    "rentrouvrirez": "rentrouvrir",
    "rentrouvririez": "rentrouvrir",
    "rentrouvririons": "rentrouvrir",
    "rentrouvrirons": "rentrouvrir",
    "rentrouvriront": "rentrouvrir",
    "rentrouvris": "rentrouvrir",
    "rentrouvrisse": "rentrouvrir",
    "rentrouvrissent": "rentrouvrir",
    "rentrouvrisses": "rentrouvrir",
    "rentrouvrissiez": "rentrouvrir",
    "rentrouvrissions": "rentrouvrir",
    "rentrouvrit": "rentrouvrir",
    "rentrouvrons": "rentrouvrir",
    "rentrouvrîmes": "rentrouvrir",
    "rentrouvrît": "rentrouvrir",
    "rentrouvrîtes": "rentrouvrir",
    "rentrâmes": "rentrer",
    "rentrât": "rentrer",
    "rentrâtes": "rentrer",
    "rentrèrent": "rentrer",
    "rentré": "rentrer",
    "rentrée": "rentrer",
    "rentrées": "rentrer",
    "rentrés": "rentrer",
    "rentée": "renter",
    "renveloppa": "renvelopper",
    "renveloppai": "renvelopper",
    "renveloppaient": "renvelopper",
    "renveloppais": "renvelopper",
    "renveloppait": "renvelopper",
    "renveloppant": "renvelopper",
    "renveloppas": "renvelopper",
    "renveloppasse": "renvelopper",
    "renveloppassent": "renvelopper",
    "renveloppasses": "renvelopper",
    "renveloppassiez": "renvelopper",
    "renveloppassions": "renvelopper",
    "renveloppe": "renvelopper",
    "renveloppent": "renvelopper",
    "renveloppera": "renvelopper",
    "renvelopperai": "renvelopper",
    "renvelopperaient": "renvelopper",
    "renvelopperais": "renvelopper",
    "renvelopperait": "renvelopper",
    "renvelopperas": "renvelopper",
    "renvelopperez": "renvelopper",
    "renvelopperiez": "renvelopper",
    "renvelopperions": "renvelopper",
    "renvelopperons": "renvelopper",
    "renvelopperont": "renvelopper",
    "renveloppes": "renvelopper",
    "renveloppez": "renvelopper",
    "renveloppiez": "renvelopper",
    "renveloppions": "renvelopper",
    "renveloppons": "renvelopper",
    "renveloppâmes": "renvelopper",
    "renveloppât": "renvelopper",
    "renveloppâtes": "renvelopper",
    "renveloppèrent": "renvelopper",
    "renveloppé": "renvelopper",
    "renveloppée": "renvelopper",
    "renveloppées": "renvelopper",
    "renveloppés": "renvelopper",
    "renverra": "renvoyer",
    "renverrai": "renvoyer",
    "renverraient": "renvoyer",
    "renverrais": "renvoyer",
    "renverrait": "renvoyer",
    "renverras": "renvoyer",
    "renverrez": "renvoyer",
    "renverriez": "renvoyer",
    "renverrions": "renvoyer",
    "renverrons": "renvoyer",
    "renverront": "renvoyer",
    "renversa": "renverser",
    "renversai": "renverser",
    "renversaient": "renverser",
    "renversais": "renverser",
    "renversait": "renverser",
    "renversant": "renverser",
    "renversante": "renversant",
    "renversantes": "renversant",
    "renversas": "renverser",
    "renversasse": "renverser",
    "renversassent": "renverser",
    "renversasses": "renverser",
    "renversassiez": "renverser",
    "renversassions": "renverser",
    "renverse": "renverser",
    "renversements": "renversement",
    "renversent": "renverser",
    "renversera": "renverser",
    "renverserai": "renverser",
    "renverseraient": "renverser",
    "renverserais": "renverser",
    "renverserait": "renverser",
    "renverseras": "renverser",
    "renverserez": "renverser",
    "renverseriez": "renverser",
    "renverserions": "renverser",
    "renverserons": "renverser",
    "renverseront": "renverser",
    "renverses": "renverser",
    "renversez": "renverser",
    "renversiez": "renverser",
    "renversions": "renverser",
    "renversons": "renverser",
    "renversâmes": "renverser",
    "renversât": "renverser",
    "renversâtes": "renverser",
    "renversèrent": "renverser",
    "renversé": "renverser",
    "renversée": "renverser",
    "renversées": "renverser",
    "renversés": "renverser",
    "renvoie": "renvoyer",
    "renvoient": "renvoyer",
    "renvoies": "renvoyer",
    "renvois": "renvoi",
    "renvoya": "renvoyer",
    "renvoyai": "renvoyer",
    "renvoyaient": "renvoyer",
    "renvoyais": "renvoyer",
    "renvoyait": "renvoyer",
    "renvoyant": "renvoyer",
    "renvoyas": "renvoyer",
    "renvoyasse": "renvoyer",
    "renvoyassent": "renvoyer",
    "renvoyasses": "renvoyer",
    "renvoyassiez": "renvoyer",
    "renvoyassions": "renvoyer",
    "renvoyez": "renvoyer",
    "renvoyiez": "renvoyer",
    "renvoyions": "renvoyer",
    "renvoyons": "renvoyer",
    "renvoyâmes": "renvoyer",
    "renvoyât": "renvoyer",
    "renvoyâtes": "renvoyer",
    "renvoyèrent": "renvoyer",
    "renvoyé": "renvoyer",
    "renvoyée": "renvoyer",
    "renvoyées": "renvoyer",
    "renvoyés": "renvoyer",
    "renâcla": "renâcler",
    "renâclai": "renâcler",
    "renâclaient": "renâcler",
    "renâclais": "renâcler",
    "renâclait": "renâcler",
    "renâclant": "renâcler",
    "renâclas": "renâcler",
    "renâclasse": "renâcler",
    "renâclassent": "renâcler",
    "renâclasses": "renâcler",
    "renâclassiez": "renâcler",
    "renâclassions": "renâcler",
    "renâcle": "renâcler",
    "renâclent": "renâcler",
    "renâclera": "renâcler",
    "renâclerai": "renâcler",
    "renâcleraient": "renâcler",
    "renâclerais": "renâcler",
    "renâclerait": "renâcler",
    "renâcleras": "renâcler",
    "renâclerez": "renâcler",
    "renâcleriez": "renâcler",
    "renâclerions": "renâcler",
    "renâclerons": "renâcler",
    "renâcleront": "renâcler",
    "renâcles": "renâcler",
    "renâclez": "renâcler",
    "renâcliez": "renâcler",
    "renâclions": "renâcler",
    "renâclons": "renâcler",
    "renâclâmes": "renâcler",
    "renâclât": "renâcler",
    "renâclâtes": "renâcler",
    "renâclèrent": "renâcler",
    "renâclé": "renâcler",
    "rené": "renaître",
    "renée": "renaître",
    "renégate": "renégat",
    "renégates": "renégat",
    "renégats": "renégat",
    "renégocia": "renégocier",
    "renégociai": "renégocier",
    "renégociaient": "renégocier",
    "renégociais": "renégocier",
    "renégociait": "renégocier",
    "renégociant": "renégocier",
    "renégocias": "renégocier",
    "renégociasse": "renégocier",
    "renégociassent": "renégocier",
    "renégociasses": "renégocier",
    "renégociassiez": "renégocier",
    "renégociassions": "renégocier",
    "renégociations": "renégociation",
    "renégocie": "renégocier",
    "renégocient": "renégocier",
    "renégociera": "renégocier",
    "renégocierai": "renégocier",
    "renégocieraient": "renégocier",
    "renégocierais": "renégocier",
    "renégocierait": "renégocier",
    "renégocieras": "renégocier",
    "renégocierez": "renégocier",
    "renégocieriez": "renégocier",
    "renégocierions": "renégocier",
    "renégocierons": "renégocier",
    "renégocieront": "renégocier",
    "renégocies": "renégocier",
    "renégociez": "renégocier",
    "renégociiez": "renégocier",
    "renégociions": "renégocier",
    "renégocions": "renégocier",
    "renégociâmes": "renégocier",
    "renégociât": "renégocier",
    "renégociâtes": "renégocier",
    "renégocièrent": "renégocier",
    "renégocié": "renégocier",
    "renégociée": "renégocier",
    "renégociées": "renégocier",
    "renégociés": "renégocier",
    "repaie": "repayer",
    "repaient": "repayer",
    "repaiera": "repayer",
    "repaierai": "repayer",
    "repaieraient": "repayer",
    "repaierais": "repayer",
    "repaierait": "repayer",
    "repaieras": "repayer",
    "repaierez": "repayer",
    "repaieriez": "repayer",
    "repaierions": "repayer",
    "repaierons": "repayer",
    "repaieront": "repayer",
    "repaies": "repayer",
    "repaira": "repairer",
    "repairai": "repairer",
    "repairaient": "repairer",
    "repairais": "repairer",
    "repairait": "repairer",
    "repairant": "repairer",
    "repairas": "repairer",
    "repairasse": "repairer",
    "repairassent": "repairer",
    "repairasses": "repairer",
    "repairassiez": "repairer",
    "repairassions": "repairer",
    "repaire": "repairer",
    "repairent": "repairer",
    "repairera": "repairer",
    "repairerai": "repairer",
    "repaireraient": "repairer",
    "repairerais": "repairer",
    "repairerait": "repairer",
    "repaireras": "repairer",
    "repairerez": "repairer",
    "repaireriez": "repairer",
    "repairerions": "repairer",
    "repairerons": "repairer",
    "repaireront": "repairer",
    "repaires": "repairer",
    "repairez": "repairer",
    "repairiez": "repairer",
    "repairions": "repairer",
    "repairons": "repairer",
    "repairâmes": "repairer",
    "repairât": "repairer",
    "repairâtes": "repairer",
    "repairèrent": "repairer",
    "repairé": "repairer",
    "repairée": "repairer",
    "repairées": "repairer",
    "repairés": "repairer",
    "repais": "repaître",
    "repaissaient": "repaître",
    "repaissais": "repaître",
    "repaissait": "repaître",
    "repaissant": "repaître",
    "repaisse": "repaître",
    "repaissent": "repaître",
    "repaisses": "repaître",
    "repaissez": "repaître",
    "repaissiez": "repaître",
    "repaissions": "repaître",
    "repaissons": "repaître",
    "reparais": "reparaître",
    "reparaissaient": "reparaître",
    "reparaissais": "reparaître",
    "reparaissait": "reparaître",
    "reparaissant": "reparaître",
    "reparaisse": "reparaître",
    "reparaissent": "reparaître",
    "reparaisses": "reparaître",
    "reparaissez": "reparaître",
    "reparaissiez": "reparaître",
    "reparaissions": "reparaître",
    "reparaissons": "reparaître",
    "reparaît": "reparaître",
    "reparaîtra": "reparaître",
    "reparaîtrai": "reparaître",
    "reparaîtraient": "reparaître",
    "reparaîtrais": "reparaître",
    "reparaîtrait": "reparaître",
    "reparaîtras": "reparaître",
    "reparaîtrez": "reparaître",
    "reparaîtriez": "reparaître",
    "reparaîtrions": "reparaître",
    "reparaîtrons": "reparaître",
    "reparaîtront": "reparaître",
    "reparcourant": "reparcourir",
    "reparcouru": "reparcourir",
    "reparla": "reparler",
    "reparlai": "reparler",
    "reparlaient": "reparler",
    "reparlais": "reparler",
    "reparlait": "reparler",
    "reparlant": "reparler",
    "reparlas": "reparler",
    "reparlasse": "reparler",
    "reparlassent": "reparler",
    "reparlasses": "reparler",
    "reparlassiez": "reparler",
    "reparlassions": "reparler",
    "reparle": "reparler",
    "reparlent": "reparler",
    "reparlera": "reparler",
    "reparlerai": "reparler",
    "reparleraient": "reparler",
    "reparlerais": "reparler",
    "reparlerait": "reparler",
    "reparleras": "reparler",
    "reparlerez": "reparler",
    "reparleriez": "reparler",
    "reparlerions": "reparler",
    "reparlerons": "reparler",
    "reparleront": "reparler",
    "reparles": "reparler",
    "reparlez": "reparler",
    "reparliez": "reparler",
    "reparlions": "reparler",
    "reparlons": "reparler",
    "reparlâmes": "reparler",
    "reparlât": "reparler",
    "reparlâtes": "reparler",
    "reparlèrent": "reparler",
    "reparlé": "reparler",
    "repars": "repartir",
    "repart": "repartir",
    "repartage": "repartager",
    "repartagea": "repartager",
    "repartageai": "repartager",
    "repartageaient": "repartager",
    "repartageais": "repartager",
    "repartageait": "repartager",
    "repartageant": "repartager",
    "repartageas": "repartager",
    "repartageasse": "repartager",
    "repartageassent": "repartager",
    "repartageasses": "repartager",
    "repartageassiez": "repartager",
    "repartageassions": "repartager",
    "repartagent": "repartager",
    "repartageons": "repartager",
    "repartagera": "repartager",
    "repartagerai": "repartager",
    "repartageraient": "repartager",
    "repartagerais": "repartager",
    "repartagerait": "repartager",
    "repartageras": "repartager",
    "repartagerez": "repartager",
    "repartageriez": "repartager",
    "repartagerions": "repartager",
    "repartagerons": "repartager",
    "repartageront": "repartager",
    "repartages": "repartager",
    "repartagez": "repartager",
    "repartageâmes": "repartager",
    "repartageât": "repartager",
    "repartageâtes": "repartager",
    "repartagiez": "repartager",
    "repartagions": "repartager",
    "repartagèrent": "repartager",
    "repartagé": "repartager",
    "repartagée": "repartager",
    "repartagées": "repartager",
    "repartagés": "repartager",
    "repartaient": "repartir",
    "repartais": "repartir",
    "repartait": "repartir",
    "repartant": "repartir",
    "reparte": "repartir",
    "repartent": "repartir",
    "repartes": "repartir",
    "repartez": "repartir",
    "reparti": "repartir",
    "repartie": "repartir",
    "reparties": "repartir",
    "repartiez": "repartir",
    "repartions": "repartir",
    "repartira": "repartir",
    "repartirai": "repartir",
    "repartiraient": "repartir",
    "repartirais": "repartir",
    "repartirait": "repartir",
    "repartiras": "repartir",
    "repartirent": "repartir",
    "repartirez": "repartir",
    "repartiriez": "repartir",
    "repartirions": "repartir",
    "repartirons": "repartir",
    "repartiront": "repartir",
    "repartis": "repartir",
    "repartisse": "repartir",
    "repartissent": "repartir",
    "repartisses": "repartir",
    "repartissiez": "repartir",
    "repartissions": "repartir",
    "repartit": "repartir",
    "repartons": "repartir",
    "repartîmes": "repartir",
    "repartît": "repartir",
    "repartîtes": "repartir",
    "reparu": "reparaître",
    "reparue": "reparaître",
    "reparues": "reparaître",
    "reparurent": "reparaître",
    "reparus": "reparaître",
    "reparusse": "reparaître",
    "reparussent": "reparaître",
    "reparusses": "reparaître",
    "reparussiez": "reparaître",
    "reparussions": "reparaître",
    "reparut": "reparaître",
    "reparûmes": "reparaître",
    "reparût": "reparaître",
    "reparûtes": "reparaître",
    "repassa": "repasser",
    "repassages": "repassage",
    "repassai": "repasser",
    "repassaient": "repasser",
    "repassais": "repasser",
    "repassait": "repasser",
    "repassant": "repasser",
    "repassas": "repasser",
    "repassasse": "repasser",
    "repassassent": "repasser",
    "repassasses": "repasser",
    "repassassiez": "repasser",
    "repassassions": "repasser",
    "repasse": "repasser",
    "repassent": "repasser",
    "repassera": "repasser",
    "repasserai": "repasser",
    "repasseraient": "repasser",
    "repasserais": "repasser",
    "repasserait": "repasser",
    "repasseras": "repasser",
    "repasserez": "repasser",
    "repasseriez": "repasser",
    "repasserions": "repasser",
    "repasserons": "repasser",
    "repasseront": "repasser",
    "repasses": "repasser",
    "repasseuse": "repasseur",
    "repasseuses": "repasseur",
    "repassez": "repasser",
    "repassiez": "repasser",
    "repassions": "repasser",
    "repassons": "repasser",
    "repassâmes": "repasser",
    "repassât": "repasser",
    "repassâtes": "repasser",
    "repassèrent": "repasser",
    "repassé": "repasser",
    "repassée": "repasser",
    "repassées": "repasser",
    "repassés": "repasser",
    "repava": "repaver",
    "repavai": "repaver",
    "repavaient": "repaver",
    "repavais": "repaver",
    "repavait": "repaver",
    "repavant": "repaver",
    "repavas": "repaver",
    "repavasse": "repaver",
    "repavassent": "repaver",
    "repavasses": "repaver",
    "repavassiez": "repaver",
    "repavassions": "repaver",
    "repave": "repaver",
    "repavent": "repaver",
    "repavera": "repaver",
    "repaverai": "repaver",
    "repaveraient": "repaver",
    "repaverais": "repaver",
    "repaverait": "repaver",
    "repaveras": "repaver",
    "repaverez": "repaver",
    "repaveriez": "repaver",
    "repaverions": "repaver",
    "repaverons": "repaver",
    "repaveront": "repaver",
    "repaves": "repaver",
    "repavez": "repaver",
    "repaviez": "repaver",
    "repavions": "repaver",
    "repavons": "repaver",
    "repavâmes": "repaver",
    "repavât": "repaver",
    "repavâtes": "repaver",
    "repavèrent": "repaver",
    "repavé": "repaver",
    "repavée": "repaver",
    "repavées": "repaver",
    "repavés": "repaver",
    "repaya": "repayer",
    "repayai": "repayer",
    "repayaient": "repayer",
    "repayais": "repayer",
    "repayait": "repayer",
    "repayant": "repayer",
    "repayas": "repayer",
    "repayasse": "repayer",
    "repayassent": "repayer",
    "repayasses": "repayer",
    "repayassiez": "repayer",
    "repayassions": "repayer",
    "repaye": "repayer",
    "repayent": "repayer",
    "repayera": "repayer",
    "repayerai": "repayer",
    "repayeraient": "repayer",
    "repayerais": "repayer",
    "repayerait": "repayer",
    "repayeras": "repayer",
    "repayerez": "repayer",
    "repayeriez": "repayer",
    "repayerions": "repayer",
    "repayerons": "repayer",
    "repayeront": "repayer",
    "repayes": "repayer",
    "repayez": "repayer",
    "repayiez": "repayer",
    "repayions": "repayer",
    "repayons": "repayer",
    "repayâmes": "repayer",
    "repayât": "repayer",
    "repayâtes": "repayer",
    "repayèrent": "repayer",
    "repayé": "repayer",
    "repayée": "repayer",
    "repayées": "repayer",
    "repayés": "repayer",
    "repaît": "repaître",
    "repaîtra": "repaître",
    "repaîtrai": "repaître",
    "repaîtraient": "repaître",
    "repaîtrais": "repaître",
    "repaîtrait": "repaître",
    "repaîtras": "repaître",
    "repaîtrez": "repaître",
    "repaîtriez": "repaître",
    "repaîtrions": "repaître",
    "repaîtrons": "repaître",
    "repaîtront": "repaître",
    "repeigna": "repeigner",
    "repeignai": "repeigner",
    "repeignaient": "repeindre",
    "repeignais": "repeindre",
    "repeignait": "repeindre",
    "repeignant": "repeindre",
    "repeignas": "repeigner",
    "repeignasse": "repeigner",
    "repeignassent": "repeigner",
    "repeignasses": "repeigner",
    "repeignassiez": "repeigner",
    "repeignassions": "repeigner",
    "repeigne": "repeindre",
    "repeignent": "repeindre",
    "repeignera": "repeigner",
    "repeignerai": "repeigner",
    "repeigneraient": "repeigner",
    "repeignerais": "repeigner",
    "repeignerait": "repeigner",
    "repeigneras": "repeigner",
    "repeignerez": "repeigner",
    "repeigneriez": "repeigner",
    "repeignerions": "repeigner",
    "repeignerons": "repeigner",
    "repeigneront": "repeigner",
    "repeignes": "repeindre",
    "repeignez": "repeindre",
    "repeigniez": "repeindre",
    "repeignions": "repeindre",
    "repeignirent": "repeindre",
    "repeignis": "repeindre",
    "repeignisse": "repeindre",
    "repeignissent": "repeindre",
    "repeignisses": "repeindre",
    "repeignissiez": "repeindre",
    "repeignissions": "repeindre",
    "repeignit": "repeindre",
    "repeignons": "repeindre",
    "repeignâmes": "repeigner",
    "repeignât": "repeigner",
    "repeignâtes": "repeigner",
    "repeignèrent": "repeigner",
    "repeigné": "repeigner",
    "repeignée": "repeigner",
    "repeignées": "repeigner",
    "repeignés": "repeigner",
    "repeignîmes": "repeindre",
    "repeignît": "repeindre",
    "repeignîtes": "repeindre",
    "repeindra": "repeindre",
    "repeindrai": "repeindre",
    "repeindraient": "repeindre",
    "repeindrais": "repeindre",
    "repeindrait": "repeindre",
    "repeindras": "repeindre",
    "repeindrez": "repeindre",
    "repeindriez": "repeindre",
    "repeindrions": "repeindre",
    "repeindrons": "repeindre",
    "repeindront": "repeindre",
    "repeins": "repeindre",
    "repeint": "repeindre",
    "repeinte": "repeindre",
    "repeintes": "repeindre",
    "repeints": "repeint",
    "repend": "rependre",
    "rependaient": "rependre",
    "rependais": "rependre",
    "rependait": "rependre",
    "rependant": "rependre",
    "repende": "rependre",
    "rependent": "rependre",
    "rependes": "rependre",
    "rependez": "rependre",
    "rependiez": "rependre",
    "rependions": "rependre",
    "rependirent": "rependre",
    "rependis": "rependre",
    "rependisse": "rependre",
    "rependissent": "rependre",
    "rependisses": "rependre",
    "rependissiez": "rependre",
    "rependissions": "rependre",
    "rependit": "rependre",
    "rependons": "rependre",
    "rependra": "rependre",
    "rependrai": "rependre",
    "rependraient": "rependre",
    "rependrais": "rependre",
    "rependrait": "rependre",
    "rependras": "rependre",
    "rependrez": "rependre",
    "rependriez": "rependre",
    "rependrions": "rependre",
    "rependrons": "rependre",
    "rependront": "rependre",
    "repends": "rependre",
    "rependu": "rependre",
    "rependue": "rependre",
    "rependues": "rependre",
    "rependus": "rependre",
    "rependîmes": "rependre",
    "rependît": "rependre",
    "rependîtes": "rependre",
    "repens": "repentir",
    "repensa": "repenser",
    "repensai": "repenser",
    "repensaient": "repenser",
    "repensais": "repenser",
    "repensait": "repenser",
    "repensant": "repenser",
    "repensas": "repenser",
    "repensasse": "repenser",
    "repensassent": "repenser",
    "repensasses": "repenser",
    "repensassiez": "repenser",
    "repensassions": "repenser",
    "repense": "repenser",
    "repensent": "repenser",
    "repensera": "repenser",
    "repenserai": "repenser",
    "repenseraient": "repenser",
    "repenserais": "repenser",
    "repenserait": "repenser",
    "repenseras": "repenser",
    "repenserez": "repenser",
    "repenseriez": "repenser",
    "repenserions": "repenser",
    "repenserons": "repenser",
    "repenseront": "repenser",
    "repenses": "repenser",
    "repensez": "repenser",
    "repensiez": "repenser",
    "repensions": "repenser",
    "repensons": "repenser",
    "repensâmes": "repenser",
    "repensât": "repenser",
    "repensâtes": "repenser",
    "repensèrent": "repenser",
    "repensé": "repenser",
    "repensée": "repenser",
    "repensées": "repenser",
    "repensés": "repenser",
    "repent": "repentir",
    "repentaient": "repentir",
    "repentais": "repentir",
    "repentait": "repentir",
    "repentant": "repentir",
    "repentante": "repentant",
    "repentantes": "repentant",
    "repentants": "repentant",
    "repente": "repentir",
    "repentent": "repentir",
    "repentes": "repentir",
    "repentez": "repentir",
    "repenti": "repentir",
    "repentie": "repentir",
    "repenties": "repentir",
    "repentiez": "repentir",
    "repentions": "repentir",
    "repentira": "repentir",
    "repentirai": "repentir",
    "repentiraient": "repentir",
    "repentirais": "repentir",
    "repentirait": "repentir",
    "repentiras": "repentir",
    "repentirent": "repentir",
    "repentirez": "repentir",
    "repentiriez": "repentir",
    "repentirions": "repentir",
    "repentirons": "repentir",
    "repentiront": "repentir",
    "repentirs": "repentir",
    "repentis": "repentir",
    "repentisse": "repentir",
    "repentissent": "repentir",
    "repentisses": "repentir",
    "repentissiez": "repentir",
    "repentissions": "repentir",
    "repentit": "repentir",
    "repentons": "repentir",
    "repentîmes": "repentir",
    "repentît": "repentir",
    "repentîtes": "repentir",
    "reperce": "repercer",
    "repercent": "repercer",
    "repercera": "repercer",
    "repercerai": "repercer",
    "reperceraient": "repercer",
    "repercerais": "repercer",
    "repercerait": "repercer",
    "reperceras": "repercer",
    "repercerez": "repercer",
    "reperceriez": "repercer",
    "repercerions": "repercer",
    "repercerons": "repercer",
    "reperceront": "repercer",
    "reperces": "repercer",
    "repercez": "repercer",
    "reperciez": "repercer",
    "repercions": "repercer",
    "repercèrent": "repercer",
    "repercé": "repercer",
    "repercée": "repercer",
    "repercées": "repercer",
    "repercés": "repercer",
    "reperd": "reperdre",
    "reperdaient": "reperdre",
    "reperdais": "reperdre",
    "reperdait": "reperdre",
    "reperdant": "reperdre",
    "reperde": "reperdre",
    "reperdent": "reperdre",
    "reperdes": "reperdre",
    "reperdez": "reperdre",
    "reperdiez": "reperdre",
    "reperdions": "reperdre",
    "reperdirent": "reperdre",
    "reperdis": "reperdre",
    "reperdisse": "reperdre",
    "reperdissent": "reperdre",
    "reperdisses": "reperdre",
    "reperdissiez": "reperdre",
    "reperdissions": "reperdre",
    "reperdit": "reperdre",
    "reperdons": "reperdre",
    "reperdra": "reperdre",
    "reperdrai": "reperdre",
    "reperdraient": "reperdre",
    "reperdrais": "reperdre",
    "reperdrait": "reperdre",
    "reperdras": "reperdre",
    "reperdrez": "reperdre",
    "reperdriez": "reperdre",
    "reperdrions": "reperdre",
    "reperdrons": "reperdre",
    "reperdront": "reperdre",
    "reperds": "reperdre",
    "reperdu": "reperdre",
    "reperdue": "reperdre",
    "reperdues": "reperdre",
    "reperdus": "reperdre",
    "reperdîmes": "reperdre",
    "reperdît": "reperdre",
    "reperdîtes": "reperdre",
    "reperça": "repercer",
    "reperçai": "repercer",
    "reperçaient": "repercer",
    "reperçais": "repercer",
    "reperçait": "repercer",
    "reperçant": "repercer",
    "reperças": "repercer",
    "reperçasse": "repercer",
    "reperçassent": "repercer",
    "reperçasses": "repercer",
    "reperçassiez": "repercer",
    "reperçassions": "repercer",
    "reperçons": "repercer",
    "reperçâmes": "repercer",
    "reperçât": "repercer",
    "reperçâtes": "repercer",
    "repeupla": "repeupler",
    "repeuplai": "repeupler",
    "repeuplaient": "repeupler",
    "repeuplais": "repeupler",
    "repeuplait": "repeupler",
    "repeuplant": "repeupler",
    "repeuplas": "repeupler",
    "repeuplasse": "repeupler",
    "repeuplassent": "repeupler",
    "repeuplasses": "repeupler",
    "repeuplassiez": "repeupler",
    "repeuplassions": "repeupler",
    "repeuple": "repeupler",
    "repeuplements": "repeuplement",
    "repeuplent": "repeupler",
    "repeuplera": "repeupler",
    "repeuplerai": "repeupler",
    "repeupleraient": "repeupler",
    "repeuplerais": "repeupler",
    "repeuplerait": "repeupler",
    "repeupleras": "repeupler",
    "repeuplerez": "repeupler",
    "repeupleriez": "repeupler",
    "repeuplerions": "repeupler",
    "repeuplerons": "repeupler",
    "repeupleront": "repeupler",
    "repeuples": "repeupler",
    "repeuplez": "repeupler",
    "repeupliez": "repeupler",
    "repeuplions": "repeupler",
    "repeuplons": "repeupler",
    "repeuplâmes": "repeupler",
    "repeuplât": "repeupler",
    "repeuplâtes": "repeupler",
    "repeuplèrent": "repeupler",
    "repeuplé": "repeupler",
    "repeuplée": "repeupler",
    "repeuplées": "repeupler",
    "repeuplés": "repeupler",
    "repince": "repincer",
    "repincent": "repincer",
    "repincera": "repincer",
    "repincerai": "repincer",
    "repinceraient": "repincer",
    "repincerais": "repincer",
    "repincerait": "repincer",
    "repinceras": "repincer",
    "repincerez": "repincer",
    "repinceriez": "repincer",
    "repincerions": "repincer",
    "repincerons": "repincer",
    "repinceront": "repincer",
    "repinces": "repincer",
    "repincez": "repincer",
    "repinciez": "repincer",
    "repincions": "repincer",
    "repincèrent": "repincer",
    "repincé": "repincer",
    "repincée": "repincer",
    "repincées": "repincer",
    "repincés": "repincer",
    "repinça": "repincer",
    "repinçai": "repincer",
    "repinçaient": "repincer",
    "repinçais": "repincer",
    "repinçait": "repincer",
    "repinçant": "repincer",
    "repinças": "repincer",
    "repinçasse": "repincer",
    "repinçassent": "repincer",
    "repinçasses": "repincer",
    "repinçassiez": "repincer",
    "repinçassions": "repincer",
    "repinçons": "repincer",
    "repinçâmes": "repincer",
    "repinçât": "repincer",
    "repinçâtes": "repincer",
    "repiqua": "repiquer",
    "repiquai": "repiquer",
    "repiquaient": "repiquer",
    "repiquais": "repiquer",
    "repiquait": "repiquer",
    "repiquant": "repiquer",
    "repiquas": "repiquer",
    "repiquasse": "repiquer",
    "repiquassent": "repiquer",
    "repiquasses": "repiquer",
    "repiquassiez": "repiquer",
    "repiquassions": "repiquer",
    "repique": "repiquer",
    "repiquent": "repiquer",
    "repiquera": "repiquer",
    "repiquerai": "repiquer",
    "repiqueraient": "repiquer",
    "repiquerais": "repiquer",
    "repiquerait": "repiquer",
    "repiqueras": "repiquer",
    "repiquerez": "repiquer",
    "repiqueriez": "repiquer",
    "repiquerions": "repiquer",
    "repiquerons": "repiquer",
    "repiqueront": "repiquer",
    "repiques": "repiquer",
    "repiquez": "repiquer",
    "repiquiez": "repiquer",
    "repiquions": "repiquer",
    "repiquons": "repiquer",
    "repiquâmes": "repiquer",
    "repiquât": "repiquer",
    "repiquâtes": "repiquer",
    "repiquèrent": "repiquer",
    "repiqué": "repiquer",
    "repiquée": "repiquer",
    "repiquées": "repiquer",
    "repiqués": "repiquer",
    "replace": "replacer",
    "replacent": "replacer",
    "replacera": "replacer",
    "replacerai": "replacer",
    "replaceraient": "replacer",
    "replacerais": "replacer",
    "replacerait": "replacer",
    "replaceras": "replacer",
    "replacerez": "replacer",
    "replaceriez": "replacer",
    "replacerions": "replacer",
    "replacerons": "replacer",
    "replaceront": "replacer",
    "replaces": "replacer",
    "replacez": "replacer",
    "replaciez": "replacer",
    "replacions": "replacer",
    "replacèrent": "replacer",
    "replacé": "replacer",
    "replacée": "replacer",
    "replacées": "replacer",
    "replacés": "replacer",
    "replanta": "replanter",
    "replantai": "replanter",
    "replantaient": "replanter",
    "replantais": "replanter",
    "replantait": "replanter",
    "replantant": "replanter",
    "replantas": "replanter",
    "replantasse": "replanter",
    "replantassent": "replanter",
    "replantasses": "replanter",
    "replantassiez": "replanter",
    "replantassions": "replanter",
    "replantations": "replantation",
    "replante": "replanter",
    "replantent": "replanter",
    "replantera": "replanter",
    "replanterai": "replanter",
    "replanteraient": "replanter",
    "replanterais": "replanter",
    "replanterait": "replanter",
    "replanteras": "replanter",
    "replanterez": "replanter",
    "replanteriez": "replanter",
    "replanterions": "replanter",
    "replanterons": "replanter",
    "replanteront": "replanter",
    "replantes": "replanter",
    "replantez": "replanter",
    "replantiez": "replanter",
    "replantions": "replanter",
    "replantons": "replanter",
    "replantâmes": "replanter",
    "replantât": "replanter",
    "replantâtes": "replanter",
    "replantèrent": "replanter",
    "replanté": "replanter",
    "replantée": "replanter",
    "replantées": "replanter",
    "replantés": "replanter",
    "replats": "replat",
    "replaça": "replacer",
    "replaçai": "replacer",
    "replaçaient": "replacer",
    "replaçais": "replacer",
    "replaçait": "replacer",
    "replaçant": "replacer",
    "replaças": "replacer",
    "replaçasse": "replacer",
    "replaçassent": "replacer",
    "replaçasses": "replacer",
    "replaçassiez": "replacer",
    "replaçassions": "replacer",
    "replaçons": "replacer",
    "replaçâmes": "replacer",
    "replaçât": "replacer",
    "replaçâtes": "replacer",
    "replets": "replet",
    "repleut": "repleuvoir",
    "repleuvaient": "repleuvoir",
    "repleuvait": "repleuvoir",
    "repleuvant": "repleuvoir",
    "repleuve": "repleuvoir",
    "repleuvent": "repleuvoir",
    "repleuvra": "repleuvoir",
    "repleuvraient": "repleuvoir",
    "repleuvrait": "repleuvoir",
    "repleuvront": "repleuvoir",
    "replia": "replier",
    "repliai": "replier",
    "repliaient": "replier",
    "repliais": "replier",
    "repliait": "replier",
    "repliant": "replier",
    "replias": "replier",
    "repliasse": "replier",
    "repliassent": "replier",
    "repliasses": "replier",
    "repliassiez": "replier",
    "repliassions": "replier",
    "replie": "replier",
    "repliements": "repliement",
    "replient": "replier",
    "repliera": "replier",
    "replierai": "replier",
    "replieraient": "replier",
    "replierais": "replier",
    "replierait": "replier",
    "replieras": "replier",
    "replierez": "replier",
    "replieriez": "replier",
    "replierions": "replier",
    "replierons": "replier",
    "replieront": "replier",
    "replies": "replier",
    "repliez": "replier",
    "repliiez": "replier",
    "repliions": "replier",
    "replions": "replier",
    "replis": "repli",
    "repliâmes": "replier",
    "repliât": "replier",
    "repliâtes": "replier",
    "replièrent": "replier",
    "replié": "replier",
    "repliée": "replier",
    "repliées": "replier",
    "repliés": "replier",
    "reploie": "reployer",
    "reploiements": "reploiement",
    "reploient": "reployer",
    "reploiera": "reployer",
    "reploierai": "reployer",
    "reploieraient": "reployer",
    "reploierais": "reployer",
    "reploierait": "reployer",
    "reploieras": "reployer",
    "reploierez": "reployer",
    "reploieriez": "reployer",
    "reploierions": "reployer",
    "reploierons": "reployer",
    "reploieront": "reployer",
    "reploies": "reployer",
    "replonge": "replonger",
    "replongea": "replonger",
    "replongeai": "replonger",
    "replongeaient": "replonger",
    "replongeais": "replonger",
    "replongeait": "replonger",
    "replongeant": "replonger",
    "replongeas": "replonger",
    "replongeasse": "replonger",
    "replongeassent": "replonger",
    "replongeasses": "replonger",
    "replongeassiez": "replonger",
    "replongeassions": "replonger",
    "replongent": "replonger",
    "replongeons": "replonger",
    "replongera": "replonger",
    "replongerai": "replonger",
    "replongeraient": "replonger",
    "replongerais": "replonger",
    "replongerait": "replonger",
    "replongeras": "replonger",
    "replongerez": "replonger",
    "replongeriez": "replonger",
    "replongerions": "replonger",
    "replongerons": "replonger",
    "replongeront": "replonger",
    "replonges": "replonger",
    "replongez": "replonger",
    "replongeâmes": "replonger",
    "replongeât": "replonger",
    "replongeâtes": "replonger",
    "replongiez": "replonger",
    "replongions": "replonger",
    "replongèrent": "replonger",
    "replongé": "replonger",
    "replongée": "replonger",
    "replongées": "replonger",
    "replongés": "replonger",
    "reploya": "reployer",
    "reployai": "reployer",
    "reployaient": "reployer",
    "reployais": "reployer",
    "reployait": "reployer",
    "reployant": "reployer",
    "reployas": "reployer",
    "reployasse": "reployer",
    "reployassent": "reployer",
    "reployasses": "reployer",
    "reployassiez": "reployer",
    "reployassions": "reployer",
    "reployez": "reployer",
    "reployiez": "reployer",
    "reployions": "reployer",
    "reployons": "reployer",
    "reployâmes": "reployer",
    "reployât": "reployer",
    "reployâtes": "reployer",
    "reployèrent": "reployer",
    "reployé": "reployer",
    "reployée": "reployer",
    "reployées": "reployer",
    "reployés": "reployer",
    "replu": "repleuvoir",
    "replurent": "repleuvoir",
    "replussent": "repleuvoir",
    "replut": "repleuvoir",
    "replâtra": "replâtrer",
    "replâtrages": "replâtrage",
    "replâtrai": "replâtrer",
    "replâtraient": "replâtrer",
    "replâtrais": "replâtrer",
    "replâtrait": "replâtrer",
    "replâtrant": "replâtrer",
    "replâtras": "replâtrer",
    "replâtrasse": "replâtrer",
    "replâtrassent": "replâtrer",
    "replâtrasses": "replâtrer",
    "replâtrassiez": "replâtrer",
    "replâtrassions": "replâtrer",
    "replâtre": "replâtrer",
    "replâtrent": "replâtrer",
    "replâtrera": "replâtrer",
    "replâtrerai": "replâtrer",
    "replâtreraient": "replâtrer",
    "replâtrerais": "replâtrer",
    "replâtrerait": "replâtrer",
    "replâtreras": "replâtrer",
    "replâtrerez": "replâtrer",
    "replâtreriez": "replâtrer",
    "replâtrerions": "replâtrer",
    "replâtrerons": "replâtrer",
    "replâtreront": "replâtrer",
    "replâtres": "replâtrer",
    "replâtrez": "replâtrer",
    "replâtriez": "replâtrer",
    "replâtrions": "replâtrer",
    "replâtrons": "replâtrer",
    "replâtrâmes": "replâtrer",
    "replâtrât": "replâtrer",
    "replâtrâtes": "replâtrer",
    "replâtrèrent": "replâtrer",
    "replâtré": "replâtrer",
    "replâtrée": "replâtrer",
    "replâtrées": "replâtrer",
    "replâtrés": "replâtrer",
    "replète": "replet",
    "replètes": "replet",
    "replût": "repleuvoir",
    "repoli": "repolir",
    "repolie": "repolir",
    "repolies": "repolir",
    "repolira": "repolir",
    "repolirai": "repolir",
    "repoliraient": "repolir",
    "repolirais": "repolir",
    "repolirait": "repolir",
    "repoliras": "repolir",
    "repolirent": "repolir",
    "repolirez": "repolir",
    "repoliriez": "repolir",
    "repolirions": "repolir",
    "repolirons": "repolir",
    "repoliront": "repolir",
    "repolis": "repolir",
    "repolissaient": "repolir",
    "repolissais": "repolir",
    "repolissait": "repolir",
    "repolissant": "repolir",
    "repolisse": "repolir",
    "repolissent": "repolir",
    "repolisses": "repolir",
    "repolissez": "repolir",
    "repolissiez": "repolir",
    "repolissions": "repolir",
    "repolissons": "repolir",
    "repolit": "repolir",
    "repolîmes": "repolir",
    "repolît": "repolir",
    "repolîtes": "repolir",
    "repopulations": "repopulation",
    "reporta": "reporter",
    "reportages": "reportage",
    "reportai": "reporter",
    "reportaient": "reporter",
    "reportais": "reporter",
    "reportait": "reporter",
    "reportant": "reporter",
    "reportas": "reporter",
    "reportasse": "reporter",
    "reportassent": "reporter",
    "reportasses": "reporter",
    "reportassiez": "reporter",
    "reportassions": "reporter",
    "reporte": "reporter",
    "reportent": "reporter",
    "reportera": "reporter",
    "reporterai": "reporter",
    "reporteraient": "reporter",
    "reporterais": "reporter",
    "reporterait": "reporter",
    "reporteras": "reporter",
    "reporterez": "reporter",
    "reporteriez": "reporter",
    "reporterions": "reporter",
    "reporterons": "reporter",
    "reporteront": "reporter",
    "reporters": "reporter",
    "reporters-cameramen": "reporter-cameraman",
    "reportes": "reporter",
    "reportez": "reporter",
    "reportiez": "reporter",
    "reportions": "reporter",
    "reportons": "reporter",
    "reports": "report",
    "reportâmes": "reporter",
    "reportât": "reporter",
    "reportâtes": "reporter",
    "reportèrent": "reporter",
    "reporté": "reporter",
    "reportée": "reporter",
    "reportées": "reporter",
    "reportés": "reporter",
    "reposa": "reposer",
    "reposai": "reposer",
    "reposaient": "reposer",
    "reposais": "reposer",
    "reposait": "reposer",
    "reposant": "reposer",
    "reposante": "reposant",
    "reposantes": "reposant",
    "reposants": "reposant",
    "reposas": "reposer",
    "reposasse": "reposer",
    "reposassent": "reposer",
    "reposasses": "reposer",
    "reposassiez": "reposer",
    "reposassions": "reposer",
    "repose": "reposer",
    "repose-pieds": "repose-pied",
    "repose-têtes": "repose-tête",
    "reposent": "reposer",
    "reposera": "reposer",
    "reposerai": "reposer",
    "reposeraient": "reposer",
    "reposerais": "reposer",
    "reposerait": "reposer",
    "reposeras": "reposer",
    "reposerez": "reposer",
    "reposeriez": "reposer",
    "reposerions": "reposer",
    "reposerons": "reposer",
    "reposeront": "reposer",
    "reposes": "reposer",
    "reposez": "reposer",
    "reposiez": "reposer",
    "reposions": "reposer",
    "repositionnent": "repositionner",
    "repositionnez": "repositionner",
    "reposoirs": "reposoir",
    "reposons": "reposer",
    "repostait": "reposter",
    "reposâmes": "reposer",
    "reposât": "reposer",
    "reposâtes": "reposer",
    "reposèrent": "reposer",
    "reposé": "reposer",
    "reposée": "reposer",
    "reposées": "reposer",
    "reposés": "reposer",
    "repoudraient": "repoudrer",
    "repoudrait": "repoudrer",
    "repoudrant": "repoudrer",
    "repoudre": "repoudrer",
    "repoudré": "repoudrer",
    "repoudrée": "repoudrer",
    "repoussa": "repousser",
    "repoussai": "repousser",
    "repoussaient": "repousser",
    "repoussais": "repousser",
    "repoussait": "repousser",
    "repoussant": "repousser",
    "repoussante": "repoussant",
    "repoussantes": "repoussant",
    "repoussants": "repoussant",
    "repoussas": "repousser",
    "repoussasse": "repousser",
    "repoussassent": "repousser",
    "repoussasses": "repousser",
    "repoussassiez": "repousser",
    "repoussassions": "repousser",
    "repousse": "repousser",
    "repoussent": "repousser",
    "repoussera": "repousser",
    "repousserai": "repousser",
    "repousseraient": "repousser",
    "repousserais": "repousser",
    "repousserait": "repousser",
    "repousseras": "repousser",
    "repousserez": "repousser",
    "repousseriez": "repousser",
    "repousserions": "repousser",
    "repousserons": "repousser",
    "repousseront": "repousser",
    "repousses": "repousser",
    "repoussez": "repousser",
    "repoussiez": "repousser",
    "repoussions": "repousser",
    "repoussoirs": "repoussoir",
    "repoussons": "repousser",
    "repoussâmes": "repousser",
    "repoussât": "repousser",
    "repoussâtes": "repousser",
    "repoussèrent": "repousser",
    "repoussé": "repousser",
    "repoussée": "repousser",
    "repoussées": "repousser",
    "repoussés": "repousser",
    "reprenaient": "reprendre",
    "reprenais": "reprendre",
    "reprenait": "reprendre",
    "reprenant": "reprendre",
    "reprend": "reprendre",
    "reprendra": "reprendre",
    "reprendrai": "reprendre",
    "reprendraient": "reprendre",
    "reprendrais": "reprendre",
    "reprendrait": "reprendre",
    "reprendras": "reprendre",
    "reprendrez": "reprendre",
    "reprendriez": "reprendre",
    "reprendrions": "reprendre",
    "reprendrons": "reprendre",
    "reprendront": "reprendre",
    "reprends": "reprendre",
    "repreneurs": "repreneur",
    "reprenez": "reprendre",
    "repreniez": "reprendre",
    "reprenions": "reprendre",
    "reprenne": "reprendre",
    "reprennent": "reprendre",
    "reprennes": "reprendre",
    "reprenons": "reprendre",
    "reprints": "reprint",
    "reprirent": "reprendre",
    "repris": "reprendre",
    "reprisa": "repriser",
    "reprisai": "repriser",
    "reprisaient": "repriser",
    "reprisais": "repriser",
    "reprisait": "repriser",
    "reprisant": "repriser",
    "reprisas": "repriser",
    "reprisasse": "repriser",
    "reprisassent": "repriser",
    "reprisasses": "repriser",
    "reprisassiez": "repriser",
    "reprisassions": "repriser",
    "reprise": "repriser",
    "reprisent": "repriser",
    "reprisera": "repriser",
    "repriserai": "repriser",
    "repriseraient": "repriser",
    "repriserais": "repriser",
    "repriserait": "repriser",
    "repriseras": "repriser",
    "repriserez": "repriser",
    "repriseriez": "repriser",
    "repriserions": "repriser",
    "repriserons": "repriser",
    "repriseront": "repriser",
    "reprises": "repriser",
    "reprisez": "repriser",
    "reprisiez": "repriser",
    "reprisions": "repriser",
    "reprisons": "repriser",
    "reprisse": "reprendre",
    "reprissent": "reprendre",
    "reprisses": "reprendre",
    "reprissiez": "reprendre",
    "reprissions": "reprendre",
    "reprisâmes": "repriser",
    "reprisât": "repriser",
    "reprisâtes": "repriser",
    "reprisèrent": "repriser",
    "reprisé": "repriser",
    "reprisée": "repriser",
    "reprisées": "repriser",
    "reprisés": "repriser",
    "reprit": "reprendre",
    "reprocha": "reprocher",
    "reprochai": "reprocher",
    "reprochaient": "reprocher",
    "reprochais": "reprocher",
    "reprochait": "reprocher",
    "reprochant": "reprocher",
    "reprochas": "reprocher",
    "reprochasse": "reprocher",
    "reprochassent": "reprocher",
    "reprochasses": "reprocher",
    "reprochassiez": "reprocher",
    "reprochassions": "reprocher",
    "reproche": "reprocher",
    "reprochent": "reprocher",
    "reprochera": "reprocher",
    "reprocherai": "reprocher",
    "reprocheraient": "reprocher",
    "reprocherais": "reprocher",
    "reprocherait": "reprocher",
    "reprocheras": "reprocher",
    "reprocherez": "reprocher",
    "reprocheriez": "reprocher",
    "reprocherions": "reprocher",
    "reprocherons": "reprocher",
    "reprocheront": "reprocher",
    "reproches": "reprocher",
    "reprochez": "reprocher",
    "reprochiez": "reprocher",
    "reprochions": "reprocher",
    "reprochons": "reprocher",
    "reprochâmes": "reprocher",
    "reprochât": "reprocher",
    "reprochâtes": "reprocher",
    "reprochèrent": "reprocher",
    "reproché": "reprocher",
    "reprochée": "reprocher",
    "reprochées": "reprocher",
    "reprochés": "reprocher",
    "reproducteurs": "reproducteur",
    "reproductibles": "reproductible",
    "reproductifs": "reproductif",
    "reproductions": "reproduction",
    "reproductive": "reproductif",
    "reproductrice": "reproducteur",
    "reproductrices": "reproducteur",
    "reproduira": "reproduire",
    "reproduirai": "reproduire",
    "reproduiraient": "reproduire",
    "reproduirais": "reproduire",
    "reproduirait": "reproduire",
    "reproduiras": "reproduire",
    "reproduirez": "reproduire",
    "reproduiriez": "reproduire",
    "reproduirions": "reproduire",
    "reproduirons": "reproduire",
    "reproduiront": "reproduire",
    "reproduis": "reproduire",
    "reproduisaient": "reproduire",
    "reproduisais": "reproduire",
    "reproduisait": "reproduire",
    "reproduisant": "reproduire",
    "reproduise": "reproduire",
    "reproduisent": "reproduire",
    "reproduises": "reproduire",
    "reproduisez": "reproduire",
    "reproduisiez": "reproduire",
    "reproduisions": "reproduire",
    "reproduisirent": "reproduire",
    "reproduisis": "reproduire",
    "reproduisisse": "reproduire",
    "reproduisissent": "reproduire",
    "reproduisisses": "reproduire",
    "reproduisissiez": "reproduire",
    "reproduisissions": "reproduire",
    "reproduisit": "reproduire",
    "reproduisons": "reproduire",
    "reproduisîmes": "reproduire",
    "reproduisît": "reproduire",
    "reproduisîtes": "reproduire",
    "reproduit": "reproduire",
    "reproduite": "reproduire",
    "reproduites": "reproduire",
    "reproduits": "reproduire",
    "reprogrammant": "reprogrammer",
    "reprogramme": "reprogrammer",
    "reprogramment": "reprogrammer",
    "reprogrammera": "reprogrammer",
    "reprogrammé": "reprogrammer",
    "reprogrammée": "reprogrammer",
    "reprogrammés": "reprogrammer",
    "reprographies": "reprographie",
    "reprouva": "reprouver",
    "reprouvai": "reprouver",
    "reprouvaient": "reprouver",
    "reprouvais": "reprouver",
    "reprouvait": "reprouver",
    "reprouvant": "reprouver",
    "reprouvas": "reprouver",
    "reprouvasse": "reprouver",
    "reprouvassent": "reprouver",
    "reprouvasses": "reprouver",
    "reprouvassiez": "reprouver",
    "reprouvassions": "reprouver",
    "reprouve": "reprouver",
    "reprouvent": "reprouver",
    "reprouvera": "reprouver",
    "reprouverai": "reprouver",
    "reprouveraient": "reprouver",
    "reprouverais": "reprouver",
    "reprouverait": "reprouver",
    "reprouveras": "reprouver",
    "reprouverez": "reprouver",
    "reprouveriez": "reprouver",
    "reprouverions": "reprouver",
    "reprouverons": "reprouver",
    "reprouveront": "reprouver",
    "reprouves": "reprouver",
    "reprouvez": "reprouver",
    "reprouviez": "reprouver",
    "reprouvions": "reprouver",
    "reprouvons": "reprouver",
    "reprouvâmes": "reprouver",
    "reprouvât": "reprouver",
    "reprouvâtes": "reprouver",
    "reprouvèrent": "reprouver",
    "reprouvé": "reprouver",
    "reprouvée": "reprouver",
    "reprouvées": "reprouver",
    "reprouvés": "reprouver",
    "représailles": "représaille",
    "représenta": "représenter",
    "représentai": "représenter",
    "représentaient": "représenter",
    "représentais": "représenter",
    "représentait": "représenter",
    "représentant": "représenter",
    "représentante": "représentant",
    "représentantes": "représentant",
    "représentants": "représentant",
    "représentas": "représenter",
    "représentasse": "représenter",
    "représentassent": "représenter",
    "représentasses": "représenter",
    "représentassiez": "représenter",
    "représentassions": "représenter",
    "représentatifs": "représentatif",
    "représentations": "représentation",
    "représentative": "représentatif",
    "représentatives": "représentatif",
    "représentativités": "représentativité",
    "représente": "représenter",
    "représentent": "représenter",
    "représentera": "représenter",
    "représenterai": "représenter",
    "représenteraient": "représenter",
    "représenterais": "représenter",
    "représenterait": "représenter",
    "représenteras": "représenter",
    "représenterez": "représenter",
    "représenteriez": "représenter",
    "représenterions": "représenter",
    "représenterons": "représenter",
    "représenteront": "représenter",
    "représentes": "représenter",
    "représentez": "représenter",
    "représentiez": "représenter",
    "représentions": "représenter",
    "représentons": "représenter",
    "représentâmes": "représenter",
    "représentât": "représenter",
    "représentâtes": "représenter",
    "représentèrent": "représenter",
    "représenté": "représenter",
    "représentée": "représenter",
    "représentées": "représenter",
    "représentés": "représenter",
    "reprîmes": "reprendre",
    "reprît": "reprendre",
    "reprîtes": "reprendre",
    "reptations": "reptation",
    "reptiles": "reptile",
    "reptilienne": "reptilien",
    "reptiliennes": "reptilien",
    "reptiliens": "reptilien",
    "repu": "repaître",
    "republia": "republier",
    "republiai": "republier",
    "republiaient": "republier",
    "republiais": "republier",
    "republiait": "republier",
    "republiant": "republier",
    "republias": "republier",
    "republiasse": "republier",
    "republiassent": "republier",
    "republiasses": "republier",
    "republiassiez": "republier",
    "republiassions": "republier",
    "republie": "republier",
    "republient": "republier",
    "republiera": "republier",
    "republierai": "republier",
    "republieraient": "republier",
    "republierais": "republier",
    "republierait": "republier",
    "republieras": "republier",
    "republierez": "republier",
    "republieriez": "republier",
    "republierions": "republier",
    "republierons": "republier",
    "republieront": "republier",
    "republies": "republier",
    "republiez": "republier",
    "republiiez": "republier",
    "republiions": "republier",
    "republions": "republier",
    "republiâmes": "republier",
    "republiât": "republier",
    "republiâtes": "republier",
    "republièrent": "republier",
    "republié": "republier",
    "republiée": "republier",
    "republiées": "republier",
    "republiés": "republier",
    "repue": "repu",
    "repues": "repu",
    "repurent": "repaître",
    "repus": "repu",
    "repusse": "repaître",
    "repussent": "repaître",
    "repusses": "repaître",
    "repussiez": "repaître",
    "repussions": "repaître",
    "reput": "repaître",
    "repère": "repérer",
    "repèrent": "repérer",
    "repères": "repérer",
    "repéra": "repérer",
    "repérables": "repérable",
    "repérages": "repérage",
    "repérai": "repérer",
    "repéraient": "repérer",
    "repérais": "repérer",
    "repérait": "repérer",
    "repérant": "repérer",
    "repéras": "repérer",
    "repérasse": "repérer",
    "repérassent": "repérer",
    "repérasses": "repérer",
    "repérassiez": "repérer",
    "repérassions": "repérer",
    "repérera": "repérer",
    "repérerai": "repérer",
    "repéreraient": "repérer",
    "repérerais": "repérer",
    "repérerait": "repérer",
    "repéreras": "repérer",
    "repérerez": "repérer",
    "repéreriez": "repérer",
    "repérerions": "repérer",
    "repérerons": "repérer",
    "repéreront": "repérer",
    "repérez": "repérer",
    "repériez": "repérer",
    "repérions": "repérer",
    "repérons": "repérer",
    "repérâmes": "repérer",
    "repérât": "repérer",
    "repérâtes": "repérer",
    "repérèrent": "repérer",
    "repéré": "repérer",
    "repérée": "repérer",
    "repérées": "repérer",
    "repérés": "repérer",
    "repétrissait": "repétrir",
    "repétrit": "repétrir",
    "repêcha": "repêcher",
    "repêchages": "repêchage",
    "repêchai": "repêcher",
    "repêchaient": "repêcher",
    "repêchais": "repêcher",
    "repêchait": "repêcher",
    "repêchant": "repêcher",
    "repêchas": "repêcher",
    "repêchasse": "repêcher",
    "repêchassent": "repêcher",
    "repêchasses": "repêcher",
    "repêchassiez": "repêcher",
    "repêchassions": "repêcher",
    "repêche": "repêcher",
    "repêchent": "repêcher",
    "repêchera": "repêcher",
    "repêcherai": "repêcher",
    "repêcheraient": "repêcher",
    "repêcherais": "repêcher",
    "repêcherait": "repêcher",
    "repêcheras": "repêcher",
    "repêcherez": "repêcher",
    "repêcheriez": "repêcher",
    "repêcherions": "repêcher",
    "repêcherons": "repêcher",
    "repêcheront": "repêcher",
    "repêches": "repêcher",
    "repêchez": "repêcher",
    "repêchiez": "repêcher",
    "repêchions": "repêcher",
    "repêchons": "repêcher",
    "repêchâmes": "repêcher",
    "repêchât": "repêcher",
    "repêchâtes": "repêcher",
    "repêchèrent": "repêcher",
    "repêché": "repêcher",
    "repêchée": "repêcher",
    "repêchées": "repêcher",
    "repêchés": "repêcher",
    "repûmes": "repaître",
    "repût": "repaître",
    "repûtes": "repaître",
    "requalifia": "requalifier",
    "requalifiai": "requalifier",
    "requalifiaient": "requalifier",
    "requalifiais": "requalifier",
    "requalifiait": "requalifier",
    "requalifiant": "requalifier",
    "requalifias": "requalifier",
    "requalifiasse": "requalifier",
    "requalifiassent": "requalifier",
    "requalifiasses": "requalifier",
    "requalifiassiez": "requalifier",
    "requalifiassions": "requalifier",
    "requalifications": "requalification",
    "requalifie": "requalifier",
    "requalifient": "requalifier",
    "requalifiera": "requalifier",
    "requalifierai": "requalifier",
    "requalifieraient": "requalifier",
    "requalifierais": "requalifier",
    "requalifierait": "requalifier",
    "requalifieras": "requalifier",
    "requalifierez": "requalifier",
    "requalifieriez": "requalifier",
    "requalifierions": "requalifier",
    "requalifierons": "requalifier",
    "requalifieront": "requalifier",
    "requalifies": "requalifier",
    "requalifiez": "requalifier",
    "requalifiiez": "requalifier",
    "requalifiions": "requalifier",
    "requalifions": "requalifier",
    "requalifiâmes": "requalifier",
    "requalifiât": "requalifier",
    "requalifiâtes": "requalifier",
    "requalifièrent": "requalifier",
    "requalifié": "requalifier",
    "requalifiée": "requalifier",
    "requalifiées": "requalifier",
    "requalifiés": "requalifier",
    "requerra": "requérir",
    "requerrai": "requérir",
    "requerraient": "requérir",
    "requerrais": "requérir",
    "requerrait": "requérir",
    "requerras": "requérir",
    "requerrez": "requérir",
    "requerriez": "requérir",
    "requerrions": "requérir",
    "requerrons": "requérir",
    "requerront": "requérir",
    "requiems": "requiem",
    "requiers": "requérir",
    "requiert": "requérir",
    "requinqua": "requinquer",
    "requinquait": "requinquer",
    "requinque": "requinquer",
    "requinquent": "requinquer",
    "requinquera": "requinquer",
    "requinquerait": "requinquer",
    "requinqué": "requinquer",
    "requinquée": "requinquer",
    "requinqués": "requinquer",
    "requins": "requin",
    "requins-marteaux": "requin-marteau",
    "requirent": "requérir",
    "requis": "requérir",
    "requise": "requis",
    "requises": "requis",
    "requisse": "requérir",
    "requissent": "requérir",
    "requisses": "requérir",
    "requissiez": "requérir",
    "requissions": "requérir",
    "requit": "requérir",
    "requitta": "requitter",
    "requittai": "requitter",
    "requittaient": "requitter",
    "requittais": "requitter",
    "requittait": "requitter",
    "requittant": "requitter",
    "requittas": "requitter",
    "requittasse": "requitter",
    "requittassent": "requitter",
    "requittasses": "requitter",
    "requittassiez": "requitter",
    "requittassions": "requitter",
    "requitte": "requitter",
    "requittent": "requitter",
    "requittera": "requitter",
    "requitterai": "requitter",
    "requitteraient": "requitter",
    "requitterais": "requitter",
    "requitterait": "requitter",
    "requitteras": "requitter",
    "requitterez": "requitter",
    "requitteriez": "requitter",
    "requitterions": "requitter",
    "requitterons": "requitter",
    "requitteront": "requitter",
    "requittes": "requitter",
    "requittez": "requitter",
    "requittiez": "requitter",
    "requittions": "requitter",
    "requittons": "requitter",
    "requittâmes": "requitter",
    "requittât": "requitter",
    "requittâtes": "requitter",
    "requittèrent": "requitter",
    "requitté": "requitter",
    "requittée": "requitter",
    "requittées": "requitter",
    "requittés": "requitter",
    "requière": "requérir",
    "requièrent": "requérir",
    "requières": "requérir",
    "requéraient": "requérir",
    "requérais": "requérir",
    "requérait": "requérir",
    "requérant": "requérir",
    "requérante": "requérant",
    "requérantes": "requérant",
    "requérants": "requérant",
    "requérez": "requérir",
    "requériez": "requérir",
    "requérions": "requérir",
    "requérons": "requérir",
    "requêtes": "requête",
    "requîmes": "requérir",
    "requît": "requérir",
    "requîtes": "requérir",
    "resala": "resaler",
    "resalai": "resaler",
    "resalaient": "resaler",
    "resalais": "resaler",
    "resalait": "resaler",
    "resalant": "resaler",
    "resalas": "resaler",
    "resalasse": "resaler",
    "resalassent": "resaler",
    "resalasses": "resaler",
    "resalassiez": "resaler",
    "resalassions": "resaler",
    "resale": "resaler",
    "resalent": "resaler",
    "resalera": "resaler",
    "resalerai": "resaler",
    "resaleraient": "resaler",
    "resalerais": "resaler",
    "resalerait": "resaler",
    "resaleras": "resaler",
    "resalerez": "resaler",
    "resaleriez": "resaler",
    "resalerions": "resaler",
    "resalerons": "resaler",
    "resaleront": "resaler",
    "resales": "resaler",
    "resalez": "resaler",
    "resali": "resalir",
    "resalie": "resalir",
    "resalies": "resalir",
    "resaliez": "resaler",
    "resalions": "resaler",
    "resalira": "resalir",
    "resalirai": "resalir",
    "resaliraient": "resalir",
    "resalirais": "resalir",
    "resalirait": "resalir",
    "resaliras": "resalir",
    "resalirent": "resalir",
    "resalirez": "resalir",
    "resaliriez": "resalir",
    "resalirions": "resalir",
    "resalirons": "resalir",
    "resaliront": "resalir",
    "resalis": "resalir",
    "resalissaient": "resalir",
    "resalissais": "resalir",
    "resalissait": "resalir",
    "resalissant": "resalir",
    "resalisse": "resalir",
    "resalissent": "resalir",
    "resalisses": "resalir",
    "resalissez": "resalir",
    "resalissiez": "resalir",
    "resalissions": "resalir",
    "resalissons": "resalir",
    "resalit": "resalir",
    "resalons": "resaler",
    "resalua": "resaluer",
    "resaluai": "resaluer",
    "resaluaient": "resaluer",
    "resaluais": "resaluer",
    "resaluait": "resaluer",
    "resaluant": "resaluer",
    "resaluas": "resaluer",
    "resaluasse": "resaluer",
    "resaluassent": "resaluer",
    "resaluasses": "resaluer",
    "resaluassiez": "resaluer",
    "resaluassions": "resaluer",
    "resalue": "resaluer",
    "resaluent": "resaluer",
    "resaluera": "resaluer",
    "resaluerai": "resaluer",
    "resalueraient": "resaluer",
    "resaluerais": "resaluer",
    "resaluerait": "resaluer",
    "resalueras": "resaluer",
    "resaluerez": "resaluer",
    "resalueriez": "resaluer",
    "resaluerions": "resaluer",
    "resaluerons": "resaluer",
    "resalueront": "resaluer",
    "resalues": "resaluer",
    "resaluez": "resaluer",
    "resaluiez": "resaluer",
    "resaluions": "resaluer",
    "resaluons": "resaluer",
    "resaluâmes": "resaluer",
    "resaluât": "resaluer",
    "resaluâtes": "resaluer",
    "resaluèrent": "resaluer",
    "resalué": "resaluer",
    "resaluée": "resaluer",
    "resaluées": "resaluer",
    "resalués": "resaluer",
    "resalâmes": "resaler",
    "resalât": "resaler",
    "resalâtes": "resaler",
    "resalèrent": "resaler",
    "resalé": "resaler",
    "resalée": "resaler",
    "resalées": "resaler",
    "resalés": "resaler",
    "resalîmes": "resalir",
    "resalît": "resalir",
    "resalîtes": "resalir",
    "resape": "resaper",
    "resapent": "resaper",
    "resapée": "resaper",
    "resapés": "resaper",
    "resauta": "resauter",
    "resautai": "resauter",
    "resautaient": "resauter",
    "resautais": "resauter",
    "resautait": "resauter",
    "resautant": "resauter",
    "resautas": "resauter",
    "resautasse": "resauter",
    "resautassent": "resauter",
    "resautasses": "resauter",
    "resautassiez": "resauter",
    "resautassions": "resauter",
    "resaute": "resauter",
    "resautent": "resauter",
    "resautera": "resauter",
    "resauterai": "resauter",
    "resauteraient": "resauter",
    "resauterais": "resauter",
    "resauterait": "resauter",
    "resauteras": "resauter",
    "resauterez": "resauter",
    "resauteriez": "resauter",
    "resauterions": "resauter",
    "resauterons": "resauter",
    "resauteront": "resauter",
    "resautes": "resauter",
    "resautez": "resauter",
    "resautiez": "resauter",
    "resautions": "resauter",
    "resautons": "resauter",
    "resautâmes": "resauter",
    "resautât": "resauter",
    "resautâtes": "resauter",
    "resautèrent": "resauter",
    "resauté": "resauter",
    "resautée": "resauter",
    "resautées": "resauter",
    "resautés": "resauter",
    "rescapes": "rescaper",
    "rescapé": "rescaper",
    "rescapée": "rescaper",
    "rescapées": "rescaper",
    "rescapés": "rescaper",
    "rescinda": "rescinder",
    "rescindai": "rescinder",
    "rescindaient": "rescinder",
    "rescindais": "rescinder",
    "rescindait": "rescinder",
    "rescindant": "rescinder",
    "rescindas": "rescinder",
    "rescindasse": "rescinder",
    "rescindassent": "rescinder",
    "rescindasses": "rescinder",
    "rescindassiez": "rescinder",
    "rescindassions": "rescinder",
    "rescinde": "rescinder",
    "rescindent": "rescinder",
    "rescindera": "rescinder",
    "rescinderai": "rescinder",
    "rescinderaient": "rescinder",
    "rescinderais": "rescinder",
    "rescinderait": "rescinder",
    "rescinderas": "rescinder",
    "rescinderez": "rescinder",
    "rescinderiez": "rescinder",
    "rescinderions": "rescinder",
    "rescinderons": "rescinder",
    "rescinderont": "rescinder",
    "rescindes": "rescinder",
    "rescindez": "rescinder",
    "rescindiez": "rescinder",
    "rescindions": "rescinder",
    "rescindons": "rescinder",
    "rescindâmes": "rescinder",
    "rescindât": "rescinder",
    "rescindâtes": "rescinder",
    "rescindèrent": "rescinder",
    "rescindé": "rescinder",
    "rescindée": "rescinder",
    "rescindées": "rescinder",
    "rescindés": "rescinder",
    "rescisions": "rescision",
    "rescousses": "rescousse",
    "rescrits": "rescrit",
    "resitua": "resituer",
    "resituai": "resituer",
    "resituaient": "resituer",
    "resituais": "resituer",
    "resituait": "resituer",
    "resituant": "resituer",
    "resituas": "resituer",
    "resituasse": "resituer",
    "resituassent": "resituer",
    "resituasses": "resituer",
    "resituassiez": "resituer",
    "resituassions": "resituer",
    "resitue": "resituer",
    "resituent": "resituer",
    "resituera": "resituer",
    "resituerai": "resituer",
    "resitueraient": "resituer",
    "resituerais": "resituer",
    "resituerait": "resituer",
    "resitueras": "resituer",
    "resituerez": "resituer",
    "resitueriez": "resituer",
    "resituerions": "resituer",
    "resituerons": "resituer",
    "resitueront": "resituer",
    "resitues": "resituer",
    "resituez": "resituer",
    "resituiez": "resituer",
    "resituions": "resituer",
    "resituons": "resituer",
    "resituâmes": "resituer",
    "resituât": "resituer",
    "resituâtes": "resituer",
    "resituèrent": "resituer",
    "resitué": "resituer",
    "resituée": "resituer",
    "resituées": "resituer",
    "resitués": "resituer",
    "resocialisations": "resocialisation",
    "resongeait": "resonger",
    "respecta": "respecter",
    "respectabilités": "respectabilité",
    "respectables": "respectable",
    "respectai": "respecter",
    "respectaient": "respecter",
    "respectais": "respecter",
    "respectait": "respecter",
    "respectant": "respecter",
    "respectas": "respecter",
    "respectasse": "respecter",
    "respectassent": "respecter",
    "respectasses": "respecter",
    "respectassiez": "respecter",
    "respectassions": "respecter",
    "respecte": "respecter",
    "respectent": "respecter",
    "respectera": "respecter",
    "respecterai": "respecter",
    "respecteraient": "respecter",
    "respecterais": "respecter",
    "respecterait": "respecter",
    "respecteras": "respecter",
    "respecterez": "respecter",
    "respecteriez": "respecter",
    "respecterions": "respecter",
    "respecterons": "respecter",
    "respecteront": "respecter",
    "respectes": "respecter",
    "respectez": "respecter",
    "respectiez": "respecter",
    "respectifs": "respectif",
    "respections": "respecter",
    "respective": "respectif",
    "respectives": "respectif",
    "respectons": "respecter",
    "respects": "respect",
    "respectueuse": "respectueux",
    "respectueuses": "respectueux",
    "respectâmes": "respecter",
    "respectât": "respecter",
    "respectâtes": "respecter",
    "respectèrent": "respecter",
    "respecté": "respecter",
    "respectée": "respecter",
    "respectées": "respecter",
    "respectés": "respecter",
    "respira": "respirer",
    "respirables": "respirable",
    "respirai": "respirer",
    "respiraient": "respirer",
    "respirais": "respirer",
    "respirait": "respirer",
    "respirant": "respirer",
    "respiras": "respirer",
    "respirasse": "respirer",
    "respirassent": "respirer",
    "respirasses": "respirer",
    "respirassiez": "respirer",
    "respirassions": "respirer",
    "respirateurs": "respirateur",
    "respirations": "respiration",
    "respiratoires": "respiratoire",
    "respire": "respirer",
    "respirent": "respirer",
    "respirera": "respirer",
    "respirerai": "respirer",
    "respireraient": "respirer",
    "respirerais": "respirer",
    "respirerait": "respirer",
    "respireras": "respirer",
    "respirerez": "respirer",
    "respireriez": "respirer",
    "respirerions": "respirer",
    "respirerons": "respirer",
    "respireront": "respirer",
    "respires": "respirer",
    "respirez": "respirer",
    "respiriez": "respirer",
    "respirions": "respirer",
    "respirons": "respirer",
    "respirâmes": "respirer",
    "respirât": "respirer",
    "respirâtes": "respirer",
    "respirèrent": "respirer",
    "respiré": "respirer",
    "respirée": "respirer",
    "respirées": "respirer",
    "respirés": "respirer",
    "resplendi": "resplendir",
    "resplendira": "resplendir",
    "resplendirai": "resplendir",
    "resplendiraient": "resplendir",
    "resplendirais": "resplendir",
    "resplendirait": "resplendir",
    "resplendiras": "resplendir",
    "resplendirent": "resplendir",
    "resplendirez": "resplendir",
    "resplendiriez": "resplendir",
    "resplendirions": "resplendir",
    "resplendirons": "resplendir",
    "resplendiront": "resplendir",
    "resplendis": "resplendir",
    "resplendissaient": "resplendir",
    "resplendissais": "resplendir",
    "resplendissait": "resplendir",
    "resplendissant": "resplendir",
    "resplendissante": "resplendissant",
    "resplendissantes": "resplendissant",
    "resplendissants": "resplendissant",
    "resplendisse": "resplendir",
    "resplendissent": "resplendir",
    "resplendisses": "resplendir",
    "resplendissez": "resplendir",
    "resplendissiez": "resplendir",
    "resplendissions": "resplendir",
    "resplendissons": "resplendir",
    "resplendit": "resplendir",
    "resplendîmes": "resplendir",
    "resplendît": "resplendir",
    "resplendîtes": "resplendir",
    "responsabilisa": "responsabiliser",
    "responsabilisai": "responsabiliser",
    "responsabilisaient": "responsabiliser",
    "responsabilisais": "responsabiliser",
    "responsabilisait": "responsabiliser",
    "responsabilisant": "responsabiliser",
    "responsabilisas": "responsabiliser",
    "responsabilisasse": "responsabiliser",
    "responsabilisassent": "responsabiliser",
    "responsabilisasses": "responsabiliser",
    "responsabilisassiez": "responsabiliser",
    "responsabilisassions": "responsabiliser",
    "responsabilise": "responsabiliser",
    "responsabilisent": "responsabiliser",
    "responsabilisera": "responsabiliser",
    "responsabiliserai": "responsabiliser",
    "responsabiliseraient": "responsabiliser",
    "responsabiliserais": "responsabiliser",
    "responsabiliserait": "responsabiliser",
    "responsabiliseras": "responsabiliser",
    "responsabiliserez": "responsabiliser",
    "responsabiliseriez": "responsabiliser",
    "responsabiliserions": "responsabiliser",
    "responsabiliserons": "responsabiliser",
    "responsabiliseront": "responsabiliser",
    "responsabilises": "responsabiliser",
    "responsabilisez": "responsabiliser",
    "responsabilisiez": "responsabiliser",
    "responsabilisions": "responsabiliser",
    "responsabilisons": "responsabiliser",
    "responsabilisâmes": "responsabiliser",
    "responsabilisât": "responsabiliser",
    "responsabilisâtes": "responsabiliser",
    "responsabilisèrent": "responsabiliser",
    "responsabilisé": "responsabiliser",
    "responsabilisée": "responsabiliser",
    "responsabilisées": "responsabiliser",
    "responsabilisés": "responsabiliser",
    "responsabilités": "responsabilité",
    "responsables": "responsable",
    "resquilla": "resquiller",
    "resquillai": "resquiller",
    "resquillaient": "resquiller",
    "resquillais": "resquiller",
    "resquillait": "resquiller",
    "resquillant": "resquiller",
    "resquillas": "resquiller",
    "resquillasse": "resquiller",
    "resquillassent": "resquiller",
    "resquillasses": "resquiller",
    "resquillassiez": "resquiller",
    "resquillassions": "resquiller",
    "resquille": "resquiller",
    "resquillent": "resquiller",
    "resquillera": "resquiller",
    "resquillerai": "resquiller",
    "resquilleraient": "resquiller",
    "resquillerais": "resquiller",
    "resquillerait": "resquiller",
    "resquilleras": "resquiller",
    "resquillerez": "resquiller",
    "resquilleriez": "resquiller",
    "resquillerions": "resquiller",
    "resquillerons": "resquiller",
    "resquilleront": "resquiller",
    "resquilles": "resquiller",
    "resquilleurs": "resquilleur",
    "resquilleuse": "resquilleur",
    "resquilleuses": "resquilleur",
    "resquillez": "resquiller",
    "resquilliez": "resquiller",
    "resquillions": "resquiller",
    "resquillons": "resquiller",
    "resquillâmes": "resquiller",
    "resquillât": "resquiller",
    "resquillâtes": "resquiller",
    "resquillèrent": "resquiller",
    "resquillé": "resquiller",
    "resquillée": "resquiller",
    "resquillées": "resquiller",
    "resquillés": "resquiller",
    "ressacs": "ressac",
    "ressaie": "ressayer",
    "ressaient": "ressayer",
    "ressaiera": "ressayer",
    "ressaierai": "ressayer",
    "ressaieraient": "ressayer",
    "ressaierais": "ressayer",
    "ressaierait": "ressayer",
    "ressaieras": "ressayer",
    "ressaierez": "ressayer",
    "ressaieriez": "ressayer",
    "ressaierions": "ressayer",
    "ressaierons": "ressayer",
    "ressaieront": "ressayer",
    "ressaies": "ressayer",
    "ressaisi": "ressaisir",
    "ressaisie": "ressaisir",
    "ressaisies": "ressaisir",
    "ressaisira": "ressaisir",
    "ressaisirai": "ressaisir",
    "ressaisiraient": "ressaisir",
    "ressaisirais": "ressaisir",
    "ressaisirait": "ressaisir",
    "ressaisiras": "ressaisir",
    "ressaisirent": "ressaisir",
    "ressaisirez": "ressaisir",
    "ressaisiriez": "ressaisir",
    "ressaisirions": "ressaisir",
    "ressaisirons": "ressaisir",
    "ressaisiront": "ressaisir",
    "ressaisis": "ressaisir",
    "ressaisissaient": "ressaisir",
    "ressaisissais": "ressaisir",
    "ressaisissait": "ressaisir",
    "ressaisissant": "ressaisir",
    "ressaisisse": "ressaisir",
    "ressaisissent": "ressaisir",
    "ressaisisses": "ressaisir",
    "ressaisissez": "ressaisir",
    "ressaisissiez": "ressaisir",
    "ressaisissions": "ressaisir",
    "ressaisissons": "ressaisir",
    "ressaisit": "ressaisir",
    "ressaisîmes": "ressaisir",
    "ressaisît": "ressaisir",
    "ressaisîtes": "ressaisir",
    "ressassa": "ressasser",
    "ressassai": "ressasser",
    "ressassaient": "ressasser",
    "ressassais": "ressasser",
    "ressassait": "ressasser",
    "ressassant": "ressasser",
    "ressassas": "ressasser",
    "ressassasse": "ressasser",
    "ressassassent": "ressasser",
    "ressassasses": "ressasser",
    "ressassassiez": "ressasser",
    "ressassassions": "ressasser",
    "ressasse": "ressasser",
    "ressassent": "ressasser",
    "ressassera": "ressasser",
    "ressasserai": "ressasser",
    "ressasseraient": "ressasser",
    "ressasserais": "ressasser",
    "ressasserait": "ressasser",
    "ressasseras": "ressasser",
    "ressasserez": "ressasser",
    "ressasseriez": "ressasser",
    "ressasserions": "ressasser",
    "ressasserons": "ressasser",
    "ressasseront": "ressasser",
    "ressasses": "ressasser",
    "ressassez": "ressasser",
    "ressassiez": "ressasser",
    "ressassions": "ressasser",
    "ressassons": "ressasser",
    "ressassâmes": "ressasser",
    "ressassât": "ressasser",
    "ressassâtes": "ressasser",
    "ressassèrent": "ressasser",
    "ressassé": "ressasser",
    "ressassée": "ressasser",
    "ressassées": "ressasser",
    "ressassés": "ressasser",
    "ressauts": "ressaut",
    "ressauté": "ressauter",
    "ressaya": "ressayer",
    "ressayai": "ressayer",
    "ressayaient": "ressayer",
    "ressayais": "ressayer",
    "ressayait": "ressayer",
    "ressayant": "ressayer",
    "ressayas": "ressayer",
    "ressayasse": "ressayer",
    "ressayassent": "ressayer",
    "ressayasses": "ressayer",
    "ressayassiez": "ressayer",
    "ressayassions": "ressayer",
    "ressaye": "ressayer",
    "ressayent": "ressayer",
    "ressayera": "ressayer",
    "ressayerai": "ressayer",
    "ressayeraient": "ressayer",
    "ressayerais": "ressayer",
    "ressayerait": "ressayer",
    "ressayeras": "ressayer",
    "ressayerez": "ressayer",
    "ressayeriez": "ressayer",
    "ressayerions": "ressayer",
    "ressayerons": "ressayer",
    "ressayeront": "ressayer",
    "ressayes": "ressayer",
    "ressayez": "ressayer",
    "ressayiez": "ressayer",
    "ressayions": "ressayer",
    "ressayons": "ressayer",
    "ressayâmes": "ressayer",
    "ressayât": "ressayer",
    "ressayâtes": "ressayer",
    "ressayèrent": "ressayer",
    "ressayé": "ressayer",
    "ressayée": "ressayer",
    "ressayées": "ressayer",
    "ressayés": "ressayer",
    "ressema": "ressemer",
    "ressemai": "ressemer",
    "ressemaient": "ressemer",
    "ressemais": "ressemer",
    "ressemait": "ressemer",
    "ressemant": "ressemer",
    "ressemas": "ressemer",
    "ressemasse": "ressemer",
    "ressemassent": "ressemer",
    "ressemasses": "ressemer",
    "ressemassiez": "ressemer",
    "ressemassions": "ressemer",
    "ressembla": "ressembler",
    "ressemblai": "ressembler",
    "ressemblaient": "ressembler",
    "ressemblais": "ressembler",
    "ressemblait": "ressembler",
    "ressemblances": "ressemblance",
    "ressemblant": "ressembler",
    "ressemblante": "ressemblant",
    "ressemblantes": "ressemblant",
    "ressemblants": "ressemblant",
    "ressemblas": "ressembler",
    "ressemblasse": "ressembler",
    "ressemblassent": "ressembler",
    "ressemblasses": "ressembler",
    "ressemblassiez": "ressembler",
    "ressemblassions": "ressembler",
    "ressemble": "ressembler",
    "ressemblent": "ressembler",
    "ressemblera": "ressembler",
    "ressemblerai": "ressembler",
    "ressembleraient": "ressembler",
    "ressemblerais": "ressembler",
    "ressemblerait": "ressembler",
    "ressembleras": "ressembler",
    "ressemblerez": "ressembler",
    "ressembleriez": "ressembler",
    "ressemblerions": "ressembler",
    "ressemblerons": "ressembler",
    "ressembleront": "ressembler",
    "ressembles": "ressembler",
    "ressemblez": "ressembler",
    "ressembliez": "ressembler",
    "ressemblions": "ressembler",
    "ressemblons": "ressembler",
    "ressemblâmes": "ressembler",
    "ressemblât": "ressembler",
    "ressemblâtes": "ressembler",
    "ressemblèrent": "ressembler",
    "ressemblé": "ressembler",
    "ressemela": "ressemeler",
    "ressemelages": "ressemelage",
    "ressemelai": "ressemeler",
    "ressemelaient": "ressemeler",
    "ressemelais": "ressemeler",
    "ressemelait": "ressemeler",
    "ressemelant": "ressemeler",
    "ressemelas": "ressemeler",
    "ressemelasse": "ressemeler",
    "ressemelassent": "ressemeler",
    "ressemelasses": "ressemeler",
    "ressemelassiez": "ressemeler",
    "ressemelassions": "ressemeler",
    "ressemelez": "ressemeler",
    "ressemeliez": "ressemeler",
    "ressemelions": "ressemeler",
    "ressemelle": "ressemeler",
    "ressemellent": "ressemeler",
    "ressemellera": "ressemeler",
    "ressemellerai": "ressemeler",
    "ressemelleraient": "ressemeler",
    "ressemellerais": "ressemeler",
    "ressemellerait": "ressemeler",
    "ressemelleras": "ressemeler",
    "ressemellerez": "ressemeler",
    "ressemelleriez": "ressemeler",
    "ressemellerions": "ressemeler",
    "ressemellerons": "ressemeler",
    "ressemelleront": "ressemeler",
    "ressemelles": "ressemeler",
    "ressemelons": "ressemeler",
    "ressemelâmes": "ressemeler",
    "ressemelât": "ressemeler",
    "ressemelâtes": "ressemeler",
    "ressemelèrent": "ressemeler",
    "ressemelé": "ressemeler",
    "ressemelée": "ressemeler",
    "ressemelées": "ressemeler",
    "ressemelés": "ressemeler",
    "ressemez": "ressemer",
    "ressemiez": "ressemer",
    "ressemions": "ressemer",
    "ressemons": "ressemer",
    "ressemâmes": "ressemer",
    "ressemât": "ressemer",
    "ressemâtes": "ressemer",
    "ressemèrent": "ressemer",
    "ressemé": "ressemer",
    "ressemée": "ressemer",
    "ressemées": "ressemer",
    "ressemés": "ressemer",
    "ressens": "ressentir",
    "ressent": "ressentir",
    "ressentaient": "ressentir",
    "ressentais": "ressentir",
    "ressentait": "ressentir",
    "ressentant": "ressentir",
    "ressente": "ressentir",
    "ressentent": "ressentir",
    "ressentes": "ressentir",
    "ressentez": "ressentir",
    "ressenti": "ressentir",
    "ressentie": "ressentir",
    "ressenties": "ressentir",
    "ressentiez": "ressentir",
    "ressentiments": "ressentiment",
    "ressentions": "ressentir",
    "ressentira": "ressentir",
    "ressentirai": "ressentir",
    "ressentiraient": "ressentir",
    "ressentirais": "ressentir",
    "ressentirait": "ressentir",
    "ressentiras": "ressentir",
    "ressentirent": "ressentir",
    "ressentirez": "ressentir",
    "ressentiriez": "ressentir",
    "ressentirions": "ressentir",
    "ressentirons": "ressentir",
    "ressentiront": "ressentir",
    "ressentis": "ressentir",
    "ressentisse": "ressentir",
    "ressentissent": "ressentir",
    "ressentisses": "ressentir",
    "ressentissiez": "ressentir",
    "ressentissions": "ressentir",
    "ressentit": "ressentir",
    "ressentons": "ressentir",
    "ressentîmes": "ressentir",
    "ressentît": "ressentir",
    "ressentîtes": "ressentir",
    "resserra": "resserrer",
    "resserrai": "resserrer",
    "resserraient": "resserrer",
    "resserrais": "resserrer",
    "resserrait": "resserrer",
    "resserrant": "resserrer",
    "resserras": "resserrer",
    "resserrasse": "resserrer",
    "resserrassent": "resserrer",
    "resserrasses": "resserrer",
    "resserrassiez": "resserrer",
    "resserrassions": "resserrer",
    "resserre": "resserrer",
    "resserrements": "resserrement",
    "resserrent": "resserrer",
    "resserrera": "resserrer",
    "resserrerai": "resserrer",
    "resserreraient": "resserrer",
    "resserrerais": "resserrer",
    "resserrerait": "resserrer",
    "resserreras": "resserrer",
    "resserrerez": "resserrer",
    "resserreriez": "resserrer",
    "resserrerions": "resserrer",
    "resserrerons": "resserrer",
    "resserreront": "resserrer",
    "resserres": "resserrer",
    "resserrez": "resserrer",
    "resserriez": "resserrer",
    "resserrions": "resserrer",
    "resserrons": "resserrer",
    "resserrâmes": "resserrer",
    "resserrât": "resserrer",
    "resserrâtes": "resserrer",
    "resserrèrent": "resserrer",
    "resserré": "resserrer",
    "resserrée": "resserrer",
    "resserrées": "resserrer",
    "resserrés": "resserrer",
    "ressers": "resservir",
    "ressert": "resservir",
    "resservaient": "resservir",
    "resservais": "resservir",
    "resservait": "resservir",
    "resservant": "resservir",
    "resserve": "resservir",
    "resservent": "resservir",
    "resserves": "resservir",
    "resservez": "resservir",
    "resservi": "resservir",
    "resservie": "resservir",
    "resservies": "resservir",
    "resserviez": "resservir",
    "resservions": "resservir",
    "resservira": "resservir",
    "resservirai": "resservir",
    "resserviraient": "resservir",
    "resservirais": "resservir",
    "resservirait": "resservir",
    "resserviras": "resservir",
    "resservirent": "resservir",
    "resservirez": "resservir",
    "resserviriez": "resservir",
    "resservirions": "resservir",
    "resservirons": "resservir",
    "resserviront": "resservir",
    "resservis": "resservir",
    "resservisse": "resservir",
    "resservissent": "resservir",
    "resservisses": "resservir",
    "resservissiez": "resservir",
    "resservissions": "resservir",
    "resservit": "resservir",
    "resservons": "resservir",
    "resservîmes": "resservir",
    "resservît": "resservir",
    "resservîtes": "resservir",
    "ressors": "ressortir",
    "ressort": "ressortir",
    "ressortaient": "ressortir",
    "ressortais": "ressortir",
    "ressortait": "ressortir",
    "ressortant": "ressortir",
    "ressorte": "ressortir",
    "ressortent": "ressortir",
    "ressortes": "ressortir",
    "ressortez": "ressortir",
    "ressorti": "ressortir",
    "ressortie": "ressortir",
    "ressorties": "ressortir",
    "ressortiez": "ressortir",
    "ressortions": "ressortir",
    "ressortira": "ressortir",
    "ressortirai": "ressortir",
    "ressortiraient": "ressortir",
    "ressortirais": "ressortir",
    "ressortirait": "ressortir",
    "ressortiras": "ressortir",
    "ressortirent": "ressortir",
    "ressortirez": "ressortir",
    "ressortiriez": "ressortir",
    "ressortirions": "ressortir",
    "ressortirons": "ressortir",
    "ressortiront": "ressortir",
    "ressortis": "ressortir",
    "ressortissaient": "ressortir",
    "ressortissais": "ressortir",
    "ressortissait": "ressortir",
    "ressortissant": "ressortir",
    "ressortissante": "ressortissant",
    "ressortissantes": "ressortissant",
    "ressortissants": "ressortissant",
    "ressortisse": "ressortir",
    "ressortissent": "ressortir",
    "ressortisses": "ressortir",
    "ressortissez": "ressortir",
    "ressortissiez": "ressortir",
    "ressortissions": "ressortir",
    "ressortissons": "ressortir",
    "ressortit": "ressortir",
    "ressortons": "ressortir",
    "ressorts": "ressort",
    "ressortîmes": "ressortir",
    "ressortît": "ressortir",
    "ressortîtes": "ressortir",
    "ressouda": "ressouder",
    "ressoudai": "ressouder",
    "ressoudaient": "ressouder",
    "ressoudais": "ressouder",
    "ressoudait": "ressouder",
    "ressoudant": "ressouder",
    "ressoudas": "ressouder",
    "ressoudasse": "ressouder",
    "ressoudassent": "ressouder",
    "ressoudasses": "ressouder",
    "ressoudassiez": "ressouder",
    "ressoudassions": "ressouder",
    "ressoude": "ressouder",
    "ressoudent": "ressouder",
    "ressoudera": "ressouder",
    "ressouderai": "ressouder",
    "ressouderaient": "ressouder",
    "ressouderais": "ressouder",
    "ressouderait": "ressouder",
    "ressouderas": "ressouder",
    "ressouderez": "ressouder",
    "ressouderiez": "ressouder",
    "ressouderions": "ressouder",
    "ressouderons": "ressouder",
    "ressouderont": "ressouder",
    "ressoudes": "ressouder",
    "ressoudez": "ressouder",
    "ressoudiez": "ressouder",
    "ressoudions": "ressouder",
    "ressoudons": "ressouder",
    "ressoudâmes": "ressouder",
    "ressoudât": "ressouder",
    "ressoudâtes": "ressouder",
    "ressoudèrent": "ressouder",
    "ressoudé": "ressouder",
    "ressoudée": "ressouder",
    "ressoudées": "ressouder",
    "ressoudés": "ressouder",
    "ressources": "ressource",
    "ressourcé": "ressourcer",
    "ressourçais": "ressourcer",
    "ressourçait": "ressourcer",
    "ressouvenaient": "ressouvenir",
    "ressouvenais": "ressouvenir",
    "ressouvenait": "ressouvenir",
    "ressouvenant": "ressouvenir",
    "ressouvenez": "ressouvenir",
    "ressouveniez": "ressouvenir",
    "ressouvenions": "ressouvenir",
    "ressouvenons": "ressouvenir",
    "ressouvenu": "ressouvenir",
    "ressouvenue": "ressouvenir",
    "ressouvenues": "ressouvenir",
    "ressouvenus": "ressouvenir",
    "ressouviendra": "ressouvenir",
    "ressouviendrai": "ressouvenir",
    "ressouviendraient": "ressouvenir",
    "ressouviendrais": "ressouvenir",
    "ressouviendrait": "ressouvenir",
    "ressouviendras": "ressouvenir",
    "ressouviendrez": "ressouvenir",
    "ressouviendriez": "ressouvenir",
    "ressouviendrions": "ressouvenir",
    "ressouviendrons": "ressouvenir",
    "ressouviendront": "ressouvenir",
    "ressouvienne": "ressouvenir",
    "ressouviennent": "ressouvenir",
    "ressouviennes": "ressouvenir",
    "ressouviens": "ressouvenir",
    "ressouvient": "ressouvenir",
    "ressouvinrent": "ressouvenir",
    "ressouvins": "ressouvenir",
    "ressouvinsse": "ressouvenir",
    "ressouvinssent": "ressouvenir",
    "ressouvinsses": "ressouvenir",
    "ressouvinssiez": "ressouvenir",
    "ressouvinssions": "ressouvenir",
    "ressouvint": "ressouvenir",
    "ressouvînmes": "ressouvenir",
    "ressouvînt": "ressouvenir",
    "ressouvîntes": "ressouvenir",
    "ressua": "ressuer",
    "ressuai": "ressuer",
    "ressuaient": "ressuer",
    "ressuais": "ressuer",
    "ressuait": "ressuer",
    "ressuant": "ressuer",
    "ressuas": "ressuer",
    "ressuasse": "ressuer",
    "ressuassent": "ressuer",
    "ressuasses": "ressuer",
    "ressuassiez": "ressuer",
    "ressuassions": "ressuer",
    "ressue": "ressuer",
    "ressuent": "ressuer",
    "ressuera": "ressuer",
    "ressuerai": "ressuer",
    "ressueraient": "ressuer",
    "ressuerais": "ressuer",
    "ressuerait": "ressuer",
    "ressueras": "ressuer",
    "ressuerez": "ressuer",
    "ressueriez": "ressuer",
    "ressuerions": "ressuer",
    "ressuerons": "ressuer",
    "ressueront": "ressuer",
    "ressues": "ressuer",
    "ressuez": "ressuer",
    "ressuie": "ressuyer",
    "ressuient": "ressuyer",
    "ressuiera": "ressuyer",
    "ressuierai": "ressuyer",
    "ressuieraient": "ressuyer",
    "ressuierais": "ressuyer",
    "ressuierait": "ressuyer",
    "ressuieras": "ressuyer",
    "ressuierez": "ressuyer",
    "ressuieriez": "ressuyer",
    "ressuierions": "ressuyer",
    "ressuierons": "ressuyer",
    "ressuieront": "ressuyer",
    "ressuies": "ressuyer",
    "ressuiez": "ressuer",
    "ressuions": "ressuer",
    "ressuons": "ressuer",
    "ressurgi": "ressurgir",
    "ressurgie": "ressurgir",
    "ressurgies": "ressurgir",
    "ressurgira": "ressurgir",
    "ressurgirai": "ressurgir",
    "ressurgiraient": "ressurgir",
    "ressurgirais": "ressurgir",
    "ressurgirait": "ressurgir",
    "ressurgiras": "ressurgir",
    "ressurgirent": "ressurgir",
    "ressurgirez": "ressurgir",
    "ressurgiriez": "ressurgir",
    "ressurgirions": "ressurgir",
    "ressurgirons": "ressurgir",
    "ressurgiront": "ressurgir",
    "ressurgis": "ressurgir",
    "ressurgissaient": "ressurgir",
    "ressurgissais": "ressurgir",
    "ressurgissait": "ressurgir",
    "ressurgissant": "ressurgir",
    "ressurgisse": "ressurgir",
    "ressurgissent": "ressurgir",
    "ressurgisses": "ressurgir",
    "ressurgissez": "ressurgir",
    "ressurgissiez": "ressurgir",
    "ressurgissions": "ressurgir",
    "ressurgissons": "ressurgir",
    "ressurgit": "ressurgir",
    "ressurgîmes": "ressurgir",
    "ressurgît": "ressurgir",
    "ressurgîtes": "ressurgir",
    "ressuscita": "ressusciter",
    "ressuscitai": "ressusciter",
    "ressuscitaient": "ressusciter",
    "ressuscitais": "ressusciter",
    "ressuscitait": "ressusciter",
    "ressuscitant": "ressusciter",
    "ressuscitas": "ressusciter",
    "ressuscitasse": "ressusciter",
    "ressuscitassent": "ressusciter",
    "ressuscitasses": "ressusciter",
    "ressuscitassiez": "ressusciter",
    "ressuscitassions": "ressusciter",
    "ressuscite": "ressusciter",
    "ressuscitent": "ressusciter",
    "ressuscitera": "ressusciter",
    "ressusciterai": "ressusciter",
    "ressusciteraient": "ressusciter",
    "ressusciterais": "ressusciter",
    "ressusciterait": "ressusciter",
    "ressusciteras": "ressusciter",
    "ressusciterez": "ressusciter",
    "ressusciteriez": "ressusciter",
    "ressusciterions": "ressusciter",
    "ressusciterons": "ressusciter",
    "ressusciteront": "ressusciter",
    "ressuscites": "ressusciter",
    "ressuscitez": "ressusciter",
    "ressuscitiez": "ressusciter",
    "ressuscitions": "ressusciter",
    "ressuscitons": "ressusciter",
    "ressuscitâmes": "ressusciter",
    "ressuscitât": "ressusciter",
    "ressuscitâtes": "ressusciter",
    "ressuscitèrent": "ressusciter",
    "ressuscité": "ressusciter",
    "ressuscitée": "ressusciter",
    "ressuscitées": "ressusciter",
    "ressuscités": "ressusciter",
    "ressuya": "ressuyer",
    "ressuyai": "ressuyer",
    "ressuyaient": "ressuyer",
    "ressuyais": "ressuyer",
    "ressuyait": "ressuyer",
    "ressuyant": "ressuyer",
    "ressuyas": "ressuyer",
    "ressuyasse": "ressuyer",
    "ressuyassent": "ressuyer",
    "ressuyasses": "ressuyer",
    "ressuyassiez": "ressuyer",
    "ressuyassions": "ressuyer",
    "ressuyez": "ressuyer",
    "ressuyiez": "ressuyer",
    "ressuyions": "ressuyer",
    "ressuyons": "ressuyer",
    "ressuyâmes": "ressuyer",
    "ressuyât": "ressuyer",
    "ressuyâtes": "ressuyer",
    "ressuyèrent": "ressuyer",
    "ressuyé": "ressuyer",
    "ressuyée": "ressuyer",
    "ressuyées": "ressuyer",
    "ressuyés": "ressuyer",
    "ressuâmes": "ressuer",
    "ressuât": "ressuer",
    "ressuâtes": "ressuer",
    "ressuèrent": "ressuer",
    "ressué": "ressuer",
    "ressème": "ressemer",
    "ressèment": "ressemer",
    "ressèmera": "ressemer",
    "ressèmerai": "ressemer",
    "ressèmeraient": "ressemer",
    "ressèmerais": "ressemer",
    "ressèmerait": "ressemer",
    "ressèmeras": "ressemer",
    "ressèmerez": "ressemer",
    "ressèmeriez": "ressemer",
    "ressèmerions": "ressemer",
    "ressèmerons": "ressemer",
    "ressèmeront": "ressemer",
    "ressèmes": "ressemer",
    "resta": "rester",
    "restai": "rester",
    "restaient": "rester",
    "restais": "rester",
    "restait": "rester",
    "restalinisations": "restalinisation",
    "restant": "rester",
    "restante": "restant",
    "restantes": "restant",
    "restants": "restant",
    "restas": "rester",
    "restasse": "rester",
    "restassent": "rester",
    "restasses": "rester",
    "restassiez": "rester",
    "restassions": "rester",
    "restaura": "restaurer",
    "restaurai": "restaurer",
    "restauraient": "restaurer",
    "restaurais": "restaurer",
    "restaurait": "restaurer",
    "restaurant": "restaurer",
    "restaurants": "restaurant",
    "restauras": "restaurer",
    "restaurasse": "restaurer",
    "restaurassent": "restaurer",
    "restaurasses": "restaurer",
    "restaurassiez": "restaurer",
    "restaurassions": "restaurer",
    "restaurateurs": "restaurateur",
    "restaurations": "restauration",
    "restauratrice": "restaurateur",
    "restaure": "restaurer",
    "restaurent": "restaurer",
    "restaurera": "restaurer",
    "restaurerai": "restaurer",
    "restaureraient": "restaurer",
    "restaurerais": "restaurer",
    "restaurerait": "restaurer",
    "restaureras": "restaurer",
    "restaurerez": "restaurer",
    "restaureriez": "restaurer",
    "restaurerions": "restaurer",
    "restaurerons": "restaurer",
    "restaureront": "restaurer",
    "restaures": "restaurer",
    "restaurez": "restaurer",
    "restauriez": "restaurer",
    "restaurions": "restaurer",
    "restaurons": "restaurer",
    "restaurâmes": "restaurer",
    "restaurât": "restaurer",
    "restaurâtes": "restaurer",
    "restaurèrent": "restaurer",
    "restauré": "restaurer",
    "restaurée": "restaurer",
    "restaurées": "restaurer",
    "restaurés": "restaurer",
    "restaus": "restau",
    "reste": "rester",
    "restent": "ruer",
    "restera": "rester",
    "resterai": "rester",
    "resteraient": "rester",
    "resterais": "rester",
    "resterait": "rester",
    "resteras": "rester",
    "resterez": "rester",
    "resteriez": "rester",
    "resterions": "rester",
    "resterons": "rester",
    "resteront": "rester",
    "restes": "rester",
    "restez": "rester",
    "restiez": "rester",
    "restions": "rester",
    "restitua": "restituer",
    "restituai": "restituer",
    "restituaient": "restituer",
    "restituais": "restituer",
    "restituait": "restituer",
    "restituant": "restituer",
    "restituas": "restituer",
    "restituasse": "restituer",
    "restituassent": "restituer",
    "restituasses": "restituer",
    "restituassiez": "restituer",
    "restituassions": "restituer",
    "restitue": "restituer",
    "restituent": "restituer",
    "restituera": "restituer",
    "restituerai": "restituer",
    "restitueraient": "restituer",
    "restituerais": "restituer",
    "restituerait": "restituer",
    "restitueras": "restituer",
    "restituerez": "restituer",
    "restitueriez": "restituer",
    "restituerions": "restituer",
    "restituerons": "restituer",
    "restitueront": "restituer",
    "restitues": "restituer",
    "restituez": "restituer",
    "restituiez": "restituer",
    "restituions": "restituer",
    "restituons": "restituer",
    "restitutions": "restitution",
    "restituâmes": "restituer",
    "restituât": "restituer",
    "restituâtes": "restituer",
    "restituèrent": "restituer",
    "restitué": "restituer",
    "restituée": "restituer",
    "restituées": "restituer",
    "restitués": "restituer",
    "restons": "rester",
    "restorations": "restoration",
    "restos": "resto",
    "restreignaient": "restreindre",
    "restreignais": "restreindre",
    "restreignait": "restreindre",
    "restreignant": "restreindre",
    "restreigne": "restreindre",
    "restreignent": "restreindre",
    "restreignes": "restreindre",
    "restreignez": "restreindre",
    "restreigniez": "restreindre",
    "restreignions": "restreindre",
    "restreignirent": "restreindre",
    "restreignis": "restreindre",
    "restreignisse": "restreindre",
    "restreignissent": "restreindre",
    "restreignisses": "restreindre",
    "restreignissiez": "restreindre",
    "restreignissions": "restreindre",
    "restreignit": "restreindre",
    "restreignons": "restreindre",
    "restreignîmes": "restreindre",
    "restreignît": "restreindre",
    "restreignîtes": "restreindre",
    "restreindra": "restreindre",
    "restreindrai": "restreindre",
    "restreindraient": "restreindre",
    "restreindrais": "restreindre",
    "restreindrait": "restreindre",
    "restreindras": "restreindre",
    "restreindrez": "restreindre",
    "restreindriez": "restreindre",
    "restreindrions": "restreindre",
    "restreindrons": "restreindre",
    "restreindront": "restreindre",
    "restreins": "restreindre",
    "restreint": "restreindre",
    "restreinte": "restreint",
    "restreintes": "restreint",
    "restreints": "restreint",
    "restrictifs": "restrictif",
    "restrictions": "restriction",
    "restrictive": "restrictif",
    "restrictives": "restrictif",
    "restructura": "restructurer",
    "restructurai": "restructurer",
    "restructuraient": "restructurer",
    "restructurais": "restructurer",
    "restructurait": "restructurer",
    "restructurant": "restructurer",
    "restructuras": "restructurer",
    "restructurasse": "restructurer",
    "restructurassent": "restructurer",
    "restructurasses": "restructurer",
    "restructurassiez": "restructurer",
    "restructurassions": "restructurer",
    "restructurations": "restructuration",
    "restructure": "restructurer",
    "restructurent": "restructurer",
    "restructurera": "restructurer",
    "restructurerai": "restructurer",
    "restructureraient": "restructurer",
    "restructurerais": "restructurer",
    "restructurerait": "restructurer",
    "restructureras": "restructurer",
    "restructurerez": "restructurer",
    "restructureriez": "restructurer",
    "restructurerions": "restructurer",
    "restructurerons": "restructurer",
    "restructureront": "restructurer",
    "restructures": "restructurer",
    "restructurez": "restructurer",
    "restructuriez": "restructurer",
    "restructurions": "restructurer",
    "restructurons": "restructurer",
    "restructurâmes": "restructurer",
    "restructurât": "restructurer",
    "restructurâtes": "restructurer",
    "restructurèrent": "restructurer",
    "restructuré": "restructurer",
    "restructurée": "restructurer",
    "restructurées": "restructurer",
    "restructurés": "restructurer",
    "restâmes": "rester",
    "restât": "rester",
    "restâtes": "rester",
    "restèrent": "rester",
    "resté": "rester",
    "restée": "rester",
    "restées": "rester",
    "restés": "rester",
    "resurgi": "resurgir",
    "resurgie": "resurgir",
    "resurgies": "resurgir",
    "resurgira": "resurgir",
    "resurgirai": "resurgir",
    "resurgiraient": "resurgir",
    "resurgirais": "resurgir",
    "resurgirait": "resurgir",
    "resurgiras": "resurgir",
    "resurgirent": "resurgir",
    "resurgirez": "resurgir",
    "resurgiriez": "resurgir",
    "resurgirions": "resurgir",
    "resurgirons": "resurgir",
    "resurgiront": "resurgir",
    "resurgis": "resurgir",
    "resurgissaient": "resurgir",
    "resurgissais": "resurgir",
    "resurgissait": "resurgir",
    "resurgissant": "resurgir",
    "resurgisse": "resurgir",
    "resurgissements": "resurgissement",
    "resurgissent": "resurgir",
    "resurgisses": "resurgir",
    "resurgissez": "resurgir",
    "resurgissiez": "resurgir",
    "resurgissions": "resurgir",
    "resurgissons": "resurgir",
    "resurgit": "resurgir",
    "resurgîmes": "resurgir",
    "resurgît": "resurgir",
    "resurgîtes": "resurgir",
    "retables": "retable",
    "retailla": "retailler",
    "retaillai": "retailler",
    "retaillaient": "retailler",
    "retaillais": "retailler",
    "retaillait": "retailler",
    "retaillant": "retailler",
    "retaillas": "retailler",
    "retaillasse": "retailler",
    "retaillassent": "retailler",
    "retaillasses": "retailler",
    "retaillassiez": "retailler",
    "retaillassions": "retailler",
    "retaille": "retailler",
    "retaillent": "retailler",
    "retaillera": "retailler",
    "retaillerai": "retailler",
    "retailleraient": "retailler",
    "retaillerais": "retailler",
    "retaillerait": "retailler",
    "retailleras": "retailler",
    "retaillerez": "retailler",
    "retailleriez": "retailler",
    "retaillerions": "retailler",
    "retaillerons": "retailler",
    "retailleront": "retailler",
    "retailles": "retailler",
    "retaillez": "retailler",
    "retailliez": "retailler",
    "retaillions": "retailler",
    "retaillons": "retailler",
    "retaillâmes": "retailler",
    "retaillât": "retailler",
    "retaillâtes": "retailler",
    "retaillèrent": "retailler",
    "retaillé": "retailler",
    "retaillée": "retailler",
    "retaillées": "retailler",
    "retaillés": "retailler",
    "retapa": "retaper",
    "retapai": "retaper",
    "retapaient": "retaper",
    "retapais": "retaper",
    "retapait": "retaper",
    "retapant": "retaper",
    "retapas": "retaper",
    "retapasse": "retaper",
    "retapassent": "retaper",
    "retapasses": "retaper",
    "retapassiez": "retaper",
    "retapassions": "retaper",
    "retape": "retaper",
    "retapent": "retaper",
    "retapera": "retaper",
    "retaperai": "retaper",
    "retaperaient": "retaper",
    "retaperais": "retaper",
    "retaperait": "retaper",
    "retaperas": "retaper",
    "retaperez": "retaper",
    "retaperiez": "retaper",
    "retaperions": "retaper",
    "retaperons": "retaper",
    "retaperont": "retaper",
    "retapes": "retaper",
    "retapez": "retaper",
    "retapiez": "retaper",
    "retapions": "retaper",
    "retapissant": "retapisser",
    "retapisse": "retapisser",
    "retapissent": "retapisser",
    "retapisserait": "retapisser",
    "retapisses": "retapisser",
    "retapissé": "retapisser",
    "retapissée": "retapisser",
    "retapissées": "retapisser",
    "retapons": "retaper",
    "retapâmes": "retaper",
    "retapât": "retaper",
    "retapâtes": "retaper",
    "retapèrent": "retaper",
    "retapé": "retaper",
    "retapée": "retaper",
    "retapées": "retaper",
    "retapés": "retaper",
    "retarda": "retarder",
    "retardai": "retarder",
    "retardaient": "retarder",
    "retardais": "retarder",
    "retardait": "retarder",
    "retardant": "retarder",
    "retardas": "retarder",
    "retardasse": "retarder",
    "retardassent": "retarder",
    "retardasses": "retarder",
    "retardassiez": "retarder",
    "retardassions": "retarder",
    "retardataires": "retardataire",
    "retardateurs": "retardateur",
    "retarde": "retarder",
    "retardements": "retardement",
    "retardent": "retarder",
    "retardera": "retarder",
    "retarderai": "retarder",
    "retarderaient": "retarder",
    "retarderais": "retarder",
    "retarderait": "retarder",
    "retarderas": "retarder",
    "retarderez": "retarder",
    "retarderiez": "retarder",
    "retarderions": "retarder",
    "retarderons": "retarder",
    "retarderont": "retarder",
    "retardes": "retarder",
    "retardez": "retarder",
    "retardiez": "retarder",
    "retardions": "retarder",
    "retardons": "retarder",
    "retards": "retard",
    "retardâmes": "retarder",
    "retardât": "retarder",
    "retardâtes": "retarder",
    "retardèrent": "retarder",
    "retardé": "retarder",
    "retardée": "retarder",
    "retardées": "retarder",
    "retardés": "retarder",
    "reteignaient": "reteindre",
    "reteignais": "reteindre",
    "reteignait": "reteindre",
    "reteignant": "reteindre",
    "reteigne": "reteindre",
    "reteignent": "reteindre",
    "reteignes": "reteindre",
    "reteignez": "reteindre",
    "reteigniez": "reteindre",
    "reteignions": "reteindre",
    "reteignirent": "reteindre",
    "reteignis": "reteindre",
    "reteignisse": "reteindre",
    "reteignissent": "reteindre",
    "reteignisses": "reteindre",
    "reteignissiez": "reteindre",
    "reteignissions": "reteindre",
    "reteignit": "reteindre",
    "reteignons": "reteindre",
    "reteignîmes": "reteindre",
    "reteignît": "reteindre",
    "reteignîtes": "reteindre",
    "reteindra": "reteindre",
    "reteindrai": "reteindre",
    "reteindraient": "reteindre",
    "reteindrais": "reteindre",
    "reteindrait": "reteindre",
    "reteindras": "reteindre",
    "reteindrez": "reteindre",
    "reteindriez": "reteindre",
    "reteindrions": "reteindre",
    "reteindrons": "reteindre",
    "reteindront": "reteindre",
    "reteins": "reteindre",
    "reteint": "reteindre",
    "reteinte": "reteindre",
    "reteintes": "reteindre",
    "reteints": "reteindre",
    "retenaient": "retenir",
    "retenais": "retenir",
    "retenait": "retenir",
    "retenant": "retenir",
    "retend": "retendre",
    "retendaient": "retendre",
    "retendais": "retendre",
    "retendait": "retendre",
    "retendant": "retendre",
    "retende": "retendre",
    "retendent": "retendre",
    "retendes": "retendre",
    "retendez": "retendre",
    "retendiez": "retendre",
    "retendions": "retendre",
    "retendirent": "retendre",
    "retendis": "retendre",
    "retendisse": "retendre",
    "retendissent": "retendre",
    "retendisses": "retendre",
    "retendissiez": "retendre",
    "retendissions": "retendre",
    "retendit": "retendre",
    "retendons": "retendre",
    "retendra": "retendre",
    "retendrai": "retendre",
    "retendraient": "retendre",
    "retendrais": "retendre",
    "retendrait": "retendre",
    "retendras": "retendre",
    "retendrez": "retendre",
    "retendriez": "retendre",
    "retendrions": "retendre",
    "retendrons": "retendre",
    "retendront": "retendre",
    "retends": "retendre",
    "retendu": "retendre",
    "retendue": "retendre",
    "retendues": "retendre",
    "retendus": "retendre",
    "retendîmes": "retendre",
    "retendît": "retendre",
    "retendîtes": "retendre",
    "retenez": "retenir",
    "reteniez": "retenir",
    "retenions": "retenir",
    "retenons": "retenir",
    "retenta": "retenter",
    "retentai": "retenter",
    "retentaient": "retenter",
    "retentais": "retenter",
    "retentait": "retenter",
    "retentant": "retenter",
    "retentas": "retenter",
    "retentasse": "retenter",
    "retentassent": "retenter",
    "retentasses": "retenter",
    "retentassiez": "retenter",
    "retentassions": "retenter",
    "retente": "retenter",
    "retentent": "retenter",
    "retentera": "retenter",
    "retenterai": "retenter",
    "retenteraient": "retenter",
    "retenterais": "retenter",
    "retenterait": "retenter",
    "retenteras": "retenter",
    "retenterez": "retenter",
    "retenteriez": "retenter",
    "retenterions": "retenter",
    "retenterons": "retenter",
    "retenteront": "retenter",
    "retentes": "retenter",
    "retentez": "retenter",
    "retenti": "retentir",
    "retentiez": "retenter",
    "retentions": "retenter",
    "retentira": "retentir",
    "retentirai": "retentir",
    "retentiraient": "retentir",
    "retentirais": "retentir",
    "retentirait": "retentir",
    "retentiras": "retentir",
    "retentirent": "retentir",
    "retentirez": "retentir",
    "retentiriez": "retentir",
    "retentirions": "retentir",
    "retentirons": "retentir",
    "retentiront": "retentir",
    "retentis": "retentir",
    "retentissaient": "retentir",
    "retentissais": "retentir",
    "retentissait": "retentir",
    "retentissant": "retentir",
    "retentissante": "retentissant",
    "retentissantes": "retentissant",
    "retentissants": "retentissant",
    "retentisse": "retentir",
    "retentissements": "retentissement",
    "retentissent": "retentir",
    "retentisses": "retentir",
    "retentissez": "retentir",
    "retentissiez": "retentir",
    "retentissions": "retentir",
    "retentissons": "retentir",
    "retentit": "retentir",
    "retentons": "retenter",
    "retentâmes": "retenter",
    "retentât": "retenter",
    "retentâtes": "retenter",
    "retentèrent": "retenter",
    "retenté": "retenter",
    "retentée": "retenter",
    "retentées": "retenter",
    "retentés": "retenter",
    "retentîmes": "retentir",
    "retentît": "retentir",
    "retentîtes": "retentir",
    "retenu": "retenir",
    "retenue": "retenu",
    "retenues": "retenue",
    "retenus": "retenu",
    "retiendra": "retenir",
    "retiendrai": "retenir",
    "retiendraient": "retenir",
    "retiendrais": "retenir",
    "retiendrait": "retenir",
    "retiendras": "retenir",
    "retiendrez": "retenir",
    "retiendriez": "retenir",
    "retiendrions": "retenir",
    "retiendrons": "retenir",
    "retiendront": "retenir",
    "retienne": "retenir",
    "retiennent": "retenir",
    "retiennes": "retenir",
    "retiens": "retenir",
    "retient": "retenir",
    "retinrent": "retenir",
    "retins": "retenir",
    "retinsse": "retenir",
    "retinssent": "retenir",
    "retinsses": "retenir",
    "retinssiez": "retenir",
    "retinssions": "retenir",
    "retint": "retenir",
    "retira": "retirer",
    "retirages": "retirage",
    "retirai": "retirer",
    "retiraient": "retirer",
    "retirais": "retirer",
    "retirait": "retirer",
    "retirant": "retirer",
    "retiras": "retirer",
    "retirasse": "retirer",
    "retirassent": "retirer",
    "retirasses": "retirer",
    "retirassiez": "retirer",
    "retirassions": "retirer",
    "retire": "retirer",
    "retirent": "retirer",
    "retirera": "retirer",
    "retirerai": "retirer",
    "retireraient": "retirer",
    "retirerais": "retirer",
    "retirerait": "retirer",
    "retireras": "retirer",
    "retirerez": "retirer",
    "retireriez": "retirer",
    "retirerions": "retirer",
    "retirerons": "retirer",
    "retireront": "retirer",
    "retires": "retirer",
    "retirez": "retirer",
    "retiriez": "retirer",
    "retirions": "retirer",
    "retirons": "retirer",
    "retirâmes": "retirer",
    "retirât": "retirer",
    "retirâtes": "retirer",
    "retirèrent": "retirer",
    "retiré": "retirer",
    "retirée": "retirer",
    "retirées": "retirer",
    "retirés": "retirer",
    "retissa": "retisser",
    "retissai": "retisser",
    "retissaient": "retisser",
    "retissais": "retisser",
    "retissait": "retisser",
    "retissant": "retisser",
    "retissas": "retisser",
    "retissasse": "retisser",
    "retissassent": "retisser",
    "retissasses": "retisser",
    "retissassiez": "retisser",
    "retissassions": "retisser",
    "retisse": "retisser",
    "retissent": "retisser",
    "retissera": "retisser",
    "retisserai": "retisser",
    "retisseraient": "retisser",
    "retisserais": "retisser",
    "retisserait": "retisser",
    "retisseras": "retisser",
    "retisserez": "retisser",
    "retisseriez": "retisser",
    "retisserions": "retisser",
    "retisserons": "retisser",
    "retisseront": "retisser",
    "retisses": "retisser",
    "retissez": "retisser",
    "retissiez": "retisser",
    "retissions": "retisser",
    "retissons": "retisser",
    "retissâmes": "retisser",
    "retissât": "retisser",
    "retissâtes": "retisser",
    "retissèrent": "retisser",
    "retissé": "retisser",
    "retissée": "retisser",
    "retissées": "retisser",
    "retissés": "retisser",
    "retomba": "retomber",
    "retombai": "retomber",
    "retombaient": "retomber",
    "retombais": "retomber",
    "retombait": "retomber",
    "retombant": "retomber",
    "retombante": "retombant",
    "retombantes": "retombant",
    "retombas": "retomber",
    "retombasse": "retomber",
    "retombassent": "retomber",
    "retombasses": "retomber",
    "retombassiez": "retomber",
    "retombassions": "retomber",
    "retombe": "retomber",
    "retombent": "retomber",
    "retombera": "retomber",
    "retomberai": "retomber",
    "retomberaient": "retomber",
    "retomberais": "retomber",
    "retomberait": "retomber",
    "retomberas": "retomber",
    "retomberez": "retomber",
    "retomberiez": "retomber",
    "retomberions": "retomber",
    "retomberons": "retomber",
    "retomberont": "retomber",
    "retombes": "retomber",
    "retombez": "retomber",
    "retombiez": "retomber",
    "retombions": "retomber",
    "retombons": "retomber",
    "retombâmes": "retomber",
    "retombât": "retomber",
    "retombâtes": "retomber",
    "retombèrent": "retomber",
    "retombé": "retomber",
    "retombée": "retomber",
    "retombées": "retomber",
    "retombés": "retomber",
    "retond": "retondre",
    "retondaient": "retondre",
    "retondais": "retondre",
    "retondait": "retondre",
    "retondant": "retondre",
    "retonde": "retondre",
    "retondent": "retondre",
    "retondes": "retondre",
    "retondez": "retondre",
    "retondiez": "retondre",
    "retondions": "retondre",
    "retondirent": "retondre",
    "retondis": "retondre",
    "retondisse": "retondre",
    "retondissent": "retondre",
    "retondisses": "retondre",
    "retondissiez": "retondre",
    "retondissions": "retondre",
    "retondit": "retondre",
    "retondons": "retondre",
    "retondra": "retondre",
    "retondrai": "retondre",
    "retondraient": "retondre",
    "retondrais": "retondre",
    "retondrait": "retondre",
    "retondras": "retondre",
    "retondrez": "retondre",
    "retondriez": "retondre",
    "retondrions": "retondre",
    "retondrons": "retondre",
    "retondront": "retondre",
    "retonds": "retondre",
    "retondu": "retondre",
    "retondue": "retondre",
    "retondues": "retondre",
    "retondus": "retondre",
    "retondîmes": "retondre",
    "retondît": "retondre",
    "retondîtes": "retondre",
    "retord": "retordre",
    "retordaient": "retordre",
    "retordais": "retordre",
    "retordait": "retordre",
    "retordant": "retordre",
    "retorde": "retordre",
    "retordent": "retordre",
    "retordes": "retordre",
    "retordez": "retordre",
    "retordiez": "retordre",
    "retordions": "retordre",
    "retordirent": "retordre",
    "retordis": "retordre",
    "retordisse": "retordre",
    "retordissent": "retordre",
    "retordisses": "retordre",
    "retordissiez": "retordre",
    "retordissions": "retordre",
    "retordit": "retordre",
    "retordons": "retordre",
    "retordra": "retordre",
    "retordrai": "retordre",
    "retordraient": "retordre",
    "retordrais": "retordre",
    "retordrait": "retordre",
    "retordras": "retordre",
    "retordrez": "retordre",
    "retordriez": "retordre",
    "retordrions": "retordre",
    "retordrons": "retordre",
    "retordront": "retordre",
    "retords": "retordre",
    "retordu": "retordre",
    "retordue": "retordre",
    "retordues": "retordre",
    "retordus": "retordre",
    "retordîmes": "retordre",
    "retordît": "retordre",
    "retordîtes": "retordre",
    "retorse": "retors",
    "retorses": "retors",
    "retorss": "retors",
    "retoucha": "retoucher",
    "retouchai": "retoucher",
    "retouchaient": "retoucher",
    "retouchais": "retoucher",
    "retouchait": "retoucher",
    "retouchant": "retoucher",
    "retouchas": "retoucher",
    "retouchasse": "retoucher",
    "retouchassent": "retoucher",
    "retouchasses": "retoucher",
    "retouchassiez": "retoucher",
    "retouchassions": "retoucher",
    "retouche": "retoucher",
    "retouchent": "retoucher",
    "retouchera": "retoucher",
    "retoucherai": "retoucher",
    "retoucheraient": "retoucher",
    "retoucherais": "retoucher",
    "retoucherait": "retoucher",
    "retoucheras": "retoucher",
    "retoucherez": "retoucher",
    "retoucheriez": "retoucher",
    "retoucherions": "retoucher",
    "retoucherons": "retoucher",
    "retoucheront": "retoucher",
    "retouches": "retoucher",
    "retouchez": "retoucher",
    "retouchiez": "retoucher",
    "retouchions": "retoucher",
    "retouchons": "retoucher",
    "retouchâmes": "retoucher",
    "retouchât": "retoucher",
    "retouchâtes": "retoucher",
    "retouchèrent": "retoucher",
    "retouché": "retoucher",
    "retouchée": "retoucher",
    "retouchées": "retoucher",
    "retouchés": "retoucher",
    "retourna": "retourner",
    "retournai": "retourner",
    "retournaient": "retourner",
    "retournais": "retourner",
    "retournait": "retourner",
    "retournant": "retourner",
    "retournas": "retourner",
    "retournasse": "retourner",
    "retournassent": "retourner",
    "retournasses": "retourner",
    "retournassiez": "retourner",
    "retournassions": "retourner",
    "retourne": "retourner",
    "retournements": "retournement",
    "retournent": "retourner",
    "retournera": "retourner",
    "retournerai": "retourner",
    "retourneraient": "retourner",
    "retournerais": "retourner",
    "retournerait": "retourner",
    "retourneras": "retourner",
    "retournerez": "retourner",
    "retourneriez": "retourner",
    "retournerions": "retourner",
    "retournerons": "retourner",
    "retourneront": "retourner",
    "retournes": "retourner",
    "retournez": "retourner",
    "retourniez": "retourner",
    "retournions": "retourner",
    "retournons": "retourner",
    "retournâmes": "retourner",
    "retournât": "retourner",
    "retournâtes": "retourner",
    "retournèrent": "retourner",
    "retourné": "retourner",
    "retournée": "retourner",
    "retournées": "retourner",
    "retournés": "retourner",
    "retours": "retour",
    "retrace": "retracer",
    "retracent": "retracer",
    "retracera": "retracer",
    "retracerai": "retracer",
    "retraceraient": "retracer",
    "retracerais": "retracer",
    "retracerait": "retracer",
    "retraceras": "retracer",
    "retracerez": "retracer",
    "retraceriez": "retracer",
    "retracerions": "retracer",
    "retracerons": "retracer",
    "retraceront": "retracer",
    "retraces": "retracer",
    "retracez": "retracer",
    "retraciez": "retracer",
    "retracions": "retracer",
    "retracèrent": "retracer",
    "retracé": "retracer",
    "retracée": "retracer",
    "retracées": "retracer",
    "retracés": "retracer",
    "retraduira": "retraduire",
    "retraduirai": "retraduire",
    "retraduiraient": "retraduire",
    "retraduirais": "retraduire",
    "retraduirait": "retraduire",
    "retraduiras": "retraduire",
    "retraduirez": "retraduire",
    "retraduiriez": "retraduire",
    "retraduirions": "retraduire",
    "retraduirons": "retraduire",
    "retraduiront": "retraduire",
    "retraduis": "retraduire",
    "retraduisaient": "retraduire",
    "retraduisais": "retraduire",
    "retraduisait": "retraduire",
    "retraduisant": "retraduire",
    "retraduise": "retraduire",
    "retraduisent": "retraduire",
    "retraduises": "retraduire",
    "retraduisez": "retraduire",
    "retraduisiez": "retraduire",
    "retraduisions": "retraduire",
    "retraduisirent": "retraduire",
    "retraduisis": "retraduire",
    "retraduisisse": "retraduire",
    "retraduisissent": "retraduire",
    "retraduisisses": "retraduire",
    "retraduisissiez": "retraduire",
    "retraduisissions": "retraduire",
    "retraduisit": "retraduire",
    "retraduisons": "retraduire",
    "retraduisîmes": "retraduire",
    "retraduisît": "retraduire",
    "retraduisîtes": "retraduire",
    "retraduit": "retraduire",
    "retraduite": "retraduire",
    "retraduites": "retraduire",
    "retraduits": "retraduire",
    "retraie": "retraire",
    "retraient": "retraire",
    "retraies": "retraire",
    "retraira": "retraire",
    "retrairai": "retraire",
    "retrairaient": "retraire",
    "retrairais": "retraire",
    "retrairait": "retraire",
    "retrairas": "retraire",
    "retrairez": "retraire",
    "retrairiez": "retraire",
    "retrairions": "retraire",
    "retrairons": "retraire",
    "retrairont": "retraire",
    "retrais": "retraire",
    "retrait": "retraire",
    "retraita": "retraiter",
    "retraitai": "retraiter",
    "retraitaient": "retraiter",
    "retraitais": "retraiter",
    "retraitait": "retraiter",
    "retraitant": "retraiter",
    "retraitas": "retraiter",
    "retraitasse": "retraiter",
    "retraitassent": "retraiter",
    "retraitasses": "retraiter",
    "retraitassiez": "retraiter",
    "retraitassions": "retraiter",
    "retraite": "retraiter",
    "retraitements": "retraitement",
    "retraitent": "retraiter",
    "retraitera": "retraiter",
    "retraiterai": "retraiter",
    "retraiteraient": "retraiter",
    "retraiterais": "retraiter",
    "retraiterait": "retraiter",
    "retraiteras": "retraiter",
    "retraiterez": "retraiter",
    "retraiteriez": "retraiter",
    "retraiterions": "retraiter",
    "retraiterons": "retraiter",
    "retraiteront": "retraiter",
    "retraites": "retraiter",
    "retraitez": "retraiter",
    "retraitiez": "retraiter",
    "retraitions": "retraiter",
    "retraitons": "retraiter",
    "retraits": "retrait",
    "retraitâmes": "retraiter",
    "retraitât": "retraiter",
    "retraitâtes": "retraiter",
    "retraitèrent": "retraiter",
    "retraité": "retraiter",
    "retraitée": "retraiter",
    "retraitées": "retraiter",
    "retraités": "retraiter",
    "retrancha": "retrancher",
    "retranchai": "retrancher",
    "retranchaient": "retrancher",
    "retranchais": "retrancher",
    "retranchait": "retrancher",
    "retranchant": "retrancher",
    "retranchas": "retrancher",
    "retranchasse": "retrancher",
    "retranchassent": "retrancher",
    "retranchasses": "retrancher",
    "retranchassiez": "retrancher",
    "retranchassions": "retrancher",
    "retranche": "retrancher",
    "retranchements": "retranchement",
    "retranchent": "retrancher",
    "retranchera": "retrancher",
    "retrancherai": "retrancher",
    "retrancheraient": "retrancher",
    "retrancherais": "retrancher",
    "retrancherait": "retrancher",
    "retrancheras": "retrancher",
    "retrancherez": "retrancher",
    "retrancheriez": "retrancher",
    "retrancherions": "retrancher",
    "retrancherons": "retrancher",
    "retrancheront": "retrancher",
    "retranches": "retrancher",
    "retranchez": "retrancher",
    "retranchiez": "retrancher",
    "retranchions": "retrancher",
    "retranchons": "retrancher",
    "retranchâmes": "retrancher",
    "retranchât": "retrancher",
    "retranchâtes": "retrancher",
    "retranchèrent": "retrancher",
    "retranché": "retrancher",
    "retranchée": "retrancher",
    "retranchées": "retrancher",
    "retranchés": "retrancher",
    "retranscriptions": "retranscription",
    "retranscrira": "retranscrire",
    "retranscrirai": "retranscrire",
    "retranscriraient": "retranscrire",
    "retranscrirais": "retranscrire",
    "retranscrirait": "retranscrire",
    "retranscriras": "retranscrire",
    "retranscrirez": "retranscrire",
    "retranscririez": "retranscrire",
    "retranscririons": "retranscrire",
    "retranscrirons": "retranscrire",
    "retranscriront": "retranscrire",
    "retranscris": "retranscrire",
    "retranscrit": "retranscrire",
    "retranscrite": "retranscrire",
    "retranscrites": "retranscrire",
    "retranscrits": "retranscrire",
    "retranscrivaient": "retranscrire",
    "retranscrivais": "retranscrire",
    "retranscrivait": "retranscrire",
    "retranscrivant": "retranscrire",
    "retranscrive": "retranscrire",
    "retranscrivent": "retranscrire",
    "retranscrives": "retranscrire",
    "retranscrivez": "retranscrire",
    "retranscriviez": "retranscrire",
    "retranscrivions": "retranscrire",
    "retranscrivirent": "retranscrire",
    "retranscrivis": "retranscrire",
    "retranscrivisse": "retranscrire",
    "retranscrivissent": "retranscrire",
    "retranscrivisses": "retranscrire",
    "retranscrivissiez": "retranscrire",
    "retranscrivissions": "retranscrire",
    "retranscrivit": "retranscrire",
    "retranscrivons": "retranscrire",
    "retranscrivîmes": "retranscrire",
    "retranscrivît": "retranscrire",
    "retranscrivîtes": "retranscrire",
    "retransforme": "retransformer",
    "retransformera": "retransformer",
    "retransmet": "retransmettre",
    "retransmets": "retransmettre",
    "retransmettaient": "retransmettre",
    "retransmettais": "retransmettre",
    "retransmettait": "retransmettre",
    "retransmettant": "retransmettre",
    "retransmette": "retransmettre",
    "retransmettent": "retransmettre",
    "retransmettes": "retransmettre",
    "retransmettez": "retransmettre",
    "retransmettiez": "retransmettre",
    "retransmettions": "retransmettre",
    "retransmettons": "retransmettre",
    "retransmettra": "retransmettre",
    "retransmettrai": "retransmettre",
    "retransmettraient": "retransmettre",
    "retransmettrais": "retransmettre",
    "retransmettrait": "retransmettre",
    "retransmettras": "retransmettre",
    "retransmettrez": "retransmettre",
    "retransmettriez": "retransmettre",
    "retransmettrions": "retransmettre",
    "retransmettrons": "retransmettre",
    "retransmettront": "retransmettre",
    "retransmirent": "retransmettre",
    "retransmis": "retransmettre",
    "retransmise": "retransmettre",
    "retransmises": "retransmettre",
    "retransmisse": "retransmettre",
    "retransmissent": "retransmettre",
    "retransmisses": "retransmettre",
    "retransmissiez": "retransmettre",
    "retransmissions": "retransmission",
    "retransmit": "retransmettre",
    "retransmîmes": "retransmettre",
    "retransmît": "retransmettre",
    "retransmîtes": "retransmettre",
    "retravailla": "retravailler",
    "retravaillai": "retravailler",
    "retravaillaient": "retravailler",
    "retravaillais": "retravailler",
    "retravaillait": "retravailler",
    "retravaillant": "retravailler",
    "retravaillas": "retravailler",
    "retravaillasse": "retravailler",
    "retravaillassent": "retravailler",
    "retravaillasses": "retravailler",
    "retravaillassiez": "retravailler",
    "retravaillassions": "retravailler",
    "retravaille": "retravailler",
    "retravaillent": "retravailler",
    "retravaillera": "retravailler",
    "retravaillerai": "retravailler",
    "retravailleraient": "retravailler",
    "retravaillerais": "retravailler",
    "retravaillerait": "retravailler",
    "retravailleras": "retravailler",
    "retravaillerez": "retravailler",
    "retravailleriez": "retravailler",
    "retravaillerions": "retravailler",
    "retravaillerons": "retravailler",
    "retravailleront": "retravailler",
    "retravailles": "retravailler",
    "retravaillez": "retravailler",
    "retravailliez": "retravailler",
    "retravaillions": "retravailler",
    "retravaillons": "retravailler",
    "retravaillâmes": "retravailler",
    "retravaillât": "retravailler",
    "retravaillâtes": "retravailler",
    "retravaillèrent": "retravailler",
    "retravaillé": "retravailler",
    "retravaillée": "retravailler",
    "retravaillées": "retravailler",
    "retravaillés": "retravailler",
    "retraversa": "retraverser",
    "retraversai": "retraverser",
    "retraversaient": "retraverser",
    "retraversais": "retraverser",
    "retraversait": "retraverser",
    "retraversant": "retraverser",
    "retraversas": "retraverser",
    "retraversasse": "retraverser",
    "retraversassent": "retraverser",
    "retraversasses": "retraverser",
    "retraversassiez": "retraverser",
    "retraversassions": "retraverser",
    "retraverse": "retraverser",
    "retraversent": "retraverser",
    "retraversera": "retraverser",
    "retraverserai": "retraverser",
    "retraverseraient": "retraverser",
    "retraverserais": "retraverser",
    "retraverserait": "retraverser",
    "retraverseras": "retraverser",
    "retraverserez": "retraverser",
    "retraverseriez": "retraverser",
    "retraverserions": "retraverser",
    "retraverserons": "retraverser",
    "retraverseront": "retraverser",
    "retraverses": "retraverser",
    "retraversez": "retraverser",
    "retraversiez": "retraverser",
    "retraversions": "retraverser",
    "retraversons": "retraverser",
    "retraversâmes": "retraverser",
    "retraversât": "retraverser",
    "retraversâtes": "retraverser",
    "retraversèrent": "retraverser",
    "retraversé": "retraverser",
    "retraversée": "retraverser",
    "retraversées": "retraverser",
    "retraversés": "retraverser",
    "retrayaient": "retraire",
    "retrayais": "retraire",
    "retrayait": "retraire",
    "retrayant": "retraire",
    "retrayez": "retraire",
    "retrayiez": "retraire",
    "retrayions": "retraire",
    "retrayons": "retraire",
    "retraça": "retracer",
    "retraçai": "retracer",
    "retraçaient": "retracer",
    "retraçais": "retracer",
    "retraçait": "retracer",
    "retraçant": "retracer",
    "retraças": "retracer",
    "retraçasse": "retracer",
    "retraçassent": "retracer",
    "retraçasses": "retracer",
    "retraçassiez": "retracer",
    "retraçassions": "retracer",
    "retraçons": "retracer",
    "retraçâmes": "retracer",
    "retraçât": "retracer",
    "retraçâtes": "retracer",
    "retrempa": "retremper",
    "retrempai": "retremper",
    "retrempaient": "retremper",
    "retrempais": "retremper",
    "retrempait": "retremper",
    "retrempant": "retremper",
    "retrempas": "retremper",
    "retrempasse": "retremper",
    "retrempassent": "retremper",
    "retrempasses": "retremper",
    "retrempassiez": "retremper",
    "retrempassions": "retremper",
    "retrempe": "retremper",
    "retrempent": "retremper",
    "retrempera": "retremper",
    "retremperai": "retremper",
    "retremperaient": "retremper",
    "retremperais": "retremper",
    "retremperait": "retremper",
    "retremperas": "retremper",
    "retremperez": "retremper",
    "retremperiez": "retremper",
    "retremperions": "retremper",
    "retremperons": "retremper",
    "retremperont": "retremper",
    "retrempes": "retremper",
    "retrempez": "retremper",
    "retrempiez": "retremper",
    "retrempions": "retremper",
    "retrempons": "retremper",
    "retrempâmes": "retremper",
    "retrempât": "retremper",
    "retrempâtes": "retremper",
    "retrempèrent": "retremper",
    "retrempé": "retremper",
    "retrempée": "retremper",
    "retrempées": "retremper",
    "retrempés": "retremper",
    "retroussa": "retrousser",
    "retroussai": "retrousser",
    "retroussaient": "retrousser",
    "retroussais": "retrousser",
    "retroussait": "retrousser",
    "retroussant": "retrousser",
    "retroussas": "retrousser",
    "retroussasse": "retrousser",
    "retroussassent": "retrousser",
    "retroussasses": "retrousser",
    "retroussassiez": "retrousser",
    "retroussassions": "retrousser",
    "retrousse": "retrousser",
    "retroussent": "retrousser",
    "retroussera": "retrousser",
    "retrousserai": "retrousser",
    "retrousseraient": "retrousser",
    "retrousserais": "retrousser",
    "retrousserait": "retrousser",
    "retrousseras": "retrousser",
    "retrousserez": "retrousser",
    "retrousseriez": "retrousser",
    "retrousserions": "retrousser",
    "retrousserons": "retrousser",
    "retrousseront": "retrousser",
    "retrousses": "retrousser",
    "retroussez": "retrousser",
    "retroussiez": "retrousser",
    "retroussions": "retrousser",
    "retroussons": "retrousser",
    "retroussâmes": "retrousser",
    "retroussât": "retrousser",
    "retroussâtes": "retrousser",
    "retroussèrent": "retrousser",
    "retroussé": "retrousser",
    "retroussée": "retrousser",
    "retroussées": "retrousser",
    "retroussés": "retrousser",
    "retrouva": "retrouver",
    "retrouvai": "retrouver",
    "retrouvaient": "retrouver",
    "retrouvailles": "retrouvaille",
    "retrouvais": "retrouver",
    "retrouvait": "retrouver",
    "retrouvant": "retrouver",
    "retrouvas": "retrouver",
    "retrouvasse": "retrouver",
    "retrouvassent": "retrouver",
    "retrouvasses": "retrouver",
    "retrouvassiez": "retrouver",
    "retrouvassions": "retrouver",
    "retrouve": "retrouver",
    "retrouvent": "retrouver",
    "retrouvera": "retrouver",
    "retrouverai": "retrouver",
    "retrouveraient": "retrouver",
    "retrouverais": "retrouver",
    "retrouverait": "retrouver",
    "retrouveras": "retrouver",
    "retrouverez": "retrouver",
    "retrouveriez": "retrouver",
    "retrouverions": "retrouver",
    "retrouverons": "retrouver",
    "retrouveront": "retrouver",
    "retrouves": "retrouver",
    "retrouvez": "retrouver",
    "retrouviez": "retrouver",
    "retrouvions": "retrouver",
    "retrouvons": "retrouver",
    "retrouvâmes": "retrouver",
    "retrouvât": "retrouver",
    "retrouvâtes": "retrouver",
    "retrouvèrent": "retrouver",
    "retrouvé": "retrouver",
    "retrouvée": "retrouver",
    "retrouvées": "retrouver",
    "retrouvés": "retrouver",
    "retâta": "retâter",
    "retâtai": "retâter",
    "retâtaient": "retâter",
    "retâtais": "retâter",
    "retâtait": "retâter",
    "retâtant": "retâter",
    "retâtas": "retâter",
    "retâtasse": "retâter",
    "retâtassent": "retâter",
    "retâtasses": "retâter",
    "retâtassiez": "retâter",
    "retâtassions": "retâter",
    "retâte": "retâter",
    "retâtent": "retâter",
    "retâtera": "retâter",
    "retâterai": "retâter",
    "retâteraient": "retâter",
    "retâterais": "retâter",
    "retâterait": "retâter",
    "retâteras": "retâter",
    "retâterez": "retâter",
    "retâteriez": "retâter",
    "retâterions": "retâter",
    "retâterons": "retâter",
    "retâteront": "retâter",
    "retâtes": "retâter",
    "retâtez": "retâter",
    "retâtiez": "retâter",
    "retâtions": "retâter",
    "retâtons": "retâter",
    "retâtâmes": "retâter",
    "retâtât": "retâter",
    "retâtâtes": "retâter",
    "retâtèrent": "retâter",
    "retâté": "retâter",
    "retâtée": "retâter",
    "retâtées": "retâter",
    "retâtés": "retâter",
    "retéléphone": "retéléphoner",
    "retînmes": "retenir",
    "retînt": "retenir",
    "retîntes": "retenir",
    "reubeus": "reubeu",
    "reutilisations": "reutilisation",
    "revaccina": "revacciner",
    "revaccinai": "revacciner",
    "revaccinaient": "revacciner",
    "revaccinais": "revacciner",
    "revaccinait": "revacciner",
    "revaccinant": "revacciner",
    "revaccinas": "revacciner",
    "revaccinasse": "revacciner",
    "revaccinassent": "revacciner",
    "revaccinasses": "revacciner",
    "revaccinassiez": "revacciner",
    "revaccinassions": "revacciner",
    "revaccinations": "revaccination",
    "revaccine": "revacciner",
    "revaccinent": "revacciner",
    "revaccinera": "revacciner",
    "revaccinerai": "revacciner",
    "revaccineraient": "revacciner",
    "revaccinerais": "revacciner",
    "revaccinerait": "revacciner",
    "revaccineras": "revacciner",
    "revaccinerez": "revacciner",
    "revaccineriez": "revacciner",
    "revaccinerions": "revacciner",
    "revaccinerons": "revacciner",
    "revaccineront": "revacciner",
    "revaccines": "revacciner",
    "revaccinez": "revacciner",
    "revacciniez": "revacciner",
    "revaccinions": "revacciner",
    "revaccinons": "revacciner",
    "revaccinâmes": "revacciner",
    "revaccinât": "revacciner",
    "revaccinâtes": "revacciner",
    "revaccinèrent": "revacciner",
    "revacciné": "revacciner",
    "revaccinée": "revacciner",
    "revaccinées": "revacciner",
    "revaccinés": "revacciner",
    "revaille": "revaloir",
    "revaillent": "revaloir",
    "revailles": "revaloir",
    "revalaient": "revaloir",
    "revalais": "revaloir",
    "revalait": "revaloir",
    "revalant": "revaloir",
    "revalent": "revaloir",
    "revalez": "revaloir",
    "revaliez": "revaloir",
    "revalions": "revaloir",
    "revalons": "revaloir",
    "revalorisa": "revaloriser",
    "revalorisai": "revaloriser",
    "revalorisaient": "revaloriser",
    "revalorisais": "revaloriser",
    "revalorisait": "revaloriser",
    "revalorisant": "revaloriser",
    "revalorisas": "revaloriser",
    "revalorisasse": "revaloriser",
    "revalorisassent": "revaloriser",
    "revalorisasses": "revaloriser",
    "revalorisassiez": "revaloriser",
    "revalorisassions": "revaloriser",
    "revalorisations": "revalorisation",
    "revalorise": "revaloriser",
    "revalorisent": "revaloriser",
    "revalorisera": "revaloriser",
    "revaloriserai": "revaloriser",
    "revaloriseraient": "revaloriser",
    "revaloriserais": "revaloriser",
    "revaloriserait": "revaloriser",
    "revaloriseras": "revaloriser",
    "revaloriserez": "revaloriser",
    "revaloriseriez": "revaloriser",
    "revaloriserions": "revaloriser",
    "revaloriserons": "revaloriser",
    "revaloriseront": "revaloriser",
    "revalorises": "revaloriser",
    "revalorisez": "revaloriser",
    "revalorisiez": "revaloriser",
    "revalorisions": "revaloriser",
    "revalorisons": "revaloriser",
    "revalorisâmes": "revaloriser",
    "revalorisât": "revaloriser",
    "revalorisâtes": "revaloriser",
    "revalorisèrent": "revaloriser",
    "revalorisé": "revaloriser",
    "revalorisée": "revaloriser",
    "revalorisées": "revaloriser",
    "revalorisés": "revaloriser",
    "revalu": "revaloir",
    "revalue": "revaloir",
    "revalues": "revaloir",
    "revalurent": "revaloir",
    "revalus": "revaloir",
    "revalusse": "revaloir",
    "revalussent": "revaloir",
    "revalusses": "revaloir",
    "revalussiez": "revaloir",
    "revalussions": "revaloir",
    "revalut": "revaloir",
    "revalûmes": "revaloir",
    "revalût": "revaloir",
    "revalûtes": "revaloir",
    "revancha": "revancher",
    "revanchaient": "revancher",
    "revancharde": "revanchard",
    "revanchardes": "revanchard",
    "revanchards": "revanchard",
    "revanchent": "revancher",
    "revanches": "revanche",
    "revanchismes": "revanchisme",
    "revaudra": "revaloir",
    "revaudrai": "revaloir",
    "revaudraient": "revaloir",
    "revaudrais": "revaloir",
    "revaudrait": "revaloir",
    "revaudras": "revaloir",
    "revaudrez": "revaloir",
    "revaudriez": "revaloir",
    "revaudrions": "revaloir",
    "revaudrons": "revaloir",
    "revaudront": "revaloir",
    "revaut": "revaloir",
    "revaux": "revaloir",
    "revenaient": "revenir",
    "revenais": "revenir",
    "revenait": "revenir",
    "revenant": "revenir",
    "revenante": "revenant",
    "revenantes": "revenant",
    "revenants": "revenant",
    "revend": "revendre",
    "revendaient": "revendre",
    "revendais": "revendre",
    "revendait": "revendre",
    "revendant": "revendre",
    "revende": "revendre",
    "revendent": "revendre",
    "revendes": "revendre",
    "revendeurs": "revendeur",
    "revendeuse": "revendeur",
    "revendeuses": "revendeur",
    "revendez": "revendre",
    "revendicateurs": "revendicateur",
    "revendicatifs": "revendicatif",
    "revendications": "revendication",
    "revendicative": "revendicatif",
    "revendicatives": "revendicatif",
    "revendicatrice": "revendicateur",
    "revendicatrices": "revendicateur",
    "revendiez": "revendre",
    "revendions": "revendre",
    "revendiqua": "revendiquer",
    "revendiquai": "revendiquer",
    "revendiquaient": "revendiquer",
    "revendiquais": "revendiquer",
    "revendiquait": "revendiquer",
    "revendiquant": "revendiquer",
    "revendiquas": "revendiquer",
    "revendiquasse": "revendiquer",
    "revendiquassent": "revendiquer",
    "revendiquasses": "revendiquer",
    "revendiquassiez": "revendiquer",
    "revendiquassions": "revendiquer",
    "revendique": "revendiquer",
    "revendiquent": "revendiquer",
    "revendiquera": "revendiquer",
    "revendiquerai": "revendiquer",
    "revendiqueraient": "revendiquer",
    "revendiquerais": "revendiquer",
    "revendiquerait": "revendiquer",
    "revendiqueras": "revendiquer",
    "revendiquerez": "revendiquer",
    "revendiqueriez": "revendiquer",
    "revendiquerions": "revendiquer",
    "revendiquerons": "revendiquer",
    "revendiqueront": "revendiquer",
    "revendiques": "revendiquer",
    "revendiquez": "revendiquer",
    "revendiquiez": "revendiquer",
    "revendiquions": "revendiquer",
    "revendiquons": "revendiquer",
    "revendiquâmes": "revendiquer",
    "revendiquât": "revendiquer",
    "revendiquâtes": "revendiquer",
    "revendiquèrent": "revendiquer",
    "revendiqué": "revendiquer",
    "revendiquée": "revendiquer",
    "revendiquées": "revendiquer",
    "revendiqués": "revendiquer",
    "revendirent": "revendre",
    "revendis": "revendre",
    "revendisse": "revendre",
    "revendissent": "revendre",
    "revendisses": "revendre",
    "revendissiez": "revendre",
    "revendissions": "revendre",
    "revendit": "revendre",
    "revendons": "revendre",
    "revendra": "revendre",
    "revendrai": "revendre",
    "revendraient": "revendre",
    "revendrais": "revendre",
    "revendrait": "revendre",
    "revendras": "revendre",
    "revendrez": "revendre",
    "revendriez": "revendre",
    "revendrions": "revendre",
    "revendrons": "revendre",
    "revendront": "revendre",
    "revends": "revendre",
    "revendu": "revendre",
    "revendue": "revendre",
    "revendues": "revendre",
    "revendus": "revendre",
    "revendîmes": "revendre",
    "revendît": "revendre",
    "revendîtes": "revendre",
    "revenez": "revenir",
    "reveniez": "revenir",
    "revenions": "revenir",
    "revenons": "revenir",
    "reventes": "revente",
    "revenu": "revenir",
    "revenue": "revenu",
    "revenues": "revenu",
    "revenus": "revenu",
    "reverchons": "reverchon",
    "reverdi": "reverdir",
    "reverdie": "reverdir",
    "reverdies": "reverdir",
    "reverdira": "reverdir",
    "reverdirai": "reverdir",
    "reverdiraient": "reverdir",
    "reverdirais": "reverdir",
    "reverdirait": "reverdir",
    "reverdiras": "reverdir",
    "reverdirent": "reverdir",
    "reverdirez": "reverdir",
    "reverdiriez": "reverdir",
    "reverdirions": "reverdir",
    "reverdirons": "reverdir",
    "reverdiront": "reverdir",
    "reverdis": "reverdir",
    "reverdissaient": "reverdir",
    "reverdissais": "reverdir",
    "reverdissait": "reverdir",
    "reverdissant": "reverdir",
    "reverdisse": "reverdir",
    "reverdissent": "reverdir",
    "reverdisses": "reverdir",
    "reverdissez": "reverdir",
    "reverdissiez": "reverdir",
    "reverdissions": "reverdir",
    "reverdissons": "reverdir",
    "reverdit": "reverdir",
    "reverdîmes": "reverdir",
    "reverdît": "reverdir",
    "reverdîtes": "reverdir",
    "reverni": "revernir",
    "revernie": "revernir",
    "revernies": "revernir",
    "revernira": "revernir",
    "revernirai": "revernir",
    "reverniraient": "revernir",
    "revernirais": "revernir",
    "revernirait": "revernir",
    "reverniras": "revernir",
    "revernirent": "revernir",
    "revernirez": "revernir",
    "reverniriez": "revernir",
    "revernirions": "revernir",
    "revernirons": "revernir",
    "reverniront": "revernir",
    "revernis": "revernir",
    "revernissaient": "revernir",
    "revernissais": "revernir",
    "revernissait": "revernir",
    "revernissant": "revernir",
    "revernisse": "revernir",
    "revernissent": "revernir",
    "revernisses": "revernir",
    "revernissez": "revernir",
    "revernissiez": "revernir",
    "revernissions": "revernir",
    "revernissons": "revernir",
    "revernit": "revernir",
    "revernîmes": "revernir",
    "revernît": "revernir",
    "revernîtes": "revernir",
    "reverra": "revoir",
    "reverrai": "revoir",
    "reverraient": "revoir",
    "reverrais": "revoir",
    "reverrait": "revoir",
    "reverras": "revoir",
    "reverrez": "revoir",
    "reverriez": "revoir",
    "reverrions": "revoir",
    "reverrons": "revoir",
    "reverront": "revoir",
    "reversa": "reverser",
    "reversai": "reverser",
    "reversaient": "reverser",
    "reversais": "reverser",
    "reversait": "reverser",
    "reversant": "reverser",
    "reversas": "reverser",
    "reversasse": "reverser",
    "reversassent": "reverser",
    "reversasses": "reverser",
    "reversassiez": "reverser",
    "reversassions": "reverser",
    "reverse": "reverser",
    "reversent": "reverser",
    "reversera": "reverser",
    "reverserai": "reverser",
    "reverseraient": "reverser",
    "reverserais": "reverser",
    "reverserait": "reverser",
    "reverseras": "reverser",
    "reverserez": "reverser",
    "reverseriez": "reverser",
    "reverserions": "reverser",
    "reverserons": "reverser",
    "reverseront": "reverser",
    "reverses": "reverser",
    "reversez": "reverser",
    "reversiez": "reverser",
    "reversions": "reverser",
    "reversons": "reverser",
    "reversâmes": "reverser",
    "reversât": "reverser",
    "reversâtes": "reverser",
    "reversèrent": "reverser",
    "reversé": "reverser",
    "reversée": "reverser",
    "reversées": "reverser",
    "reversés": "reverser",
    "reveuille": "revouloir",
    "reveuillent": "revouloir",
    "reveuilles": "revouloir",
    "reveulent": "revouloir",
    "reveut": "revouloir",
    "reveux": "revouloir",
    "revida": "revider",
    "revidèrent": "revider",
    "reviendra": "revenir",
    "reviendrai": "revenir",
    "reviendraient": "revenir",
    "reviendrais": "revenir",
    "reviendrait": "revenir",
    "reviendras": "revenir",
    "reviendrez": "revenir",
    "reviendriez": "revenir",
    "reviendrions": "revenir",
    "reviendrons": "revenir",
    "reviendront": "revenir",
    "revienne": "revenir",
    "reviennent": "revenir",
    "reviennes": "revenir",
    "reviens": "revenir",
    "revient": "revenir",
    "revients": "revient",
    "revigora": "revigorer",
    "revigorai": "revigorer",
    "revigoraient": "revigorer",
    "revigorais": "revigorer",
    "revigorait": "revigorer",
    "revigorant": "revigorer",
    "revigorante": "revigorant",
    "revigorantes": "revigorant",
    "revigorants": "revigorant",
    "revigoras": "revigorer",
    "revigorasse": "revigorer",
    "revigorassent": "revigorer",
    "revigorasses": "revigorer",
    "revigorassiez": "revigorer",
    "revigorassions": "revigorer",
    "revigore": "revigorer",
    "revigorent": "revigorer",
    "revigorera": "revigorer",
    "revigorerai": "revigorer",
    "revigoreraient": "revigorer",
    "revigorerais": "revigorer",
    "revigorerait": "revigorer",
    "revigoreras": "revigorer",
    "revigorerez": "revigorer",
    "revigoreriez": "revigorer",
    "revigorerions": "revigorer",
    "revigorerons": "revigorer",
    "revigoreront": "revigorer",
    "revigores": "revigorer",
    "revigorez": "revigorer",
    "revigoriez": "revigorer",
    "revigorions": "revigorer",
    "revigorons": "revigorer",
    "revigorâmes": "revigorer",
    "revigorât": "revigorer",
    "revigorâtes": "revigorer",
    "revigorèrent": "revigorer",
    "revigoré": "revigorer",
    "revigorée": "revigorer",
    "revigorées": "revigorer",
    "revigorés": "revigorer",
    "revinrent": "revenir",
    "revins": "revenir",
    "revinsse": "revenir",
    "revinssent": "revenir",
    "revinsses": "revenir",
    "revinssiez": "revenir",
    "revinssions": "revenir",
    "revint": "revenir",
    "revirements": "revirement",
    "revirent": "revoir",
    "revis": "revoir",
    "revisita": "revisiter",
    "revisite": "revisiter",
    "revisitent": "revisiter",
    "revisité": "revisiter",
    "revisitée": "revisiter",
    "revisitées": "revisité",
    "revisités": "revisité",
    "revissa": "revisser",
    "revisse": "revoir",
    "revissent": "revoir",
    "revisses": "revoir",
    "revissiez": "revoir",
    "revissions": "revoir",
    "revissé": "revisser",
    "revissées": "revisser",
    "revit": "revoir",
    "revitalisa": "revitaliser",
    "revitalisai": "revitaliser",
    "revitalisaient": "revitaliser",
    "revitalisais": "revitaliser",
    "revitalisait": "revitaliser",
    "revitalisant": "revitaliser",
    "revitalisas": "revitaliser",
    "revitalisasse": "revitaliser",
    "revitalisassent": "revitaliser",
    "revitalisasses": "revitaliser",
    "revitalisassiez": "revitaliser",
    "revitalisassions": "revitaliser",
    "revitalise": "revitaliser",
    "revitalisent": "revitaliser",
    "revitalisera": "revitaliser",
    "revitaliserai": "revitaliser",
    "revitaliseraient": "revitaliser",
    "revitaliserais": "revitaliser",
    "revitaliserait": "revitaliser",
    "revitaliseras": "revitaliser",
    "revitaliserez": "revitaliser",
    "revitaliseriez": "revitaliser",
    "revitaliserions": "revitaliser",
    "revitaliserons": "revitaliser",
    "revitaliseront": "revitaliser",
    "revitalises": "revitaliser",
    "revitalisez": "revitaliser",
    "revitalisiez": "revitaliser",
    "revitalisions": "revitaliser",
    "revitalisons": "revitaliser",
    "revitalisâmes": "revitaliser",
    "revitalisât": "revitaliser",
    "revitalisâtes": "revitaliser",
    "revitalisèrent": "revitaliser",
    "revitalisé": "revitaliser",
    "revitalisée": "revitaliser",
    "revitalisées": "revitaliser",
    "revitalisés": "revitaliser",
    "revivaient": "revivre",
    "revivais": "revivre",
    "revivait": "revivre",
    "revivant": "revivre",
    "revive": "revivre",
    "revivent": "revivre",
    "revives": "revivre",
    "revivez": "revivre",
    "reviviez": "revivre",
    "revivifia": "revivifier",
    "revivifiai": "revivifier",
    "revivifiaient": "revivifier",
    "revivifiais": "revivifier",
    "revivifiait": "revivifier",
    "revivifiant": "revivifier",
    "revivifias": "revivifier",
    "revivifiasse": "revivifier",
    "revivifiassent": "revivifier",
    "revivifiasses": "revivifier",
    "revivifiassiez": "revivifier",
    "revivifiassions": "revivifier",
    "revivifie": "revivifier",
    "revivifient": "revivifier",
    "revivifiera": "revivifier",
    "revivifierai": "revivifier",
    "revivifieraient": "revivifier",
    "revivifierais": "revivifier",
    "revivifierait": "revivifier",
    "revivifieras": "revivifier",
    "revivifierez": "revivifier",
    "revivifieriez": "revivifier",
    "revivifierions": "revivifier",
    "revivifierons": "revivifier",
    "revivifieront": "revivifier",
    "revivifies": "revivifier",
    "revivifiez": "revivifier",
    "revivifiiez": "revivifier",
    "revivifiions": "revivifier",
    "revivifions": "revivifier",
    "revivifiâmes": "revivifier",
    "revivifiât": "revivifier",
    "revivifiâtes": "revivifier",
    "revivifièrent": "revivifier",
    "revivifié": "revivifier",
    "revivifiée": "revivifier",
    "revivifiées": "revivifier",
    "revivifiés": "revivifier",
    "revivions": "revivre",
    "reviviscences": "reviviscence",
    "revivons": "revivre",
    "revivra": "revivre",
    "revivrai": "revivre",
    "revivraient": "revivre",
    "revivrais": "revivre",
    "revivrait": "revivre",
    "revivras": "revivre",
    "revivrez": "revivre",
    "revivriez": "revivre",
    "revivrions": "revivre",
    "revivrons": "revivre",
    "revivront": "revivre",
    "revoie": "revoir",
    "revoient": "revoir",
    "revoies": "revoir",
    "revois": "revoir",
    "revoit": "revoir",
    "revola": "revoler",
    "revolai": "revoler",
    "revolaient": "revoler",
    "revolais": "revoler",
    "revolait": "revoler",
    "revolant": "revoler",
    "revolas": "revoler",
    "revolasse": "revoler",
    "revolassent": "revoler",
    "revolasses": "revoler",
    "revolassiez": "revoler",
    "revolassions": "revoler",
    "revole": "revoler",
    "revolent": "revoler",
    "revolera": "revoler",
    "revolerai": "revoler",
    "revoleraient": "revoler",
    "revolerais": "revoler",
    "revolerait": "revoler",
    "revoleras": "revoler",
    "revolerez": "revoler",
    "revoleriez": "revoler",
    "revolerions": "revoler",
    "revolerons": "revoler",
    "revoleront": "revoler",
    "revoles": "revoler",
    "revolez": "revoler",
    "revoliez": "revoler",
    "revolions": "revoler",
    "revolons": "revoler",
    "revolvers": "revolver",
    "revolâmes": "revoler",
    "revolât": "revoler",
    "revolâtes": "revoler",
    "revolèrent": "revoler",
    "revolé": "revoler",
    "revolée": "revoler",
    "revolées": "revoler",
    "revolés": "revoler",
    "revomissant": "revomir",
    "revota": "revoter",
    "revotai": "revoter",
    "revotaient": "revoter",
    "revotais": "revoter",
    "revotait": "revoter",
    "revotant": "revoter",
    "revotas": "revoter",
    "revotasse": "revoter",
    "revotassent": "revoter",
    "revotasses": "revoter",
    "revotassiez": "revoter",
    "revotassions": "revoter",
    "revote": "revoter",
    "revotent": "revoter",
    "revotera": "revoter",
    "revoterai": "revoter",
    "revoteraient": "revoter",
    "revoterais": "revoter",
    "revoterait": "revoter",
    "revoteras": "revoter",
    "revoterez": "revoter",
    "revoteriez": "revoter",
    "revoterions": "revoter",
    "revoterons": "revoter",
    "revoteront": "revoter",
    "revotes": "revoter",
    "revotez": "revoter",
    "revotiez": "revoter",
    "revotions": "revoter",
    "revotons": "revoter",
    "revotâmes": "revoter",
    "revotât": "revoter",
    "revotâtes": "revoter",
    "revotèrent": "revoter",
    "revoté": "revoter",
    "revotée": "revoter",
    "revotées": "revoter",
    "revotés": "revoter",
    "revoudra": "revouloir",
    "revoudrai": "revouloir",
    "revoudraient": "revouloir",
    "revoudrais": "revouloir",
    "revoudrait": "revouloir",
    "revoudras": "revouloir",
    "revoudrez": "revouloir",
    "revoudriez": "revouloir",
    "revoudrions": "revouloir",
    "revoudrons": "revouloir",
    "revoudront": "revouloir",
    "revoulaient": "revouloir",
    "revoulais": "revouloir",
    "revoulait": "revouloir",
    "revoulant": "revouloir",
    "revoulez": "revouloir",
    "revouliez": "revouloir",
    "revoulions": "revouloir",
    "revoulons": "revouloir",
    "revoulu": "revouloir",
    "revoulue": "revouloir",
    "revoulues": "revouloir",
    "revoulurent": "revouloir",
    "revoulus": "revouloir",
    "revoulusse": "revouloir",
    "revoulussent": "revouloir",
    "revoulusses": "revouloir",
    "revoulussiez": "revouloir",
    "revoulussions": "revouloir",
    "revoulut": "revouloir",
    "revoulûmes": "revouloir",
    "revoulût": "revouloir",
    "revoulûtes": "revouloir",
    "revoyaient": "revoir",
    "revoyais": "revoir",
    "revoyait": "revoir",
    "revoyant": "revoir",
    "revoyez": "revoir",
    "revoyiez": "revoir",
    "revoyions": "revoir",
    "revoyons": "revoir",
    "revoyures": "revoyure",
    "revu": "revoir",
    "revue": "revu",
    "revues": "revue",
    "revuistes": "revuiste",
    "revus": "revu",
    "revécu": "revivre",
    "revécue": "revivre",
    "revécues": "revivre",
    "revécurent": "revivre",
    "revécus": "revivre",
    "revécusse": "revivre",
    "revécussent": "revivre",
    "revécusses": "revivre",
    "revécussiez": "revivre",
    "revécussions": "revivre",
    "revécut": "revivre",
    "revécûmes": "revivre",
    "revécût": "revivre",
    "revécûtes": "revivre",
    "revêches": "revêche",
    "revêt": "revêtir",
    "revêtaient": "revêtir",
    "revêtais": "revêtir",
    "revêtait": "revêtir",
    "revêtant": "revêtir",
    "revête": "revêtir",
    "revêtements": "revêtement",
    "revêtent": "revêtir",
    "revêtes": "revêtir",
    "revêtez": "revêtir",
    "revêtiez": "revêtir",
    "revêtions": "revêtir",
    "revêtira": "revêtir",
    "revêtirai": "revêtir",
    "revêtiraient": "revêtir",
    "revêtirais": "revêtir",
    "revêtirait": "revêtir",
    "revêtiras": "revêtir",
    "revêtirent": "revêtir",
    "revêtirez": "revêtir",
    "revêtiriez": "revêtir",
    "revêtirions": "revêtir",
    "revêtirons": "revêtir",
    "revêtiront": "revêtir",
    "revêtis": "revêtir",
    "revêtisse": "revêtir",
    "revêtissent": "revêtir",
    "revêtisses": "revêtir",
    "revêtissiez": "revêtir",
    "revêtissions": "revêtir",
    "revêtit": "revêtir",
    "revêtons": "revêtir",
    "revêts": "revêtir",
    "revêtu": "revêtir",
    "revêtue": "revêtu",
    "revêtues": "revêtu",
    "revêtus": "revêtu",
    "revêtîmes": "revêtir",
    "revêtît": "revêtir",
    "revêtîtes": "revêtir",
    "revîmes": "revoir",
    "revînmes": "revenir",
    "revînt": "revenir",
    "revîntes": "revenir",
    "revît": "revoir",
    "revîtes": "revoir",
    "rewrita": "rewriter",
    "rewritai": "rewriter",
    "rewritaient": "rewriter",
    "rewritais": "rewriter",
    "rewritait": "rewriter",
    "rewritant": "rewriter",
    "rewritas": "rewriter",
    "rewritasse": "rewriter",
    "rewritassent": "rewriter",
    "rewritasses": "rewriter",
    "rewritassiez": "rewriter",
    "rewritassions": "rewriter",
    "rewrite": "rewriter",
    "rewritent": "rewriter",
    "rewritera": "rewriter",
    "rewriterai": "rewriter",
    "rewriteraient": "rewriter",
    "rewriterais": "rewriter",
    "rewriterait": "rewriter",
    "rewriteras": "rewriter",
    "rewriterez": "rewriter",
    "rewriteriez": "rewriter",
    "rewriterions": "rewriter",
    "rewriterons": "rewriter",
    "rewriteront": "rewriter",
    "rewriters": "rewriter",
    "rewrites": "rewriter",
    "rewritez": "rewriter",
    "rewritiez": "rewriter",
    "rewritings": "rewriting",
    "rewritions": "rewriter",
    "rewritons": "rewriter",
    "rewritâmes": "rewriter",
    "rewritât": "rewriter",
    "rewritâtes": "rewriter",
    "rewritèrent": "rewriter",
    "rewrité": "rewriter",
    "rewritée": "rewriter",
    "rewritées": "rewriter",
    "rewrités": "rewriter",
    "rexistes": "rexiste",
    "rezzous": "rezzou",
    "reàlisations": "reàlisation",
    "reçois": "recevoir",
    "reçoit": "recevoir",
    "reçoive": "recevoir",
    "reçoivent": "recevoir",
    "reçoives": "recevoir",
    "reçu": "recevoir",
    "reçue": "reçu",
    "reçues": "reçu",
    "reçurent": "recevoir",
    "reçus": "reçu",
    "reçusse": "recevoir",
    "reçussent": "recevoir",
    "reçusses": "recevoir",
    "reçussiez": "recevoir",
    "reçussions": "recevoir",
    "reçut": "recevoir",
    "reçûmes": "recevoir",
    "reçût": "recevoir",
    "reçûtes": "recevoir",
    "reéquilibrages": "reéquilibrage",
    "reîtres": "reître",
    "rhabilla": "rhabiller",
    "rhabillai": "rhabiller",
    "rhabillaient": "rhabiller",
    "rhabillais": "rhabiller",
    "rhabillait": "rhabiller",
    "rhabillant": "rhabiller",
    "rhabillas": "rhabiller",
    "rhabillasse": "rhabiller",
    "rhabillassent": "rhabiller",
    "rhabillasses": "rhabiller",
    "rhabillassiez": "rhabiller",
    "rhabillassions": "rhabiller",
    "rhabille": "rhabiller",
    "rhabillent": "rhabiller",
    "rhabillera": "rhabiller",
    "rhabillerai": "rhabiller",
    "rhabilleraient": "rhabiller",
    "rhabillerais": "rhabiller",
    "rhabillerait": "rhabiller",
    "rhabilleras": "rhabiller",
    "rhabillerez": "rhabiller",
    "rhabilleriez": "rhabiller",
    "rhabillerions": "rhabiller",
    "rhabillerons": "rhabiller",
    "rhabilleront": "rhabiller",
    "rhabilles": "rhabiller",
    "rhabillez": "rhabiller",
    "rhabilliez": "rhabiller",
    "rhabillions": "rhabiller",
    "rhabillons": "rhabiller",
    "rhabillâmes": "rhabiller",
    "rhabillât": "rhabiller",
    "rhabillâtes": "rhabiller",
    "rhabillèrent": "rhabiller",
    "rhabillé": "rhabiller",
    "rhabillée": "rhabiller",
    "rhabillées": "rhabiller",
    "rhabillés": "rhabiller",
    "rhapsodes": "rhapsode",
    "rhapsodies": "rhapsodie",
    "rhingraves": "rhingrave",
    "rhinites": "rhinite",
    "rhino-pharyngites": "rhino-pharyngite",
    "rhinos": "rhino",
    "rhizomanies": "rhizomanie",
    "rhodanienne": "rhodanien",
    "rhodaniennes": "rhodanien",
    "rhodaniens": "rhodanien",
    "rhododendrons": "rhododendron",
    "rhombiques": "rhombique",
    "rhomboïdale": "rhomboïdal",
    "rhomboïdales": "rhomboïdal",
    "rhomboïdaux": "rhomboïdal",
    "rhomboïdes": "rhomboïde",
    "rhubarbes": "rhubarbe",
    "rhumatisante": "rhumatisant",
    "rhumatisants": "rhumatisant",
    "rhumatismale": "rhumatismal",
    "rhumatismales": "rhumatismal",
    "rhumatismaux": "rhumatismal",
    "rhumatismes": "rhumatisme",
    "rhumatologies": "rhumatologie",
    "rhumbs": "rhumb",
    "rhumes": "rhume",
    "rhums": "rhum",
    "rhynchites": "rhynchite",
    "rhénane": "rhénan",
    "rhénanes": "rhénan",
    "rhénans": "rhénan",
    "rhéostats": "rhéostat",
    "rhéteurs": "rhéteur",
    "rhétoriques": "rhétorique",
    "ri": "rire",
    "riaient": "rire",
    "riais": "rire",
    "riait": "rire",
    "rials": "rial",
    "riant": "rire",
    "riante": "riant",
    "riantes": "riant",
    "riants": "riant",
    "ribambelles": "ribambelle",
    "ribaude": "ribaud",
    "ribaudes": "ribaud",
    "ribauds": "ribaud",
    "rible": "ribler",
    "ribosomes": "ribosome",
    "ribote": "ribot",
    "ribotes": "ribote",
    "riboulait": "ribouler",
    "riboulant": "ribouler",
    "riboulants": "riboulant",
    "ribouldingues": "ribouldingue",
    "ricaine": "ricain",
    "ricaines": "ricain",
    "ricains": "ricain",
    "ricana": "ricaner",
    "ricanai": "ricaner",
    "ricanaient": "ricaner",
    "ricanais": "ricaner",
    "ricanait": "ricaner",
    "ricanant": "ricaner",
    "ricanante": "ricanant",
    "ricanantes": "ricanant",
    "ricanants": "ricanant",
    "ricanas": "ricaner",
    "ricanasse": "ricaner",
    "ricanassent": "ricaner",
    "ricanasses": "ricaner",
    "ricanassiez": "ricaner",
    "ricanassions": "ricaner",
    "ricane": "ricaner",
    "ricanements": "ricanement",
    "ricanent": "ricaner",
    "ricanera": "ricaner",
    "ricanerai": "ricaner",
    "ricaneraient": "ricaner",
    "ricanerais": "ricaner",
    "ricanerait": "ricaner",
    "ricaneras": "ricaner",
    "ricanerez": "ricaner",
    "ricaneriez": "ricaner",
    "ricanerions": "ricaner",
    "ricanerons": "ricaner",
    "ricaneront": "ricaner",
    "ricanes": "ricaner",
    "ricaneurs": "ricaneur",
    "ricaneuse": "ricaneur",
    "ricanez": "ricaner",
    "ricaniez": "ricaner",
    "ricanions": "ricaner",
    "ricanons": "ricaner",
    "ricanâmes": "ricaner",
    "ricanât": "ricaner",
    "ricanâtes": "ricaner",
    "ricanèrent": "ricaner",
    "ricané": "ricaner",
    "ricassant": "ricasser",
    "richarde": "richard",
    "richards": "richard",
    "richelieus": "richelieu",
    "riches": "riche",
    "richesses": "richesse",
    "richissimes": "richissime",
    "ricins": "ricin",
    "ricocha": "ricocher",
    "ricochai": "ricocher",
    "ricochaient": "ricocher",
    "ricochais": "ricocher",
    "ricochait": "ricocher",
    "ricochant": "ricocher",
    "ricochas": "ricocher",
    "ricochasse": "ricocher",
    "ricochassent": "ricocher",
    "ricochasses": "ricocher",
    "ricochassiez": "ricocher",
    "ricochassions": "ricocher",
    "ricoche": "ricocher",
    "ricochent": "ricocher",
    "ricochera": "ricocher",
    "ricocherai": "ricocher",
    "ricocheraient": "ricocher",
    "ricocherais": "ricocher",
    "ricocherait": "ricocher",
    "ricocheras": "ricocher",
    "ricocherez": "ricocher",
    "ricocheriez": "ricocher",
    "ricocherions": "ricocher",
    "ricocherons": "ricocher",
    "ricocheront": "ricocher",
    "ricoches": "ricocher",
    "ricochets": "ricochet",
    "ricochez": "ricocher",
    "ricochiez": "ricocher",
    "ricochions": "ricocher",
    "ricochons": "ricocher",
    "ricochâmes": "ricocher",
    "ricochât": "ricocher",
    "ricochâtes": "ricocher",
    "ricochèrent": "ricocher",
    "ricoché": "ricocher",
    "ricochée": "ricocher",
    "ricochées": "ricocher",
    "ricochés": "ricocher",
    "rida": "rider",
    "ridai": "rider",
    "ridaient": "rider",
    "ridais": "rider",
    "ridait": "rider",
    "ridant": "rider",
    "ridas": "rider",
    "ridasse": "rider",
    "ridassent": "rider",
    "ridasses": "rider",
    "ridassiez": "rider",
    "ridassions": "rider",
    "ride": "rider",
    "rideaux": "rideau",
    "ridelle": "rideau",
    "ridelles": "ridelle",
    "rident": "rider",
    "ridera": "rider",
    "riderai": "rider",
    "rideraient": "rider",
    "riderais": "rider",
    "riderait": "rider",
    "rideras": "rider",
    "riderez": "rider",
    "rideriez": "rider",
    "riderions": "rider",
    "riderons": "rider",
    "rideront": "rider",
    "rides": "rider",
    "ridez": "rider",
    "ridicules": "ridicule",
    "ridiculisa": "ridiculiser",
    "ridiculisai": "ridiculiser",
    "ridiculisaient": "ridiculiser",
    "ridiculisais": "ridiculiser",
    "ridiculisait": "ridiculiser",
    "ridiculisant": "ridiculiser",
    "ridiculisas": "ridiculiser",
    "ridiculisasse": "ridiculiser",
    "ridiculisassent": "ridiculiser",
    "ridiculisasses": "ridiculiser",
    "ridiculisassiez": "ridiculiser",
    "ridiculisassions": "ridiculiser",
    "ridiculise": "ridiculiser",
    "ridiculisent": "ridiculiser",
    "ridiculisera": "ridiculiser",
    "ridiculiserai": "ridiculiser",
    "ridiculiseraient": "ridiculiser",
    "ridiculiserais": "ridiculiser",
    "ridiculiserait": "ridiculiser",
    "ridiculiseras": "ridiculiser",
    "ridiculiserez": "ridiculiser",
    "ridiculiseriez": "ridiculiser",
    "ridiculiserions": "ridiculiser",
    "ridiculiserons": "ridiculiser",
    "ridiculiseront": "ridiculiser",
    "ridiculises": "ridiculiser",
    "ridiculisez": "ridiculiser",
    "ridiculisiez": "ridiculiser",
    "ridiculisions": "ridiculiser",
    "ridiculisons": "ridiculiser",
    "ridiculisâmes": "ridiculiser",
    "ridiculisât": "ridiculiser",
    "ridiculisâtes": "ridiculiser",
    "ridiculisèrent": "ridiculiser",
    "ridiculisé": "ridiculiser",
    "ridiculisée": "ridiculiser",
    "ridiculisées": "ridiculiser",
    "ridiculisés": "ridiculiser",
    "ridiculités": "ridiculité",
    "ridiez": "rider",
    "ridions": "rider",
    "ridons": "rider",
    "ridules": "ridule",
    "ridâmes": "rider",
    "ridât": "rider",
    "ridâtes": "rider",
    "ridèrent": "rider",
    "ridé": "rider",
    "ridée": "rider",
    "ridées": "rider",
    "ridés": "rider",
    "rie": "rire",
    "riens": "rien",
    "rient": "rire",
    "ries": "rire",
    "rieurs": "rieur",
    "rieuse": "rieux",
    "rieuses": "rieux",
    "riez": "rire",
    "rifains": "rifain",
    "riffaude": "riffauder",
    "riffaudé": "riffauder",
    "riffs": "riff",
    "rififis": "rififi",
    "rifla": "rifler",
    "riflai": "rifler",
    "riflaient": "rifler",
    "riflais": "rifler",
    "riflait": "rifler",
    "riflant": "rifler",
    "riflards": "riflard",
    "riflas": "rifler",
    "riflasse": "rifler",
    "riflassent": "rifler",
    "riflasses": "rifler",
    "riflassiez": "rifler",
    "riflassions": "rifler",
    "rifle": "rifler",
    "riflent": "rifler",
    "riflera": "rifler",
    "riflerai": "rifler",
    "rifleraient": "rifler",
    "riflerais": "rifler",
    "riflerait": "rifler",
    "rifleras": "rifler",
    "riflerez": "rifler",
    "rifleriez": "rifler",
    "riflerions": "rifler",
    "riflerons": "rifler",
    "rifleront": "rifler",
    "rifles": "rifler",
    "riflez": "rifler",
    "rifliez": "rifler",
    "riflions": "rifler",
    "riflons": "rifler",
    "riflâmes": "rifler",
    "riflât": "rifler",
    "riflâtes": "rifler",
    "riflèrent": "rifler",
    "riflé": "rifler",
    "riflée": "rifler",
    "riflées": "rifler",
    "riflés": "rifler",
    "rigaudons": "rigaudon",
    "rigides": "rigide",
    "rigidités": "rigidité",
    "rigodons": "rigodon",
    "rigola": "rigoler",
    "rigolades": "rigolade",
    "rigolai": "rigoler",
    "rigolaient": "rigoler",
    "rigolais": "rigoler",
    "rigolait": "rigoler",
    "rigolant": "rigoler",
    "rigolarde": "rigolard",
    "rigolardes": "rigolard",
    "rigolards": "rigolard",
    "rigolas": "rigoler",
    "rigolasse": "rigoler",
    "rigolassent": "rigoler",
    "rigolasses": "rigoler",
    "rigolassiez": "rigoler",
    "rigolassions": "rigoler",
    "rigole": "rigoler",
    "rigolent": "rigoler",
    "rigolera": "rigoler",
    "rigolerai": "rigoler",
    "rigoleraient": "rigoler",
    "rigolerais": "rigoler",
    "rigolerait": "rigoler",
    "rigoleras": "rigoler",
    "rigolerez": "rigoler",
    "rigoleriez": "rigoler",
    "rigolerions": "rigoler",
    "rigolerons": "rigoler",
    "rigoleront": "rigoler",
    "rigoles": "rigoler",
    "rigolez": "rigoler",
    "rigoliez": "rigoler",
    "rigolions": "rigoler",
    "rigolons": "rigoler",
    "rigolos": "rigolo",
    "rigolote": "rigolo",
    "rigolotes": "rigolote",
    "rigolâmes": "rigoler",
    "rigolât": "rigoler",
    "rigolâtes": "rigoler",
    "rigolèrent": "rigoler",
    "rigolé": "rigoler",
    "rigoristes": "rigoriste",
    "rigoureuse": "rigoureux",
    "rigoureuses": "rigoureux",
    "rigueurs": "rigueur",
    "riiez": "rire",
    "riions": "rire",
    "rima": "rimer",
    "rimai": "rimer",
    "rimaient": "rimer",
    "rimailla": "rimailler",
    "rimaillai": "rimailler",
    "rimaillaient": "rimailler",
    "rimaillais": "rimailler",
    "rimaillait": "rimailler",
    "rimaillant": "rimailler",
    "rimaillas": "rimailler",
    "rimaillasse": "rimailler",
    "rimaillassent": "rimailler",
    "rimaillasses": "rimailler",
    "rimaillassiez": "rimailler",
    "rimaillassions": "rimailler",
    "rimaille": "rimailler",
    "rimaillent": "rimailler",
    "rimaillera": "rimailler",
    "rimaillerai": "rimailler",
    "rimailleraient": "rimailler",
    "rimaillerais": "rimailler",
    "rimaillerait": "rimailler",
    "rimailleras": "rimailler",
    "rimaillerez": "rimailler",
    "rimailleriez": "rimailler",
    "rimaillerions": "rimailler",
    "rimaillerons": "rimailler",
    "rimailleront": "rimailler",
    "rimailles": "rimailler",
    "rimailleurs": "rimailleur",
    "rimaillez": "rimailler",
    "rimailliez": "rimailler",
    "rimaillions": "rimailler",
    "rimaillons": "rimailler",
    "rimaillâmes": "rimailler",
    "rimaillât": "rimailler",
    "rimaillâtes": "rimailler",
    "rimaillèrent": "rimailler",
    "rimaillé": "rimailler",
    "rimaillée": "rimailler",
    "rimaillées": "rimailler",
    "rimaillés": "rimailler",
    "rimais": "rimer",
    "rimait": "rimer",
    "rimant": "rimer",
    "rimante": "rimant",
    "rimas": "rimer",
    "rimasse": "rimer",
    "rimassent": "rimer",
    "rimasses": "rimer",
    "rimassiez": "rimer",
    "rimassions": "rimer",
    "rimayes": "rimaye",
    "rime": "rimer",
    "riment": "rimer",
    "rimera": "rimer",
    "rimerai": "rimer",
    "rimeraient": "rimer",
    "rimerais": "rimer",
    "rimerait": "rimer",
    "rimeras": "rimer",
    "rimerez": "rimer",
    "rimeriez": "rimer",
    "rimerions": "rimer",
    "rimerons": "rimer",
    "rimeront": "rimer",
    "rimes": "rimer",
    "rimeurs": "rimeur",
    "rimeuse": "rimeur",
    "rimez": "rimer",
    "rimiez": "rimer",
    "rimions": "rimer",
    "rimmels": "rimmel",
    "rimons": "rimer",
    "rimâmes": "rimer",
    "rimât": "rimer",
    "rimâtes": "rimer",
    "rimèrent": "rimer",
    "rimé": "rimer",
    "rimée": "rimer",
    "rimées": "rimer",
    "rimés": "rimer",
    "rince": "rincer",
    "rince-bouches": "rince-bouche",
    "rince-bouteilles": "rince-bouteille",
    "rinceaux": "rinceau",
    "rincent": "rincer",
    "rincera": "rincer",
    "rincerai": "rincer",
    "rinceraient": "rincer",
    "rincerais": "rincer",
    "rincerait": "rincer",
    "rinceras": "rincer",
    "rincerez": "rincer",
    "rinceriez": "rincer",
    "rincerions": "rincer",
    "rincerons": "rincer",
    "rinceront": "rincer",
    "rinces": "rincer",
    "rincez": "rincer",
    "rinciez": "rincer",
    "rincions": "rincer",
    "rincèrent": "rincer",
    "rincé": "rincer",
    "rincée": "rincer",
    "rincées": "rincer",
    "rincés": "rincer",
    "ringarde": "ringard",
    "ringardes": "ringard",
    "ringardises": "ringardise",
    "ringards": "ringard",
    "rings": "ring",
    "rinça": "rincer",
    "rinçages": "rinçage",
    "rinçai": "rincer",
    "rinçaient": "rincer",
    "rinçais": "rincer",
    "rinçait": "rincer",
    "rinçant": "rincer",
    "rinças": "rincer",
    "rinçasse": "rincer",
    "rinçassent": "rincer",
    "rinçasses": "rincer",
    "rinçassiez": "rincer",
    "rinçassions": "rincer",
    "rinçons": "rincer",
    "rinçâmes": "rincer",
    "rinçât": "rincer",
    "rinçâtes": "rincer",
    "rions": "rire",
    "ripa": "riper",
    "ripai": "riper",
    "ripaient": "riper",
    "ripailla": "ripailler",
    "ripaillai": "ripailler",
    "ripaillaient": "ripailler",
    "ripaillais": "ripailler",
    "ripaillait": "ripailler",
    "ripaillant": "ripailler",
    "ripaillas": "ripailler",
    "ripaillasse": "ripailler",
    "ripaillassent": "ripailler",
    "ripaillasses": "ripailler",
    "ripaillassiez": "ripailler",
    "ripaillassions": "ripailler",
    "ripaille": "ripailler",
    "ripaillent": "ripailler",
    "ripaillera": "ripailler",
    "ripaillerai": "ripailler",
    "ripailleraient": "ripailler",
    "ripaillerais": "ripailler",
    "ripaillerait": "ripailler",
    "ripailleras": "ripailler",
    "ripaillerez": "ripailler",
    "ripailleriez": "ripailler",
    "ripaillerions": "ripailler",
    "ripaillerons": "ripailler",
    "ripailleront": "ripailler",
    "ripailles": "ripailler",
    "ripaillez": "ripailler",
    "ripailliez": "ripailler",
    "ripaillions": "ripailler",
    "ripaillons": "ripailler",
    "ripaillâmes": "ripailler",
    "ripaillât": "ripailler",
    "ripaillâtes": "ripailler",
    "ripaillèrent": "ripailler",
    "ripaillé": "ripailler",
    "ripaillée": "ripailler",
    "ripaillées": "ripailler",
    "ripaillés": "ripailler",
    "ripais": "riper",
    "ripait": "riper",
    "ripant": "riper",
    "ripas": "riper",
    "ripasse": "riper",
    "ripassent": "riper",
    "ripasses": "riper",
    "ripassiez": "riper",
    "ripassions": "riper",
    "ripatons": "ripaton",
    "ripe": "riper",
    "ripent": "riper",
    "ripera": "riper",
    "riperai": "riper",
    "riperaient": "riper",
    "riperais": "riper",
    "riperait": "riper",
    "riperas": "riper",
    "riperez": "riper",
    "riperiez": "riper",
    "riperions": "riper",
    "riperons": "riper",
    "riperont": "riper",
    "ripes": "riper",
    "ripez": "riper",
    "ripiez": "riper",
    "ripions": "riper",
    "ripolines": "ripoliner",
    "ripoliné": "ripoliner",
    "ripolinée": "ripoliner",
    "ripolinées": "ripoliner",
    "ripolinés": "ripoliner",
    "ripons": "riper",
    "riposta": "riposter",
    "ripostai": "riposter",
    "ripostaient": "riposter",
    "ripostais": "riposter",
    "ripostait": "riposter",
    "ripostant": "riposter",
    "ripostas": "riposter",
    "ripostasse": "riposter",
    "ripostassent": "riposter",
    "ripostasses": "riposter",
    "ripostassiez": "riposter",
    "ripostassions": "riposter",
    "riposte": "riposter",
    "ripostent": "riposter",
    "ripostera": "riposter",
    "riposterai": "riposter",
    "riposteraient": "riposter",
    "riposterais": "riposter",
    "riposterait": "riposter",
    "riposteras": "riposter",
    "riposterez": "riposter",
    "riposteriez": "riposter",
    "riposterions": "riposter",
    "riposterons": "riposter",
    "riposteront": "riposter",
    "ripostes": "riposter",
    "ripostez": "riposter",
    "ripostiez": "riposter",
    "ripostions": "riposter",
    "ripostons": "riposter",
    "ripostâmes": "riposter",
    "ripostât": "riposter",
    "ripostâtes": "riposter",
    "ripostèrent": "riposter",
    "riposté": "riposter",
    "ripostée": "riposter",
    "ripostées": "riposter",
    "ripostés": "riposter",
    "rippers": "ripper",
    "ripâmes": "riper",
    "ripât": "riper",
    "ripâtes": "riper",
    "ripèrent": "riper",
    "ripé": "riper",
    "ripée": "riper",
    "ripées": "riper",
    "ripés": "riper",
    "rira": "rire",
    "rirai": "rire",
    "riraient": "rire",
    "rirais": "rire",
    "rirait": "rire",
    "riras": "rire",
    "rirent": "rire",
    "rires": "rire",
    "rirez": "rire",
    "ririez": "rire",
    "ririons": "rire",
    "rirons": "rire",
    "riront": "rire",
    "ris": "rire",
    "risettes": "risette",
    "risibles": "risible",
    "risottos": "risotto",
    "risqua": "risquer",
    "risquai": "risquer",
    "risquaient": "risquer",
    "risquais": "risquer",
    "risquait": "risquer",
    "risquant": "risquer",
    "risquas": "risquer",
    "risquasse": "risquer",
    "risquassent": "risquer",
    "risquasses": "risquer",
    "risquassiez": "risquer",
    "risquassions": "risquer",
    "risque": "risquer",
    "risquent": "risquer",
    "risquera": "risquer",
    "risquerai": "risquer",
    "risqueraient": "risquer",
    "risquerais": "risquer",
    "risquerait": "risquer",
    "risqueras": "risquer",
    "risquerez": "risquer",
    "risqueriez": "risquer",
    "risquerions": "risquer",
    "risquerons": "risquer",
    "risqueront": "risquer",
    "risques": "risquer",
    "risquez": "risquer",
    "risquiez": "risquer",
    "risquions": "risquer",
    "risquons": "risquer",
    "risquâmes": "risquer",
    "risquât": "risquer",
    "risquâtes": "risquer",
    "risquèrent": "risquer",
    "risqué": "risquer",
    "risquée": "risquer",
    "risquées": "risquer",
    "risqués": "risquer",
    "risse": "rire",
    "rissent": "rire",
    "risses": "rire",
    "rissiez": "rire",
    "rissions": "rire",
    "rissola": "rissoler",
    "rissolai": "rissoler",
    "rissolaient": "rissoler",
    "rissolais": "rissoler",
    "rissolait": "rissoler",
    "rissolant": "rissoler",
    "rissolas": "rissoler",
    "rissolasse": "rissoler",
    "rissolassent": "rissoler",
    "rissolasses": "rissoler",
    "rissolassiez": "rissoler",
    "rissolassions": "rissoler",
    "rissole": "rissoler",
    "rissolent": "rissoler",
    "rissolera": "rissoler",
    "rissolerai": "rissoler",
    "rissoleraient": "rissoler",
    "rissolerais": "rissoler",
    "rissolerait": "rissoler",
    "rissoleras": "rissoler",
    "rissolerez": "rissoler",
    "rissoleriez": "rissoler",
    "rissolerions": "rissoler",
    "rissolerons": "rissoler",
    "rissoleront": "rissoler",
    "rissoles": "rissoler",
    "rissolez": "rissoler",
    "rissoliez": "rissoler",
    "rissolions": "rissoler",
    "rissolons": "rissoler",
    "rissolâmes": "rissoler",
    "rissolât": "rissoler",
    "rissolâtes": "rissoler",
    "rissolèrent": "rissoler",
    "rissolé": "rissoler",
    "rissolée": "rissoler",
    "rissolées": "rissoler",
    "rissolés": "rissoler",
    "ristournait": "ristourner",
    "ristourne": "ristourner",
    "ristournes": "ristourne",
    "risées": "risée",
    "rit": "rire",
    "ritale": "rital",
    "ritales": "rital",
    "ritals": "rital",
    "rites": "rite",
    "ritournelles": "ritournelle",
    "rittes": "ritt",
    "ritualisa": "ritualiser",
    "ritualistes": "ritualiste",
    "ritualisé": "ritualiser",
    "ritualisés": "ritualiser",
    "rituelle": "rituel",
    "rituelles": "rituel",
    "rituels": "rituel",
    "riva": "river",
    "rivages": "rivage",
    "rivai": "river",
    "rivaient": "river",
    "rivais": "river",
    "rivait": "river",
    "rivale": "rival",
    "rivales": "rival",
    "rivalisa": "rivaliser",
    "rivalisai": "rivaliser",
    "rivalisaient": "rivaliser",
    "rivalisais": "rivaliser",
    "rivalisait": "rivaliser",
    "rivalisant": "rivaliser",
    "rivalisas": "rivaliser",
    "rivalisasse": "rivaliser",
    "rivalisassent": "rivaliser",
    "rivalisasses": "rivaliser",
    "rivalisassiez": "rivaliser",
    "rivalisassions": "rivaliser",
    "rivalise": "rivaliser",
    "rivalisent": "rivaliser",
    "rivalisera": "rivaliser",
    "rivaliserai": "rivaliser",
    "rivaliseraient": "rivaliser",
    "rivaliserais": "rivaliser",
    "rivaliserait": "rivaliser",
    "rivaliseras": "rivaliser",
    "rivaliserez": "rivaliser",
    "rivaliseriez": "rivaliser",
    "rivaliserions": "rivaliser",
    "rivaliserons": "rivaliser",
    "rivaliseront": "rivaliser",
    "rivalises": "rivaliser",
    "rivalisez": "rivaliser",
    "rivalisiez": "rivaliser",
    "rivalisions": "rivaliser",
    "rivalisons": "rivaliser",
    "rivalisâmes": "rivaliser",
    "rivalisât": "rivaliser",
    "rivalisâtes": "rivaliser",
    "rivalisèrent": "rivaliser",
    "rivalisé": "rivaliser",
    "rivalités": "rivalité",
    "rivant": "river",
    "rivas": "river",
    "rivasse": "river",
    "rivassent": "river",
    "rivasses": "river",
    "rivassiez": "river",
    "rivassions": "river",
    "rivaux": "rival",
    "rive": "river",
    "rivelaines": "rivelaine",
    "rivent": "river",
    "rivera": "river",
    "riverai": "river",
    "riveraient": "river",
    "riveraine": "riverain",
    "riveraines": "riverain",
    "riverains": "riverain",
    "riverais": "river",
    "riverait": "river",
    "riveras": "river",
    "riverez": "river",
    "riveriez": "river",
    "riverions": "river",
    "riverons": "river",
    "riveront": "river",
    "rives": "river",
    "riveta": "riveter",
    "rivetai": "riveter",
    "rivetaient": "riveter",
    "rivetais": "riveter",
    "rivetait": "riveter",
    "rivetant": "riveter",
    "rivetas": "riveter",
    "rivetasse": "riveter",
    "rivetassent": "riveter",
    "rivetasses": "riveter",
    "rivetassiez": "riveter",
    "rivetassions": "riveter",
    "riveteuse": "riveteur",
    "rivetez": "riveter",
    "rivetiez": "riveter",
    "rivetions": "riveter",
    "rivetons": "riveter",
    "rivets": "rivet",
    "rivette": "riveter",
    "rivettent": "riveter",
    "rivettera": "riveter",
    "rivetterai": "riveter",
    "rivetteraient": "riveter",
    "rivetterais": "riveter",
    "rivetterait": "riveter",
    "rivetteras": "riveter",
    "rivetterez": "riveter",
    "rivetteriez": "riveter",
    "rivetterions": "riveter",
    "rivetterons": "riveter",
    "rivetteront": "riveter",
    "rivettes": "riveter",
    "rivetâmes": "riveter",
    "rivetât": "riveter",
    "rivetâtes": "riveter",
    "rivetèrent": "riveter",
    "riveté": "riveter",
    "rivetée": "riveter",
    "rivetées": "riveter",
    "rivetés": "riveter",
    "rivez": "river",
    "rivieras": "riviera",
    "riviez": "river",
    "rivions": "river",
    "rivières": "rivière",
    "rivons": "river",
    "rivâmes": "river",
    "rivât": "river",
    "rivâtes": "river",
    "rivèrent": "river",
    "rivé": "river",
    "rivée": "river",
    "rivées": "river",
    "rivés": "river",
    "rixdales": "rixdale",
    "rixes": "rixe",
    "riziculteurs": "riziculteur",
    "rizicultrice": "riziculteur",
    "rizicultrices": "riziculteur",
    "rizières": "rizière",
    "roast beef": "roast-beef",
    "roberts": "robert",
    "robes": "robe",
    "robinets": "robinet",
    "robinetteries": "robinetterie",
    "robiniers": "robinier",
    "robins": "robin",
    "robinsons": "robinson",
    "roborative": "roboratif",
    "roboratives": "roboratif",
    "robotiques": "robotique",
    "robotisations": "robotisation",
    "robotisé": "robotiser",
    "robotisée": "robotiser",
    "robotisées": "robotiser",
    "robots": "robot",
    "robres": "robre",
    "robs": "rob",
    "robustes": "robuste",
    "rocades": "rocade",
    "rocailles": "rocaille",
    "rocailleuse": "rocailleux",
    "rocailleuses": "rocailleux",
    "rocaillé": "rocailler",
    "rocamboles": "rocambole",
    "rocambolesques": "rocambolesque",
    "rocardienne": "rocardien",
    "rocardiennes": "rocardien",
    "rocardiens": "rocardien",
    "rocardismes": "rocardisme",
    "rochas": "rocher",
    "rochers": "rocher",
    "roches": "roche",
    "rochets": "rochet",
    "rocheuse": "rocheux",
    "rocheuses": "rocheux",
    "rochiers": "rochier",
    "roché": "rocher",
    "rock": "rocke",
    "rock'n'rolls": "rock'n'roll",
    "rock-'n-roll": "rock-n-roll",
    "rockers": "rocker",
    "rockets": "rocket",
    "rockeurs": "rockeur",
    "rockeuse": "rockeur",
    "rocking chair": "rocking-chair",
    "rocking-chairs": "rocking-chair",
    "rocks": "rock",
    "rococos": "rococo",
    "rocous": "rocou",
    "rocs": "roc",
    "roda": "roder",
    "rodages": "rodage",
    "rodai": "roder",
    "rodaient": "roder",
    "rodais": "roder",
    "rodait": "roder",
    "rodant": "roder",
    "rodas": "roder",
    "rodasse": "roder",
    "rodassent": "roder",
    "rodasses": "roder",
    "rodassiez": "roder",
    "rodassions": "roder",
    "rode": "roder",
    "rodent": "roder",
    "rodera": "roder",
    "roderai": "roder",
    "roderaient": "roder",
    "roderais": "roder",
    "roderait": "roder",
    "roderas": "roder",
    "roderez": "roder",
    "roderiez": "roder",
    "roderions": "roder",
    "roderons": "roder",
    "roderont": "roder",
    "rodes": "roder",
    "rodez": "roder",
    "rodiez": "roder",
    "rodions": "roder",
    "rodomontades": "rodomontade",
    "rodons": "roder",
    "rodâmes": "roder",
    "rodât": "roder",
    "rodâtes": "roder",
    "rodèrent": "roder",
    "rodé": "roder",
    "rodée": "roder",
    "rodées": "roder",
    "rodéos": "rodéo",
    "rodés": "roder",
    "roentgens": "roentgen",
    "rogations": "rogation",
    "rogatoires": "rogatoire",
    "rogatons": "rogaton",
    "rogna": "rogner",
    "rognai": "rogner",
    "rognaient": "rogner",
    "rognais": "rogner",
    "rognait": "rogner",
    "rognant": "rogner",
    "rognas": "rogner",
    "rognasse": "rogner",
    "rognassent": "rogner",
    "rognasses": "rogner",
    "rognassiez": "rogner",
    "rognassions": "rogner",
    "rogne": "rogner",
    "rognent": "rogner",
    "rognera": "rogner",
    "rognerai": "rogner",
    "rogneraient": "rogner",
    "rognerais": "rogner",
    "rognerait": "rogner",
    "rogneras": "rogner",
    "rognerez": "rogner",
    "rogneriez": "rogner",
    "rognerions": "rogner",
    "rognerons": "rogner",
    "rogneront": "rogner",
    "rognes": "rogner",
    "rognez": "rogner",
    "rogniez": "rogner",
    "rognions": "rogner",
    "rognonnades": "rognonnade",
    "rognonnait": "rognonner",
    "rognons": "rognon",
    "rognures": "rognure",
    "rognâmes": "rogner",
    "rognât": "rogner",
    "rognâtes": "rogner",
    "rognèrent": "rogner",
    "rogné": "rogner",
    "rognée": "rogner",
    "rognées": "rogner",
    "rognés": "rogner",
    "rogommes": "rogomme",
    "rogues": "rogue",
    "roides": "roide",
    "roidi": "roidir",
    "roidie": "roidir",
    "roidies": "roidir",
    "roidira": "roidir",
    "roidirai": "roidir",
    "roidiraient": "roidir",
    "roidirais": "roidir",
    "roidirait": "roidir",
    "roidiras": "roidir",
    "roidirent": "roidir",
    "roidirez": "roidir",
    "roidiriez": "roidir",
    "roidirions": "roidir",
    "roidirons": "roidir",
    "roidiront": "roidir",
    "roidis": "roidir",
    "roidissaient": "roidir",
    "roidissais": "roidir",
    "roidissait": "roidir",
    "roidissant": "roidir",
    "roidisse": "roidir",
    "roidissent": "roidir",
    "roidisses": "roidir",
    "roidissez": "roidir",
    "roidissiez": "roidir",
    "roidissions": "roidir",
    "roidissons": "roidir",
    "roidit": "roidir",
    "roidîmes": "roidir",
    "roidît": "roidir",
    "roidîtes": "roidir",
    "rois": "roi",
    "roitelets": "roitelet",
    "rollers": "roller",
    "rollots": "rollot",
    "romaine": "romain",
    "romaines": "romain",
    "romains": "romain",
    "romance": "romancer",
    "romancent": "romancer",
    "romancera": "romancer",
    "romancerai": "romancer",
    "romanceraient": "romancer",
    "romancerais": "romancer",
    "romancerait": "romancer",
    "romanceras": "romancer",
    "romancerez": "romancer",
    "romanceriez": "romancer",
    "romancerions": "romancer",
    "romancerons": "romancer",
    "romanceront": "romancer",
    "romanceros": "romancero",
    "romances": "romancer",
    "romancez": "romancer",
    "romanches": "romanche",
    "romanciers": "romancier",
    "romanciez": "romancer",
    "romancions": "romancer",
    "romancière": "romancier",
    "romancières": "romancier",
    "romancèrent": "romancer",
    "romancé": "romancer",
    "romancée": "romancer",
    "romancées": "romancer",
    "romancés": "romancer",
    "romande": "romand",
    "romandes": "romand",
    "romands": "romand",
    "romane": "roman",
    "romanes": "roman",
    "romanesques": "romanesque",
    "romanichelle": "romanichel",
    "romanichelles": "romanichel",
    "romanichels": "romanichel",
    "romanisa": "romaniser",
    "romanisai": "romaniser",
    "romanisaient": "romaniser",
    "romanisais": "romaniser",
    "romanisait": "romaniser",
    "romanisant": "romaniser",
    "romanisas": "romaniser",
    "romanisasse": "romaniser",
    "romanisassent": "romaniser",
    "romanisasses": "romaniser",
    "romanisassiez": "romaniser",
    "romanisassions": "romaniser",
    "romanise": "romaniser",
    "romanisent": "romaniser",
    "romanisera": "romaniser",
    "romaniserai": "romaniser",
    "romaniseraient": "romaniser",
    "romaniserais": "romaniser",
    "romaniserait": "romaniser",
    "romaniseras": "romaniser",
    "romaniserez": "romaniser",
    "romaniseriez": "romaniser",
    "romaniserions": "romaniser",
    "romaniserons": "romaniser",
    "romaniseront": "romaniser",
    "romanises": "romaniser",
    "romanisez": "romaniser",
    "romanisiez": "romaniser",
    "romanisions": "romaniser",
    "romanisons": "romaniser",
    "romanistes": "romaniste",
    "romanisâmes": "romaniser",
    "romanisât": "romaniser",
    "romanisâtes": "romaniser",
    "romanisèrent": "romaniser",
    "romanisé": "romaniser",
    "romanisée": "romaniser",
    "romanisées": "romaniser",
    "romanisés": "romaniser",
    "romanos": "romano",
    "romans": "roman",
    "romans-feuilletons": "roman-feuilleton",
    "romans-fleuves": "roman-fleuve",
    "romans-photos": "roman-photo",
    "romantiques": "romantique",
    "romantismes": "romantisme",
    "romança": "romancer",
    "romançai": "romancer",
    "romançaient": "romancer",
    "romançais": "romancer",
    "romançait": "romancer",
    "romançant": "romancer",
    "romanças": "romancer",
    "romançasse": "romancer",
    "romançassent": "romancer",
    "romançasses": "romancer",
    "romançassiez": "romancer",
    "romançassions": "romancer",
    "romançons": "romancer",
    "romançâmes": "romancer",
    "romançât": "romancer",
    "romançâtes": "romancer",
    "romarins": "romarin",
    "rombière": "rombier",
    "rombières": "rombière",
    "rompaient": "rompre",
    "rompais": "rompre",
    "rompait": "rompre",
    "rompant": "rompre",
    "rompe": "rompre",
    "rompent": "rompre",
    "rompes": "rompre",
    "rompez": "rompre",
    "rompiez": "rompre",
    "rompions": "rompre",
    "rompirent": "rompre",
    "rompis": "rompre",
    "rompisse": "rompre",
    "rompissent": "rompre",
    "rompisses": "rompre",
    "rompissiez": "rompre",
    "rompissions": "rompre",
    "rompit": "rompre",
    "rompons": "rompre",
    "rompra": "rompre",
    "romprai": "rompre",
    "rompraient": "rompre",
    "romprais": "rompre",
    "romprait": "rompre",
    "rompras": "rompre",
    "romprez": "rompre",
    "rompriez": "rompre",
    "romprions": "rompre",
    "romprons": "rompre",
    "rompront": "rompre",
    "romps": "rompre",
    "rompt": "rompre",
    "rompu": "rompre",
    "rompue": "rompu",
    "rompues": "rompu",
    "rompus": "rompu",
    "rompîmes": "rompre",
    "rompît": "rompre",
    "rompîtes": "rompre",
    "roms": "rom",
    "romstecks": "romsteck",
    "ronces": "ronce",
    "ronchonna": "ronchonner",
    "ronchonnai": "ronchonner",
    "ronchonnaient": "ronchonner",
    "ronchonnais": "ronchonner",
    "ronchonnait": "ronchonner",
    "ronchonnant": "ronchonner",
    "ronchonnas": "ronchonner",
    "ronchonnasse": "ronchonner",
    "ronchonnassent": "ronchonner",
    "ronchonnasses": "ronchonner",
    "ronchonnassiez": "ronchonner",
    "ronchonnassions": "ronchonner",
    "ronchonne": "ronchonner",
    "ronchonnent": "ronchonner",
    "ronchonnera": "ronchonner",
    "ronchonnerai": "ronchonner",
    "ronchonneraient": "ronchonner",
    "ronchonnerais": "ronchonner",
    "ronchonnerait": "ronchonner",
    "ronchonneras": "ronchonner",
    "ronchonnerez": "ronchonner",
    "ronchonneriez": "ronchonner",
    "ronchonnerions": "ronchonner",
    "ronchonnerons": "ronchonner",
    "ronchonneront": "ronchonner",
    "ronchonnes": "ronchonner",
    "ronchonneuse": "ronchonneur",
    "ronchonnez": "ronchonner",
    "ronchonniez": "ronchonner",
    "ronchonnions": "ronchonner",
    "ronchonnons": "ronchonner",
    "ronchonnâmes": "ronchonner",
    "ronchonnât": "ronchonner",
    "ronchonnâtes": "ronchonner",
    "ronchonnèrent": "ronchonner",
    "ronchonné": "ronchonner",
    "ronchons": "ronchon",
    "ronciers": "roncier",
    "rondaches": "rondache",
    "ronde": "rond",
    "rondeaux": "rondeau",
    "rondelette": "rondelet",
    "rondelettes": "rondelet",
    "rondelles": "rondelle",
    "rondes": "ronde",
    "rondes-bosses": "ronde-bosse",
    "rondeurs": "rondeur",
    "rondins": "rondin",
    "rondos": "rondo",
    "rondouillarde": "rondouillard",
    "rondouillards": "rondouillard",
    "ronds": "rond",
    "ronds-de-cuir": "rond-de-cuir",
    "ronds-points": "rond-point",
    "ronfla": "ronfler",
    "ronflai": "ronfler",
    "ronflaient": "ronfler",
    "ronflais": "ronfler",
    "ronflait": "ronfler",
    "ronflant": "ronfler",
    "ronflante": "ronflant",
    "ronflantes": "ronflant",
    "ronflants": "ronflant",
    "ronflas": "ronfler",
    "ronflasse": "ronfler",
    "ronflassent": "ronfler",
    "ronflasses": "ronfler",
    "ronflassiez": "ronfler",
    "ronflassions": "ronfler",
    "ronfle": "ronfler",
    "ronflements": "ronflement",
    "ronflent": "ronfler",
    "ronflera": "ronfler",
    "ronflerai": "ronfler",
    "ronfleraient": "ronfler",
    "ronflerais": "ronfler",
    "ronflerait": "ronfler",
    "ronfleras": "ronfler",
    "ronflerez": "ronfler",
    "ronfleriez": "ronfler",
    "ronflerions": "ronfler",
    "ronflerons": "ronfler",
    "ronfleront": "ronfler",
    "ronfles": "ronfler",
    "ronfleurs": "ronfleur",
    "ronfleuse": "ronfleur",
    "ronflez": "ronfler",
    "ronfliez": "ronfler",
    "ronflions": "ronfler",
    "ronflons": "ronfler",
    "ronflotait": "ronfloter",
    "ronflotant": "ronfloter",
    "ronflote": "ronfloter",
    "ronflâmes": "ronfler",
    "ronflât": "ronfler",
    "ronflâtes": "ronfler",
    "ronflèrent": "ronfler",
    "ronflé": "ronfler",
    "ronge": "ronger",
    "rongea": "ronger",
    "rongeai": "ronger",
    "rongeaient": "ronger",
    "rongeais": "ronger",
    "rongeait": "ronger",
    "rongeant": "ronger",
    "rongeante": "rongeant",
    "rongeantes": "rongeant",
    "rongeas": "ronger",
    "rongeasse": "ronger",
    "rongeassent": "ronger",
    "rongeasses": "ronger",
    "rongeassiez": "ronger",
    "rongeassions": "ronger",
    "rongent": "ronger",
    "rongeons": "ronger",
    "rongera": "ronger",
    "rongerai": "ronger",
    "rongeraient": "ronger",
    "rongerais": "ronger",
    "rongerait": "ronger",
    "rongeras": "ronger",
    "rongerez": "ronger",
    "rongeriez": "ronger",
    "rongerions": "ronger",
    "rongerons": "ronger",
    "rongeront": "ronger",
    "ronges": "ronger",
    "rongeurs": "rongeur",
    "rongeuse": "rongeur",
    "rongeuses": "rongeur",
    "rongez": "ronger",
    "rongeâmes": "ronger",
    "rongeât": "ronger",
    "rongeâtes": "ronger",
    "rongiez": "ronger",
    "rongions": "ronger",
    "rongèrent": "ronger",
    "rongé": "ronger",
    "rongée": "ronger",
    "rongées": "ronger",
    "rongés": "ronger",
    "ronronna": "ronronner",
    "ronronnai": "ronronner",
    "ronronnaient": "ronronner",
    "ronronnais": "ronronner",
    "ronronnait": "ronronner",
    "ronronnant": "ronronner",
    "ronronnante": "ronronnant",
    "ronronnantes": "ronronnant",
    "ronronnants": "ronronnant",
    "ronronnas": "ronronner",
    "ronronnasse": "ronronner",
    "ronronnassent": "ronronner",
    "ronronnasses": "ronronner",
    "ronronnassiez": "ronronner",
    "ronronnassions": "ronronner",
    "ronronne": "ronronner",
    "ronronnements": "ronronnement",
    "ronronnent": "ronronner",
    "ronronnera": "ronronner",
    "ronronnerai": "ronronner",
    "ronronneraient": "ronronner",
    "ronronnerais": "ronronner",
    "ronronnerait": "ronronner",
    "ronronneras": "ronronner",
    "ronronnerez": "ronronner",
    "ronronneriez": "ronronner",
    "ronronnerions": "ronronner",
    "ronronnerons": "ronronner",
    "ronronneront": "ronronner",
    "ronronnes": "ronronner",
    "ronronnez": "ronronner",
    "ronronniez": "ronronner",
    "ronronnions": "ronronner",
    "ronronnons": "ronronner",
    "ronronnâmes": "ronronner",
    "ronronnât": "ronronner",
    "ronronnâtes": "ronronner",
    "ronronnèrent": "ronronner",
    "ronronné": "ronronner",
    "ronronnée": "ronronner",
    "ronronnées": "ronronner",
    "ronronnés": "ronronner",
    "ronrons": "ronron",
    "ronéotions": "ronéoter",
    "ronéotypé": "ronéotyper",
    "ronéotypés": "ronéotyper",
    "ronéoté": "ronéoter",
    "roofs": "roof",
    "rookeries": "rookerie",
    "rookerys": "rookery",
    "roploplos": "roploplo",
    "roqua": "roquer",
    "roquai": "roquer",
    "roquaient": "roquer",
    "roquais": "roquer",
    "roquait": "roquer",
    "roquant": "roquer",
    "roquas": "roquer",
    "roquasse": "roquer",
    "roquassent": "roquer",
    "roquasses": "roquer",
    "roquassiez": "roquer",
    "roquassions": "roquer",
    "roque": "roquer",
    "roqueforts": "roquefort",
    "roquent": "roquer",
    "roquera": "roquer",
    "roquerai": "roquer",
    "roqueraient": "roquer",
    "roquerais": "roquer",
    "roquerait": "roquer",
    "roqueras": "roquer",
    "roquerez": "roquer",
    "roqueriez": "roquer",
    "roquerions": "roquer",
    "roquerons": "roquer",
    "roqueront": "roquer",
    "roques": "roquer",
    "roquets": "roquet",
    "roquettes": "roquette",
    "roquez": "roquer",
    "roquiez": "roquer",
    "roquions": "roquer",
    "roquons": "roquer",
    "roquâmes": "roquer",
    "roquât": "roquer",
    "roquâtes": "roquer",
    "roquèrent": "roquer",
    "roqué": "roquer",
    "roquée": "roquer",
    "roquées": "roquer",
    "roqués": "roquer",
    "rorquals": "rorqual",
    "rosa": "roser",
    "rosaces": "rosace",
    "rosacées": "rosacée",
    "rosages": "rosage",
    "rosaires": "rosaire",
    "rosbifs": "rosbif",
    "rose": "roser",
    "roseaux": "roseau",
    "roseliers": "roselier",
    "roselière": "roselier",
    "roselières": "roselière",
    "roseraies": "roseraie",
    "roses": "rose",
    "rosettes": "rosette",
    "roseurs": "roseur",
    "rosi": "rosir",
    "rosicrucienne": "rosicrucien",
    "rosicruciens": "rosicrucien",
    "rosie": "rosir",
    "rosiers": "rosier",
    "rosies": "rosir",
    "rosira": "rosir",
    "rosirai": "rosir",
    "rosiraient": "rosir",
    "rosirais": "rosir",
    "rosirait": "rosir",
    "rosiras": "rosir",
    "rosirent": "rosir",
    "rosirez": "rosir",
    "rosiriez": "rosir",
    "rosirions": "rosir",
    "rosirons": "rosir",
    "rosiront": "rosir",
    "rosis": "rosir",
    "rosissaient": "rosir",
    "rosissais": "rosir",
    "rosissait": "rosir",
    "rosissant": "rosir",
    "rosisse": "rosir",
    "rosissent": "rosir",
    "rosisses": "rosir",
    "rosissez": "rosir",
    "rosissiez": "rosir",
    "rosissions": "rosir",
    "rosissons": "rosir",
    "rosit": "rosir",
    "rosières": "rosière",
    "rossa": "rosser",
    "rossai": "rosser",
    "rossaient": "rosser",
    "rossais": "rosser",
    "rossait": "rosser",
    "rossant": "rosser",
    "rossards": "rossard",
    "rossas": "rosser",
    "rossasse": "rosser",
    "rossassent": "rosser",
    "rossasses": "rosser",
    "rossassiez": "rosser",
    "rossassions": "rosser",
    "rosse": "rosser",
    "rossent": "rosser",
    "rossera": "rosser",
    "rosserai": "rosser",
    "rosseraient": "rosser",
    "rosserais": "rosser",
    "rosserait": "rosser",
    "rosseras": "rosser",
    "rosserez": "rosser",
    "rosseries": "rosserie",
    "rosseriez": "rosser",
    "rosserions": "rosser",
    "rosserons": "rosser",
    "rosseront": "rosser",
    "rosses": "rosser",
    "rossez": "rosser",
    "rossiez": "rosser",
    "rossignols": "rossignol",
    "rossinantes": "rossinante",
    "rossions": "rosser",
    "rossons": "rosser",
    "rossâmes": "rosser",
    "rossât": "rosser",
    "rossâtes": "rosser",
    "rossèrent": "rosser",
    "rossé": "rosser",
    "rossée": "rosser",
    "rossées": "rosser",
    "rossés": "rosser",
    "rostres": "rostre",
    "rosâtres": "rosâtre",
    "rosé": "roser",
    "rosée": "roser",
    "rosées": "roser",
    "roséoles": "roséole",
    "rosés": "rosé",
    "rosîmes": "rosir",
    "rosît": "rosir",
    "rosîtes": "rosir",
    "rota": "roter",
    "rotai": "roter",
    "rotaient": "roter",
    "rotais": "roter",
    "rotait": "roter",
    "rotangs": "rotang",
    "rotant": "roter",
    "rotariens": "rotarien",
    "rotarys": "rotary",
    "rotas": "roter",
    "rotasse": "roter",
    "rotassent": "roter",
    "rotasses": "roter",
    "rotassiez": "roter",
    "rotassions": "roter",
    "rotatifs": "rotatif",
    "rotations": "rotation",
    "rotative": "rotatif",
    "rotatives": "rotative",
    "rotativistes": "rotativiste",
    "rote": "roter",
    "rotengles": "rotengle",
    "rotent": "roter",
    "rotera": "roter",
    "roterai": "roter",
    "roteraient": "roter",
    "roterais": "roter",
    "roterait": "roter",
    "roteras": "roter",
    "roterez": "roter",
    "roteriez": "roter",
    "roterions": "roter",
    "roterons": "roter",
    "roteront": "roter",
    "rotes": "roter",
    "roteuse": "roteur",
    "roteuses": "roteur",
    "rotez": "roter",
    "rotiez": "roter",
    "rotins": "rotin",
    "rotions": "roter",
    "rotonde": "rotond",
    "rotondes": "rotonde",
    "rotondités": "rotondité",
    "rotons": "roter",
    "rotors": "rotor",
    "rotos": "roto",
    "rototos": "rototo",
    "rots": "rot",
    "rotules": "rotule",
    "rotures": "roture",
    "roturiers": "roturier",
    "roturière": "roturier",
    "rotâmes": "roter",
    "rotât": "roter",
    "rotâtes": "roter",
    "rotèrent": "roter",
    "roté": "roter",
    "rotées": "roter",
    "roua": "rouer",
    "rouages": "rouage",
    "rouai": "rouer",
    "rouaient": "rouer",
    "rouais": "rouer",
    "rouait": "rouer",
    "rouant": "rouer",
    "rouas": "rouer",
    "rouasse": "rouer",
    "rouassent": "rouer",
    "rouasses": "rouer",
    "rouassiez": "rouer",
    "rouassions": "rouer",
    "roubaisienne": "roubaisien",
    "roublarde": "roublard",
    "roublardes": "roublard",
    "roublardises": "roublardise",
    "roublards": "roublard",
    "roubles": "rouble",
    "roucoula": "roucouler",
    "roucoulades": "roucoulade",
    "roucoulai": "roucouler",
    "roucoulaient": "roucouler",
    "roucoulais": "roucouler",
    "roucoulait": "roucouler",
    "roucoulant": "roucouler",
    "roucoulante": "roucoulant",
    "roucoulantes": "roucoulant",
    "roucoulants": "roucoulant",
    "roucoulas": "roucouler",
    "roucoulasse": "roucouler",
    "roucoulassent": "roucouler",
    "roucoulasses": "roucouler",
    "roucoulassiez": "roucouler",
    "roucoulassions": "roucouler",
    "roucoule": "roucouler",
    "roucoulements": "roucoulement",
    "roucoulent": "roucouler",
    "roucoulera": "roucouler",
    "roucoulerai": "roucouler",
    "roucouleraient": "roucouler",
    "roucoulerais": "roucouler",
    "roucoulerait": "roucouler",
    "roucouleras": "roucouler",
    "roucoulerez": "roucouler",
    "roucouleriez": "roucouler",
    "roucoulerions": "roucouler",
    "roucoulerons": "roucouler",
    "roucouleront": "roucouler",
    "roucoules": "roucouler",
    "roucoulez": "roucouler",
    "roucouliez": "roucouler",
    "roucoulions": "roucouler",
    "roucoulons": "roucouler",
    "roucoulâmes": "roucouler",
    "roucoulât": "roucouler",
    "roucoulâtes": "roucouler",
    "roucoulèrent": "roucouler",
    "roucoulé": "roucouler",
    "roucoulée": "roucouler",
    "roucoulées": "roucouler",
    "roucoulés": "roucouler",
    "roudoudous": "roudoudou",
    "roue": "rouer",
    "rouelles": "rouelle",
    "rouennaise": "rouennais",
    "rouenneries": "rouennerie",
    "rouent": "rouer",
    "rouera": "rouer",
    "rouerai": "rouer",
    "roueraient": "rouer",
    "rouerais": "rouer",
    "rouerait": "rouer",
    "roueras": "rouer",
    "rouerez": "rouer",
    "roueries": "rouerie",
    "roueriez": "rouer",
    "rouerions": "rouer",
    "rouerons": "rouer",
    "roueront": "rouer",
    "roues": "rouer",
    "rouets": "rouet",
    "rouez": "rouer",
    "rouflaquettes": "rouflaquette",
    "roufs": "rouf",
    "rougeaude": "rougeaud",
    "rougeaudes": "rougeaud",
    "rougeauds": "rougeaud",
    "rougeoie": "rougeoyer",
    "rougeoiements": "rougeoiement",
    "rougeoient": "rougeoyer",
    "rougeoiera": "rougeoyer",
    "rougeoierai": "rougeoyer",
    "rougeoieraient": "rougeoyer",
    "rougeoierais": "rougeoyer",
    "rougeoierait": "rougeoyer",
    "rougeoieras": "rougeoyer",
    "rougeoierez": "rougeoyer",
    "rougeoieriez": "rougeoyer",
    "rougeoierions": "rougeoyer",
    "rougeoierons": "rougeoyer",
    "rougeoieront": "rougeoyer",
    "rougeoies": "rougeoyer",
    "rougeoles": "rougeole",
    "rougeoya": "rougeoyer",
    "rougeoyai": "rougeoyer",
    "rougeoyaient": "rougeoyer",
    "rougeoyais": "rougeoyer",
    "rougeoyait": "rougeoyer",
    "rougeoyant": "rougeoyer",
    "rougeoyante": "rougeoyant",
    "rougeoyantes": "rougeoyant",
    "rougeoyants": "rougeoyant",
    "rougeoyas": "rougeoyer",
    "rougeoyasse": "rougeoyer",
    "rougeoyassent": "rougeoyer",
    "rougeoyasses": "rougeoyer",
    "rougeoyassiez": "rougeoyer",
    "rougeoyassions": "rougeoyer",
    "rougeoyez": "rougeoyer",
    "rougeoyiez": "rougeoyer",
    "rougeoyions": "rougeoyer",
    "rougeoyons": "rougeoyer",
    "rougeoyâmes": "rougeoyer",
    "rougeoyât": "rougeoyer",
    "rougeoyâtes": "rougeoyer",
    "rougeoyèrent": "rougeoyer",
    "rougeoyé": "rougeoyer",
    "rougeoyée": "rougeoyer",
    "rougeoyées": "rougeoyer",
    "rougeoyés": "rougeoyer",
    "rouges": "rouge",
    "rouges-gorges": "rouge-gorge",
    "rouges-queues": "rouge-queue",
    "rougets": "rouget",
    "rougeurs": "rougeur",
    "rougeâtres": "rougeâtre",
    "rougi": "rougir",
    "rougie": "rougir",
    "rougies": "rougir",
    "rougira": "rougir",
    "rougirai": "rougir",
    "rougiraient": "rougir",
    "rougirais": "rougir",
    "rougirait": "rougir",
    "rougiras": "rougir",
    "rougirent": "rougir",
    "rougirez": "rougir",
    "rougiriez": "rougir",
    "rougirions": "rougir",
    "rougirons": "rougir",
    "rougiront": "rougir",
    "rougis": "rougir",
    "rougissaient": "rougir",
    "rougissais": "rougir",
    "rougissait": "rougir",
    "rougissant": "rougir",
    "rougissante": "rougissant",
    "rougissantes": "rougissant",
    "rougissants": "rougissant",
    "rougisse": "rougir",
    "rougissements": "rougissement",
    "rougissent": "rougir",
    "rougisses": "rougir",
    "rougissez": "rougir",
    "rougissiez": "rougir",
    "rougissions": "rougir",
    "rougissons": "rougir",
    "rougit": "rougir",
    "rougîmes": "rougir",
    "rougît": "rougir",
    "rougîtes": "rougir",
    "roui": "rouir",
    "rouie": "rouir",
    "rouies": "rouir",
    "rouiez": "rouer",
    "rouilla": "rouiller",
    "rouillai": "rouiller",
    "rouillaient": "rouiller",
    "rouillais": "rouiller",
    "rouillait": "rouiller",
    "rouillant": "rouiller",
    "rouillas": "rouiller",
    "rouillasse": "rouiller",
    "rouillassent": "rouiller",
    "rouillasses": "rouiller",
    "rouillassiez": "rouiller",
    "rouillassions": "rouiller",
    "rouille": "rouiller",
    "rouillent": "rouiller",
    "rouillera": "rouiller",
    "rouillerai": "rouiller",
    "rouilleraient": "rouiller",
    "rouillerais": "rouiller",
    "rouillerait": "rouiller",
    "rouilleras": "rouiller",
    "rouillerez": "rouiller",
    "rouilleriez": "rouiller",
    "rouillerions": "rouiller",
    "rouillerons": "rouiller",
    "rouilleront": "rouiller",
    "rouilles": "rouiller",
    "rouillez": "rouiller",
    "rouilliez": "rouiller",
    "rouillions": "rouiller",
    "rouillons": "rouiller",
    "rouillures": "rouillure",
    "rouillâmes": "rouiller",
    "rouillât": "rouiller",
    "rouillâtes": "rouiller",
    "rouillèrent": "rouiller",
    "rouillé": "rouiller",
    "rouillée": "rouiller",
    "rouillées": "rouiller",
    "rouillés": "rouiller",
    "rouions": "rouer",
    "rouira": "rouir",
    "rouirai": "rouir",
    "rouiraient": "rouir",
    "rouirais": "rouir",
    "rouirait": "rouir",
    "rouiras": "rouir",
    "rouirent": "rouir",
    "rouirez": "rouir",
    "rouiriez": "rouir",
    "rouirions": "rouir",
    "rouirons": "rouir",
    "rouiront": "rouir",
    "rouis": "rouir",
    "rouissaient": "rouir",
    "rouissais": "rouir",
    "rouissait": "rouir",
    "rouissant": "rouir",
    "rouisse": "rouir",
    "rouissent": "rouir",
    "rouisses": "rouir",
    "rouissez": "rouir",
    "rouissiez": "rouir",
    "rouissions": "rouir",
    "rouissons": "rouir",
    "rouit": "rouir",
    "roula": "rouler",
    "roulades": "roulade",
    "roulages": "roulage",
    "roulai": "rouler",
    "roulaient": "rouler",
    "roulais": "rouler",
    "roulait": "rouler",
    "roulant": "rouler",
    "roulante": "roulant",
    "roulantes": "roulante",
    "roulants": "roulant",
    "roulas": "rouler",
    "roulasse": "rouler",
    "roulassent": "rouler",
    "roulasses": "rouler",
    "roulassiez": "rouler",
    "roulassions": "rouler",
    "roule": "rouler",
    "rouleaux": "rouleau",
    "roulements": "roulement",
    "roulent": "rouler",
    "roulera": "rouler",
    "roulerai": "rouler",
    "rouleraient": "rouler",
    "roulerais": "rouler",
    "roulerait": "rouler",
    "rouleras": "rouler",
    "roulerez": "rouler",
    "rouleriez": "rouler",
    "roulerions": "rouler",
    "roulerons": "rouler",
    "rouleront": "rouler",
    "roules": "rouler",
    "roulettes": "roulette",
    "rouleurs": "rouleur",
    "rouleuse": "rouleur",
    "rouleuses": "rouleur",
    "roulez": "rouler",
    "rouliers": "roulier",
    "rouliez": "rouler",
    "roulions": "rouler",
    "roulons": "rouler",
    "roulottait": "roulotter",
    "roulottent": "roulotter",
    "roulottes": "roulotte",
    "roulottiers": "roulottier",
    "roulottière": "roulottier",
    "roulures": "roulure",
    "roulâmes": "rouler",
    "roulât": "rouler",
    "roulâtes": "rouler",
    "roulèrent": "rouler",
    "roulé": "rouler",
    "roulée": "rouler",
    "roulées": "rouler",
    "roulés": "rouler",
    "roulés-boulés": "roulé-boulé",
    "roumaine": "roumain",
    "roumaines": "roumain",
    "roumains": "roumain",
    "roumis": "roumi",
    "rounds": "round",
    "rouons": "rouer",
    "roupies": "roupie",
    "roupilla": "roupiller",
    "roupillai": "roupiller",
    "roupillaient": "roupiller",
    "roupillais": "roupiller",
    "roupillait": "roupiller",
    "roupillant": "roupiller",
    "roupillas": "roupiller",
    "roupillasse": "roupiller",
    "roupillassent": "roupiller",
    "roupillasses": "roupiller",
    "roupillassiez": "roupiller",
    "roupillassions": "roupiller",
    "roupille": "roupiller",
    "roupillent": "roupiller",
    "roupillera": "roupiller",
    "roupillerai": "roupiller",
    "roupilleraient": "roupiller",
    "roupillerais": "roupiller",
    "roupillerait": "roupiller",
    "roupilleras": "roupiller",
    "roupillerez": "roupiller",
    "roupilleriez": "roupiller",
    "roupillerions": "roupiller",
    "roupillerons": "roupiller",
    "roupilleront": "roupiller",
    "roupilles": "roupiller",
    "roupillez": "roupiller",
    "roupilliez": "roupiller",
    "roupillions": "roupiller",
    "roupillons": "roupillon",
    "roupillâmes": "roupiller",
    "roupillât": "roupiller",
    "roupillâtes": "roupiller",
    "roupillèrent": "roupiller",
    "roupillé": "roupiller",
    "rouquine": "rouquin",
    "rouquines": "rouquin",
    "rouquins": "rouquin",
    "rouscaillait": "rouscailler",
    "rouscaillant": "rouscailler",
    "rouscaille": "rouscailler",
    "rouscaillent": "rouscailler",
    "rouspète": "rouspéter",
    "rouspètent": "rouspéter",
    "rouspètes": "rouspéter",
    "rouspéta": "rouspéter",
    "rouspétai": "rouspéter",
    "rouspétaient": "rouspéter",
    "rouspétais": "rouspéter",
    "rouspétait": "rouspéter",
    "rouspétant": "rouspéter",
    "rouspétas": "rouspéter",
    "rouspétasse": "rouspéter",
    "rouspétassent": "rouspéter",
    "rouspétasses": "rouspéter",
    "rouspétassiez": "rouspéter",
    "rouspétassions": "rouspéter",
    "rouspétera": "rouspéter",
    "rouspéterai": "rouspéter",
    "rouspéteraient": "rouspéter",
    "rouspéterais": "rouspéter",
    "rouspéterait": "rouspéter",
    "rouspéteras": "rouspéter",
    "rouspéterez": "rouspéter",
    "rouspéteriez": "rouspéter",
    "rouspéterions": "rouspéter",
    "rouspéterons": "rouspéter",
    "rouspéteront": "rouspéter",
    "rouspéteurs": "rouspéteur",
    "rouspéteuse": "rouspéteur",
    "rouspéteuses": "rouspéteur",
    "rouspétez": "rouspéter",
    "rouspétiez": "rouspéter",
    "rouspétions": "rouspéter",
    "rouspétons": "rouspéter",
    "rouspétâmes": "rouspéter",
    "rouspétât": "rouspéter",
    "rouspétâtes": "rouspéter",
    "rouspétèrent": "rouspéter",
    "rouspété": "rouspéter",
    "rousse": "roux",
    "rousseaux": "rousseau",
    "rousselée": "rousseler",
    "rousserolles": "rousserolle",
    "rousses": "roux",
    "roussettes": "roussette",
    "rousseurs": "rousseur",
    "roussi": "roussir",
    "roussie": "roussir",
    "roussies": "roussir",
    "roussins": "roussin",
    "roussira": "roussir",
    "roussirai": "roussir",
    "roussiraient": "roussir",
    "roussirais": "roussir",
    "roussirait": "roussir",
    "roussiras": "roussir",
    "roussirent": "roussir",
    "roussirez": "roussir",
    "roussiriez": "roussir",
    "roussirions": "roussir",
    "roussirons": "roussir",
    "roussiront": "roussir",
    "roussis": "roussir",
    "roussissaient": "roussir",
    "roussissais": "roussir",
    "roussissait": "roussir",
    "roussissant": "roussir",
    "roussisse": "roussir",
    "roussissent": "roussir",
    "roussisses": "roussir",
    "roussissez": "roussir",
    "roussissiez": "roussir",
    "roussissions": "roussir",
    "roussissons": "roussir",
    "roussissures": "roussissure",
    "roussit": "roussir",
    "roussâtres": "roussâtre",
    "roussé": "rousser",
    "roussîmes": "roussir",
    "roussît": "roussir",
    "roussîtes": "roussir",
    "roustes": "rouste",
    "rousti": "roustir",
    "roustie": "roustir",
    "rousties": "roustir",
    "roustira": "roustir",
    "roustirai": "roustir",
    "roustiraient": "roustir",
    "roustirais": "roustir",
    "roustirait": "roustir",
    "roustiras": "roustir",
    "roustirent": "roustir",
    "roustirez": "roustir",
    "roustiriez": "roustir",
    "roustirions": "roustir",
    "roustirons": "roustir",
    "roustiront": "roustir",
    "roustis": "roustir",
    "roustissaient": "roustir",
    "roustissais": "roustir",
    "roustissait": "roustir",
    "roustissant": "roustir",
    "roustisse": "roustir",
    "roustissent": "roustir",
    "roustisses": "roustir",
    "roustissez": "roustir",
    "roustissiez": "roustir",
    "roustissions": "roustir",
    "roustissons": "roustir",
    "roustit": "roustir",
    "roustîmes": "roustir",
    "roustît": "roustir",
    "roustîtes": "roustir",
    "routa": "router",
    "routages": "routage",
    "routai": "router",
    "routaient": "router",
    "routais": "router",
    "routait": "router",
    "routant": "router",
    "routarde": "routard",
    "routards": "routard",
    "routas": "router",
    "routasse": "router",
    "routassent": "router",
    "routasses": "router",
    "routassiez": "router",
    "routassions": "router",
    "route": "router",
    "routent": "router",
    "routera": "router",
    "routerai": "router",
    "routeraient": "router",
    "routerais": "router",
    "routerait": "router",
    "routeras": "router",
    "routerez": "router",
    "routeriez": "router",
    "routerions": "router",
    "routerons": "router",
    "routeront": "router",
    "routes": "router",
    "routeurs": "routeur",
    "routez": "router",
    "routiers": "routier",
    "routiez": "router",
    "routines": "routine",
    "routiniers": "routinier",
    "routinière": "routinier",
    "routinières": "routinier",
    "routions": "router",
    "routière": "routier",
    "routières": "routier",
    "routons": "router",
    "routâmes": "router",
    "routât": "router",
    "routâtes": "router",
    "routèrent": "router",
    "routé": "router",
    "routée": "router",
    "routées": "router",
    "routés": "router",
    "rouverains": "rouverain",
    "rouverins": "rouverin",
    "rouvert": "rouvrir",
    "rouverte": "rouvrir",
    "rouvertes": "rouvrir",
    "rouverts": "rouvrir",
    "rouvraient": "rouvrir",
    "rouvrais": "rouvrir",
    "rouvrait": "rouvrir",
    "rouvrant": "rouvrir",
    "rouvre": "rouvrir",
    "rouvrent": "rouvrir",
    "rouvres": "rouvrir",
    "rouvrez": "rouvrir",
    "rouvriez": "rouvrir",
    "rouvrions": "rouvrir",
    "rouvrira": "rouvrir",
    "rouvrirai": "rouvrir",
    "rouvriraient": "rouvrir",
    "rouvrirais": "rouvrir",
    "rouvrirait": "rouvrir",
    "rouvriras": "rouvrir",
    "rouvrirent": "rouvrir",
    "rouvrirez": "rouvrir",
    "rouvririez": "rouvrir",
    "rouvririons": "rouvrir",
    "rouvrirons": "rouvrir",
    "rouvriront": "rouvrir",
    "rouvris": "rouvrir",
    "rouvrisse": "rouvrir",
    "rouvrissent": "rouvrir",
    "rouvrisses": "rouvrir",
    "rouvrissiez": "rouvrir",
    "rouvrissions": "rouvrir",
    "rouvrit": "rouvrir",
    "rouvrons": "rouvrir",
    "rouvrîmes": "rouvrir",
    "rouvrît": "rouvrir",
    "rouvrîtes": "rouvrir",
    "rouâmes": "rouer",
    "rouât": "rouer",
    "rouâtes": "rouer",
    "rouèrent": "rouer",
    "roué": "rouer",
    "rouée": "rouer",
    "rouées": "rouer",
    "roués": "rouer",
    "rouîmes": "rouir",
    "rouît": "rouir",
    "rouîtes": "rouir",
    "rowings": "rowing",
    "royale": "royal",
    "royales": "royale",
    "royalistes": "royaliste",
    "royaumes": "royaume",
    "royautés": "royauté",
    "royaux": "royal",
    "rua": "ruer",
    "ruades": "ruade",
    "ruai": "ruer",
    "ruaient": "ruer",
    "ruais": "ruer",
    "ruait": "ruer",
    "ruant": "ruer",
    "ruas": "ruer",
    "ruasse": "ruer",
    "ruassent": "ruer",
    "ruasses": "ruer",
    "ruassiez": "ruer",
    "ruassions": "ruer",
    "rubaneries": "rubanerie",
    "rubans": "ruban",
    "rubiconde": "rubicond",
    "rubicondes": "rubicond",
    "rubiconds": "rubicond",
    "rubriques": "rubrique",
    "rubénienne": "rubénien",
    "rubéoles": "rubéole",
    "ruchers": "rucher",
    "ruches": "ruche",
    "ruché": "rucher",
    "ruchée": "ruché",
    "rudes": "rude",
    "rudesses": "rudesse",
    "rudimentaires": "rudimentaire",
    "rudiments": "rudiment",
    "rudoie": "rudoyer",
    "rudoiements": "rudoiement",
    "rudoient": "rudoyer",
    "rudoiera": "rudoyer",
    "rudoierai": "rudoyer",
    "rudoieraient": "rudoyer",
    "rudoierais": "rudoyer",
    "rudoierait": "rudoyer",
    "rudoieras": "rudoyer",
    "rudoierez": "rudoyer",
    "rudoieriez": "rudoyer",
    "rudoierions": "rudoyer",
    "rudoierons": "rudoyer",
    "rudoieront": "rudoyer",
    "rudoies": "rudoyer",
    "rudoya": "rudoyer",
    "rudoyai": "rudoyer",
    "rudoyaient": "rudoyer",
    "rudoyais": "rudoyer",
    "rudoyait": "rudoyer",
    "rudoyant": "rudoyer",
    "rudoyas": "rudoyer",
    "rudoyasse": "rudoyer",
    "rudoyassent": "rudoyer",
    "rudoyasses": "rudoyer",
    "rudoyassiez": "rudoyer",
    "rudoyassions": "rudoyer",
    "rudoyez": "rudoyer",
    "rudoyiez": "rudoyer",
    "rudoyions": "rudoyer",
    "rudoyons": "rudoyer",
    "rudoyâmes": "rudoyer",
    "rudoyât": "rudoyer",
    "rudoyâtes": "rudoyer",
    "rudoyèrent": "rudoyer",
    "rudoyé": "rudoyer",
    "rudoyée": "rudoyer",
    "rudoyées": "rudoyer",
    "rudoyés": "rudoyer",
    "rudérale": "rudéral",
    "rudérales": "rudéral",
    "rudéraux": "rudéral",
    "rue": "ruer",
    "ruelles": "ruelle",
    "ruent": "ruer",
    "ruera": "ruer",
    "ruerai": "ruer",
    "rueraient": "ruer",
    "ruerais": "ruer",
    "ruerait": "ruer",
    "rueras": "ruer",
    "ruerez": "ruer",
    "rueriez": "ruer",
    "ruerions": "ruer",
    "ruerons": "ruer",
    "rueront": "ruer",
    "rues": "ruer",
    "ruez": "ruer",
    "ruffians": "ruffian",
    "rugbymans": "rugbyman",
    "rugbymen": "rugbyman",
    "rugbys": "rugby",
    "rugi": "rugir",
    "rugie": "rugir",
    "rugies": "rugir",
    "rugines": "rugine",
    "rugira": "rugir",
    "rugirai": "rugir",
    "rugiraient": "rugir",
    "rugirais": "rugir",
    "rugirait": "rugir",
    "rugiras": "rugir",
    "rugirent": "rugir",
    "rugirez": "rugir",
    "rugiriez": "rugir",
    "rugirions": "rugir",
    "rugirons": "rugir",
    "rugiront": "rugir",
    "rugis": "rugir",
    "rugissaient": "rugir",
    "rugissais": "rugir",
    "rugissait": "rugir",
    "rugissant": "rugir",
    "rugissante": "rugissant",
    "rugissantes": "rugissant",
    "rugissants": "rugissant",
    "rugisse": "rugir",
    "rugissements": "rugissement",
    "rugissent": "rugir",
    "rugisses": "rugir",
    "rugissez": "rugir",
    "rugissiez": "rugir",
    "rugissions": "rugir",
    "rugissons": "rugir",
    "rugit": "rugir",
    "rugosités": "rugosité",
    "rugueuse": "rugueux",
    "rugueuses": "rugueux",
    "rugîmes": "rugir",
    "rugît": "rugir",
    "rugîtes": "rugir",
    "ruiez": "ruer",
    "ruina": "ruiner",
    "ruinai": "ruiner",
    "ruinaient": "ruiner",
    "ruinais": "ruiner",
    "ruinait": "ruiner",
    "ruinant": "ruiner",
    "ruinas": "ruiner",
    "ruinasse": "ruiner",
    "ruinassent": "ruiner",
    "ruinasses": "ruiner",
    "ruinassiez": "ruiner",
    "ruinassions": "ruiner",
    "ruine": "ruiner",
    "ruinent": "ruiner",
    "ruinera": "ruiner",
    "ruinerai": "ruiner",
    "ruineraient": "ruiner",
    "ruinerais": "ruiner",
    "ruinerait": "ruiner",
    "ruineras": "ruiner",
    "ruinerez": "ruiner",
    "ruineriez": "ruiner",
    "ruinerions": "ruiner",
    "ruinerons": "ruiner",
    "ruineront": "ruiner",
    "ruines": "ruiner",
    "ruineuse": "ruineux",
    "ruineuses": "ruineux",
    "ruinez": "ruiner",
    "ruiniez": "ruiner",
    "ruinions": "ruiner",
    "ruinons": "ruiner",
    "ruinâmes": "ruiner",
    "ruinât": "ruiner",
    "ruinâtes": "ruiner",
    "ruinèrent": "ruiner",
    "ruiné": "ruiner",
    "ruinée": "ruiner",
    "ruinées": "ruiner",
    "ruinés": "ruiner",
    "ruions": "ruer",
    "ruisseaux": "ruisseau",
    "ruissela": "ruisseler",
    "ruisselai": "ruisseler",
    "ruisselaient": "ruisseler",
    "ruisselais": "ruisseler",
    "ruisselait": "ruisseler",
    "ruisselant": "ruisseler",
    "ruisselante": "ruisselant",
    "ruisselantes": "ruisselant",
    "ruisselants": "ruisselant",
    "ruisselas": "ruisseler",
    "ruisselasse": "ruisseler",
    "ruisselassent": "ruisseler",
    "ruisselasses": "ruisseler",
    "ruisselassiez": "ruisseler",
    "ruisselassions": "ruisseler",
    "ruisselets": "ruisselet",
    "ruisselez": "ruisseler",
    "ruisseliez": "ruisseler",
    "ruisselions": "ruisseler",
    "ruisselle": "ruisseler",
    "ruissellements": "ruissellement",
    "ruissellent": "ruisseler",
    "ruissellera": "ruisseler",
    "ruissellerai": "ruisseler",
    "ruisselleraient": "ruisseler",
    "ruissellerais": "ruisseler",
    "ruissellerait": "ruisseler",
    "ruisselleras": "ruisseler",
    "ruissellerez": "ruisseler",
    "ruisselleriez": "ruisseler",
    "ruissellerions": "ruisseler",
    "ruissellerons": "ruisseler",
    "ruisselleront": "ruisseler",
    "ruisselles": "ruisseler",
    "ruisselons": "ruisseler",
    "ruisselâmes": "ruisseler",
    "ruisselât": "ruisseler",
    "ruisselâtes": "ruisseler",
    "ruisselèrent": "ruisseler",
    "ruisselé": "ruisseler",
    "rumbas": "rumba",
    "rumeurs": "rumeur",
    "rumina": "ruminer",
    "ruminai": "ruminer",
    "ruminaient": "ruminer",
    "ruminais": "ruminer",
    "ruminait": "ruminer",
    "ruminant": "ruminer",
    "ruminante": "ruminant",
    "ruminantes": "ruminant",
    "ruminants": "ruminant",
    "ruminas": "ruminer",
    "ruminasse": "ruminer",
    "ruminassent": "ruminer",
    "ruminasses": "ruminer",
    "ruminassiez": "ruminer",
    "ruminassions": "ruminer",
    "ruminations": "rumination",
    "rumine": "ruminer",
    "ruminements": "ruminement",
    "ruminent": "ruminer",
    "ruminera": "ruminer",
    "ruminerai": "ruminer",
    "rumineraient": "ruminer",
    "ruminerais": "ruminer",
    "ruminerait": "ruminer",
    "rumineras": "ruminer",
    "ruminerez": "ruminer",
    "rumineriez": "ruminer",
    "ruminerions": "ruminer",
    "ruminerons": "ruminer",
    "rumineront": "ruminer",
    "rumines": "ruminer",
    "ruminez": "ruminer",
    "ruminiez": "ruminer",
    "ruminions": "ruminer",
    "ruminons": "ruminer",
    "ruminâmes": "ruminer",
    "ruminât": "ruminer",
    "ruminâtes": "ruminer",
    "ruminèrent": "ruminer",
    "ruminé": "ruminer",
    "ruminée": "ruminer",
    "ruminées": "ruminer",
    "ruminés": "ruminer",
    "rumstecks": "rumsteck",
    "runabouts": "runabout",
    "runes": "rune",
    "runiques": "runique",
    "ruons": "ruer",
    "rupestres": "rupestre",
    "rupinasse": "rupiner",
    "rupine": "rupin",
    "rupines": "rupin",
    "rupiniez": "rupiner",
    "rupins": "rupin",
    "ruptures": "rupture",
    "rurale": "rural",
    "rurales": "rural",
    "ruraux": "rural",
    "rus": "ru",
    "rusa": "ruser",
    "rusai": "ruser",
    "rusaient": "ruser",
    "rusais": "ruser",
    "rusait": "ruser",
    "rusant": "ruser",
    "rusas": "ruser",
    "rusasse": "ruser",
    "rusassent": "ruser",
    "rusasses": "ruser",
    "rusassiez": "ruser",
    "rusassions": "ruser",
    "ruse": "ruser",
    "rusent": "ruser",
    "rusera": "ruser",
    "ruserai": "ruser",
    "ruseraient": "ruser",
    "ruserais": "ruser",
    "ruserait": "ruser",
    "ruseras": "ruser",
    "ruserez": "ruser",
    "ruseriez": "ruser",
    "ruserions": "ruser",
    "ruserons": "ruser",
    "ruseront": "ruser",
    "ruses": "ruser",
    "rusez": "ruser",
    "rushes": "rush",
    "rushs": "rush",
    "rusiez": "ruser",
    "rusions": "ruser",
    "rusons": "ruser",
    "russes": "russe",
    "russifiant": "russifier",
    "russifié": "russifier",
    "russifiée": "russifier",
    "russo-allemande": "russo-allemand",
    "russo-japonaise": "russo-japonais",
    "russo-polonaise": "russo-polonais",
    "russophones": "russophone",
    "russules": "russule",
    "rustaude": "rustaud",
    "rustaudes": "rustaud",
    "rustauds": "rustaud",
    "rustines": "rustine",
    "rustique": "rustiquer",
    "rustiques": "rustique",
    "rustres": "rustre",
    "rusâmes": "ruser",
    "rusât": "ruser",
    "rusâtes": "ruser",
    "rusèrent": "ruser",
    "rusé": "ruser",
    "rusée": "ruser",
    "rusées": "ruser",
    "rusés": "ruser",
    "rutabagas": "rutabaga",
    "ruthéniums": "ruthénium",
    "rutila": "rutiler",
    "rutilai": "rutiler",
    "rutilaient": "rutiler",
    "rutilais": "rutiler",
    "rutilait": "rutiler",
    "rutilances": "rutilance",
    "rutilant": "rutiler",
    "rutilante": "rutilant",
    "rutilantes": "rutilant",
    "rutilants": "rutilant",
    "rutilas": "rutiler",
    "rutilasse": "rutiler",
    "rutilassent": "rutiler",
    "rutilasses": "rutiler",
    "rutilassiez": "rutiler",
    "rutilassions": "rutiler",
    "rutile": "rutiler",
    "rutilent": "rutiler",
    "rutilera": "rutiler",
    "rutilerai": "rutiler",
    "rutileraient": "rutiler",
    "rutilerais": "rutiler",
    "rutilerait": "rutiler",
    "rutileras": "rutiler",
    "rutilerez": "rutiler",
    "rutileriez": "rutiler",
    "rutilerions": "rutiler",
    "rutilerons": "rutiler",
    "rutileront": "rutiler",
    "rutiles": "rutiler",
    "rutilez": "rutiler",
    "rutiliez": "rutiler",
    "rutilions": "rutiler",
    "rutilons": "rutiler",
    "rutilâmes": "rutiler",
    "rutilât": "rutiler",
    "rutilâtes": "rutiler",
    "rutilèrent": "rutiler",
    "rutilé": "rutiler",
    "ruâmes": "ruer",
    "ruât": "ruer",
    "ruâtes": "ruer",
    "ruèrent": "ruer",
    "rué": "ruer",
    "ruée": "ruer",
    "ruées": "ruer",
    "rués": "ruer",
    "rythmaient": "rythmer",
    "rythmait": "rythmer",
    "rythmant": "rythmer",
    "rythme": "rythmer",
    "rythment": "rythmer",
    "rythmera": "rythmer",
    "rythmes": "rythme",
    "rythmiques": "rythmique",
    "rythmé": "rythmer",
    "rythmée": "rythmer",
    "rythmées": "rythmer",
    "rythmés": "rythmer",
    "râbles": "râble",
    "râblé": "râbler",
    "râblée": "râblé",
    "râblées": "râblé",
    "râblés": "râbler",
    "râclements": "râclement",
    "râla": "râler",
    "râlai": "râler",
    "râlaient": "râler",
    "râlais": "râler",
    "râlait": "râler",
    "râlant": "râler",
    "râlante": "râlant",
    "râlas": "râler",
    "râlasse": "râler",
    "râlassent": "râler",
    "râlasses": "râler",
    "râlassiez": "râler",
    "râlassions": "râler",
    "râle": "râler",
    "râlent": "râler",
    "râlera": "râler",
    "râlerai": "râler",
    "râleraient": "râler",
    "râlerais": "râler",
    "râlerait": "râler",
    "râleras": "râler",
    "râlerez": "râler",
    "râleriez": "râler",
    "râlerions": "râler",
    "râlerons": "râler",
    "râleront": "râler",
    "râles": "râler",
    "râleurs": "râleur",
    "râleuse": "râleux",
    "râleuses": "râleur",
    "râlez": "râler",
    "râliez": "râler",
    "râlions": "râler",
    "râlons": "râler",
    "râlâmes": "râler",
    "râlât": "râler",
    "râlâtes": "râler",
    "râlèrent": "râler",
    "râlé": "râler",
    "râpa": "râper",
    "râpai": "râper",
    "râpaient": "râper",
    "râpais": "râper",
    "râpait": "râper",
    "râpant": "râper",
    "râpas": "râper",
    "râpasse": "râper",
    "râpassent": "râper",
    "râpasses": "râper",
    "râpassiez": "râper",
    "râpassions": "râper",
    "râpe": "râper",
    "râpent": "râper",
    "râpera": "râper",
    "râperai": "râper",
    "râperaient": "râper",
    "râperais": "râper",
    "râperait": "râper",
    "râperas": "râper",
    "râperez": "râper",
    "râperiez": "râper",
    "râperions": "râper",
    "râperons": "râper",
    "râperont": "râper",
    "râpes": "râper",
    "râpeuse": "râpeux",
    "râpeuses": "râpeux",
    "râpez": "râper",
    "râpiez": "râper",
    "râpions": "râper",
    "râpons": "râper",
    "râpâmes": "râper",
    "râpât": "râper",
    "râpâtes": "râper",
    "râpèrent": "râper",
    "râpé": "râper",
    "râpée": "râper",
    "râpées": "râper",
    "râpés": "râper",
    "râteaux": "râteau",
    "râtela": "râteler",
    "râtelai": "râteler",
    "râtelaient": "râteler",
    "râtelais": "râteler",
    "râtelait": "râteler",
    "râtelant": "râteler",
    "râtelas": "râteler",
    "râtelasse": "râteler",
    "râtelassent": "râteler",
    "râtelasses": "râteler",
    "râtelassiez": "râteler",
    "râtelassions": "râteler",
    "râtelez": "râteler",
    "râteliers": "râtelier",
    "râteliez": "râteler",
    "râtelions": "râteler",
    "râtelle": "râteler",
    "râtellent": "râteler",
    "râtellera": "râteler",
    "râtellerai": "râteler",
    "râtelleraient": "râteler",
    "râtellerais": "râteler",
    "râtellerait": "râteler",
    "râtelleras": "râteler",
    "râtellerez": "râteler",
    "râtelleriez": "râteler",
    "râtellerions": "râteler",
    "râtellerons": "râteler",
    "râtelleront": "râteler",
    "râtelles": "râteler",
    "râtelons": "râteler",
    "râtelâmes": "râteler",
    "râtelât": "râteler",
    "râtelâtes": "râteler",
    "râtelèrent": "râteler",
    "râtelé": "râteler",
    "râtelée": "râteler",
    "râtelées": "râteler",
    "râtelés": "râteler",
    "règle": "régler",
    "règlementations": "règlementation",
    "règlements": "règlement",
    "règlent": "régler",
    "règles": "régler",
    "règne": "régner",
    "règnent": "régner",
    "règnes": "régner",
    "réa": "réer",
    "réabonna": "réabonner",
    "réabonnai": "réabonner",
    "réabonnaient": "réabonner",
    "réabonnais": "réabonner",
    "réabonnait": "réabonner",
    "réabonnant": "réabonner",
    "réabonnas": "réabonner",
    "réabonnasse": "réabonner",
    "réabonnassent": "réabonner",
    "réabonnasses": "réabonner",
    "réabonnassiez": "réabonner",
    "réabonnassions": "réabonner",
    "réabonne": "réabonner",
    "réabonnent": "réabonner",
    "réabonnera": "réabonner",
    "réabonnerai": "réabonner",
    "réabonneraient": "réabonner",
    "réabonnerais": "réabonner",
    "réabonnerait": "réabonner",
    "réabonneras": "réabonner",
    "réabonnerez": "réabonner",
    "réabonneriez": "réabonner",
    "réabonnerions": "réabonner",
    "réabonnerons": "réabonner",
    "réabonneront": "réabonner",
    "réabonnes": "réabonner",
    "réabonnez": "réabonner",
    "réabonniez": "réabonner",
    "réabonnions": "réabonner",
    "réabonnons": "réabonner",
    "réabonnâmes": "réabonner",
    "réabonnât": "réabonner",
    "réabonnâtes": "réabonner",
    "réabonnèrent": "réabonner",
    "réabonné": "réabonner",
    "réabonnée": "réabonner",
    "réabonnées": "réabonner",
    "réabonnés": "réabonner",
    "réabsorba": "réabsorber",
    "réabsorbai": "réabsorber",
    "réabsorbaient": "réabsorber",
    "réabsorbais": "réabsorber",
    "réabsorbait": "réabsorber",
    "réabsorbant": "réabsorber",
    "réabsorbas": "réabsorber",
    "réabsorbasse": "réabsorber",
    "réabsorbassent": "réabsorber",
    "réabsorbasses": "réabsorber",
    "réabsorbassiez": "réabsorber",
    "réabsorbassions": "réabsorber",
    "réabsorbe": "réabsorber",
    "réabsorbent": "réabsorber",
    "réabsorbera": "réabsorber",
    "réabsorberai": "réabsorber",
    "réabsorberaient": "réabsorber",
    "réabsorberais": "réabsorber",
    "réabsorberait": "réabsorber",
    "réabsorberas": "réabsorber",
    "réabsorberez": "réabsorber",
    "réabsorberiez": "réabsorber",
    "réabsorberions": "réabsorber",
    "réabsorberons": "réabsorber",
    "réabsorberont": "réabsorber",
    "réabsorbes": "réabsorber",
    "réabsorbez": "réabsorber",
    "réabsorbiez": "réabsorber",
    "réabsorbions": "réabsorber",
    "réabsorbons": "réabsorber",
    "réabsorbâmes": "réabsorber",
    "réabsorbât": "réabsorber",
    "réabsorbâtes": "réabsorber",
    "réabsorbèrent": "réabsorber",
    "réabsorbé": "réabsorber",
    "réabsorbée": "réabsorber",
    "réabsorbées": "réabsorber",
    "réabsorbés": "réabsorber",
    "réaccoutuma": "réaccoutumer",
    "réaccoutumai": "réaccoutumer",
    "réaccoutumaient": "réaccoutumer",
    "réaccoutumais": "réaccoutumer",
    "réaccoutumait": "réaccoutumer",
    "réaccoutumant": "réaccoutumer",
    "réaccoutumas": "réaccoutumer",
    "réaccoutumasse": "réaccoutumer",
    "réaccoutumassent": "réaccoutumer",
    "réaccoutumasses": "réaccoutumer",
    "réaccoutumassiez": "réaccoutumer",
    "réaccoutumassions": "réaccoutumer",
    "réaccoutume": "réaccoutumer",
    "réaccoutument": "réaccoutumer",
    "réaccoutumera": "réaccoutumer",
    "réaccoutumerai": "réaccoutumer",
    "réaccoutumeraient": "réaccoutumer",
    "réaccoutumerais": "réaccoutumer",
    "réaccoutumerait": "réaccoutumer",
    "réaccoutumeras": "réaccoutumer",
    "réaccoutumerez": "réaccoutumer",
    "réaccoutumeriez": "réaccoutumer",
    "réaccoutumerions": "réaccoutumer",
    "réaccoutumerons": "réaccoutumer",
    "réaccoutumeront": "réaccoutumer",
    "réaccoutumes": "réaccoutumer",
    "réaccoutumez": "réaccoutumer",
    "réaccoutumiez": "réaccoutumer",
    "réaccoutumions": "réaccoutumer",
    "réaccoutumons": "réaccoutumer",
    "réaccoutumâmes": "réaccoutumer",
    "réaccoutumât": "réaccoutumer",
    "réaccoutumâtes": "réaccoutumer",
    "réaccoutumèrent": "réaccoutumer",
    "réaccoutumé": "réaccoutumer",
    "réaccoutumée": "réaccoutumer",
    "réaccoutumées": "réaccoutumer",
    "réaccoutumés": "réaccoutumer",
    "réacs": "réac",
    "réacteurs": "réacteur",
    "réactifs": "réactif",
    "réactionnaires": "réactionnaire",
    "réactions": "réaction",
    "réactiva": "réactiver",
    "réactivai": "réactiver",
    "réactivaient": "réactiver",
    "réactivais": "réactiver",
    "réactivait": "réactiver",
    "réactivant": "réactiver",
    "réactivas": "réactiver",
    "réactivasse": "réactiver",
    "réactivassent": "réactiver",
    "réactivasses": "réactiver",
    "réactivassiez": "réactiver",
    "réactivassions": "réactiver",
    "réactive": "réactiver",
    "réactivent": "réactiver",
    "réactivera": "réactiver",
    "réactiverai": "réactiver",
    "réactiveraient": "réactiver",
    "réactiverais": "réactiver",
    "réactiverait": "réactiver",
    "réactiveras": "réactiver",
    "réactiverez": "réactiver",
    "réactiveriez": "réactiver",
    "réactiverions": "réactiver",
    "réactiverons": "réactiver",
    "réactiveront": "réactiver",
    "réactives": "réactiver",
    "réactivez": "réactiver",
    "réactiviez": "réactiver",
    "réactivions": "réactiver",
    "réactivités": "réactivité",
    "réactivons": "réactiver",
    "réactivâmes": "réactiver",
    "réactivât": "réactiver",
    "réactivâtes": "réactiver",
    "réactivèrent": "réactiver",
    "réactivé": "réactiver",
    "réactivée": "réactiver",
    "réactivées": "réactiver",
    "réactivés": "réactiver",
    "réactualisa": "réactualiser",
    "réactualisai": "réactualiser",
    "réactualisaient": "réactualiser",
    "réactualisais": "réactualiser",
    "réactualisait": "réactualiser",
    "réactualisant": "réactualiser",
    "réactualisas": "réactualiser",
    "réactualisasse": "réactualiser",
    "réactualisassent": "réactualiser",
    "réactualisasses": "réactualiser",
    "réactualisassiez": "réactualiser",
    "réactualisassions": "réactualiser",
    "réactualisations": "réactualisation",
    "réactualise": "réactualiser",
    "réactualisent": "réactualiser",
    "réactualisera": "réactualiser",
    "réactualiserai": "réactualiser",
    "réactualiseraient": "réactualiser",
    "réactualiserais": "réactualiser",
    "réactualiserait": "réactualiser",
    "réactualiseras": "réactualiser",
    "réactualiserez": "réactualiser",
    "réactualiseriez": "réactualiser",
    "réactualiserions": "réactualiser",
    "réactualiserons": "réactualiser",
    "réactualiseront": "réactualiser",
    "réactualises": "réactualiser",
    "réactualisez": "réactualiser",
    "réactualisiez": "réactualiser",
    "réactualisions": "réactualiser",
    "réactualisons": "réactualiser",
    "réactualisâmes": "réactualiser",
    "réactualisât": "réactualiser",
    "réactualisâtes": "réactualiser",
    "réactualisèrent": "réactualiser",
    "réactualisé": "réactualiser",
    "réactualisée": "réactualiser",
    "réactualisées": "réactualiser",
    "réactualisés": "réactualiser",
    "réadapta": "réadapter",
    "réadaptai": "réadapter",
    "réadaptaient": "réadapter",
    "réadaptais": "réadapter",
    "réadaptait": "réadapter",
    "réadaptant": "réadapter",
    "réadaptas": "réadapter",
    "réadaptasse": "réadapter",
    "réadaptassent": "réadapter",
    "réadaptasses": "réadapter",
    "réadaptassiez": "réadapter",
    "réadaptassions": "réadapter",
    "réadaptations": "réadaptation",
    "réadapte": "réadapter",
    "réadaptent": "réadapter",
    "réadaptera": "réadapter",
    "réadapterai": "réadapter",
    "réadapteraient": "réadapter",
    "réadapterais": "réadapter",
    "réadapterait": "réadapter",
    "réadapteras": "réadapter",
    "réadapterez": "réadapter",
    "réadapteriez": "réadapter",
    "réadapterions": "réadapter",
    "réadapterons": "réadapter",
    "réadapteront": "réadapter",
    "réadaptes": "réadapter",
    "réadaptez": "réadapter",
    "réadaptiez": "réadapter",
    "réadaptions": "réadapter",
    "réadaptons": "réadapter",
    "réadaptâmes": "réadapter",
    "réadaptât": "réadapter",
    "réadaptâtes": "réadapter",
    "réadaptèrent": "réadapter",
    "réadapté": "réadapter",
    "réadaptée": "réadapter",
    "réadaptées": "réadapter",
    "réadaptés": "réadapter",
    "réadmet": "réadmettre",
    "réadmets": "réadmettre",
    "réadmettaient": "réadmettre",
    "réadmettais": "réadmettre",
    "réadmettait": "réadmettre",
    "réadmettant": "réadmettre",
    "réadmette": "réadmettre",
    "réadmettent": "réadmettre",
    "réadmettes": "réadmettre",
    "réadmettez": "réadmettre",
    "réadmettiez": "réadmettre",
    "réadmettions": "réadmettre",
    "réadmettons": "réadmettre",
    "réadmettra": "réadmettre",
    "réadmettrai": "réadmettre",
    "réadmettraient": "réadmettre",
    "réadmettrais": "réadmettre",
    "réadmettrait": "réadmettre",
    "réadmettras": "réadmettre",
    "réadmettrez": "réadmettre",
    "réadmettriez": "réadmettre",
    "réadmettrions": "réadmettre",
    "réadmettrons": "réadmettre",
    "réadmettront": "réadmettre",
    "réadmirent": "réadmettre",
    "réadmis": "réadmettre",
    "réadmise": "réadmettre",
    "réadmises": "réadmettre",
    "réadmisse": "réadmettre",
    "réadmissent": "réadmettre",
    "réadmisses": "réadmettre",
    "réadmissiez": "réadmettre",
    "réadmissions": "réadmettre",
    "réadmit": "réadmettre",
    "réadmîmes": "réadmettre",
    "réadmît": "réadmettre",
    "réadmîtes": "réadmettre",
    "réaffecta": "réaffecter",
    "réaffectai": "réaffecter",
    "réaffectaient": "réaffecter",
    "réaffectais": "réaffecter",
    "réaffectait": "réaffecter",
    "réaffectant": "réaffecter",
    "réaffectas": "réaffecter",
    "réaffectasse": "réaffecter",
    "réaffectassent": "réaffecter",
    "réaffectasses": "réaffecter",
    "réaffectassiez": "réaffecter",
    "réaffectassions": "réaffecter",
    "réaffectations": "réaffectation",
    "réaffecte": "réaffecter",
    "réaffectent": "réaffecter",
    "réaffectera": "réaffecter",
    "réaffecterai": "réaffecter",
    "réaffecteraient": "réaffecter",
    "réaffecterais": "réaffecter",
    "réaffecterait": "réaffecter",
    "réaffecteras": "réaffecter",
    "réaffecterez": "réaffecter",
    "réaffecteriez": "réaffecter",
    "réaffecterions": "réaffecter",
    "réaffecterons": "réaffecter",
    "réaffecteront": "réaffecter",
    "réaffectes": "réaffecter",
    "réaffectez": "réaffecter",
    "réaffectiez": "réaffecter",
    "réaffections": "réaffection",
    "réaffectons": "réaffecter",
    "réaffectâmes": "réaffecter",
    "réaffectât": "réaffecter",
    "réaffectâtes": "réaffecter",
    "réaffectèrent": "réaffecter",
    "réaffecté": "réaffecter",
    "réaffectée": "réaffecter",
    "réaffectées": "réaffecter",
    "réaffectés": "réaffecter",
    "réaffichées": "réafficher",
    "réaffirma": "réaffirmer",
    "réaffirmai": "réaffirmer",
    "réaffirmaient": "réaffirmer",
    "réaffirmais": "réaffirmer",
    "réaffirmait": "réaffirmer",
    "réaffirmant": "réaffirmer",
    "réaffirmas": "réaffirmer",
    "réaffirmasse": "réaffirmer",
    "réaffirmassent": "réaffirmer",
    "réaffirmasses": "réaffirmer",
    "réaffirmassiez": "réaffirmer",
    "réaffirmassions": "réaffirmer",
    "réaffirmations": "réaffirmation",
    "réaffirme": "réaffirmer",
    "réaffirment": "réaffirmer",
    "réaffirmera": "réaffirmer",
    "réaffirmerai": "réaffirmer",
    "réaffirmeraient": "réaffirmer",
    "réaffirmerais": "réaffirmer",
    "réaffirmerait": "réaffirmer",
    "réaffirmeras": "réaffirmer",
    "réaffirmerez": "réaffirmer",
    "réaffirmeriez": "réaffirmer",
    "réaffirmerions": "réaffirmer",
    "réaffirmerons": "réaffirmer",
    "réaffirmeront": "réaffirmer",
    "réaffirmes": "réaffirmer",
    "réaffirmez": "réaffirmer",
    "réaffirmiez": "réaffirmer",
    "réaffirmions": "réaffirmer",
    "réaffirmons": "réaffirmer",
    "réaffirmâmes": "réaffirmer",
    "réaffirmât": "réaffirmer",
    "réaffirmâtes": "réaffirmer",
    "réaffirmèrent": "réaffirmer",
    "réaffirmé": "réaffirmer",
    "réaffirmée": "réaffirmer",
    "réaffirmées": "réaffirmer",
    "réaffirmés": "réaffirmer",
    "réaffûtée": "réaffûter",
    "réagi": "réagir",
    "réagira": "réagir",
    "réagirai": "réagir",
    "réagiraient": "réagir",
    "réagirais": "réagir",
    "réagirait": "réagir",
    "réagiras": "réagir",
    "réagirent": "réagir",
    "réagirez": "réagir",
    "réagiriez": "réagir",
    "réagirions": "réagir",
    "réagirons": "réagir",
    "réagiront": "réagir",
    "réagis": "réagir",
    "réagissaient": "réagir",
    "réagissais": "réagir",
    "réagissait": "réagir",
    "réagissant": "réagir",
    "réagissante": "réagissant",
    "réagisse": "réagir",
    "réagissent": "réagir",
    "réagisses": "réagir",
    "réagissez": "réagir",
    "réagissiez": "réagir",
    "réagissions": "réagir",
    "réagissons": "réagir",
    "réagit": "réagir",
    "réagîmes": "réagir",
    "réagît": "réagir",
    "réagîtes": "réagir",
    "réait": "réer",
    "réajusta": "réajuster",
    "réajustai": "réajuster",
    "réajustaient": "réajuster",
    "réajustais": "réajuster",
    "réajustait": "réajuster",
    "réajustant": "réajuster",
    "réajustas": "réajuster",
    "réajustasse": "réajuster",
    "réajustassent": "réajuster",
    "réajustasses": "réajuster",
    "réajustassiez": "réajuster",
    "réajustassions": "réajuster",
    "réajuste": "réajuster",
    "réajustements": "réajustement",
    "réajustent": "réajuster",
    "réajustera": "réajuster",
    "réajusterai": "réajuster",
    "réajusteraient": "réajuster",
    "réajusterais": "réajuster",
    "réajusterait": "réajuster",
    "réajusteras": "réajuster",
    "réajusterez": "réajuster",
    "réajusteriez": "réajuster",
    "réajusterions": "réajuster",
    "réajusterons": "réajuster",
    "réajusteront": "réajuster",
    "réajustes": "réajuster",
    "réajustez": "réajuster",
    "réajustiez": "réajuster",
    "réajustions": "réajuster",
    "réajustons": "réajuster",
    "réajustâmes": "réajuster",
    "réajustât": "réajuster",
    "réajustâtes": "réajuster",
    "réajustèrent": "réajuster",
    "réajusté": "réajuster",
    "réajustée": "réajuster",
    "réajustées": "réajuster",
    "réajustés": "réajuster",
    "réaligne": "réaligner",
    "réalignements": "réalignement",
    "réalisa": "réaliser",
    "réalisables": "réalisable",
    "réalisai": "réaliser",
    "réalisaient": "réaliser",
    "réalisais": "réaliser",
    "réalisait": "réaliser",
    "réalisant": "réaliser",
    "réalisas": "réaliser",
    "réalisasse": "réaliser",
    "réalisassent": "réaliser",
    "réalisasses": "réaliser",
    "réalisassiez": "réaliser",
    "réalisassions": "réaliser",
    "réalisateurs": "réalisateur",
    "réalisations": "réalisation",
    "réalisatrice": "réalisateur",
    "réalisatrices": "réalisateur",
    "réalise": "réaliser",
    "réalisent": "réaliser",
    "réalisera": "réaliser",
    "réaliserai": "réaliser",
    "réaliseraient": "réaliser",
    "réaliserais": "réaliser",
    "réaliserait": "réaliser",
    "réaliseras": "réaliser",
    "réaliserez": "réaliser",
    "réaliseriez": "réaliser",
    "réaliserions": "réaliser",
    "réaliserons": "réaliser",
    "réaliseront": "réaliser",
    "réalises": "réaliser",
    "réalisez": "réaliser",
    "réalisiez": "réaliser",
    "réalisions": "réaliser",
    "réalismes": "réalisme",
    "réalisons": "réaliser",
    "réalistes": "réaliste",
    "réalisâmes": "réaliser",
    "réalisât": "réaliser",
    "réalisâtes": "réaliser",
    "réalisèrent": "réaliser",
    "réalisé": "réaliser",
    "réalisée": "réaliser",
    "réalisées": "réaliser",
    "réalisés": "réaliser",
    "réalités": "réalité",
    "réallocations": "réallocation",
    "réalèse": "réaléser",
    "réalèsent": "réaléser",
    "réalèses": "réaléser",
    "réalésa": "réaléser",
    "réalésai": "réaléser",
    "réalésaient": "réaléser",
    "réalésais": "réaléser",
    "réalésait": "réaléser",
    "réalésant": "réaléser",
    "réalésas": "réaléser",
    "réalésasse": "réaléser",
    "réalésassent": "réaléser",
    "réalésasses": "réaléser",
    "réalésassiez": "réaléser",
    "réalésassions": "réaléser",
    "réalésera": "réaléser",
    "réaléserai": "réaléser",
    "réaléseraient": "réaléser",
    "réaléserais": "réaléser",
    "réaléserait": "réaléser",
    "réaléseras": "réaléser",
    "réaléserez": "réaléser",
    "réaléseriez": "réaléser",
    "réaléserions": "réaléser",
    "réaléserons": "réaléser",
    "réaléseront": "réaléser",
    "réalésez": "réaléser",
    "réalésiez": "réaléser",
    "réalésions": "réaléser",
    "réalésons": "réaléser",
    "réalésâmes": "réaléser",
    "réalésât": "réaléser",
    "réalésâtes": "réaléser",
    "réalésèrent": "réaléser",
    "réalésé": "réaléser",
    "réalésée": "réaléser",
    "réalésées": "réaléser",
    "réalésés": "réaléser",
    "réamorce": "réamorcer",
    "réamorcent": "réamorcer",
    "réamorçait": "réamorcer",
    "réaménage": "réaménager",
    "réaménagea": "réaménager",
    "réaménageai": "réaménager",
    "réaménageaient": "réaménager",
    "réaménageais": "réaménager",
    "réaménageait": "réaménager",
    "réaménageant": "réaménager",
    "réaménageas": "réaménager",
    "réaménageasse": "réaménager",
    "réaménageassent": "réaménager",
    "réaménageasses": "réaménager",
    "réaménageassiez": "réaménager",
    "réaménageassions": "réaménager",
    "réaménagements": "réaménagement",
    "réaménagent": "réaménager",
    "réaménageons": "réaménager",
    "réaménagera": "réaménager",
    "réaménagerai": "réaménager",
    "réaménageraient": "réaménager",
    "réaménagerais": "réaménager",
    "réaménagerait": "réaménager",
    "réaménageras": "réaménager",
    "réaménagerez": "réaménager",
    "réaménageriez": "réaménager",
    "réaménagerions": "réaménager",
    "réaménagerons": "réaménager",
    "réaménageront": "réaménager",
    "réaménages": "réaménager",
    "réaménagez": "réaménager",
    "réaménageâmes": "réaménager",
    "réaménageât": "réaménager",
    "réaménageâtes": "réaménager",
    "réaménagiez": "réaménager",
    "réaménagions": "réaménager",
    "réaménagèrent": "réaménager",
    "réaménagé": "réaménager",
    "réaménagée": "réaménager",
    "réaménagées": "réaménager",
    "réaménagés": "réaménager",
    "réanima": "réanimer",
    "réanimai": "réanimer",
    "réanimaient": "réanimer",
    "réanimais": "réanimer",
    "réanimait": "réanimer",
    "réanimant": "réanimer",
    "réanimas": "réanimer",
    "réanimasse": "réanimer",
    "réanimassent": "réanimer",
    "réanimasses": "réanimer",
    "réanimassiez": "réanimer",
    "réanimassions": "réanimer",
    "réanimations": "réanimation",
    "réanime": "réanimer",
    "réaniment": "réanimer",
    "réanimera": "réanimer",
    "réanimerai": "réanimer",
    "réanimeraient": "réanimer",
    "réanimerais": "réanimer",
    "réanimerait": "réanimer",
    "réanimeras": "réanimer",
    "réanimerez": "réanimer",
    "réanimeriez": "réanimer",
    "réanimerions": "réanimer",
    "réanimerons": "réanimer",
    "réanimeront": "réanimer",
    "réanimes": "réanimer",
    "réanimez": "réanimer",
    "réanimiez": "réanimer",
    "réanimions": "réanimer",
    "réanimons": "réanimer",
    "réanimâmes": "réanimer",
    "réanimât": "réanimer",
    "réanimâtes": "réanimer",
    "réanimèrent": "réanimer",
    "réanimé": "réanimer",
    "réanimée": "réanimer",
    "réanimées": "réanimer",
    "réanimés": "réanimer",
    "réapparais": "réapparaître",
    "réapparaissaient": "réapparaître",
    "réapparaissais": "réapparaître",
    "réapparaissait": "réapparaître",
    "réapparaissant": "réapparaître",
    "réapparaisse": "réapparaître",
    "réapparaissent": "réapparaître",
    "réapparaisses": "réapparaître",
    "réapparaissez": "réapparaître",
    "réapparaissiez": "réapparaître",
    "réapparaissions": "réapparaître",
    "réapparaissons": "réapparaître",
    "réapparaît": "réapparaître",
    "réapparaîtra": "réapparaître",
    "réapparaîtrai": "réapparaître",
    "réapparaîtraient": "réapparaître",
    "réapparaîtrais": "réapparaître",
    "réapparaîtrait": "réapparaître",
    "réapparaîtras": "réapparaître",
    "réapparaîtrez": "réapparaître",
    "réapparaîtriez": "réapparaître",
    "réapparaîtrions": "réapparaître",
    "réapparaîtrons": "réapparaître",
    "réapparaîtront": "réapparaître",
    "réapparitions": "réapparition",
    "réapparu": "réapparaître",
    "réapparue": "réapparaître",
    "réapparues": "réapparaître",
    "réapparurent": "réapparaître",
    "réapparus": "réapparaître",
    "réapparusse": "réapparaître",
    "réapparussent": "réapparaître",
    "réapparusses": "réapparaître",
    "réapparussiez": "réapparaître",
    "réapparussions": "réapparaître",
    "réapparut": "réapparaître",
    "réapparûmes": "réapparaître",
    "réapparût": "réapparaître",
    "réapparûtes": "réapparaître",
    "réapprenaient": "réapprendre",
    "réapprenais": "réapprendre",
    "réapprenait": "réapprendre",
    "réapprenant": "réapprendre",
    "réapprend": "réapprendre",
    "réapprendra": "réapprendre",
    "réapprendrai": "réapprendre",
    "réapprendraient": "réapprendre",
    "réapprendrais": "réapprendre",
    "réapprendrait": "réapprendre",
    "réapprendras": "réapprendre",
    "réapprendrez": "réapprendre",
    "réapprendriez": "réapprendre",
    "réapprendrions": "réapprendre",
    "réapprendrons": "réapprendre",
    "réapprendront": "réapprendre",
    "réapprends": "réapprendre",
    "réapprenez": "réapprendre",
    "réappreniez": "réapprendre",
    "réapprenions": "réapprendre",
    "réapprenne": "réapprendre",
    "réapprennent": "réapprendre",
    "réapprennes": "réapprendre",
    "réapprenons": "réapprendre",
    "réapprirent": "réapprendre",
    "réappris": "réapprendre",
    "réapprise": "réapprendre",
    "réapprises": "réapprendre",
    "réapprisse": "réapprendre",
    "réapprissent": "réapprendre",
    "réapprisses": "réapprendre",
    "réapprissiez": "réapprendre",
    "réapprissions": "réapprendre",
    "réapprit": "réapprendre",
    "réappropria": "réapproprier",
    "réappropriai": "réapproprier",
    "réappropriaient": "réapproprier",
    "réappropriais": "réapproprier",
    "réappropriait": "réapproprier",
    "réappropriant": "réapproprier",
    "réapproprias": "réapproprier",
    "réappropriasse": "réapproprier",
    "réappropriassent": "réapproprier",
    "réappropriasses": "réapproprier",
    "réappropriassiez": "réapproprier",
    "réappropriassions": "réapproprier",
    "réapproprie": "réapproprier",
    "réapproprient": "réapproprier",
    "réappropriera": "réapproprier",
    "réapproprierai": "réapproprier",
    "réapproprieraient": "réapproprier",
    "réapproprierais": "réapproprier",
    "réapproprierait": "réapproprier",
    "réapproprieras": "réapproprier",
    "réapproprierez": "réapproprier",
    "réapproprieriez": "réapproprier",
    "réapproprierions": "réapproprier",
    "réapproprierons": "réapproprier",
    "réapproprieront": "réapproprier",
    "réappropries": "réapproprier",
    "réappropriez": "réapproprier",
    "réappropriiez": "réapproprier",
    "réappropriions": "réapproprier",
    "réapproprions": "réapproprier",
    "réappropriâmes": "réapproprier",
    "réappropriât": "réapproprier",
    "réappropriâtes": "réapproprier",
    "réapproprièrent": "réapproprier",
    "réapproprié": "réapproprier",
    "réappropriée": "réapproprier",
    "réappropriées": "réapproprier",
    "réappropriés": "réapproprier",
    "réapprovisionna": "réapprovisionner",
    "réapprovisionnai": "réapprovisionner",
    "réapprovisionnaient": "réapprovisionner",
    "réapprovisionnais": "réapprovisionner",
    "réapprovisionnait": "réapprovisionner",
    "réapprovisionnant": "réapprovisionner",
    "réapprovisionnas": "réapprovisionner",
    "réapprovisionnasse": "réapprovisionner",
    "réapprovisionnassent": "réapprovisionner",
    "réapprovisionnasses": "réapprovisionner",
    "réapprovisionnassiez": "réapprovisionner",
    "réapprovisionnassions": "réapprovisionner",
    "réapprovisionne": "réapprovisionner",
    "réapprovisionnements": "réapprovisionnement",
    "réapprovisionnent": "réapprovisionner",
    "réapprovisionnera": "réapprovisionner",
    "réapprovisionnerai": "réapprovisionner",
    "réapprovisionneraient": "réapprovisionner",
    "réapprovisionnerais": "réapprovisionner",
    "réapprovisionnerait": "réapprovisionner",
    "réapprovisionneras": "réapprovisionner",
    "réapprovisionnerez": "réapprovisionner",
    "réapprovisionneriez": "réapprovisionner",
    "réapprovisionnerions": "réapprovisionner",
    "réapprovisionnerons": "réapprovisionner",
    "réapprovisionneront": "réapprovisionner",
    "réapprovisionnes": "réapprovisionner",
    "réapprovisionnez": "réapprovisionner",
    "réapprovisionniez": "réapprovisionner",
    "réapprovisionnions": "réapprovisionner",
    "réapprovisionnons": "réapprovisionner",
    "réapprovisionnâmes": "réapprovisionner",
    "réapprovisionnât": "réapprovisionner",
    "réapprovisionnâtes": "réapprovisionner",
    "réapprovisionnèrent": "réapprovisionner",
    "réapprovisionné": "réapprovisionner",
    "réapprovisionnée": "réapprovisionner",
    "réapprovisionnées": "réapprovisionner",
    "réapprovisionnés": "réapprovisionner",
    "réapprîmes": "réapprendre",
    "réapprît": "réapprendre",
    "réapprîtes": "réapprendre",
    "réargenta": "réargenter",
    "réargentai": "réargenter",
    "réargentaient": "réargenter",
    "réargentais": "réargenter",
    "réargentait": "réargenter",
    "réargentant": "réargenter",
    "réargentas": "réargenter",
    "réargentasse": "réargenter",
    "réargentassent": "réargenter",
    "réargentasses": "réargenter",
    "réargentassiez": "réargenter",
    "réargentassions": "réargenter",
    "réargente": "réargenter",
    "réargentent": "réargenter",
    "réargentera": "réargenter",
    "réargenterai": "réargenter",
    "réargenteraient": "réargenter",
    "réargenterais": "réargenter",
    "réargenterait": "réargenter",
    "réargenteras": "réargenter",
    "réargenterez": "réargenter",
    "réargenteriez": "réargenter",
    "réargenterions": "réargenter",
    "réargenterons": "réargenter",
    "réargenteront": "réargenter",
    "réargentes": "réargenter",
    "réargentez": "réargenter",
    "réargentiez": "réargenter",
    "réargentions": "réargenter",
    "réargentons": "réargenter",
    "réargentâmes": "réargenter",
    "réargentât": "réargenter",
    "réargentâtes": "réargenter",
    "réargentèrent": "réargenter",
    "réargenté": "réargenter",
    "réargentée": "réargenter",
    "réargentées": "réargenter",
    "réargentés": "réargenter",
    "réarma": "réarmer",
    "réarmai": "réarmer",
    "réarmaient": "réarmer",
    "réarmais": "réarmer",
    "réarmait": "réarmer",
    "réarmant": "réarmer",
    "réarmas": "réarmer",
    "réarmasse": "réarmer",
    "réarmassent": "réarmer",
    "réarmasses": "réarmer",
    "réarmassiez": "réarmer",
    "réarmassions": "réarmer",
    "réarme": "réarmer",
    "réarmements": "réarmement",
    "réarment": "réarmer",
    "réarmera": "réarmer",
    "réarmerai": "réarmer",
    "réarmeraient": "réarmer",
    "réarmerais": "réarmer",
    "réarmerait": "réarmer",
    "réarmeras": "réarmer",
    "réarmerez": "réarmer",
    "réarmeriez": "réarmer",
    "réarmerions": "réarmer",
    "réarmerons": "réarmer",
    "réarmeront": "réarmer",
    "réarmes": "réarmer",
    "réarmez": "réarmer",
    "réarmiez": "réarmer",
    "réarmions": "réarmer",
    "réarmons": "réarmer",
    "réarmâmes": "réarmer",
    "réarmât": "réarmer",
    "réarmâtes": "réarmer",
    "réarmèrent": "réarmer",
    "réarmé": "réarmer",
    "réarmée": "réarmer",
    "réarmées": "réarmer",
    "réarmés": "réarmer",
    "réarrange": "réarranger",
    "réarrangea": "réarranger",
    "réarrangeai": "réarranger",
    "réarrangeaient": "réarranger",
    "réarrangeais": "réarranger",
    "réarrangeait": "réarranger",
    "réarrangeant": "réarranger",
    "réarrangeas": "réarranger",
    "réarrangeasse": "réarranger",
    "réarrangeassent": "réarranger",
    "réarrangeasses": "réarranger",
    "réarrangeassiez": "réarranger",
    "réarrangeassions": "réarranger",
    "réarrangent": "réarranger",
    "réarrangeons": "réarranger",
    "réarrangera": "réarranger",
    "réarrangerai": "réarranger",
    "réarrangeraient": "réarranger",
    "réarrangerais": "réarranger",
    "réarrangerait": "réarranger",
    "réarrangeras": "réarranger",
    "réarrangerez": "réarranger",
    "réarrangeriez": "réarranger",
    "réarrangerions": "réarranger",
    "réarrangerons": "réarranger",
    "réarrangeront": "réarranger",
    "réarranges": "réarranger",
    "réarrangez": "réarranger",
    "réarrangeâmes": "réarranger",
    "réarrangeât": "réarranger",
    "réarrangeâtes": "réarranger",
    "réarrangiez": "réarranger",
    "réarrangions": "réarranger",
    "réarrangèrent": "réarranger",
    "réarrangé": "réarranger",
    "réarrangée": "réarranger",
    "réarrangées": "réarranger",
    "réarrangés": "réarranger",
    "réaslisations": "réaslisation",
    "réassigna": "réassigner",
    "réassignai": "réassigner",
    "réassignaient": "réassigner",
    "réassignais": "réassigner",
    "réassignait": "réassigner",
    "réassignant": "réassigner",
    "réassignas": "réassigner",
    "réassignasse": "réassigner",
    "réassignassent": "réassigner",
    "réassignasses": "réassigner",
    "réassignassiez": "réassigner",
    "réassignassions": "réassigner",
    "réassigne": "réassigner",
    "réassignent": "réassigner",
    "réassignera": "réassigner",
    "réassignerai": "réassigner",
    "réassigneraient": "réassigner",
    "réassignerais": "réassigner",
    "réassignerait": "réassigner",
    "réassigneras": "réassigner",
    "réassignerez": "réassigner",
    "réassigneriez": "réassigner",
    "réassignerions": "réassigner",
    "réassignerons": "réassigner",
    "réassigneront": "réassigner",
    "réassignes": "réassigner",
    "réassignez": "réassigner",
    "réassigniez": "réassigner",
    "réassignions": "réassigner",
    "réassignons": "réassigner",
    "réassignâmes": "réassigner",
    "réassignât": "réassigner",
    "réassignâtes": "réassigner",
    "réassignèrent": "réassigner",
    "réassigné": "réassigner",
    "réassignée": "réassigner",
    "réassignées": "réassigner",
    "réassignés": "réassigner",
    "réassimilé": "réassimiler",
    "réassorti": "réassortir",
    "réassortie": "réassortir",
    "réassorties": "réassortir",
    "réassortira": "réassortir",
    "réassortirai": "réassortir",
    "réassortiraient": "réassortir",
    "réassortirais": "réassortir",
    "réassortirait": "réassortir",
    "réassortiras": "réassortir",
    "réassortirent": "réassortir",
    "réassortirez": "réassortir",
    "réassortiriez": "réassortir",
    "réassortirions": "réassortir",
    "réassortirons": "réassortir",
    "réassortiront": "réassortir",
    "réassortis": "réassortir",
    "réassortissaient": "réassortir",
    "réassortissais": "réassortir",
    "réassortissait": "réassortir",
    "réassortissant": "réassortir",
    "réassortisse": "réassortir",
    "réassortissent": "réassortir",
    "réassortisses": "réassortir",
    "réassortissez": "réassortir",
    "réassortissiez": "réassortir",
    "réassortissions": "réassortir",
    "réassortissons": "réassortir",
    "réassortit": "réassortir",
    "réassortîmes": "réassortir",
    "réassortît": "réassortir",
    "réassortîtes": "réassortir",
    "réassujetti": "réassujettir",
    "réassujettie": "réassujettir",
    "réassujetties": "réassujettir",
    "réassujettira": "réassujettir",
    "réassujettirai": "réassujettir",
    "réassujettiraient": "réassujettir",
    "réassujettirais": "réassujettir",
    "réassujettirait": "réassujettir",
    "réassujettiras": "réassujettir",
    "réassujettirent": "réassujettir",
    "réassujettirez": "réassujettir",
    "réassujettiriez": "réassujettir",
    "réassujettirions": "réassujettir",
    "réassujettirons": "réassujettir",
    "réassujettiront": "réassujettir",
    "réassujettis": "réassujettir",
    "réassujettissaient": "réassujettir",
    "réassujettissais": "réassujettir",
    "réassujettissait": "réassujettir",
    "réassujettissant": "réassujettir",
    "réassujettisse": "réassujettir",
    "réassujettissent": "réassujettir",
    "réassujettisses": "réassujettir",
    "réassujettissez": "réassujettir",
    "réassujettissiez": "réassujettir",
    "réassujettissions": "réassujettir",
    "réassujettissons": "réassujettir",
    "réassujettit": "réassujettir",
    "réassujettîmes": "réassujettir",
    "réassujettît": "réassujettir",
    "réassujettîtes": "réassujettir",
    "réassura": "réassurer",
    "réassurai": "réassurer",
    "réassuraient": "réassurer",
    "réassurais": "réassurer",
    "réassurait": "réassurer",
    "réassurances": "réassurance",
    "réassurant": "réassurer",
    "réassuras": "réassurer",
    "réassurasse": "réassurer",
    "réassurassent": "réassurer",
    "réassurasses": "réassurer",
    "réassurassiez": "réassurer",
    "réassurassions": "réassurer",
    "réassure": "réassurer",
    "réassurent": "réassurer",
    "réassurera": "réassurer",
    "réassurerai": "réassurer",
    "réassureraient": "réassurer",
    "réassurerais": "réassurer",
    "réassurerait": "réassurer",
    "réassureras": "réassurer",
    "réassurerez": "réassurer",
    "réassureriez": "réassurer",
    "réassurerions": "réassurer",
    "réassurerons": "réassurer",
    "réassureront": "réassurer",
    "réassures": "réassurer",
    "réassurez": "réassurer",
    "réassuriez": "réassurer",
    "réassurions": "réassurer",
    "réassurons": "réassurer",
    "réassurâmes": "réassurer",
    "réassurât": "réassurer",
    "réassurâtes": "réassurer",
    "réassurèrent": "réassurer",
    "réassuré": "réassurer",
    "réassurée": "réassurer",
    "réassurées": "réassurer",
    "réassurés": "réassurer",
    "réattaquai": "réattaquer",
    "réattaquait": "réattaquer",
    "réattaque": "réattaquer",
    "réattaqué": "réattaquer",
    "réaux": "réal",
    "rébarbatifs": "rébarbatif",
    "rébarbative": "rébarbatif",
    "rébarbatives": "rébarbatif",
    "rébellions": "rébellion",
    "récalcitrante": "récalcitrant",
    "récalcitrantes": "récalcitrant",
    "récalcitrants": "récalcitrant",
    "récapitula": "récapituler",
    "récapitulai": "récapituler",
    "récapitulaient": "récapituler",
    "récapitulais": "récapituler",
    "récapitulait": "récapituler",
    "récapitulant": "récapituler",
    "récapitulas": "récapituler",
    "récapitulasse": "récapituler",
    "récapitulassent": "récapituler",
    "récapitulasses": "récapituler",
    "récapitulassiez": "récapituler",
    "récapitulassions": "récapituler",
    "récapitulatifs": "récapitulatif",
    "récapitulatives": "récapitulatif",
    "récapitule": "récapituler",
    "récapitulent": "récapituler",
    "récapitulera": "récapituler",
    "récapitulerai": "récapituler",
    "récapituleraient": "récapituler",
    "récapitulerais": "récapituler",
    "récapitulerait": "récapituler",
    "récapituleras": "récapituler",
    "récapitulerez": "récapituler",
    "récapituleriez": "récapituler",
    "récapitulerions": "récapituler",
    "récapitulerons": "récapituler",
    "récapituleront": "récapituler",
    "récapitules": "récapituler",
    "récapitulez": "récapituler",
    "récapituliez": "récapituler",
    "récapitulions": "récapituler",
    "récapitulons": "récapituler",
    "récapitulâmes": "récapituler",
    "récapitulât": "récapituler",
    "récapitulâtes": "récapituler",
    "récapitulèrent": "récapituler",
    "récapitulé": "récapituler",
    "récapitulée": "récapituler",
    "récapitulées": "récapituler",
    "récapitulés": "récapituler",
    "récente": "récent",
    "récentes": "récent",
    "récents": "récent",
    "réceptacles": "réceptacle",
    "récepteurs": "récepteur",
    "réceptifs": "réceptif",
    "réceptionna": "réceptionner",
    "réceptionnai": "réceptionner",
    "réceptionnaient": "réceptionner",
    "réceptionnais": "réceptionner",
    "réceptionnait": "réceptionner",
    "réceptionnant": "réceptionner",
    "réceptionnas": "réceptionner",
    "réceptionnasse": "réceptionner",
    "réceptionnassent": "réceptionner",
    "réceptionnasses": "réceptionner",
    "réceptionnassiez": "réceptionner",
    "réceptionnassions": "réceptionner",
    "réceptionne": "réceptionner",
    "réceptionnent": "réceptionner",
    "réceptionnera": "réceptionner",
    "réceptionnerai": "réceptionner",
    "réceptionneraient": "réceptionner",
    "réceptionnerais": "réceptionner",
    "réceptionnerait": "réceptionner",
    "réceptionneras": "réceptionner",
    "réceptionnerez": "réceptionner",
    "réceptionneriez": "réceptionner",
    "réceptionnerions": "réceptionner",
    "réceptionnerons": "réceptionner",
    "réceptionneront": "réceptionner",
    "réceptionnes": "réceptionner",
    "réceptionnez": "réceptionner",
    "réceptionniez": "réceptionner",
    "réceptionnions": "réceptionner",
    "réceptionnistes": "réceptionniste",
    "réceptionnons": "réceptionner",
    "réceptionnâmes": "réceptionner",
    "réceptionnât": "réceptionner",
    "réceptionnâtes": "réceptionner",
    "réceptionnèrent": "réceptionner",
    "réceptionné": "réceptionner",
    "réceptionnée": "réceptionner",
    "réceptionnées": "réceptionner",
    "réceptionnés": "réceptionner",
    "réceptions": "réception",
    "réceptive": "réceptif",
    "réceptives": "réceptif",
    "réceptrice": "récepteur",
    "réceptrices": "récepteur",
    "récessifs": "récessif",
    "récessions": "récession",
    "récessive": "récessif",
    "récessives": "récessif",
    "réchampi": "réchampir",
    "réchampie": "réchampir",
    "réchampies": "réchampir",
    "réchampira": "réchampir",
    "réchampirai": "réchampir",
    "réchampiraient": "réchampir",
    "réchampirais": "réchampir",
    "réchampirait": "réchampir",
    "réchampiras": "réchampir",
    "réchampirent": "réchampir",
    "réchampirez": "réchampir",
    "réchampiriez": "réchampir",
    "réchampirions": "réchampir",
    "réchampirons": "réchampir",
    "réchampiront": "réchampir",
    "réchampis": "réchampir",
    "réchampissaient": "réchampir",
    "réchampissais": "réchampir",
    "réchampissait": "réchampir",
    "réchampissant": "réchampir",
    "réchampisse": "réchampir",
    "réchampissent": "réchampir",
    "réchampisses": "réchampir",
    "réchampissez": "réchampir",
    "réchampissiez": "réchampir",
    "réchampissions": "réchampir",
    "réchampissons": "réchampir",
    "réchampit": "réchampir",
    "réchampîmes": "réchampir",
    "réchampît": "réchampir",
    "réchampîtes": "réchampir",
    "réchappa": "réchapper",
    "réchappai": "réchapper",
    "réchappaient": "réchapper",
    "réchappais": "réchapper",
    "réchappait": "réchapper",
    "réchappant": "réchapper",
    "réchappas": "réchapper",
    "réchappasse": "réchapper",
    "réchappassent": "réchapper",
    "réchappasses": "réchapper",
    "réchappassiez": "réchapper",
    "réchappassions": "réchapper",
    "réchappe": "réchapper",
    "réchappent": "réchapper",
    "réchappera": "réchapper",
    "réchapperai": "réchapper",
    "réchapperaient": "réchapper",
    "réchapperais": "réchapper",
    "réchapperait": "réchapper",
    "réchapperas": "réchapper",
    "réchapperez": "réchapper",
    "réchapperiez": "réchapper",
    "réchapperions": "réchapper",
    "réchapperons": "réchapper",
    "réchapperont": "réchapper",
    "réchappes": "réchapper",
    "réchappez": "réchapper",
    "réchappiez": "réchapper",
    "réchappions": "réchapper",
    "réchappons": "réchapper",
    "réchappâmes": "réchapper",
    "réchappât": "réchapper",
    "réchappâtes": "réchapper",
    "réchappèrent": "réchapper",
    "réchappé": "réchapper",
    "réchappés": "réchapper",
    "réchauds": "réchaud",
    "réchauffa": "réchauffer",
    "réchauffai": "réchauffer",
    "réchauffaient": "réchauffer",
    "réchauffais": "réchauffer",
    "réchauffait": "réchauffer",
    "réchauffant": "réchauffer",
    "réchauffante": "réchauffant",
    "réchauffantes": "réchauffant",
    "réchauffants": "réchauffant",
    "réchauffas": "réchauffer",
    "réchauffasse": "réchauffer",
    "réchauffassent": "réchauffer",
    "réchauffasses": "réchauffer",
    "réchauffassiez": "réchauffer",
    "réchauffassions": "réchauffer",
    "réchauffe": "réchauffer",
    "réchauffements": "réchauffement",
    "réchauffent": "réchauffer",
    "réchauffera": "réchauffer",
    "réchaufferai": "réchauffer",
    "réchaufferaient": "réchauffer",
    "réchaufferais": "réchauffer",
    "réchaufferait": "réchauffer",
    "réchaufferas": "réchauffer",
    "réchaufferez": "réchauffer",
    "réchaufferiez": "réchauffer",
    "réchaufferions": "réchauffer",
    "réchaufferons": "réchauffer",
    "réchaufferont": "réchauffer",
    "réchauffes": "réchauffer",
    "réchauffez": "réchauffer",
    "réchauffiez": "réchauffer",
    "réchauffions": "réchauffer",
    "réchauffons": "réchauffer",
    "réchauffâmes": "réchauffer",
    "réchauffât": "réchauffer",
    "réchauffâtes": "réchauffer",
    "réchauffèrent": "réchauffer",
    "réchauffé": "réchauffer",
    "réchauffée": "réchauffer",
    "réchauffées": "réchauffer",
    "réchauffés": "réchauffer",
    "récidiva": "récidiver",
    "récidivai": "récidiver",
    "récidivaient": "récidiver",
    "récidivais": "récidiver",
    "récidivait": "récidiver",
    "récidivant": "récidiver",
    "récidivante": "récidivant",
    "récidivas": "récidiver",
    "récidivasse": "récidiver",
    "récidivassent": "récidiver",
    "récidivasses": "récidiver",
    "récidivassiez": "récidiver",
    "récidivassions": "récidiver",
    "récidive": "récidiver",
    "récidivent": "récidiver",
    "récidivera": "récidiver",
    "récidiverai": "récidiver",
    "récidiveraient": "récidiver",
    "récidiverais": "récidiver",
    "récidiverait": "récidiver",
    "récidiveras": "récidiver",
    "récidiverez": "récidiver",
    "récidiveriez": "récidiver",
    "récidiverions": "récidiver",
    "récidiverons": "récidiver",
    "récidiveront": "récidiver",
    "récidives": "récidiver",
    "récidivez": "récidiver",
    "récidiviez": "récidiver",
    "récidivions": "récidiver",
    "récidivistes": "récidiviste",
    "récidivons": "récidiver",
    "récidivâmes": "récidiver",
    "récidivât": "récidiver",
    "récidivâtes": "récidiver",
    "récidivèrent": "récidiver",
    "récidivé": "récidiver",
    "récidivée": "récidiver",
    "récidivées": "récidiver",
    "récidivés": "récidiver",
    "récifale": "récifal",
    "récifs": "récif",
    "récipiendaires": "récipiendaire",
    "récipients": "récipient",
    "réciprocités": "réciprocité",
    "réciproques": "réciproquer",
    "récita": "réciter",
    "récitai": "réciter",
    "récitaient": "réciter",
    "récitais": "réciter",
    "récitait": "réciter",
    "récitals": "récital",
    "récitant": "réciter",
    "récitante": "récitant",
    "récitants": "récitant",
    "récitas": "réciter",
    "récitasse": "réciter",
    "récitassent": "réciter",
    "récitasses": "réciter",
    "récitassiez": "réciter",
    "récitassions": "réciter",
    "récitatifs": "récitatif",
    "récitations": "récitation",
    "récite": "réciter",
    "récitent": "réciter",
    "récitera": "réciter",
    "réciterai": "réciter",
    "réciteraient": "réciter",
    "réciterais": "réciter",
    "réciterait": "réciter",
    "réciteras": "réciter",
    "réciterez": "réciter",
    "réciteriez": "réciter",
    "réciterions": "réciter",
    "réciterons": "réciter",
    "réciteront": "réciter",
    "récites": "réciter",
    "récitez": "réciter",
    "récitiez": "réciter",
    "récitions": "réciter",
    "récitons": "réciter",
    "récits": "récit",
    "récitâmes": "réciter",
    "récitât": "réciter",
    "récitâtes": "réciter",
    "récitèrent": "réciter",
    "récité": "réciter",
    "récitée": "réciter",
    "récitées": "réciter",
    "récités": "réciter",
    "réclama": "réclamer",
    "réclamai": "réclamer",
    "réclamaient": "réclamer",
    "réclamais": "réclamer",
    "réclamait": "réclamer",
    "réclamant": "réclamer",
    "réclamantes": "réclamant",
    "réclamas": "réclamer",
    "réclamasse": "réclamer",
    "réclamassent": "réclamer",
    "réclamasses": "réclamer",
    "réclamassiez": "réclamer",
    "réclamassions": "réclamer",
    "réclamations": "réclamation",
    "réclame": "réclamer",
    "réclament": "réclamer",
    "réclamera": "réclamer",
    "réclamerai": "réclamer",
    "réclameraient": "réclamer",
    "réclamerais": "réclamer",
    "réclamerait": "réclamer",
    "réclameras": "réclamer",
    "réclamerez": "réclamer",
    "réclameriez": "réclamer",
    "réclamerions": "réclamer",
    "réclamerons": "réclamer",
    "réclameront": "réclamer",
    "réclames": "réclamer",
    "réclamez": "réclamer",
    "réclamiez": "réclamer",
    "réclamions": "réclamer",
    "réclamons": "réclamer",
    "réclamâmes": "réclamer",
    "réclamât": "réclamer",
    "réclamâtes": "réclamer",
    "réclamèrent": "réclamer",
    "réclamé": "réclamer",
    "réclamée": "réclamer",
    "réclamées": "réclamer",
    "réclamés": "réclamer",
    "réclusionnaires": "réclusionnaire",
    "réclusions": "réclusion",
    "récollets": "récollet",
    "récolta": "récolter",
    "récoltai": "récolter",
    "récoltaient": "récolter",
    "récoltais": "récolter",
    "récoltait": "récolter",
    "récoltant": "récolter",
    "récoltas": "récolter",
    "récoltasse": "récolter",
    "récoltassent": "récolter",
    "récoltasses": "récolter",
    "récoltassiez": "récolter",
    "récoltassions": "récolter",
    "récolte": "récolter",
    "récoltent": "récolter",
    "récoltera": "récolter",
    "récolterai": "récolter",
    "récolteraient": "récolter",
    "récolterais": "récolter",
    "récolterait": "récolter",
    "récolteras": "récolter",
    "récolterez": "récolter",
    "récolteriez": "récolter",
    "récolterions": "récolter",
    "récolterons": "récolter",
    "récolteront": "récolter",
    "récoltes": "récolter",
    "récolteurs": "récolteur",
    "récolteuse": "récolteur",
    "récoltez": "récolter",
    "récoltiez": "récolter",
    "récoltions": "récolter",
    "récoltons": "récolter",
    "récoltâmes": "récolter",
    "récoltât": "récolter",
    "récoltâtes": "récolter",
    "récoltèrent": "récolter",
    "récolté": "récolter",
    "récoltée": "récolter",
    "récoltées": "récolter",
    "récoltés": "récolter",
    "récompensa": "récompenser",
    "récompensai": "récompenser",
    "récompensaient": "récompenser",
    "récompensais": "récompenser",
    "récompensait": "récompenser",
    "récompensant": "récompenser",
    "récompensas": "récompenser",
    "récompensasse": "récompenser",
    "récompensassent": "récompenser",
    "récompensasses": "récompenser",
    "récompensassiez": "récompenser",
    "récompensassions": "récompenser",
    "récompense": "récompenser",
    "récompensent": "récompenser",
    "récompensera": "récompenser",
    "récompenserai": "récompenser",
    "récompenseraient": "récompenser",
    "récompenserais": "récompenser",
    "récompenserait": "récompenser",
    "récompenseras": "récompenser",
    "récompenserez": "récompenser",
    "récompenseriez": "récompenser",
    "récompenserions": "récompenser",
    "récompenserons": "récompenser",
    "récompenseront": "récompenser",
    "récompenses": "récompenser",
    "récompensez": "récompenser",
    "récompensiez": "récompenser",
    "récompensions": "récompenser",
    "récompensons": "récompenser",
    "récompensâmes": "récompenser",
    "récompensât": "récompenser",
    "récompensâtes": "récompenser",
    "récompensèrent": "récompenser",
    "récompensé": "récompenser",
    "récompensée": "récompenser",
    "récompensées": "récompenser",
    "récompensés": "récompenser",
    "réconcilia": "réconcilier",
    "réconciliai": "réconcilier",
    "réconciliaient": "réconcilier",
    "réconciliais": "réconcilier",
    "réconciliait": "réconcilier",
    "réconciliant": "réconcilier",
    "réconcilias": "réconcilier",
    "réconciliasse": "réconcilier",
    "réconciliassent": "réconcilier",
    "réconciliasses": "réconcilier",
    "réconciliassiez": "réconcilier",
    "réconciliassions": "réconcilier",
    "réconciliations": "réconciliation",
    "réconciliatrice": "réconciliateur",
    "réconcilie": "réconcilier",
    "réconcilient": "réconcilier",
    "réconciliera": "réconcilier",
    "réconcilierai": "réconcilier",
    "réconcilieraient": "réconcilier",
    "réconcilierais": "réconcilier",
    "réconcilierait": "réconcilier",
    "réconcilieras": "réconcilier",
    "réconcilierez": "réconcilier",
    "réconcilieriez": "réconcilier",
    "réconcilierions": "réconcilier",
    "réconcilierons": "réconcilier",
    "réconcilieront": "réconcilier",
    "réconcilies": "réconcilier",
    "réconciliez": "réconcilier",
    "réconciliiez": "réconcilier",
    "réconciliions": "réconcilier",
    "réconcilions": "réconcilier",
    "réconciliâmes": "réconcilier",
    "réconciliât": "réconcilier",
    "réconciliâtes": "réconcilier",
    "réconcilièrent": "réconcilier",
    "réconcilié": "réconcilier",
    "réconciliée": "réconcilier",
    "réconciliées": "réconcilier",
    "réconciliés": "réconcilier",
    "réconforta": "réconforter",
    "réconfortai": "réconforter",
    "réconfortaient": "réconforter",
    "réconfortais": "réconforter",
    "réconfortait": "réconforter",
    "réconfortant": "réconforter",
    "réconfortante": "réconfortant",
    "réconfortantes": "réconfortant",
    "réconfortants": "réconfortant",
    "réconfortas": "réconforter",
    "réconfortasse": "réconforter",
    "réconfortassent": "réconforter",
    "réconfortasses": "réconforter",
    "réconfortassiez": "réconforter",
    "réconfortassions": "réconforter",
    "réconforte": "réconforter",
    "réconfortent": "réconforter",
    "réconfortera": "réconforter",
    "réconforterai": "réconforter",
    "réconforteraient": "réconforter",
    "réconforterais": "réconforter",
    "réconforterait": "réconforter",
    "réconforteras": "réconforter",
    "réconforterez": "réconforter",
    "réconforteriez": "réconforter",
    "réconforterions": "réconforter",
    "réconforterons": "réconforter",
    "réconforteront": "réconforter",
    "réconfortes": "réconforter",
    "réconfortez": "réconforter",
    "réconfortiez": "réconforter",
    "réconfortions": "réconforter",
    "réconfortons": "réconforter",
    "réconforts": "réconfort",
    "réconfortâmes": "réconforter",
    "réconfortât": "réconforter",
    "réconfortâtes": "réconforter",
    "réconfortèrent": "réconforter",
    "réconforté": "réconforter",
    "réconfortée": "réconforter",
    "réconfortées": "réconforter",
    "réconfortés": "réconforter",
    "récria": "récrier",
    "récriai": "récrier",
    "récriaient": "récrier",
    "récriais": "récrier",
    "récriait": "récrier",
    "récriant": "récrier",
    "récrias": "récrier",
    "récriasse": "récrier",
    "récriassent": "récrier",
    "récriasses": "récrier",
    "récriassiez": "récrier",
    "récriassions": "récrier",
    "récrie": "récrier",
    "récrient": "récrier",
    "récriera": "récrier",
    "récrierai": "récrier",
    "récrieraient": "récrier",
    "récrierais": "récrier",
    "récrierait": "récrier",
    "récrieras": "récrier",
    "récrierez": "récrier",
    "récrieriez": "récrier",
    "récrierions": "récrier",
    "récrierons": "récrier",
    "récrieront": "récrier",
    "récries": "récrier",
    "récriez": "récrier",
    "récriiez": "récrier",
    "récriions": "récrier",
    "récrimina": "récriminer",
    "récriminai": "récriminer",
    "récriminaient": "récriminer",
    "récriminais": "récriminer",
    "récriminait": "récriminer",
    "récriminant": "récriminer",
    "récriminas": "récriminer",
    "récriminasse": "récriminer",
    "récriminassent": "récriminer",
    "récriminasses": "récriminer",
    "récriminassiez": "récriminer",
    "récriminassions": "récriminer",
    "récriminations": "récrimination",
    "récrimine": "récriminer",
    "récriminent": "récriminer",
    "récriminera": "récriminer",
    "récriminerai": "récriminer",
    "récrimineraient": "récriminer",
    "récriminerais": "récriminer",
    "récriminerait": "récriminer",
    "récrimineras": "récriminer",
    "récriminerez": "récriminer",
    "récrimineriez": "récriminer",
    "récriminerions": "récriminer",
    "récriminerons": "récriminer",
    "récrimineront": "récriminer",
    "récrimines": "récriminer",
    "récriminez": "récriminer",
    "récriminiez": "récriminer",
    "récriminions": "récriminer",
    "récriminons": "récriminer",
    "récriminâmes": "récriminer",
    "récriminât": "récriminer",
    "récriminâtes": "récriminer",
    "récriminèrent": "récriminer",
    "récriminé": "récriminer",
    "récrions": "récrier",
    "récrira": "récrire",
    "récrirai": "récrire",
    "récriraient": "récrire",
    "récrirais": "récrire",
    "récrirait": "récrire",
    "récriras": "récrire",
    "récrirez": "récrire",
    "récririez": "récrire",
    "récririons": "récrire",
    "récrirons": "récrire",
    "récriront": "récrire",
    "récris": "récrire",
    "récrit": "récrire",
    "récrite": "récrire",
    "récrites": "récrire",
    "récrits": "récrire",
    "récrivaient": "récrire",
    "récrivais": "récrire",
    "récrivait": "récrire",
    "récrivant": "récrire",
    "récrive": "récrire",
    "récrivent": "récrire",
    "récrives": "récrire",
    "récrivez": "récrire",
    "récriviez": "récrire",
    "récrivions": "récrire",
    "récrivirent": "récrire",
    "récrivis": "récrire",
    "récrivisse": "récrire",
    "récrivissent": "récrire",
    "récrivisses": "récrire",
    "récrivissiez": "récrire",
    "récrivissions": "récrire",
    "récrivit": "récrire",
    "récrivons": "récrire",
    "récrivîmes": "récrire",
    "récrivît": "récrire",
    "récrivîtes": "récrire",
    "récriâmes": "récrier",
    "récriât": "récrier",
    "récriâtes": "récrier",
    "récrièrent": "récrier",
    "récrié": "récrier",
    "récriée": "récrier",
    "récriées": "récrier",
    "récriés": "récrier",
    "récréa": "récréer",
    "récréai": "récréer",
    "récréaient": "récréer",
    "récréais": "récréer",
    "récréait": "récréer",
    "récréant": "récréer",
    "récréas": "récréer",
    "récréasse": "récréer",
    "récréassent": "récréer",
    "récréasses": "récréer",
    "récréassiez": "récréer",
    "récréassions": "récréer",
    "récréatifs": "récréatif",
    "récréations": "récréation",
    "récréative": "récréatif",
    "récréatives": "récréatif",
    "récrée": "récréer",
    "récréent": "récréer",
    "récréera": "récréer",
    "récréerai": "récréer",
    "récréeraient": "récréer",
    "récréerais": "récréer",
    "récréerait": "récréer",
    "récréeras": "récréer",
    "récréerez": "récréer",
    "récréeriez": "récréer",
    "récréerions": "récréer",
    "récréerons": "récréer",
    "récréeront": "récréer",
    "récrées": "récréer",
    "récréez": "récréer",
    "récréiez": "récréer",
    "récréions": "récréer",
    "récréons": "récréer",
    "récrés": "récré",
    "récréâmes": "récréer",
    "récréât": "récréer",
    "récréâtes": "récréer",
    "récréèrent": "récréer",
    "récréé": "récréer",
    "récréée": "récréer",
    "récréées": "récréer",
    "récréés": "récréer",
    "récupe": "récup",
    "récupère": "récupérer",
    "récupèrent": "récupérer",
    "récupères": "récupérer",
    "récupéra": "récupérer",
    "récupérables": "récupérable",
    "récupérai": "récupérer",
    "récupéraient": "récupérer",
    "récupérais": "récupérer",
    "récupérait": "récupérer",
    "récupérant": "récupérer",
    "récupéras": "récupérer",
    "récupérasse": "récupérer",
    "récupérassent": "récupérer",
    "récupérasses": "récupérer",
    "récupérassiez": "récupérer",
    "récupérassions": "récupérer",
    "récupérateurs": "récupérateur",
    "récupérations": "récupération",
    "récupérera": "récupérer",
    "récupérerai": "récupérer",
    "récupéreraient": "récupérer",
    "récupérerais": "récupérer",
    "récupérerait": "récupérer",
    "récupéreras": "récupérer",
    "récupérerez": "récupérer",
    "récupéreriez": "récupérer",
    "récupérerions": "récupérer",
    "récupérerons": "récupérer",
    "récupéreront": "récupérer",
    "récupérez": "récupérer",
    "récupériez": "récupérer",
    "récupérions": "récupérer",
    "récupérons": "récupérer",
    "récupérâmes": "récupérer",
    "récupérât": "récupérer",
    "récupérâtes": "récupérer",
    "récupérèrent": "récupérer",
    "récupéré": "récupérer",
    "récupérée": "récupérer",
    "récupérées": "récupérer",
    "récupérés": "récupérer",
    "récura": "récurer",
    "récurai": "récurer",
    "récuraient": "récurer",
    "récurais": "récurer",
    "récurait": "récurer",
    "récurant": "récurer",
    "récuras": "récurer",
    "récurasse": "récurer",
    "récurassent": "récurer",
    "récurasses": "récurer",
    "récurassiez": "récurer",
    "récurassions": "récurer",
    "récure": "récurer",
    "récurent": "récurer",
    "récurera": "récurer",
    "récurerai": "récurer",
    "récureraient": "récurer",
    "récurerais": "récurer",
    "récurerait": "récurer",
    "récureras": "récurer",
    "récurerez": "récurer",
    "récureriez": "récurer",
    "récurerions": "récurer",
    "récurerons": "récurer",
    "récureront": "récurer",
    "récures": "récurer",
    "récurez": "récurer",
    "récuriez": "récurer",
    "récurions": "récurer",
    "récurons": "récurer",
    "récurrences": "récurrence",
    "récurrente": "récurrent",
    "récurrentes": "récurrent",
    "récurrents": "récurrent",
    "récurâmes": "récurer",
    "récurât": "récurer",
    "récurâtes": "récurer",
    "récurèrent": "récurer",
    "récuré": "récurer",
    "récurée": "récurer",
    "récurées": "récurer",
    "récurés": "récurer",
    "récusa": "récuser",
    "récusables": "récusable",
    "récusai": "récuser",
    "récusaient": "récuser",
    "récusais": "récuser",
    "récusait": "récuser",
    "récusant": "récuser",
    "récusas": "récuser",
    "récusasse": "récuser",
    "récusassent": "récuser",
    "récusasses": "récuser",
    "récusassiez": "récuser",
    "récusassions": "récuser",
    "récusations": "récusation",
    "récuse": "récuser",
    "récusent": "récuser",
    "récusera": "récuser",
    "récuserai": "récuser",
    "récuseraient": "récuser",
    "récuserais": "récuser",
    "récuserait": "récuser",
    "récuseras": "récuser",
    "récuserez": "récuser",
    "récuseriez": "récuser",
    "récuserions": "récuser",
    "récuserons": "récuser",
    "récuseront": "récuser",
    "récuses": "récuser",
    "récusez": "récuser",
    "récusiez": "récuser",
    "récusions": "récuser",
    "récusons": "récuser",
    "récusâmes": "récuser",
    "récusât": "récuser",
    "récusâtes": "récuser",
    "récusèrent": "récuser",
    "récusé": "récuser",
    "récusée": "récuser",
    "récusées": "récuser",
    "récusés": "récuser",
    "récépissés": "récépissé",
    "rédacteurs": "rédacteur",
    "rédactionnelle": "rédactionnel",
    "rédactionnelles": "rédactionnel",
    "rédactionnels": "rédactionnel",
    "rédactions": "rédaction",
    "rédactrice": "rédacteur",
    "rédactrices": "rédacteur",
    "rédempteurs": "rédempteur",
    "rédemptions": "rédemption",
    "rédemptrice": "rédempteur",
    "rédemptrices": "rédempteur",
    "rédhibitions": "rédhibition",
    "rédhibitoires": "rédhibitoire",
    "rédige": "rédiger",
    "rédigea": "rédiger",
    "rédigeai": "rédiger",
    "rédigeaient": "rédiger",
    "rédigeais": "rédiger",
    "rédigeait": "rédiger",
    "rédigeant": "rédiger",
    "rédigeas": "rédiger",
    "rédigeasse": "rédiger",
    "rédigeassent": "rédiger",
    "rédigeasses": "rédiger",
    "rédigeassiez": "rédiger",
    "rédigeassions": "rédiger",
    "rédigent": "rédiger",
    "rédigeons": "rédiger",
    "rédigera": "rédiger",
    "rédigerai": "rédiger",
    "rédigeraient": "rédiger",
    "rédigerais": "rédiger",
    "rédigerait": "rédiger",
    "rédigeras": "rédiger",
    "rédigerez": "rédiger",
    "rédigeriez": "rédiger",
    "rédigerions": "rédiger",
    "rédigerons": "rédiger",
    "rédigeront": "rédiger",
    "rédiges": "rédiger",
    "rédigez": "rédiger",
    "rédigeâmes": "rédiger",
    "rédigeât": "rédiger",
    "rédigeâtes": "rédiger",
    "rédigiez": "rédiger",
    "rédigions": "rédiger",
    "rédigèrent": "rédiger",
    "rédigé": "rédiger",
    "rédigée": "rédiger",
    "rédigées": "rédiger",
    "rédigés": "rédiger",
    "rédimaient": "rédimer",
    "réducteurs": "réducteur",
    "réductionnismes": "réductionnisme",
    "réductions": "réduction",
    "réductrice": "réducteur",
    "réductrices": "réducteur",
    "réduira": "réduire",
    "réduirai": "réduire",
    "réduiraient": "réduire",
    "réduirais": "réduire",
    "réduirait": "réduire",
    "réduiras": "réduire",
    "réduirez": "réduire",
    "réduiriez": "réduire",
    "réduirions": "réduire",
    "réduirons": "réduire",
    "réduiront": "réduire",
    "réduis": "réduire",
    "réduisaient": "réduire",
    "réduisais": "réduire",
    "réduisait": "réduire",
    "réduisant": "réduire",
    "réduise": "réduire",
    "réduisent": "réduire",
    "réduises": "réduire",
    "réduisez": "réduire",
    "réduisiez": "réduire",
    "réduisions": "réduire",
    "réduisirent": "réduire",
    "réduisis": "réduire",
    "réduisisse": "réduire",
    "réduisissent": "réduire",
    "réduisisses": "réduire",
    "réduisissiez": "réduire",
    "réduisissions": "réduire",
    "réduisit": "réduire",
    "réduisons": "réduire",
    "réduisîmes": "réduire",
    "réduisît": "réduire",
    "réduisîtes": "réduire",
    "réduit": "réduire",
    "réduite": "réduit",
    "réduites": "réduit",
    "réduits": "réduit",
    "réduplications": "réduplication",
    "réelle": "réel",
    "réelles": "réel",
    "réels": "réel",
    "réembarque": "réembarquer",
    "réembaucha": "réembaucher",
    "réembauchai": "réembaucher",
    "réembauchaient": "réembaucher",
    "réembauchais": "réembaucher",
    "réembauchait": "réembaucher",
    "réembauchant": "réembaucher",
    "réembauchas": "réembaucher",
    "réembauchasse": "réembaucher",
    "réembauchassent": "réembaucher",
    "réembauchasses": "réembaucher",
    "réembauchassiez": "réembaucher",
    "réembauchassions": "réembaucher",
    "réembauche": "réembaucher",
    "réembauchent": "réembaucher",
    "réembauchera": "réembaucher",
    "réembaucherai": "réembaucher",
    "réembaucheraient": "réembaucher",
    "réembaucherais": "réembaucher",
    "réembaucherait": "réembaucher",
    "réembaucheras": "réembaucher",
    "réembaucherez": "réembaucher",
    "réembaucheriez": "réembaucher",
    "réembaucherions": "réembaucher",
    "réembaucherons": "réembaucher",
    "réembaucheront": "réembaucher",
    "réembauches": "réembaucher",
    "réembauchez": "réembaucher",
    "réembauchiez": "réembaucher",
    "réembauchions": "réembaucher",
    "réembauchons": "réembaucher",
    "réembauchâmes": "réembaucher",
    "réembauchât": "réembaucher",
    "réembauchâtes": "réembaucher",
    "réembauchèrent": "réembaucher",
    "réembauché": "réembaucher",
    "réembauchée": "réembaucher",
    "réembauchées": "réembaucher",
    "réembauchés": "réembaucher",
    "réemploie": "réemployer",
    "réemploient": "réemployer",
    "réemploiera": "réemployer",
    "réemploierai": "réemployer",
    "réemploieraient": "réemployer",
    "réemploierais": "réemployer",
    "réemploierait": "réemployer",
    "réemploieras": "réemployer",
    "réemploierez": "réemployer",
    "réemploieriez": "réemployer",
    "réemploierions": "réemployer",
    "réemploierons": "réemployer",
    "réemploieront": "réemployer",
    "réemploies": "réemployer",
    "réemplois": "réemploi",
    "réemploya": "réemployer",
    "réemployai": "réemployer",
    "réemployaient": "réemployer",
    "réemployais": "réemployer",
    "réemployait": "réemployer",
    "réemployant": "réemployer",
    "réemployas": "réemployer",
    "réemployasse": "réemployer",
    "réemployassent": "réemployer",
    "réemployasses": "réemployer",
    "réemployassiez": "réemployer",
    "réemployassions": "réemployer",
    "réemployez": "réemployer",
    "réemployiez": "réemployer",
    "réemployions": "réemployer",
    "réemployons": "réemployer",
    "réemployâmes": "réemployer",
    "réemployât": "réemployer",
    "réemployâtes": "réemployer",
    "réemployèrent": "réemployer",
    "réemployé": "réemployer",
    "réemployée": "réemployer",
    "réemployées": "réemployer",
    "réemployés": "réemployer",
    "réenclencha": "réenclencher",
    "réenclenchai": "réenclencher",
    "réenclenchaient": "réenclencher",
    "réenclenchais": "réenclencher",
    "réenclenchait": "réenclencher",
    "réenclenchant": "réenclencher",
    "réenclenchas": "réenclencher",
    "réenclenchasse": "réenclencher",
    "réenclenchassent": "réenclencher",
    "réenclenchasses": "réenclencher",
    "réenclenchassiez": "réenclencher",
    "réenclenchassions": "réenclencher",
    "réenclenche": "réenclencher",
    "réenclenchent": "réenclencher",
    "réenclenchera": "réenclencher",
    "réenclencherai": "réenclencher",
    "réenclencheraient": "réenclencher",
    "réenclencherais": "réenclencher",
    "réenclencherait": "réenclencher",
    "réenclencheras": "réenclencher",
    "réenclencherez": "réenclencher",
    "réenclencheriez": "réenclencher",
    "réenclencherions": "réenclencher",
    "réenclencherons": "réenclencher",
    "réenclencheront": "réenclencher",
    "réenclenches": "réenclencher",
    "réenclenchez": "réenclencher",
    "réenclenchiez": "réenclencher",
    "réenclenchions": "réenclencher",
    "réenclenchons": "réenclencher",
    "réenclenchâmes": "réenclencher",
    "réenclenchât": "réenclencher",
    "réenclenchâtes": "réenclencher",
    "réenclenchèrent": "réenclencher",
    "réenclenché": "réenclencher",
    "réenclenchée": "réenclencher",
    "réenclenchées": "réenclencher",
    "réenclenchés": "réenclencher",
    "réendossant": "réendosser",
    "réengage": "réengager",
    "réengagea": "réengager",
    "réengageai": "réengager",
    "réengageaient": "réengager",
    "réengageais": "réengager",
    "réengageait": "réengager",
    "réengageant": "réengager",
    "réengageas": "réengager",
    "réengageasse": "réengager",
    "réengageassent": "réengager",
    "réengageasses": "réengager",
    "réengageassiez": "réengager",
    "réengageassions": "réengager",
    "réengagent": "réengager",
    "réengageons": "réengager",
    "réengagera": "réengager",
    "réengagerai": "réengager",
    "réengageraient": "réengager",
    "réengagerais": "réengager",
    "réengagerait": "réengager",
    "réengageras": "réengager",
    "réengagerez": "réengager",
    "réengageriez": "réengager",
    "réengagerions": "réengager",
    "réengagerons": "réengager",
    "réengageront": "réengager",
    "réengages": "réengager",
    "réengagez": "réengager",
    "réengageâmes": "réengager",
    "réengageât": "réengager",
    "réengageâtes": "réengager",
    "réengagiez": "réengager",
    "réengagions": "réengager",
    "réengagèrent": "réengager",
    "réengagé": "réengager",
    "réengagée": "réengager",
    "réengagées": "réengager",
    "réengagés": "réengager",
    "réenregistrements": "réenregistrement",
    "réenregistré": "réenregistrer",
    "réensemencements": "réensemencement",
    "réentend": "réentendre",
    "réentendaient": "réentendre",
    "réentendais": "réentendre",
    "réentendait": "réentendre",
    "réentendant": "réentendre",
    "réentende": "réentendre",
    "réentendent": "réentendre",
    "réentendes": "réentendre",
    "réentendez": "réentendre",
    "réentendiez": "réentendre",
    "réentendions": "réentendre",
    "réentendirent": "réentendre",
    "réentendis": "réentendre",
    "réentendisse": "réentendre",
    "réentendissent": "réentendre",
    "réentendisses": "réentendre",
    "réentendissiez": "réentendre",
    "réentendissions": "réentendre",
    "réentendit": "réentendre",
    "réentendons": "réentendre",
    "réentendra": "réentendre",
    "réentendrai": "réentendre",
    "réentendraient": "réentendre",
    "réentendrais": "réentendre",
    "réentendrait": "réentendre",
    "réentendras": "réentendre",
    "réentendrez": "réentendre",
    "réentendriez": "réentendre",
    "réentendrions": "réentendre",
    "réentendrons": "réentendre",
    "réentendront": "réentendre",
    "réentends": "réentendre",
    "réentendu": "réentendre",
    "réentendue": "réentendre",
    "réentendues": "réentendre",
    "réentendus": "réentendre",
    "réentendîmes": "réentendre",
    "réentendît": "réentendre",
    "réentendîtes": "réentendre",
    "réescomptes": "réescompte",
    "réessaie": "réessayer",
    "réessaient": "réessayer",
    "réessaiera": "réessayer",
    "réessaierai": "réessayer",
    "réessaieraient": "réessayer",
    "réessaierais": "réessayer",
    "réessaierait": "réessayer",
    "réessaieras": "réessayer",
    "réessaierez": "réessayer",
    "réessaieriez": "réessayer",
    "réessaierions": "réessayer",
    "réessaierons": "réessayer",
    "réessaieront": "réessayer",
    "réessaies": "réessayer",
    "réessaya": "réessayer",
    "réessayai": "réessayer",
    "réessayaient": "réessayer",
    "réessayais": "réessayer",
    "réessayait": "réessayer",
    "réessayant": "réessayer",
    "réessayas": "réessayer",
    "réessayasse": "réessayer",
    "réessayassent": "réessayer",
    "réessayasses": "réessayer",
    "réessayassiez": "réessayer",
    "réessayassions": "réessayer",
    "réessaye": "réessayer",
    "réessayent": "réessayer",
    "réessayera": "réessayer",
    "réessayerai": "réessayer",
    "réessayeraient": "réessayer",
    "réessayerais": "réessayer",
    "réessayerait": "réessayer",
    "réessayeras": "réessayer",
    "réessayerez": "réessayer",
    "réessayeriez": "réessayer",
    "réessayerions": "réessayer",
    "réessayerons": "réessayer",
    "réessayeront": "réessayer",
    "réessayes": "réessayer",
    "réessayez": "réessayer",
    "réessayiez": "réessayer",
    "réessayions": "réessayer",
    "réessayons": "réessayer",
    "réessayâmes": "réessayer",
    "réessayât": "réessayer",
    "réessayâtes": "réessayer",
    "réessayèrent": "réessayer",
    "réessayé": "réessayer",
    "réessayée": "réessayer",
    "réessayées": "réessayer",
    "réessayés": "réessayer",
    "réexamens": "réexamen",
    "réexamina": "réexaminer",
    "réexaminai": "réexaminer",
    "réexaminaient": "réexaminer",
    "réexaminais": "réexaminer",
    "réexaminait": "réexaminer",
    "réexaminant": "réexaminer",
    "réexaminas": "réexaminer",
    "réexaminasse": "réexaminer",
    "réexaminassent": "réexaminer",
    "réexaminasses": "réexaminer",
    "réexaminassiez": "réexaminer",
    "réexaminassions": "réexaminer",
    "réexamine": "réexaminer",
    "réexaminent": "réexaminer",
    "réexaminera": "réexaminer",
    "réexaminerai": "réexaminer",
    "réexamineraient": "réexaminer",
    "réexaminerais": "réexaminer",
    "réexaminerait": "réexaminer",
    "réexamineras": "réexaminer",
    "réexaminerez": "réexaminer",
    "réexamineriez": "réexaminer",
    "réexaminerions": "réexaminer",
    "réexaminerons": "réexaminer",
    "réexamineront": "réexaminer",
    "réexamines": "réexaminer",
    "réexaminez": "réexaminer",
    "réexaminiez": "réexaminer",
    "réexaminions": "réexaminer",
    "réexaminons": "réexaminer",
    "réexaminâmes": "réexaminer",
    "réexaminât": "réexaminer",
    "réexaminâtes": "réexaminer",
    "réexaminèrent": "réexaminer",
    "réexaminé": "réexaminer",
    "réexaminée": "réexaminer",
    "réexaminées": "réexaminer",
    "réexaminés": "réexaminer",
    "réexporta": "réexporter",
    "réexportai": "réexporter",
    "réexportaient": "réexporter",
    "réexportais": "réexporter",
    "réexportait": "réexporter",
    "réexportant": "réexporter",
    "réexportas": "réexporter",
    "réexportasse": "réexporter",
    "réexportassent": "réexporter",
    "réexportasses": "réexporter",
    "réexportassiez": "réexporter",
    "réexportassions": "réexporter",
    "réexportations": "réexportation",
    "réexporte": "réexporter",
    "réexportent": "réexporter",
    "réexportera": "réexporter",
    "réexporterai": "réexporter",
    "réexporteraient": "réexporter",
    "réexporterais": "réexporter",
    "réexporterait": "réexporter",
    "réexporteras": "réexporter",
    "réexporterez": "réexporter",
    "réexporteriez": "réexporter",
    "réexporterions": "réexporter",
    "réexporterons": "réexporter",
    "réexporteront": "réexporter",
    "réexportes": "réexporter",
    "réexportez": "réexporter",
    "réexportiez": "réexporter",
    "réexportions": "réexporter",
    "réexportons": "réexporter",
    "réexportâmes": "réexporter",
    "réexportât": "réexporter",
    "réexportâtes": "réexporter",
    "réexportèrent": "réexporter",
    "réexporté": "réexporter",
    "réexportée": "réexporter",
    "réexportées": "réexporter",
    "réexportés": "réexporter",
    "réexpédia": "réexpédier",
    "réexpédiai": "réexpédier",
    "réexpédiaient": "réexpédier",
    "réexpédiais": "réexpédier",
    "réexpédiait": "réexpédier",
    "réexpédiant": "réexpédier",
    "réexpédias": "réexpédier",
    "réexpédiasse": "réexpédier",
    "réexpédiassent": "réexpédier",
    "réexpédiasses": "réexpédier",
    "réexpédiassiez": "réexpédier",
    "réexpédiassions": "réexpédier",
    "réexpédie": "réexpédier",
    "réexpédient": "réexpédier",
    "réexpédiera": "réexpédier",
    "réexpédierai": "réexpédier",
    "réexpédieraient": "réexpédier",
    "réexpédierais": "réexpédier",
    "réexpédierait": "réexpédier",
    "réexpédieras": "réexpédier",
    "réexpédierez": "réexpédier",
    "réexpédieriez": "réexpédier",
    "réexpédierions": "réexpédier",
    "réexpédierons": "réexpédier",
    "réexpédieront": "réexpédier",
    "réexpédies": "réexpédier",
    "réexpédiez": "réexpédier",
    "réexpédiiez": "réexpédier",
    "réexpédiions": "réexpédier",
    "réexpédions": "réexpédier",
    "réexpédiâmes": "réexpédier",
    "réexpédiât": "réexpédier",
    "réexpédiâtes": "réexpédier",
    "réexpédièrent": "réexpédier",
    "réexpédié": "réexpédier",
    "réexpédiée": "réexpédier",
    "réexpédiées": "réexpédier",
    "réexpédiés": "réexpédier",
    "réfactions": "réfaction",
    "réfections": "réfection",
    "réfectoires": "réfectoire",
    "réflecteurs": "réflecteur",
    "réflexes": "réflexe",
    "réflexions": "réflexion",
    "réflexive": "réflexif",
    "réflexologistes": "réflexologiste",
    "réfléchi": "réfléchir",
    "réfléchie": "réfléchir",
    "réfléchies": "réfléchir",
    "réfléchira": "réfléchir",
    "réfléchirai": "réfléchir",
    "réfléchiraient": "réfléchir",
    "réfléchirais": "réfléchir",
    "réfléchirait": "réfléchir",
    "réfléchiras": "réfléchir",
    "réfléchirent": "réfléchir",
    "réfléchirez": "réfléchir",
    "réfléchiriez": "réfléchir",
    "réfléchirions": "réfléchir",
    "réfléchirons": "réfléchir",
    "réfléchiront": "réfléchir",
    "réfléchis": "réfléchir",
    "réfléchissaient": "réfléchir",
    "réfléchissais": "réfléchir",
    "réfléchissait": "réfléchir",
    "réfléchissant": "réfléchir",
    "réfléchissante": "réfléchissant",
    "réfléchissantes": "réfléchissant",
    "réfléchissants": "réfléchissant",
    "réfléchisse": "réfléchir",
    "réfléchissent": "réfléchir",
    "réfléchisses": "réfléchir",
    "réfléchissez": "réfléchir",
    "réfléchissiez": "réfléchir",
    "réfléchissions": "réfléchir",
    "réfléchissons": "réfléchir",
    "réfléchit": "réfléchir",
    "réfléchîmes": "réfléchir",
    "réfléchît": "réfléchir",
    "réfléchîtes": "réfléchir",
    "réforma": "réformer",
    "réformai": "réformer",
    "réformaient": "réformer",
    "réformais": "réformer",
    "réformait": "réformer",
    "réformant": "réformer",
    "réformas": "réformer",
    "réformasse": "réformer",
    "réformassent": "réformer",
    "réformasses": "réformer",
    "réformassiez": "réformer",
    "réformassions": "réformer",
    "réformateurs": "réformateur",
    "réformatrice": "réformateur",
    "réformatrices": "réformateur",
    "réforme": "réformer",
    "réforment": "réformer",
    "réformera": "réformer",
    "réformerai": "réformer",
    "réformeraient": "réformer",
    "réformerais": "réformer",
    "réformerait": "réformer",
    "réformeras": "réformer",
    "réformerez": "réformer",
    "réformeriez": "réformer",
    "réformerions": "réformer",
    "réformerons": "réformer",
    "réformeront": "réformer",
    "réformes": "réformer",
    "réformez": "réformer",
    "réformiez": "réformer",
    "réformions": "réformer",
    "réformismes": "réformisme",
    "réformistes": "réformiste",
    "réformons": "réformer",
    "réformâmes": "réformer",
    "réformât": "réformer",
    "réformâtes": "réformer",
    "réformèrent": "réformer",
    "réformé": "réformer",
    "réformée": "réformer",
    "réformées": "réformer",
    "réformés": "réformer",
    "réfracta": "réfracter",
    "réfractai": "réfracter",
    "réfractaient": "réfracter",
    "réfractaires": "réfractaire",
    "réfractais": "réfracter",
    "réfractait": "réfracter",
    "réfractant": "réfracter",
    "réfractas": "réfracter",
    "réfractasse": "réfracter",
    "réfractassent": "réfracter",
    "réfractasses": "réfracter",
    "réfractassiez": "réfracter",
    "réfractassions": "réfracter",
    "réfracte": "réfracter",
    "réfractent": "réfracter",
    "réfractera": "réfracter",
    "réfracterai": "réfracter",
    "réfracteraient": "réfracter",
    "réfracterais": "réfracter",
    "réfracterait": "réfracter",
    "réfracteras": "réfracter",
    "réfracterez": "réfracter",
    "réfracteriez": "réfracter",
    "réfracterions": "réfracter",
    "réfracterons": "réfracter",
    "réfracteront": "réfracter",
    "réfractes": "réfracter",
    "réfractez": "réfracter",
    "réfractiez": "réfracter",
    "réfractions": "réfraction",
    "réfractons": "réfracter",
    "réfractâmes": "réfracter",
    "réfractât": "réfracter",
    "réfractâtes": "réfracter",
    "réfractèrent": "réfracter",
    "réfracté": "réfracter",
    "réfractée": "réfracter",
    "réfractées": "réfracter",
    "réfractés": "réfracter",
    "réfrangibles": "réfrangible",
    "réfrigère": "réfrigérer",
    "réfrigèrent": "réfrigérer",
    "réfrigères": "réfrigérer",
    "réfrigéra": "réfrigérer",
    "réfrigérai": "réfrigérer",
    "réfrigéraient": "réfrigérer",
    "réfrigérais": "réfrigérer",
    "réfrigérait": "réfrigérer",
    "réfrigérant": "réfrigérer",
    "réfrigérante": "réfrigérant",
    "réfrigérantes": "réfrigérant",
    "réfrigérants": "réfrigérant",
    "réfrigéras": "réfrigérer",
    "réfrigérasse": "réfrigérer",
    "réfrigérassent": "réfrigérer",
    "réfrigérasses": "réfrigérer",
    "réfrigérassiez": "réfrigérer",
    "réfrigérassions": "réfrigérer",
    "réfrigérateurs": "réfrigérateur",
    "réfrigérera": "réfrigérer",
    "réfrigérerai": "réfrigérer",
    "réfrigéreraient": "réfrigérer",
    "réfrigérerais": "réfrigérer",
    "réfrigérerait": "réfrigérer",
    "réfrigéreras": "réfrigérer",
    "réfrigérerez": "réfrigérer",
    "réfrigéreriez": "réfrigérer",
    "réfrigérerions": "réfrigérer",
    "réfrigérerons": "réfrigérer",
    "réfrigéreront": "réfrigérer",
    "réfrigérez": "réfrigérer",
    "réfrigériez": "réfrigérer",
    "réfrigérions": "réfrigérer",
    "réfrigérons": "réfrigérer",
    "réfrigérâmes": "réfrigérer",
    "réfrigérât": "réfrigérer",
    "réfrigérâtes": "réfrigérer",
    "réfrigérèrent": "réfrigérer",
    "réfrigéré": "réfrigérer",
    "réfrigérée": "réfrigérer",
    "réfrigérées": "réfrigérer",
    "réfrigérés": "réfrigérer",
    "réfringente": "réfringent",
    "réfringentes": "réfringent",
    "réfringents": "réfringent",
    "réfrène": "réfréner",
    "réfrènements": "réfrènement",
    "réfrènent": "réfréner",
    "réfrènes": "réfréner",
    "réfréna": "réfréner",
    "réfrénai": "réfréner",
    "réfrénaient": "réfréner",
    "réfrénais": "réfréner",
    "réfrénait": "réfréner",
    "réfrénant": "réfréner",
    "réfrénas": "réfréner",
    "réfrénasse": "réfréner",
    "réfrénassent": "réfréner",
    "réfrénasses": "réfréner",
    "réfrénassiez": "réfréner",
    "réfrénassions": "réfréner",
    "réfrénera": "réfréner",
    "réfrénerai": "réfréner",
    "réfréneraient": "réfréner",
    "réfrénerais": "réfréner",
    "réfrénerait": "réfréner",
    "réfréneras": "réfréner",
    "réfrénerez": "réfréner",
    "réfréneriez": "réfréner",
    "réfrénerions": "réfréner",
    "réfrénerons": "réfréner",
    "réfréneront": "réfréner",
    "réfrénez": "réfréner",
    "réfréniez": "réfréner",
    "réfrénions": "réfréner",
    "réfrénons": "réfréner",
    "réfrénâmes": "réfréner",
    "réfrénât": "réfréner",
    "réfrénâtes": "réfréner",
    "réfrénèrent": "réfréner",
    "réfréné": "réfréner",
    "réfrénée": "réfréner",
    "réfrénées": "réfréner",
    "réfrénés": "réfréner",
    "réfugia": "réfugier",
    "réfugiai": "réfugier",
    "réfugiaient": "réfugier",
    "réfugiais": "réfugier",
    "réfugiait": "réfugier",
    "réfugiant": "réfugier",
    "réfugias": "réfugier",
    "réfugiasse": "réfugier",
    "réfugiassent": "réfugier",
    "réfugiasses": "réfugier",
    "réfugiassiez": "réfugier",
    "réfugiassions": "réfugier",
    "réfugie": "réfugier",
    "réfugient": "réfugier",
    "réfugiera": "réfugier",
    "réfugierai": "réfugier",
    "réfugieraient": "réfugier",
    "réfugierais": "réfugier",
    "réfugierait": "réfugier",
    "réfugieras": "réfugier",
    "réfugierez": "réfugier",
    "réfugieriez": "réfugier",
    "réfugierions": "réfugier",
    "réfugierons": "réfugier",
    "réfugieront": "réfugier",
    "réfugies": "réfugier",
    "réfugiez": "réfugier",
    "réfugiiez": "réfugier",
    "réfugiions": "réfugier",
    "réfugions": "réfugier",
    "réfugiâmes": "réfugier",
    "réfugiât": "réfugier",
    "réfugiâtes": "réfugier",
    "réfugièrent": "réfugier",
    "réfugié": "réfugier",
    "réfugiée": "réfugier",
    "réfugiées": "réfugier",
    "réfugiés": "réfugier",
    "réfuta": "réfuter",
    "réfutai": "réfuter",
    "réfutaient": "réfuter",
    "réfutais": "réfuter",
    "réfutait": "réfuter",
    "réfutant": "réfuter",
    "réfutas": "réfuter",
    "réfutasse": "réfuter",
    "réfutassent": "réfuter",
    "réfutasses": "réfuter",
    "réfutassiez": "réfuter",
    "réfutassions": "réfuter",
    "réfutations": "réfutation",
    "réfute": "réfuter",
    "réfutent": "réfuter",
    "réfutera": "réfuter",
    "réfuterai": "réfuter",
    "réfuteraient": "réfuter",
    "réfuterais": "réfuter",
    "réfuterait": "réfuter",
    "réfuteras": "réfuter",
    "réfuterez": "réfuter",
    "réfuteriez": "réfuter",
    "réfuterions": "réfuter",
    "réfuterons": "réfuter",
    "réfuteront": "réfuter",
    "réfutes": "réfuter",
    "réfutez": "réfuter",
    "réfutiez": "réfuter",
    "réfutions": "réfuter",
    "réfutons": "réfuter",
    "réfutâmes": "réfuter",
    "réfutât": "réfuter",
    "réfutâtes": "réfuter",
    "réfutèrent": "réfuter",
    "réfuté": "réfuter",
    "réfutée": "réfuter",
    "réfutées": "réfuter",
    "réfutés": "réfuter",
    "réfère": "référer",
    "réfèrent": "référer",
    "réfères": "référer",
    "référa": "référer",
    "référai": "référer",
    "référaient": "référer",
    "référais": "référer",
    "référait": "référer",
    "référant": "référer",
    "référas": "référer",
    "référasse": "référer",
    "référassent": "référer",
    "référasses": "référer",
    "référassiez": "référer",
    "référassions": "référer",
    "références": "référence",
    "référencé": "référencer",
    "référencée": "référencer",
    "référendaires": "référendaire",
    "référendums": "référendum",
    "référentielle": "référentiel",
    "référentielles": "référentiel",
    "référentiels": "référentiel",
    "référents": "référent",
    "référera": "référer",
    "référerai": "référer",
    "référeraient": "référer",
    "référerais": "référer",
    "référerait": "référer",
    "référeras": "référer",
    "référerez": "référer",
    "référeriez": "référer",
    "référerions": "référer",
    "référerons": "référer",
    "référeront": "référer",
    "référez": "référer",
    "référiez": "référer",
    "référions": "référer",
    "référons": "référer",
    "référâmes": "référer",
    "référât": "référer",
    "référâtes": "référer",
    "référèrent": "référer",
    "référé": "référer",
    "référée": "référer",
    "référées": "référer",
    "référés": "référer",
    "régala": "régaler",
    "régalai": "régaler",
    "régalaient": "régaler",
    "régalais": "régaler",
    "régalait": "régaler",
    "régalant": "régaler",
    "régalas": "régaler",
    "régalasse": "régaler",
    "régalassent": "régaler",
    "régalasses": "régaler",
    "régalassiez": "régaler",
    "régalassions": "régaler",
    "régale": "régaler",
    "régalent": "régaler",
    "régalera": "régaler",
    "régalerai": "régaler",
    "régaleraient": "régaler",
    "régalerais": "régaler",
    "régalerait": "régaler",
    "régaleras": "régaler",
    "régalerez": "régaler",
    "régaleriez": "régaler",
    "régalerions": "régaler",
    "régalerons": "régaler",
    "régaleront": "régaler",
    "régales": "régaler",
    "régalez": "régaler",
    "régaliez": "régaler",
    "régalions": "régaler",
    "régalons": "régaler",
    "régals": "régal",
    "régalâmes": "régaler",
    "régalât": "régaler",
    "régalâtes": "régaler",
    "régalèrent": "régaler",
    "régalé": "régaler",
    "régalée": "régaler",
    "régalées": "régaler",
    "régalés": "régaler",
    "régates": "régate",
    "régatiers": "régatier",
    "régelementations": "régelementation",
    "régences": "régence",
    "régenta": "régenter",
    "régentai": "régenter",
    "régentaient": "régenter",
    "régentais": "régenter",
    "régentait": "régenter",
    "régentant": "régenter",
    "régentas": "régenter",
    "régentasse": "régenter",
    "régentassent": "régenter",
    "régentasses": "régenter",
    "régentassiez": "régenter",
    "régentassions": "régenter",
    "régente": "régenter",
    "régentent": "régenter",
    "régentera": "régenter",
    "régenterai": "régenter",
    "régenteraient": "régenter",
    "régenterais": "régenter",
    "régenterait": "régenter",
    "régenteras": "régenter",
    "régenterez": "régenter",
    "régenteriez": "régenter",
    "régenterions": "régenter",
    "régenterons": "régenter",
    "régenteront": "régenter",
    "régentes": "régenter",
    "régentez": "régenter",
    "régentiez": "régenter",
    "régentions": "régenter",
    "régentons": "régenter",
    "régents": "régent",
    "régentâmes": "régenter",
    "régentât": "régenter",
    "régentâtes": "régenter",
    "régentèrent": "régenter",
    "régenté": "régenter",
    "régentée": "régenter",
    "régentées": "régenter",
    "régentés": "régenter",
    "régi": "régir",
    "régicides": "régicide",
    "régie": "régir",
    "régies": "régir",
    "régimentaires": "régimentaire",
    "régiments": "régiment",
    "régimes": "régime",
    "régionale": "régional",
    "régionales": "régional",
    "régionalisations": "régionalisation",
    "régionalismes": "régionalisme",
    "régionalistes": "régionaliste",
    "régionaux": "régional",
    "régions": "région",
    "régira": "régir",
    "régirai": "régir",
    "régiraient": "régir",
    "régirais": "régir",
    "régirait": "régir",
    "régiras": "régir",
    "régirent": "régir",
    "régirez": "régir",
    "régiriez": "régir",
    "régirions": "régir",
    "régirons": "régir",
    "régiront": "régir",
    "régis": "régir",
    "régissaient": "régir",
    "régissais": "régir",
    "régissait": "régir",
    "régissant": "régir",
    "régisse": "régir",
    "régissent": "régir",
    "régisses": "régir",
    "régisseurs": "régisseur",
    "régisseuse": "régisseur",
    "régissez": "régir",
    "régissiez": "régir",
    "régissions": "régir",
    "régissons": "régir",
    "régit": "régir",
    "régla": "régler",
    "réglables": "réglable",
    "réglages": "réglage",
    "réglai": "régler",
    "réglaient": "régler",
    "réglais": "régler",
    "réglait": "régler",
    "réglant": "régler",
    "réglas": "régler",
    "réglasse": "régler",
    "réglassent": "régler",
    "réglasses": "régler",
    "réglassiez": "régler",
    "réglassions": "régler",
    "réglementa": "réglementer",
    "réglementai": "réglementer",
    "réglementaient": "réglementer",
    "réglementaires": "réglementaire",
    "réglementais": "réglementer",
    "réglementait": "réglementer",
    "réglementant": "réglementer",
    "réglementas": "réglementer",
    "réglementasse": "réglementer",
    "réglementassent": "réglementer",
    "réglementasses": "réglementer",
    "réglementassiez": "réglementer",
    "réglementassions": "réglementer",
    "réglementations": "réglementation",
    "réglemente": "réglementer",
    "réglementent": "réglementer",
    "réglementera": "réglementer",
    "réglementerai": "réglementer",
    "réglementeraient": "réglementer",
    "réglementerais": "réglementer",
    "réglementerait": "réglementer",
    "réglementeras": "réglementer",
    "réglementerez": "réglementer",
    "réglementeriez": "réglementer",
    "réglementerions": "réglementer",
    "réglementerons": "réglementer",
    "réglementeront": "réglementer",
    "réglementes": "réglementer",
    "réglementez": "réglementer",
    "réglementiez": "réglementer",
    "réglementions": "réglemention",
    "réglementons": "réglementer",
    "réglements": "réglement",
    "réglementâmes": "réglementer",
    "réglementât": "réglementer",
    "réglementâtes": "réglementer",
    "réglementèrent": "réglementer",
    "réglementé": "réglementer",
    "réglementée": "réglementer",
    "réglementées": "réglementer",
    "réglementés": "réglementer",
    "réglera": "régler",
    "réglerai": "régler",
    "régleraient": "régler",
    "réglerais": "régler",
    "réglerait": "régler",
    "régleras": "régler",
    "réglerez": "régler",
    "régleriez": "régler",
    "réglerions": "régler",
    "réglerons": "régler",
    "régleront": "régler",
    "réglettes": "réglette",
    "réglez": "régler",
    "régliez": "régler",
    "réglions": "régler",
    "réglisses": "réglisse",
    "réglons": "régler",
    "réglos": "réglo",
    "réglâmes": "régler",
    "réglât": "régler",
    "réglâtes": "régler",
    "réglèrent": "régler",
    "réglé": "régler",
    "réglée": "régler",
    "réglées": "régler",
    "réglés": "régler",
    "régna": "régner",
    "régnai": "régner",
    "régnaient": "régner",
    "régnais": "régner",
    "régnait": "régner",
    "régnant": "régner",
    "régnante": "régnant",
    "régnantes": "régnant",
    "régnants": "régnant",
    "régnas": "régner",
    "régnasse": "régner",
    "régnassent": "régner",
    "régnasses": "régner",
    "régnassiez": "régner",
    "régnassions": "régner",
    "régnera": "régner",
    "régnerai": "régner",
    "régneraient": "régner",
    "régnerais": "régner",
    "régnerait": "régner",
    "régneras": "régner",
    "régnerez": "régner",
    "régneriez": "régner",
    "régnerions": "régner",
    "régnerons": "régner",
    "régneront": "régner",
    "régnez": "régner",
    "régniez": "régner",
    "régnions": "régner",
    "régnons": "régner",
    "régnâmes": "régner",
    "régnât": "régner",
    "régnâtes": "régner",
    "régnèrent": "régner",
    "régné": "régner",
    "régressa": "régresser",
    "régressai": "régresser",
    "régressaient": "régresser",
    "régressais": "régresser",
    "régressait": "régresser",
    "régressant": "régresser",
    "régressas": "régresser",
    "régressasse": "régresser",
    "régressassent": "régresser",
    "régressasses": "régresser",
    "régressassiez": "régresser",
    "régressassions": "régresser",
    "régresse": "régresser",
    "régressent": "régresser",
    "régressera": "régresser",
    "régresserai": "régresser",
    "régresseraient": "régresser",
    "régresserais": "régresser",
    "régresserait": "régresser",
    "régresseras": "régresser",
    "régresserez": "régresser",
    "régresseriez": "régresser",
    "régresserions": "régresser",
    "régresserons": "régresser",
    "régresseront": "régresser",
    "régresses": "régresser",
    "régressez": "régresser",
    "régressiez": "régresser",
    "régressifs": "régressif",
    "régressions": "régression",
    "régressive": "régressif",
    "régressives": "régressif",
    "régressons": "régresser",
    "régressâmes": "régresser",
    "régressât": "régresser",
    "régressâtes": "régresser",
    "régressèrent": "régresser",
    "régressé": "régresser",
    "régressée": "régresser",
    "régressées": "régresser",
    "régressés": "régresser",
    "régula": "réguler",
    "régulai": "réguler",
    "régulaient": "réguler",
    "régulais": "réguler",
    "régulait": "réguler",
    "régulant": "réguler",
    "régularisa": "régulariser",
    "régularisai": "régulariser",
    "régularisaient": "régulariser",
    "régularisais": "régulariser",
    "régularisait": "régulariser",
    "régularisant": "régulariser",
    "régularisas": "régulariser",
    "régularisasse": "régulariser",
    "régularisassent": "régulariser",
    "régularisasses": "régulariser",
    "régularisassiez": "régulariser",
    "régularisassions": "régulariser",
    "régularisations": "régularisation",
    "régularise": "régulariser",
    "régularisent": "régulariser",
    "régularisera": "régulariser",
    "régulariserai": "régulariser",
    "régulariseraient": "régulariser",
    "régulariserais": "régulariser",
    "régulariserait": "régulariser",
    "régulariseras": "régulariser",
    "régulariserez": "régulariser",
    "régulariseriez": "régulariser",
    "régulariserions": "régulariser",
    "régulariserons": "régulariser",
    "régulariseront": "régulariser",
    "régularises": "régulariser",
    "régularisez": "régulariser",
    "régularisiez": "régulariser",
    "régularisions": "régulariser",
    "régularisons": "régulariser",
    "régularisâmes": "régulariser",
    "régularisât": "régulariser",
    "régularisâtes": "régulariser",
    "régularisèrent": "régulariser",
    "régularisé": "régulariser",
    "régularisée": "régulariser",
    "régularisées": "régulariser",
    "régularisés": "régulariser",
    "régularités": "régularité",
    "régulas": "réguler",
    "régulasse": "réguler",
    "régulassent": "réguler",
    "régulasses": "réguler",
    "régulassiez": "réguler",
    "régulassions": "réguler",
    "régulateurs": "régulateur",
    "régulations": "régulation",
    "régulatrice": "régulateur",
    "régulatrices": "régulatrice",
    "régule": "réguler",
    "régulent": "réguler",
    "régulera": "réguler",
    "régulerai": "réguler",
    "réguleraient": "réguler",
    "régulerais": "réguler",
    "régulerait": "réguler",
    "réguleras": "réguler",
    "régulerez": "réguler",
    "réguleriez": "réguler",
    "régulerions": "réguler",
    "régulerons": "réguler",
    "réguleront": "réguler",
    "régules": "réguler",
    "régulez": "réguler",
    "réguliers": "régulier",
    "réguliez": "réguler",
    "régulions": "réguler",
    "régulière": "régulier",
    "régulières": "régulier",
    "régulons": "réguler",
    "régulâmes": "réguler",
    "régulât": "réguler",
    "régulâtes": "réguler",
    "régulèrent": "réguler",
    "régulé": "réguler",
    "régulée": "réguler",
    "régulées": "réguler",
    "régulés": "réguler",
    "régurgita": "régurgiter",
    "régurgitai": "régurgiter",
    "régurgitaient": "régurgiter",
    "régurgitais": "régurgiter",
    "régurgitait": "régurgiter",
    "régurgitant": "régurgiter",
    "régurgitas": "régurgiter",
    "régurgitasse": "régurgiter",
    "régurgitassent": "régurgiter",
    "régurgitasses": "régurgiter",
    "régurgitassiez": "régurgiter",
    "régurgitassions": "régurgiter",
    "régurgitations": "régurgitation",
    "régurgite": "régurgiter",
    "régurgitent": "régurgiter",
    "régurgitera": "régurgiter",
    "régurgiterai": "régurgiter",
    "régurgiteraient": "régurgiter",
    "régurgiterais": "régurgiter",
    "régurgiterait": "régurgiter",
    "régurgiteras": "régurgiter",
    "régurgiterez": "régurgiter",
    "régurgiteriez": "régurgiter",
    "régurgiterions": "régurgiter",
    "régurgiterons": "régurgiter",
    "régurgiteront": "régurgiter",
    "régurgites": "régurgiter",
    "régurgitez": "régurgiter",
    "régurgitiez": "régurgiter",
    "régurgitions": "régurgiter",
    "régurgitons": "régurgiter",
    "régurgitâmes": "régurgiter",
    "régurgitât": "régurgiter",
    "régurgitâtes": "régurgiter",
    "régurgitèrent": "régurgiter",
    "régurgité": "régurgiter",
    "régurgitée": "régurgiter",
    "régurgitées": "régurgiter",
    "régurgités": "régurgiter",
    "régénère": "régénérer",
    "régénèrent": "régénérer",
    "régénères": "régénérer",
    "régénéra": "régénérer",
    "régénérai": "régénérer",
    "régénéraient": "régénérer",
    "régénérais": "régénérer",
    "régénérait": "régénérer",
    "régénérant": "régénérer",
    "régénéras": "régénérer",
    "régénérasse": "régénérer",
    "régénérassent": "régénérer",
    "régénérasses": "régénérer",
    "régénérassiez": "régénérer",
    "régénérassions": "régénérer",
    "régénérateurs": "régénérateur",
    "régénérations": "régénération",
    "régénératrice": "régénérateur",
    "régénérera": "régénérer",
    "régénérerai": "régénérer",
    "régénéreraient": "régénérer",
    "régénérerais": "régénérer",
    "régénérerait": "régénérer",
    "régénéreras": "régénérer",
    "régénérerez": "régénérer",
    "régénéreriez": "régénérer",
    "régénérerions": "régénérer",
    "régénérerons": "régénérer",
    "régénéreront": "régénérer",
    "régénérez": "régénérer",
    "régénériez": "régénérer",
    "régénérions": "régénérer",
    "régénérons": "régénérer",
    "régénérâmes": "régénérer",
    "régénérât": "régénérer",
    "régénérâtes": "régénérer",
    "régénérèrent": "régénérer",
    "régénéré": "régénérer",
    "régénérée": "régénérer",
    "régénérées": "régénérer",
    "régénérés": "régénérer",
    "régîmes": "régir",
    "régît": "régir",
    "régîtes": "régir",
    "réhabilita": "réhabiliter",
    "réhabilitai": "réhabiliter",
    "réhabilitaient": "réhabiliter",
    "réhabilitais": "réhabiliter",
    "réhabilitait": "réhabiliter",
    "réhabilitant": "réhabiliter",
    "réhabilitas": "réhabiliter",
    "réhabilitasse": "réhabiliter",
    "réhabilitassent": "réhabiliter",
    "réhabilitasses": "réhabiliter",
    "réhabilitassiez": "réhabiliter",
    "réhabilitassions": "réhabiliter",
    "réhabilitations": "réhabilitation",
    "réhabilite": "réhabiliter",
    "réhabilitent": "réhabiliter",
    "réhabilitera": "réhabiliter",
    "réhabiliterai": "réhabiliter",
    "réhabiliteraient": "réhabiliter",
    "réhabiliterais": "réhabiliter",
    "réhabiliterait": "réhabiliter",
    "réhabiliteras": "réhabiliter",
    "réhabiliterez": "réhabiliter",
    "réhabiliteriez": "réhabiliter",
    "réhabiliterions": "réhabiliter",
    "réhabiliterons": "réhabiliter",
    "réhabiliteront": "réhabiliter",
    "réhabilites": "réhabiliter",
    "réhabilitez": "réhabiliter",
    "réhabilitiez": "réhabiliter",
    "réhabilitions": "réhabilition",
    "réhabilitons": "réhabiliter",
    "réhabilitâmes": "réhabiliter",
    "réhabilitât": "réhabiliter",
    "réhabilitâtes": "réhabiliter",
    "réhabilitèrent": "réhabiliter",
    "réhabilité": "réhabiliter",
    "réhabilitée": "réhabiliter",
    "réhabilitées": "réhabiliter",
    "réhabilités": "réhabiliter",
    "réhabitua": "réhabituer",
    "réhabituai": "réhabituer",
    "réhabituaient": "réhabituer",
    "réhabituais": "réhabituer",
    "réhabituait": "réhabituer",
    "réhabituant": "réhabituer",
    "réhabituas": "réhabituer",
    "réhabituasse": "réhabituer",
    "réhabituassent": "réhabituer",
    "réhabituasses": "réhabituer",
    "réhabituassiez": "réhabituer",
    "réhabituassions": "réhabituer",
    "réhabitue": "réhabituer",
    "réhabituent": "réhabituer",
    "réhabituera": "réhabituer",
    "réhabituerai": "réhabituer",
    "réhabitueraient": "réhabituer",
    "réhabituerais": "réhabituer",
    "réhabituerait": "réhabituer",
    "réhabitueras": "réhabituer",
    "réhabituerez": "réhabituer",
    "réhabitueriez": "réhabituer",
    "réhabituerions": "réhabituer",
    "réhabituerons": "réhabituer",
    "réhabitueront": "réhabituer",
    "réhabitues": "réhabituer",
    "réhabituez": "réhabituer",
    "réhabituiez": "réhabituer",
    "réhabituions": "réhabituer",
    "réhabituons": "réhabituer",
    "réhabituâmes": "réhabituer",
    "réhabituât": "réhabituer",
    "réhabituâtes": "réhabituer",
    "réhabituèrent": "réhabituer",
    "réhabitué": "réhabituer",
    "réhabituée": "réhabituer",
    "réhabituées": "réhabituer",
    "réhabitués": "réhabituer",
    "réhydratations": "réhydratation",
    "réhydraté": "réhydrater",
    "réifia": "réifier",
    "réifiai": "réifier",
    "réifiaient": "réifier",
    "réifiais": "réifier",
    "réifiait": "réifier",
    "réifiant": "réifier",
    "réifias": "réifier",
    "réifiasse": "réifier",
    "réifiassent": "réifier",
    "réifiasses": "réifier",
    "réifiassiez": "réifier",
    "réifiassions": "réifier",
    "réifie": "réifier",
    "réifient": "réifier",
    "réifiera": "réifier",
    "réifierai": "réifier",
    "réifieraient": "réifier",
    "réifierais": "réifier",
    "réifierait": "réifier",
    "réifieras": "réifier",
    "réifierez": "réifier",
    "réifieriez": "réifier",
    "réifierions": "réifier",
    "réifierons": "réifier",
    "réifieront": "réifier",
    "réifies": "réifier",
    "réifiez": "réifier",
    "réifiiez": "réifier",
    "réifiions": "réifier",
    "réifions": "réifier",
    "réifiâmes": "réifier",
    "réifiât": "réifier",
    "réifiâtes": "réifier",
    "réifièrent": "réifier",
    "réifié": "réifier",
    "réifiée": "réifier",
    "réifiées": "réifier",
    "réifiés": "réifier",
    "réimplantations": "réimplantation",
    "réimplanté": "réimplanter",
    "réimplantée": "réimplanter",
    "réimporta": "réimporter",
    "réimportai": "réimporter",
    "réimportaient": "réimporter",
    "réimportais": "réimporter",
    "réimportait": "réimporter",
    "réimportant": "réimporter",
    "réimportas": "réimporter",
    "réimportasse": "réimporter",
    "réimportassent": "réimporter",
    "réimportasses": "réimporter",
    "réimportassiez": "réimporter",
    "réimportassions": "réimporter",
    "réimportations": "réimportation",
    "réimporte": "réimporter",
    "réimportent": "réimporter",
    "réimportera": "réimporter",
    "réimporterai": "réimporter",
    "réimporteraient": "réimporter",
    "réimporterais": "réimporter",
    "réimporterait": "réimporter",
    "réimporteras": "réimporter",
    "réimporterez": "réimporter",
    "réimporteriez": "réimporter",
    "réimporterions": "réimporter",
    "réimporterons": "réimporter",
    "réimporteront": "réimporter",
    "réimportes": "réimporter",
    "réimportez": "réimporter",
    "réimportiez": "réimporter",
    "réimportions": "réimporter",
    "réimportons": "réimporter",
    "réimportâmes": "réimporter",
    "réimportât": "réimporter",
    "réimportâtes": "réimporter",
    "réimportèrent": "réimporter",
    "réimporté": "réimporter",
    "réimportée": "réimporter",
    "réimportées": "réimporter",
    "réimportés": "réimporter",
    "réimposa": "réimposer",
    "réimposai": "réimposer",
    "réimposaient": "réimposer",
    "réimposais": "réimposer",
    "réimposait": "réimposer",
    "réimposant": "réimposer",
    "réimposas": "réimposer",
    "réimposasse": "réimposer",
    "réimposassent": "réimposer",
    "réimposasses": "réimposer",
    "réimposassiez": "réimposer",
    "réimposassions": "réimposer",
    "réimpose": "réimposer",
    "réimposent": "réimposer",
    "réimposera": "réimposer",
    "réimposerai": "réimposer",
    "réimposeraient": "réimposer",
    "réimposerais": "réimposer",
    "réimposerait": "réimposer",
    "réimposeras": "réimposer",
    "réimposerez": "réimposer",
    "réimposeriez": "réimposer",
    "réimposerions": "réimposer",
    "réimposerons": "réimposer",
    "réimposeront": "réimposer",
    "réimposes": "réimposer",
    "réimposez": "réimposer",
    "réimposiez": "réimposer",
    "réimposions": "réimposer",
    "réimposons": "réimposer",
    "réimposâmes": "réimposer",
    "réimposât": "réimposer",
    "réimposâtes": "réimposer",
    "réimposèrent": "réimposer",
    "réimposé": "réimposer",
    "réimposée": "réimposer",
    "réimposées": "réimposer",
    "réimposés": "réimposer",
    "réimprima": "réimprimer",
    "réimprimai": "réimprimer",
    "réimprimaient": "réimprimer",
    "réimprimais": "réimprimer",
    "réimprimait": "réimprimer",
    "réimprimant": "réimprimer",
    "réimprimas": "réimprimer",
    "réimprimasse": "réimprimer",
    "réimprimassent": "réimprimer",
    "réimprimasses": "réimprimer",
    "réimprimassiez": "réimprimer",
    "réimprimassions": "réimprimer",
    "réimprime": "réimprimer",
    "réimpriment": "réimprimer",
    "réimprimera": "réimprimer",
    "réimprimerai": "réimprimer",
    "réimprimeraient": "réimprimer",
    "réimprimerais": "réimprimer",
    "réimprimerait": "réimprimer",
    "réimprimeras": "réimprimer",
    "réimprimerez": "réimprimer",
    "réimprimeriez": "réimprimer",
    "réimprimerions": "réimprimer",
    "réimprimerons": "réimprimer",
    "réimprimeront": "réimprimer",
    "réimprimes": "réimprimer",
    "réimprimez": "réimprimer",
    "réimprimiez": "réimprimer",
    "réimprimions": "réimprimer",
    "réimprimons": "réimprimer",
    "réimprimâmes": "réimprimer",
    "réimprimât": "réimprimer",
    "réimprimâtes": "réimprimer",
    "réimprimèrent": "réimprimer",
    "réimprimé": "réimprimer",
    "réimprimée": "réimprimer",
    "réimprimées": "réimprimer",
    "réimprimés": "réimprimer",
    "réincarcère": "réincarcérer",
    "réincarcèrent": "réincarcérer",
    "réincarcères": "réincarcérer",
    "réincarcéra": "réincarcérer",
    "réincarcérai": "réincarcérer",
    "réincarcéraient": "réincarcérer",
    "réincarcérais": "réincarcérer",
    "réincarcérait": "réincarcérer",
    "réincarcérant": "réincarcérer",
    "réincarcéras": "réincarcérer",
    "réincarcérasse": "réincarcérer",
    "réincarcérassent": "réincarcérer",
    "réincarcérasses": "réincarcérer",
    "réincarcérassiez": "réincarcérer",
    "réincarcérassions": "réincarcérer",
    "réincarcérera": "réincarcérer",
    "réincarcérerai": "réincarcérer",
    "réincarcéreraient": "réincarcérer",
    "réincarcérerais": "réincarcérer",
    "réincarcérerait": "réincarcérer",
    "réincarcéreras": "réincarcérer",
    "réincarcérerez": "réincarcérer",
    "réincarcéreriez": "réincarcérer",
    "réincarcérerions": "réincarcérer",
    "réincarcérerons": "réincarcérer",
    "réincarcéreront": "réincarcérer",
    "réincarcérez": "réincarcérer",
    "réincarcériez": "réincarcérer",
    "réincarcérions": "réincarcérer",
    "réincarcérons": "réincarcérer",
    "réincarcérâmes": "réincarcérer",
    "réincarcérât": "réincarcérer",
    "réincarcérâtes": "réincarcérer",
    "réincarcérèrent": "réincarcérer",
    "réincarcéré": "réincarcérer",
    "réincarcérée": "réincarcérer",
    "réincarcérées": "réincarcérer",
    "réincarcérés": "réincarcérer",
    "réincarna": "réincarner",
    "réincarnai": "réincarner",
    "réincarnaient": "réincarner",
    "réincarnais": "réincarner",
    "réincarnait": "réincarner",
    "réincarnant": "réincarner",
    "réincarnas": "réincarner",
    "réincarnasse": "réincarner",
    "réincarnassent": "réincarner",
    "réincarnasses": "réincarner",
    "réincarnassiez": "réincarner",
    "réincarnassions": "réincarner",
    "réincarnations": "réincarnation",
    "réincarne": "réincarner",
    "réincarnent": "réincarner",
    "réincarnera": "réincarner",
    "réincarnerai": "réincarner",
    "réincarneraient": "réincarner",
    "réincarnerais": "réincarner",
    "réincarnerait": "réincarner",
    "réincarneras": "réincarner",
    "réincarnerez": "réincarner",
    "réincarneriez": "réincarner",
    "réincarnerions": "réincarner",
    "réincarnerons": "réincarner",
    "réincarneront": "réincarner",
    "réincarnes": "réincarner",
    "réincarnez": "réincarner",
    "réincarniez": "réincarner",
    "réincarnions": "réincarner",
    "réincarnons": "réincarner",
    "réincarnâmes": "réincarner",
    "réincarnât": "réincarner",
    "réincarnâtes": "réincarner",
    "réincarnèrent": "réincarner",
    "réincarné": "réincarner",
    "réincarnée": "réincarner",
    "réincarnées": "réincarner",
    "réincarnés": "réincarner",
    "réincorpora": "réincorporer",
    "réincorporai": "réincorporer",
    "réincorporaient": "réincorporer",
    "réincorporais": "réincorporer",
    "réincorporait": "réincorporer",
    "réincorporant": "réincorporer",
    "réincorporas": "réincorporer",
    "réincorporasse": "réincorporer",
    "réincorporassent": "réincorporer",
    "réincorporasses": "réincorporer",
    "réincorporassiez": "réincorporer",
    "réincorporassions": "réincorporer",
    "réincorpore": "réincorporer",
    "réincorporent": "réincorporer",
    "réincorporera": "réincorporer",
    "réincorporerai": "réincorporer",
    "réincorporeraient": "réincorporer",
    "réincorporerais": "réincorporer",
    "réincorporerait": "réincorporer",
    "réincorporeras": "réincorporer",
    "réincorporerez": "réincorporer",
    "réincorporeriez": "réincorporer",
    "réincorporerions": "réincorporer",
    "réincorporerons": "réincorporer",
    "réincorporeront": "réincorporer",
    "réincorpores": "réincorporer",
    "réincorporez": "réincorporer",
    "réincorporiez": "réincorporer",
    "réincorporions": "réincorporer",
    "réincorporons": "réincorporer",
    "réincorporâmes": "réincorporer",
    "réincorporât": "réincorporer",
    "réincorporâtes": "réincorporer",
    "réincorporèrent": "réincorporer",
    "réincorporé": "réincorporer",
    "réincorporée": "réincorporer",
    "réincorporées": "réincorporer",
    "réincorporés": "réincorporer",
    "réinfecta": "réinfecter",
    "réinfectai": "réinfecter",
    "réinfectaient": "réinfecter",
    "réinfectais": "réinfecter",
    "réinfectait": "réinfecter",
    "réinfectant": "réinfecter",
    "réinfectas": "réinfecter",
    "réinfectasse": "réinfecter",
    "réinfectassent": "réinfecter",
    "réinfectasses": "réinfecter",
    "réinfectassiez": "réinfecter",
    "réinfectassions": "réinfecter",
    "réinfecte": "réinfecter",
    "réinfectent": "réinfecter",
    "réinfectera": "réinfecter",
    "réinfecterai": "réinfecter",
    "réinfecteraient": "réinfecter",
    "réinfecterais": "réinfecter",
    "réinfecterait": "réinfecter",
    "réinfecteras": "réinfecter",
    "réinfecterez": "réinfecter",
    "réinfecteriez": "réinfecter",
    "réinfecterions": "réinfecter",
    "réinfecterons": "réinfecter",
    "réinfecteront": "réinfecter",
    "réinfectes": "réinfecter",
    "réinfectez": "réinfecter",
    "réinfectiez": "réinfecter",
    "réinfections": "réinfecter",
    "réinfectons": "réinfecter",
    "réinfectâmes": "réinfecter",
    "réinfectât": "réinfecter",
    "réinfectâtes": "réinfecter",
    "réinfectèrent": "réinfecter",
    "réinfecté": "réinfecter",
    "réinfectée": "réinfecter",
    "réinfectées": "réinfecter",
    "réinfectés": "réinfecter",
    "réinitialisez": "réinitialiser",
    "réinitialisé": "réinitialiser",
    "réinscrira": "réinscrire",
    "réinscrirai": "réinscrire",
    "réinscriraient": "réinscrire",
    "réinscrirais": "réinscrire",
    "réinscrirait": "réinscrire",
    "réinscriras": "réinscrire",
    "réinscrirez": "réinscrire",
    "réinscririez": "réinscrire",
    "réinscririons": "réinscrire",
    "réinscrirons": "réinscrire",
    "réinscriront": "réinscrire",
    "réinscris": "réinscrire",
    "réinscrit": "réinscrire",
    "réinscrite": "réinscrire",
    "réinscrites": "réinscrire",
    "réinscrits": "réinscrire",
    "réinscrivaient": "réinscrire",
    "réinscrivais": "réinscrire",
    "réinscrivait": "réinscrire",
    "réinscrivant": "réinscrire",
    "réinscrive": "réinscrire",
    "réinscrivent": "réinscrire",
    "réinscrives": "réinscrire",
    "réinscrivez": "réinscrire",
    "réinscriviez": "réinscrire",
    "réinscrivions": "réinscrire",
    "réinscrivirent": "réinscrire",
    "réinscrivis": "réinscrire",
    "réinscrivisse": "réinscrire",
    "réinscrivissent": "réinscrire",
    "réinscrivisses": "réinscrire",
    "réinscrivissiez": "réinscrire",
    "réinscrivissions": "réinscrire",
    "réinscrivit": "réinscrire",
    "réinscrivons": "réinscrire",
    "réinscrivîmes": "réinscrire",
    "réinscrivît": "réinscrire",
    "réinscrivîtes": "réinscrire",
    "réinsertions": "réinsertion",
    "réinspections": "réinspection",
    "réinstalla": "réinstaller",
    "réinstallai": "réinstaller",
    "réinstallaient": "réinstaller",
    "réinstallais": "réinstaller",
    "réinstallait": "réinstaller",
    "réinstallant": "réinstaller",
    "réinstallas": "réinstaller",
    "réinstallasse": "réinstaller",
    "réinstallassent": "réinstaller",
    "réinstallasses": "réinstaller",
    "réinstallassiez": "réinstaller",
    "réinstallassions": "réinstaller",
    "réinstallations": "réinstallation",
    "réinstalle": "réinstaller",
    "réinstallent": "réinstaller",
    "réinstallera": "réinstaller",
    "réinstallerai": "réinstaller",
    "réinstalleraient": "réinstaller",
    "réinstallerais": "réinstaller",
    "réinstallerait": "réinstaller",
    "réinstalleras": "réinstaller",
    "réinstallerez": "réinstaller",
    "réinstalleriez": "réinstaller",
    "réinstallerions": "réinstaller",
    "réinstallerons": "réinstaller",
    "réinstalleront": "réinstaller",
    "réinstalles": "réinstaller",
    "réinstallez": "réinstaller",
    "réinstalliez": "réinstaller",
    "réinstallions": "réinstaller",
    "réinstallons": "réinstaller",
    "réinstallâmes": "réinstaller",
    "réinstallât": "réinstaller",
    "réinstallâtes": "réinstaller",
    "réinstallèrent": "réinstaller",
    "réinstallé": "réinstaller",
    "réinstallée": "réinstaller",
    "réinstallées": "réinstaller",
    "réinstallés": "réinstaller",
    "réinséré": "réinsérer",
    "réinterprète": "réinterpréter",
    "réinterprétations": "réinterprétation",
    "réinterroge": "réinterroger",
    "réintroductions": "réintroduction",
    "réintroduira": "réintroduire",
    "réintroduirai": "réintroduire",
    "réintroduiraient": "réintroduire",
    "réintroduirais": "réintroduire",
    "réintroduirait": "réintroduire",
    "réintroduiras": "réintroduire",
    "réintroduirez": "réintroduire",
    "réintroduiriez": "réintroduire",
    "réintroduirions": "réintroduire",
    "réintroduirons": "réintroduire",
    "réintroduiront": "réintroduire",
    "réintroduis": "réintroduire",
    "réintroduisaient": "réintroduire",
    "réintroduisais": "réintroduire",
    "réintroduisait": "réintroduire",
    "réintroduisant": "réintroduire",
    "réintroduise": "réintroduire",
    "réintroduisent": "réintroduire",
    "réintroduises": "réintroduire",
    "réintroduisez": "réintroduire",
    "réintroduisiez": "réintroduire",
    "réintroduisions": "réintroduire",
    "réintroduisirent": "réintroduire",
    "réintroduisis": "réintroduire",
    "réintroduisisse": "réintroduire",
    "réintroduisissent": "réintroduire",
    "réintroduisisses": "réintroduire",
    "réintroduisissiez": "réintroduire",
    "réintroduisissions": "réintroduire",
    "réintroduisit": "réintroduire",
    "réintroduisons": "réintroduire",
    "réintroduisîmes": "réintroduire",
    "réintroduisît": "réintroduire",
    "réintroduisîtes": "réintroduire",
    "réintroduit": "réintroduire",
    "réintroduite": "réintroduire",
    "réintroduites": "réintroduire",
    "réintroduits": "réintroduire",
    "réintègre": "réintégrer",
    "réintègrent": "réintégrer",
    "réintègres": "réintégrer",
    "réintégra": "réintégrer",
    "réintégrai": "réintégrer",
    "réintégraient": "réintégrer",
    "réintégrais": "réintégrer",
    "réintégrait": "réintégrer",
    "réintégrant": "réintégrer",
    "réintégras": "réintégrer",
    "réintégrasse": "réintégrer",
    "réintégrassent": "réintégrer",
    "réintégrasses": "réintégrer",
    "réintégrassiez": "réintégrer",
    "réintégrassions": "réintégrer",
    "réintégrations": "réintégration",
    "réintégrera": "réintégrer",
    "réintégrerai": "réintégrer",
    "réintégreraient": "réintégrer",
    "réintégrerais": "réintégrer",
    "réintégrerait": "réintégrer",
    "réintégreras": "réintégrer",
    "réintégrerez": "réintégrer",
    "réintégreriez": "réintégrer",
    "réintégrerions": "réintégrer",
    "réintégrerons": "réintégrer",
    "réintégreront": "réintégrer",
    "réintégrez": "réintégrer",
    "réintégriez": "réintégrer",
    "réintégrions": "réintégrer",
    "réintégrons": "réintégrer",
    "réintégrâmes": "réintégrer",
    "réintégrât": "réintégrer",
    "réintégrâtes": "réintégrer",
    "réintégrèrent": "réintégrer",
    "réintégré": "réintégrer",
    "réintégrée": "réintégrer",
    "réintégrées": "réintégrer",
    "réintégrés": "réintégrer",
    "réinventa": "réinventer",
    "réinventai": "réinventer",
    "réinventaient": "réinventer",
    "réinventais": "réinventer",
    "réinventait": "réinventer",
    "réinventant": "réinventer",
    "réinventas": "réinventer",
    "réinventasse": "réinventer",
    "réinventassent": "réinventer",
    "réinventasses": "réinventer",
    "réinventassiez": "réinventer",
    "réinventassions": "réinventer",
    "réinvente": "réinventer",
    "réinventent": "réinventer",
    "réinventera": "réinventer",
    "réinventerai": "réinventer",
    "réinventeraient": "réinventer",
    "réinventerais": "réinventer",
    "réinventerait": "réinventer",
    "réinventeras": "réinventer",
    "réinventerez": "réinventer",
    "réinventeriez": "réinventer",
    "réinventerions": "réinventer",
    "réinventerons": "réinventer",
    "réinventeront": "réinventer",
    "réinventes": "réinventer",
    "réinventez": "réinventer",
    "réinventiez": "réinventer",
    "réinventions": "réinventer",
    "réinventons": "réinventer",
    "réinventâmes": "réinventer",
    "réinventât": "réinventer",
    "réinventâtes": "réinventer",
    "réinventèrent": "réinventer",
    "réinventé": "réinventer",
    "réinventée": "réinventer",
    "réinventées": "réinventer",
    "réinventés": "réinventer",
    "réinvesti": "réinvestir",
    "réinvestie": "réinvestir",
    "réinvesties": "réinvestir",
    "réinvestira": "réinvestir",
    "réinvestirai": "réinvestir",
    "réinvestiraient": "réinvestir",
    "réinvestirais": "réinvestir",
    "réinvestirait": "réinvestir",
    "réinvestiras": "réinvestir",
    "réinvestirent": "réinvestir",
    "réinvestirez": "réinvestir",
    "réinvestiriez": "réinvestir",
    "réinvestirions": "réinvestir",
    "réinvestirons": "réinvestir",
    "réinvestiront": "réinvestir",
    "réinvestis": "réinvestir",
    "réinvestissaient": "réinvestir",
    "réinvestissais": "réinvestir",
    "réinvestissait": "réinvestir",
    "réinvestissant": "réinvestir",
    "réinvestisse": "réinvestir",
    "réinvestissements": "réinvestissement",
    "réinvestissent": "réinvestir",
    "réinvestisses": "réinvestir",
    "réinvestissez": "réinvestir",
    "réinvestissiez": "réinvestir",
    "réinvestissions": "réinvestir",
    "réinvestissons": "réinvestir",
    "réinvestit": "réinvestir",
    "réinvestîmes": "réinvestir",
    "réinvestît": "réinvestir",
    "réinvestîtes": "réinvestir",
    "réinvita": "réinviter",
    "réinvitai": "réinviter",
    "réinvitaient": "réinviter",
    "réinvitais": "réinviter",
    "réinvitait": "réinviter",
    "réinvitant": "réinviter",
    "réinvitas": "réinviter",
    "réinvitasse": "réinviter",
    "réinvitassent": "réinviter",
    "réinvitasses": "réinviter",
    "réinvitassiez": "réinviter",
    "réinvitassions": "réinviter",
    "réinvite": "réinviter",
    "réinvitent": "réinviter",
    "réinvitera": "réinviter",
    "réinviterai": "réinviter",
    "réinviteraient": "réinviter",
    "réinviterais": "réinviter",
    "réinviterait": "réinviter",
    "réinviteras": "réinviter",
    "réinviterez": "réinviter",
    "réinviteriez": "réinviter",
    "réinviterions": "réinviter",
    "réinviterons": "réinviter",
    "réinviteront": "réinviter",
    "réinvites": "réinviter",
    "réinvitez": "réinviter",
    "réinvitiez": "réinviter",
    "réinvitions": "réinviter",
    "réinvitons": "réinviter",
    "réinvitâmes": "réinviter",
    "réinvitât": "réinviter",
    "réinvitâtes": "réinviter",
    "réinvitèrent": "réinviter",
    "réinvité": "réinviter",
    "réinvitée": "réinviter",
    "réinvitées": "réinviter",
    "réinvités": "réinviter",
    "réitère": "réitérer",
    "réitèrent": "réitérer",
    "réitères": "réitérer",
    "réitéra": "réitérer",
    "réitérai": "réitérer",
    "réitéraient": "réitérer",
    "réitérais": "réitérer",
    "réitérait": "réitérer",
    "réitérant": "réitérer",
    "réitéras": "réitérer",
    "réitérasse": "réitérer",
    "réitérassent": "réitérer",
    "réitérasses": "réitérer",
    "réitérassiez": "réitérer",
    "réitérassions": "réitérer",
    "réitérations": "réitération",
    "réitérera": "réitérer",
    "réitérerai": "réitérer",
    "réitéreraient": "réitérer",
    "réitérerais": "réitérer",
    "réitérerait": "réitérer",
    "réitéreras": "réitérer",
    "réitérerez": "réitérer",
    "réitéreriez": "réitérer",
    "réitérerions": "réitérer",
    "réitérerons": "réitérer",
    "réitéreront": "réitérer",
    "réitérez": "réitérer",
    "réitériez": "réitérer",
    "réitérions": "réitérer",
    "réitérons": "réitérer",
    "réitérâmes": "réitérer",
    "réitérât": "réitérer",
    "réitérâtes": "réitérer",
    "réitérèrent": "réitérer",
    "réitéré": "réitérer",
    "réitérée": "réitérer",
    "réitérées": "réitérer",
    "réitérés": "réitérer",
    "réjoui": "réjouir",
    "réjouie": "réjouir",
    "réjouies": "réjouir",
    "réjouira": "réjouir",
    "réjouirai": "réjouir",
    "réjouiraient": "réjouir",
    "réjouirais": "réjouir",
    "réjouirait": "réjouir",
    "réjouiras": "réjouir",
    "réjouirent": "réjouir",
    "réjouirez": "réjouir",
    "réjouiriez": "réjouir",
    "réjouirions": "réjouir",
    "réjouirons": "réjouir",
    "réjouiront": "réjouir",
    "réjouis": "réjouir",
    "réjouissaient": "réjouir",
    "réjouissais": "réjouir",
    "réjouissait": "réjouir",
    "réjouissances": "réjouissance",
    "réjouissant": "réjouir",
    "réjouissante": "réjouissant",
    "réjouissantes": "réjouissant",
    "réjouissants": "réjouissant",
    "réjouisse": "réjouir",
    "réjouissent": "réjouir",
    "réjouisses": "réjouir",
    "réjouissez": "réjouir",
    "réjouissiez": "réjouir",
    "réjouissions": "réjouir",
    "réjouissons": "réjouir",
    "réjouit": "réjouir",
    "réjouîmes": "réjouir",
    "réjouît": "réjouir",
    "réjouîtes": "réjouir",
    "rélargi": "rélargir",
    "rélargie": "rélargir",
    "rélargies": "rélargir",
    "rélargira": "rélargir",
    "rélargirai": "rélargir",
    "rélargiraient": "rélargir",
    "rélargirais": "rélargir",
    "rélargirait": "rélargir",
    "rélargiras": "rélargir",
    "rélargirent": "rélargir",
    "rélargirez": "rélargir",
    "rélargiriez": "rélargir",
    "rélargirions": "rélargir",
    "rélargirons": "rélargir",
    "rélargiront": "rélargir",
    "rélargis": "rélargir",
    "rélargissaient": "rélargir",
    "rélargissais": "rélargir",
    "rélargissait": "rélargir",
    "rélargissant": "rélargir",
    "rélargisse": "rélargir",
    "rélargissent": "rélargir",
    "rélargisses": "rélargir",
    "rélargissez": "rélargir",
    "rélargissiez": "rélargir",
    "rélargissions": "rélargir",
    "rélargissons": "rélargir",
    "rélargit": "rélargir",
    "rélargîmes": "rélargir",
    "rélargît": "rélargir",
    "rélargîtes": "rélargir",
    "rémanences": "rémanence",
    "rémanente": "rémanent",
    "rémanentes": "rémanent",
    "rémanents": "rémanent",
    "rémiges": "rémige",
    "réminiscences": "réminiscence",
    "rémissions": "rémission",
    "rémittente": "rémittent",
    "rémittentes": "rémittent",
    "rémittents": "rémittent",
    "rémoras": "rémora",
    "rémoulades": "rémoulade",
    "rémouleurs": "rémouleur",
    "rémunère": "rémunérer",
    "rémunèrent": "rémunérer",
    "rémunères": "rémunérer",
    "rémunéra": "rémunérer",
    "rémunérai": "rémunérer",
    "rémunéraient": "rémunérer",
    "rémunérais": "rémunérer",
    "rémunérait": "rémunérer",
    "rémunérant": "rémunérer",
    "rémunéras": "rémunérer",
    "rémunérasse": "rémunérer",
    "rémunérassent": "rémunérer",
    "rémunérasses": "rémunérer",
    "rémunérassiez": "rémunérer",
    "rémunérassions": "rémunérer",
    "rémunérateurs": "rémunérateur",
    "rémunérations": "rémunération",
    "rémunératoires": "rémunératoire",
    "rémunératrice": "rémunérateur",
    "rémunératrices": "rémunérateur",
    "rémunérera": "rémunérer",
    "rémunérerai": "rémunérer",
    "rémunéreraient": "rémunérer",
    "rémunérerais": "rémunérer",
    "rémunérerait": "rémunérer",
    "rémunéreras": "rémunérer",
    "rémunérerez": "rémunérer",
    "rémunéreriez": "rémunérer",
    "rémunérerions": "rémunérer",
    "rémunérerons": "rémunérer",
    "rémunéreront": "rémunérer",
    "rémunérez": "rémunérer",
    "rémunériez": "rémunérer",
    "rémunérions": "rémunérer",
    "rémunérons": "rémunérer",
    "rémunérâmes": "rémunérer",
    "rémunérât": "rémunérer",
    "rémunérâtes": "rémunérer",
    "rémunérèrent": "rémunérer",
    "rémunéré": "rémunérer",
    "rémunérée": "rémunérer",
    "rémunérées": "rémunérer",
    "rémunérés": "rémunérer",
    "rénale": "rénal",
    "rénales": "rénal",
    "rénaux": "rénal",
    "rénettes": "rénette",
    "rénova": "rénover",
    "rénovai": "rénover",
    "rénovaient": "rénover",
    "rénovais": "rénover",
    "rénovait": "rénover",
    "rénovant": "rénover",
    "rénovas": "rénover",
    "rénovasse": "rénover",
    "rénovassent": "rénover",
    "rénovasses": "rénover",
    "rénovassiez": "rénover",
    "rénovassions": "rénover",
    "rénovateurs": "rénovateur",
    "rénovations": "rénovation",
    "rénovatrice": "rénovateur",
    "rénovatrices": "rénovateur",
    "rénove": "rénover",
    "rénovent": "rénover",
    "rénovera": "rénover",
    "rénoverai": "rénover",
    "rénoveraient": "rénover",
    "rénoverais": "rénover",
    "rénoverait": "rénover",
    "rénoveras": "rénover",
    "rénoverez": "rénover",
    "rénoveriez": "rénover",
    "rénoverions": "rénover",
    "rénoverons": "rénover",
    "rénoveront": "rénover",
    "rénoves": "rénover",
    "rénovez": "rénover",
    "rénoviez": "rénover",
    "rénovions": "rénover",
    "rénovons": "rénover",
    "rénovâmes": "rénover",
    "rénovât": "rénover",
    "rénovâtes": "rénover",
    "rénovèrent": "rénover",
    "rénové": "rénover",
    "rénovée": "rénover",
    "rénovées": "rénover",
    "rénovés": "rénover",
    "rénumérations": "rénumération",
    "réoccupa": "réoccuper",
    "réoccupai": "réoccuper",
    "réoccupaient": "réoccuper",
    "réoccupais": "réoccuper",
    "réoccupait": "réoccuper",
    "réoccupant": "réoccuper",
    "réoccupas": "réoccuper",
    "réoccupasse": "réoccuper",
    "réoccupassent": "réoccuper",
    "réoccupasses": "réoccuper",
    "réoccupassiez": "réoccuper",
    "réoccupassions": "réoccuper",
    "réoccupe": "réoccuper",
    "réoccupent": "réoccuper",
    "réoccupera": "réoccuper",
    "réoccuperai": "réoccuper",
    "réoccuperaient": "réoccuper",
    "réoccuperais": "réoccuper",
    "réoccuperait": "réoccuper",
    "réoccuperas": "réoccuper",
    "réoccuperez": "réoccuper",
    "réoccuperiez": "réoccuper",
    "réoccuperions": "réoccuper",
    "réoccuperons": "réoccuper",
    "réoccuperont": "réoccuper",
    "réoccupes": "réoccuper",
    "réoccupez": "réoccuper",
    "réoccupiez": "réoccuper",
    "réoccupions": "réoccuper",
    "réoccupons": "réoccuper",
    "réoccupâmes": "réoccuper",
    "réoccupât": "réoccuper",
    "réoccupâtes": "réoccuper",
    "réoccupèrent": "réoccuper",
    "réoccupé": "réoccuper",
    "réoccupée": "réoccuper",
    "réoccupées": "réoccuper",
    "réoccupés": "réoccuper",
    "réopère": "réopérer",
    "réopèrent": "réopérer",
    "réopères": "réopérer",
    "réopéra": "réopérer",
    "réopérai": "réopérer",
    "réopéraient": "réopérer",
    "réopérais": "réopérer",
    "réopérait": "réopérer",
    "réopérant": "réopérer",
    "réopéras": "réopérer",
    "réopérasse": "réopérer",
    "réopérassent": "réopérer",
    "réopérasses": "réopérer",
    "réopérassiez": "réopérer",
    "réopérassions": "réopérer",
    "réopérera": "réopérer",
    "réopérerai": "réopérer",
    "réopéreraient": "réopérer",
    "réopérerais": "réopérer",
    "réopérerait": "réopérer",
    "réopéreras": "réopérer",
    "réopérerez": "réopérer",
    "réopéreriez": "réopérer",
    "réopérerions": "réopérer",
    "réopérerons": "réopérer",
    "réopéreront": "réopérer",
    "réopérez": "réopérer",
    "réopériez": "réopérer",
    "réopérions": "réopérer",
    "réopérons": "réopérer",
    "réopérâmes": "réopérer",
    "réopérât": "réopérer",
    "réopérâtes": "réopérer",
    "réopérèrent": "réopérer",
    "réopéré": "réopérer",
    "réopérée": "réopérer",
    "réopérées": "réopérer",
    "réopérés": "réopérer",
    "réorchestra": "réorchestrer",
    "réorchestrai": "réorchestrer",
    "réorchestraient": "réorchestrer",
    "réorchestrais": "réorchestrer",
    "réorchestrait": "réorchestrer",
    "réorchestrant": "réorchestrer",
    "réorchestras": "réorchestrer",
    "réorchestrasse": "réorchestrer",
    "réorchestrassent": "réorchestrer",
    "réorchestrasses": "réorchestrer",
    "réorchestrassiez": "réorchestrer",
    "réorchestrassions": "réorchestrer",
    "réorchestre": "réorchestrer",
    "réorchestrent": "réorchestrer",
    "réorchestrera": "réorchestrer",
    "réorchestrerai": "réorchestrer",
    "réorchestreraient": "réorchestrer",
    "réorchestrerais": "réorchestrer",
    "réorchestrerait": "réorchestrer",
    "réorchestreras": "réorchestrer",
    "réorchestrerez": "réorchestrer",
    "réorchestreriez": "réorchestrer",
    "réorchestrerions": "réorchestrer",
    "réorchestrerons": "réorchestrer",
    "réorchestreront": "réorchestrer",
    "réorchestres": "réorchestrer",
    "réorchestrez": "réorchestrer",
    "réorchestriez": "réorchestrer",
    "réorchestrions": "réorchestrer",
    "réorchestrons": "réorchestrer",
    "réorchestrâmes": "réorchestrer",
    "réorchestrât": "réorchestrer",
    "réorchestrâtes": "réorchestrer",
    "réorchestrèrent": "réorchestrer",
    "réorchestré": "réorchestrer",
    "réorchestrée": "réorchestrer",
    "réorchestrées": "réorchestrer",
    "réorchestrés": "réorchestrer",
    "réordonna": "réordonner",
    "réordonnai": "réordonner",
    "réordonnaient": "réordonner",
    "réordonnais": "réordonner",
    "réordonnait": "réordonner",
    "réordonnant": "réordonner",
    "réordonnas": "réordonner",
    "réordonnasse": "réordonner",
    "réordonnassent": "réordonner",
    "réordonnasses": "réordonner",
    "réordonnassiez": "réordonner",
    "réordonnassions": "réordonner",
    "réordonne": "réordonner",
    "réordonnent": "réordonner",
    "réordonnera": "réordonner",
    "réordonnerai": "réordonner",
    "réordonneraient": "réordonner",
    "réordonnerais": "réordonner",
    "réordonnerait": "réordonner",
    "réordonneras": "réordonner",
    "réordonnerez": "réordonner",
    "réordonneriez": "réordonner",
    "réordonnerions": "réordonner",
    "réordonnerons": "réordonner",
    "réordonneront": "réordonner",
    "réordonnes": "réordonner",
    "réordonnez": "réordonner",
    "réordonniez": "réordonner",
    "réordonnions": "réordonner",
    "réordonnons": "réordonner",
    "réordonnâmes": "réordonner",
    "réordonnât": "réordonner",
    "réordonnâtes": "réordonner",
    "réordonnèrent": "réordonner",
    "réordonné": "réordonner",
    "réordonnée": "réordonner",
    "réordonnées": "réordonner",
    "réordonnés": "réordonner",
    "réorganisa": "réorganiser",
    "réorganisai": "réorganiser",
    "réorganisaient": "réorganiser",
    "réorganisais": "réorganiser",
    "réorganisait": "réorganiser",
    "réorganisant": "réorganiser",
    "réorganisas": "réorganiser",
    "réorganisasse": "réorganiser",
    "réorganisassent": "réorganiser",
    "réorganisasses": "réorganiser",
    "réorganisassiez": "réorganiser",
    "réorganisassions": "réorganiser",
    "réorganisations": "réorganisation",
    "réorganise": "réorganiser",
    "réorganisent": "réorganiser",
    "réorganisera": "réorganiser",
    "réorganiserai": "réorganiser",
    "réorganiseraient": "réorganiser",
    "réorganiserais": "réorganiser",
    "réorganiserait": "réorganiser",
    "réorganiseras": "réorganiser",
    "réorganiserez": "réorganiser",
    "réorganiseriez": "réorganiser",
    "réorganiserions": "réorganiser",
    "réorganiserons": "réorganiser",
    "réorganiseront": "réorganiser",
    "réorganises": "réorganiser",
    "réorganisez": "réorganiser",
    "réorganisiez": "réorganiser",
    "réorganisions": "réorganiser",
    "réorganisons": "réorganiser",
    "réorganisâmes": "réorganiser",
    "réorganisât": "réorganiser",
    "réorganisâtes": "réorganiser",
    "réorganisèrent": "réorganiser",
    "réorganisé": "réorganiser",
    "réorganisée": "réorganiser",
    "réorganisées": "réorganiser",
    "réorganisés": "réorganiser",
    "réorienta": "réorienter",
    "réorientai": "réorienter",
    "réorientaient": "réorienter",
    "réorientais": "réorienter",
    "réorientait": "réorienter",
    "réorientant": "réorienter",
    "réorientas": "réorienter",
    "réorientasse": "réorienter",
    "réorientassent": "réorienter",
    "réorientasses": "réorienter",
    "réorientassiez": "réorienter",
    "réorientassions": "réorienter",
    "réorientations": "réorientation",
    "réoriente": "réorienter",
    "réorientent": "réorienter",
    "réorientera": "réorienter",
    "réorienterai": "réorienter",
    "réorienteraient": "réorienter",
    "réorienterais": "réorienter",
    "réorienterait": "réorienter",
    "réorienteras": "réorienter",
    "réorienterez": "réorienter",
    "réorienteriez": "réorienter",
    "réorienterions": "réorienter",
    "réorienterons": "réorienter",
    "réorienteront": "réorienter",
    "réorientes": "réorienter",
    "réorientez": "réorienter",
    "réorientiez": "réorienter",
    "réorientions": "réorienter",
    "réorientons": "réorienter",
    "réorientâmes": "réorienter",
    "réorientât": "réorienter",
    "réorientâtes": "réorienter",
    "réorientèrent": "réorienter",
    "réorienté": "réorienter",
    "réorientée": "réorienter",
    "réorientées": "réorienter",
    "réorientés": "réorienter",
    "réouverte": "réouvert",
    "réouvertes": "réouvert",
    "réouverts": "réouvert",
    "réouvertures": "réouverture",
    "répand": "répandre",
    "répandaient": "répandre",
    "répandais": "répandre",
    "répandait": "répandre",
    "répandant": "répandre",
    "répande": "répandre",
    "répandent": "répandre",
    "répandes": "répandre",
    "répandez": "répandre",
    "répandiez": "répandre",
    "répandions": "répandre",
    "répandirent": "répandre",
    "répandis": "répandre",
    "répandisse": "répandre",
    "répandissent": "répandre",
    "répandisses": "répandre",
    "répandissiez": "répandre",
    "répandissions": "répandre",
    "répandit": "répandre",
    "répandons": "répandre",
    "répandra": "répandre",
    "répandrai": "répandre",
    "répandraient": "répandre",
    "répandrais": "répandre",
    "répandrait": "répandre",
    "répandras": "répandre",
    "répandrez": "répandre",
    "répandriez": "répandre",
    "répandrions": "répandre",
    "répandrons": "répandre",
    "répandront": "répandre",
    "répands": "répandre",
    "répandu": "répandre",
    "répandue": "répandu",
    "répandues": "répandu",
    "répandus": "répandu",
    "répandîmes": "répandre",
    "répandît": "répandre",
    "répandîtes": "répandre",
    "répara": "réparer",
    "réparables": "réparable",
    "réparai": "réparer",
    "réparaient": "réparer",
    "réparais": "réparer",
    "réparait": "réparer",
    "réparant": "réparer",
    "réparas": "réparer",
    "réparasse": "réparer",
    "réparassent": "réparer",
    "réparasses": "réparer",
    "réparassiez": "réparer",
    "réparassions": "réparer",
    "réparateurs": "réparateur",
    "réparations": "réparation",
    "réparatrice": "réparateur",
    "réparatrices": "réparateur",
    "répare": "réparer",
    "réparent": "réparer",
    "réparera": "réparer",
    "réparerai": "réparer",
    "répareraient": "réparer",
    "réparerais": "réparer",
    "réparerait": "réparer",
    "répareras": "réparer",
    "réparerez": "réparer",
    "répareriez": "réparer",
    "réparerions": "réparer",
    "réparerons": "réparer",
    "répareront": "réparer",
    "répares": "réparer",
    "réparez": "réparer",
    "répariez": "réparer",
    "réparions": "réparer",
    "réparons": "réparer",
    "réparti": "répartir",
    "répartie": "répartir",
    "réparties": "répartir",
    "répartira": "répartir",
    "répartirai": "répartir",
    "répartiraient": "répartir",
    "répartirais": "répartir",
    "répartirait": "répartir",
    "répartiras": "répartir",
    "répartirent": "répartir",
    "répartirez": "répartir",
    "répartiriez": "répartir",
    "répartirions": "répartir",
    "répartirons": "répartir",
    "répartiront": "répartir",
    "répartis": "répartir",
    "répartissaient": "répartir",
    "répartissais": "répartir",
    "répartissait": "répartir",
    "répartissant": "répartir",
    "répartisse": "répartir",
    "répartissent": "répartir",
    "répartisses": "répartir",
    "répartissez": "répartir",
    "répartissiez": "répartir",
    "répartissions": "répartir",
    "répartissons": "répartir",
    "répartit": "répartir",
    "répartitions": "répartition",
    "répartîmes": "répartir",
    "répartît": "répartir",
    "répartîtes": "répartir",
    "réparâmes": "réparer",
    "réparât": "réparer",
    "réparâtes": "réparer",
    "réparèrent": "réparer",
    "réparé": "réparer",
    "réparée": "réparer",
    "réparées": "réparer",
    "réparés": "réparer",
    "répercussions": "répercussion",
    "répercuta": "répercuter",
    "répercutai": "répercuter",
    "répercutaient": "répercuter",
    "répercutais": "répercuter",
    "répercutait": "répercuter",
    "répercutant": "répercuter",
    "répercutas": "répercuter",
    "répercutasse": "répercuter",
    "répercutassent": "répercuter",
    "répercutasses": "répercuter",
    "répercutassiez": "répercuter",
    "répercutassions": "répercuter",
    "répercute": "répercuter",
    "répercutent": "répercuter",
    "répercutera": "répercuter",
    "répercuterai": "répercuter",
    "répercuteraient": "répercuter",
    "répercuterais": "répercuter",
    "répercuterait": "répercuter",
    "répercuteras": "répercuter",
    "répercuterez": "répercuter",
    "répercuteriez": "répercuter",
    "répercuterions": "répercuter",
    "répercuterons": "répercuter",
    "répercuteront": "répercuter",
    "répercutes": "répercuter",
    "répercutez": "répercuter",
    "répercutiez": "répercuter",
    "répercutions": "répercuter",
    "répercutons": "répercuter",
    "répercutâmes": "répercuter",
    "répercutât": "répercuter",
    "répercutâtes": "répercuter",
    "répercutèrent": "répercuter",
    "répercuté": "répercuter",
    "répercutée": "répercuter",
    "répercutées": "répercuter",
    "répercutés": "répercuter",
    "répertoires": "répertoire",
    "répertoria": "répertorier",
    "répertoriai": "répertorier",
    "répertoriaient": "répertorier",
    "répertoriais": "répertorier",
    "répertoriait": "répertorier",
    "répertoriant": "répertorier",
    "répertorias": "répertorier",
    "répertoriasse": "répertorier",
    "répertoriassent": "répertorier",
    "répertoriasses": "répertorier",
    "répertoriassiez": "répertorier",
    "répertoriassions": "répertorier",
    "répertorie": "répertorier",
    "répertorient": "répertorier",
    "répertoriera": "répertorier",
    "répertorierai": "répertorier",
    "répertorieraient": "répertorier",
    "répertorierais": "répertorier",
    "répertorierait": "répertorier",
    "répertorieras": "répertorier",
    "répertorierez": "répertorier",
    "répertorieriez": "répertorier",
    "répertorierions": "répertorier",
    "répertorierons": "répertorier",
    "répertorieront": "répertorier",
    "répertories": "répertorier",
    "répertoriez": "répertorier",
    "répertoriiez": "répertorier",
    "répertoriions": "répertorier",
    "répertorions": "répertorier",
    "répertoriâmes": "répertorier",
    "répertoriât": "répertorier",
    "répertoriâtes": "répertorier",
    "répertorièrent": "répertorier",
    "répertorié": "répertorier",
    "répertoriée": "répertorier",
    "répertoriées": "répertorier",
    "répertoriés": "répertorier",
    "répits": "répit",
    "répliqua": "répliquer",
    "répliquai": "répliquer",
    "répliquaient": "répliquer",
    "répliquais": "répliquer",
    "répliquait": "répliquer",
    "répliquant": "répliquer",
    "répliquas": "répliquer",
    "répliquasse": "répliquer",
    "répliquassent": "répliquer",
    "répliquasses": "répliquer",
    "répliquassiez": "répliquer",
    "répliquassions": "répliquer",
    "réplique": "répliquer",
    "répliquent": "répliquer",
    "répliquera": "répliquer",
    "répliquerai": "répliquer",
    "répliqueraient": "répliquer",
    "répliquerais": "répliquer",
    "répliquerait": "répliquer",
    "répliqueras": "répliquer",
    "répliquerez": "répliquer",
    "répliqueriez": "répliquer",
    "répliquerions": "répliquer",
    "répliquerons": "répliquer",
    "répliqueront": "répliquer",
    "répliques": "répliquer",
    "répliquez": "répliquer",
    "répliquiez": "répliquer",
    "répliquions": "répliquer",
    "répliquons": "répliquer",
    "répliquâmes": "répliquer",
    "répliquât": "répliquer",
    "répliquâtes": "répliquer",
    "répliquèrent": "répliquer",
    "répliqué": "répliquer",
    "répliquée": "répliquer",
    "répliquées": "répliquer",
    "répliqués": "répliquer",
    "réplétifs": "réplétif",
    "réplétive": "réplétif",
    "réplétives": "réplétif",
    "répond": "répondre",
    "répondaient": "répondre",
    "répondais": "répondre",
    "répondait": "répondre",
    "répondant": "répondre",
    "répondants": "répondant",
    "réponde": "répondre",
    "répondent": "répondre",
    "répondes": "répondre",
    "répondeurs": "répondeur",
    "répondeuse": "répondeur",
    "répondez": "répondre",
    "répondiez": "répondre",
    "répondions": "répondre",
    "répondirent": "répondre",
    "répondis": "répondre",
    "répondisse": "répondre",
    "répondissent": "répondre",
    "répondisses": "répondre",
    "répondissiez": "répondre",
    "répondissions": "répondre",
    "répondit": "répondre",
    "répondons": "répondre",
    "répondra": "répondre",
    "répondrai": "répondre",
    "répondraient": "répondre",
    "répondrais": "répondre",
    "répondrait": "répondre",
    "répondras": "répondre",
    "répondrez": "répondre",
    "répondriez": "répondre",
    "répondrions": "répondre",
    "répondrons": "répondre",
    "répondront": "répondre",
    "réponds": "répondre",
    "répondu": "répondre",
    "répondue": "répondre",
    "répondues": "répondre",
    "répondus": "répondre",
    "répondîmes": "répondre",
    "répondît": "répondre",
    "répondîtes": "répondre",
    "réponses": "réponse",
    "répressifs": "répressif",
    "répressions": "répression",
    "répressive": "répressif",
    "répressives": "répressif",
    "réprima": "réprimer",
    "réprimai": "réprimer",
    "réprimaient": "réprimer",
    "réprimais": "réprimer",
    "réprimait": "réprimer",
    "réprimanda": "réprimander",
    "réprimandait": "réprimander",
    "réprimande": "réprimander",
    "réprimandes": "réprimande",
    "réprimandiez": "réprimander",
    "réprimandé": "réprimander",
    "réprimandée": "réprimander",
    "réprimant": "réprimer",
    "réprimas": "réprimer",
    "réprimasse": "réprimer",
    "réprimassent": "réprimer",
    "réprimasses": "réprimer",
    "réprimassiez": "réprimer",
    "réprimassions": "réprimer",
    "réprime": "réprimer",
    "répriment": "réprimer",
    "réprimera": "réprimer",
    "réprimerai": "réprimer",
    "réprimeraient": "réprimer",
    "réprimerais": "réprimer",
    "réprimerait": "réprimer",
    "réprimeras": "réprimer",
    "réprimerez": "réprimer",
    "réprimeriez": "réprimer",
    "réprimerions": "réprimer",
    "réprimerons": "réprimer",
    "réprimeront": "réprimer",
    "réprimes": "réprimer",
    "réprimez": "réprimer",
    "réprimiez": "réprimer",
    "réprimions": "réprimer",
    "réprimons": "réprimer",
    "réprimâmes": "réprimer",
    "réprimât": "réprimer",
    "réprimâtes": "réprimer",
    "réprimèrent": "réprimer",
    "réprimé": "réprimer",
    "réprimée": "réprimer",
    "réprimées": "réprimer",
    "réprimés": "réprimer",
    "réprobateurs": "réprobateur",
    "réprobations": "réprobation",
    "réprobatrice": "réprobateur",
    "réprobatrices": "réprobateur",
    "réprouva": "réprouver",
    "réprouvai": "réprouver",
    "réprouvaient": "réprouver",
    "réprouvais": "réprouver",
    "réprouvait": "réprouver",
    "réprouvant": "réprouver",
    "réprouvas": "réprouver",
    "réprouvasse": "réprouver",
    "réprouvassent": "réprouver",
    "réprouvasses": "réprouver",
    "réprouvassiez": "réprouver",
    "réprouvassions": "réprouver",
    "réprouve": "réprouver",
    "réprouvent": "réprouver",
    "réprouvera": "réprouver",
    "réprouverai": "réprouver",
    "réprouveraient": "réprouver",
    "réprouverais": "réprouver",
    "réprouverait": "réprouver",
    "réprouveras": "réprouver",
    "réprouverez": "réprouver",
    "réprouveriez": "réprouver",
    "réprouverions": "réprouver",
    "réprouverons": "réprouver",
    "réprouveront": "réprouver",
    "réprouves": "réprouver",
    "réprouvez": "réprouver",
    "réprouviez": "réprouver",
    "réprouvions": "réprouver",
    "réprouvons": "réprouver",
    "réprouvâmes": "réprouver",
    "réprouvât": "réprouver",
    "réprouvâtes": "réprouver",
    "réprouvèrent": "réprouver",
    "réprouvé": "réprouver",
    "réprouvée": "réprouver",
    "réprouvées": "réprouver",
    "réprouvés": "réprouver",
    "répréhensibles": "répréhensible",
    "républicaine": "républicain",
    "républicaines": "républicain",
    "républicains": "républicain",
    "républicanismes": "républicanisme",
    "républiques": "république",
    "répudia": "répudier",
    "répudiai": "répudier",
    "répudiaient": "répudier",
    "répudiais": "répudier",
    "répudiait": "répudier",
    "répudiant": "répudier",
    "répudias": "répudier",
    "répudiasse": "répudier",
    "répudiassent": "répudier",
    "répudiasses": "répudier",
    "répudiassiez": "répudier",
    "répudiassions": "répudier",
    "répudiations": "répudiation",
    "répudie": "répudier",
    "répudient": "répudier",
    "répudiera": "répudier",
    "répudierai": "répudier",
    "répudieraient": "répudier",
    "répudierais": "répudier",
    "répudierait": "répudier",
    "répudieras": "répudier",
    "répudierez": "répudier",
    "répudieriez": "répudier",
    "répudierions": "répudier",
    "répudierons": "répudier",
    "répudieront": "répudier",
    "répudies": "répudier",
    "répudiez": "répudier",
    "répudiiez": "répudier",
    "répudiions": "répudier",
    "répudions": "répudier",
    "répudiâmes": "répudier",
    "répudiât": "répudier",
    "répudiâtes": "répudier",
    "répudièrent": "répudier",
    "répudié": "répudier",
    "répudiée": "répudier",
    "répudiées": "répudier",
    "répudiés": "répudier",
    "répugna": "répugner",
    "répugnai": "répugner",
    "répugnaient": "répugner",
    "répugnais": "répugner",
    "répugnait": "répugner",
    "répugnances": "répugnance",
    "répugnant": "répugner",
    "répugnante": "répugnant",
    "répugnantes": "répugnant",
    "répugnants": "répugnant",
    "répugnas": "répugner",
    "répugnasse": "répugner",
    "répugnassent": "répugner",
    "répugnasses": "répugner",
    "répugnassiez": "répugner",
    "répugnassions": "répugner",
    "répugne": "répugner",
    "répugnent": "répugner",
    "répugnera": "répugner",
    "répugnerai": "répugner",
    "répugneraient": "répugner",
    "répugnerais": "répugner",
    "répugnerait": "répugner",
    "répugneras": "répugner",
    "répugnerez": "répugner",
    "répugneriez": "répugner",
    "répugnerions": "répugner",
    "répugnerons": "répugner",
    "répugneront": "répugner",
    "répugnes": "répugner",
    "répugnez": "répugner",
    "répugniez": "répugner",
    "répugnions": "répugner",
    "répugnons": "répugner",
    "répugnâmes": "répugner",
    "répugnât": "répugner",
    "répugnâtes": "répugner",
    "répugnèrent": "répugner",
    "répugné": "répugner",
    "répugnée": "répugner",
    "répulsifs": "répulsif",
    "répulsions": "répulsion",
    "répulsive": "répulsif",
    "répulsives": "répulsif",
    "réputa": "réputer",
    "réputai": "réputer",
    "réputaient": "réputer",
    "réputais": "réputer",
    "réputait": "réputer",
    "réputant": "réputer",
    "réputas": "réputer",
    "réputasse": "réputer",
    "réputassent": "réputer",
    "réputasses": "réputer",
    "réputassiez": "réputer",
    "réputassions": "réputer",
    "réputations": "réputation",
    "répute": "réputer",
    "réputent": "réputer",
    "réputera": "réputer",
    "réputerai": "réputer",
    "réputeraient": "réputer",
    "réputerais": "réputer",
    "réputerait": "réputer",
    "réputeras": "réputer",
    "réputerez": "réputer",
    "réputeriez": "réputer",
    "réputerions": "réputer",
    "réputerons": "réputer",
    "réputeront": "réputer",
    "réputes": "réputer",
    "réputez": "réputer",
    "réputiez": "réputer",
    "réputions": "réputer",
    "réputons": "réputer",
    "réputâmes": "réputer",
    "réputât": "réputer",
    "réputâtes": "réputer",
    "réputèrent": "réputer",
    "réputé": "réputer",
    "réputée": "réputer",
    "réputées": "réputer",
    "réputés": "réputer",
    "répète": "répéter",
    "répètent": "répéter",
    "répètes": "répéter",
    "répéta": "répéter",
    "répétai": "répéter",
    "répétaient": "répéter",
    "répétais": "répéter",
    "répétait": "répéter",
    "répétant": "répéter",
    "répétas": "répéter",
    "répétasse": "répéter",
    "répétassent": "répéter",
    "répétasses": "répéter",
    "répétassiez": "répéter",
    "répétassions": "répéter",
    "répétera": "répéter",
    "répéterai": "répéter",
    "répéteraient": "répéter",
    "répéterais": "répéter",
    "répéterait": "répéter",
    "répéteras": "répéter",
    "répéterez": "répéter",
    "répéteriez": "répéter",
    "répéterions": "répéter",
    "répéterons": "répéter",
    "répéteront": "répéter",
    "répétez": "répéter",
    "répétiez": "répéter",
    "répétions": "répéter",
    "répétiteurs": "répétiteur",
    "répétitifs": "répétitif",
    "répétitions": "répétition",
    "répétitive": "répétitif",
    "répétitives": "répétitif",
    "répétitrice": "répétiteur",
    "répétons": "répéter",
    "répétâmes": "répéter",
    "répétât": "répéter",
    "répétâtes": "répéter",
    "répétèrent": "répéter",
    "répété": "répéter",
    "répétée": "répéter",
    "répétées": "répéter",
    "répétés": "répéter",
    "réquisitionna": "réquisitionner",
    "réquisitionnai": "réquisitionner",
    "réquisitionnaient": "réquisitionner",
    "réquisitionnais": "réquisitionner",
    "réquisitionnait": "réquisitionner",
    "réquisitionnant": "réquisitionner",
    "réquisitionnas": "réquisitionner",
    "réquisitionnasse": "réquisitionner",
    "réquisitionnassent": "réquisitionner",
    "réquisitionnasses": "réquisitionner",
    "réquisitionnassiez": "réquisitionner",
    "réquisitionnassions": "réquisitionner",
    "réquisitionne": "réquisitionner",
    "réquisitionnent": "réquisitionner",
    "réquisitionnera": "réquisitionner",
    "réquisitionnerai": "réquisitionner",
    "réquisitionneraient": "réquisitionner",
    "réquisitionnerais": "réquisitionner",
    "réquisitionnerait": "réquisitionner",
    "réquisitionneras": "réquisitionner",
    "réquisitionnerez": "réquisitionner",
    "réquisitionneriez": "réquisitionner",
    "réquisitionnerions": "réquisitionner",
    "réquisitionnerons": "réquisitionner",
    "réquisitionneront": "réquisitionner",
    "réquisitionnes": "réquisitionner",
    "réquisitionnez": "réquisitionner",
    "réquisitionniez": "réquisitionner",
    "réquisitionnions": "réquisitionner",
    "réquisitionnons": "réquisitionner",
    "réquisitionnâmes": "réquisitionner",
    "réquisitionnât": "réquisitionner",
    "réquisitionnâtes": "réquisitionner",
    "réquisitionnèrent": "réquisitionner",
    "réquisitionné": "réquisitionner",
    "réquisitionnée": "réquisitionner",
    "réquisitionnées": "réquisitionner",
    "réquisitionnés": "réquisitionner",
    "réquisitions": "réquisition",
    "réquisitoires": "réquisitoire",
    "réseaux": "réseau",
    "résections": "résection",
    "réserva": "réserver",
    "réservai": "réserver",
    "réservaient": "réserver",
    "réservais": "réserver",
    "réservait": "réserver",
    "réservant": "réserver",
    "réservas": "réserver",
    "réservasse": "réserver",
    "réservassent": "réserver",
    "réservasses": "réserver",
    "réservassiez": "réserver",
    "réservassions": "réserver",
    "réservations": "réservation",
    "réserve": "réserver",
    "réservent": "réserver",
    "réservera": "réserver",
    "réserverai": "réserver",
    "réserveraient": "réserver",
    "réserverais": "réserver",
    "réserverait": "réserver",
    "réserveras": "réserver",
    "réserverez": "réserver",
    "réserveriez": "réserver",
    "réserverions": "réserver",
    "réserverons": "réserver",
    "réserveront": "réserver",
    "réserves": "réserver",
    "réservez": "réserver",
    "réserviez": "réserver",
    "réservions": "réserver",
    "réservistes": "réserviste",
    "réservoirs": "réservoir",
    "réservons": "réserver",
    "réservâmes": "réserver",
    "réservât": "réserver",
    "réservâtes": "réserver",
    "réservèrent": "réserver",
    "réservé": "réserver",
    "réservée": "réserver",
    "réservées": "réserver",
    "réservés": "réserver",
    "résida": "résider",
    "résidai": "résider",
    "résidaient": "résider",
    "résidais": "résider",
    "résidait": "résider",
    "résidant": "résider",
    "résidante": "résidant",
    "résidantes": "résidant",
    "résidants": "résidant",
    "résidas": "résider",
    "résidasse": "résider",
    "résidassent": "résider",
    "résidasses": "résider",
    "résidassiez": "résider",
    "résidassions": "résider",
    "réside": "résider",
    "résidences": "résidence",
    "résident": "résider",
    "résidente": "résident",
    "résidentes": "résident",
    "résidentielle": "résidentiel",
    "résidentielles": "résidentiel",
    "résidentiels": "résidentiel",
    "résidents": "résident",
    "résidera": "résider",
    "résiderai": "résider",
    "résideraient": "résider",
    "résiderais": "résider",
    "résiderait": "résider",
    "résideras": "résider",
    "résiderez": "résider",
    "résideriez": "résider",
    "résiderions": "résider",
    "résiderons": "résider",
    "résideront": "résider",
    "résides": "résider",
    "résidez": "résider",
    "résidiez": "résider",
    "résidions": "résider",
    "résidons": "résider",
    "résiduaires": "résiduaire",
    "résiduelle": "résiduel",
    "résiduelles": "résiduel",
    "résiduels": "résiduel",
    "résidus": "résidu",
    "résidâmes": "résider",
    "résidât": "résider",
    "résidâtes": "résider",
    "résidèrent": "résider",
    "résidé": "résider",
    "résigna": "résigner",
    "résignai": "résigner",
    "résignaient": "résigner",
    "résignais": "résigner",
    "résignait": "résigner",
    "résignant": "résigner",
    "résignas": "résigner",
    "résignasse": "résigner",
    "résignassent": "résigner",
    "résignasses": "résigner",
    "résignassiez": "résigner",
    "résignassions": "résigner",
    "résignations": "résignation",
    "résigne": "résigner",
    "résignent": "résigner",
    "résignera": "résigner",
    "résignerai": "résigner",
    "résigneraient": "résigner",
    "résignerais": "résigner",
    "résignerait": "résigner",
    "résigneras": "résigner",
    "résignerez": "résigner",
    "résigneriez": "résigner",
    "résignerions": "résigner",
    "résignerons": "résigner",
    "résigneront": "résigner",
    "résignes": "résigner",
    "résignez": "résigner",
    "résigniez": "résigner",
    "résignions": "résigner",
    "résignons": "résigner",
    "résignâmes": "résigner",
    "résignât": "résigner",
    "résignâtes": "résigner",
    "résignèrent": "résigner",
    "résigné": "résigner",
    "résignée": "résigner",
    "résignées": "résigner",
    "résignés": "résigner",
    "résilia": "résilier",
    "résiliai": "résilier",
    "résiliaient": "résilier",
    "résiliais": "résilier",
    "résiliait": "résilier",
    "résiliant": "résilier",
    "résilias": "résilier",
    "résiliasse": "résilier",
    "résiliassent": "résilier",
    "résiliasses": "résilier",
    "résiliassiez": "résilier",
    "résiliassions": "résilier",
    "résiliations": "résiliation",
    "résilie": "résilier",
    "résilient": "résilier",
    "résiliera": "résilier",
    "résilierai": "résilier",
    "résilieraient": "résilier",
    "résilierais": "résilier",
    "résilierait": "résilier",
    "résilieras": "résilier",
    "résilierez": "résilier",
    "résilieriez": "résilier",
    "résilierions": "résilier",
    "résilierons": "résilier",
    "résilieront": "résilier",
    "résilies": "résilier",
    "résiliez": "résilier",
    "résiliiez": "résilier",
    "résiliions": "résilier",
    "résilions": "résilier",
    "résiliâmes": "résilier",
    "résiliât": "résilier",
    "résiliâtes": "résilier",
    "résilièrent": "résilier",
    "résilié": "résilier",
    "résiliée": "résilier",
    "résiliées": "résilier",
    "résiliés": "résilier",
    "résilles": "résille",
    "résines": "résine",
    "résineuse": "résineux",
    "résineuses": "résineux",
    "résinée": "résiner",
    "résipiscences": "résipiscence",
    "résista": "résister",
    "résistai": "résister",
    "résistaient": "résister",
    "résistais": "résister",
    "résistait": "résister",
    "résistances": "résistance",
    "résistant": "résister",
    "résistante": "résistant",
    "résistantes": "résistant",
    "résistants": "résistant",
    "résistas": "résister",
    "résistasse": "résister",
    "résistassent": "résister",
    "résistasses": "résister",
    "résistassiez": "résister",
    "résistassions": "résister",
    "résiste": "résister",
    "résistent": "résister",
    "résistera": "résister",
    "résisterai": "résister",
    "résisteraient": "résister",
    "résisterais": "résister",
    "résisterait": "résister",
    "résisteras": "résister",
    "résisterez": "résister",
    "résisteriez": "résister",
    "résisterions": "résister",
    "résisterons": "résister",
    "résisteront": "résister",
    "résistes": "résister",
    "résistez": "résister",
    "résistiez": "résister",
    "résistions": "résister",
    "résistons": "résister",
    "résistâmes": "résister",
    "résistât": "résister",
    "résistâtes": "résister",
    "résistèrent": "résister",
    "résisté": "résister",
    "résolu": "résoudre",
    "résolue": "résoudre",
    "résolues": "résoudre",
    "résolurent": "résoudre",
    "résolus": "résoudre",
    "résolusse": "résoudre",
    "résolussent": "résoudre",
    "résolusses": "résoudre",
    "résolussiez": "résoudre",
    "résolussions": "résoudre",
    "résolut": "résoudre",
    "résolutions": "résolution",
    "résolvaient": "résoudre",
    "résolvais": "résoudre",
    "résolvait": "résoudre",
    "résolvant": "résoudre",
    "résolve": "résoudre",
    "résolvent": "résoudre",
    "résolves": "résoudre",
    "résolvez": "résoudre",
    "résolviez": "résoudre",
    "résolvions": "résoudre",
    "résolvons": "résoudre",
    "résolûmes": "résoudre",
    "résolût": "résoudre",
    "résolûtes": "résoudre",
    "résonances": "résonance",
    "résonateurs": "résonateur",
    "résonna": "résonner",
    "résonnai": "résonner",
    "résonnaient": "résonner",
    "résonnais": "résonner",
    "résonnait": "résonner",
    "résonnances": "résonnance",
    "résonnant": "résonner",
    "résonnante": "résonnant",
    "résonnantes": "résonnant",
    "résonnants": "résonnant",
    "résonnas": "résonner",
    "résonnasse": "résonner",
    "résonnassent": "résonner",
    "résonnasses": "résonner",
    "résonnassiez": "résonner",
    "résonnassions": "résonner",
    "résonne": "résonner",
    "résonnent": "résonner",
    "résonnera": "résonner",
    "résonnerai": "résonner",
    "résonneraient": "résonner",
    "résonnerais": "résonner",
    "résonnerait": "résonner",
    "résonneras": "résonner",
    "résonnerez": "résonner",
    "résonneriez": "résonner",
    "résonnerions": "résonner",
    "résonnerons": "résonner",
    "résonneront": "résonner",
    "résonnes": "résonner",
    "résonnez": "résonner",
    "résonniez": "résonner",
    "résonnions": "résonner",
    "résonnons": "résonner",
    "résonnâmes": "résonner",
    "résonnât": "résonner",
    "résonnâtes": "résonner",
    "résonnèrent": "résonner",
    "résonné": "résonner",
    "résorba": "résorber",
    "résorbai": "résorber",
    "résorbaient": "résorber",
    "résorbais": "résorber",
    "résorbait": "résorber",
    "résorbant": "résorber",
    "résorbas": "résorber",
    "résorbasse": "résorber",
    "résorbassent": "résorber",
    "résorbasses": "résorber",
    "résorbassiez": "résorber",
    "résorbassions": "résorber",
    "résorbe": "résorber",
    "résorbent": "résorber",
    "résorbera": "résorber",
    "résorberai": "résorber",
    "résorberaient": "résorber",
    "résorberais": "résorber",
    "résorberait": "résorber",
    "résorberas": "résorber",
    "résorberez": "résorber",
    "résorberiez": "résorber",
    "résorberions": "résorber",
    "résorberons": "résorber",
    "résorberont": "résorber",
    "résorbes": "résorber",
    "résorbez": "résorber",
    "résorbiez": "résorber",
    "résorbions": "résorber",
    "résorbons": "résorber",
    "résorbâmes": "résorber",
    "résorbât": "résorber",
    "résorbâtes": "résorber",
    "résorbèrent": "résorber",
    "résorbé": "résorber",
    "résorbée": "résorber",
    "résorbées": "résorber",
    "résorbés": "résorber",
    "résorptions": "résorption",
    "résoudra": "résoudre",
    "résoudrai": "résoudre",
    "résoudraient": "résoudre",
    "résoudrais": "résoudre",
    "résoudrait": "résoudre",
    "résoudras": "résoudre",
    "résoudrez": "résoudre",
    "résoudriez": "résoudre",
    "résoudrions": "résoudre",
    "résoudrons": "résoudre",
    "résoudront": "résoudre",
    "résous": "résoudre",
    "résout": "résoudre",
    "résulta": "résulter",
    "résultaient": "résulter",
    "résultais": "résulter",
    "résultait": "résulter",
    "résultant": "résulter",
    "résultante": "résultant",
    "résultantes": "résultante",
    "résultants": "résultant",
    "résultassent": "résulter",
    "résultats": "résultat",
    "résulte": "résulter",
    "résultent": "résulter",
    "résultera": "résulter",
    "résulteraient": "résulter",
    "résulterait": "résulter",
    "résulteront": "résulter",
    "résultât": "résulter",
    "résultèrent": "résulter",
    "résulté": "résulter",
    "résultée": "résulter",
    "résultées": "résulter",
    "résulutions": "résulution",
    "résuma": "résumer",
    "résumai": "résumer",
    "résumaient": "résumer",
    "résumais": "résumer",
    "résumait": "résumer",
    "résumant": "résumer",
    "résumas": "résumer",
    "résumasse": "résumer",
    "résumassent": "résumer",
    "résumasses": "résumer",
    "résumassiez": "résumer",
    "résumassions": "résumer",
    "résume": "résumer",
    "résument": "résumer",
    "résumera": "résumer",
    "résumerai": "résumer",
    "résumeraient": "résumer",
    "résumerais": "résumer",
    "résumerait": "résumer",
    "résumeras": "résumer",
    "résumerez": "résumer",
    "résumeriez": "résumer",
    "résumerions": "résumer",
    "résumerons": "résumer",
    "résumeront": "résumer",
    "résumes": "résumer",
    "résumez": "résumer",
    "résumiez": "résumer",
    "résumions": "résumer",
    "résumons": "résumer",
    "résumâmes": "résumer",
    "résumât": "résumer",
    "résumâtes": "résumer",
    "résumèrent": "résumer",
    "résumé": "résumer",
    "résumée": "résumer",
    "résumées": "résumer",
    "résumés": "résumer",
    "résurgences": "résurgence",
    "résurgente": "résurgent",
    "résurrections": "résurrection",
    "résèque": "réséquer",
    "résèquent": "réséquer",
    "résèques": "réséquer",
    "résédas": "réséda",
    "réséqua": "réséquer",
    "réséquai": "réséquer",
    "réséquaient": "réséquer",
    "réséquais": "réséquer",
    "réséquait": "réséquer",
    "réséquant": "réséquer",
    "réséquas": "réséquer",
    "réséquasse": "réséquer",
    "réséquassent": "réséquer",
    "réséquasses": "réséquer",
    "réséquassiez": "réséquer",
    "réséquassions": "réséquer",
    "réséquera": "réséquer",
    "réséquerai": "réséquer",
    "réséqueraient": "réséquer",
    "réséquerais": "réséquer",
    "réséquerait": "réséquer",
    "réséqueras": "réséquer",
    "réséquerez": "réséquer",
    "réséqueriez": "réséquer",
    "réséquerions": "réséquer",
    "réséquerons": "réséquer",
    "réséqueront": "réséquer",
    "réséquez": "réséquer",
    "réséquiez": "réséquer",
    "réséquions": "réséquer",
    "réséquons": "réséquer",
    "réséquâmes": "réséquer",
    "réséquât": "réséquer",
    "réséquâtes": "réséquer",
    "réséquèrent": "réséquer",
    "réséqué": "réséquer",
    "réséquée": "réséquer",
    "réséquées": "réséquer",
    "réséqués": "réséquer",
    "rétabli": "rétablir",
    "rétablie": "rétablir",
    "rétablies": "rétablir",
    "rétablira": "rétablir",
    "rétablirai": "rétablir",
    "rétabliraient": "rétablir",
    "rétablirais": "rétablir",
    "rétablirait": "rétablir",
    "rétabliras": "rétablir",
    "rétablirent": "rétablir",
    "rétablirez": "rétablir",
    "rétabliriez": "rétablir",
    "rétablirions": "rétablir",
    "rétablirons": "rétablir",
    "rétabliront": "rétablir",
    "rétablis": "rétablir",
    "rétablissaient": "rétablir",
    "rétablissais": "rétablir",
    "rétablissait": "rétablir",
    "rétablissant": "rétablir",
    "rétablisse": "rétablir",
    "rétablissements": "rétablissement",
    "rétablissent": "rétablir",
    "rétablisses": "rétablir",
    "rétablissez": "rétablir",
    "rétablissiez": "rétablir",
    "rétablissions": "rétablir",
    "rétablissons": "rétablir",
    "rétablit": "rétablir",
    "rétablîmes": "rétablir",
    "rétablît": "rétablir",
    "rétablîtes": "rétablir",
    "rétama": "rétamer",
    "rétamai": "rétamer",
    "rétamaient": "rétamer",
    "rétamais": "rétamer",
    "rétamait": "rétamer",
    "rétamant": "rétamer",
    "rétamas": "rétamer",
    "rétamasse": "rétamer",
    "rétamassent": "rétamer",
    "rétamasses": "rétamer",
    "rétamassiez": "rétamer",
    "rétamassions": "rétamer",
    "rétame": "rétamer",
    "rétament": "rétamer",
    "rétamera": "rétamer",
    "rétamerai": "rétamer",
    "rétameraient": "rétamer",
    "rétamerais": "rétamer",
    "rétamerait": "rétamer",
    "rétameras": "rétamer",
    "rétamerez": "rétamer",
    "rétameriez": "rétamer",
    "rétamerions": "rétamer",
    "rétamerons": "rétamer",
    "rétameront": "rétamer",
    "rétames": "rétamer",
    "rétamez": "rétamer",
    "rétamiez": "rétamer",
    "rétamions": "rétamer",
    "rétamons": "rétamer",
    "rétamâmes": "rétamer",
    "rétamât": "rétamer",
    "rétamâtes": "rétamer",
    "rétamèrent": "rétamer",
    "rétamé": "rétamer",
    "rétamée": "rétamer",
    "rétamées": "rétamer",
    "rétamés": "rétamer",
    "rétentions": "rétention",
    "rétiaires": "rétiaire",
    "réticences": "réticence",
    "réticente": "réticent",
    "réticentes": "réticent",
    "réticents": "réticent",
    "réticulaires": "réticulaire",
    "réticules": "réticule",
    "réticulée": "réticuler",
    "réticulées": "réticulé",
    "réticulés": "réticulé",
    "rétifs": "rétif",
    "rétines": "rétine",
    "rétinienne": "rétinien",
    "rétiniennes": "rétinien",
    "rétinopathies": "rétinopathie",
    "rétive": "rétif",
    "rétives": "rétif",
    "rétorqua": "rétorquer",
    "rétorquai": "rétorquer",
    "rétorquaient": "rétorquer",
    "rétorquais": "rétorquer",
    "rétorquait": "rétorquer",
    "rétorquant": "rétorquer",
    "rétorquas": "rétorquer",
    "rétorquasse": "rétorquer",
    "rétorquassent": "rétorquer",
    "rétorquasses": "rétorquer",
    "rétorquassiez": "rétorquer",
    "rétorquassions": "rétorquer",
    "rétorque": "rétorquer",
    "rétorquent": "rétorquer",
    "rétorquera": "rétorquer",
    "rétorquerai": "rétorquer",
    "rétorqueraient": "rétorquer",
    "rétorquerais": "rétorquer",
    "rétorquerait": "rétorquer",
    "rétorqueras": "rétorquer",
    "rétorquerez": "rétorquer",
    "rétorqueriez": "rétorquer",
    "rétorquerions": "rétorquer",
    "rétorquerons": "rétorquer",
    "rétorqueront": "rétorquer",
    "rétorques": "rétorquer",
    "rétorquez": "rétorquer",
    "rétorquiez": "rétorquer",
    "rétorquions": "rétorquer",
    "rétorquons": "rétorquer",
    "rétorquâmes": "rétorquer",
    "rétorquât": "rétorquer",
    "rétorquâtes": "rétorquer",
    "rétorquèrent": "rétorquer",
    "rétorqué": "rétorquer",
    "rétorquée": "rétorquer",
    "rétorquées": "rétorquer",
    "rétorqués": "rétorquer",
    "rétorsions": "rétorsion",
    "rétracta": "rétracter",
    "rétractai": "rétracter",
    "rétractaient": "rétracter",
    "rétractais": "rétracter",
    "rétractait": "rétracter",
    "rétractant": "rétracter",
    "rétractas": "rétracter",
    "rétractasse": "rétracter",
    "rétractassent": "rétracter",
    "rétractasses": "rétracter",
    "rétractassiez": "rétracter",
    "rétractassions": "rétracter",
    "rétractations": "rétractation",
    "rétracte": "rétracter",
    "rétractent": "rétracter",
    "rétractera": "rétracter",
    "rétracterai": "rétracter",
    "rétracteraient": "rétracter",
    "rétracterais": "rétracter",
    "rétracterait": "rétracter",
    "rétracteras": "rétracter",
    "rétracterez": "rétracter",
    "rétracteriez": "rétracter",
    "rétracterions": "rétracter",
    "rétracterons": "rétracter",
    "rétracteront": "rétracter",
    "rétractes": "rétracter",
    "rétracteurs": "rétracteur",
    "rétractez": "rétracter",
    "rétractiez": "rétracter",
    "rétractiles": "rétractile",
    "rétractions": "rétraction",
    "rétractons": "rétracter",
    "rétractâmes": "rétracter",
    "rétractât": "rétracter",
    "rétractâtes": "rétracter",
    "rétractèrent": "rétracter",
    "rétracté": "rétracter",
    "rétractée": "rétracter",
    "rétractées": "rétracter",
    "rétractés": "rétracter",
    "rétreignaient": "rétreindre",
    "rétreignais": "rétreindre",
    "rétreignait": "rétreindre",
    "rétreignant": "rétreindre",
    "rétreigne": "rétreindre",
    "rétreignent": "rétreindre",
    "rétreignes": "rétreindre",
    "rétreignez": "rétreindre",
    "rétreigniez": "rétreindre",
    "rétreignions": "rétreindre",
    "rétreignirent": "rétreindre",
    "rétreignis": "rétreindre",
    "rétreignisse": "rétreindre",
    "rétreignissent": "rétreindre",
    "rétreignisses": "rétreindre",
    "rétreignissiez": "rétreindre",
    "rétreignissions": "rétreindre",
    "rétreignit": "rétreindre",
    "rétreignons": "rétreindre",
    "rétreignîmes": "rétreindre",
    "rétreignît": "rétreindre",
    "rétreignîtes": "rétreindre",
    "rétreindra": "rétreindre",
    "rétreindrai": "rétreindre",
    "rétreindraient": "rétreindre",
    "rétreindrais": "rétreindre",
    "rétreindrait": "rétreindre",
    "rétreindras": "rétreindre",
    "rétreindrez": "rétreindre",
    "rétreindriez": "rétreindre",
    "rétreindrions": "rétreindre",
    "rétreindrons": "rétreindre",
    "rétreindront": "rétreindre",
    "rétreins": "rétreindre",
    "rétreint": "rétreindre",
    "rétreinte": "rétreindre",
    "rétreintes": "rétreindre",
    "rétreints": "rétreindre",
    "rétribua": "rétribuer",
    "rétribuai": "rétribuer",
    "rétribuaient": "rétribuer",
    "rétribuais": "rétribuer",
    "rétribuait": "rétribuer",
    "rétribuant": "rétribuer",
    "rétribuas": "rétribuer",
    "rétribuasse": "rétribuer",
    "rétribuassent": "rétribuer",
    "rétribuasses": "rétribuer",
    "rétribuassiez": "rétribuer",
    "rétribuassions": "rétribuer",
    "rétribue": "rétribuer",
    "rétribuent": "rétribuer",
    "rétribuera": "rétribuer",
    "rétribuerai": "rétribuer",
    "rétribueraient": "rétribuer",
    "rétribuerais": "rétribuer",
    "rétribuerait": "rétribuer",
    "rétribueras": "rétribuer",
    "rétribuerez": "rétribuer",
    "rétribueriez": "rétribuer",
    "rétribuerions": "rétribuer",
    "rétribuerons": "rétribuer",
    "rétribueront": "rétribuer",
    "rétribues": "rétribuer",
    "rétribuez": "rétribuer",
    "rétribuiez": "rétribuer",
    "rétribuions": "rétribuer",
    "rétribuons": "rétribuer",
    "rétributions": "rétribution",
    "rétribuâmes": "rétribuer",
    "rétribuât": "rétribuer",
    "rétribuâtes": "rétribuer",
    "rétribuèrent": "rétribuer",
    "rétribué": "rétribuer",
    "rétribuée": "rétribuer",
    "rétribuées": "rétribuer",
    "rétribués": "rétribuer",
    "rétroactifs": "rétroactif",
    "rétroactions": "rétroaction",
    "rétroactive": "rétroactif",
    "rétroactives": "rétroactif",
    "rétroagi": "rétroagir",
    "rétroagie": "rétroagir",
    "rétroagies": "rétroagir",
    "rétroagira": "rétroagir",
    "rétroagirai": "rétroagir",
    "rétroagiraient": "rétroagir",
    "rétroagirais": "rétroagir",
    "rétroagirait": "rétroagir",
    "rétroagiras": "rétroagir",
    "rétroagirent": "rétroagir",
    "rétroagirez": "rétroagir",
    "rétroagiriez": "rétroagir",
    "rétroagirions": "rétroagir",
    "rétroagirons": "rétroagir",
    "rétroagiront": "rétroagir",
    "rétroagis": "rétroagir",
    "rétroagissaient": "rétroagir",
    "rétroagissais": "rétroagir",
    "rétroagissait": "rétroagir",
    "rétroagissant": "rétroagir",
    "rétroagisse": "rétroagir",
    "rétroagissent": "rétroagir",
    "rétroagisses": "rétroagir",
    "rétroagissez": "rétroagir",
    "rétroagissiez": "rétroagir",
    "rétroagissions": "rétroagir",
    "rétroagissons": "rétroagir",
    "rétroagit": "rétroagir",
    "rétroagîmes": "rétroagir",
    "rétroagît": "rétroagir",
    "rétroagîtes": "rétroagir",
    "rétrocessions": "rétrocession",
    "rétrocède": "rétrocéder",
    "rétrocèdent": "rétrocéder",
    "rétrocèdes": "rétrocéder",
    "rétrocéda": "rétrocéder",
    "rétrocédai": "rétrocéder",
    "rétrocédaient": "rétrocéder",
    "rétrocédais": "rétrocéder",
    "rétrocédait": "rétrocéder",
    "rétrocédant": "rétrocéder",
    "rétrocédas": "rétrocéder",
    "rétrocédasse": "rétrocéder",
    "rétrocédassent": "rétrocéder",
    "rétrocédasses": "rétrocéder",
    "rétrocédassiez": "rétrocéder",
    "rétrocédassions": "rétrocéder",
    "rétrocédera": "rétrocéder",
    "rétrocéderai": "rétrocéder",
    "rétrocéderaient": "rétrocéder",
    "rétrocéderais": "rétrocéder",
    "rétrocéderait": "rétrocéder",
    "rétrocéderas": "rétrocéder",
    "rétrocéderez": "rétrocéder",
    "rétrocéderiez": "rétrocéder",
    "rétrocéderions": "rétrocéder",
    "rétrocéderons": "rétrocéder",
    "rétrocéderont": "rétrocéder",
    "rétrocédez": "rétrocéder",
    "rétrocédiez": "rétrocéder",
    "rétrocédions": "rétrocéder",
    "rétrocédons": "rétrocéder",
    "rétrocédâmes": "rétrocéder",
    "rétrocédât": "rétrocéder",
    "rétrocédâtes": "rétrocéder",
    "rétrocédèrent": "rétrocéder",
    "rétrocédé": "rétrocéder",
    "rétrocédée": "rétrocéder",
    "rétrocédées": "rétrocéder",
    "rétrocédés": "rétrocéder",
    "rétroflexes": "rétroflexe",
    "rétrofusées": "rétrofusée",
    "rétrograda": "rétrograder",
    "rétrogradai": "rétrograder",
    "rétrogradaient": "rétrograder",
    "rétrogradais": "rétrograder",
    "rétrogradait": "rétrograder",
    "rétrogradant": "rétrograder",
    "rétrogradas": "rétrograder",
    "rétrogradasse": "rétrograder",
    "rétrogradassent": "rétrograder",
    "rétrogradasses": "rétrograder",
    "rétrogradassiez": "rétrograder",
    "rétrogradassions": "rétrograder",
    "rétrogradations": "rétrogradation",
    "rétrograde": "rétrograder",
    "rétrogradent": "rétrograder",
    "rétrogradera": "rétrograder",
    "rétrograderai": "rétrograder",
    "rétrograderaient": "rétrograder",
    "rétrograderais": "rétrograder",
    "rétrograderait": "rétrograder",
    "rétrograderas": "rétrograder",
    "rétrograderez": "rétrograder",
    "rétrograderiez": "rétrograder",
    "rétrograderions": "rétrograder",
    "rétrograderons": "rétrograder",
    "rétrograderont": "rétrograder",
    "rétrogrades": "rétrograder",
    "rétrogradez": "rétrograder",
    "rétrogradiez": "rétrograder",
    "rétrogradions": "rétrograder",
    "rétrogradons": "rétrograder",
    "rétrogradâmes": "rétrograder",
    "rétrogradât": "rétrograder",
    "rétrogradâtes": "rétrograder",
    "rétrogradèrent": "rétrograder",
    "rétrogradé": "rétrograder",
    "rétrogradée": "rétrograder",
    "rétrogradées": "rétrograder",
    "rétrogradés": "rétrograder",
    "rétroprojecteurs": "rétroprojecteur",
    "rétros": "rétro",
    "rétrospectifs": "rétrospectif",
    "rétrospective": "rétrospectif",
    "rétrospectives": "rétrospective",
    "rétrovirale": "rétroviral",
    "rétroviseurs": "rétroviseur",
    "rétréci": "rétrécir",
    "rétrécie": "rétrécir",
    "rétrécies": "rétrécir",
    "rétrécira": "rétrécir",
    "rétrécirai": "rétrécir",
    "rétréciraient": "rétrécir",
    "rétrécirais": "rétrécir",
    "rétrécirait": "rétrécir",
    "rétréciras": "rétrécir",
    "rétrécirent": "rétrécir",
    "rétrécirez": "rétrécir",
    "rétréciriez": "rétrécir",
    "rétrécirions": "rétrécir",
    "rétrécirons": "rétrécir",
    "rétréciront": "rétrécir",
    "rétrécis": "rétrécir",
    "rétrécissaient": "rétrécir",
    "rétrécissais": "rétrécir",
    "rétrécissait": "rétrécir",
    "rétrécissant": "rétrécir",
    "rétrécisse": "rétrécir",
    "rétrécissements": "rétrécissement",
    "rétrécissent": "rétrécir",
    "rétrécisses": "rétrécir",
    "rétrécissez": "rétrécir",
    "rétrécissiez": "rétrécir",
    "rétrécissions": "rétrécir",
    "rétrécissons": "rétrécir",
    "rétrécit": "rétrécir",
    "rétrécîmes": "rétrécir",
    "rétrécît": "rétrécir",
    "rétrécîtes": "rétrécir",
    "réuni": "réunir",
    "réunie": "réunir",
    "réunies": "réunir",
    "réunifia": "réunifier",
    "réunifiai": "réunifier",
    "réunifiaient": "réunifier",
    "réunifiais": "réunifier",
    "réunifiait": "réunifier",
    "réunifiant": "réunifier",
    "réunifias": "réunifier",
    "réunifiasse": "réunifier",
    "réunifiassent": "réunifier",
    "réunifiasses": "réunifier",
    "réunifiassiez": "réunifier",
    "réunifiassions": "réunifier",
    "réunifications": "réunification",
    "réunifictions": "réunifiction",
    "réunifie": "réunifier",
    "réunifient": "réunifier",
    "réunifiera": "réunifier",
    "réunifierai": "réunifier",
    "réunifieraient": "réunifier",
    "réunifierais": "réunifier",
    "réunifierait": "réunifier",
    "réunifieras": "réunifier",
    "réunifierez": "réunifier",
    "réunifieriez": "réunifier",
    "réunifierions": "réunifier",
    "réunifierons": "réunifier",
    "réunifieront": "réunifier",
    "réunifies": "réunifier",
    "réunifiez": "réunifier",
    "réunifiiez": "réunifier",
    "réunifiions": "réunifier",
    "réunifions": "réunifier",
    "réunifiâmes": "réunifier",
    "réunifiât": "réunifier",
    "réunifiâtes": "réunifier",
    "réunifièrent": "réunifier",
    "réunifié": "réunifier",
    "réunifiée": "réunifier",
    "réunifiées": "réunifier",
    "réunifiés": "réunifier",
    "réunionnaise": "réunionnais",
    "réunionnaises": "réunionnais",
    "réunions": "réunion",
    "réunira": "réunir",
    "réunirai": "réunir",
    "réuniraient": "réunir",
    "réunirais": "réunir",
    "réunirait": "réunir",
    "réuniras": "réunir",
    "réunirent": "réunir",
    "réunirez": "réunir",
    "réuniriez": "réunir",
    "réunirions": "réunir",
    "réunirons": "réunir",
    "réuniront": "réunir",
    "réunis": "réunir",
    "réunissaient": "réunir",
    "réunissais": "réunir",
    "réunissait": "réunir",
    "réunissant": "réunir",
    "réunisse": "réunir",
    "réunissent": "réunir",
    "réunisses": "réunir",
    "réunissez": "réunir",
    "réunissiez": "réunir",
    "réunissions": "réunir",
    "réunissons": "réunir",
    "réunit": "réunir",
    "réunîmes": "réunir",
    "réunît": "réunir",
    "réunîtes": "réunir",
    "réussi": "réussir",
    "réussie": "réussir",
    "réussies": "réussir",
    "réussira": "réussir",
    "réussirai": "réussir",
    "réussiraient": "réussir",
    "réussirais": "réussir",
    "réussirait": "réussir",
    "réussiras": "réussir",
    "réussirent": "réussir",
    "réussirez": "réussir",
    "réussiriez": "réussir",
    "réussirions": "réussir",
    "réussirons": "réussir",
    "réussiront": "réussir",
    "réussis": "réussir",
    "réussissaient": "réussir",
    "réussissais": "réussir",
    "réussissait": "réussir",
    "réussissant": "réussir",
    "réussisse": "réussir",
    "réussissent": "réussir",
    "réussisses": "réussir",
    "réussissez": "réussir",
    "réussissiez": "réussir",
    "réussissions": "réussir",
    "réussissons": "réussir",
    "réussit": "réussir",
    "réussites": "réussite",
    "réussîmes": "réussir",
    "réussît": "réussir",
    "réussîtes": "réussir",
    "réutilisables": "réutilisable",
    "réutilisait": "réutiliser",
    "réutilisations": "réutilisation",
    "réutilise": "réutiliser",
    "réutilisé": "réutiliser",
    "réutilisés": "réutiliser",
    "réveilla": "réveiller",
    "réveillai": "réveiller",
    "réveillaient": "réveiller",
    "réveillais": "réveiller",
    "réveillait": "réveiller",
    "réveillant": "réveiller",
    "réveillas": "réveiller",
    "réveillasse": "réveiller",
    "réveillassent": "réveiller",
    "réveillasses": "réveiller",
    "réveillassiez": "réveiller",
    "réveillassions": "réveiller",
    "réveille": "réveiller",
    "réveille-matins": "réveille-matin",
    "réveillent": "réveiller",
    "réveillera": "réveiller",
    "réveillerai": "réveiller",
    "réveilleraient": "réveiller",
    "réveillerais": "réveiller",
    "réveillerait": "réveiller",
    "réveilleras": "réveiller",
    "réveillerez": "réveiller",
    "réveilleriez": "réveiller",
    "réveillerions": "réveiller",
    "réveillerons": "réveiller",
    "réveilleront": "réveiller",
    "réveilles": "réveiller",
    "réveilleurs": "réveilleur",
    "réveillez": "réveiller",
    "réveilliez": "réveiller",
    "réveillions": "réveiller",
    "réveillonna": "réveillonner",
    "réveillonnai": "réveillonner",
    "réveillonnaient": "réveillonner",
    "réveillonnais": "réveillonner",
    "réveillonnait": "réveillonner",
    "réveillonnant": "réveillonner",
    "réveillonnas": "réveillonner",
    "réveillonnasse": "réveillonner",
    "réveillonnassent": "réveillonner",
    "réveillonnasses": "réveillonner",
    "réveillonnassiez": "réveillonner",
    "réveillonnassions": "réveillonner",
    "réveillonne": "réveillonner",
    "réveillonnent": "réveillonner",
    "réveillonnera": "réveillonner",
    "réveillonnerai": "réveillonner",
    "réveillonneraient": "réveillonner",
    "réveillonnerais": "réveillonner",
    "réveillonnerait": "réveillonner",
    "réveillonneras": "réveillonner",
    "réveillonnerez": "réveillonner",
    "réveillonneriez": "réveillonner",
    "réveillonnerions": "réveillonner",
    "réveillonnerons": "réveillonner",
    "réveillonneront": "réveillonner",
    "réveillonnes": "réveillonner",
    "réveillonneurs": "réveillonneur",
    "réveillonnez": "réveillonner",
    "réveillonniez": "réveillonner",
    "réveillonnions": "réveillonner",
    "réveillonnons": "réveillonner",
    "réveillonnâmes": "réveillonner",
    "réveillonnât": "réveillonner",
    "réveillonnâtes": "réveillonner",
    "réveillonnèrent": "réveillonner",
    "réveillonné": "réveillonner",
    "réveillons": "réveillon",
    "réveillâmes": "réveiller",
    "réveillât": "réveiller",
    "réveillâtes": "réveiller",
    "réveillèrent": "réveiller",
    "réveillé": "réveiller",
    "réveillée": "réveiller",
    "réveillées": "réveiller",
    "réveillés": "réveiller",
    "réveils": "réveil",
    "réverbère": "réverbérer",
    "réverbèrent": "réverbérer",
    "réverbères": "réverbérer",
    "réverbéra": "réverbérer",
    "réverbérai": "réverbérer",
    "réverbéraient": "réverbérer",
    "réverbérais": "réverbérer",
    "réverbérait": "réverbérer",
    "réverbérant": "réverbérer",
    "réverbéras": "réverbérer",
    "réverbérasse": "réverbérer",
    "réverbérassent": "réverbérer",
    "réverbérasses": "réverbérer",
    "réverbérassiez": "réverbérer",
    "réverbérassions": "réverbérer",
    "réverbérations": "réverbération",
    "réverbérera": "réverbérer",
    "réverbérerai": "réverbérer",
    "réverbéreraient": "réverbérer",
    "réverbérerais": "réverbérer",
    "réverbérerait": "réverbérer",
    "réverbéreras": "réverbérer",
    "réverbérerez": "réverbérer",
    "réverbéreriez": "réverbérer",
    "réverbérerions": "réverbérer",
    "réverbérerons": "réverbérer",
    "réverbéreront": "réverbérer",
    "réverbérez": "réverbérer",
    "réverbériez": "réverbérer",
    "réverbérions": "réverbérer",
    "réverbérons": "réverbérer",
    "réverbérâmes": "réverbérer",
    "réverbérât": "réverbérer",
    "réverbérâtes": "réverbérer",
    "réverbérèrent": "réverbérer",
    "réverbéré": "réverbérer",
    "réverbérée": "réverbérer",
    "réverbérées": "réverbérer",
    "réverbérés": "réverbérer",
    "réversale": "réversal",
    "réversales": "réversal",
    "réversaux": "réversal",
    "réversibles": "réversible",
    "réversions": "réversion",
    "révisa": "réviser",
    "révisai": "réviser",
    "révisaient": "réviser",
    "révisais": "réviser",
    "révisait": "réviser",
    "révisant": "réviser",
    "révisas": "réviser",
    "révisasse": "réviser",
    "révisassent": "réviser",
    "révisasses": "réviser",
    "révisassiez": "réviser",
    "révisassions": "réviser",
    "révise": "réviser",
    "révisent": "réviser",
    "révisera": "réviser",
    "réviserai": "réviser",
    "réviseraient": "réviser",
    "réviserais": "réviser",
    "réviserait": "réviser",
    "réviseras": "réviser",
    "réviserez": "réviser",
    "réviseriez": "réviser",
    "réviserions": "réviser",
    "réviserons": "réviser",
    "réviseront": "réviser",
    "révises": "réviser",
    "révisez": "réviser",
    "révisiez": "réviser",
    "révisionnismes": "révisionnisme",
    "révisionnistes": "révisionniste",
    "révisions": "révision",
    "révisons": "réviser",
    "révisâmes": "réviser",
    "révisât": "réviser",
    "révisâtes": "réviser",
    "révisèrent": "réviser",
    "révisé": "réviser",
    "révisée": "réviser",
    "révisées": "réviser",
    "révisés": "réviser",
    "révocabilités": "révocabilité",
    "révocables": "révocable",
    "révocations": "révocation",
    "révolta": "révolter",
    "révoltai": "révolter",
    "révoltaient": "révolter",
    "révoltais": "révolter",
    "révoltait": "révolter",
    "révoltant": "révolter",
    "révoltante": "révoltant",
    "révoltantes": "révoltant",
    "révoltants": "révoltant",
    "révoltas": "révolter",
    "révoltasse": "révolter",
    "révoltassent": "révolter",
    "révoltasses": "révolter",
    "révoltassiez": "révolter",
    "révoltassions": "révolter",
    "révolte": "révolter",
    "révoltent": "révolter",
    "révoltera": "révolter",
    "révolterai": "révolter",
    "révolteraient": "révolter",
    "révolterais": "révolter",
    "révolterait": "révolter",
    "révolteras": "révolter",
    "révolterez": "révolter",
    "révolteriez": "révolter",
    "révolterions": "révolter",
    "révolterons": "révolter",
    "révolteront": "révolter",
    "révoltes": "révolter",
    "révoltez": "révolter",
    "révoltiez": "révolter",
    "révoltions": "révolter",
    "révoltons": "révolter",
    "révoltâmes": "révolter",
    "révoltât": "révolter",
    "révoltâtes": "révolter",
    "révoltèrent": "révolter",
    "révolté": "révolter",
    "révoltée": "révolter",
    "révoltées": "révolter",
    "révoltés": "révolter",
    "révolue": "révolu",
    "révolues": "révolu",
    "révolus": "révolu",
    "révolutionna": "révolutionner",
    "révolutionnai": "révolutionner",
    "révolutionnaient": "révolutionner",
    "révolutionnaires": "révolutionnaire",
    "révolutionnais": "révolutionner",
    "révolutionnait": "révolutionner",
    "révolutionnant": "révolutionner",
    "révolutionnas": "révolutionner",
    "révolutionnasse": "révolutionner",
    "révolutionnassent": "révolutionner",
    "révolutionnasses": "révolutionner",
    "révolutionnassiez": "révolutionner",
    "révolutionnassions": "révolutionner",
    "révolutionne": "révolutionner",
    "révolutionnent": "révolutionner",
    "révolutionnera": "révolutionner",
    "révolutionnerai": "révolutionner",
    "révolutionneraient": "révolutionner",
    "révolutionnerais": "révolutionner",
    "révolutionnerait": "révolutionner",
    "révolutionneras": "révolutionner",
    "révolutionnerez": "révolutionner",
    "révolutionneriez": "révolutionner",
    "révolutionnerions": "révolutionner",
    "révolutionnerons": "révolutionner",
    "révolutionneront": "révolutionner",
    "révolutionnes": "révolutionner",
    "révolutionnez": "révolutionner",
    "révolutionniez": "révolutionner",
    "révolutionnions": "révolutionner",
    "révolutionnons": "révolutionner",
    "révolutionnâmes": "révolutionner",
    "révolutionnât": "révolutionner",
    "révolutionnâtes": "révolutionner",
    "révolutionnèrent": "révolutionner",
    "révolutionné": "révolutionner",
    "révolutionnée": "révolutionner",
    "révolutionnées": "révolutionner",
    "révolutionnés": "révolutionner",
    "révolutions": "révolution",
    "révoqua": "révoquer",
    "révoquai": "révoquer",
    "révoquaient": "révoquer",
    "révoquais": "révoquer",
    "révoquait": "révoquer",
    "révoquant": "révoquer",
    "révoquas": "révoquer",
    "révoquasse": "révoquer",
    "révoquassent": "révoquer",
    "révoquasses": "révoquer",
    "révoquassiez": "révoquer",
    "révoquassions": "révoquer",
    "révoque": "révoquer",
    "révoquent": "révoquer",
    "révoquera": "révoquer",
    "révoquerai": "révoquer",
    "révoqueraient": "révoquer",
    "révoquerais": "révoquer",
    "révoquerait": "révoquer",
    "révoqueras": "révoquer",
    "révoquerez": "révoquer",
    "révoqueriez": "révoquer",
    "révoquerions": "révoquer",
    "révoquerons": "révoquer",
    "révoqueront": "révoquer",
    "révoques": "révoquer",
    "révoquez": "révoquer",
    "révoquiez": "révoquer",
    "révoquions": "révoquer",
    "révoquons": "révoquer",
    "révoquâmes": "révoquer",
    "révoquât": "révoquer",
    "révoquâtes": "révoquer",
    "révoquèrent": "révoquer",
    "révoqué": "révoquer",
    "révoquée": "révoquer",
    "révoquées": "révoquer",
    "révoqués": "révoquer",
    "révulsa": "révulser",
    "révulsai": "révulser",
    "révulsaient": "révulser",
    "révulsais": "révulser",
    "révulsait": "révulser",
    "révulsant": "révulser",
    "révulsas": "révulser",
    "révulsasse": "révulser",
    "révulsassent": "révulser",
    "révulsasses": "révulser",
    "révulsassiez": "révulser",
    "révulsassions": "révulser",
    "révulse": "révulser",
    "révulsent": "révulser",
    "révulsera": "révulser",
    "révulserai": "révulser",
    "révulseraient": "révulser",
    "révulserais": "révulser",
    "révulserait": "révulser",
    "révulseras": "révulser",
    "révulserez": "révulser",
    "révulseriez": "révulser",
    "révulserions": "révulser",
    "révulserons": "révulser",
    "révulseront": "révulser",
    "révulses": "révulser",
    "révulsez": "révulser",
    "révulsiez": "révulser",
    "révulsifs": "révulsif",
    "révulsions": "révulsion",
    "révulsive": "révulsif",
    "révulsons": "révulser",
    "révulsâmes": "révulser",
    "révulsât": "révulser",
    "révulsâtes": "révulser",
    "révulsèrent": "révulser",
    "révulsé": "révulser",
    "révulsée": "révulser",
    "révulsées": "révulser",
    "révulsés": "révulser",
    "révèle": "révéler",
    "révèlent": "révéler",
    "révèles": "révéler",
    "révère": "révérer",
    "révèrent": "révérer",
    "révères": "révérer",
    "révéla": "révéler",
    "révélai": "révéler",
    "révélaient": "révéler",
    "révélais": "révéler",
    "révélait": "révéler",
    "révélant": "révéler",
    "révélas": "révéler",
    "révélasse": "révéler",
    "révélassent": "révéler",
    "révélasses": "révéler",
    "révélassiez": "révéler",
    "révélassions": "révéler",
    "révélateurs": "révélateur",
    "révélations": "révélation",
    "révélatrice": "révélateur",
    "révélatrices": "révélateur",
    "révélera": "révéler",
    "révélerai": "révéler",
    "révéleraient": "révéler",
    "révélerais": "révéler",
    "révélerait": "révéler",
    "révéleras": "révéler",
    "révélerez": "révéler",
    "révéleriez": "révéler",
    "révélerions": "révéler",
    "révélerons": "révéler",
    "révéleront": "révéler",
    "révélez": "révéler",
    "révéliez": "révéler",
    "révélions": "révéler",
    "révélons": "révéler",
    "révélâmes": "révéler",
    "révélât": "révéler",
    "révélâtes": "révéler",
    "révélèrent": "révéler",
    "révélé": "révéler",
    "révélée": "révéler",
    "révélées": "révéler",
    "révélés": "révéler",
    "révéra": "révérer",
    "révérai": "révérer",
    "révéraient": "révérer",
    "révérais": "révérer",
    "révérait": "révérer",
    "révérant": "révérer",
    "révéras": "révérer",
    "révérasse": "révérer",
    "révérassent": "révérer",
    "révérasses": "révérer",
    "révérassiez": "révérer",
    "révérassions": "révérer",
    "révérences": "révérence",
    "révérencielle": "révérenciel",
    "révérencielles": "révérenciel",
    "révérenciels": "révérenciel",
    "révérencieuse": "révérencieux",
    "révérencieuses": "révérencieux",
    "révérende": "révérend",
    "révérendes": "révérend",
    "révérends": "révérend",
    "révérera": "révérer",
    "révérerai": "révérer",
    "révéreraient": "révérer",
    "révérerais": "révérer",
    "révérerait": "révérer",
    "révéreras": "révérer",
    "révérerez": "révérer",
    "révéreriez": "révérer",
    "révérerions": "révérer",
    "révérerons": "révérer",
    "révéreront": "révérer",
    "révérez": "révérer",
    "révériez": "révérer",
    "révérions": "révérer",
    "révérons": "révérer",
    "révérâmes": "révérer",
    "révérât": "révérer",
    "révérâtes": "révérer",
    "révérèrent": "révérer",
    "révéré": "révérer",
    "révérée": "révérer",
    "révérées": "révérer",
    "révérés": "révérer",
    "rééchelonnements": "rééchelonnement",
    "réécouta": "réécouter",
    "réécoutai": "réécouter",
    "réécoutaient": "réécouter",
    "réécoutais": "réécouter",
    "réécoutait": "réécouter",
    "réécoutant": "réécouter",
    "réécoutas": "réécouter",
    "réécoutasse": "réécouter",
    "réécoutassent": "réécouter",
    "réécoutasses": "réécouter",
    "réécoutassiez": "réécouter",
    "réécoutassions": "réécouter",
    "réécoute": "réécouter",
    "réécoutent": "réécouter",
    "réécoutera": "réécouter",
    "réécouterai": "réécouter",
    "réécouteraient": "réécouter",
    "réécouterais": "réécouter",
    "réécouterait": "réécouter",
    "réécouteras": "réécouter",
    "réécouterez": "réécouter",
    "réécouteriez": "réécouter",
    "réécouterions": "réécouter",
    "réécouterons": "réécouter",
    "réécouteront": "réécouter",
    "réécoutes": "réécouter",
    "réécoutez": "réécouter",
    "réécoutiez": "réécouter",
    "réécoutions": "réécouter",
    "réécoutons": "réécouter",
    "réécoutâmes": "réécouter",
    "réécoutât": "réécouter",
    "réécoutâtes": "réécouter",
    "réécoutèrent": "réécouter",
    "réécouté": "réécouter",
    "réécoutée": "réécouter",
    "réécoutées": "réécouter",
    "réécoutés": "réécouter",
    "réécrira": "réécrire",
    "réécrirai": "réécrire",
    "réécriraient": "réécrire",
    "réécrirais": "réécrire",
    "réécrirait": "réécrire",
    "réécriras": "réécrire",
    "réécrirez": "réécrire",
    "réécririez": "réécrire",
    "réécririons": "réécrire",
    "réécrirons": "réécrire",
    "réécriront": "réécrire",
    "réécris": "réécrire",
    "réécrit": "réécrire",
    "réécrite": "réécrire",
    "réécrites": "réécrire",
    "réécrits": "réécrire",
    "réécritures": "réécriture",
    "réécrivaient": "réécrire",
    "réécrivais": "réécrire",
    "réécrivait": "réécrire",
    "réécrivant": "réécrire",
    "réécrive": "réécrire",
    "réécrivent": "réécrire",
    "réécrives": "réécrire",
    "réécrivez": "réécrire",
    "réécriviez": "réécrire",
    "réécrivions": "réécrire",
    "réécrivirent": "réécrire",
    "réécrivis": "réécrire",
    "réécrivisse": "réécrire",
    "réécrivissent": "réécrire",
    "réécrivisses": "réécrire",
    "réécrivissiez": "réécrire",
    "réécrivissions": "réécrire",
    "réécrivit": "réécrire",
    "réécrivons": "réécrire",
    "réécrivîmes": "réécrire",
    "réécrivît": "réécrire",
    "réécrivîtes": "réécrire",
    "réédifia": "réédifier",
    "réédifiai": "réédifier",
    "réédifiaient": "réédifier",
    "réédifiais": "réédifier",
    "réédifiait": "réédifier",
    "réédifiant": "réédifier",
    "réédifias": "réédifier",
    "réédifiasse": "réédifier",
    "réédifiassent": "réédifier",
    "réédifiasses": "réédifier",
    "réédifiassiez": "réédifier",
    "réédifiassions": "réédifier",
    "réédifie": "réédifier",
    "réédifient": "réédifier",
    "réédifiera": "réédifier",
    "réédifierai": "réédifier",
    "réédifieraient": "réédifier",
    "réédifierais": "réédifier",
    "réédifierait": "réédifier",
    "réédifieras": "réédifier",
    "réédifierez": "réédifier",
    "réédifieriez": "réédifier",
    "réédifierions": "réédifier",
    "réédifierons": "réédifier",
    "réédifieront": "réédifier",
    "réédifies": "réédifier",
    "réédifiez": "réédifier",
    "réédifiiez": "réédifier",
    "réédifiions": "réédifier",
    "réédifions": "réédifier",
    "réédifiâmes": "réédifier",
    "réédifiât": "réédifier",
    "réédifiâtes": "réédifier",
    "réédifièrent": "réédifier",
    "réédifié": "réédifier",
    "réédifiée": "réédifier",
    "réédifiées": "réédifier",
    "réédifiés": "réédifier",
    "réédita": "rééditer",
    "rééditai": "rééditer",
    "rééditaient": "rééditer",
    "rééditais": "rééditer",
    "rééditait": "rééditer",
    "rééditant": "rééditer",
    "rééditas": "rééditer",
    "rééditasse": "rééditer",
    "rééditassent": "rééditer",
    "rééditasses": "rééditer",
    "rééditassiez": "rééditer",
    "rééditassions": "rééditer",
    "réédite": "rééditer",
    "rééditent": "rééditer",
    "rééditera": "rééditer",
    "rééditerai": "rééditer",
    "rééditeraient": "rééditer",
    "rééditerais": "rééditer",
    "rééditerait": "rééditer",
    "rééditeras": "rééditer",
    "rééditerez": "rééditer",
    "rééditeriez": "rééditer",
    "rééditerions": "rééditer",
    "rééditerons": "rééditer",
    "rééditeront": "rééditer",
    "réédites": "rééditer",
    "rééditez": "rééditer",
    "rééditiez": "rééditer",
    "rééditions": "réédition",
    "rééditons": "rééditer",
    "rééditâmes": "rééditer",
    "rééditât": "rééditer",
    "rééditâtes": "rééditer",
    "rééditèrent": "rééditer",
    "réédité": "rééditer",
    "rééditée": "rééditer",
    "rééditées": "rééditer",
    "réédités": "rééditer",
    "rééducatifs": "rééducatif",
    "rééducations": "rééducation",
    "rééducatives": "rééducatif",
    "rééduqua": "rééduquer",
    "rééduquai": "rééduquer",
    "rééduquaient": "rééduquer",
    "rééduquais": "rééduquer",
    "rééduquait": "rééduquer",
    "rééduquant": "rééduquer",
    "rééduquas": "rééduquer",
    "rééduquasse": "rééduquer",
    "rééduquassent": "rééduquer",
    "rééduquasses": "rééduquer",
    "rééduquassiez": "rééduquer",
    "rééduquassions": "rééduquer",
    "rééduque": "rééduquer",
    "rééduquent": "rééduquer",
    "rééduquera": "rééduquer",
    "rééduquerai": "rééduquer",
    "rééduqueraient": "rééduquer",
    "rééduquerais": "rééduquer",
    "rééduquerait": "rééduquer",
    "rééduqueras": "rééduquer",
    "rééduquerez": "rééduquer",
    "rééduqueriez": "rééduquer",
    "rééduquerions": "rééduquer",
    "rééduquerons": "rééduquer",
    "rééduqueront": "rééduquer",
    "rééduques": "rééduquer",
    "rééduquez": "rééduquer",
    "rééduquiez": "rééduquer",
    "rééduquions": "rééduquer",
    "rééduquons": "rééduquer",
    "rééduquâmes": "rééduquer",
    "rééduquât": "rééduquer",
    "rééduquâtes": "rééduquer",
    "rééduquèrent": "rééduquer",
    "rééduqué": "rééduquer",
    "rééduquée": "rééduquer",
    "rééduquées": "rééduquer",
    "rééduqués": "rééduquer",
    "réélections": "réélection",
    "réélira": "réélire",
    "réélirai": "réélire",
    "rééliraient": "réélire",
    "réélirais": "réélire",
    "réélirait": "réélire",
    "rééliras": "réélire",
    "réélirez": "réélire",
    "rééliriez": "réélire",
    "réélirions": "réélire",
    "réélirons": "réélire",
    "rééliront": "réélire",
    "réélis": "réélire",
    "réélisaient": "réélire",
    "réélisais": "réélire",
    "réélisait": "réélire",
    "réélisant": "réélire",
    "réélise": "réélire",
    "réélisent": "réélire",
    "réélises": "réélire",
    "réélisez": "réélire",
    "réélisiez": "réélire",
    "réélisions": "réélire",
    "réélisons": "réélire",
    "réélit": "réélire",
    "réélu": "réélire",
    "réélue": "réélire",
    "réélues": "réélire",
    "réélurent": "réélire",
    "réélus": "réélire",
    "réélusse": "réélire",
    "réélussent": "réélire",
    "réélusses": "réélire",
    "réélussiez": "réélire",
    "réélussions": "réélire",
    "réélut": "réélire",
    "réélûmes": "réélire",
    "réélût": "réélire",
    "réélûtes": "réélire",
    "rééquilibra": "rééquilibrer",
    "rééquilibrages": "rééquilibrage",
    "rééquilibrai": "rééquilibrer",
    "rééquilibraient": "rééquilibrer",
    "rééquilibrais": "rééquilibrer",
    "rééquilibrait": "rééquilibrer",
    "rééquilibrant": "rééquilibrer",
    "rééquilibras": "rééquilibrer",
    "rééquilibrasse": "rééquilibrer",
    "rééquilibrassent": "rééquilibrer",
    "rééquilibrasses": "rééquilibrer",
    "rééquilibrassiez": "rééquilibrer",
    "rééquilibrassions": "rééquilibrer",
    "rééquilibre": "rééquilibrer",
    "rééquilibrent": "rééquilibrer",
    "rééquilibrera": "rééquilibrer",
    "rééquilibrerai": "rééquilibrer",
    "rééquilibreraient": "rééquilibrer",
    "rééquilibrerais": "rééquilibrer",
    "rééquilibrerait": "rééquilibrer",
    "rééquilibreras": "rééquilibrer",
    "rééquilibrerez": "rééquilibrer",
    "rééquilibreriez": "rééquilibrer",
    "rééquilibrerions": "rééquilibrer",
    "rééquilibrerons": "rééquilibrer",
    "rééquilibreront": "rééquilibrer",
    "rééquilibres": "rééquilibrer",
    "rééquilibrez": "rééquilibrer",
    "rééquilibriez": "rééquilibrer",
    "rééquilibrions": "rééquilibrer",
    "rééquilibrons": "rééquilibrer",
    "rééquilibrâmes": "rééquilibrer",
    "rééquilibrât": "rééquilibrer",
    "rééquilibrâtes": "rééquilibrer",
    "rééquilibrèrent": "rééquilibrer",
    "rééquilibré": "rééquilibrer",
    "rééquilibrée": "rééquilibrer",
    "rééquilibrées": "rééquilibrer",
    "rééquilibrés": "rééquilibrer",
    "rééquipent": "rééquiper",
    "rééquipé": "rééquiper",
    "rééquipée": "rééquiper",
    "réétudiez": "réétudier",
    "réévalua": "réévaluer",
    "réévaluai": "réévaluer",
    "réévaluaient": "réévaluer",
    "réévaluais": "réévaluer",
    "réévaluait": "réévaluer",
    "réévaluant": "réévaluer",
    "réévaluas": "réévaluer",
    "réévaluasse": "réévaluer",
    "réévaluassent": "réévaluer",
    "réévaluasses": "réévaluer",
    "réévaluassiez": "réévaluer",
    "réévaluassions": "réévaluer",
    "réévaluations": "réévaluation",
    "réévalue": "réévaluer",
    "réévaluent": "réévaluer",
    "réévaluera": "réévaluer",
    "réévaluerai": "réévaluer",
    "réévalueraient": "réévaluer",
    "réévaluerais": "réévaluer",
    "réévaluerait": "réévaluer",
    "réévalueras": "réévaluer",
    "réévaluerez": "réévaluer",
    "réévalueriez": "réévaluer",
    "réévaluerions": "réévaluer",
    "réévaluerons": "réévaluer",
    "réévalueront": "réévaluer",
    "réévalues": "réévaluer",
    "réévaluez": "réévaluer",
    "réévaluiez": "réévaluer",
    "réévaluions": "réévaluer",
    "réévaluons": "réévaluer",
    "réévaluâmes": "réévaluer",
    "réévaluât": "réévaluer",
    "réévaluâtes": "réévaluer",
    "réévaluèrent": "réévaluer",
    "réévalué": "réévaluer",
    "réévaluée": "réévaluer",
    "réévaluées": "réévaluer",
    "réévalués": "réévaluer",
    "rêches": "rêche",
    "rênes": "rêne",
    "rêva": "rêver",
    "rêvai": "rêver",
    "rêvaient": "rêver",
    "rêvais": "rêver",
    "rêvait": "rêver",
    "rêvant": "rêver",
    "rêvas": "rêver",
    "rêvassa": "rêvasser",
    "rêvassai": "rêvasser",
    "rêvassaient": "rêvasser",
    "rêvassais": "rêvasser",
    "rêvassait": "rêvasser",
    "rêvassant": "rêvasser",
    "rêvassas": "rêvasser",
    "rêvassasse": "rêvasser",
    "rêvassassent": "rêvasser",
    "rêvassasses": "rêvasser",
    "rêvassassiez": "rêvasser",
    "rêvassassions": "rêvasser",
    "rêvasse": "rêver",
    "rêvassent": "rêver",
    "rêvassera": "rêvasser",
    "rêvasserai": "rêvasser",
    "rêvasseraient": "rêvasser",
    "rêvasserais": "rêvasser",
    "rêvasserait": "rêvasser",
    "rêvasseras": "rêvasser",
    "rêvasserez": "rêvasser",
    "rêvasseries": "rêvasserie",
    "rêvasseriez": "rêvasser",
    "rêvasserions": "rêvasser",
    "rêvasserons": "rêvasser",
    "rêvasseront": "rêvasser",
    "rêvasses": "rêver",
    "rêvassez": "rêvasser",
    "rêvassiez": "rêver",
    "rêvassions": "rêver",
    "rêvassons": "rêvasser",
    "rêvassâmes": "rêvasser",
    "rêvassât": "rêvasser",
    "rêvassâtes": "rêvasser",
    "rêvassèrent": "rêvasser",
    "rêvassé": "rêvasser",
    "rêvassée": "rêvasser",
    "rêvassées": "rêvasser",
    "rêvassés": "rêvasser",
    "rêve": "rêver",
    "rêvent": "rêver",
    "rêvera": "rêver",
    "rêverai": "rêver",
    "rêveraient": "rêver",
    "rêverais": "rêver",
    "rêverait": "rêver",
    "rêveras": "rêver",
    "rêverez": "rêver",
    "rêveries": "rêverie",
    "rêveriez": "rêver",
    "rêverions": "rêver",
    "rêverons": "rêver",
    "rêveront": "rêver",
    "rêves": "rêver",
    "rêveurs": "rêveur",
    "rêveuse": "rêveur",
    "rêveuses": "rêveur",
    "rêvez": "rêver",
    "rêviez": "rêver",
    "rêvions": "rêver",
    "rêvons": "rêver",
    "rêvâmes": "rêver",
    "rêvât": "rêver",
    "rêvâtes": "rêver",
    "rêvèrent": "rêver",
    "rêvé": "rêver",
    "rêvée": "rêver",
    "rêvées": "rêver",
    "rêvés": "rêver",
    "rîmes": "rire",
    "rît": "rire",
    "rîtes": "rire",
    "rôda": "rôder",
    "rôdai": "rôder",
    "rôdaient": "rôder",
    "rôdais": "rôder",
    "rôdait": "rôder",
    "rôdant": "rôder",
    "rôdas": "rôder",
    "rôdasse": "rôder",
    "rôdassent": "rôder",
    "rôdasses": "rôder",
    "rôdassiez": "rôder",
    "rôdassions": "rôder",
    "rôde": "rôder",
    "rôdent": "rôder",
    "rôdera": "rôder",
    "rôderai": "rôder",
    "rôderaient": "rôder",
    "rôderais": "rôder",
    "rôderait": "rôder",
    "rôderas": "rôder",
    "rôderez": "rôder",
    "rôderiez": "rôder",
    "rôderions": "rôder",
    "rôderons": "rôder",
    "rôderont": "rôder",
    "rôdes": "rôder",
    "rôdeurs": "rôdeur",
    "rôdeuse": "rôdeur",
    "rôdeuses": "rôdeur",
    "rôdez": "rôder",
    "rôdiez": "rôder",
    "rôdions": "rôder",
    "rôdons": "rôder",
    "rôdâmes": "rôder",
    "rôdât": "rôder",
    "rôdâtes": "rôder",
    "rôdèrent": "rôder",
    "rôdé": "rôder",
    "rôdée": "rôder",
    "rôdés": "rôder",
    "rôles": "rôle",
    "rôniers": "rônier",
    "rônins": "rônin",
    "rôti": "rôtir",
    "rôtie": "rôtir",
    "rôties": "rôtir",
    "rôtira": "rôtir",
    "rôtirai": "rôtir",
    "rôtiraient": "rôtir",
    "rôtirais": "rôtir",
    "rôtirait": "rôtir",
    "rôtiras": "rôtir",
    "rôtirent": "rôtir",
    "rôtirez": "rôtir",
    "rôtiriez": "rôtir",
    "rôtirions": "rôtir",
    "rôtirons": "rôtir",
    "rôtiront": "rôtir",
    "rôtis": "rôtir",
    "rôtissaient": "rôtir",
    "rôtissais": "rôtir",
    "rôtissait": "rôtir",
    "rôtissant": "rôtir",
    "rôtisse": "rôtir",
    "rôtissent": "rôtir",
    "rôtisses": "rôtir",
    "rôtisseurs": "rôtisseur",
    "rôtisseuse": "rôtisseur",
    "rôtisseuses": "rôtisseur",
    "rôtissez": "rôtir",
    "rôtissiez": "rôtir",
    "rôtissions": "rôtir",
    "rôtissoires": "rôtissoire",
    "rôtissons": "rôtir",
    "rôtit": "rôtir",
    "rôts": "rôt",
    "rôtîmes": "rôtir",
    "rôtît": "rôtir",
    "rôtîtes": "rôtir",
    "röntgens": "röntgen",
    "s": "avoir",
    "s'": "si",
    "sa": "son",
    "sabayons": "sabayon",
    "sabbatiques": "sabbatique",
    "sabbats": "sabbat",
    "sabelles": "sabelle",
    "sabines": "sabine",
    "sabins": "sabin",
    "sabirs": "sabir",
    "sabla": "sabler",
    "sablages": "sablage",
    "sablai": "sabler",
    "sablaient": "sabler",
    "sablais": "sabler",
    "sablait": "sabler",
    "sablant": "sabler",
    "sablas": "sabler",
    "sablasse": "sabler",
    "sablassent": "sabler",
    "sablasses": "sabler",
    "sablassiez": "sabler",
    "sablassions": "sabler",
    "sable": "sabler",
    "sablent": "sabler",
    "sablera": "sabler",
    "sablerai": "sabler",
    "sableraient": "sabler",
    "sablerais": "sabler",
    "sablerait": "sabler",
    "sableras": "sabler",
    "sablerez": "sabler",
    "sableriez": "sabler",
    "sablerions": "sabler",
    "sablerons": "sabler",
    "sableront": "sabler",
    "sables": "sabler",
    "sableurs": "sableur",
    "sableuse": "sableux",
    "sableuses": "sableux",
    "sablez": "sabler",
    "sabliers": "sablier",
    "sabliez": "sabler",
    "sablions": "sabler",
    "sablières": "sablière",
    "sablonneuse": "sablonneux",
    "sablonneuses": "sablonneux",
    "sablons": "sablon",
    "sablâmes": "sabler",
    "sablât": "sabler",
    "sablâtes": "sabler",
    "sablèrent": "sabler",
    "sablé": "sabler",
    "sablée": "sabler",
    "sablées": "sabler",
    "sablés": "sabler",
    "saborda": "saborder",
    "sabordai": "saborder",
    "sabordaient": "saborder",
    "sabordais": "saborder",
    "sabordait": "saborder",
    "sabordant": "saborder",
    "sabordas": "saborder",
    "sabordasse": "saborder",
    "sabordassent": "saborder",
    "sabordasses": "saborder",
    "sabordassiez": "saborder",
    "sabordassions": "saborder",
    "saborde": "saborder",
    "sabordent": "saborder",
    "sabordera": "saborder",
    "saborderai": "saborder",
    "saborderaient": "saborder",
    "saborderais": "saborder",
    "saborderait": "saborder",
    "saborderas": "saborder",
    "saborderez": "saborder",
    "saborderiez": "saborder",
    "saborderions": "saborder",
    "saborderons": "saborder",
    "saborderont": "saborder",
    "sabordes": "saborder",
    "sabordez": "saborder",
    "sabordiez": "saborder",
    "sabordions": "saborder",
    "sabordons": "saborder",
    "sabords": "sabord",
    "sabordâmes": "saborder",
    "sabordât": "saborder",
    "sabordâtes": "saborder",
    "sabordèrent": "saborder",
    "sabordé": "saborder",
    "sabordée": "saborder",
    "sabordées": "saborder",
    "sabordés": "saborder",
    "sabota": "saboter",
    "sabotages": "sabotage",
    "sabotai": "saboter",
    "sabotaient": "saboter",
    "sabotais": "saboter",
    "sabotait": "saboter",
    "sabotant": "saboter",
    "sabotas": "saboter",
    "sabotasse": "saboter",
    "sabotassent": "saboter",
    "sabotasses": "saboter",
    "sabotassiez": "saboter",
    "sabotassions": "saboter",
    "sabote": "saboter",
    "sabotent": "saboter",
    "sabotera": "saboter",
    "saboterai": "saboter",
    "saboteraient": "saboter",
    "saboterais": "saboter",
    "saboterait": "saboter",
    "saboteras": "saboter",
    "saboterez": "saboter",
    "saboteriez": "saboter",
    "saboterions": "saboter",
    "saboterons": "saboter",
    "saboteront": "saboter",
    "sabotes": "saboter",
    "saboteurs": "saboteur",
    "saboteuse": "saboteur",
    "sabotez": "saboter",
    "sabotiers": "sabotier",
    "sabotiez": "saboter",
    "sabotions": "saboter",
    "sabotons": "saboter",
    "sabots": "sabot",
    "sabots-de-Vénus": "sabot-de-Vénus",
    "sabotâmes": "saboter",
    "sabotât": "saboter",
    "sabotâtes": "saboter",
    "sabotèrent": "saboter",
    "saboté": "saboter",
    "sabotée": "saboter",
    "sabotées": "saboter",
    "sabotés": "saboter",
    "saboule": "sabouler",
    "saboulent": "sabouler",
    "saboulé": "sabouler",
    "saboulés": "sabouler",
    "sabra": "sabrer",
    "sabrai": "sabrer",
    "sabraient": "sabrer",
    "sabrais": "sabrer",
    "sabrait": "sabrer",
    "sabrant": "sabrer",
    "sabras": "sabrer",
    "sabrasse": "sabrer",
    "sabrassent": "sabrer",
    "sabrasses": "sabrer",
    "sabrassiez": "sabrer",
    "sabrassions": "sabrer",
    "sabre": "sabrer",
    "sabrent": "sabrer",
    "sabrera": "sabrer",
    "sabrerai": "sabrer",
    "sabreraient": "sabrer",
    "sabrerais": "sabrer",
    "sabrerait": "sabrer",
    "sabreras": "sabrer",
    "sabrerez": "sabrer",
    "sabreriez": "sabrer",
    "sabrerions": "sabrer",
    "sabrerons": "sabrer",
    "sabreront": "sabrer",
    "sabres": "sabrer",
    "sabres-baïonnettes": "sabre-baïonnette",
    "sabretaches": "sabretache",
    "sabreurs": "sabreur",
    "sabrez": "sabrer",
    "sabriez": "sabrer",
    "sabrions": "sabrer",
    "sabrons": "sabrer",
    "sabrâmes": "sabrer",
    "sabrât": "sabrer",
    "sabrâtes": "sabrer",
    "sabrèrent": "sabrer",
    "sabré": "sabrer",
    "sabrée": "sabrer",
    "sabrées": "sabrer",
    "sabrés": "sabrer",
    "saccada": "saccader",
    "saccadai": "saccader",
    "saccadaient": "saccader",
    "saccadais": "saccader",
    "saccadait": "saccader",
    "saccadant": "saccader",
    "saccadas": "saccader",
    "saccadasse": "saccader",
    "saccadassent": "saccader",
    "saccadasses": "saccader",
    "saccadassiez": "saccader",
    "saccadassions": "saccader",
    "saccade": "saccader",
    "saccadent": "saccader",
    "saccadera": "saccader",
    "saccaderai": "saccader",
    "saccaderaient": "saccader",
    "saccaderais": "saccader",
    "saccaderait": "saccader",
    "saccaderas": "saccader",
    "saccaderez": "saccader",
    "saccaderiez": "saccader",
    "saccaderions": "saccader",
    "saccaderons": "saccader",
    "saccaderont": "saccader",
    "saccades": "saccader",
    "saccadez": "saccader",
    "saccadiez": "saccader",
    "saccadions": "saccader",
    "saccadons": "saccader",
    "saccadâmes": "saccader",
    "saccadât": "saccader",
    "saccadâtes": "saccader",
    "saccadèrent": "saccader",
    "saccadé": "saccader",
    "saccadée": "saccader",
    "saccadées": "saccader",
    "saccadés": "saccader",
    "saccage": "saccager",
    "saccagea": "saccager",
    "saccageai": "saccager",
    "saccageaient": "saccager",
    "saccageais": "saccager",
    "saccageait": "saccager",
    "saccageant": "saccager",
    "saccageas": "saccager",
    "saccageasse": "saccager",
    "saccageassent": "saccager",
    "saccageasses": "saccager",
    "saccageassiez": "saccager",
    "saccageassions": "saccager",
    "saccagent": "saccager",
    "saccageons": "saccager",
    "saccagera": "saccager",
    "saccagerai": "saccager",
    "saccageraient": "saccager",
    "saccagerais": "saccager",
    "saccagerait": "saccager",
    "saccageras": "saccager",
    "saccagerez": "saccager",
    "saccageriez": "saccager",
    "saccagerions": "saccager",
    "saccagerons": "saccager",
    "saccageront": "saccager",
    "saccages": "saccager",
    "saccageurs": "saccageur",
    "saccagez": "saccager",
    "saccageâmes": "saccager",
    "saccageât": "saccager",
    "saccageâtes": "saccager",
    "saccagiez": "saccager",
    "saccagions": "saccager",
    "saccagèrent": "saccager",
    "saccagé": "saccager",
    "saccagée": "saccager",
    "saccagées": "saccager",
    "saccagés": "saccager",
    "saccharines": "saccharine",
    "saccharoses": "saccharose",
    "saccules": "saccule",
    "sacculines": "sacculine",
    "sacerdoces": "sacerdoce",
    "sacerdotale": "sacerdotal",
    "sacerdotales": "sacerdotal",
    "sacerdotaux": "sacerdotal",
    "sachant": "savoir",
    "sache": "savoir",
    "sachems": "sachem",
    "sachent": "savoir",
    "saches": "savoir",
    "sachets": "sachet",
    "sachez": "savoir",
    "sachiez": "savoir",
    "sachions": "savoir",
    "sachons": "savoir",
    "sacoches": "sacoche",
    "sacqua": "sacquer",
    "sacquais": "sacquer",
    "sacquant": "sacquer",
    "sacque": "sacquer",
    "sacqué": "sacquer",
    "sacra": "sacrer",
    "sacrai": "sacrer",
    "sacraient": "sacrer",
    "sacrais": "sacrer",
    "sacrait": "sacrer",
    "sacrale": "sacral",
    "sacrales": "sacral",
    "sacralisés": "sacraliser",
    "sacramentaux": "sacramental",
    "sacramentelle": "sacramentel",
    "sacramentelles": "sacramentel",
    "sacramentels": "sacramentel",
    "sacrant": "sacrer",
    "sacras": "sacrer",
    "sacrasse": "sacrer",
    "sacrassent": "sacrer",
    "sacrasses": "sacrer",
    "sacrassiez": "sacrer",
    "sacrassions": "sacrer",
    "sacraux": "sacral",
    "sacre": "sacrer",
    "sacrements": "sacrement",
    "sacrent": "sacrer",
    "sacrera": "sacrer",
    "sacrerai": "sacrer",
    "sacreraient": "sacrer",
    "sacrerais": "sacrer",
    "sacrerait": "sacrer",
    "sacreras": "sacrer",
    "sacrerez": "sacrer",
    "sacreriez": "sacrer",
    "sacrerions": "sacrer",
    "sacrerons": "sacrer",
    "sacreront": "sacrer",
    "sacres": "sacrer",
    "sacrez": "sacrer",
    "sacriez": "sacrer",
    "sacrifia": "sacrifier",
    "sacrifiai": "sacrifier",
    "sacrifiaient": "sacrifier",
    "sacrifiais": "sacrifier",
    "sacrifiait": "sacrifier",
    "sacrifiant": "sacrifier",
    "sacrifias": "sacrifier",
    "sacrifiasse": "sacrifier",
    "sacrifiassent": "sacrifier",
    "sacrifiasses": "sacrifier",
    "sacrifiassiez": "sacrifier",
    "sacrifiassions": "sacrifier",
    "sacrificateurs": "sacrificateur",
    "sacrifices": "sacrifice",
    "sacrificielle": "sacrificiel",
    "sacrificiels": "sacrificiel",
    "sacrifie": "sacrifier",
    "sacrifient": "sacrifier",
    "sacrifiera": "sacrifier",
    "sacrifierai": "sacrifier",
    "sacrifieraient": "sacrifier",
    "sacrifierais": "sacrifier",
    "sacrifierait": "sacrifier",
    "sacrifieras": "sacrifier",
    "sacrifierez": "sacrifier",
    "sacrifieriez": "sacrifier",
    "sacrifierions": "sacrifier",
    "sacrifierons": "sacrifier",
    "sacrifieront": "sacrifier",
    "sacrifies": "sacrifier",
    "sacrifiez": "sacrifier",
    "sacrifiiez": "sacrifier",
    "sacrifiions": "sacrifier",
    "sacrifions": "sacrifier",
    "sacrifiâmes": "sacrifier",
    "sacrifiât": "sacrifier",
    "sacrifiâtes": "sacrifier",
    "sacrifièrent": "sacrifier",
    "sacrifié": "sacrifier",
    "sacrifiée": "sacrifier",
    "sacrifiées": "sacrifier",
    "sacrifiés": "sacrifier",
    "sacrilèges": "sacrilège",
    "sacrions": "sacrer",
    "sacripants": "sacripant",
    "sacristaine": "sacristain",
    "sacristaines": "sacristain",
    "sacristains": "sacristain",
    "sacristies": "sacristie",
    "sacristines": "sacristine",
    "sacro-iliaques": "sacro-iliaque",
    "sacro-sainte": "sacro-saint",
    "sacro-saintes": "sacro-saint",
    "sacro-saints": "sacro-saint",
    "sacrons": "sacrer",
    "sacrums": "sacrum",
    "sacrâmes": "sacrer",
    "sacrât": "sacrer",
    "sacrâtes": "sacrer",
    "sacrèrent": "sacrer",
    "sacré": "sacrer",
    "sacrée": "sacrer",
    "sacrées": "sacrer",
    "sacrés": "sacrer",
    "sacs": "sac",
    "sacs-poubelles": "sac-poubelle",
    "sadienne": "sadien",
    "sadiques": "sadique",
    "sadismes": "sadisme",
    "sadomasochismes": "sadomasochisme",
    "sados": "sado",
    "safaris": "safari",
    "safaris-photos": "safari-photo",
    "safrane": "safraner",
    "safrans": "safran",
    "sagaces": "sagace",
    "sagaies": "sagaie",
    "sagas": "saga",
    "sages": "sage",
    "sages-femmes": "sage-femme",
    "sagesses": "sagesse",
    "sagettes": "sagette",
    "sagittaires": "sagittaire",
    "sagittale": "sagittal",
    "sagittales": "sagittal",
    "sagittaux": "sagittal",
    "sagouins": "sagouin",
    "sagous": "sagou",
    "saharienne": "saharien",
    "sahariennes": "saharienne",
    "sahariens": "saharien",
    "sahibs": "sahib",
    "saies": "saie",
    "saigna": "saigner",
    "saignai": "saigner",
    "saignaient": "saigner",
    "saignais": "saigner",
    "saignait": "saigner",
    "saignant": "saigner",
    "saignante": "saignant",
    "saignantes": "saignant",
    "saignants": "saignant",
    "saignas": "saigner",
    "saignasse": "saigner",
    "saignassent": "saigner",
    "saignasses": "saigner",
    "saignassiez": "saigner",
    "saignassions": "saigner",
    "saigne": "saigner",
    "saignements": "saignement",
    "saignent": "saigner",
    "saignera": "saigner",
    "saignerai": "saigner",
    "saigneraient": "saigner",
    "saignerais": "saigner",
    "saignerait": "saigner",
    "saigneras": "saigner",
    "saignerez": "saigner",
    "saigneriez": "saigner",
    "saignerions": "saigner",
    "saignerons": "saigner",
    "saigneront": "saigner",
    "saignes": "saigner",
    "saignez": "saigner",
    "saigniez": "saigner",
    "saignions": "saigner",
    "saignons": "saigner",
    "saignâmes": "saigner",
    "saignât": "saigner",
    "saignâtes": "saigner",
    "saignèrent": "saigner",
    "saigné": "saigner",
    "saignée": "saigner",
    "saignées": "saigner",
    "saignés": "saigner",
    "saillaient": "saillir",
    "saillait": "saillir",
    "saillant": "saillir",
    "saillante": "saillant",
    "saillantes": "saillant",
    "saillants": "saillant",
    "saille": "saillir",
    "saillent": "saillir",
    "saillera": "saillir",
    "sailleront": "saillir",
    "sailli": "saillir",
    "saillie": "saillir",
    "saillies": "saillir",
    "saillira": "saillir",
    "sailliraient": "saillir",
    "saillirait": "saillir",
    "saillirent": "saillir",
    "sailliront": "saillir",
    "saillis": "saillir",
    "saillissaient": "saillir",
    "saillissait": "saillir",
    "saillissant": "saillir",
    "saillisse": "saillir",
    "saillissent": "saillir",
    "saillit": "saillir",
    "saillît": "saillir",
    "saine": "sain",
    "saines": "sain",
    "sainfoins": "sainfoin",
    "sains": "sain",
    "saint-bernards": "saint-bernard",
    "saint-cyriens": "saint-cyrien",
    "saint-honorés": "saint-honoré",
    "saint-marcellins": "saint-marcellin",
    "saint-nectaires": "saint-nectaire",
    "saint-paulins": "saint-paulin",
    "saint-pierres": "saint-pierre",
    "saint-pétersbourgeoise": "saint-pétersbourgeois",
    "saint-pétersbourgeoises": "saint-pétersbourgeois",
    "saint-simonienne": "saint-simonien",
    "saint-simoniennes": "saint-simonien",
    "saint-simoniens": "saint-simonien",
    "saint-émilions": "saint-émilion",
    "sainte": "saint",
    "saintes": "saint",
    "saintes-barbes": "sainte-barbe",
    "saintes-nitouches": "sainte-nitouche",
    "saintetés": "sainteté",
    "saints": "saint",
    "saints-pères": "saint-père",
    "sais": "savoir",
    "saisi": "saisir",
    "saisie": "saisir",
    "saisies": "saisir",
    "saisies-arrêts": "saisie-arrêt",
    "saisies-exécutions": "saisie-exécution",
    "saisines": "saisine",
    "saisira": "saisir",
    "saisirai": "saisir",
    "saisiraient": "saisir",
    "saisirais": "saisir",
    "saisirait": "saisir",
    "saisiras": "saisir",
    "saisirent": "saisir",
    "saisirez": "saisir",
    "saisiriez": "saisir",
    "saisirions": "saisir",
    "saisirons": "saisir",
    "saisiront": "saisir",
    "saisis": "saisir",
    "saisissables": "saisissable",
    "saisissaient": "saisir",
    "saisissais": "saisir",
    "saisissait": "saisir",
    "saisissant": "saisir",
    "saisissante": "saisissant",
    "saisissantes": "saisissant",
    "saisissants": "saisissant",
    "saisisse": "saisir",
    "saisissements": "saisissement",
    "saisissent": "saisir",
    "saisisses": "saisir",
    "saisissez": "saisir",
    "saisissiez": "saisir",
    "saisissions": "saisir",
    "saisissons": "saisir",
    "saisit": "saisir",
    "saisonna": "saisonner",
    "saisonnai": "saisonner",
    "saisonnaient": "saisonner",
    "saisonnais": "saisonner",
    "saisonnait": "saisonner",
    "saisonnant": "saisonner",
    "saisonnas": "saisonner",
    "saisonnasse": "saisonner",
    "saisonnassent": "saisonner",
    "saisonnasses": "saisonner",
    "saisonnassiez": "saisonner",
    "saisonnassions": "saisonner",
    "saisonne": "saisonner",
    "saisonnent": "saisonner",
    "saisonnera": "saisonner",
    "saisonnerai": "saisonner",
    "saisonneraient": "saisonner",
    "saisonnerais": "saisonner",
    "saisonnerait": "saisonner",
    "saisonneras": "saisonner",
    "saisonnerez": "saisonner",
    "saisonneriez": "saisonner",
    "saisonnerions": "saisonner",
    "saisonnerons": "saisonner",
    "saisonneront": "saisonner",
    "saisonnes": "saisonner",
    "saisonnez": "saisonner",
    "saisonniers": "saisonnier",
    "saisonniez": "saisonner",
    "saisonnions": "saisonner",
    "saisonnière": "saisonnier",
    "saisonnières": "saisonnier",
    "saisonnons": "saisonner",
    "saisonnâmes": "saisonner",
    "saisonnât": "saisonner",
    "saisonnâtes": "saisonner",
    "saisonnèrent": "saisonner",
    "saisonné": "saisonner",
    "saisonnée": "saisonner",
    "saisonnées": "saisonner",
    "saisonnés": "saisonner",
    "saisons": "saison",
    "saisîmes": "saisir",
    "saisît": "saisir",
    "saisîtes": "saisir",
    "sait": "savoir",
    "sajous": "sajou",
    "sakés": "saké",
    "sala": "saler",
    "salaces": "salace",
    "salacités": "salacité",
    "salades": "salade",
    "saladiers": "saladier",
    "salai": "saler",
    "salaient": "saler",
    "salaires": "salaire",
    "salais": "saler",
    "salaisons": "salaison",
    "salait": "saler",
    "salamalecs": "salamalec",
    "salamandres": "salamandre",
    "salamis": "salami",
    "salant": "saler",
    "salante": "salant",
    "salantes": "salant",
    "salants": "salant",
    "salaria": "salarier",
    "salariai": "salarier",
    "salariaient": "salarier",
    "salariais": "salarier",
    "salariait": "salarier",
    "salariale": "salarial",
    "salariales": "salarial",
    "salariant": "salarier",
    "salarias": "salarier",
    "salariasse": "salarier",
    "salariassent": "salarier",
    "salariasses": "salarier",
    "salariassiez": "salarier",
    "salariassions": "salarier",
    "salariaux": "salarial",
    "salarie": "salarier",
    "salarient": "salarier",
    "salariera": "salarier",
    "salarierai": "salarier",
    "salarieraient": "salarier",
    "salarierais": "salarier",
    "salarierait": "salarier",
    "salarieras": "salarier",
    "salarierez": "salarier",
    "salarieriez": "salarier",
    "salarierions": "salarier",
    "salarierons": "salarier",
    "salarieront": "salarier",
    "salaries": "salarier",
    "salariez": "salarier",
    "salariiez": "salarier",
    "salariions": "salarier",
    "salarions": "salarier",
    "salariâmes": "salarier",
    "salariât": "salarier",
    "salariâtes": "salarier",
    "salarièrent": "salarier",
    "salarié": "salarier",
    "salariée": "salarier",
    "salariées": "salarier",
    "salariés": "salarier",
    "salas": "saler",
    "salasse": "saler",
    "salassent": "saler",
    "salasses": "saler",
    "salassiez": "saler",
    "salassions": "saler",
    "salauds": "salaud",
    "sale": "saler",
    "salent": "saler",
    "salera": "saler",
    "salerai": "saler",
    "saleraient": "saler",
    "salerais": "saler",
    "salerait": "saler",
    "saleras": "saler",
    "salerez": "saler",
    "saleriez": "saler",
    "salerions": "saler",
    "salerons": "saler",
    "saleront": "saler",
    "sales": "saler",
    "saletés": "saleté",
    "salez": "saler",
    "sali": "salir",
    "salicaires": "salicaire",
    "salicylates": "salicylate",
    "salie": "salir",
    "salies": "salir",
    "saliez": "saler",
    "saligaude": "saligaud",
    "saligaudes": "saligaud",
    "saligauds": "saligaud",
    "saline": "salin",
    "salines": "salin",
    "salingues": "salingue",
    "salinités": "salinité",
    "salins": "salin",
    "salions": "saler",
    "salira": "salir",
    "salirai": "salir",
    "saliraient": "salir",
    "salirais": "salir",
    "salirait": "salir",
    "saliras": "salir",
    "salirent": "salir",
    "salirez": "salir",
    "saliriez": "salir",
    "salirions": "salir",
    "salirons": "salir",
    "saliront": "salir",
    "salis": "salir",
    "salissaient": "salir",
    "salissais": "salir",
    "salissait": "salir",
    "salissant": "salir",
    "salissante": "salissant",
    "salissantes": "salissant",
    "salissants": "salissant",
    "salisse": "salir",
    "salissent": "salir",
    "salisses": "salir",
    "salissez": "salir",
    "salissiez": "salir",
    "salissions": "salir",
    "salissons": "salir",
    "salissures": "salissure",
    "salit": "salir",
    "saliva": "saliver",
    "salivai": "saliver",
    "salivaient": "saliver",
    "salivaires": "salivaire",
    "salivais": "saliver",
    "salivait": "saliver",
    "salivant": "saliver",
    "salivas": "saliver",
    "salivasse": "saliver",
    "salivassent": "saliver",
    "salivasses": "saliver",
    "salivassiez": "saliver",
    "salivassions": "saliver",
    "salive": "saliver",
    "salivent": "saliver",
    "salivera": "saliver",
    "saliverai": "saliver",
    "saliveraient": "saliver",
    "saliverais": "saliver",
    "saliverait": "saliver",
    "saliveras": "saliver",
    "saliverez": "saliver",
    "saliveriez": "saliver",
    "saliverions": "saliver",
    "saliverons": "saliver",
    "saliveront": "saliver",
    "salives": "saliver",
    "saliveuse": "saliveux",
    "saliveuses": "saliveux",
    "salivez": "saliver",
    "saliviez": "saliver",
    "salivions": "saliver",
    "salivons": "saliver",
    "salivâmes": "saliver",
    "salivât": "saliver",
    "salivâtes": "saliver",
    "salivèrent": "saliver",
    "salivé": "saliver",
    "salivée": "saliver",
    "salivées": "saliver",
    "salivés": "saliver",
    "salières": "salière",
    "salles": "salle",
    "salmonelles": "salmonelle",
    "salmonelloses": "salmonellose",
    "salmonicoles": "salmonicole",
    "saloirs": "saloir",
    "salonnarde": "salonnard",
    "salonnardes": "salonnard",
    "salonnards": "salonnard",
    "salonniers": "salonnier",
    "salonnières": "salonnière",
    "salons": "salon",
    "saloons": "saloon",
    "salopards": "salopard",
    "salopent": "saloper",
    "saloperies": "saloperie",
    "salopes": "salope",
    "salopettes": "salopette",
    "salopez": "saloper",
    "salopiauds": "salopiaud",
    "salopiaux": "salopiau",
    "salopiots": "salopiot",
    "salops": "salop",
    "salopé": "saloper",
    "salopée": "saloper",
    "salopées": "saloper",
    "salopés": "saloper",
    "salpingites": "salpingite",
    "salpêtres": "salpêtre",
    "salpêtrées": "salpêtrer",
    "salpêtrés": "salpêtrer",
    "sals": "sal",
    "salsepareilles": "salsepareille",
    "saltations": "saltation",
    "saltimbanques": "saltimbanque",
    "salua": "saluer",
    "saluai": "saluer",
    "saluaient": "saluer",
    "saluais": "saluer",
    "saluait": "saluer",
    "saluant": "saluer",
    "saluas": "saluer",
    "saluasse": "saluer",
    "saluassent": "saluer",
    "saluasses": "saluer",
    "saluassiez": "saluer",
    "saluassions": "saluer",
    "salubres": "salubre",
    "salubrités": "salubrité",
    "salue": "saluer",
    "saluent": "saluer",
    "saluera": "saluer",
    "saluerai": "saluer",
    "salueraient": "saluer",
    "saluerais": "saluer",
    "saluerait": "saluer",
    "salueras": "saluer",
    "saluerez": "saluer",
    "salueriez": "saluer",
    "saluerions": "saluer",
    "saluerons": "saluer",
    "salueront": "saluer",
    "salues": "saluer",
    "saluez": "saluer",
    "saluiez": "saluer",
    "saluions": "saluer",
    "saluons": "saluer",
    "salutaires": "salutaire",
    "salutations": "salutation",
    "salutistes": "salutiste",
    "saluts": "salut",
    "saluâmes": "saluer",
    "saluât": "saluer",
    "saluâtes": "saluer",
    "saluèrent": "saluer",
    "salué": "saluer",
    "saluée": "saluer",
    "saluées": "saluer",
    "salués": "saluer",
    "salvadorienne": "salvadorien",
    "salvadoriens": "salvadorien",
    "salvateurs": "salvateur",
    "salvatrice": "sauveur",
    "salvatrices": "salvateur",
    "salves": "salve",
    "salzbourgeoise": "salzbourgeois",
    "salzbourgeoises": "salzbourgeois",
    "salâmes": "saler",
    "salât": "saler",
    "salâtes": "saler",
    "salèrent": "saler",
    "salé": "saler",
    "salée": "saler",
    "salées": "saler",
    "salés": "saler",
    "salésienne": "salésien",
    "salîmes": "salir",
    "salît": "salir",
    "salîtes": "salir",
    "samaras": "samara",
    "samares": "samare",
    "samaritaine": "samaritain",
    "samaritaines": "samaritain",
    "samaritains": "samaritain",
    "sambas": "samba",
    "samedis": "samedi",
    "samizdats": "samizdat",
    "samoans": "samoan",
    "samouraïs": "samouraï",
    "samovars": "samovar",
    "sampangs": "sampang",
    "sampans": "sampan",
    "sampots": "sampot",
    "san-benitos": "san-benito",
    "sanas": "sana",
    "sanatoriums": "sanatorium",
    "sancerres": "sancerre",
    "sanctifia": "sanctifier",
    "sanctifiai": "sanctifier",
    "sanctifiaient": "sanctifier",
    "sanctifiais": "sanctifier",
    "sanctifiait": "sanctifier",
    "sanctifiant": "sanctifier",
    "sanctifiante": "sanctifiant",
    "sanctifias": "sanctifier",
    "sanctifiasse": "sanctifier",
    "sanctifiassent": "sanctifier",
    "sanctifiasses": "sanctifier",
    "sanctifiassiez": "sanctifier",
    "sanctifiassions": "sanctifier",
    "sanctificatrice": "sanctificateur",
    "sanctifie": "sanctifier",
    "sanctifient": "sanctifier",
    "sanctifiera": "sanctifier",
    "sanctifierai": "sanctifier",
    "sanctifieraient": "sanctifier",
    "sanctifierais": "sanctifier",
    "sanctifierait": "sanctifier",
    "sanctifieras": "sanctifier",
    "sanctifierez": "sanctifier",
    "sanctifieriez": "sanctifier",
    "sanctifierions": "sanctifier",
    "sanctifierons": "sanctifier",
    "sanctifieront": "sanctifier",
    "sanctifies": "sanctifier",
    "sanctifiez": "sanctifier",
    "sanctifiiez": "sanctifier",
    "sanctifiions": "sanctifier",
    "sanctifions": "sanctifier",
    "sanctifiâmes": "sanctifier",
    "sanctifiât": "sanctifier",
    "sanctifiâtes": "sanctifier",
    "sanctifièrent": "sanctifier",
    "sanctifié": "sanctifier",
    "sanctifiée": "sanctifier",
    "sanctifiées": "sanctifier",
    "sanctifiés": "sanctifier",
    "sanctionna": "sanctionner",
    "sanctionnai": "sanctionner",
    "sanctionnaient": "sanctionner",
    "sanctionnais": "sanctionner",
    "sanctionnait": "sanctionner",
    "sanctionnant": "sanctionner",
    "sanctionnas": "sanctionner",
    "sanctionnasse": "sanctionner",
    "sanctionnassent": "sanctionner",
    "sanctionnasses": "sanctionner",
    "sanctionnassiez": "sanctionner",
    "sanctionnassions": "sanctionner",
    "sanctionne": "sanctionner",
    "sanctionnent": "sanctionner",
    "sanctionnera": "sanctionner",
    "sanctionnerai": "sanctionner",
    "sanctionneraient": "sanctionner",
    "sanctionnerais": "sanctionner",
    "sanctionnerait": "sanctionner",
    "sanctionneras": "sanctionner",
    "sanctionnerez": "sanctionner",
    "sanctionneriez": "sanctionner",
    "sanctionnerions": "sanctionner",
    "sanctionnerons": "sanctionner",
    "sanctionneront": "sanctionner",
    "sanctionnes": "sanctionner",
    "sanctionnez": "sanctionner",
    "sanctionniez": "sanctionner",
    "sanctionnions": "sanctionner",
    "sanctionnons": "sanctionner",
    "sanctionnâmes": "sanctionner",
    "sanctionnât": "sanctionner",
    "sanctionnâtes": "sanctionner",
    "sanctionnèrent": "sanctionner",
    "sanctionné": "sanctionner",
    "sanctionnée": "sanctionner",
    "sanctionnées": "sanctionner",
    "sanctionnés": "sanctionner",
    "sanctions": "sanction",
    "sanctuaires": "sanctuaire",
    "sandale": "sandal",
    "sandales": "sandale",
    "sandalettes": "sandalette",
    "sandaraques": "sandaraque",
    "sanderlings": "sanderling",
    "sandinistes": "sandiniste",
    "sandows": "sandow",
    "sandres": "sandre",
    "sandwiches": "sandwiche",
    "sandwichs": "sandwich",
    "sangla": "sangler",
    "sanglai": "sangler",
    "sanglait": "sangler",
    "sanglant": "sangler",
    "sanglante": "sanglant",
    "sanglantes": "sanglant",
    "sanglants": "sanglant",
    "sangle": "sangler",
    "sanglent": "sangler",
    "sangles": "sangle",
    "sanglez": "sangler",
    "sangliers": "sanglier",
    "sanglota": "sangloter",
    "sanglotai": "sangloter",
    "sanglotaient": "sangloter",
    "sanglotais": "sangloter",
    "sanglotait": "sangloter",
    "sanglotant": "sangloter",
    "sanglotante": "sanglotant",
    "sanglotants": "sanglotant",
    "sanglotas": "sangloter",
    "sanglotasse": "sangloter",
    "sanglotassent": "sangloter",
    "sanglotasses": "sangloter",
    "sanglotassiez": "sangloter",
    "sanglotassions": "sangloter",
    "sanglote": "sangloter",
    "sanglotent": "sangloter",
    "sanglotera": "sangloter",
    "sangloterai": "sangloter",
    "sangloteraient": "sangloter",
    "sangloterais": "sangloter",
    "sangloterait": "sangloter",
    "sangloteras": "sangloter",
    "sangloterez": "sangloter",
    "sangloteriez": "sangloter",
    "sangloterions": "sangloter",
    "sangloterons": "sangloter",
    "sangloteront": "sangloter",
    "sanglotes": "sangloter",
    "sanglotez": "sangloter",
    "sanglotiez": "sangloter",
    "sanglotions": "sangloter",
    "sanglotons": "sangloter",
    "sanglots": "sanglot",
    "sanglotâmes": "sangloter",
    "sanglotât": "sangloter",
    "sanglotâtes": "sangloter",
    "sanglotèrent": "sangloter",
    "sangloté": "sangloter",
    "sanglotée": "sangloter",
    "sanglotées": "sangloter",
    "sanglotés": "sangloter",
    "sanglé": "sangler",
    "sanglée": "sangler",
    "sanglées": "sangler",
    "sanglés": "sangler",
    "sangrias": "sangria",
    "sangs": "sang",
    "sangsues": "sangsue",
    "sanguinaires": "sanguinaire",
    "sanguine": "sanguin",
    "sanguines": "sanguine",
    "sanguinolente": "sanguinolent",
    "sanguinolentes": "sanguinolent",
    "sanguinolents": "sanguinolent",
    "sanguins": "sanguin",
    "sanies": "sanie",
    "sanieuses": "sanieux",
    "sanitaires": "sanitaire",
    "sans-culottes": "sans-culotte",
    "sans-culottides": "sans-culottide",
    "sans-filistes": "sans-filiste",
    "sanscrite": "sanscrit",
    "sanscrites": "sanscrit",
    "sanscrits": "sanscrit",
    "sanskrite": "sanskrit",
    "sanskrites": "sanskrit",
    "sanskrits": "sanskrit",
    "sansonnets": "sansonnet",
    "santals": "santal",
    "santiags": "santiag",
    "santons": "santon",
    "santés": "santé",
    "saoudienne": "saoudien",
    "saoudiennes": "saoudienne",
    "saoudiens": "saoudien",
    "saoula": "saouler",
    "saoulai": "saouler",
    "saoulaient": "saouler",
    "saoulais": "saouler",
    "saoulait": "saouler",
    "saoulant": "saouler",
    "saoularde": "saoulard",
    "saoulardes": "saoulard",
    "saoulards": "saoulard",
    "saoulas": "saouler",
    "saoulasse": "saouler",
    "saoulassent": "saouler",
    "saoulasses": "saouler",
    "saoulassiez": "saouler",
    "saoulassions": "saouler",
    "saoule": "saouler",
    "saoulent": "saouler",
    "saoulera": "saouler",
    "saoulerai": "saouler",
    "saouleraient": "saouler",
    "saoulerais": "saouler",
    "saoulerait": "saouler",
    "saouleras": "saouler",
    "saoulerez": "saouler",
    "saouleries": "saoulerie",
    "saouleriez": "saouler",
    "saoulerions": "saouler",
    "saoulerons": "saouler",
    "saouleront": "saouler",
    "saoules": "saouler",
    "saoulez": "saouler",
    "saouliez": "saouler",
    "saoulions": "saouler",
    "saoulons": "saouler",
    "saouls": "saoul",
    "saoulâmes": "saouler",
    "saoulât": "saouler",
    "saoulâtes": "saouler",
    "saoulèrent": "saouler",
    "saoulé": "saouler",
    "saoulée": "saouler",
    "saoulées": "saouler",
    "saoulés": "saouler",
    "sapa": "saper",
    "sapai": "saper",
    "sapaient": "saper",
    "sapais": "saper",
    "sapait": "saper",
    "sapajous": "sapajou",
    "sapant": "saper",
    "sapas": "saper",
    "sapasse": "saper",
    "sapassent": "saper",
    "sapasses": "saper",
    "sapassiez": "saper",
    "sapassions": "saper",
    "sape": "saper",
    "sapements": "sapement",
    "sapent": "saper",
    "sapera": "saper",
    "saperai": "saper",
    "saperaient": "saper",
    "saperais": "saper",
    "saperait": "saper",
    "saperas": "saper",
    "saperez": "saper",
    "saperiez": "saper",
    "saperions": "saper",
    "saperons": "saper",
    "saperont": "saper",
    "sapes": "saper",
    "sapeurs": "sapeur",
    "sapeurs-pompiers": "sapeur-pompier",
    "sapez": "saper",
    "saphiques": "saphique",
    "saphirs": "saphir",
    "saphismes": "saphisme",
    "sapides": "sapide",
    "sapien": "sapiens",
    "sapiences": "sapience",
    "sapiez": "saper",
    "sapines": "sapine",
    "sapinettes": "sapinette",
    "sapinières": "sapinière",
    "sapins": "sapin",
    "sapions": "saper",
    "saponaires": "saponaire",
    "saponifia": "saponifier",
    "saponifiai": "saponifier",
    "saponifiaient": "saponifier",
    "saponifiais": "saponifier",
    "saponifiait": "saponifier",
    "saponifiant": "saponifier",
    "saponifias": "saponifier",
    "saponifiasse": "saponifier",
    "saponifiassent": "saponifier",
    "saponifiasses": "saponifier",
    "saponifiassiez": "saponifier",
    "saponifiassions": "saponifier",
    "saponifie": "saponifier",
    "saponifient": "saponifier",
    "saponifiera": "saponifier",
    "saponifierai": "saponifier",
    "saponifieraient": "saponifier",
    "saponifierais": "saponifier",
    "saponifierait": "saponifier",
    "saponifieras": "saponifier",
    "saponifierez": "saponifier",
    "saponifieriez": "saponifier",
    "saponifierions": "saponifier",
    "saponifierons": "saponifier",
    "saponifieront": "saponifier",
    "saponifies": "saponifier",
    "saponifiez": "saponifier",
    "saponifiiez": "saponifier",
    "saponifiions": "saponifier",
    "saponifions": "saponifier",
    "saponifiâmes": "saponifier",
    "saponifiât": "saponifier",
    "saponifiâtes": "saponifier",
    "saponifièrent": "saponifier",
    "saponifié": "saponifier",
    "saponifiée": "saponifier",
    "saponifiées": "saponifier",
    "saponifiés": "saponifier",
    "sapons": "saper",
    "sapotes": "sapote",
    "sapotilles": "sapotille",
    "saprophytes": "saprophyte",
    "sapâmes": "saper",
    "sapât": "saper",
    "sapâtes": "saper",
    "sapèques": "sapèque",
    "sapèrent": "saper",
    "sapé": "saper",
    "sapée": "saper",
    "sapées": "saper",
    "sapés": "saper",
    "saqua": "saquer",
    "saquai": "saquer",
    "saquaient": "saquer",
    "saquais": "saquer",
    "saquait": "saquer",
    "saquant": "saquer",
    "saquas": "saquer",
    "saquasse": "saquer",
    "saquassent": "saquer",
    "saquasses": "saquer",
    "saquassiez": "saquer",
    "saquassions": "saquer",
    "saque": "saquer",
    "saquent": "saquer",
    "saquera": "saquer",
    "saquerai": "saquer",
    "saqueraient": "saquer",
    "saquerais": "saquer",
    "saquerait": "saquer",
    "saqueras": "saquer",
    "saquerez": "saquer",
    "saqueriez": "saquer",
    "saquerions": "saquer",
    "saquerons": "saquer",
    "saqueront": "saquer",
    "saques": "saquer",
    "saquez": "saquer",
    "saquiez": "saquer",
    "saquions": "saquer",
    "saquons": "saquer",
    "saquâmes": "saquer",
    "saquât": "saquer",
    "saquâtes": "saquer",
    "saquèrent": "saquer",
    "saqué": "saquer",
    "saquée": "saquer",
    "saquées": "saquer",
    "saqués": "saquer",
    "sarabandes": "sarabande",
    "sarbacanes": "sarbacane",
    "sarcasmes": "sarcasme",
    "sarcastiques": "sarcastique",
    "sarcelles": "sarcelle",
    "sarcla": "sarcler",
    "sarclai": "sarcler",
    "sarclaient": "sarcler",
    "sarclais": "sarcler",
    "sarclait": "sarcler",
    "sarclant": "sarcler",
    "sarclas": "sarcler",
    "sarclasse": "sarcler",
    "sarclassent": "sarcler",
    "sarclasses": "sarcler",
    "sarclassiez": "sarcler",
    "sarclassions": "sarcler",
    "sarcle": "sarcler",
    "sarclent": "sarcler",
    "sarclera": "sarcler",
    "sarclerai": "sarcler",
    "sarcleraient": "sarcler",
    "sarclerais": "sarcler",
    "sarclerait": "sarcler",
    "sarcleras": "sarcler",
    "sarclerez": "sarcler",
    "sarcleriez": "sarcler",
    "sarclerions": "sarcler",
    "sarclerons": "sarcler",
    "sarcleront": "sarcler",
    "sarcles": "sarcler",
    "sarcleuse": "sarcleur",
    "sarclez": "sarcler",
    "sarcliez": "sarcler",
    "sarclions": "sarcler",
    "sarclons": "sarcler",
    "sarclâmes": "sarcler",
    "sarclât": "sarcler",
    "sarclâtes": "sarcler",
    "sarclèrent": "sarcler",
    "sarclé": "sarcler",
    "sarclée": "sarcler",
    "sarclées": "sarcler",
    "sarclés": "sarcler",
    "sarcomes": "sarcome",
    "sarcophages": "sarcophage",
    "sardanapalesques": "sardanapalesque",
    "sardanes": "sardane",
    "sardes": "sarde",
    "sardinaient": "sardiner",
    "sardines": "sardine",
    "sardiniers": "sardinier",
    "sardoines": "sardoine",
    "sardoniques": "sardonique",
    "sargasses": "sargasse",
    "sarigues": "sarigue",
    "saris": "sari",
    "sarments": "sarment",
    "sarouals": "saroual",
    "sarrasine": "sarrasin",
    "sarrasines": "sarrasin",
    "sarrasins": "sarrasin",
    "sarraus": "sarrau",
    "sarriettes": "sarriette",
    "sarroise": "sarrois",
    "sassa": "sasser",
    "sassai": "sasser",
    "sassaient": "sasser",
    "sassais": "sasser",
    "sassait": "sasser",
    "sassanides": "sassanide",
    "sassant": "sasser",
    "sassas": "sasser",
    "sassasse": "sasser",
    "sassassent": "sasser",
    "sassasses": "sasser",
    "sassassiez": "sasser",
    "sassassions": "sasser",
    "sasse": "sasser",
    "sassent": "sasser",
    "sassera": "sasser",
    "sasserai": "sasser",
    "sasseraient": "sasser",
    "sasserais": "sasser",
    "sasserait": "sasser",
    "sasseras": "sasser",
    "sasserez": "sasser",
    "sasseriez": "sasser",
    "sasserions": "sasser",
    "sasserons": "sasser",
    "sasseront": "sasser",
    "sasses": "sasser",
    "sassez": "sasser",
    "sassiez": "sasser",
    "sassions": "sasser",
    "sassons": "sasser",
    "sassâmes": "sasser",
    "sassât": "sasser",
    "sassâtes": "sasser",
    "sassèrent": "sasser",
    "sassé": "sasser",
    "sassée": "sasser",
    "sassées": "sasser",
    "sassés": "sasser",
    "satana": "sataner",
    "satanaient": "sataner",
    "satanas": "sataner",
    "sataniques": "satanique",
    "satané": "sataner",
    "satanée": "sataner",
    "satanées": "satané",
    "satanés": "sataner",
    "satellisée": "satelliser",
    "satellitaires": "satellitaire",
    "satellites": "satellite",
    "satellites-espions": "satellites-espion",
    "satina": "satiner",
    "satinai": "satiner",
    "satinaient": "satiner",
    "satinais": "satiner",
    "satinait": "satiner",
    "satinant": "satiner",
    "satinas": "satiner",
    "satinasse": "satiner",
    "satinassent": "satiner",
    "satinasses": "satiner",
    "satinassiez": "satiner",
    "satinassions": "satiner",
    "satine": "satiner",
    "satinent": "satiner",
    "satinera": "satiner",
    "satinerai": "satiner",
    "satineraient": "satiner",
    "satinerais": "satiner",
    "satinerait": "satiner",
    "satineras": "satiner",
    "satinerez": "satiner",
    "satineriez": "satiner",
    "satinerions": "satiner",
    "satinerons": "satiner",
    "satineront": "satiner",
    "satines": "satiner",
    "satinettes": "satinette",
    "satinez": "satiner",
    "satiniez": "satiner",
    "satinions": "satiner",
    "satinons": "satiner",
    "satins": "satin",
    "satinâmes": "satiner",
    "satinât": "satiner",
    "satinâtes": "satiner",
    "satinèrent": "satiner",
    "satiné": "satiner",
    "satinée": "satiner",
    "satinées": "satiner",
    "satinés": "satiner",
    "satires": "satire",
    "satiriques": "satirique",
    "satirisaient": "satiriser",
    "satisfactions": "satisfaction",
    "satisfais": "satisfaire",
    "satisfaisaient": "satisfaire",
    "satisfaisais": "satisfaire",
    "satisfaisait": "satisfaire",
    "satisfaisant": "satisfaire",
    "satisfaisante": "satisfaisant",
    "satisfaisantes": "satisfaisant",
    "satisfaisants": "satisfaisant",
    "satisfaisiez": "satisfaire",
    "satisfaisions": "satisfaire",
    "satisfaisons": "satisfaire",
    "satisfait": "satisfaire",
    "satisfaite": "satisfait",
    "satisfaites": "satisfait",
    "satisfaits": "satisfait",
    "satisfasse": "satisfaire",
    "satisfassent": "satisfaire",
    "satisfasses": "satisfaire",
    "satisfassiez": "satisfaire",
    "satisfassions": "satisfaire",
    "satisfera": "satisfaire",
    "satisferai": "satisfaire",
    "satisferaient": "satisfaire",
    "satisferais": "satisfaire",
    "satisferait": "satisfaire",
    "satisferas": "satisfaire",
    "satisferez": "satisfaire",
    "satisferiez": "satisfaire",
    "satisferions": "satisfaire",
    "satisferons": "satisfaire",
    "satisferont": "satisfaire",
    "satisfirent": "satisfaire",
    "satisfis": "satisfaire",
    "satisfisse": "satisfaire",
    "satisfissent": "satisfaire",
    "satisfisses": "satisfaire",
    "satisfissiez": "satisfaire",
    "satisfissions": "satisfaire",
    "satisfit": "satisfaire",
    "satisfont": "satisfaire",
    "satisfîmes": "satisfaire",
    "satisfît": "satisfaire",
    "satisfîtes": "satisfaire",
    "satiétés": "satiété",
    "satonne": "satonner",
    "satonné": "satonner",
    "satrapes": "satrape",
    "satura": "saturer",
    "saturai": "saturer",
    "saturaient": "saturer",
    "saturais": "saturer",
    "saturait": "saturer",
    "saturant": "saturer",
    "saturas": "saturer",
    "saturasse": "saturer",
    "saturassent": "saturer",
    "saturasses": "saturer",
    "saturassiez": "saturer",
    "saturassions": "saturer",
    "saturations": "saturation",
    "sature": "saturer",
    "saturent": "saturer",
    "saturera": "saturer",
    "saturerai": "saturer",
    "satureraient": "saturer",
    "saturerais": "saturer",
    "saturerait": "saturer",
    "satureras": "saturer",
    "saturerez": "saturer",
    "satureriez": "saturer",
    "saturerions": "saturer",
    "saturerons": "saturer",
    "satureront": "saturer",
    "satures": "saturer",
    "saturez": "saturer",
    "saturiez": "saturer",
    "saturions": "saturer",
    "saturniennes": "saturnienne",
    "saturniens": "saturnien",
    "saturons": "saturer",
    "saturâmes": "saturer",
    "saturât": "saturer",
    "saturâtes": "saturer",
    "saturèrent": "saturer",
    "saturé": "saturer",
    "saturée": "saturer",
    "saturées": "saturer",
    "saturés": "saturer",
    "satyres": "satyre",
    "sauce": "saucer",
    "saucent": "saucer",
    "saucera": "saucer",
    "saucerai": "saucer",
    "sauceraient": "saucer",
    "saucerais": "saucer",
    "saucerait": "saucer",
    "sauceras": "saucer",
    "saucerez": "saucer",
    "sauceriez": "saucer",
    "saucerions": "saucer",
    "saucerons": "saucer",
    "sauceront": "saucer",
    "sauces": "saucer",
    "saucez": "saucer",
    "sauciez": "saucer",
    "saucions": "saucer",
    "saucisses": "saucisse",
    "saucissonnages": "saucissonnage",
    "saucissonnant": "saucissonner",
    "saucissonne": "saucissonner",
    "saucissonné": "saucissonner",
    "saucissonnée": "saucissonner",
    "saucissonnés": "saucissonner",
    "saucissons": "saucisson",
    "saucières": "saucière",
    "saucèrent": "saucer",
    "saucé": "saucer",
    "saucée": "saucer",
    "saucées": "saucer",
    "saucés": "saucer",
    "sauf-conduits": "sauf-conduit",
    "saufs": "sauf",
    "sauges": "sauge",
    "saugrenue": "saugrenu",
    "saugrenues": "saugrenu",
    "saugrenus": "saugrenu",
    "saulaies": "saulaie",
    "saules": "saule",
    "saumoneaux": "saumoneau",
    "saumons": "saumon",
    "saumonée": "saumoné",
    "saumonées": "saumoné",
    "saumures": "saumure",
    "saumurées": "saumuré",
    "saumâtres": "saumâtre",
    "sauna": "sauner",
    "saunai": "sauner",
    "saunaient": "sauner",
    "saunais": "sauner",
    "saunait": "sauner",
    "saunant": "sauner",
    "saunas": "sauner",
    "saunasse": "sauner",
    "saunassent": "sauner",
    "saunasses": "sauner",
    "saunassiez": "sauner",
    "saunassions": "sauner",
    "saune": "sauner",
    "saunent": "sauner",
    "saunera": "sauner",
    "saunerai": "sauner",
    "sauneraient": "sauner",
    "saunerais": "sauner",
    "saunerait": "sauner",
    "sauneras": "sauner",
    "saunerez": "sauner",
    "sauneriez": "sauner",
    "saunerions": "sauner",
    "saunerons": "sauner",
    "sauneront": "sauner",
    "saunes": "sauner",
    "saunez": "sauner",
    "sauniers": "saunier",
    "sauniez": "sauner",
    "saunions": "sauner",
    "saunières": "saunière",
    "saunons": "sauner",
    "saunâmes": "sauner",
    "saunât": "sauner",
    "saunâtes": "sauner",
    "saunèrent": "sauner",
    "sauné": "sauner",
    "saunée": "sauner",
    "saunées": "sauner",
    "saunés": "sauner",
    "saupiquets": "saupiquet",
    "saupoudra": "saupoudrer",
    "saupoudrages": "saupoudrage",
    "saupoudrai": "saupoudrer",
    "saupoudraient": "saupoudrer",
    "saupoudrais": "saupoudrer",
    "saupoudrait": "saupoudrer",
    "saupoudrant": "saupoudrer",
    "saupoudras": "saupoudrer",
    "saupoudrasse": "saupoudrer",
    "saupoudrassent": "saupoudrer",
    "saupoudrasses": "saupoudrer",
    "saupoudrassiez": "saupoudrer",
    "saupoudrassions": "saupoudrer",
    "saupoudre": "saupoudrer",
    "saupoudrent": "saupoudrer",
    "saupoudrera": "saupoudrer",
    "saupoudrerai": "saupoudrer",
    "saupoudreraient": "saupoudrer",
    "saupoudrerais": "saupoudrer",
    "saupoudrerait": "saupoudrer",
    "saupoudreras": "saupoudrer",
    "saupoudrerez": "saupoudrer",
    "saupoudreriez": "saupoudrer",
    "saupoudrerions": "saupoudrer",
    "saupoudrerons": "saupoudrer",
    "saupoudreront": "saupoudrer",
    "saupoudres": "saupoudrer",
    "saupoudrez": "saupoudrer",
    "saupoudriez": "saupoudrer",
    "saupoudrions": "saupoudrer",
    "saupoudrons": "saupoudrer",
    "saupoudrâmes": "saupoudrer",
    "saupoudrât": "saupoudrer",
    "saupoudrâtes": "saupoudrer",
    "saupoudrèrent": "saupoudrer",
    "saupoudré": "saupoudrer",
    "saupoudrée": "saupoudrer",
    "saupoudrées": "saupoudrer",
    "saupoudrés": "saupoudrer",
    "saura": "savoir",
    "saurai": "savoir",
    "sauraient": "savoir",
    "saurais": "savoir",
    "saurait": "savoir",
    "saurant": "saurer",
    "sauras": "savoir",
    "saurasse": "saurer",
    "saurassent": "saurer",
    "saurasses": "saurer",
    "saurassiez": "saurer",
    "saurassions": "saurer",
    "saure": "saurer",
    "saurent": "saurer",
    "saurera": "saurer",
    "saurerai": "saurer",
    "saureraient": "saurer",
    "saurerais": "saurer",
    "saurerait": "saurer",
    "saureras": "saurer",
    "saurerez": "saurer",
    "saureriez": "saurer",
    "saurerions": "saurer",
    "saurerons": "saurer",
    "saureront": "saurer",
    "saures": "saurer",
    "saurets": "sauret",
    "saurez": "savoir",
    "sauri": "saurir",
    "sauriens": "saurien",
    "sauriez": "savoir",
    "saurions": "savoir",
    "saurons": "savoir",
    "sauront": "savoir",
    "saurs": "saur",
    "saurâmes": "saurer",
    "saurât": "saurer",
    "saurâtes": "saurer",
    "saurèrent": "saurer",
    "sauré": "saurer",
    "saurée": "saurer",
    "saurées": "saurer",
    "saurés": "saurer",
    "saussaies": "saussaie",
    "sauta": "sauter",
    "sautai": "sauter",
    "sautaient": "sauter",
    "sautais": "sauter",
    "sautait": "sauter",
    "sautant": "sauter",
    "sautante": "sautant",
    "sautas": "sauter",
    "sautasse": "sauter",
    "sautassent": "sauter",
    "sautasses": "sauter",
    "sautassiez": "sauter",
    "sautassions": "sauter",
    "saute": "sauter",
    "saute-ruisseaux": "saute-ruisseau",
    "sautelant": "sauteler",
    "sautent": "sauter",
    "sautera": "sauter",
    "sauterai": "sauter",
    "sauteraient": "sauter",
    "sauterais": "sauter",
    "sauterait": "sauter",
    "sauteras": "sauter",
    "sauterelles": "sauterelle",
    "sauterez": "sauter",
    "sauteries": "sauterie",
    "sauteriez": "sauter",
    "sauterions": "sauter",
    "sauterons": "sauter",
    "sauteront": "sauter",
    "sautes": "sauter",
    "sauteurs": "sauteur",
    "sauteuse": "sauteur",
    "sauteuses": "sauteur",
    "sautez": "sauter",
    "sautiez": "sauter",
    "sautilla": "sautiller",
    "sautillai": "sautiller",
    "sautillaient": "sautiller",
    "sautillais": "sautiller",
    "sautillait": "sautiller",
    "sautillant": "sautiller",
    "sautillante": "sautillant",
    "sautillantes": "sautillant",
    "sautillants": "sautillant",
    "sautillas": "sautiller",
    "sautillasse": "sautiller",
    "sautillassent": "sautiller",
    "sautillasses": "sautiller",
    "sautillassiez": "sautiller",
    "sautillassions": "sautiller",
    "sautille": "sautiller",
    "sautillements": "sautillement",
    "sautillent": "sautiller",
    "sautillera": "sautiller",
    "sautillerai": "sautiller",
    "sautilleraient": "sautiller",
    "sautillerais": "sautiller",
    "sautillerait": "sautiller",
    "sautilleras": "sautiller",
    "sautillerez": "sautiller",
    "sautilleriez": "sautiller",
    "sautillerions": "sautiller",
    "sautillerons": "sautiller",
    "sautilleront": "sautiller",
    "sautilles": "sautiller",
    "sautillez": "sautiller",
    "sautilliez": "sautiller",
    "sautillions": "sautiller",
    "sautillons": "sautiller",
    "sautillâmes": "sautiller",
    "sautillât": "sautiller",
    "sautillâtes": "sautiller",
    "sautillèrent": "sautiller",
    "sautillé": "sautiller",
    "sautillée": "sautiller",
    "sautillées": "sautiller",
    "sautillés": "sautiller",
    "sautions": "sauter",
    "sautoirs": "sautoir",
    "sautons": "sauton",
    "sauts": "saut",
    "sauts-de-lit": "saut-de-lit",
    "sauts-de-loup": "saut-de-loup",
    "sauts-de-mouton": "saut-de-mouton",
    "sautâmes": "sauter",
    "sautât": "sauter",
    "sautâtes": "sauter",
    "sautèrent": "sauter",
    "sauté": "sauter",
    "sautée": "sauter",
    "sautées": "sauter",
    "sautés": "sauter",
    "sauva": "sauver",
    "sauvageonne": "sauvageon",
    "sauvageonnes": "sauvageon",
    "sauvageons": "sauvageon",
    "sauvageries": "sauvagerie",
    "sauvages": "sauvage",
    "sauvagesses": "sauvagesse",
    "sauvagine": "sauvagin",
    "sauvagines": "sauvagin",
    "sauvai": "sauver",
    "sauvaient": "sauver",
    "sauvais": "sauver",
    "sauvait": "sauver",
    "sauvant": "sauver",
    "sauvas": "sauver",
    "sauvasse": "sauver",
    "sauvassent": "sauver",
    "sauvasses": "sauver",
    "sauvassiez": "sauver",
    "sauvassions": "sauver",
    "sauve": "sauver",
    "sauvegarda": "sauvegarder",
    "sauvegardai": "sauvegarder",
    "sauvegardaient": "sauvegarder",
    "sauvegardais": "sauvegarder",
    "sauvegardait": "sauvegarder",
    "sauvegardant": "sauvegarder",
    "sauvegardas": "sauvegarder",
    "sauvegardasse": "sauvegarder",
    "sauvegardassent": "sauvegarder",
    "sauvegardasses": "sauvegarder",
    "sauvegardassiez": "sauvegarder",
    "sauvegardassions": "sauvegarder",
    "sauvegarde": "sauvegarder",
    "sauvegardent": "sauvegarder",
    "sauvegardera": "sauvegarder",
    "sauvegarderai": "sauvegarder",
    "sauvegarderaient": "sauvegarder",
    "sauvegarderais": "sauvegarder",
    "sauvegarderait": "sauvegarder",
    "sauvegarderas": "sauvegarder",
    "sauvegarderez": "sauvegarder",
    "sauvegarderiez": "sauvegarder",
    "sauvegarderions": "sauvegarder",
    "sauvegarderons": "sauvegarder",
    "sauvegarderont": "sauvegarder",
    "sauvegardes": "sauvegarder",
    "sauvegardez": "sauvegarder",
    "sauvegardiez": "sauvegarder",
    "sauvegardions": "sauvegarder",
    "sauvegardons": "sauvegarder",
    "sauvegardâmes": "sauvegarder",
    "sauvegardât": "sauvegarder",
    "sauvegardâtes": "sauvegarder",
    "sauvegardèrent": "sauvegarder",
    "sauvegardé": "sauvegarder",
    "sauvegardée": "sauvegarder",
    "sauvegardées": "sauvegarder",
    "sauvegardés": "sauvegarder",
    "sauvent": "sauver",
    "sauvera": "sauver",
    "sauverai": "sauver",
    "sauveraient": "sauver",
    "sauverais": "sauver",
    "sauverait": "sauver",
    "sauveras": "sauver",
    "sauverez": "sauver",
    "sauvergarda": "sauvergarder",
    "sauvergardai": "sauvergarder",
    "sauvergardaient": "sauvergarder",
    "sauvergardais": "sauvergarder",
    "sauvergardait": "sauvergarder",
    "sauvergardant": "sauvergarder",
    "sauvergardas": "sauvergarder",
    "sauvergardasse": "sauvergarder",
    "sauvergardassent": "sauvergarder",
    "sauvergardasses": "sauvergarder",
    "sauvergardassiez": "sauvergarder",
    "sauvergardassions": "sauvergarder",
    "sauvergarde": "sauvergarder",
    "sauvergardent": "sauvergarder",
    "sauvergardera": "sauvergarder",
    "sauvergarderai": "sauvergarder",
    "sauvergarderaient": "sauvergarder",
    "sauvergarderais": "sauvergarder",
    "sauvergarderait": "sauvergarder",
    "sauvergarderas": "sauvergarder",
    "sauvergarderez": "sauvergarder",
    "sauvergarderiez": "sauvergarder",
    "sauvergarderions": "sauvergarder",
    "sauvergarderons": "sauvergarder",
    "sauvergarderont": "sauvergarder",
    "sauvergardes": "sauvergarder",
    "sauvergardez": "sauvergarder",
    "sauvergardiez": "sauvergarder",
    "sauvergardions": "sauvergarder",
    "sauvergardons": "sauvergarder",
    "sauvergardâmes": "sauvergarder",
    "sauvergardât": "sauvergarder",
    "sauvergardâtes": "sauvergarder",
    "sauvergardèrent": "sauvergarder",
    "sauvergardé": "sauvergarder",
    "sauvergardée": "sauvergarder",
    "sauvergardées": "sauvergarder",
    "sauvergardés": "sauvergarder",
    "sauveriez": "sauver",
    "sauverions": "sauver",
    "sauverons": "sauver",
    "sauveront": "sauver",
    "sauves": "sauver",
    "sauvetages": "sauvetage",
    "sauveteurs": "sauveteur",
    "sauvette": "sauveter",
    "sauveurs": "sauveur",
    "sauveuse": "sauveur",
    "sauvez": "sauver",
    "sauviez": "sauver",
    "sauvignons": "sauvignon",
    "sauvions": "sauver",
    "sauvons": "sauver",
    "sauvâmes": "sauver",
    "sauvât": "sauver",
    "sauvâtes": "sauver",
    "sauvèrent": "sauver",
    "sauvé": "sauver",
    "sauvée": "sauver",
    "sauvées": "sauver",
    "sauvés": "sauver",
    "sauça": "saucer",
    "sauçai": "saucer",
    "sauçaient": "saucer",
    "sauçais": "saucer",
    "sauçait": "saucer",
    "sauçant": "saucer",
    "sauças": "saucer",
    "sauçasse": "saucer",
    "sauçassent": "saucer",
    "sauçasses": "saucer",
    "sauçassiez": "saucer",
    "sauçassions": "saucer",
    "sauçons": "saucer",
    "sauçâmes": "saucer",
    "sauçât": "saucer",
    "sauçâtes": "saucer",
    "savaient": "savoir",
    "savais": "savoir",
    "savait": "savoir",
    "savanes": "savane",
    "savantasses": "savantasse",
    "savante": "savant",
    "savantes": "savant",
    "savantissimes": "savantissime",
    "savants": "savant",
    "savarins": "savarin",
    "savata": "savater",
    "savatait": "savater",
    "savate": "savater",
    "savates": "savater",
    "savent": "savoir",
    "savetiers": "savetier",
    "saveurs": "saveur",
    "savez": "savoir",
    "saviez": "savoir",
    "savions": "savoir",
    "savoirs": "savoir",
    "savonna": "savonner",
    "savonnages": "savonnage",
    "savonnai": "savonner",
    "savonnaient": "savonner",
    "savonnais": "savonner",
    "savonnait": "savonner",
    "savonnant": "savonner",
    "savonnas": "savonner",
    "savonnasse": "savonner",
    "savonnassent": "savonner",
    "savonnasses": "savonner",
    "savonnassiez": "savonner",
    "savonnassions": "savonner",
    "savonne": "savonner",
    "savonnent": "savonner",
    "savonnera": "savonner",
    "savonnerai": "savonner",
    "savonneraient": "savonner",
    "savonnerais": "savonner",
    "savonnerait": "savonner",
    "savonneras": "savonner",
    "savonnerez": "savonner",
    "savonneries": "savonnerie",
    "savonneriez": "savonner",
    "savonnerions": "savonner",
    "savonnerons": "savonner",
    "savonneront": "savonner",
    "savonnes": "savonner",
    "savonnettes": "savonnette",
    "savonneuse": "savonneux",
    "savonneuses": "savonneux",
    "savonnez": "savonner",
    "savonniez": "savonner",
    "savonnions": "savonner",
    "savonnons": "savonner",
    "savonnâmes": "savonner",
    "savonnât": "savonner",
    "savonnâtes": "savonner",
    "savonnèrent": "savonner",
    "savonné": "savonner",
    "savonnée": "savonner",
    "savonnées": "savonner",
    "savonnés": "savonner",
    "savons": "savon",
    "savoura": "savourer",
    "savourai": "savourer",
    "savouraient": "savourer",
    "savourais": "savourer",
    "savourait": "savourer",
    "savourant": "savourer",
    "savouras": "savourer",
    "savourasse": "savourer",
    "savourassent": "savourer",
    "savourasses": "savourer",
    "savourassiez": "savourer",
    "savourassions": "savourer",
    "savoure": "savourer",
    "savourent": "savourer",
    "savourera": "savourer",
    "savourerai": "savourer",
    "savoureraient": "savourer",
    "savourerais": "savourer",
    "savourerait": "savourer",
    "savoureras": "savourer",
    "savourerez": "savourer",
    "savoureriez": "savourer",
    "savourerions": "savourer",
    "savourerons": "savourer",
    "savoureront": "savourer",
    "savoures": "savourer",
    "savoureuse": "savoureux",
    "savoureuses": "savoureux",
    "savourez": "savourer",
    "savouriez": "savourer",
    "savourions": "savourer",
    "savourons": "savourer",
    "savourâmes": "savourer",
    "savourât": "savourer",
    "savourâtes": "savourer",
    "savourèrent": "savourer",
    "savouré": "savourer",
    "savourée": "savourer",
    "savourées": "savourer",
    "savourés": "savourer",
    "savoyarde": "savoyard",
    "savoyardes": "savoyard",
    "savoyards": "savoyard",
    "saxes": "saxe",
    "saxhorns": "saxhorn",
    "saxifragacées": "saxifragacée",
    "saxifrages": "saxifrage",
    "saxonne": "saxon",
    "saxonnes": "saxonne",
    "saxons": "saxon",
    "saxophones": "saxophone",
    "saxophonistes": "saxophoniste",
    "saxos": "saxo",
    "saynètes": "saynète",
    "sayons": "sayon",
    "saïgas": "saïga",
    "sbires": "sbire",
    "sbuventions": "sbuvention",
    "scabieuse": "scabieux",
    "scabreuse": "scabreux",
    "scabreuses": "scabreux",
    "scaferlatis": "scaferlati",
    "scalaires": "scalaire",
    "scalpa": "scalper",
    "scalpai": "scalper",
    "scalpaient": "scalper",
    "scalpais": "scalper",
    "scalpait": "scalper",
    "scalpant": "scalper",
    "scalpas": "scalper",
    "scalpasse": "scalper",
    "scalpassent": "scalper",
    "scalpasses": "scalper",
    "scalpassiez": "scalper",
    "scalpassions": "scalper",
    "scalpe": "scalper",
    "scalpels": "scalpel",
    "scalpent": "scalper",
    "scalpera": "scalper",
    "scalperai": "scalper",
    "scalperaient": "scalper",
    "scalperais": "scalper",
    "scalperait": "scalper",
    "scalperas": "scalper",
    "scalperez": "scalper",
    "scalperiez": "scalper",
    "scalperions": "scalper",
    "scalperons": "scalper",
    "scalperont": "scalper",
    "scalpes": "scalper",
    "scalpez": "scalper",
    "scalpiez": "scalper",
    "scalpions": "scalper",
    "scalpons": "scalper",
    "scalps": "scalp",
    "scalpâmes": "scalper",
    "scalpât": "scalper",
    "scalpâtes": "scalper",
    "scalpèrent": "scalper",
    "scalpé": "scalper",
    "scalpée": "scalper",
    "scalpées": "scalper",
    "scalpés": "scalper",
    "scalènes": "scalène",
    "scanda": "scander",
    "scandai": "scander",
    "scandaient": "scander",
    "scandais": "scander",
    "scandait": "scander",
    "scandales": "scandale",
    "scandaleuse": "scandaleux",
    "scandaleuses": "scandaleux",
    "scandalisa": "scandaliser",
    "scandalisai": "scandaliser",
    "scandalisaient": "scandaliser",
    "scandalisais": "scandaliser",
    "scandalisait": "scandaliser",
    "scandalisant": "scandaliser",
    "scandalise": "scandaliser",
    "scandalisent": "scandaliser",
    "scandalisera": "scandaliser",
    "scandaliserait": "scandaliser",
    "scandalisons": "scandaliser",
    "scandalisèrent": "scandaliser",
    "scandalisé": "scandaliser",
    "scandalisée": "scandaliser",
    "scandalisées": "scandaliser",
    "scandalisés": "scandaliser",
    "scandant": "scander",
    "scandas": "scander",
    "scandasse": "scander",
    "scandassent": "scander",
    "scandasses": "scander",
    "scandassiez": "scander",
    "scandassions": "scander",
    "scande": "scander",
    "scandent": "scander",
    "scandera": "scander",
    "scanderai": "scander",
    "scanderaient": "scander",
    "scanderais": "scander",
    "scanderait": "scander",
    "scanderas": "scander",
    "scanderez": "scander",
    "scanderiez": "scander",
    "scanderions": "scander",
    "scanderons": "scander",
    "scanderont": "scander",
    "scandes": "scander",
    "scandez": "scander",
    "scandiez": "scander",
    "scandinaves": "scandinave",
    "scandions": "scander",
    "scandons": "scander",
    "scandâmes": "scander",
    "scandât": "scander",
    "scandâtes": "scander",
    "scandèrent": "scander",
    "scandé": "scander",
    "scandée": "scander",
    "scandées": "scander",
    "scandés": "scander",
    "scannais": "scanner",
    "scanne": "scanner",
    "scannent": "scanner",
    "scannera": "scanner",
    "scanneront": "scanner",
    "scanners": "scanner",
    "scannes": "scanner",
    "scannez": "scanner",
    "scannons": "scanner",
    "scanné": "scanner",
    "scannée": "scanner",
    "scannés": "scanner",
    "scanographies": "scanographie",
    "scansions": "scansion",
    "scaphandres": "scaphandre",
    "scaphandriers": "scaphandrier",
    "scapulaires": "scapulaire",
    "scarabées": "scarabée",
    "scarifia": "scarifier",
    "scarifiai": "scarifier",
    "scarifiaient": "scarifier",
    "scarifiais": "scarifier",
    "scarifiait": "scarifier",
    "scarifiant": "scarifier",
    "scarifias": "scarifier",
    "scarifiasse": "scarifier",
    "scarifiassent": "scarifier",
    "scarifiasses": "scarifier",
    "scarifiassiez": "scarifier",
    "scarifiassions": "scarifier",
    "scarifications": "scarification",
    "scarifie": "scarifier",
    "scarifient": "scarifier",
    "scarifiera": "scarifier",
    "scarifierai": "scarifier",
    "scarifieraient": "scarifier",
    "scarifierais": "scarifier",
    "scarifierait": "scarifier",
    "scarifieras": "scarifier",
    "scarifierez": "scarifier",
    "scarifieriez": "scarifier",
    "scarifierions": "scarifier",
    "scarifierons": "scarifier",
    "scarifieront": "scarifier",
    "scarifies": "scarifier",
    "scarifiez": "scarifier",
    "scarifiiez": "scarifier",
    "scarifiions": "scarifier",
    "scarifions": "scarifier",
    "scarifiâmes": "scarifier",
    "scarifiât": "scarifier",
    "scarifiâtes": "scarifier",
    "scarifièrent": "scarifier",
    "scarifié": "scarifier",
    "scarifiée": "scarifier",
    "scarifiées": "scarifier",
    "scarifiés": "scarifier",
    "scarlatin": "scarlatine",
    "scarlatine": "scarlatin",
    "scarlatines": "scarlatine",
    "scaroles": "scarole",
    "scatologies": "scatologie",
    "scatologiques": "scatologique",
    "scatophiles": "scatophile",
    "scatos": "scato",
    "scazons": "scazon",
    "sceaux": "sceau",
    "sceaux-de-salomon": "sceau-de-salomon",
    "scella": "sceller",
    "scellai": "sceller",
    "scellaient": "sceller",
    "scellais": "sceller",
    "scellait": "sceller",
    "scellant": "sceller",
    "scellas": "sceller",
    "scellasse": "sceller",
    "scellassent": "sceller",
    "scellasses": "sceller",
    "scellassiez": "sceller",
    "scellassions": "sceller",
    "scelle": "sceller",
    "scellements": "scellement",
    "scellent": "sceller",
    "scellera": "sceller",
    "scellerai": "sceller",
    "scelleraient": "sceller",
    "scellerais": "sceller",
    "scellerait": "sceller",
    "scelleras": "sceller",
    "scellerez": "sceller",
    "scelleriez": "sceller",
    "scellerions": "sceller",
    "scellerons": "sceller",
    "scelleront": "sceller",
    "scelles": "sceller",
    "scellez": "sceller",
    "scelliez": "sceller",
    "scellions": "sceller",
    "scellons": "sceller",
    "scellâmes": "sceller",
    "scellât": "sceller",
    "scellâtes": "sceller",
    "scellèrent": "sceller",
    "scellé": "sceller",
    "scellée": "sceller",
    "scellées": "sceller",
    "scellés": "sceller",
    "scepticismes": "scepticisme",
    "sceptiques": "sceptique",
    "sceptres": "sceptre",
    "schelems": "schelem",
    "scherzos": "scherzo",
    "schillings": "schilling",
    "schismatiques": "schismatique",
    "schismes": "schisme",
    "schistes": "schiste",
    "schisteuses": "schisteux",
    "schizophrènes": "schizophrène",
    "schizophrénies": "schizophrénie",
    "schizophréniques": "schizophrénique",
    "schizoïdes": "schizoïde",
    "schlagues": "schlague",
    "schlinguait": "schlinguer",
    "schlinguant": "schlinguer",
    "schlingue": "schlinguer",
    "schlingues": "schlinguer",
    "schlittes": "schlitte",
    "schmecte": "schmecter",
    "schnocks": "schnock",
    "schnoques": "schnoque",
    "schnouffe": "schnouffer",
    "schooners": "schooner",
    "schtroumpfs": "schtroumpf",
    "schupos": "schupo",
    "schèmes": "schème",
    "schémas": "schéma",
    "schématiques": "schématique",
    "schématisa": "schématiser",
    "schématisai": "schématiser",
    "schématisaient": "schématiser",
    "schématisais": "schématiser",
    "schématisait": "schématiser",
    "schématisant": "schématiser",
    "schématisas": "schématiser",
    "schématisasse": "schématiser",
    "schématisassent": "schématiser",
    "schématisasses": "schématiser",
    "schématisassiez": "schématiser",
    "schématisassions": "schématiser",
    "schématise": "schématiser",
    "schématisent": "schématiser",
    "schématisera": "schématiser",
    "schématiserai": "schématiser",
    "schématiseraient": "schématiser",
    "schématiserais": "schématiser",
    "schématiserait": "schématiser",
    "schématiseras": "schématiser",
    "schématiserez": "schématiser",
    "schématiseriez": "schématiser",
    "schématiserions": "schématiser",
    "schématiserons": "schématiser",
    "schématiseront": "schématiser",
    "schématises": "schématiser",
    "schématisez": "schématiser",
    "schématisiez": "schématiser",
    "schématisions": "schématiser",
    "schématisons": "schématiser",
    "schématisâmes": "schématiser",
    "schématisât": "schématiser",
    "schématisâtes": "schématiser",
    "schématisèrent": "schématiser",
    "schématisé": "schématiser",
    "schématisée": "schématiser",
    "schématisées": "schématiser",
    "schématisés": "schématiser",
    "scia": "scier",
    "sciai": "scier",
    "sciaient": "scier",
    "sciais": "scier",
    "sciait": "scier",
    "sciant": "scier",
    "scias": "scier",
    "sciasse": "scier",
    "sciassent": "scier",
    "sciasses": "scier",
    "sciassiez": "scier",
    "sciassions": "scier",
    "sciatiques": "sciatique",
    "scie": "scier",
    "sciences": "science",
    "sciences-fictions": "science-fiction",
    "scient": "scier",
    "scientifiques": "scientifique",
    "scientologues": "scientologue",
    "sciera": "scier",
    "scierai": "scier",
    "scieraient": "scier",
    "scierais": "scier",
    "scierait": "scier",
    "scieras": "scier",
    "scierez": "scier",
    "scieries": "scierie",
    "scieriez": "scier",
    "scierions": "scier",
    "scierons": "scier",
    "scieront": "scier",
    "scies": "scier",
    "scieurs": "scieur",
    "sciez": "scier",
    "sciiez": "scier",
    "sciions": "scier",
    "scinda": "scinder",
    "scindai": "scinder",
    "scindaient": "scinder",
    "scindais": "scinder",
    "scindait": "scinder",
    "scindant": "scinder",
    "scindas": "scinder",
    "scindasse": "scinder",
    "scindassent": "scinder",
    "scindasses": "scinder",
    "scindassiez": "scinder",
    "scindassions": "scinder",
    "scinde": "scinder",
    "scindent": "scinder",
    "scindera": "scinder",
    "scinderai": "scinder",
    "scinderaient": "scinder",
    "scinderais": "scinder",
    "scinderait": "scinder",
    "scinderas": "scinder",
    "scinderez": "scinder",
    "scinderiez": "scinder",
    "scinderions": "scinder",
    "scinderons": "scinder",
    "scinderont": "scinder",
    "scindes": "scinder",
    "scindez": "scinder",
    "scindiez": "scinder",
    "scindions": "scinder",
    "scindons": "scinder",
    "scindâmes": "scinder",
    "scindât": "scinder",
    "scindâtes": "scinder",
    "scindèrent": "scinder",
    "scindé": "scinder",
    "scindée": "scinder",
    "scindées": "scinder",
    "scindés": "scinder",
    "scintilla": "scintiller",
    "scintillai": "scintiller",
    "scintillaient": "scintiller",
    "scintillais": "scintiller",
    "scintillait": "scintiller",
    "scintillant": "scintiller",
    "scintillante": "scintillant",
    "scintillantes": "scintillant",
    "scintillants": "scintillant",
    "scintillas": "scintiller",
    "scintillasse": "scintiller",
    "scintillassent": "scintiller",
    "scintillasses": "scintiller",
    "scintillassiez": "scintiller",
    "scintillassions": "scintiller",
    "scintillations": "scintillation",
    "scintille": "scintiller",
    "scintillements": "scintillement",
    "scintillent": "scintiller",
    "scintillera": "scintiller",
    "scintillerai": "scintiller",
    "scintilleraient": "scintiller",
    "scintillerais": "scintiller",
    "scintillerait": "scintiller",
    "scintilleras": "scintiller",
    "scintillerez": "scintiller",
    "scintilleriez": "scintiller",
    "scintillerions": "scintiller",
    "scintillerons": "scintiller",
    "scintilleront": "scintiller",
    "scintilles": "scintiller",
    "scintillez": "scintiller",
    "scintilliez": "scintiller",
    "scintillions": "scintiller",
    "scintillons": "scintiller",
    "scintillâmes": "scintiller",
    "scintillât": "scintiller",
    "scintillâtes": "scintiller",
    "scintillèrent": "scintiller",
    "scintillé": "scintiller",
    "scions": "scion",
    "scirpes": "scirpe",
    "scissionnistes": "scissionniste",
    "scissions": "scission",
    "scissipares": "scissipare",
    "scissures": "scissure",
    "sciures": "sciure",
    "sciâmes": "scier",
    "sciât": "scier",
    "sciâtes": "scier",
    "scièrent": "scier",
    "scié": "scier",
    "sciée": "scier",
    "sciées": "scier",
    "sciés": "scier",
    "sclérale": "scléral",
    "sclérales": "scléral",
    "scléraux": "scléral",
    "sclérenchymes": "sclérenchyme",
    "sclérosante": "sclérosant",
    "sclérose": "scléroser",
    "scléroserai": "scléroser",
    "scléroses": "sclérose",
    "sclérosé": "scléroser",
    "sclérosée": "scléroser",
    "sclérosées": "sclérosé",
    "sclérosés": "sclérosé",
    "sclérotiques": "sclérotique",
    "scolaires": "scolaire",
    "scolarisa": "scolariser",
    "scolarisai": "scolariser",
    "scolarisaient": "scolariser",
    "scolarisais": "scolariser",
    "scolarisait": "scolariser",
    "scolarisant": "scolariser",
    "scolarisas": "scolariser",
    "scolarisasse": "scolariser",
    "scolarisassent": "scolariser",
    "scolarisasses": "scolariser",
    "scolarisassiez": "scolariser",
    "scolarisassions": "scolariser",
    "scolarisations": "scolarisation",
    "scolarise": "scolariser",
    "scolarisent": "scolariser",
    "scolarisera": "scolariser",
    "scolariserai": "scolariser",
    "scolariseraient": "scolariser",
    "scolariserais": "scolariser",
    "scolariserait": "scolariser",
    "scolariseras": "scolariser",
    "scolariserez": "scolariser",
    "scolariseriez": "scolariser",
    "scolariserions": "scolariser",
    "scolariserons": "scolariser",
    "scolariseront": "scolariser",
    "scolarises": "scolariser",
    "scolarisez": "scolariser",
    "scolarisiez": "scolariser",
    "scolarisions": "scolariser",
    "scolarisons": "scolariser",
    "scolarisâmes": "scolariser",
    "scolarisât": "scolariser",
    "scolarisâtes": "scolariser",
    "scolarisèrent": "scolariser",
    "scolarisé": "scolariser",
    "scolarisée": "scolariser",
    "scolarisées": "scolariser",
    "scolarisés": "scolariser",
    "scolarités": "scolarité",
    "scolastiques": "scolastique",
    "scolies": "scolie",
    "scolioses": "scoliose",
    "scolopendres": "scolopendre",
    "scones": "scone",
    "sconses": "sconse",
    "scoops": "scoop",
    "scooters": "scooter",
    "scootéristes": "scootériste",
    "scopes": "scope",
    "scopitones": "scopitone",
    "scorbuts": "scorbut",
    "scores": "score",
    "scories": "scorie",
    "scorpions": "scorpion",
    "scorsonères": "scorsonère",
    "scotchais": "scotcher",
    "scotches": "scotcher",
    "scotchons": "scotcher",
    "scotchs": "scotch",
    "scotché": "scotcher",
    "scotchée": "scotcher",
    "scotchées": "scotcher",
    "scotchés": "scotcher",
    "scotomes": "scotome",
    "scotomisa": "scotomiser",
    "scotomisai": "scotomiser",
    "scotomisaient": "scotomiser",
    "scotomisais": "scotomiser",
    "scotomisait": "scotomiser",
    "scotomisant": "scotomiser",
    "scotomisas": "scotomiser",
    "scotomisasse": "scotomiser",
    "scotomisassent": "scotomiser",
    "scotomisasses": "scotomiser",
    "scotomisassiez": "scotomiser",
    "scotomisassions": "scotomiser",
    "scotomise": "scotomiser",
    "scotomisent": "scotomiser",
    "scotomisera": "scotomiser",
    "scotomiserai": "scotomiser",
    "scotomiseraient": "scotomiser",
    "scotomiserais": "scotomiser",
    "scotomiserait": "scotomiser",
    "scotomiseras": "scotomiser",
    "scotomiserez": "scotomiser",
    "scotomiseriez": "scotomiser",
    "scotomiserions": "scotomiser",
    "scotomiserons": "scotomiser",
    "scotomiseront": "scotomiser",
    "scotomises": "scotomiser",
    "scotomisez": "scotomiser",
    "scotomisiez": "scotomiser",
    "scotomisions": "scotomiser",
    "scotomisons": "scotomiser",
    "scotomisâmes": "scotomiser",
    "scotomisât": "scotomiser",
    "scotomisâtes": "scotomiser",
    "scotomisèrent": "scotomiser",
    "scotomisé": "scotomiser",
    "scotomisée": "scotomiser",
    "scotomisées": "scotomiser",
    "scotomisés": "scotomiser",
    "scottish-terriers": "scottish-terrier",
    "scoubidous": "scoubidou",
    "scoute": "scout",
    "scoutes": "scout",
    "scouts": "scout",
    "scrapers": "scraper",
    "scratcha": "scratcher",
    "scratchai": "scratcher",
    "scratchaient": "scratcher",
    "scratchais": "scratcher",
    "scratchait": "scratcher",
    "scratchant": "scratcher",
    "scratchas": "scratcher",
    "scratchasse": "scratcher",
    "scratchassent": "scratcher",
    "scratchasses": "scratcher",
    "scratchassiez": "scratcher",
    "scratchassions": "scratcher",
    "scratche": "scratcher",
    "scratchent": "scratcher",
    "scratchera": "scratcher",
    "scratcherai": "scratcher",
    "scratcheraient": "scratcher",
    "scratcherais": "scratcher",
    "scratcherait": "scratcher",
    "scratcheras": "scratcher",
    "scratcherez": "scratcher",
    "scratcheriez": "scratcher",
    "scratcherions": "scratcher",
    "scratcherons": "scratcher",
    "scratcheront": "scratcher",
    "scratches": "scratcher",
    "scratchez": "scratcher",
    "scratchiez": "scratcher",
    "scratchions": "scratcher",
    "scratchons": "scratcher",
    "scratchâmes": "scratcher",
    "scratchât": "scratcher",
    "scratchâtes": "scratcher",
    "scratchèrent": "scratcher",
    "scratché": "scratcher",
    "scratchée": "scratcher",
    "scratchées": "scratcher",
    "scratchés": "scratcher",
    "scribes": "scribe",
    "scribouillages": "scribouillage",
    "scribouillards": "scribouillard",
    "scribouille": "scribouiller",
    "script-girls": "script-girl",
    "scriptes": "scripte",
    "scripteurs": "scripteur",
    "scripts": "script",
    "scrofules": "scrofule",
    "scrotale": "scrotal",
    "scrotales": "scrotal",
    "scrotaux": "scrotal",
    "scrotums": "scrotum",
    "scrubbers": "scrubber",
    "scrubs": "scrub",
    "scrupules": "scrupule",
    "scrupuleuse": "scrupuleux",
    "scrupuleuses": "scrupuleux",
    "scruta": "scruter",
    "scrutai": "scruter",
    "scrutaient": "scruter",
    "scrutais": "scruter",
    "scrutait": "scruter",
    "scrutant": "scruter",
    "scrutas": "scruter",
    "scrutasse": "scruter",
    "scrutassent": "scruter",
    "scrutasses": "scruter",
    "scrutassiez": "scruter",
    "scrutassions": "scruter",
    "scrutateurs": "scrutateur",
    "scrutatrices": "scrutateur",
    "scrute": "scruter",
    "scrutent": "scruter",
    "scrutera": "scruter",
    "scruterai": "scruter",
    "scruteraient": "scruter",
    "scruterais": "scruter",
    "scruterait": "scruter",
    "scruteras": "scruter",
    "scruterez": "scruter",
    "scruteriez": "scruter",
    "scruterions": "scruter",
    "scruterons": "scruter",
    "scruteront": "scruter",
    "scrutes": "scruter",
    "scrutez": "scruter",
    "scrutiez": "scruter",
    "scrutins": "scrutin",
    "scrutions": "scruter",
    "scrutons": "scruter",
    "scrutâmes": "scruter",
    "scrutât": "scruter",
    "scrutâtes": "scruter",
    "scrutèrent": "scruter",
    "scruté": "scruter",
    "scrutée": "scruter",
    "scrutées": "scruter",
    "scrutés": "scruter",
    "sculls": "scull",
    "sculpta": "sculpter",
    "sculptai": "sculpter",
    "sculptaient": "sculpter",
    "sculptais": "sculpter",
    "sculptait": "sculpter",
    "sculptant": "sculpter",
    "sculptas": "sculpter",
    "sculptasse": "sculpter",
    "sculptassent": "sculpter",
    "sculptasses": "sculpter",
    "sculptassiez": "sculpter",
    "sculptassions": "sculpter",
    "sculpte": "sculpter",
    "sculptent": "sculpter",
    "sculptera": "sculpter",
    "sculpterai": "sculpter",
    "sculpteraient": "sculpter",
    "sculpterais": "sculpter",
    "sculpterait": "sculpter",
    "sculpteras": "sculpter",
    "sculpterez": "sculpter",
    "sculpteriez": "sculpter",
    "sculpterions": "sculpter",
    "sculpterons": "sculpter",
    "sculpteront": "sculpter",
    "sculptes": "sculpter",
    "sculpteurs": "sculpteur",
    "sculptez": "sculpter",
    "sculptiez": "sculpter",
    "sculptions": "sculpter",
    "sculptons": "sculpter",
    "sculptrice": "sculpteur",
    "sculpturale": "sculptural",
    "sculpturales": "sculptural",
    "sculpturaux": "sculptural",
    "sculptures": "sculpture",
    "sculptâmes": "sculpter",
    "sculptât": "sculpter",
    "sculptâtes": "sculpter",
    "sculptèrent": "sculpter",
    "sculpté": "sculpter",
    "sculptée": "sculpter",
    "sculptées": "sculpter",
    "sculptés": "sculpter",
    "scutigères": "scutigère",
    "scythes": "scythe",
    "scènes": "scène",
    "scènes-clés": "scènes-clé",
    "scélérate": "scélérat",
    "scélérates": "scélérat",
    "scélératesses": "scélératesse",
    "scélérats": "scélérat",
    "scénarii": "scénario",
    "scénarios": "scénario",
    "scénaristes": "scénariste",
    "scénars": "scénar",
    "scéniques": "scénique",
    "scénographies": "scénographie",
    "sea-lines": "sea-line",
    "seaux": "seau",
    "sebkhas": "sebkha",
    "seccos": "secco",
    "seconda": "seconder",
    "secondai": "seconder",
    "secondaient": "seconder",
    "secondaires": "secondaire",
    "secondais": "seconder",
    "secondait": "seconder",
    "secondant": "seconder",
    "secondas": "seconder",
    "secondasse": "seconder",
    "secondassent": "seconder",
    "secondasses": "seconder",
    "secondassiez": "seconder",
    "secondassions": "seconder",
    "seconde": "seconder",
    "secondent": "seconder",
    "secondera": "seconder",
    "seconderai": "seconder",
    "seconderaient": "seconder",
    "seconderais": "seconder",
    "seconderait": "seconder",
    "seconderas": "seconder",
    "seconderez": "seconder",
    "seconderiez": "seconder",
    "seconderions": "seconder",
    "seconderons": "seconder",
    "seconderont": "seconder",
    "secondes": "seconder",
    "secondez": "seconder",
    "secondiez": "seconder",
    "secondions": "seconder",
    "secondons": "seconder",
    "seconds": "second",
    "secondâmes": "seconder",
    "secondât": "seconder",
    "secondâtes": "seconder",
    "secondèrent": "seconder",
    "secondé": "seconder",
    "secondée": "seconder",
    "secondées": "seconder",
    "secondés": "seconder",
    "secoua": "secouer",
    "secouai": "secouer",
    "secouaient": "secouer",
    "secouais": "secouer",
    "secouait": "secouer",
    "secouant": "secouer",
    "secouas": "secouer",
    "secouasse": "secouer",
    "secouassent": "secouer",
    "secouasses": "secouer",
    "secouassiez": "secouer",
    "secouassions": "secouer",
    "secoue": "secouer",
    "secouements": "secouement",
    "secouent": "secouer",
    "secouera": "secouer",
    "secouerai": "secouer",
    "secoueraient": "secouer",
    "secouerais": "secouer",
    "secouerait": "secouer",
    "secoueras": "secouer",
    "secouerez": "secouer",
    "secoueriez": "secouer",
    "secouerions": "secouer",
    "secouerons": "secouer",
    "secoueront": "secouer",
    "secoues": "secouer",
    "secoueurs": "secoueur",
    "secouez": "secouer",
    "secouiez": "secouer",
    "secouions": "secouer",
    "secouons": "secouer",
    "secourables": "secourable",
    "secouraient": "secourir",
    "secourais": "secourir",
    "secourait": "secourir",
    "secourant": "secourir",
    "secoure": "secourir",
    "secourent": "secourir",
    "secoures": "secourir",
    "secourez": "secourir",
    "secouriez": "secourir",
    "secourions": "secourir",
    "secouristes": "secouriste",
    "secourons": "secourir",
    "secourra": "secourir",
    "secourrai": "secourir",
    "secourraient": "secourir",
    "secourrais": "secourir",
    "secourrait": "secourir",
    "secourras": "secourir",
    "secourrez": "secourir",
    "secourriez": "secourir",
    "secourrions": "secourir",
    "secourrons": "secourir",
    "secourront": "secourir",
    "secours": "secourir",
    "secourt": "secourir",
    "secouru": "secourir",
    "secourue": "secourir",
    "secourues": "secourir",
    "secoururent": "secourir",
    "secourus": "secourir",
    "secourusse": "secourir",
    "secourussent": "secourir",
    "secourusses": "secourir",
    "secourussiez": "secourir",
    "secourussions": "secourir",
    "secourut": "secourir",
    "secourûmes": "secourir",
    "secourût": "secourir",
    "secourûtes": "secourir",
    "secousses": "secousse",
    "secouâmes": "secouer",
    "secouât": "secouer",
    "secouâtes": "secouer",
    "secouèrent": "secouer",
    "secoué": "secouer",
    "secouée": "secouer",
    "secouées": "secouer",
    "secoués": "secouer",
    "secrets": "secret",
    "secrète": "secréter",
    "secrètent": "secréter",
    "secrètes": "secréter",
    "secrétaient": "secréter",
    "secrétaires": "secrétaire",
    "secrétariats": "secrétariat",
    "secrété": "secréter",
    "secrétée": "secréter",
    "secs": "sec",
    "sectaires": "sectaire",
    "sectarismes": "sectarisme",
    "sectateurs": "sectateur",
    "sectes": "secte",
    "secteurs": "secteur",
    "sectionna": "sectionner",
    "sectionnai": "sectionner",
    "sectionnaient": "sectionner",
    "sectionnais": "sectionner",
    "sectionnait": "sectionner",
    "sectionnant": "sectionner",
    "sectionnas": "sectionner",
    "sectionnasse": "sectionner",
    "sectionnassent": "sectionner",
    "sectionnasses": "sectionner",
    "sectionnassiez": "sectionner",
    "sectionnassions": "sectionner",
    "sectionne": "sectionner",
    "sectionnent": "sectionner",
    "sectionnera": "sectionner",
    "sectionnerai": "sectionner",
    "sectionneraient": "sectionner",
    "sectionnerais": "sectionner",
    "sectionnerait": "sectionner",
    "sectionneras": "sectionner",
    "sectionnerez": "sectionner",
    "sectionneriez": "sectionner",
    "sectionnerions": "sectionner",
    "sectionnerons": "sectionner",
    "sectionneront": "sectionner",
    "sectionnes": "sectionner",
    "sectionnez": "sectionner",
    "sectionniez": "sectionner",
    "sectionnions": "sectionner",
    "sectionnons": "sectionner",
    "sectionnâmes": "sectionner",
    "sectionnât": "sectionner",
    "sectionnâtes": "sectionner",
    "sectionnèrent": "sectionner",
    "sectionné": "sectionner",
    "sectionnée": "sectionner",
    "sectionnées": "sectionner",
    "sectionnés": "sectionner",
    "sections": "section",
    "sectorielle": "sectoriel",
    "sectorielles": "sectoriel",
    "sectoriels": "sectoriel",
    "sedums": "sedum",
    "segmenta": "segmenter",
    "segmentai": "segmenter",
    "segmentaient": "segmenter",
    "segmentais": "segmenter",
    "segmentait": "segmenter",
    "segmentale": "segmental",
    "segmentant": "segmenter",
    "segmentas": "segmenter",
    "segmentasse": "segmenter",
    "segmentassent": "segmenter",
    "segmentasses": "segmenter",
    "segmentassiez": "segmenter",
    "segmentassions": "segmenter",
    "segmente": "segmenter",
    "segmentent": "segmenter",
    "segmentera": "segmenter",
    "segmenterai": "segmenter",
    "segmenteraient": "segmenter",
    "segmenterais": "segmenter",
    "segmenterait": "segmenter",
    "segmenteras": "segmenter",
    "segmenterez": "segmenter",
    "segmenteriez": "segmenter",
    "segmenterions": "segmenter",
    "segmenterons": "segmenter",
    "segmenteront": "segmenter",
    "segmentes": "segmenter",
    "segmentez": "segmenter",
    "segmentiez": "segmenter",
    "segmentions": "segmenter",
    "segmentons": "segmenter",
    "segments": "segment",
    "segmentâmes": "segmenter",
    "segmentât": "segmenter",
    "segmentâtes": "segmenter",
    "segmentèrent": "segmenter",
    "segmenté": "segmenter",
    "segmentée": "segmenter",
    "segmentées": "segmenter",
    "segmentés": "segmenter",
    "seguedillas": "seguedilla",
    "seiches": "seiche",
    "seigles": "seigle",
    "seigneuriale": "seigneurial",
    "seigneuriales": "seigneurial",
    "seigneuriaux": "seigneurial",
    "seigneuries": "seigneurie",
    "seigneurs": "seigneur",
    "seilles": "seille",
    "seings": "seing",
    "seins": "sein",
    "seizièmes": "seizième",
    "seldjoukides": "seldjoukide",
    "selects": "select",
    "self-controls": "self-control",
    "self-governments": "self-government",
    "self-inductances": "self-inductance",
    "self-inductions": "self-induction",
    "self-services": "self-service",
    "selfs": "self",
    "sellait": "seller",
    "selle": "seller",
    "selleries": "sellerie",
    "selles": "seller",
    "sellettes": "sellette",
    "sellez": "seller",
    "selliers": "sellier",
    "sellé": "seller",
    "sellée": "seller",
    "sellées": "seller",
    "sellés": "seller",
    "sels": "sel",
    "sema": "semer",
    "semai": "semer",
    "semaient": "semer",
    "semailles": "semaille",
    "semaines": "semaine",
    "semainiers": "semainier",
    "semais": "semer",
    "semait": "semer",
    "semant": "semer",
    "semas": "semer",
    "semasse": "semer",
    "semassent": "semer",
    "semasses": "semer",
    "semassiez": "semer",
    "semassions": "semer",
    "sembla": "sembler",
    "semblables": "semblable",
    "semblai": "sembler",
    "semblaient": "sembler",
    "semblais": "sembler",
    "semblait": "sembler",
    "semblant": "sembler",
    "semblants": "semblant",
    "semblas": "sembler",
    "semblasse": "sembler",
    "semblassent": "sembler",
    "semblasses": "sembler",
    "semblassiez": "sembler",
    "semblassions": "sembler",
    "semble": "sembler",
    "semblent": "sembler",
    "semblera": "sembler",
    "semblerai": "sembler",
    "sembleraient": "sembler",
    "semblerais": "sembler",
    "semblerait": "sembler",
    "sembleras": "sembler",
    "semblerez": "sembler",
    "sembleriez": "sembler",
    "semblerions": "sembler",
    "semblerons": "sembler",
    "sembleront": "sembler",
    "sembles": "sembler",
    "semblez": "sembler",
    "sembliez": "sembler",
    "semblions": "sembler",
    "semblons": "sembler",
    "semblâmes": "sembler",
    "semblât": "sembler",
    "semblâtes": "sembler",
    "semblèrent": "sembler",
    "semblé": "sembler",
    "semelles": "semelle",
    "semences": "semence",
    "semenciers": "semencier",
    "semestres": "semestre",
    "semestrialités": "semestrialité",
    "semestrielle": "semestriel",
    "semestrielles": "semestriel",
    "semestriels": "semestriel",
    "semeurs": "semeur",
    "semeuses": "semeur",
    "semez": "semer",
    "semi-arides": "semi-aride",
    "semi-automatiques": "semi-automatique",
    "semi-conducteurs": "semi-conducteur",
    "semi-nomades": "semi-nomade",
    "semi-officielle": "semi-officiel",
    "semi-officielles": "semi-officiel",
    "semi-officiels": "semi-officiel",
    "semi-précieuse": "semi-précieux",
    "semi-précieuses": "semi-précieux",
    "semi-remorques": "semi-remorque",
    "semiez": "semer",
    "semions": "semer",
    "semoirs": "semoir",
    "semonces": "semonce",
    "semoncé": "semoncer",
    "semons": "semer",
    "semonça": "semoncer",
    "semonçait": "semoncer",
    "semonçant": "semoncer",
    "semoules": "semoule",
    "sempiternelle": "sempiternel",
    "sempiternelles": "sempiternel",
    "sempiternels": "sempiternel",
    "semâmes": "semer",
    "semât": "semer",
    "semâtes": "semer",
    "semèrent": "semer",
    "semé": "semer",
    "semée": "semer",
    "semées": "semer",
    "semés": "semer",
    "senestres": "senestre",
    "seniors": "senior",
    "senne": "seine",
    "senneurs": "senneur",
    "sens": "sentir",
    "sensationnelle": "sensationnel",
    "sensationnelles": "sensationnel",
    "sensationnels": "sensationnel",
    "sensations": "sensation",
    "senseurs": "senseur",
    "sensibilisa": "sensibiliser",
    "sensibilisai": "sensibiliser",
    "sensibilisaient": "sensibiliser",
    "sensibilisais": "sensibiliser",
    "sensibilisait": "sensibiliser",
    "sensibilisant": "sensibiliser",
    "sensibilisas": "sensibiliser",
    "sensibilisasse": "sensibiliser",
    "sensibilisassent": "sensibiliser",
    "sensibilisasses": "sensibiliser",
    "sensibilisassiez": "sensibiliser",
    "sensibilisassions": "sensibiliser",
    "sensibilisations": "sensibilisation",
    "sensibilise": "sensibiliser",
    "sensibilisent": "sensibiliser",
    "sensibilisera": "sensibiliser",
    "sensibiliserai": "sensibiliser",
    "sensibiliseraient": "sensibiliser",
    "sensibiliserais": "sensibiliser",
    "sensibiliserait": "sensibiliser",
    "sensibiliseras": "sensibiliser",
    "sensibiliserez": "sensibiliser",
    "sensibiliseriez": "sensibiliser",
    "sensibiliserions": "sensibiliser",
    "sensibiliserons": "sensibiliser",
    "sensibiliseront": "sensibiliser",
    "sensibilises": "sensibiliser",
    "sensibilisez": "sensibiliser",
    "sensibilisiez": "sensibiliser",
    "sensibilisions": "sensibiliser",
    "sensibilisons": "sensibiliser",
    "sensibilisâmes": "sensibiliser",
    "sensibilisât": "sensibiliser",
    "sensibilisâtes": "sensibiliser",
    "sensibilisèrent": "sensibiliser",
    "sensibilisé": "sensibiliser",
    "sensibilisée": "sensibiliser",
    "sensibilisées": "sensibiliser",
    "sensibilisés": "sensibiliser",
    "sensibilitations": "sensibilitation",
    "sensibilités": "sensibilité",
    "sensibleries": "sensiblerie",
    "sensibles": "sensible",
    "sensitifs": "sensitif",
    "sensitive": "sensitif",
    "sensitives": "sensitif",
    "sensorielle": "sensoriel",
    "sensorielles": "sensoriel",
    "sensoriels": "sensoriel",
    "sensualités": "sensualité",
    "sensuelle": "sensuel",
    "sensuelles": "sensuel",
    "sensuels": "sensuel",
    "sensée": "sensé",
    "sensées": "sensé",
    "sensés": "sensé",
    "sent": "sentir",
    "sentaient": "sentir",
    "sentais": "sentir",
    "sentait": "sentir",
    "sentant": "sentir",
    "sente": "sentir",
    "sentences": "sentence",
    "sentencieuse": "sentencieux",
    "sentencieuses": "sentencieux",
    "sentent": "sentir",
    "sentes": "sentir",
    "senteurs": "senteur",
    "sentez": "sentir",
    "senti": "sentir",
    "sentie": "sentir",
    "sentiers": "sentier",
    "senties": "sentir",
    "sentiez": "sentir",
    "sentimentale": "sentimental",
    "sentimentales": "sentimental",
    "sentimentalismes": "sentimentalisme",
    "sentimentalités": "sentimentalité",
    "sentimentaux": "sentimental",
    "sentiments": "sentiment",
    "sentinelles": "sentinelle",
    "sentines": "sentine",
    "sentions": "sentir",
    "sentira": "sentir",
    "sentirai": "sentir",
    "sentiraient": "sentir",
    "sentirais": "sentir",
    "sentirait": "sentir",
    "sentiras": "sentir",
    "sentirent": "sentir",
    "sentirez": "sentir",
    "sentiriez": "sentir",
    "sentirions": "sentir",
    "sentirons": "sentir",
    "sentiront": "sentir",
    "sentis": "sentir",
    "sentisse": "sentir",
    "sentissent": "sentir",
    "sentisses": "sentir",
    "sentissiez": "sentir",
    "sentissions": "sentir",
    "sentit": "sentir",
    "sentons": "sentir",
    "sentîmes": "sentir",
    "sentît": "sentir",
    "sentîtes": "sentir",
    "seps": "sep",
    "septale": "septal",
    "septaux": "septal",
    "septembres": "septembre",
    "septennale": "septennal",
    "septennales": "septennal",
    "septennats": "septennat",
    "septennaux": "septennal",
    "septentrionale": "septentrional",
    "septentrionales": "septentrional",
    "septentrionaux": "septentrional",
    "septentrions": "septentrion",
    "septicismes": "septicisme",
    "septicémies": "septicémie",
    "septiques": "septique",
    "septièmes": "septième",
    "septuagénaires": "septuagénaire",
    "septuagésimes": "septuagésime",
    "septuors": "septuor",
    "septuples": "septuple",
    "sequins": "sequin",
    "sera": "être",
    "serai": "être",
    "seraient": "être",
    "serais": "être",
    "serait": "être",
    "seras": "être",
    "serbes": "serbe",
    "sereine": "serein",
    "sereines": "serein",
    "sereins": "serein",
    "serez": "être",
    "serfouettes": "serfouette",
    "serfoui": "serfouir",
    "serfouie": "serfouir",
    "serfouies": "serfouir",
    "serfouira": "serfouir",
    "serfouirai": "serfouir",
    "serfouiraient": "serfouir",
    "serfouirais": "serfouir",
    "serfouirait": "serfouir",
    "serfouiras": "serfouir",
    "serfouirent": "serfouir",
    "serfouirez": "serfouir",
    "serfouiriez": "serfouir",
    "serfouirions": "serfouir",
    "serfouirons": "serfouir",
    "serfouiront": "serfouir",
    "serfouis": "serfouir",
    "serfouissaient": "serfouir",
    "serfouissais": "serfouir",
    "serfouissait": "serfouir",
    "serfouissant": "serfouir",
    "serfouisse": "serfouir",
    "serfouissent": "serfouir",
    "serfouisses": "serfouir",
    "serfouissez": "serfouir",
    "serfouissiez": "serfouir",
    "serfouissions": "serfouir",
    "serfouissons": "serfouir",
    "serfouit": "serfouir",
    "serfouîmes": "serfouir",
    "serfouît": "serfouir",
    "serfouîtes": "serfouir",
    "serfs": "serf",
    "sergents": "sergent",
    "sergents-chefs": "sergent-chef",
    "sergents-majors": "sergent-major",
    "serges": "serge",
    "sergots": "sergot",
    "seriez": "être",
    "serina": "seriner",
    "serinai": "seriner",
    "serinaient": "seriner",
    "serinais": "seriner",
    "serinait": "seriner",
    "serinant": "seriner",
    "serinas": "seriner",
    "serinasse": "seriner",
    "serinassent": "seriner",
    "serinasses": "seriner",
    "serinassiez": "seriner",
    "serinassions": "seriner",
    "serine": "seriner",
    "serinent": "seriner",
    "serinera": "seriner",
    "serinerai": "seriner",
    "serineraient": "seriner",
    "serinerais": "seriner",
    "serinerait": "seriner",
    "serineras": "seriner",
    "serinerez": "seriner",
    "serineriez": "seriner",
    "serinerions": "seriner",
    "serinerons": "seriner",
    "serineront": "seriner",
    "serines": "seriner",
    "serinettes": "serinette",
    "serinez": "seriner",
    "seringas": "seringa",
    "seringuaient": "seringuer",
    "seringuait": "seringuer",
    "seringueiros": "seringueiro",
    "seringues": "seringue",
    "seringuée": "seringuer",
    "seriniez": "seriner",
    "serinions": "seriner",
    "serinons": "seriner",
    "serins": "serin",
    "serinâmes": "seriner",
    "serinât": "seriner",
    "serinâtes": "seriner",
    "serinèrent": "seriner",
    "seriné": "seriner",
    "serinée": "seriner",
    "serinées": "seriner",
    "serinés": "seriner",
    "serions": "être",
    "serments": "serment",
    "sermonna": "sermonner",
    "sermonnai": "sermonner",
    "sermonnaient": "sermonner",
    "sermonnais": "sermonner",
    "sermonnait": "sermonner",
    "sermonnant": "sermonner",
    "sermonnas": "sermonner",
    "sermonnasse": "sermonner",
    "sermonnassent": "sermonner",
    "sermonnasses": "sermonner",
    "sermonnassiez": "sermonner",
    "sermonnassions": "sermonner",
    "sermonne": "sermonner",
    "sermonnent": "sermonner",
    "sermonnera": "sermonner",
    "sermonnerai": "sermonner",
    "sermonneraient": "sermonner",
    "sermonnerais": "sermonner",
    "sermonnerait": "sermonner",
    "sermonneras": "sermonner",
    "sermonnerez": "sermonner",
    "sermonneriez": "sermonner",
    "sermonnerions": "sermonner",
    "sermonnerons": "sermonner",
    "sermonneront": "sermonner",
    "sermonnes": "sermonner",
    "sermonneurs": "sermonneur",
    "sermonnez": "sermonner",
    "sermonniez": "sermonner",
    "sermonnions": "sermonner",
    "sermonnons": "sermonner",
    "sermonnâmes": "sermonner",
    "sermonnât": "sermonner",
    "sermonnâtes": "sermonner",
    "sermonnèrent": "sermonner",
    "sermonné": "sermonner",
    "sermonnée": "sermonner",
    "sermonnées": "sermonner",
    "sermonnés": "sermonner",
    "sermons": "sermon",
    "serons": "être",
    "seront": "être",
    "serpenta": "serpenter",
    "serpentai": "serpenter",
    "serpentaient": "serpenter",
    "serpentaires": "serpentaire",
    "serpentais": "serpenter",
    "serpentait": "serpenter",
    "serpentant": "serpenter",
    "serpentas": "serpenter",
    "serpentasse": "serpenter",
    "serpentassent": "serpenter",
    "serpentasses": "serpenter",
    "serpentassiez": "serpenter",
    "serpentassions": "serpenter",
    "serpente": "serpenter",
    "serpenteaux": "serpenteau",
    "serpentements": "serpentement",
    "serpentent": "serpenter",
    "serpentera": "serpenter",
    "serpenterai": "serpenter",
    "serpenteraient": "serpenter",
    "serpenterais": "serpenter",
    "serpenterait": "serpenter",
    "serpenteras": "serpenter",
    "serpenterez": "serpenter",
    "serpenteriez": "serpenter",
    "serpenterions": "serpenter",
    "serpenterons": "serpenter",
    "serpenteront": "serpenter",
    "serpentes": "serpenter",
    "serpentez": "serpenter",
    "serpentiez": "serpenter",
    "serpentine": "serpentin",
    "serpentines": "serpentin",
    "serpentins": "serpentin",
    "serpentions": "serpenter",
    "serpentons": "serpenter",
    "serpents": "serpent",
    "serpentâmes": "serpenter",
    "serpentât": "serpenter",
    "serpentâtes": "serpenter",
    "serpentèrent": "serpenter",
    "serpenté": "serpenter",
    "serpes": "serpe",
    "serpillières": "serpillière",
    "serpolets": "serpolet",
    "serra": "serrer",
    "serrai": "serrer",
    "serraient": "serrer",
    "serrais": "serrer",
    "serrait": "serrer",
    "serrant": "serrer",
    "serras": "serrer",
    "serrasse": "serrer",
    "serrassent": "serrer",
    "serrasses": "serrer",
    "serrassiez": "serrer",
    "serrassions": "serrer",
    "serratules": "serratule",
    "serre": "serrer",
    "serre-files": "serre-file",
    "serre-freins": "serre-frein",
    "serre-joints": "serre-joint",
    "serre-têtes": "serre-tête",
    "serrements": "serrement",
    "serrent": "serrer",
    "serrera": "serrer",
    "serrerai": "serrer",
    "serreraient": "serrer",
    "serrerais": "serrer",
    "serrerait": "serrer",
    "serreras": "serrer",
    "serrerez": "serrer",
    "serreriez": "serrer",
    "serrerions": "serrer",
    "serrerons": "serrer",
    "serreront": "serrer",
    "serres": "serrer",
    "serrez": "serrer",
    "serriez": "serrer",
    "serrions": "serrer",
    "serrons": "serrer",
    "serrures": "serrure",
    "serruriers": "serrurier",
    "serrurière": "serrurier",
    "serrâmes": "serrer",
    "serrât": "serrer",
    "serrâtes": "serrer",
    "serrèrent": "serrer",
    "serré": "serrer",
    "serrée": "serrer",
    "serrées": "serrer",
    "serrés": "serrer",
    "sers": "servir",
    "sert": "servir",
    "serti": "sertir",
    "sertie": "sertir",
    "serties": "sertir",
    "sertira": "sertir",
    "sertirai": "sertir",
    "sertiraient": "sertir",
    "sertirais": "sertir",
    "sertirait": "sertir",
    "sertiras": "sertir",
    "sertirent": "sertir",
    "sertirez": "sertir",
    "sertiriez": "sertir",
    "sertirions": "sertir",
    "sertirons": "sertir",
    "sertiront": "sertir",
    "sertis": "sertir",
    "sertissaient": "sertir",
    "sertissais": "sertir",
    "sertissait": "sertir",
    "sertissant": "sertir",
    "sertisse": "sertir",
    "sertissent": "sertir",
    "sertisses": "sertir",
    "sertissez": "sertir",
    "sertissiez": "sertir",
    "sertissions": "sertir",
    "sertissons": "sertir",
    "sertit": "sertir",
    "sertîmes": "sertir",
    "sertît": "sertir",
    "sertîtes": "sertir",
    "servages": "servage",
    "servaient": "servir",
    "servais": "servir",
    "servait": "servir",
    "servals": "serval",
    "servant": "servir",
    "servante": "servant",
    "servantes": "servant",
    "servants": "servant",
    "serve": "servir",
    "servent": "servir",
    "serves": "servir",
    "serveurs": "serveur",
    "serveuse": "serveur",
    "serveuses": "serveur",
    "servez": "servir",
    "servi": "servir",
    "serviables": "serviable",
    "services": "service",
    "servie": "servir",
    "servies": "servir",
    "serviettes": "serviette",
    "serviettes-éponges": "serviette-éponge",
    "serviez": "servir",
    "serviles": "servile",
    "servilités": "servilité",
    "servions": "servir",
    "servira": "servir",
    "servirai": "servir",
    "serviraient": "servir",
    "servirais": "servir",
    "servirait": "servir",
    "serviras": "servir",
    "servirent": "servir",
    "servirez": "servir",
    "serviriez": "servir",
    "servirions": "servir",
    "servirons": "servir",
    "serviront": "servir",
    "servis": "servir",
    "servisse": "servir",
    "servissent": "servir",
    "servisses": "servir",
    "servissiez": "servir",
    "servissions": "servir",
    "servit": "servir",
    "serviteurs": "serviteur",
    "servitudes": "servitude",
    "servofreins": "servofrein",
    "servomoteurs": "servomoteur",
    "servons": "servir",
    "servîmes": "servir",
    "servît": "servir",
    "servîtes": "servir",
    "ses": "son",
    "sessions": "session",
    "sesterces": "sesterce",
    "setiers": "setier",
    "sets": "set",
    "setters": "setter",
    "seuils": "seuil",
    "seulabres": "seulabre",
    "seule": "seul",
    "seules": "seul",
    "seulette": "seulet",
    "seulettes": "seulet",
    "seuls": "seul",
    "sevra": "sevrer",
    "sevrages": "sevrage",
    "sevrai": "sevrer",
    "sevraient": "sevrer",
    "sevrais": "sevrer",
    "sevrait": "sevrer",
    "sevrant": "sevrer",
    "sevras": "sevrer",
    "sevrasse": "sevrer",
    "sevrassent": "sevrer",
    "sevrasses": "sevrer",
    "sevrassiez": "sevrer",
    "sevrassions": "sevrer",
    "sevrez": "sevrer",
    "sevriez": "sevrer",
    "sevrions": "sevrer",
    "sevrons": "sevrer",
    "sevrâmes": "sevrer",
    "sevrât": "sevrer",
    "sevrâtes": "sevrer",
    "sevrèrent": "sevrer",
    "sevré": "sevrer",
    "sevrée": "sevrer",
    "sevrées": "sevrer",
    "sevrés": "sevrer",
    "sex appeal": "sex-appeal",
    "sex shop": "sex-shop",
    "sex shops": "sex-shop",
    "sex-appeals": "sex-appeal",
    "sex-shops": "sex-shop",
    "sexagénaires": "sexagénaire",
    "sexagésimes": "sexagésime",
    "sexes": "sexe",
    "sexistes": "sexiste",
    "sexologies": "sexologie",
    "sexologues": "sexologue",
    "sextants": "sextant",
    "sextile": "sextil",
    "sextuors": "sextuor",
    "sextuples": "sextuple",
    "sextuplée": "sextuplé",
    "sextuplées": "sextuplé",
    "sextuplés": "sextuplé",
    "sexualisé": "sexualiser",
    "sexualités": "sexualité",
    "sexuelle": "sexuel",
    "sexuelles": "sexuel",
    "sexuels": "sexuel",
    "sexués": "sexué",
    "seyaient": "seoir",
    "seyait": "seoir",
    "seyant": "seoir",
    "seyante": "seyant",
    "seyantes": "seyant",
    "seyants": "seyant",
    "shahs": "shah",
    "shakers": "shaker",
    "shakespearienne": "shakespearien",
    "shakespeariennes": "shakespearien",
    "shakespeariens": "shakespearien",
    "shakos": "shako",
    "shamans": "shaman",
    "shampoings": "shampoing",
    "shampooings": "shampooing",
    "shampouina": "shampouiner",
    "shampouinai": "shampouiner",
    "shampouinaient": "shampouiner",
    "shampouinais": "shampouiner",
    "shampouinait": "shampouiner",
    "shampouinant": "shampouiner",
    "shampouinas": "shampouiner",
    "shampouinasse": "shampouiner",
    "shampouinassent": "shampouiner",
    "shampouinasses": "shampouiner",
    "shampouinassiez": "shampouiner",
    "shampouinassions": "shampouiner",
    "shampouine": "shampouiner",
    "shampouinent": "shampouiner",
    "shampouinera": "shampouiner",
    "shampouinerai": "shampouiner",
    "shampouineraient": "shampouiner",
    "shampouinerais": "shampouiner",
    "shampouinerait": "shampouiner",
    "shampouineras": "shampouiner",
    "shampouinerez": "shampouiner",
    "shampouineriez": "shampouiner",
    "shampouinerions": "shampouiner",
    "shampouinerons": "shampouiner",
    "shampouineront": "shampouiner",
    "shampouines": "shampouiner",
    "shampouineurs": "shampouineur",
    "shampouineuse": "shampouineur",
    "shampouineuses": "shampouineur",
    "shampouinez": "shampouiner",
    "shampouiniez": "shampouiner",
    "shampouinions": "shampouiner",
    "shampouinons": "shampouiner",
    "shampouinâmes": "shampouiner",
    "shampouinât": "shampouiner",
    "shampouinâtes": "shampouiner",
    "shampouinèrent": "shampouiner",
    "shampouiné": "shampouiner",
    "shampouinée": "shampouiner",
    "shampouinées": "shampouiner",
    "shampouinés": "shampouiner",
    "shanghaiens": "shanghaien",
    "shantungs": "shantung",
    "shekels": "shekel",
    "sherpas": "sherpa",
    "shetlands": "shetland",
    "shillings": "shilling",
    "shimmys": "shimmy",
    "shintoïsmes": "shintoïsme",
    "shippings": "shipping",
    "shirtings": "shirting",
    "shogouns": "shogoun",
    "shogunale": "shogunal",
    "shoguns": "shogun",
    "shoota": "shooter",
    "shootai": "shooter",
    "shootaient": "shooter",
    "shootais": "shooter",
    "shootait": "shooter",
    "shootant": "shooter",
    "shootas": "shooter",
    "shootasse": "shooter",
    "shootassent": "shooter",
    "shootasses": "shooter",
    "shootassiez": "shooter",
    "shootassions": "shooter",
    "shoote": "shooter",
    "shootent": "shooter",
    "shootera": "shooter",
    "shooterai": "shooter",
    "shooteraient": "shooter",
    "shooterais": "shooter",
    "shooterait": "shooter",
    "shooteras": "shooter",
    "shooterez": "shooter",
    "shooteriez": "shooter",
    "shooterions": "shooter",
    "shooterons": "shooter",
    "shooteront": "shooter",
    "shootes": "shooter",
    "shooteuse": "shooteur",
    "shootez": "shooter",
    "shootiez": "shooter",
    "shootions": "shooter",
    "shootons": "shooter",
    "shoots": "shoot",
    "shootâmes": "shooter",
    "shootât": "shooter",
    "shootâtes": "shooter",
    "shootèrent": "shooter",
    "shooté": "shooter",
    "shootée": "shooter",
    "shootées": "shooter",
    "shootés": "shooter",
    "shoppings": "shopping",
    "shorts": "short",
    "shoshones": "shoshone",
    "shows": "show",
    "shrapnells": "shrapnell",
    "shrapnels": "shrapnel",
    "shunte": "shunter",
    "shunts": "shunt",
    "shérifs": "shérif",
    "sials": "sial",
    "siamoise": "siamois",
    "siamoises": "siamois",
    "sibilante": "sibilant",
    "sibilantes": "sibilant",
    "sibilants": "sibilant",
    "sibylles": "sibylle",
    "sibylline": "sibyllin",
    "sibyllines": "sibyllin",
    "sibyllins": "sibyllin",
    "sibérienne": "sibérien",
    "sibériennes": "sibérien",
    "sibériens": "sibérien",
    "sicaires": "sicaire",
    "siccités": "siccité",
    "sicilienne": "sicilien",
    "siciliennes": "sicilien",
    "siciliens": "sicilien",
    "sidas": "sida",
    "side-cars": "side-car",
    "sidis": "sidi",
    "sidère": "sidérer",
    "sidèrent": "sidérer",
    "sidères": "sidérer",
    "sidéenne": "sidéen",
    "sidéens": "sidéen",
    "sidéra": "sidérer",
    "sidérai": "sidérer",
    "sidéraient": "sidérer",
    "sidérais": "sidérer",
    "sidérait": "sidérer",
    "sidérale": "sidéral",
    "sidérales": "sidéral",
    "sidérant": "sidérer",
    "sidérante": "sidérant",
    "sidéras": "sidérer",
    "sidérasse": "sidérer",
    "sidérassent": "sidérer",
    "sidérasses": "sidérer",
    "sidérassiez": "sidérer",
    "sidérassions": "sidérer",
    "sidéraux": "sidéral",
    "sidérera": "sidérer",
    "sidérerai": "sidérer",
    "sidéreraient": "sidérer",
    "sidérerais": "sidérer",
    "sidérerait": "sidérer",
    "sidéreras": "sidérer",
    "sidérerez": "sidérer",
    "sidéreriez": "sidérer",
    "sidérerions": "sidérer",
    "sidérerons": "sidérer",
    "sidéreront": "sidérer",
    "sidérez": "sidérer",
    "sidériez": "sidérer",
    "sidérions": "sidérer",
    "sidérons": "sidérer",
    "sidéroses": "sidérose",
    "sidérurgies": "sidérurgie",
    "sidérurgiques": "sidérurgique",
    "sidérurgistes": "sidérurgiste",
    "sidérâmes": "sidérer",
    "sidérât": "sidérer",
    "sidérâtes": "sidérer",
    "sidérèrent": "sidérer",
    "sidéré": "sidérer",
    "sidérée": "sidérer",
    "sidérées": "sidérer",
    "sidérés": "sidérer",
    "sied": "seoir",
    "sienne": "sien",
    "siennes": "sien",
    "siennoise": "siennois",
    "siennoises": "siennois",
    "siens": "sien",
    "sierras": "sierra",
    "siesta": "siester",
    "siestant": "siester",
    "siestes": "sieste",
    "sieurs": "sieur",
    "siffla": "siffler",
    "sifflai": "siffler",
    "sifflaient": "siffler",
    "sifflais": "siffler",
    "sifflait": "siffler",
    "sifflant": "siffler",
    "sifflante": "sifflant",
    "sifflantes": "sifflant",
    "sifflants": "sifflant",
    "sifflas": "siffler",
    "sifflasse": "siffler",
    "sifflassent": "siffler",
    "sifflasses": "siffler",
    "sifflassiez": "siffler",
    "sifflassions": "siffler",
    "siffle": "siffler",
    "sifflements": "sifflement",
    "sifflent": "siffler",
    "sifflera": "siffler",
    "sifflerai": "siffler",
    "siffleraient": "siffler",
    "sifflerais": "siffler",
    "sifflerait": "siffler",
    "siffleras": "siffler",
    "sifflerez": "siffler",
    "siffleriez": "siffler",
    "sifflerions": "siffler",
    "sifflerons": "siffler",
    "siffleront": "siffler",
    "siffles": "siffler",
    "sifflets": "sifflet",
    "sifflez": "siffler",
    "siffliez": "siffler",
    "sifflions": "siffler",
    "sifflons": "siffler",
    "sifflota": "siffloter",
    "sifflotai": "siffloter",
    "sifflotaient": "siffloter",
    "sifflotais": "siffloter",
    "sifflotait": "siffloter",
    "sifflotant": "siffloter",
    "sifflotas": "siffloter",
    "sifflotasse": "siffloter",
    "sifflotassent": "siffloter",
    "sifflotasses": "siffloter",
    "sifflotassiez": "siffloter",
    "sifflotassions": "siffloter",
    "sifflote": "siffloter",
    "sifflotent": "siffloter",
    "sifflotera": "siffloter",
    "siffloterai": "siffloter",
    "siffloteraient": "siffloter",
    "siffloterais": "siffloter",
    "siffloterait": "siffloter",
    "siffloteras": "siffloter",
    "siffloterez": "siffloter",
    "siffloteriez": "siffloter",
    "siffloterions": "siffloter",
    "siffloterons": "siffloter",
    "siffloteront": "siffloter",
    "sifflotes": "siffloter",
    "sifflotez": "siffloter",
    "sifflotiez": "siffloter",
    "sifflotions": "siffloter",
    "sifflotons": "siffloter",
    "sifflotâmes": "siffloter",
    "sifflotât": "siffloter",
    "sifflotâtes": "siffloter",
    "sifflotèrent": "siffloter",
    "siffloté": "siffloter",
    "sifflotée": "siffloter",
    "sifflotées": "siffloter",
    "sifflotés": "siffloter",
    "sifflâmes": "siffler",
    "sifflât": "siffler",
    "sifflâtes": "siffler",
    "sifflèrent": "siffler",
    "sifflé": "siffler",
    "sifflée": "siffler",
    "sifflées": "siffler",
    "sifflés": "siffler",
    "sigillographies": "sigillographie",
    "sigillée": "sigillé",
    "sigisbées": "sigisbée",
    "siglaisons": "siglaison",
    "sigles": "sigle",
    "sigmas": "sigma",
    "sigmoïdes": "sigmoïde",
    "signa": "signer",
    "signai": "signer",
    "signaient": "signer",
    "signais": "signer",
    "signait": "signer",
    "signala": "signaler",
    "signalai": "signaler",
    "signalaient": "signaler",
    "signalais": "signaler",
    "signalait": "signaler",
    "signalant": "signaler",
    "signalas": "signaler",
    "signalasse": "signaler",
    "signalassent": "signaler",
    "signalasses": "signaler",
    "signalassiez": "signaler",
    "signalassions": "signaler",
    "signale": "signaler",
    "signalements": "signalement",
    "signalent": "signaler",
    "signalera": "signaler",
    "signalerai": "signaler",
    "signaleraient": "signaler",
    "signalerais": "signaler",
    "signalerait": "signaler",
    "signaleras": "signaler",
    "signalerez": "signaler",
    "signaleriez": "signaler",
    "signalerions": "signaler",
    "signalerons": "signaler",
    "signaleront": "signaler",
    "signales": "signaler",
    "signaleurs": "signaleur",
    "signalez": "signaler",
    "signaliez": "signaler",
    "signalions": "signaler",
    "signalisa": "signaliser",
    "signalisai": "signaliser",
    "signalisaient": "signaliser",
    "signalisais": "signaliser",
    "signalisait": "signaliser",
    "signalisant": "signaliser",
    "signalisas": "signaliser",
    "signalisasse": "signaliser",
    "signalisassent": "signaliser",
    "signalisasses": "signaliser",
    "signalisassiez": "signaliser",
    "signalisassions": "signaliser",
    "signalisations": "signalisation",
    "signalise": "signaliser",
    "signalisent": "signaliser",
    "signalisera": "signaliser",
    "signaliserai": "signaliser",
    "signaliseraient": "signaliser",
    "signaliserais": "signaliser",
    "signaliserait": "signaliser",
    "signaliseras": "signaliser",
    "signaliserez": "signaliser",
    "signaliseriez": "signaliser",
    "signaliserions": "signaliser",
    "signaliserons": "signaliser",
    "signaliseront": "signaliser",
    "signalises": "signaliser",
    "signalisez": "signaliser",
    "signalisiez": "signaliser",
    "signalisions": "signaliser",
    "signalisons": "signaliser",
    "signalisâmes": "signaliser",
    "signalisât": "signaliser",
    "signalisâtes": "signaliser",
    "signalisèrent": "signaliser",
    "signalisé": "signaliser",
    "signalisée": "signaliser",
    "signalisées": "signaliser",
    "signalisés": "signaliser",
    "signalons": "signaler",
    "signalâmes": "signaler",
    "signalât": "signaler",
    "signalâtes": "signaler",
    "signalèrent": "signaler",
    "signalé": "signaler",
    "signalée": "signaler",
    "signalées": "signaler",
    "signalés": "signaler",
    "signalétiques": "signalétique",
    "signant": "signer",
    "signas": "signer",
    "signasse": "signer",
    "signassent": "signer",
    "signasses": "signer",
    "signassiez": "signer",
    "signassions": "signer",
    "signataires": "signataire",
    "signatures": "signature",
    "signaux": "signal",
    "signe": "signer",
    "signent": "signer",
    "signera": "signer",
    "signerai": "signer",
    "signeraient": "signer",
    "signerais": "signer",
    "signerait": "signer",
    "signeras": "signer",
    "signerez": "signer",
    "signeriez": "signer",
    "signerions": "signer",
    "signerons": "signer",
    "signeront": "signer",
    "signes": "signer",
    "signets": "signet",
    "signez": "signer",
    "signiez": "signer",
    "signifia": "signifier",
    "signifiai": "signifier",
    "signifiaient": "signifier",
    "signifiais": "signifier",
    "signifiait": "signifier",
    "signifiant": "signifier",
    "signifiante": "signifiant",
    "signifiantes": "signifiant",
    "signifiants": "signifiant",
    "signifias": "signifier",
    "signifiasse": "signifier",
    "signifiassent": "signifier",
    "signifiasses": "signifier",
    "signifiassiez": "signifier",
    "signifiassions": "signifier",
    "significatifs": "significatif",
    "significations": "signification",
    "significative": "significatif",
    "significatives": "significatif",
    "signifie": "signifier",
    "signifient": "signifier",
    "signifiera": "signifier",
    "signifierai": "signifier",
    "signifieraient": "signifier",
    "signifierais": "signifier",
    "signifierait": "signifier",
    "signifieras": "signifier",
    "signifierez": "signifier",
    "signifieriez": "signifier",
    "signifierions": "signifier",
    "signifierons": "signifier",
    "signifieront": "signifier",
    "signifies": "signifier",
    "signifiez": "signifier",
    "signifiiez": "signifier",
    "signifiions": "signifier",
    "signifions": "signifier",
    "signifiâmes": "signifier",
    "signifiât": "signifier",
    "signifiâtes": "signifier",
    "signifièrent": "signifier",
    "signifié": "signifier",
    "signifiée": "signifier",
    "signifiées": "signifier",
    "signifiés": "signifier",
    "signions": "signer",
    "signons": "signer",
    "signora": "signor",
    "signâmes": "signer",
    "signât": "signer",
    "signâtes": "signer",
    "signèrent": "signer",
    "signé": "signer",
    "signée": "signer",
    "signées": "signer",
    "signés": "signer",
    "sihanoukistes": "sihanoukiste",
    "sikhs": "sikh",
    "silences": "silence",
    "silencieuse": "silencieux",
    "silencieuses": "silencieux",
    "silhouettait": "silhouetter",
    "silhouettant": "silhouetter",
    "silhouette": "silhouetter",
    "silhouettent": "silhouetter",
    "silhouettes": "silhouette",
    "silhouetté": "silhouetter",
    "silhouettée": "silhouetter",
    "silices": "silice",
    "siliceuse": "siliceux",
    "siliciums": "silicium",
    "siliconé": "siliconer",
    "siliconée": "siliconer",
    "siliconées": "siliconer",
    "silicosée": "silicosé",
    "sillages": "sillage",
    "sillonna": "sillonner",
    "sillonnai": "sillonner",
    "sillonnaient": "sillonner",
    "sillonnais": "sillonner",
    "sillonnait": "sillonner",
    "sillonnant": "sillonner",
    "sillonnas": "sillonner",
    "sillonnasse": "sillonner",
    "sillonnassent": "sillonner",
    "sillonnasses": "sillonner",
    "sillonnassiez": "sillonner",
    "sillonnassions": "sillonner",
    "sillonne": "sillonner",
    "sillonnent": "sillonner",
    "sillonnera": "sillonner",
    "sillonnerai": "sillonner",
    "sillonneraient": "sillonner",
    "sillonnerais": "sillonner",
    "sillonnerait": "sillonner",
    "sillonneras": "sillonner",
    "sillonnerez": "sillonner",
    "sillonneriez": "sillonner",
    "sillonnerions": "sillonner",
    "sillonnerons": "sillonner",
    "sillonneront": "sillonner",
    "sillonnes": "sillonner",
    "sillonnez": "sillonner",
    "sillonniez": "sillonner",
    "sillonnions": "sillonner",
    "sillonnons": "sillonner",
    "sillonnâmes": "sillonner",
    "sillonnât": "sillonner",
    "sillonnâtes": "sillonner",
    "sillonnèrent": "sillonner",
    "sillonné": "sillonner",
    "sillonnée": "sillonner",
    "sillonnées": "sillonner",
    "sillonnés": "sillonner",
    "sillons": "sillon",
    "silos": "silo",
    "silotages": "silotage",
    "sils": "sil",
    "silènes": "silène",
    "simagrées": "simagrée",
    "simarres": "simarre",
    "simazines": "simazine",
    "simbleaux": "simbleau",
    "simienne": "simien",
    "simiens": "simien",
    "simiesques": "simiesque",
    "similaires": "similaire",
    "similarités": "similarité",
    "similicuirs": "similicuir",
    "similis": "simili",
    "similitudes": "similitude",
    "similors": "similor",
    "simonies": "simonie",
    "simouns": "simoun",
    "simples": "simple",
    "simplets": "simplet",
    "simplette": "simplet",
    "simplettes": "simplet",
    "simplicités": "simplicité",
    "simplifia": "simplifier",
    "simplifiai": "simplifier",
    "simplifiaient": "simplifier",
    "simplifiais": "simplifier",
    "simplifiait": "simplifier",
    "simplifiant": "simplifier",
    "simplifias": "simplifier",
    "simplifiasse": "simplifier",
    "simplifiassent": "simplifier",
    "simplifiasses": "simplifier",
    "simplifiassiez": "simplifier",
    "simplifiassions": "simplifier",
    "simplifications": "simplification",
    "simplifie": "simplifier",
    "simplifient": "simplifier",
    "simplifiera": "simplifier",
    "simplifierai": "simplifier",
    "simplifieraient": "simplifier",
    "simplifierais": "simplifier",
    "simplifierait": "simplifier",
    "simplifieras": "simplifier",
    "simplifierez": "simplifier",
    "simplifieriez": "simplifier",
    "simplifierions": "simplifier",
    "simplifierons": "simplifier",
    "simplifieront": "simplifier",
    "simplifies": "simplifier",
    "simplifiez": "simplifier",
    "simplifiiez": "simplifier",
    "simplifiions": "simplifier",
    "simplifions": "simplifier",
    "simplifiâmes": "simplifier",
    "simplifiât": "simplifier",
    "simplifiâtes": "simplifier",
    "simplifièrent": "simplifier",
    "simplifié": "simplifier",
    "simplifiée": "simplifier",
    "simplifiées": "simplifier",
    "simplifiés": "simplifier",
    "simplistes": "simpliste",
    "simula": "simuler",
    "simulacres": "simulacre",
    "simulai": "simuler",
    "simulaient": "simuler",
    "simulais": "simuler",
    "simulait": "simuler",
    "simulant": "simuler",
    "simulas": "simuler",
    "simulasse": "simuler",
    "simulassent": "simuler",
    "simulasses": "simuler",
    "simulassiez": "simuler",
    "simulassions": "simuler",
    "simulateurs": "simulateur",
    "simulations": "simulation",
    "simulatrice": "simulateur",
    "simulatrices": "simulateur",
    "simule": "simuler",
    "simulent": "simuler",
    "simulera": "simuler",
    "simulerai": "simuler",
    "simuleraient": "simuler",
    "simulerais": "simuler",
    "simulerait": "simuler",
    "simuleras": "simuler",
    "simulerez": "simuler",
    "simuleriez": "simuler",
    "simulerions": "simuler",
    "simulerons": "simuler",
    "simuleront": "simuler",
    "simules": "simuler",
    "simulez": "simuler",
    "simuliez": "simuler",
    "simulions": "simuler",
    "simulons": "simuler",
    "simultanée": "simultané",
    "simultanées": "simultané",
    "simultanés": "simultané",
    "simulâmes": "simuler",
    "simulât": "simuler",
    "simulâtes": "simuler",
    "simulèrent": "simuler",
    "simulé": "simuler",
    "simulée": "simuler",
    "simulées": "simuler",
    "simulés": "simuler",
    "sinapismes": "sinapisme",
    "sincères": "sincère",
    "sincérités": "sincérité",
    "singe": "singer",
    "singea": "singer",
    "singeai": "singer",
    "singeaient": "singer",
    "singeais": "singer",
    "singeait": "singer",
    "singeant": "singer",
    "singeas": "singer",
    "singeasse": "singer",
    "singeassent": "singer",
    "singeasses": "singer",
    "singeassiez": "singer",
    "singeassions": "singer",
    "singent": "singer",
    "singeons": "singer",
    "singera": "singer",
    "singerai": "singer",
    "singeraient": "singer",
    "singerais": "singer",
    "singerait": "singer",
    "singeras": "singer",
    "singerez": "singer",
    "singeries": "singerie",
    "singeriez": "singer",
    "singerions": "singer",
    "singerons": "singer",
    "singeront": "singer",
    "singes": "singer",
    "singez": "singer",
    "singeâmes": "singer",
    "singeât": "singer",
    "singeâtes": "singer",
    "singiez": "singer",
    "singions": "singer",
    "singles": "single",
    "singletons": "singleton",
    "singularisait": "singulariser",
    "singularise": "singulariser",
    "singularises": "singulariser",
    "singularités": "singularité",
    "singuliers": "singulier",
    "singulière": "singulier",
    "singulières": "singulier",
    "singèrent": "singer",
    "singé": "singer",
    "singée": "singer",
    "singées": "singer",
    "singés": "singer",
    "sinisa": "siniser",
    "sinisai": "siniser",
    "sinisaient": "siniser",
    "sinisais": "siniser",
    "sinisait": "siniser",
    "sinisant": "siniser",
    "sinisas": "siniser",
    "sinisasse": "siniser",
    "sinisassent": "siniser",
    "sinisasses": "siniser",
    "sinisassiez": "siniser",
    "sinisassions": "siniser",
    "sinise": "siniser",
    "sinisent": "siniser",
    "sinisera": "siniser",
    "siniserai": "siniser",
    "siniseraient": "siniser",
    "siniserais": "siniser",
    "siniserait": "siniser",
    "siniseras": "siniser",
    "siniserez": "siniser",
    "siniseriez": "siniser",
    "siniserions": "siniser",
    "siniserons": "siniser",
    "siniseront": "siniser",
    "sinises": "siniser",
    "sinisez": "siniser",
    "sinisiez": "siniser",
    "sinisions": "siniser",
    "sinisons": "siniser",
    "sinistres": "sinistre",
    "sinistrée": "sinistré",
    "sinistrées": "sinistré",
    "sinistrés": "sinistré",
    "sinisâmes": "siniser",
    "sinisât": "siniser",
    "sinisâtes": "siniser",
    "sinisèrent": "siniser",
    "sinisé": "siniser",
    "sinisée": "siniser",
    "sinisées": "siniser",
    "sinisés": "siniser",
    "sino-japonaise": "sino-japonais",
    "sinologues": "sinologue",
    "sinoples": "sinople",
    "sinoques": "sinoque",
    "sinuaient": "sinuer",
    "sinuait": "sinuer",
    "sinuant": "sinuer",
    "sinue": "sinuer",
    "sinuent": "sinuer",
    "sinueuse": "sinueux",
    "sinueuses": "sinueux",
    "sinuosités": "sinuosité",
    "sinusale": "sinusal",
    "sinusites": "sinusite",
    "sinusoïdale": "sinusoïdal",
    "sinusoïdales": "sinusoïdal",
    "sinusoïdaux": "sinusoïdal",
    "sinusoïdes": "sinusoïde",
    "sinué": "sinuer",
    "sinécures": "sinécure",
    "sionismes": "sionisme",
    "sionistes": "sioniste",
    "siphonna": "siphonner",
    "siphonnai": "siphonner",
    "siphonnaient": "siphonner",
    "siphonnais": "siphonner",
    "siphonnait": "siphonner",
    "siphonnant": "siphonner",
    "siphonnas": "siphonner",
    "siphonnasse": "siphonner",
    "siphonnassent": "siphonner",
    "siphonnasses": "siphonner",
    "siphonnassiez": "siphonner",
    "siphonnassions": "siphonner",
    "siphonne": "siphonner",
    "siphonnent": "siphonner",
    "siphonnera": "siphonner",
    "siphonnerai": "siphonner",
    "siphonneraient": "siphonner",
    "siphonnerais": "siphonner",
    "siphonnerait": "siphonner",
    "siphonneras": "siphonner",
    "siphonnerez": "siphonner",
    "siphonneriez": "siphonner",
    "siphonnerions": "siphonner",
    "siphonnerons": "siphonner",
    "siphonneront": "siphonner",
    "siphonnes": "siphonner",
    "siphonnez": "siphonner",
    "siphonniez": "siphonner",
    "siphonnions": "siphonner",
    "siphonnons": "siphonner",
    "siphonnâmes": "siphonner",
    "siphonnât": "siphonner",
    "siphonnâtes": "siphonner",
    "siphonnèrent": "siphonner",
    "siphonné": "siphonner",
    "siphonnée": "siphonner",
    "siphonnées": "siphonner",
    "siphonnés": "siphonner",
    "siphons": "siphon",
    "sires": "sire",
    "siroccos": "sirocco",
    "sirops": "sirop",
    "sirota": "siroter",
    "sirotai": "siroter",
    "sirotaient": "siroter",
    "sirotais": "siroter",
    "sirotait": "siroter",
    "sirotant": "siroter",
    "sirotas": "siroter",
    "sirotasse": "siroter",
    "sirotassent": "siroter",
    "sirotasses": "siroter",
    "sirotassiez": "siroter",
    "sirotassions": "siroter",
    "sirote": "siroter",
    "sirotent": "siroter",
    "sirotera": "siroter",
    "siroterai": "siroter",
    "siroteraient": "siroter",
    "siroterais": "siroter",
    "siroterait": "siroter",
    "siroteras": "siroter",
    "siroterez": "siroter",
    "siroteriez": "siroter",
    "siroterions": "siroter",
    "siroterons": "siroter",
    "siroteront": "siroter",
    "sirotes": "siroter",
    "sirotez": "siroter",
    "sirotiez": "siroter",
    "sirotions": "siroter",
    "sirotons": "siroter",
    "sirotâmes": "siroter",
    "sirotât": "siroter",
    "sirotâtes": "siroter",
    "sirotèrent": "siroter",
    "siroté": "siroter",
    "sirotée": "siroter",
    "sirotées": "siroter",
    "sirotés": "siroter",
    "sirupeuse": "sirupeux",
    "sirupeuses": "sirupeux",
    "sirènes": "sirène",
    "sisals": "sisal",
    "sise": "sis",
    "sises": "sis",
    "sismale": "sismal",
    "sismales": "sismal",
    "sismaux": "sismal",
    "sismicités": "sismicité",
    "sismiques": "sismique",
    "sismographes": "sismographe",
    "sismologies": "sismologie",
    "sismologues": "sismologue",
    "sister-ships": "sister-ship",
    "sistres": "sistre",
    "sitautions": "sitaution",
    "sitcoms": "sitcom",
    "sites": "site",
    "situa": "situer",
    "situai": "situer",
    "situaient": "situer",
    "situais": "situer",
    "situait": "situer",
    "situant": "situer",
    "situas": "situer",
    "situasse": "situer",
    "situassent": "situer",
    "situasses": "situer",
    "situassiez": "situer",
    "situassions": "situer",
    "situationnistes": "situationniste",
    "situations": "situation",
    "situe": "situer",
    "situent": "situer",
    "situera": "situer",
    "situerai": "situer",
    "situeraient": "situer",
    "situerais": "situer",
    "situerait": "situer",
    "situeras": "situer",
    "situerez": "situer",
    "situeriez": "situer",
    "situerions": "situer",
    "situerons": "situer",
    "situeront": "situer",
    "situes": "situer",
    "situez": "situer",
    "situiez": "situer",
    "situions": "situer",
    "situons": "situer",
    "situâmes": "situer",
    "situât": "situer",
    "situâtes": "situer",
    "situèrent": "situer",
    "situé": "situer",
    "située": "situer",
    "situées": "situer",
    "situés": "situer",
    "siutations": "siutation",
    "sixains": "sixain",
    "sixièmes": "sixième",
    "sixtes": "sixte",
    "sizains": "sizain",
    "siècles": "siècle",
    "siège": "siéger",
    "siègent": "siéger",
    "sièges": "siéger",
    "siée": "seoir",
    "siéent": "seoir",
    "siégea": "siéger",
    "siégeai": "siéger",
    "siégeaient": "siéger",
    "siégeais": "siéger",
    "siégeait": "siéger",
    "siégeant": "siéger",
    "siégeas": "siéger",
    "siégeasse": "siéger",
    "siégeassent": "siéger",
    "siégeasses": "siéger",
    "siégeassiez": "siéger",
    "siégeassions": "siéger",
    "siégeons": "siéger",
    "siégera": "siéger",
    "siégerai": "siéger",
    "siégeraient": "siéger",
    "siégerais": "siéger",
    "siégerait": "siéger",
    "siégeras": "siéger",
    "siégerez": "siéger",
    "siégeriez": "siéger",
    "siégerions": "siéger",
    "siégerons": "siéger",
    "siégeront": "siéger",
    "siégez": "siéger",
    "siégeâmes": "siéger",
    "siégeât": "siéger",
    "siégeâtes": "siéger",
    "siégiez": "siéger",
    "siégions": "siéger",
    "siégèrent": "siéger",
    "siégé": "siéger",
    "siéra": "seoir",
    "siéraient": "seoir",
    "siérait": "seoir",
    "siéront": "seoir",
    "skateboards": "skateboard",
    "skates": "skate",
    "skatings": "skating",
    "skaïs": "skaï",
    "skeets": "skeet",
    "sketches": "sketch",
    "sketchs": "sketch",
    "skia": "skier",
    "skiables": "skiable",
    "skiai": "skier",
    "skiaient": "skier",
    "skiais": "skier",
    "skiait": "skier",
    "skiant": "skier",
    "skias": "skier",
    "skiasse": "skier",
    "skiassent": "skier",
    "skiasses": "skier",
    "skiassiez": "skier",
    "skiassions": "skier",
    "skie": "skier",
    "skient": "skier",
    "skiera": "skier",
    "skierai": "skier",
    "skieraient": "skier",
    "skierais": "skier",
    "skierait": "skier",
    "skieras": "skier",
    "skierez": "skier",
    "skieriez": "skier",
    "skierions": "skier",
    "skierons": "skier",
    "skieront": "skier",
    "skies": "skier",
    "skieurs": "skieur",
    "skieuse": "skieur",
    "skieuses": "skieur",
    "skiez": "skier",
    "skiffs": "skiff",
    "skiiez": "skier",
    "skiions": "skier",
    "skinheads": "skinhead",
    "skins": "skin",
    "skions": "skier",
    "skippers": "skipper",
    "skips": "skip",
    "skis": "ski",
    "skiâmes": "skier",
    "skiât": "skier",
    "skiâtes": "skier",
    "skièrent": "skier",
    "skié": "skier",
    "skiée": "skier",
    "skiées": "skier",
    "skiés": "skier",
    "skye-terriers": "skye-terrier",
    "slalomant": "slalomer",
    "slaloms": "slalom",
    "slalomé": "slalomer",
    "slaves": "slave",
    "slavisant": "slaviser",
    "slavophiles": "slavophile",
    "sleepings": "sleeping",
    "slikkes": "slikke",
    "slips": "slip",
    "slogans": "slogan",
    "sloops": "sloop",
    "sloughis": "sloughi",
    "slovaques": "slovaque",
    "slovènes": "slovène",
    "slows": "slow",
    "smacks": "smack",
    "smalahs": "smalah",
    "smalas": "smala",
    "smaragdites": "smaragdite",
    "smashe": "smasher",
    "smashes": "smash",
    "smashs": "smash",
    "smicards": "smicard",
    "smogs": "smog",
    "smokings": "smoking",
    "snack-bars": "snack-bar",
    "snacks": "snack",
    "sniffaient": "sniffer",
    "sniffais": "sniffer",
    "sniffait": "sniffer",
    "sniffant": "sniffer",
    "sniffe": "sniffer",
    "sniffent": "sniffer",
    "snifferai": "sniffer",
    "sniffes": "sniffer",
    "sniffez": "sniffer",
    "sniffé": "sniffer",
    "sniffée": "sniffer",
    "sniffées": "sniffer",
    "snipers": "sniper",
    "snobaient": "snober",
    "snobais": "snober",
    "snobe": "snober",
    "snobent": "snober",
    "snoberez": "snober",
    "snobez": "snober",
    "snobinarde": "snobinard",
    "snobinardes": "snobinard",
    "snobinards": "snobinard",
    "snobismes": "snobisme",
    "snobs": "snob",
    "snobé": "snober",
    "snobée": "snober",
    "snobés": "snober",
    "snow-boots": "snow-boot",
    "soap opéra": "soap-opéra",
    "sobres": "sobre",
    "sobriquets": "sobriquet",
    "sobriétés": "sobriété",
    "sochalienne": "sochalien",
    "sochaliennes": "sochalien",
    "sochaliens": "sochalien",
    "sociables": "sociable",
    "social-démocraties": "social-démocratie",
    "sociale": "social",
    "sociales": "social",
    "socialisante": "socialisant",
    "socialisantes": "socialisant",
    "socialisants": "socialisant",
    "socialisations": "socialisation",
    "socialise": "socialiser",
    "socialisez": "socialiser",
    "socialismes": "socialisme",
    "socialistes": "socialiste",
    "socialos": "socialo",
    "sociaux": "social",
    "sociaux-chrétiens": "social-chrétien",
    "sociaux-démocrates": "social-démocrate",
    "sociniens": "socinien",
    "socio-culturelles": "socio-culturel",
    "socio-culturels": "socio-culturel",
    "socio-économiques": "socio-économique",
    "socio-éducatifs": "socio-éducatif",
    "socio-éducative": "socio-éducatif",
    "socio-éducatives": "socio-éducatif",
    "socioculturelle": "socioculturel",
    "socioculturelles": "socioculturel",
    "socioculturels": "socioculturel",
    "sociolinguistiques": "sociolinguistique",
    "sociologies": "sociologie",
    "sociologiques": "sociologique",
    "sociologues": "sociologue",
    "sociopathes": "sociopathe",
    "sociopolitiques": "sociopolitique",
    "socioprofessionnelle": "socioprofessionnel",
    "socioprofessionnelles": "socioprofessionnel",
    "socioprofessionnels": "socioprofessionnel",
    "socioéconomiques": "socioéconomique",
    "sociétaires": "sociétaire",
    "sociétale": "sociétal",
    "sociétés": "société",
    "socles": "socle",
    "socques": "socque",
    "socquettes": "socquette",
    "socratiques": "socratique",
    "socs": "soc",
    "sodas": "soda",
    "sodiums": "sodium",
    "sodomies": "sodomie",
    "sodomisa": "sodomiser",
    "sodomisait": "sodomiser",
    "sodomisant": "sodomiser",
    "sodomise": "sodomiser",
    "sodomiseront": "sodomiser",
    "sodomisez": "sodomiser",
    "sodomisé": "sodomiser",
    "sodomisée": "sodomiser",
    "sodomisés": "sodomiser",
    "sodomites": "sodomite",
    "sodomitiques": "sodomitique",
    "soeurs": "soeur",
    "sofas": "sofa",
    "softs": "soft",
    "soient": "être",
    "soieries": "soierie",
    "soies": "soie",
    "soiffarde": "soiffard",
    "soiffardes": "soiffard",
    "soiffards": "soiffard",
    "soifs": "soif",
    "soigna": "soigner",
    "soignai": "soigner",
    "soignaient": "soigner",
    "soignais": "soigner",
    "soignait": "soigner",
    "soignant": "soigner",
    "soignante": "soignant",
    "soignantes": "soignant",
    "soignants": "soignant",
    "soignas": "soigner",
    "soignasse": "soigner",
    "soignassent": "soigner",
    "soignasses": "soigner",
    "soignassiez": "soigner",
    "soignassions": "soigner",
    "soigne": "soigner",
    "soignent": "soigner",
    "soigner": "saler",
    "soignera": "soigner",
    "soignerai": "soigner",
    "soigneraient": "soigner",
    "soignerais": "soigner",
    "soignerait": "soigner",
    "soigneras": "soigner",
    "soignerez": "soigner",
    "soigneriez": "soigner",
    "soignerions": "soigner",
    "soignerons": "soigner",
    "soigneront": "soigner",
    "soignes": "soigner",
    "soigneurs": "soigneur",
    "soigneuse": "soigneux",
    "soigneuses": "soigneux",
    "soignez": "soigner",
    "soigniez": "soigner",
    "soignions": "soigner",
    "soignons": "soigner",
    "soignâmes": "soigner",
    "soignât": "soigner",
    "soignâtes": "soigner",
    "soignèrent": "soigner",
    "soigné": "soigner",
    "soignée": "soigner",
    "soignées": "soigner",
    "soignés": "soigner",
    "soins": "soin",
    "soirs": "soir",
    "soirées": "soirée",
    "sois": "être",
    "soit": "être",
    "soixantaines": "soixantaine",
    "soixante-cinquièmes": "soixante-cinquième",
    "soixante-deuxièmes": "soixante-deuxième",
    "soixante-dix-huitièmes": "soixante-dix-huitième",
    "soixante-dix-neuvièmes": "soixante-dix-neuvième",
    "soixante-dix-septièmes": "soixante-dix-septième",
    "soixante-dixièmes": "soixante-dixième",
    "soixante-douzièmes": "soixante-douzième",
    "soixante-et-onzièmes": "soixante-et-onzième",
    "soixante-et-une": "soixante-et-un",
    "soixante-et-unièmes": "soixante-et-unième",
    "soixante-huitarde": "soixante-huitard",
    "soixante-huitards": "soixante-huitard",
    "soixante-huitièmes": "soixante-huitième",
    "soixante-neuvièmes": "soixante-neuvième",
    "soixante-quatorzièmes": "soixante-quatorzième",
    "soixante-quatrièmes": "soixante-quatrième",
    "soixante-quinzièmes": "soixante-quinzième",
    "soixante-seizièmes": "soixante-seizième",
    "soixante-septièmes": "soixante-septième",
    "soixante-sixièmes": "soixante-sixième",
    "soixante-treizièmes": "soixante-treizième",
    "soixante-troisièmes": "soixante-troisième",
    "soixantièmes": "soixantième",
    "sojas": "soja",
    "solaires": "solaire",
    "solanacées": "solanacée",
    "solarisations": "solarisation",
    "solariums": "solarium",
    "solda": "solder",
    "soldai": "solder",
    "soldaient": "solder",
    "soldais": "solder",
    "soldait": "solder",
    "soldanelles": "soldanelle",
    "soldant": "solder",
    "soldas": "solder",
    "soldasse": "solder",
    "soldassent": "solder",
    "soldasses": "solder",
    "soldassiez": "solder",
    "soldassions": "solder",
    "soldate": "soldat",
    "soldats": "soldat",
    "solde": "solder",
    "soldent": "solder",
    "soldera": "solder",
    "solderai": "solder",
    "solderaient": "solder",
    "solderais": "solder",
    "solderait": "solder",
    "solderas": "solder",
    "solderez": "solder",
    "solderiez": "solder",
    "solderions": "solder",
    "solderons": "solder",
    "solderont": "solder",
    "soldes": "solder",
    "soldeurs": "soldeur",
    "soldez": "solder",
    "soldiez": "solder",
    "soldions": "solder",
    "soldons": "solder",
    "soldâmes": "solder",
    "soldât": "solder",
    "soldâtes": "solder",
    "soldèrent": "solder",
    "soldé": "solder",
    "soldée": "solder",
    "soldées": "solder",
    "soldés": "solder",
    "soleils": "soleil",
    "solennelle": "solennel",
    "solennelles": "solennel",
    "solennels": "solennel",
    "solennisa": "solenniser",
    "solennisai": "solenniser",
    "solennisaient": "solenniser",
    "solennisais": "solenniser",
    "solennisait": "solenniser",
    "solennisant": "solenniser",
    "solennisas": "solenniser",
    "solennisasse": "solenniser",
    "solennisassent": "solenniser",
    "solennisasses": "solenniser",
    "solennisassiez": "solenniser",
    "solennisassions": "solenniser",
    "solennise": "solenniser",
    "solennisent": "solenniser",
    "solennisera": "solenniser",
    "solenniserai": "solenniser",
    "solenniseraient": "solenniser",
    "solenniserais": "solenniser",
    "solenniserait": "solenniser",
    "solenniseras": "solenniser",
    "solenniserez": "solenniser",
    "solenniseriez": "solenniser",
    "solenniserions": "solenniser",
    "solenniserons": "solenniser",
    "solenniseront": "solenniser",
    "solennises": "solenniser",
    "solennisez": "solenniser",
    "solennisiez": "solenniser",
    "solennisions": "solenniser",
    "solennisons": "solenniser",
    "solennisâmes": "solenniser",
    "solennisât": "solenniser",
    "solennisâtes": "solenniser",
    "solennisèrent": "solenniser",
    "solennisé": "solenniser",
    "solennisée": "solenniser",
    "solennisées": "solenniser",
    "solennisés": "solenniser",
    "solennités": "solennité",
    "soles": "sole",
    "solfatares": "solfatare",
    "solfia": "solfier",
    "solfiai": "solfier",
    "solfiaient": "solfier",
    "solfiais": "solfier",
    "solfiait": "solfier",
    "solfiant": "solfier",
    "solfias": "solfier",
    "solfiasse": "solfier",
    "solfiassent": "solfier",
    "solfiasses": "solfier",
    "solfiassiez": "solfier",
    "solfiassions": "solfier",
    "solfie": "solfier",
    "solfient": "solfier",
    "solfiera": "solfier",
    "solfierai": "solfier",
    "solfieraient": "solfier",
    "solfierais": "solfier",
    "solfierait": "solfier",
    "solfieras": "solfier",
    "solfierez": "solfier",
    "solfieriez": "solfier",
    "solfierions": "solfier",
    "solfierons": "solfier",
    "solfieront": "solfier",
    "solfies": "solfier",
    "solfiez": "solfier",
    "solfiiez": "solfier",
    "solfiions": "solfier",
    "solfions": "solfier",
    "solfiâmes": "solfier",
    "solfiât": "solfier",
    "solfiâtes": "solfier",
    "solfièrent": "solfier",
    "solfié": "solfier",
    "solfiée": "solfier",
    "solfiées": "solfier",
    "solfiés": "solfier",
    "solfèges": "solfège",
    "soli": "solo",
    "solicitors": "solicitor",
    "solidaires": "solidaire",
    "solidarisa": "solidariser",
    "solidarisai": "solidariser",
    "solidarisaient": "solidariser",
    "solidarisais": "solidariser",
    "solidarisait": "solidariser",
    "solidarisant": "solidariser",
    "solidarisas": "solidariser",
    "solidarisasse": "solidariser",
    "solidarisassent": "solidariser",
    "solidarisasses": "solidariser",
    "solidarisassiez": "solidariser",
    "solidarisassions": "solidariser",
    "solidarise": "solidariser",
    "solidarisent": "solidariser",
    "solidarisera": "solidariser",
    "solidariserai": "solidariser",
    "solidariseraient": "solidariser",
    "solidariserais": "solidariser",
    "solidariserait": "solidariser",
    "solidariseras": "solidariser",
    "solidariserez": "solidariser",
    "solidariseriez": "solidariser",
    "solidariserions": "solidariser",
    "solidariserons": "solidariser",
    "solidariseront": "solidariser",
    "solidarises": "solidariser",
    "solidarisez": "solidariser",
    "solidarisiez": "solidariser",
    "solidarisions": "solidariser",
    "solidarisons": "solidariser",
    "solidarisâmes": "solidariser",
    "solidarisât": "solidariser",
    "solidarisâtes": "solidariser",
    "solidarisèrent": "solidariser",
    "solidarisé": "solidariser",
    "solidarisée": "solidariser",
    "solidarisées": "solidariser",
    "solidarisés": "solidariser",
    "solidarités": "solidarité",
    "solides": "solide",
    "solidifia": "solidifier",
    "solidifiai": "solidifier",
    "solidifiaient": "solidifier",
    "solidifiais": "solidifier",
    "solidifiait": "solidifier",
    "solidifiant": "solidifier",
    "solidifias": "solidifier",
    "solidifiasse": "solidifier",
    "solidifiassent": "solidifier",
    "solidifiasses": "solidifier",
    "solidifiassiez": "solidifier",
    "solidifiassions": "solidifier",
    "solidifications": "solidification",
    "solidifie": "solidifier",
    "solidifient": "solidifier",
    "solidifiera": "solidifier",
    "solidifierai": "solidifier",
    "solidifieraient": "solidifier",
    "solidifierais": "solidifier",
    "solidifierait": "solidifier",
    "solidifieras": "solidifier",
    "solidifierez": "solidifier",
    "solidifieriez": "solidifier",
    "solidifierions": "solidifier",
    "solidifierons": "solidifier",
    "solidifieront": "solidifier",
    "solidifies": "solidifier",
    "solidifiez": "solidifier",
    "solidifiiez": "solidifier",
    "solidifiions": "solidifier",
    "solidifions": "solidifier",
    "solidifiâmes": "solidifier",
    "solidifiât": "solidifier",
    "solidifiâtes": "solidifier",
    "solidifièrent": "solidifier",
    "solidifié": "solidifier",
    "solidifiée": "solidifier",
    "solidifiées": "solidifier",
    "solidifiés": "solidifier",
    "solidités": "solidité",
    "solifluctions": "solifluction",
    "solifluxions": "solifluxion",
    "soliloqua": "soliloquer",
    "soliloquait": "soliloquer",
    "soliloque": "soliloquer",
    "soliloques": "soliloque",
    "solins": "solin",
    "solipsismes": "solipsisme",
    "solipèdes": "solipède",
    "solistes": "soliste",
    "solitaires": "solitaire",
    "solitudes": "solitude",
    "soliveaux": "soliveau",
    "solives": "solive",
    "sollicita": "solliciter",
    "sollicitai": "solliciter",
    "sollicitaient": "solliciter",
    "sollicitais": "solliciter",
    "sollicitait": "solliciter",
    "sollicitant": "solliciter",
    "sollicitas": "solliciter",
    "sollicitasse": "solliciter",
    "sollicitassent": "solliciter",
    "sollicitasses": "solliciter",
    "sollicitassiez": "solliciter",
    "sollicitassions": "solliciter",
    "sollicitations": "sollicitation",
    "sollicite": "solliciter",
    "sollicitent": "solliciter",
    "sollicitera": "solliciter",
    "solliciterai": "solliciter",
    "solliciteraient": "solliciter",
    "solliciterais": "solliciter",
    "solliciterait": "solliciter",
    "solliciteras": "solliciter",
    "solliciterez": "solliciter",
    "solliciteriez": "solliciter",
    "solliciterions": "solliciter",
    "solliciterons": "solliciter",
    "solliciteront": "solliciter",
    "sollicites": "solliciter",
    "solliciteurs": "solliciteur",
    "solliciteuse": "solliciteur",
    "sollicitez": "solliciter",
    "sollicitiez": "solliciter",
    "sollicitions": "solliciter",
    "sollicitons": "solliciter",
    "sollicitudes": "sollicitude",
    "sollicitâmes": "solliciter",
    "sollicitât": "solliciter",
    "sollicitâtes": "solliciter",
    "sollicitèrent": "solliciter",
    "sollicité": "solliciter",
    "sollicitée": "solliciter",
    "sollicitées": "solliciter",
    "sollicités": "solliciter",
    "solognote": "solognot",
    "solognots": "solognot",
    "solos": "solo",
    "sols": "sol",
    "solstices": "solstice",
    "solsticiale": "solsticial",
    "solsticiales": "solsticial",
    "solsticiaux": "solsticial",
    "solubles": "soluble",
    "solutionnait": "solutionner",
    "solutionnons": "solutionner",
    "solutions": "solution",
    "solutés": "soluté",
    "solvabilités": "solvabilité",
    "solvables": "solvable",
    "solvants": "solvant",
    "solécismes": "solécisme",
    "solénoïdes": "solénoïde",
    "somalienne": "somalien",
    "somaliennes": "somalien",
    "somaliens": "somalien",
    "somalis": "somali",
    "somatiques": "somatique",
    "somatisant": "somatiser",
    "somatise": "somatiser",
    "somatiserez": "somatiser",
    "somatisée": "somatiser",
    "somatotrophines": "somatotrophine",
    "somatotropines": "somatotropine",
    "sombra": "sombrer",
    "sombrai": "sombrer",
    "sombraient": "sombrer",
    "sombrais": "sombrer",
    "sombrait": "sombrer",
    "sombrant": "sombrer",
    "sombras": "sombrer",
    "sombrasse": "sombrer",
    "sombrassent": "sombrer",
    "sombrasses": "sombrer",
    "sombrassiez": "sombrer",
    "sombrassions": "sombrer",
    "sombre": "sombrer",
    "sombrent": "sombrer",
    "sombrera": "sombrer",
    "sombrerai": "sombrer",
    "sombreraient": "sombrer",
    "sombrerais": "sombrer",
    "sombrerait": "sombrer",
    "sombreras": "sombrer",
    "sombrerez": "sombrer",
    "sombreriez": "sombrer",
    "sombrerions": "sombrer",
    "sombrerons": "sombrer",
    "sombreront": "sombrer",
    "sombreros": "sombrero",
    "sombres": "sombrer",
    "sombrez": "sombrer",
    "sombriez": "sombrer",
    "sombrions": "sombrer",
    "sombrons": "sombrer",
    "sombrâmes": "sombrer",
    "sombrât": "sombrer",
    "sombrâtes": "sombrer",
    "sombrèrent": "sombrer",
    "sombré": "sombrer",
    "sombrée": "sombrer",
    "sombrées": "sombrer",
    "sombrés": "sombrer",
    "somma": "sommer",
    "sommai": "sommer",
    "sommaient": "sommer",
    "sommaires": "sommaire",
    "sommais": "sommer",
    "sommait": "sommer",
    "sommant": "sommer",
    "sommas": "sommer",
    "sommasse": "sommer",
    "sommassent": "sommer",
    "sommasses": "sommer",
    "sommassiez": "sommer",
    "sommassions": "sommer",
    "sommations": "sommation",
    "somme": "sommer",
    "sommeilla": "sommeiller",
    "sommeillai": "sommeiller",
    "sommeillaient": "sommeiller",
    "sommeillais": "sommeiller",
    "sommeillait": "sommeiller",
    "sommeillant": "sommeiller",
    "sommeillante": "sommeillant",
    "sommeillants": "sommeillant",
    "sommeillas": "sommeiller",
    "sommeillasse": "sommeiller",
    "sommeillassent": "sommeiller",
    "sommeillasses": "sommeiller",
    "sommeillassiez": "sommeiller",
    "sommeillassions": "sommeiller",
    "sommeille": "sommeiller",
    "sommeillent": "sommeiller",
    "sommeillera": "sommeiller",
    "sommeillerai": "sommeiller",
    "sommeilleraient": "sommeiller",
    "sommeillerais": "sommeiller",
    "sommeillerait": "sommeiller",
    "sommeilleras": "sommeiller",
    "sommeillerez": "sommeiller",
    "sommeilleriez": "sommeiller",
    "sommeillerions": "sommeiller",
    "sommeillerons": "sommeiller",
    "sommeilleront": "sommeiller",
    "sommeilles": "sommeiller",
    "sommeillez": "sommeiller",
    "sommeilliez": "sommeiller",
    "sommeillions": "sommeiller",
    "sommeillons": "sommeiller",
    "sommeillâmes": "sommeiller",
    "sommeillât": "sommeiller",
    "sommeillâtes": "sommeiller",
    "sommeillèrent": "sommeiller",
    "sommeillé": "sommeiller",
    "sommeils": "sommeil",
    "sommeliers": "sommelier",
    "sommelleries": "sommellerie",
    "somment": "sommer",
    "sommera": "sommer",
    "sommerai": "sommer",
    "sommeraient": "sommer",
    "sommerais": "sommer",
    "sommerait": "sommer",
    "sommeras": "sommer",
    "sommerez": "sommer",
    "sommeriez": "sommer",
    "sommerions": "sommer",
    "sommerons": "sommer",
    "sommeront": "sommer",
    "sommes": "sommer",
    "sommets": "sommet",
    "sommez": "sommer",
    "sommiers": "sommier",
    "sommiez": "sommer",
    "sommions": "sommer",
    "sommitales": "sommital",
    "sommités": "sommité",
    "sommons": "sommer",
    "sommâmes": "sommer",
    "sommât": "sommer",
    "sommâtes": "sommer",
    "sommèrent": "sommer",
    "sommé": "sommer",
    "sommée": "sommer",
    "sommées": "sommer",
    "sommés": "sommer",
    "somnambulant": "somnambuler",
    "somnambules": "somnambule",
    "somnambuliques": "somnambulique",
    "somnifères": "somnifère",
    "somnola": "somnoler",
    "somnolai": "somnoler",
    "somnolaient": "somnoler",
    "somnolais": "somnoler",
    "somnolait": "somnoler",
    "somnolant": "somnoler",
    "somnolas": "somnoler",
    "somnolasse": "somnoler",
    "somnolassent": "somnoler",
    "somnolasses": "somnoler",
    "somnolassiez": "somnoler",
    "somnolassions": "somnoler",
    "somnole": "somnoler",
    "somnolences": "somnolence",
    "somnolent": "somnoler",
    "somnolente": "somnolent",
    "somnolentes": "somnolent",
    "somnolents": "somnolent",
    "somnolera": "somnoler",
    "somnolerai": "somnoler",
    "somnoleraient": "somnoler",
    "somnolerais": "somnoler",
    "somnolerait": "somnoler",
    "somnoleras": "somnoler",
    "somnolerez": "somnoler",
    "somnoleriez": "somnoler",
    "somnolerions": "somnoler",
    "somnolerons": "somnoler",
    "somnoleront": "somnoler",
    "somnoles": "somnoler",
    "somnolez": "somnoler",
    "somnoliez": "somnoler",
    "somnolions": "somnoler",
    "somnolons": "somnoler",
    "somnolâmes": "somnoler",
    "somnolât": "somnoler",
    "somnolâtes": "somnoler",
    "somnolèrent": "somnoler",
    "somnolé": "somnoler",
    "somozistes": "somoziste",
    "somptuaires": "somptuaire",
    "somptueuse": "somptueux",
    "somptueuses": "somptueux",
    "somptuosités": "somptuosité",
    "sonars": "sonar",
    "sonates": "sonate",
    "sonda": "sonder",
    "sondages": "sondage",
    "sondai": "sonder",
    "sondaient": "sonder",
    "sondais": "sonder",
    "sondait": "sonder",
    "sondant": "sonder",
    "sondas": "sonder",
    "sondasse": "sonder",
    "sondassent": "sonder",
    "sondasses": "sonder",
    "sondassiez": "sonder",
    "sondassions": "sonder",
    "sonde": "sonder",
    "sondent": "sonder",
    "sondera": "sonder",
    "sonderai": "sonder",
    "sonderaient": "sonder",
    "sonderais": "sonder",
    "sonderait": "sonder",
    "sonderas": "sonder",
    "sonderez": "sonder",
    "sonderiez": "sonder",
    "sonderions": "sonder",
    "sonderons": "sonder",
    "sonderont": "sonder",
    "sondes": "sonder",
    "sondeurs": "sondeur",
    "sondeuse": "sondeur",
    "sondez": "sonder",
    "sondiez": "sonder",
    "sondions": "sonder",
    "sondons": "sonder",
    "sondâmes": "sonder",
    "sondât": "sonder",
    "sondâtes": "sonder",
    "sondèrent": "sonder",
    "sondé": "sonder",
    "sondée": "sonder",
    "sondées": "sonder",
    "sondés": "sonder",
    "songe": "songer",
    "songea": "songer",
    "songeai": "songer",
    "songeaient": "songer",
    "songeais": "songer",
    "songeait": "songer",
    "songeant": "songer",
    "songeas": "songer",
    "songeasse": "songer",
    "songeassent": "songer",
    "songeasses": "songer",
    "songeassiez": "songer",
    "songeassions": "songer",
    "songent": "songer",
    "songeons": "songer",
    "songera": "songer",
    "songerai": "songer",
    "songeraient": "songer",
    "songerais": "songer",
    "songerait": "songer",
    "songeras": "songer",
    "songerez": "songer",
    "songeries": "songerie",
    "songeriez": "songer",
    "songerions": "songer",
    "songerons": "songer",
    "songeront": "songer",
    "songes": "songer",
    "songeurs": "songeur",
    "songeuse": "songeur",
    "songeuses": "songeur",
    "songez": "songer",
    "songeâmes": "songer",
    "songeât": "songer",
    "songeâtes": "songer",
    "songiez": "songer",
    "songions": "songer",
    "songèrent": "songer",
    "songé": "songer",
    "songée": "songer",
    "songées": "songer",
    "songés": "songer",
    "soniques": "sonique",
    "sonna": "sonner",
    "sonnai": "sonner",
    "sonnaient": "sonner",
    "sonnaillaient": "sonnailler",
    "sonnailles": "sonnaille",
    "sonnais": "sonner",
    "sonnait": "sonner",
    "sonnant": "sonner",
    "sonnante": "sonnant",
    "sonnantes": "sonnant",
    "sonnants": "sonnant",
    "sonnas": "sonner",
    "sonnasse": "sonner",
    "sonnassent": "sonner",
    "sonnasses": "sonner",
    "sonnassiez": "sonner",
    "sonnassions": "sonner",
    "sonne": "sonner",
    "sonnent": "sonner",
    "sonnera": "sonner",
    "sonnerai": "sonner",
    "sonneraient": "sonner",
    "sonnerais": "sonner",
    "sonnerait": "sonner",
    "sonneras": "sonner",
    "sonnerez": "sonner",
    "sonneries": "sonnerie",
    "sonneriez": "sonner",
    "sonnerions": "sonner",
    "sonnerons": "sonner",
    "sonneront": "sonner",
    "sonnes": "sonner",
    "sonnets": "sonnet",
    "sonnettes": "sonnette",
    "sonneurs": "sonneur",
    "sonnez": "sonner",
    "sonniez": "sonner",
    "sonnions": "sonner",
    "sonnons": "sonner",
    "sonnâmes": "sonner",
    "sonnât": "sonner",
    "sonnâtes": "sonner",
    "sonnèrent": "sonner",
    "sonné": "sonner",
    "sonnée": "sonner",
    "sonnées": "sonner",
    "sonnés": "sonner",
    "sonomètres": "sonomètre",
    "sonores": "sonore",
    "sonorisateurs": "sonorisateur",
    "sonorisations": "sonorisation",
    "sonorise": "sonoriser",
    "sonorisé": "sonoriser",
    "sonorisées": "sonoriser",
    "sonorités": "sonorité",
    "sonos": "sono",
    "sonotones": "sonotone",
    "sons": "son",
    "sont": "être",
    "sophismes": "sophisme",
    "sophistes": "sophiste",
    "sophistications": "sophistication",
    "sophistiqua": "sophistiquer",
    "sophistiquai": "sophistiquer",
    "sophistiquaient": "sophistiquer",
    "sophistiquais": "sophistiquer",
    "sophistiquait": "sophistiquer",
    "sophistiquant": "sophistiquer",
    "sophistiquas": "sophistiquer",
    "sophistiquasse": "sophistiquer",
    "sophistiquassent": "sophistiquer",
    "sophistiquasses": "sophistiquer",
    "sophistiquassiez": "sophistiquer",
    "sophistiquassions": "sophistiquer",
    "sophistique": "sophistiquer",
    "sophistiquent": "sophistiquer",
    "sophistiquera": "sophistiquer",
    "sophistiquerai": "sophistiquer",
    "sophistiqueraient": "sophistiquer",
    "sophistiquerais": "sophistiquer",
    "sophistiquerait": "sophistiquer",
    "sophistiqueras": "sophistiquer",
    "sophistiquerez": "sophistiquer",
    "sophistiqueriez": "sophistiquer",
    "sophistiquerions": "sophistiquer",
    "sophistiquerons": "sophistiquer",
    "sophistiqueront": "sophistiquer",
    "sophistiques": "sophistiquer",
    "sophistiquez": "sophistiquer",
    "sophistiquiez": "sophistiquer",
    "sophistiquions": "sophistiquer",
    "sophistiquons": "sophistiquer",
    "sophistiquâmes": "sophistiquer",
    "sophistiquât": "sophistiquer",
    "sophistiquâtes": "sophistiquer",
    "sophistiquèrent": "sophistiquer",
    "sophistiqué": "sophistiquer",
    "sophistiquée": "sophistiquer",
    "sophistiquées": "sophistiquer",
    "sophistiqués": "sophistiquer",
    "soporifiques": "soporifique",
    "soprani": "soprano",
    "sopranos": "soprano",
    "sorbes": "sorbe",
    "sorbetières": "sorbetière",
    "sorbets": "sorbet",
    "sorbiers": "sorbier",
    "sorbonnarde": "sorbonnard",
    "sorbonne": "sorbon",
    "sorcelleries": "sorcellerie",
    "sorciers": "sorcier",
    "sorcière": "sorcier",
    "sorcières": "sorcier",
    "sordides": "sordide",
    "sorghos": "sorgho",
    "sornettes": "sornette",
    "sororale": "sororal",
    "sororales": "sororal",
    "sororités": "sororité",
    "sors": "sortir",
    "sort": "sortir",
    "sortables": "sortable",
    "sortaient": "sortir",
    "sortais": "sortir",
    "sortait": "sortir",
    "sortant": "sortir",
    "sortante": "sortant",
    "sortantes": "sortant",
    "sortants": "sortant",
    "sorte": "sortir",
    "sortent": "sortir",
    "sortes": "sortir",
    "sortez": "sortir",
    "sorti": "sortir",
    "sortie": "sortir",
    "sorties": "sortir",
    "sorties-de-bain": "sortie-de-bain",
    "sorties-de-bal": "sortie-de-bal",
    "sortiez": "sortir",
    "sortilèges": "sortilège",
    "sortions": "sortir",
    "sortira": "sortir",
    "sortirai": "sortir",
    "sortiraient": "sortir",
    "sortirais": "sortir",
    "sortirait": "sortir",
    "sortiras": "sortir",
    "sortirent": "sortir",
    "sortirez": "sortir",
    "sortiriez": "sortir",
    "sortirions": "sortir",
    "sortirons": "sortir",
    "sortiront": "sortir",
    "sortis": "sortir",
    "sortissaient": "sortir",
    "sortissait": "sortir",
    "sortissant": "sortir",
    "sortisse": "sortir",
    "sortissent": "sortir",
    "sortisses": "sortir",
    "sortissiez": "sortir",
    "sortissions": "sortir",
    "sortit": "sortir",
    "sortons": "sortir",
    "sorts": "sort",
    "sortîmes": "sortir",
    "sortît": "sortir",
    "sortîtes": "sortir",
    "sosies": "sosie",
    "soties": "sotie",
    "sots": "sot",
    "sotte": "sot",
    "sottes": "sot",
    "sotties": "sottie",
    "sottises": "sottise",
    "sottisiers": "sottisier",
    "souabes": "souabe",
    "soubassements": "soubassement",
    "soubat": "soubattre",
    "soubats": "soubattre",
    "soubattaient": "soubattre",
    "soubattais": "soubattre",
    "soubattait": "soubattre",
    "soubattant": "soubattre",
    "soubatte": "soubattre",
    "soubattent": "soubattre",
    "soubattes": "soubattre",
    "soubattez": "soubattre",
    "soubattiez": "soubattre",
    "soubattions": "soubattre",
    "soubattirent": "soubattre",
    "soubattis": "soubattre",
    "soubattisse": "soubattre",
    "soubattissent": "soubattre",
    "soubattisses": "soubattre",
    "soubattissiez": "soubattre",
    "soubattissions": "soubattre",
    "soubattit": "soubattre",
    "soubattons": "soubattre",
    "soubattra": "soubattre",
    "soubattrai": "soubattre",
    "soubattraient": "soubattre",
    "soubattrais": "soubattre",
    "soubattrait": "soubattre",
    "soubattras": "soubattre",
    "soubattrez": "soubattre",
    "soubattriez": "soubattre",
    "soubattrions": "soubattre",
    "soubattrons": "soubattre",
    "soubattront": "soubattre",
    "soubattu": "soubattre",
    "soubattue": "soubattre",
    "soubattues": "soubattre",
    "soubattus": "soubattre",
    "soubattîmes": "soubattre",
    "soubattît": "soubattre",
    "soubattîtes": "soubattre",
    "soubresauta": "soubresauter",
    "soubresautai": "soubresauter",
    "soubresautaient": "soubresauter",
    "soubresautais": "soubresauter",
    "soubresautait": "soubresauter",
    "soubresautant": "soubresauter",
    "soubresautas": "soubresauter",
    "soubresautasse": "soubresauter",
    "soubresautassent": "soubresauter",
    "soubresautasses": "soubresauter",
    "soubresautassiez": "soubresauter",
    "soubresautassions": "soubresauter",
    "soubresaute": "soubresauter",
    "soubresautent": "soubresauter",
    "soubresautera": "soubresauter",
    "soubresauterai": "soubresauter",
    "soubresauteraient": "soubresauter",
    "soubresauterais": "soubresauter",
    "soubresauterait": "soubresauter",
    "soubresauteras": "soubresauter",
    "soubresauterez": "soubresauter",
    "soubresauteriez": "soubresauter",
    "soubresauterions": "soubresauter",
    "soubresauterons": "soubresauter",
    "soubresauteront": "soubresauter",
    "soubresautes": "soubresauter",
    "soubresautez": "soubresauter",
    "soubresautiez": "soubresauter",
    "soubresautions": "soubresauter",
    "soubresautons": "soubresauter",
    "soubresauts": "soubresaut",
    "soubresautâmes": "soubresauter",
    "soubresautât": "soubresauter",
    "soubresautâtes": "soubresauter",
    "soubresautèrent": "soubresauter",
    "soubresauté": "soubresauter",
    "soubresautée": "soubresauter",
    "soubresautées": "soubresauter",
    "soubresautés": "soubresauter",
    "soubrettes": "soubrette",
    "souches": "souche",
    "soucia": "soucier",
    "souciai": "soucier",
    "souciaient": "soucier",
    "souciais": "soucier",
    "souciait": "soucier",
    "souciant": "soucier",
    "soucias": "soucier",
    "souciasse": "soucier",
    "souciassent": "soucier",
    "souciasses": "soucier",
    "souciassiez": "soucier",
    "souciassions": "soucier",
    "soucie": "soucier",
    "soucient": "soucier",
    "souciera": "soucier",
    "soucierai": "soucier",
    "soucieraient": "soucier",
    "soucierais": "soucier",
    "soucierait": "soucier",
    "soucieras": "soucier",
    "soucierez": "soucier",
    "soucieriez": "soucier",
    "soucierions": "soucier",
    "soucierons": "soucier",
    "soucieront": "soucier",
    "soucies": "soucier",
    "soucieuse": "soucieux",
    "soucieuses": "soucieux",
    "souciez": "soucier",
    "souciiez": "soucier",
    "souciions": "soucier",
    "soucions": "soucier",
    "soucis": "souci",
    "souciâmes": "soucier",
    "souciât": "soucier",
    "souciâtes": "soucier",
    "soucièrent": "soucier",
    "soucié": "soucier",
    "souciée": "soucier",
    "souciées": "soucier",
    "souciés": "soucier",
    "soucoupes": "soucoupe",
    "souda": "souder",
    "soudai": "souder",
    "soudaient": "souder",
    "soudaine": "soudain",
    "soudaines": "soudain",
    "soudains": "soudain",
    "soudais": "souder",
    "soudait": "souder",
    "soudanaise": "soudanais",
    "soudant": "souder",
    "soudards": "soudard",
    "soudas": "souder",
    "soudasse": "souder",
    "soudassent": "souder",
    "soudasses": "souder",
    "soudassiez": "souder",
    "soudassions": "souder",
    "soude": "souder",
    "soudent": "souder",
    "soudera": "souder",
    "souderai": "souder",
    "souderaient": "souder",
    "souderais": "souder",
    "souderait": "souder",
    "souderas": "souder",
    "souderez": "souder",
    "souderiez": "souder",
    "souderions": "souder",
    "souderons": "souder",
    "souderont": "souder",
    "soudes": "souder",
    "soudeurs": "soudeur",
    "soudeuse": "soudeur",
    "soudez": "souder",
    "soudiez": "souder",
    "soudions": "souder",
    "soudoie": "soudoyer",
    "soudoient": "soudoyer",
    "soudoiera": "soudoyer",
    "soudoierai": "soudoyer",
    "soudoieraient": "soudoyer",
    "soudoierais": "soudoyer",
    "soudoierait": "soudoyer",
    "soudoieras": "soudoyer",
    "soudoierez": "soudoyer",
    "soudoieriez": "soudoyer",
    "soudoierions": "soudoyer",
    "soudoierons": "soudoyer",
    "soudoieront": "soudoyer",
    "soudoies": "soudoyer",
    "soudons": "souder",
    "soudoya": "soudoyer",
    "soudoyai": "soudoyer",
    "soudoyaient": "soudoyer",
    "soudoyais": "soudoyer",
    "soudoyait": "soudoyer",
    "soudoyant": "soudoyer",
    "soudoyas": "soudoyer",
    "soudoyasse": "soudoyer",
    "soudoyassent": "soudoyer",
    "soudoyasses": "soudoyer",
    "soudoyassiez": "soudoyer",
    "soudoyassions": "soudoyer",
    "soudoyez": "soudoyer",
    "soudoyiez": "soudoyer",
    "soudoyions": "soudoyer",
    "soudoyons": "soudoyer",
    "soudoyâmes": "soudoyer",
    "soudoyât": "soudoyer",
    "soudoyâtes": "soudoyer",
    "soudoyèrent": "soudoyer",
    "soudoyé": "soudoyer",
    "soudoyée": "soudoyer",
    "soudoyées": "soudoyer",
    "soudoyés": "soudoyer",
    "soudures": "soudure",
    "soudâmes": "souder",
    "soudât": "souder",
    "soudâtes": "souder",
    "soudèrent": "souder",
    "soudé": "souder",
    "soudée": "souder",
    "soudées": "souder",
    "soudés": "souder",
    "soues": "soue",
    "souffert": "souffrir",
    "soufferte": "souffrir",
    "souffertes": "souffrir",
    "soufferts": "souffrir",
    "souffla": "souffler",
    "soufflages": "soufflage",
    "soufflai": "souffler",
    "soufflaient": "souffler",
    "soufflais": "souffler",
    "soufflait": "souffler",
    "soufflant": "souffler",
    "soufflante": "soufflant",
    "soufflants": "soufflant",
    "soufflas": "souffler",
    "soufflasse": "souffler",
    "soufflassent": "souffler",
    "soufflasses": "souffler",
    "soufflassiez": "souffler",
    "soufflassions": "souffler",
    "souffle": "souffler",
    "soufflements": "soufflement",
    "soufflent": "souffler",
    "soufflera": "souffler",
    "soufflerai": "souffler",
    "souffleraient": "souffler",
    "soufflerais": "souffler",
    "soufflerait": "souffler",
    "souffleras": "souffler",
    "soufflerez": "souffler",
    "souffleriez": "souffler",
    "soufflerions": "souffler",
    "soufflerons": "souffler",
    "souffleront": "souffler",
    "souffles": "souffler",
    "souffleta": "souffleter",
    "souffletai": "souffleter",
    "souffletaient": "souffleter",
    "souffletais": "souffleter",
    "souffletait": "souffleter",
    "souffletant": "souffleter",
    "souffletas": "souffleter",
    "souffletasse": "souffleter",
    "souffletassent": "souffleter",
    "souffletasses": "souffleter",
    "souffletassiez": "souffleter",
    "souffletassions": "souffleter",
    "souffletez": "souffleter",
    "souffletiez": "souffleter",
    "souffletions": "souffleter",
    "souffletons": "souffleter",
    "soufflets": "soufflet",
    "soufflette": "souffleter",
    "soufflettent": "souffleter",
    "soufflettera": "souffleter",
    "souffletterai": "souffleter",
    "souffletteraient": "souffleter",
    "souffletterais": "souffleter",
    "souffletterait": "souffleter",
    "souffletteras": "souffleter",
    "souffletterez": "souffleter",
    "souffletteriez": "souffleter",
    "souffletterions": "souffleter",
    "souffletterons": "souffleter",
    "souffletteront": "souffleter",
    "soufflettes": "souffleter",
    "souffletâmes": "souffleter",
    "souffletât": "souffleter",
    "souffletâtes": "souffleter",
    "souffletèrent": "souffleter",
    "souffleté": "souffleter",
    "souffletée": "souffleter",
    "souffletées": "souffleter",
    "souffletés": "souffleter",
    "souffleurs": "souffleur",
    "souffleuse": "souffleur",
    "soufflez": "souffler",
    "souffliez": "souffler",
    "soufflions": "souffler",
    "soufflons": "souffler",
    "soufflures": "soufflure",
    "soufflâmes": "souffler",
    "soufflât": "souffler",
    "soufflâtes": "souffler",
    "soufflèrent": "souffler",
    "soufflé": "souffler",
    "soufflée": "souffler",
    "soufflées": "souffler",
    "soufflés": "souffler",
    "souffraient": "souffrir",
    "souffrais": "souffrir",
    "souffrait": "souffrir",
    "souffrances": "souffrance",
    "souffrant": "souffrir",
    "souffrante": "souffrant",
    "souffrantes": "souffrant",
    "souffrants": "souffrant",
    "souffre": "souffrir",
    "souffrent": "souffrir",
    "souffres": "souffrir",
    "souffreteuse": "souffreteux",
    "souffreteuses": "souffreteux",
    "souffrez": "souffrir",
    "souffriez": "souffrir",
    "souffrions": "souffrir",
    "souffrira": "souffrir",
    "souffrirai": "souffrir",
    "souffriraient": "souffrir",
    "souffrirais": "souffrir",
    "souffrirait": "souffrir",
    "souffriras": "souffrir",
    "souffrirent": "souffrir",
    "souffrirez": "souffrir",
    "souffririez": "souffrir",
    "souffririons": "souffrir",
    "souffrirons": "souffrir",
    "souffriront": "souffrir",
    "souffris": "souffrir",
    "souffrisse": "souffrir",
    "souffrissent": "souffrir",
    "souffrisses": "souffrir",
    "souffrissiez": "souffrir",
    "souffrissions": "souffrir",
    "souffrit": "souffrir",
    "souffrons": "souffrir",
    "souffrîmes": "souffrir",
    "souffrît": "souffrir",
    "souffrîtes": "souffrir",
    "soufis": "soufi",
    "soufra": "soufrer",
    "soufrages": "soufrage",
    "soufrai": "soufrer",
    "soufraient": "soufrer",
    "soufrais": "soufrer",
    "soufrait": "soufrer",
    "soufrant": "soufrer",
    "soufras": "soufrer",
    "soufrasse": "soufrer",
    "soufrassent": "soufrer",
    "soufrasses": "soufrer",
    "soufrassiez": "soufrer",
    "soufrassions": "soufrer",
    "soufre": "soufrer",
    "soufrent": "soufrer",
    "soufrera": "soufrer",
    "soufrerai": "soufrer",
    "soufreraient": "soufrer",
    "soufrerais": "soufrer",
    "soufrerait": "soufrer",
    "soufreras": "soufrer",
    "soufrerez": "soufrer",
    "soufreriez": "soufrer",
    "soufrerions": "soufrer",
    "soufrerons": "soufrer",
    "soufreront": "soufrer",
    "soufres": "soufrer",
    "soufrez": "soufrer",
    "soufriez": "soufrer",
    "soufrions": "soufrer",
    "soufrons": "soufrer",
    "soufrâmes": "soufrer",
    "soufrât": "soufrer",
    "soufrâtes": "soufrer",
    "soufrèrent": "soufrer",
    "soufré": "soufrer",
    "soufrée": "soufrer",
    "soufrées": "soufrer",
    "soufrés": "soufrer",
    "souhaita": "souhaiter",
    "souhaitables": "souhaitable",
    "souhaitai": "souhaiter",
    "souhaitaient": "souhaiter",
    "souhaitais": "souhaiter",
    "souhaitait": "souhaiter",
    "souhaitant": "souhaiter",
    "souhaitas": "souhaiter",
    "souhaitasse": "souhaiter",
    "souhaitassent": "souhaiter",
    "souhaitasses": "souhaiter",
    "souhaitassiez": "souhaiter",
    "souhaitassions": "souhaiter",
    "souhaite": "souhaiter",
    "souhaitent": "souhaiter",
    "souhaitera": "souhaiter",
    "souhaiterai": "souhaiter",
    "souhaiteraient": "souhaiter",
    "souhaiterais": "souhaiter",
    "souhaiterait": "souhaiter",
    "souhaiteras": "souhaiter",
    "souhaiterez": "souhaiter",
    "souhaiteriez": "souhaiter",
    "souhaiterions": "souhaiter",
    "souhaiterons": "souhaiter",
    "souhaiteront": "souhaiter",
    "souhaites": "souhaiter",
    "souhaitez": "souhaiter",
    "souhaitiez": "souhaiter",
    "souhaitions": "souhaiter",
    "souhaitons": "souhaiter",
    "souhaits": "souhait",
    "souhaitâmes": "souhaiter",
    "souhaitât": "souhaiter",
    "souhaitâtes": "souhaiter",
    "souhaitèrent": "souhaiter",
    "souhaité": "souhaiter",
    "souhaitée": "souhaiter",
    "souhaitées": "souhaiter",
    "souhaités": "souhaiter",
    "souilla": "souiller",
    "souillai": "souiller",
    "souillaient": "souiller",
    "souillais": "souiller",
    "souillait": "souiller",
    "souillant": "souiller",
    "souillarde": "souillard",
    "souillas": "souiller",
    "souillasse": "souiller",
    "souillassent": "souiller",
    "souillasses": "souiller",
    "souillassiez": "souiller",
    "souillassions": "souiller",
    "souille": "souiller",
    "souillent": "souiller",
    "souillera": "souiller",
    "souillerai": "souiller",
    "souilleraient": "souiller",
    "souillerais": "souiller",
    "souillerait": "souiller",
    "souilleras": "souiller",
    "souillerez": "souiller",
    "souilleriez": "souiller",
    "souillerions": "souiller",
    "souillerons": "souiller",
    "souilleront": "souiller",
    "souilles": "souiller",
    "souillez": "souiller",
    "souilliez": "souiller",
    "souillions": "souiller",
    "souillonnes": "souillonner",
    "souillons": "souillon",
    "souillures": "souillure",
    "souillâmes": "souiller",
    "souillât": "souiller",
    "souillâtes": "souiller",
    "souillèrent": "souiller",
    "souillé": "souiller",
    "souillée": "souiller",
    "souillées": "souiller",
    "souillés": "souiller",
    "souks": "souk",
    "soulage": "soulager",
    "soulagea": "soulager",
    "soulageai": "soulager",
    "soulageaient": "soulager",
    "soulageais": "soulager",
    "soulageait": "soulager",
    "soulageant": "soulager",
    "soulageas": "soulager",
    "soulageasse": "soulager",
    "soulageassent": "soulager",
    "soulageasses": "soulager",
    "soulageassiez": "soulager",
    "soulageassions": "soulager",
    "soulagements": "soulagement",
    "soulagent": "soulager",
    "soulageons": "soulager",
    "soulagera": "soulager",
    "soulagerai": "soulager",
    "soulageraient": "soulager",
    "soulagerais": "soulager",
    "soulagerait": "soulager",
    "soulageras": "soulager",
    "soulagerez": "soulager",
    "soulageriez": "soulager",
    "soulagerions": "soulager",
    "soulagerons": "soulager",
    "soulageront": "soulager",
    "soulages": "soulager",
    "soulagez": "soulager",
    "soulageâmes": "soulager",
    "soulageât": "soulager",
    "soulageâtes": "soulager",
    "soulagiez": "soulager",
    "soulagions": "soulager",
    "soulagèrent": "soulager",
    "soulagé": "soulager",
    "soulagée": "soulager",
    "soulagées": "soulager",
    "soulagés": "soulager",
    "souleva": "soulever",
    "soulevai": "soulever",
    "soulevaient": "soulever",
    "soulevais": "soulever",
    "soulevait": "soulever",
    "soulevant": "soulever",
    "soulevas": "soulever",
    "soulevasse": "soulever",
    "soulevassent": "soulever",
    "soulevasses": "soulever",
    "soulevassiez": "soulever",
    "soulevassions": "soulever",
    "soulevez": "soulever",
    "souleviez": "soulever",
    "soulevions": "soulever",
    "soulevons": "soulever",
    "soulevâmes": "soulever",
    "soulevât": "soulever",
    "soulevâtes": "soulever",
    "soulevèrent": "soulever",
    "soulevé": "soulever",
    "soulevée": "soulever",
    "soulevées": "soulever",
    "soulevés": "soulever",
    "souliers": "soulier",
    "souligna": "souligner",
    "soulignai": "souligner",
    "soulignaient": "souligner",
    "soulignais": "souligner",
    "soulignait": "souligner",
    "soulignant": "souligner",
    "soulignas": "souligner",
    "soulignasse": "souligner",
    "soulignassent": "souligner",
    "soulignasses": "souligner",
    "soulignassiez": "souligner",
    "soulignassions": "souligner",
    "souligne": "souligner",
    "soulignent": "souligner",
    "soulignera": "souligner",
    "soulignerai": "souligner",
    "souligneraient": "souligner",
    "soulignerais": "souligner",
    "soulignerait": "souligner",
    "souligneras": "souligner",
    "soulignerez": "souligner",
    "souligneriez": "souligner",
    "soulignerions": "souligner",
    "soulignerons": "souligner",
    "souligneront": "souligner",
    "soulignes": "souligner",
    "soulignez": "souligner",
    "souligniez": "souligner",
    "soulignions": "souligner",
    "soulignons": "souligner",
    "soulignâmes": "souligner",
    "soulignât": "souligner",
    "soulignâtes": "souligner",
    "soulignèrent": "souligner",
    "souligné": "souligner",
    "soulignée": "souligner",
    "soulignées": "souligner",
    "soulignés": "souligner",
    "soultes": "soulte",
    "soulève": "soulever",
    "soulèvements": "soulèvement",
    "soulèvent": "soulever",
    "soulèvera": "soulever",
    "soulèverai": "soulever",
    "soulèveraient": "soulever",
    "soulèverais": "soulever",
    "soulèverait": "soulever",
    "soulèveras": "soulever",
    "soulèverez": "soulever",
    "soulèveriez": "soulever",
    "soulèverions": "soulever",
    "soulèverons": "soulever",
    "soulèveront": "soulever",
    "soulèves": "soulever",
    "soumet": "soumettre",
    "soumets": "soumettre",
    "soumettaient": "soumettre",
    "soumettais": "soumettre",
    "soumettait": "soumettre",
    "soumettant": "soumettre",
    "soumette": "soumettre",
    "soumettent": "soumettre",
    "soumettes": "soumettre",
    "soumettez": "soumettre",
    "soumettiez": "soumettre",
    "soumettions": "soumettre",
    "soumettons": "soumettre",
    "soumettra": "soumettre",
    "soumettrai": "soumettre",
    "soumettraient": "soumettre",
    "soumettrais": "soumettre",
    "soumettrait": "soumettre",
    "soumettras": "soumettre",
    "soumettrez": "soumettre",
    "soumettriez": "soumettre",
    "soumettrions": "soumettre",
    "soumettrons": "soumettre",
    "soumettront": "soumettre",
    "soumirent": "soumettre",
    "soumis": "soumettre",
    "soumise": "soumis",
    "soumises": "soumis",
    "soumisse": "soumettre",
    "soumissent": "soumettre",
    "soumisses": "soumettre",
    "soumissiez": "soumettre",
    "soumissionna": "soumissionner",
    "soumissionnai": "soumissionner",
    "soumissionnaient": "soumissionner",
    "soumissionnaires": "soumissionnaire",
    "soumissionnais": "soumissionner",
    "soumissionnait": "soumissionner",
    "soumissionnant": "soumissionner",
    "soumissionnas": "soumissionner",
    "soumissionnasse": "soumissionner",
    "soumissionnassent": "soumissionner",
    "soumissionnasses": "soumissionner",
    "soumissionnassiez": "soumissionner",
    "soumissionnassions": "soumissionner",
    "soumissionne": "soumissionner",
    "soumissionnent": "soumissionner",
    "soumissionnera": "soumissionner",
    "soumissionnerai": "soumissionner",
    "soumissionneraient": "soumissionner",
    "soumissionnerais": "soumissionner",
    "soumissionnerait": "soumissionner",
    "soumissionneras": "soumissionner",
    "soumissionnerez": "soumissionner",
    "soumissionneriez": "soumissionner",
    "soumissionnerions": "soumissionner",
    "soumissionnerons": "soumissionner",
    "soumissionneront": "soumissionner",
    "soumissionnes": "soumissionner",
    "soumissionnez": "soumissionner",
    "soumissionniez": "soumissionner",
    "soumissionnions": "soumissionner",
    "soumissionnons": "soumissionner",
    "soumissionnâmes": "soumissionner",
    "soumissionnât": "soumissionner",
    "soumissionnâtes": "soumissionner",
    "soumissionnèrent": "soumissionner",
    "soumissionné": "soumissionner",
    "soumissionnée": "soumissionner",
    "soumissionnées": "soumissionner",
    "soumissionnés": "soumissionner",
    "soumissions": "soumission",
    "soumit": "soumettre",
    "soumîmes": "soumettre",
    "soumît": "soumettre",
    "soumîtes": "soumettre",
    "soupa": "souper",
    "soupai": "souper",
    "soupaient": "souper",
    "soupais": "souper",
    "soupait": "souper",
    "soupant": "souper",
    "soupapes": "soupape",
    "soupas": "souper",
    "soupasse": "souper",
    "soupassent": "souper",
    "soupasses": "souper",
    "soupassiez": "souper",
    "soupassions": "souper",
    "soupe": "souper",
    "soupent": "souper",
    "soupentes": "soupente",
    "soupera": "souper",
    "souperai": "souper",
    "souperaient": "souper",
    "souperais": "souper",
    "souperait": "souper",
    "souperas": "souper",
    "souperez": "souper",
    "souperiez": "souper",
    "souperions": "souper",
    "souperons": "souper",
    "souperont": "souper",
    "soupers": "souper",
    "soupes": "souper",
    "soupesa": "soupeser",
    "soupesai": "soupeser",
    "soupesaient": "soupeser",
    "soupesais": "soupeser",
    "soupesait": "soupeser",
    "soupesant": "soupeser",
    "soupesas": "soupeser",
    "soupesasse": "soupeser",
    "soupesassent": "soupeser",
    "soupesasses": "soupeser",
    "soupesassiez": "soupeser",
    "soupesassions": "soupeser",
    "soupesez": "soupeser",
    "soupesiez": "soupeser",
    "soupesions": "soupeser",
    "soupesons": "soupeser",
    "soupesâmes": "soupeser",
    "soupesât": "soupeser",
    "soupesâtes": "soupeser",
    "soupesèrent": "soupeser",
    "soupesé": "soupeser",
    "soupesée": "soupeser",
    "soupesées": "soupeser",
    "soupesés": "soupeser",
    "soupeurs": "soupeur",
    "soupez": "souper",
    "soupiez": "souper",
    "soupions": "souper",
    "soupira": "soupirer",
    "soupirai": "soupirer",
    "soupiraient": "soupirer",
    "soupirais": "soupirer",
    "soupirait": "soupirer",
    "soupirant": "soupirer",
    "soupirants": "soupirant",
    "soupiras": "soupirer",
    "soupirasse": "soupirer",
    "soupirassent": "soupirer",
    "soupirasses": "soupirer",
    "soupirassiez": "soupirer",
    "soupirassions": "soupirer",
    "soupiraux": "soupirail",
    "soupire": "soupirer",
    "soupirent": "soupirer",
    "soupirera": "soupirer",
    "soupirerai": "soupirer",
    "soupireraient": "soupirer",
    "soupirerais": "soupirer",
    "soupirerait": "soupirer",
    "soupireras": "soupirer",
    "soupirerez": "soupirer",
    "soupireriez": "soupirer",
    "soupirerions": "soupirer",
    "soupirerons": "soupirer",
    "soupireront": "soupirer",
    "soupires": "soupirer",
    "soupirez": "soupirer",
    "soupiriez": "soupirer",
    "soupirions": "soupirer",
    "soupirons": "soupirer",
    "soupirs": "soupir",
    "soupirâmes": "soupirer",
    "soupirât": "soupirer",
    "soupirâtes": "soupirer",
    "soupirèrent": "soupirer",
    "soupiré": "soupirer",
    "soupirée": "soupirer",
    "soupirées": "soupirer",
    "soupirés": "soupirer",
    "soupières": "soupière",
    "souples": "souple",
    "souplesses": "souplesse",
    "soupons": "souper",
    "soupâmes": "souper",
    "soupât": "souper",
    "soupâtes": "souper",
    "soupçonna": "soupçonner",
    "soupçonnai": "soupçonner",
    "soupçonnaient": "soupçonner",
    "soupçonnais": "soupçonner",
    "soupçonnait": "soupçonner",
    "soupçonnant": "soupçonner",
    "soupçonnas": "soupçonner",
    "soupçonnasse": "soupçonner",
    "soupçonnassent": "soupçonner",
    "soupçonnasses": "soupçonner",
    "soupçonnassiez": "soupçonner",
    "soupçonnassions": "soupçonner",
    "soupçonne": "soupçonner",
    "soupçonnent": "soupçonner",
    "soupçonnera": "soupçonner",
    "soupçonnerai": "soupçonner",
    "soupçonneraient": "soupçonner",
    "soupçonnerais": "soupçonner",
    "soupçonnerait": "soupçonner",
    "soupçonneras": "soupçonner",
    "soupçonnerez": "soupçonner",
    "soupçonneriez": "soupçonner",
    "soupçonnerions": "soupçonner",
    "soupçonnerons": "soupçonner",
    "soupçonneront": "soupçonner",
    "soupçonnes": "soupçonner",
    "soupçonneuse": "soupçonneux",
    "soupçonneuses": "soupçonneux",
    "soupçonnez": "soupçonner",
    "soupçonniez": "soupçonner",
    "soupçonnions": "soupçonner",
    "soupçonnons": "soupçonner",
    "soupçonnâmes": "soupçonner",
    "soupçonnât": "soupçonner",
    "soupçonnâtes": "soupçonner",
    "soupçonnèrent": "soupçonner",
    "soupçonné": "soupçonner",
    "soupçonnée": "soupçonner",
    "soupçonnées": "soupçonner",
    "soupçonnés": "soupçonner",
    "soupçons": "soupçon",
    "soupèrent": "souper",
    "soupèse": "soupeser",
    "soupèsent": "soupeser",
    "soupèsera": "soupeser",
    "soupèserai": "soupeser",
    "soupèseraient": "soupeser",
    "soupèserais": "soupeser",
    "soupèserait": "soupeser",
    "soupèseras": "soupeser",
    "soupèserez": "soupeser",
    "soupèseriez": "soupeser",
    "soupèserions": "soupeser",
    "soupèserons": "soupeser",
    "soupèseront": "soupeser",
    "soupèses": "soupeser",
    "soupé": "souper",
    "souqua": "souquer",
    "souquai": "souquer",
    "souquaient": "souquer",
    "souquais": "souquer",
    "souquait": "souquer",
    "souquant": "souquer",
    "souquas": "souquer",
    "souquasse": "souquer",
    "souquassent": "souquer",
    "souquasses": "souquer",
    "souquassiez": "souquer",
    "souquassions": "souquer",
    "souque": "souquer",
    "souquenilles": "souquenille",
    "souquent": "souquer",
    "souquera": "souquer",
    "souquerai": "souquer",
    "souqueraient": "souquer",
    "souquerais": "souquer",
    "souquerait": "souquer",
    "souqueras": "souquer",
    "souquerez": "souquer",
    "souqueriez": "souquer",
    "souquerions": "souquer",
    "souquerons": "souquer",
    "souqueront": "souquer",
    "souques": "souquer",
    "souquez": "souquer",
    "souquiez": "souquer",
    "souquions": "souquer",
    "souquons": "souquer",
    "souquâmes": "souquer",
    "souquât": "souquer",
    "souquâtes": "souquer",
    "souquèrent": "souquer",
    "souqué": "souquer",
    "souquée": "souquer",
    "souquées": "souquer",
    "souqués": "souquer",
    "sourates": "sourate",
    "sources": "source",
    "sourciers": "sourcier",
    "sourcilière": "sourcilier",
    "sourcilières": "sourcilier",
    "sourcilla": "sourciller",
    "sourcillai": "sourciller",
    "sourcillaient": "sourciller",
    "sourcillais": "sourciller",
    "sourcillait": "sourciller",
    "sourcillant": "sourciller",
    "sourcillas": "sourciller",
    "sourcillasse": "sourciller",
    "sourcillassent": "sourciller",
    "sourcillasses": "sourciller",
    "sourcillassiez": "sourciller",
    "sourcillassions": "sourciller",
    "sourcille": "sourciller",
    "sourcillent": "sourciller",
    "sourcillera": "sourciller",
    "sourcillerai": "sourciller",
    "sourcilleraient": "sourciller",
    "sourcillerais": "sourciller",
    "sourcillerait": "sourciller",
    "sourcilleras": "sourciller",
    "sourcillerez": "sourciller",
    "sourcilleriez": "sourciller",
    "sourcillerions": "sourciller",
    "sourcillerons": "sourciller",
    "sourcilleront": "sourciller",
    "sourcilles": "sourciller",
    "sourcilleuse": "sourcilleux",
    "sourcilleuses": "sourcilleux",
    "sourcillez": "sourciller",
    "sourcilliez": "sourciller",
    "sourcillions": "sourciller",
    "sourcillons": "sourciller",
    "sourcillâmes": "sourciller",
    "sourcillât": "sourciller",
    "sourcillâtes": "sourciller",
    "sourcillèrent": "sourciller",
    "sourcillé": "sourciller",
    "sourcils": "sourcil",
    "sourd": "sourdre",
    "sourdaient": "sourdre",
    "sourdait": "sourdre",
    "sourdant": "sourdre",
    "sourde": "sourdre",
    "sourde-muette": "sourd-muet",
    "sourdent": "sourdre",
    "sourdes": "sourd",
    "sourdes-muettes": "sourd-muet",
    "sourdines": "sourdine",
    "sourdingues": "sourdingue",
    "sourdront": "sourdre",
    "sourds": "sourdre",
    "sourds-muets": "sourd-muet",
    "souri": "sourire",
    "souriaient": "sourire",
    "souriais": "sourire",
    "souriait": "sourire",
    "souriant": "sourire",
    "souriante": "souriant",
    "souriantes": "souriant",
    "souriants": "souriant",
    "souriceaux": "souriceau",
    "souricières": "souricière",
    "sourie": "sourire",
    "sourient": "sourire",
    "souries": "sourire",
    "souriez": "sourire",
    "souriiez": "sourire",
    "souriions": "sourire",
    "sourions": "sourire",
    "sourira": "sourire",
    "sourirai": "sourire",
    "souriraient": "sourire",
    "sourirais": "sourire",
    "sourirait": "sourire",
    "souriras": "sourire",
    "sourirent": "sourire",
    "sourires": "sourire",
    "sourirez": "sourire",
    "souririez": "sourire",
    "souririons": "sourire",
    "sourirons": "sourire",
    "souriront": "sourire",
    "souris": "sourire",
    "sourisse": "sourire",
    "sourissent": "sourire",
    "sourisses": "sourire",
    "sourissiez": "sourire",
    "sourissions": "sourire",
    "sourit": "sourire",
    "sournoise": "sournois",
    "sournoiseries": "sournoiserie",
    "sournoises": "sournois",
    "sourîmes": "sourire",
    "sourît": "sourire",
    "sourîtes": "sourire",
    "sous": "sou",
    "sous-alimenta": "sous-alimenter",
    "sous-alimentai": "sous-alimenter",
    "sous-alimentaient": "sous-alimenter",
    "sous-alimentais": "sous-alimenter",
    "sous-alimentait": "sous-alimenter",
    "sous-alimentant": "sous-alimenter",
    "sous-alimentas": "sous-alimenter",
    "sous-alimentasse": "sous-alimenter",
    "sous-alimentassent": "sous-alimenter",
    "sous-alimentasses": "sous-alimenter",
    "sous-alimentassiez": "sous-alimenter",
    "sous-alimentassions": "sous-alimenter",
    "sous-alimentations": "sous-alimentation",
    "sous-alimente": "sous-alimenter",
    "sous-alimentent": "sous-alimenter",
    "sous-alimentera": "sous-alimenter",
    "sous-alimenterai": "sous-alimenter",
    "sous-alimenteraient": "sous-alimenter",
    "sous-alimenterais": "sous-alimenter",
    "sous-alimenterait": "sous-alimenter",
    "sous-alimenteras": "sous-alimenter",
    "sous-alimenterez": "sous-alimenter",
    "sous-alimenteriez": "sous-alimenter",
    "sous-alimenterions": "sous-alimenter",
    "sous-alimenterons": "sous-alimenter",
    "sous-alimenteront": "sous-alimenter",
    "sous-alimentes": "sous-alimenter",
    "sous-alimentez": "sous-alimenter",
    "sous-alimentiez": "sous-alimenter",
    "sous-alimentions": "sous-alimenter",
    "sous-alimentons": "sous-alimenter",
    "sous-alimentâmes": "sous-alimenter",
    "sous-alimentât": "sous-alimenter",
    "sous-alimentâtes": "sous-alimenter",
    "sous-alimentèrent": "sous-alimenter",
    "sous-alimenté": "sous-alimenter",
    "sous-alimentée": "sous-alimenter",
    "sous-alimentées": "sous-alimenter",
    "sous-alimentés": "sous-alimenter",
    "sous-amendements": "sous-amendement",
    "sous-chefs": "sous-chef",
    "sous-classes": "sous-classe",
    "sous-clavière": "sous-clavier",
    "sous-commissions": "sous-commission",
    "sous-consommations": "sous-consommation",
    "sous-continents": "sous-continent",
    "sous-cutanée": "sous-cutané",
    "sous-cutanées": "sous-cutané",
    "sous-cutanés": "sous-cutané",
    "sous-directeurs": "sous-directeur",
    "sous-directrice": "sous-directeur",
    "sous-directrices": "sous-directeur",
    "sous-délégués": "sous-délégué",
    "sous-développée": "sous-développé",
    "sous-développées": "sous-développé",
    "sous-développés": "sous-développé",
    "sous-effectifs": "sous-effectif",
    "sous-emploie": "sous-employer",
    "sous-emploient": "sous-employer",
    "sous-emploiera": "sous-employer",
    "sous-emploierai": "sous-employer",
    "sous-emploieraient": "sous-employer",
    "sous-emploierais": "sous-employer",
    "sous-emploierait": "sous-employer",
    "sous-emploieras": "sous-employer",
    "sous-emploierez": "sous-employer",
    "sous-emploieriez": "sous-employer",
    "sous-emploierions": "sous-employer",
    "sous-emploierons": "sous-employer",
    "sous-emploieront": "sous-employer",
    "sous-emploies": "sous-employer",
    "sous-emplois": "sous-emploi",
    "sous-employa": "sous-employer",
    "sous-employai": "sous-employer",
    "sous-employaient": "sous-employer",
    "sous-employais": "sous-employer",
    "sous-employait": "sous-employer",
    "sous-employant": "sous-employer",
    "sous-employas": "sous-employer",
    "sous-employasse": "sous-employer",
    "sous-employassent": "sous-employer",
    "sous-employasses": "sous-employer",
    "sous-employassiez": "sous-employer",
    "sous-employassions": "sous-employer",
    "sous-employez": "sous-employer",
    "sous-employiez": "sous-employer",
    "sous-employions": "sous-employer",
    "sous-employons": "sous-employer",
    "sous-employâmes": "sous-employer",
    "sous-employât": "sous-employer",
    "sous-employâtes": "sous-employer",
    "sous-employèrent": "sous-employer",
    "sous-employé": "sous-employer",
    "sous-employée": "sous-employer",
    "sous-employées": "sous-employer",
    "sous-employés": "sous-employer",
    "sous-entend": "sous-entendre",
    "sous-entendaient": "sous-entendre",
    "sous-entendais": "sous-entendre",
    "sous-entendait": "sous-entendre",
    "sous-entendant": "sous-entendre",
    "sous-entende": "sous-entendre",
    "sous-entendent": "sous-entendre",
    "sous-entendes": "sous-entendre",
    "sous-entendez": "sous-entendre",
    "sous-entendiez": "sous-entendre",
    "sous-entendions": "sous-entendre",
    "sous-entendirent": "sous-entendre",
    "sous-entendis": "sous-entendre",
    "sous-entendisse": "sous-entendre",
    "sous-entendissent": "sous-entendre",
    "sous-entendisses": "sous-entendre",
    "sous-entendissiez": "sous-entendre",
    "sous-entendissions": "sous-entendre",
    "sous-entendit": "sous-entendre",
    "sous-entendons": "sous-entendre",
    "sous-entendra": "sous-entendre",
    "sous-entendrai": "sous-entendre",
    "sous-entendraient": "sous-entendre",
    "sous-entendrais": "sous-entendre",
    "sous-entendrait": "sous-entendre",
    "sous-entendras": "sous-entendre",
    "sous-entendrez": "sous-entendre",
    "sous-entendriez": "sous-entendre",
    "sous-entendrions": "sous-entendre",
    "sous-entendrons": "sous-entendre",
    "sous-entendront": "sous-entendre",
    "sous-entends": "sous-entendre",
    "sous-entendu": "sous-entendre",
    "sous-entendue": "sous-entendu",
    "sous-entendues": "sous-entendre",
    "sous-entendus": "sous-entendu",
    "sous-entendîmes": "sous-entendre",
    "sous-entendît": "sous-entendre",
    "sous-entendîtes": "sous-entendre",
    "sous-estima": "sous-estimer",
    "sous-estimai": "sous-estimer",
    "sous-estimaient": "sous-estimer",
    "sous-estimais": "sous-estimer",
    "sous-estimait": "sous-estimer",
    "sous-estimant": "sous-estimer",
    "sous-estimas": "sous-estimer",
    "sous-estimasse": "sous-estimer",
    "sous-estimassent": "sous-estimer",
    "sous-estimasses": "sous-estimer",
    "sous-estimassiez": "sous-estimer",
    "sous-estimassions": "sous-estimer",
    "sous-estime": "sous-estimer",
    "sous-estiment": "sous-estimer",
    "sous-estimera": "sous-estimer",
    "sous-estimerai": "sous-estimer",
    "sous-estimeraient": "sous-estimer",
    "sous-estimerais": "sous-estimer",
    "sous-estimerait": "sous-estimer",
    "sous-estimeras": "sous-estimer",
    "sous-estimerez": "sous-estimer",
    "sous-estimeriez": "sous-estimer",
    "sous-estimerions": "sous-estimer",
    "sous-estimerons": "sous-estimer",
    "sous-estimeront": "sous-estimer",
    "sous-estimes": "sous-estimer",
    "sous-estimez": "sous-estimer",
    "sous-estimiez": "sous-estimer",
    "sous-estimions": "sous-estimer",
    "sous-estimons": "sous-estimer",
    "sous-estimâmes": "sous-estimer",
    "sous-estimât": "sous-estimer",
    "sous-estimâtes": "sous-estimer",
    "sous-estimèrent": "sous-estimer",
    "sous-estimé": "sous-estimer",
    "sous-estimée": "sous-estimer",
    "sous-estimées": "sous-estimer",
    "sous-estimés": "sous-estimer",
    "sous-exploita": "sous-exploiter",
    "sous-exploitai": "sous-exploiter",
    "sous-exploitaient": "sous-exploiter",
    "sous-exploitais": "sous-exploiter",
    "sous-exploitait": "sous-exploiter",
    "sous-exploitant": "sous-exploiter",
    "sous-exploitas": "sous-exploiter",
    "sous-exploitasse": "sous-exploiter",
    "sous-exploitassent": "sous-exploiter",
    "sous-exploitasses": "sous-exploiter",
    "sous-exploitassiez": "sous-exploiter",
    "sous-exploitassions": "sous-exploiter",
    "sous-exploite": "sous-exploiter",
    "sous-exploitent": "sous-exploiter",
    "sous-exploitera": "sous-exploiter",
    "sous-exploiterai": "sous-exploiter",
    "sous-exploiteraient": "sous-exploiter",
    "sous-exploiterais": "sous-exploiter",
    "sous-exploiterait": "sous-exploiter",
    "sous-exploiteras": "sous-exploiter",
    "sous-exploiterez": "sous-exploiter",
    "sous-exploiteriez": "sous-exploiter",
    "sous-exploiterions": "sous-exploiter",
    "sous-exploiterons": "sous-exploiter",
    "sous-exploiteront": "sous-exploiter",
    "sous-exploites": "sous-exploiter",
    "sous-exploitez": "sous-exploiter",
    "sous-exploitiez": "sous-exploiter",
    "sous-exploitions": "sous-exploiter",
    "sous-exploitons": "sous-exploiter",
    "sous-exploitâmes": "sous-exploiter",
    "sous-exploitât": "sous-exploiter",
    "sous-exploitâtes": "sous-exploiter",
    "sous-exploitèrent": "sous-exploiter",
    "sous-exploité": "sous-exploiter",
    "sous-exploitée": "sous-exploiter",
    "sous-exploitées": "sous-exploiter",
    "sous-exploités": "sous-exploiter",
    "sous-exposa": "sous-exposer",
    "sous-exposai": "sous-exposer",
    "sous-exposaient": "sous-exposer",
    "sous-exposais": "sous-exposer",
    "sous-exposait": "sous-exposer",
    "sous-exposant": "sous-exposer",
    "sous-exposas": "sous-exposer",
    "sous-exposasse": "sous-exposer",
    "sous-exposassent": "sous-exposer",
    "sous-exposasses": "sous-exposer",
    "sous-exposassiez": "sous-exposer",
    "sous-exposassions": "sous-exposer",
    "sous-expose": "sous-exposer",
    "sous-exposent": "sous-exposer",
    "sous-exposera": "sous-exposer",
    "sous-exposerai": "sous-exposer",
    "sous-exposeraient": "sous-exposer",
    "sous-exposerais": "sous-exposer",
    "sous-exposerait": "sous-exposer",
    "sous-exposeras": "sous-exposer",
    "sous-exposerez": "sous-exposer",
    "sous-exposeriez": "sous-exposer",
    "sous-exposerions": "sous-exposer",
    "sous-exposerons": "sous-exposer",
    "sous-exposeront": "sous-exposer",
    "sous-exposes": "sous-exposer",
    "sous-exposez": "sous-exposer",
    "sous-exposiez": "sous-exposer",
    "sous-exposions": "sous-exposer",
    "sous-exposons": "sous-exposer",
    "sous-exposâmes": "sous-exposer",
    "sous-exposât": "sous-exposer",
    "sous-exposâtes": "sous-exposer",
    "sous-exposèrent": "sous-exposer",
    "sous-exposé": "sous-exposer",
    "sous-exposée": "sous-exposer",
    "sous-exposées": "sous-exposer",
    "sous-exposés": "sous-exposer",
    "sous-fifres": "sous-fifre",
    "sous-hommes": "sous-homme",
    "sous-intendants": "sous-intendant",
    "sous-jacente": "sous-jacent",
    "sous-jacentes": "sous-jacent",
    "sous-jacents": "sous-jacent",
    "sous-lieutenants": "sous-lieutenant",
    "sous-locataires": "sous-locataire",
    "sous-locations": "sous-location",
    "sous-loua": "sous-louer",
    "sous-louai": "sous-louer",
    "sous-louaient": "sous-louer",
    "sous-louais": "sous-louer",
    "sous-louait": "sous-louer",
    "sous-louant": "sous-louer",
    "sous-louas": "sous-louer",
    "sous-louasse": "sous-louer",
    "sous-louassent": "sous-louer",
    "sous-louasses": "sous-louer",
    "sous-louassiez": "sous-louer",
    "sous-louassions": "sous-louer",
    "sous-loue": "sous-louer",
    "sous-louent": "sous-louer",
    "sous-louera": "sous-louer",
    "sous-louerai": "sous-louer",
    "sous-loueraient": "sous-louer",
    "sous-louerais": "sous-louer",
    "sous-louerait": "sous-louer",
    "sous-loueras": "sous-louer",
    "sous-louerez": "sous-louer",
    "sous-loueriez": "sous-louer",
    "sous-louerions": "sous-louer",
    "sous-louerons": "sous-louer",
    "sous-loueront": "sous-louer",
    "sous-loues": "sous-louer",
    "sous-louez": "sous-louer",
    "sous-louiez": "sous-louer",
    "sous-louions": "sous-louer",
    "sous-louons": "sous-louer",
    "sous-louâmes": "sous-louer",
    "sous-louât": "sous-louer",
    "sous-louâtes": "sous-louer",
    "sous-louèrent": "sous-louer",
    "sous-loué": "sous-louer",
    "sous-louée": "sous-louer",
    "sous-louées": "sous-louer",
    "sous-loués": "sous-louer",
    "sous-marine": "sous-marin",
    "sous-marines": "sous-marin",
    "sous-mariniers": "sous-marinier",
    "sous-marins": "sous-marin",
    "sous-marques": "sous-marque",
    "sous-merdes": "sous-merde",
    "sous-multiples": "sous-multiple",
    "sous-oeuvres": "sous-oeuvre",
    "sous-officiers": "sous-officier",
    "sous-offs": "sous-off",
    "sous-ordres": "sous-ordre",
    "sous-paie": "sous-payer",
    "sous-paient": "sous-payer",
    "sous-paiera": "sous-payer",
    "sous-paierai": "sous-payer",
    "sous-paieraient": "sous-payer",
    "sous-paierais": "sous-payer",
    "sous-paierait": "sous-payer",
    "sous-paieras": "sous-payer",
    "sous-paierez": "sous-payer",
    "sous-paieriez": "sous-payer",
    "sous-paierions": "sous-payer",
    "sous-paierons": "sous-payer",
    "sous-paieront": "sous-payer",
    "sous-paies": "sous-payer",
    "sous-paya": "sous-payer",
    "sous-payai": "sous-payer",
    "sous-payaient": "sous-payer",
    "sous-payais": "sous-payer",
    "sous-payait": "sous-payer",
    "sous-payant": "sous-payer",
    "sous-payas": "sous-payer",
    "sous-payasse": "sous-payer",
    "sous-payassent": "sous-payer",
    "sous-payasses": "sous-payer",
    "sous-payassiez": "sous-payer",
    "sous-payassions": "sous-payer",
    "sous-paye": "sous-payer",
    "sous-payent": "sous-payer",
    "sous-payera": "sous-payer",
    "sous-payerai": "sous-payer",
    "sous-payeraient": "sous-payer",
    "sous-payerais": "sous-payer",
    "sous-payerait": "sous-payer",
    "sous-payeras": "sous-payer",
    "sous-payerez": "sous-payer",
    "sous-payeriez": "sous-payer",
    "sous-payerions": "sous-payer",
    "sous-payerons": "sous-payer",
    "sous-payeront": "sous-payer",
    "sous-payes": "sous-payer",
    "sous-payez": "sous-payer",
    "sous-payiez": "sous-payer",
    "sous-payions": "sous-payer",
    "sous-payons": "sous-payer",
    "sous-payâmes": "sous-payer",
    "sous-payât": "sous-payer",
    "sous-payâtes": "sous-payer",
    "sous-payèrent": "sous-payer",
    "sous-payé": "sous-payer",
    "sous-payée": "sous-payer",
    "sous-payées": "sous-payer",
    "sous-payés": "sous-payer",
    "sous-peuplée": "sous-peuplé",
    "sous-peuplées": "sous-peuplé",
    "sous-peuplés": "sous-peuplé",
    "sous-pieds": "sous-pied",
    "sous-produits": "sous-produit",
    "sous-programmes": "sous-programme",
    "sous-prolétaires": "sous-prolétaire",
    "sous-préfectures": "sous-préfecture",
    "sous-préfets": "sous-préfet",
    "sous-préfète": "sous-préfet",
    "sous-préfètes": "sous-préfet",
    "sous-pulls": "sous-pull",
    "sous-qualifiée": "sous-qualifié",
    "sous-secrétaires": "sous-secrétaire",
    "sous-secrétariats": "sous-secrétariat",
    "sous-sols": "sous-sol",
    "sous-stations": "sous-station",
    "sous-tasses": "sous-tasse",
    "sous-tend": "sous-tendre",
    "sous-tendaient": "sous-tendre",
    "sous-tendais": "sous-tendre",
    "sous-tendait": "sous-tendre",
    "sous-tendant": "sous-tendre",
    "sous-tende": "sous-tendre",
    "sous-tendent": "sous-tendre",
    "sous-tendes": "sous-tendre",
    "sous-tendez": "sous-tendre",
    "sous-tendiez": "sous-tendre",
    "sous-tendions": "sous-tendre",
    "sous-tendirent": "sous-tendre",
    "sous-tendis": "sous-tendre",
    "sous-tendisse": "sous-tendre",
    "sous-tendissent": "sous-tendre",
    "sous-tendisses": "sous-tendre",
    "sous-tendissiez": "sous-tendre",
    "sous-tendissions": "sous-tendre",
    "sous-tendit": "sous-tendre",
    "sous-tendons": "sous-tendre",
    "sous-tendra": "sous-tendre",
    "sous-tendrai": "sous-tendre",
    "sous-tendraient": "sous-tendre",
    "sous-tendrais": "sous-tendre",
    "sous-tendrait": "sous-tendre",
    "sous-tendras": "sous-tendre",
    "sous-tendrez": "sous-tendre",
    "sous-tendriez": "sous-tendre",
    "sous-tendrions": "sous-tendre",
    "sous-tendrons": "sous-tendre",
    "sous-tendront": "sous-tendre",
    "sous-tends": "sous-tendre",
    "sous-tendu": "sous-tendre",
    "sous-tendue": "sous-tendre",
    "sous-tendues": "sous-tendre",
    "sous-tendus": "sous-tendre",
    "sous-tendîmes": "sous-tendre",
    "sous-tendît": "sous-tendre",
    "sous-tendîtes": "sous-tendre",
    "sous-titra": "sous-titrer",
    "sous-titrai": "sous-titrer",
    "sous-titraient": "sous-titrer",
    "sous-titrais": "sous-titrer",
    "sous-titrait": "sous-titrer",
    "sous-titrant": "sous-titrer",
    "sous-titras": "sous-titrer",
    "sous-titrasse": "sous-titrer",
    "sous-titrassent": "sous-titrer",
    "sous-titrasses": "sous-titrer",
    "sous-titrassiez": "sous-titrer",
    "sous-titrassions": "sous-titrer",
    "sous-titre": "sous-titrer",
    "sous-titrent": "sous-titrer",
    "sous-titrera": "sous-titrer",
    "sous-titrerai": "sous-titrer",
    "sous-titreraient": "sous-titrer",
    "sous-titrerais": "sous-titrer",
    "sous-titrerait": "sous-titrer",
    "sous-titreras": "sous-titrer",
    "sous-titrerez": "sous-titrer",
    "sous-titreriez": "sous-titrer",
    "sous-titrerions": "sous-titrer",
    "sous-titrerons": "sous-titrer",
    "sous-titreront": "sous-titrer",
    "sous-titres": "sous-titrer",
    "sous-titrez": "sous-titrer",
    "sous-titriez": "sous-titrer",
    "sous-titrions": "sous-titrer",
    "sous-titrons": "sous-titrer",
    "sous-titrâmes": "sous-titrer",
    "sous-titrât": "sous-titrer",
    "sous-titrâtes": "sous-titrer",
    "sous-titrèrent": "sous-titrer",
    "sous-titré": "sous-titrer",
    "sous-titrée": "sous-titrer",
    "sous-titrées": "sous-titrer",
    "sous-titrés": "sous-titrer",
    "sous-traita": "sous-traiter",
    "sous-traitai": "sous-traiter",
    "sous-traitaient": "sous-traiter",
    "sous-traitais": "sous-traiter",
    "sous-traitait": "sous-traiter",
    "sous-traitant": "sous-traiter",
    "sous-traitante": "sous-traitant",
    "sous-traitantes": "sous-traitant",
    "sous-traitants": "sous-traitant",
    "sous-traitas": "sous-traiter",
    "sous-traitasse": "sous-traiter",
    "sous-traitassent": "sous-traiter",
    "sous-traitasses": "sous-traiter",
    "sous-traitassiez": "sous-traiter",
    "sous-traitassions": "sous-traiter",
    "sous-traite": "sous-traiter",
    "sous-traitent": "sous-traiter",
    "sous-traitera": "sous-traiter",
    "sous-traiterai": "sous-traiter",
    "sous-traiteraient": "sous-traiter",
    "sous-traiterais": "sous-traiter",
    "sous-traiterait": "sous-traiter",
    "sous-traiteras": "sous-traiter",
    "sous-traiterez": "sous-traiter",
    "sous-traiteriez": "sous-traiter",
    "sous-traiterions": "sous-traiter",
    "sous-traiterons": "sous-traiter",
    "sous-traiteront": "sous-traiter",
    "sous-traites": "sous-traiter",
    "sous-traitez": "sous-traiter",
    "sous-traitiez": "sous-traiter",
    "sous-traitions": "sous-traiter",
    "sous-traitons": "sous-traiter",
    "sous-traitâmes": "sous-traiter",
    "sous-traitât": "sous-traiter",
    "sous-traitâtes": "sous-traiter",
    "sous-traitèrent": "sous-traiter",
    "sous-traité": "sous-traiter",
    "sous-traitée": "sous-traiter",
    "sous-traitées": "sous-traiter",
    "sous-traités": "sous-traiter",
    "sous-ventrières": "sous-ventrière",
    "sous-verres": "sous-verre",
    "sous-vira": "sous-virer",
    "sous-virai": "sous-virer",
    "sous-viraient": "sous-virer",
    "sous-virais": "sous-virer",
    "sous-virait": "sous-virer",
    "sous-virant": "sous-virer",
    "sous-viras": "sous-virer",
    "sous-virasse": "sous-virer",
    "sous-virassent": "sous-virer",
    "sous-virasses": "sous-virer",
    "sous-virassiez": "sous-virer",
    "sous-virassions": "sous-virer",
    "sous-vire": "sous-virer",
    "sous-virent": "sous-virer",
    "sous-virera": "sous-virer",
    "sous-virerai": "sous-virer",
    "sous-vireraient": "sous-virer",
    "sous-virerais": "sous-virer",
    "sous-virerait": "sous-virer",
    "sous-vireras": "sous-virer",
    "sous-virerez": "sous-virer",
    "sous-vireriez": "sous-virer",
    "sous-virerions": "sous-virer",
    "sous-virerons": "sous-virer",
    "sous-vireront": "sous-virer",
    "sous-vires": "sous-virer",
    "sous-virez": "sous-virer",
    "sous-viriez": "sous-virer",
    "sous-virions": "sous-virer",
    "sous-virons": "sous-virer",
    "sous-virâmes": "sous-virer",
    "sous-virât": "sous-virer",
    "sous-virâtes": "sous-virer",
    "sous-virèrent": "sous-virer",
    "sous-viré": "sous-virer",
    "sous-vêtements": "sous-vêtement",
    "sous-équipements": "sous-équipement",
    "sous-équipée": "sous-équipé",
    "sous-équipées": "sous-équipé",
    "sous-équipés": "sous-équipé",
    "sous-évalua": "sous-évaluer",
    "sous-évaluai": "sous-évaluer",
    "sous-évaluaient": "sous-évaluer",
    "sous-évaluais": "sous-évaluer",
    "sous-évaluait": "sous-évaluer",
    "sous-évaluant": "sous-évaluer",
    "sous-évaluas": "sous-évaluer",
    "sous-évaluasse": "sous-évaluer",
    "sous-évaluassent": "sous-évaluer",
    "sous-évaluasses": "sous-évaluer",
    "sous-évaluassiez": "sous-évaluer",
    "sous-évaluassions": "sous-évaluer",
    "sous-évalue": "sous-évaluer",
    "sous-évaluent": "sous-évaluer",
    "sous-évaluera": "sous-évaluer",
    "sous-évaluerai": "sous-évaluer",
    "sous-évalueraient": "sous-évaluer",
    "sous-évaluerais": "sous-évaluer",
    "sous-évaluerait": "sous-évaluer",
    "sous-évalueras": "sous-évaluer",
    "sous-évaluerez": "sous-évaluer",
    "sous-évalueriez": "sous-évaluer",
    "sous-évaluerions": "sous-évaluer",
    "sous-évaluerons": "sous-évaluer",
    "sous-évalueront": "sous-évaluer",
    "sous-évalues": "sous-évaluer",
    "sous-évaluez": "sous-évaluer",
    "sous-évaluiez": "sous-évaluer",
    "sous-évaluions": "sous-évaluer",
    "sous-évaluons": "sous-évaluer",
    "sous-évaluâmes": "sous-évaluer",
    "sous-évaluât": "sous-évaluer",
    "sous-évaluâtes": "sous-évaluer",
    "sous-évaluèrent": "sous-évaluer",
    "sous-évalué": "sous-évaluer",
    "sous-évaluée": "sous-évaluer",
    "sous-évaluées": "sous-évaluer",
    "sous-évalués": "sous-évaluer",
    "souscripteurs": "souscripteur",
    "souscripteuse": "souscripteur",
    "souscripteuses": "souscripteur",
    "souscriptions": "souscription",
    "souscrira": "souscrire",
    "souscrirai": "souscrire",
    "souscriraient": "souscrire",
    "souscrirais": "souscrire",
    "souscrirait": "souscrire",
    "souscriras": "souscrire",
    "souscrirez": "souscrire",
    "souscririez": "souscrire",
    "souscririons": "souscrire",
    "souscrirons": "souscrire",
    "souscriront": "souscrire",
    "souscris": "souscrire",
    "souscrit": "souscrire",
    "souscrite": "souscrit",
    "souscrites": "souscrit",
    "souscrits": "souscrit",
    "souscrivaient": "souscrire",
    "souscrivais": "souscrire",
    "souscrivait": "souscrire",
    "souscrivant": "souscrire",
    "souscrive": "souscrire",
    "souscrivent": "souscrire",
    "souscrives": "souscrire",
    "souscrivez": "souscrire",
    "souscriviez": "souscrire",
    "souscrivions": "souscrire",
    "souscrivirent": "souscrire",
    "souscrivis": "souscrire",
    "souscrivisse": "souscrire",
    "souscrivissent": "souscrire",
    "souscrivisses": "souscrire",
    "souscrivissiez": "souscrire",
    "souscrivissions": "souscrire",
    "souscrivit": "souscrire",
    "souscrivons": "souscrire",
    "souscrivîmes": "souscrire",
    "souscrivît": "souscrire",
    "souscrivîtes": "souscrire",
    "soussigner": "sous-signer",
    "soussignée": "soussigné",
    "soussignées": "soussigné",
    "soussignés": "soussigné",
    "soussous": "soussou",
    "soustractions": "soustraction",
    "soustraie": "soustraire",
    "soustraient": "soustraire",
    "soustraies": "soustraire",
    "soustraira": "soustraire",
    "soustrairai": "soustraire",
    "soustrairaient": "soustraire",
    "soustrairais": "soustraire",
    "soustrairait": "soustraire",
    "soustrairas": "soustraire",
    "soustrairez": "soustraire",
    "soustrairiez": "soustraire",
    "soustrairions": "soustraire",
    "soustrairons": "soustraire",
    "soustrairont": "soustraire",
    "soustrais": "soustraire",
    "soustrait": "soustraire",
    "soustraite": "soustraire",
    "soustraites": "soustraire",
    "soustraits": "soustraire",
    "soustrayaient": "soustraire",
    "soustrayais": "soustraire",
    "soustrayait": "soustraire",
    "soustrayant": "soustraire",
    "soustrayez": "soustraire",
    "soustrayiez": "soustraire",
    "soustrayions": "soustraire",
    "soustrayons": "soustraire",
    "soutacha": "soutacher",
    "soutachai": "soutacher",
    "soutachaient": "soutacher",
    "soutachais": "soutacher",
    "soutachait": "soutacher",
    "soutachant": "soutacher",
    "soutachas": "soutacher",
    "soutachasse": "soutacher",
    "soutachassent": "soutacher",
    "soutachasses": "soutacher",
    "soutachassiez": "soutacher",
    "soutachassions": "soutacher",
    "soutache": "soutacher",
    "soutachent": "soutacher",
    "soutachera": "soutacher",
    "soutacherai": "soutacher",
    "soutacheraient": "soutacher",
    "soutacherais": "soutacher",
    "soutacherait": "soutacher",
    "soutacheras": "soutacher",
    "soutacherez": "soutacher",
    "soutacheriez": "soutacher",
    "soutacherions": "soutacher",
    "soutacherons": "soutacher",
    "soutacheront": "soutacher",
    "soutaches": "soutacher",
    "soutachez": "soutacher",
    "soutachiez": "soutacher",
    "soutachions": "soutacher",
    "soutachons": "soutacher",
    "soutachâmes": "soutacher",
    "soutachât": "soutacher",
    "soutachâtes": "soutacher",
    "soutachèrent": "soutacher",
    "soutaché": "soutacher",
    "soutachée": "soutacher",
    "soutachées": "soutacher",
    "soutachés": "soutacher",
    "soutanes": "soutane",
    "soutenables": "soutenable",
    "soutenaient": "soutenir",
    "soutenais": "soutenir",
    "soutenait": "soutenir",
    "soutenant": "soutenir",
    "souteneurs": "souteneur",
    "soutenez": "soutenir",
    "souteniez": "soutenir",
    "soutenions": "soutenir",
    "soutenons": "soutenir",
    "soutenu": "soutenir",
    "soutenue": "soutenu",
    "soutenues": "soutenu",
    "soutenus": "soutenu",
    "souterraine": "souterrain",
    "souterraines": "souterrain",
    "souterrains": "souterrain",
    "soutes": "soute",
    "soutiendra": "soutenir",
    "soutiendrai": "soutenir",
    "soutiendraient": "soutenir",
    "soutiendrais": "soutenir",
    "soutiendrait": "soutenir",
    "soutiendras": "soutenir",
    "soutiendrez": "soutenir",
    "soutiendriez": "soutenir",
    "soutiendrions": "soutenir",
    "soutiendrons": "soutenir",
    "soutiendront": "soutenir",
    "soutienne": "soutenir",
    "soutiennent": "soutenir",
    "soutiennes": "soutenir",
    "soutiens": "soutien",
    "soutiens-gorge": "soutien-gorge",
    "soutient": "soutenir",
    "soutiers": "soutier",
    "soutifs": "soutif",
    "soutinrent": "soutenir",
    "soutins": "soutenir",
    "soutinsse": "soutenir",
    "soutinssent": "soutenir",
    "soutinsses": "soutenir",
    "soutinssiez": "soutenir",
    "soutinssions": "soutenir",
    "soutint": "soutenir",
    "soutira": "soutirer",
    "soutirai": "soutirer",
    "soutiraient": "soutirer",
    "soutirais": "soutirer",
    "soutirait": "soutirer",
    "soutirant": "soutirer",
    "soutiras": "soutirer",
    "soutirasse": "soutirer",
    "soutirassent": "soutirer",
    "soutirasses": "soutirer",
    "soutirassiez": "soutirer",
    "soutirassions": "soutirer",
    "soutire": "soutirer",
    "soutirent": "soutirer",
    "soutirera": "soutirer",
    "soutirerai": "soutirer",
    "soutireraient": "soutirer",
    "soutirerais": "soutirer",
    "soutirerait": "soutirer",
    "soutireras": "soutirer",
    "soutirerez": "soutirer",
    "soutireriez": "soutirer",
    "soutirerions": "soutirer",
    "soutirerons": "soutirer",
    "soutireront": "soutirer",
    "soutires": "soutirer",
    "soutirez": "soutirer",
    "soutiriez": "soutirer",
    "soutirions": "soutirer",
    "soutirons": "soutirer",
    "soutirâmes": "soutirer",
    "soutirât": "soutirer",
    "soutirâtes": "soutirer",
    "soutirèrent": "soutirer",
    "soutiré": "soutirer",
    "soutirée": "soutirer",
    "soutirées": "soutirer",
    "soutirés": "soutirer",
    "soutènements": "soutènement",
    "soutînmes": "soutenir",
    "soutînt": "soutenir",
    "soutîntes": "soutenir",
    "souvenaient": "souvenir",
    "souvenais": "souvenir",
    "souvenait": "souvenir",
    "souvenances": "souvenance",
    "souvenant": "souvenir",
    "souvenez": "souvenir",
    "souveniez": "souvenir",
    "souvenions": "souvenir",
    "souvenirs": "souvenir",
    "souvenons": "souvenir",
    "souvenu": "souvenir",
    "souvenue": "souvenir",
    "souvenues": "souvenir",
    "souvenus": "souvenir",
    "souveraine": "souverain",
    "souveraines": "souverain",
    "souverainetés": "souveraineté",
    "souverains": "souverain",
    "souviendra": "souvenir",
    "souviendrai": "souvenir",
    "souviendraient": "souvenir",
    "souviendrais": "souvenir",
    "souviendrait": "souvenir",
    "souviendras": "souvenir",
    "souviendrez": "souvenir",
    "souviendriez": "souvenir",
    "souviendrions": "souvenir",
    "souviendrons": "souvenir",
    "souviendront": "souvenir",
    "souvienne": "souvenir",
    "souviennent": "souvenir",
    "souviennes": "souvenir",
    "souviens": "souvenir",
    "souvient": "souvenir",
    "souvinrent": "souvenir",
    "souvins": "souvenir",
    "souvinsse": "souvenir",
    "souvinssent": "souvenir",
    "souvinsses": "souvenir",
    "souvinssiez": "souvenir",
    "souvinssions": "souvenir",
    "souvint": "souvenir",
    "souvînmes": "souvenir",
    "souvînt": "souvenir",
    "souvîntes": "souvenir",
    "soviets": "soviet",
    "soviétiformes": "soviétiforme",
    "soviétiques": "soviétique",
    "soviétologues": "soviétologue",
    "sovkhozes": "sovkhoze",
    "soyas": "soya",
    "soyeuse": "soyeux",
    "soyeuses": "soyeux",
    "soyez": "être",
    "soyons": "être",
    "soûla": "soûler",
    "soûlai": "soûler",
    "soûlaient": "soûler",
    "soûlais": "soûler",
    "soûlait": "soûler",
    "soûlant": "soûler",
    "soûlante": "soûlant",
    "soûlarde": "soûlard",
    "soûlards": "soûlard",
    "soûlas": "soûler",
    "soûlasse": "soûler",
    "soûlassent": "soûler",
    "soûlasses": "soûler",
    "soûlassiez": "soûler",
    "soûlassions": "soûler",
    "soûlauds": "soûlaud",
    "soûle": "soûler",
    "soûlent": "soûler",
    "soûlera": "soûler",
    "soûlerai": "soûler",
    "soûleraient": "soûler",
    "soûlerais": "soûler",
    "soûlerait": "soûler",
    "soûleras": "soûler",
    "soûlerez": "soûler",
    "soûleriez": "soûler",
    "soûlerions": "soûler",
    "soûlerons": "soûler",
    "soûleront": "soûler",
    "soûles": "soûler",
    "soûlez": "soûler",
    "soûliez": "soûler",
    "soûlions": "soûler",
    "soûlons": "soûler",
    "soûlots": "soûlot",
    "soûls": "soûl",
    "soûlâmes": "soûler",
    "soûlât": "soûler",
    "soûlâtes": "soûler",
    "soûlèrent": "soûler",
    "soûlé": "soûler",
    "soûlée": "soûler",
    "soûlées": "soûler",
    "soûlés": "soûler",
    "spacieuse": "spacieux",
    "spacieuses": "spacieux",
    "spadassins": "spadassin",
    "spaghettis": "spaghetti",
    "spahis": "spahi",
    "spallations": "spallation",
    "sparadraps": "sparadrap",
    "spartakistes": "spartakiste",
    "sparteries": "sparterie",
    "spartiates": "spartiate",
    "spas": "spa",
    "spasmes": "spasme",
    "spasmodiques": "spasmodique",
    "spaths": "spath",
    "spatiale": "spatial",
    "spatiales": "spatial",
    "spatiaux": "spatial",
    "spatio-temporelle": "spatio-temporel",
    "spatio-temporelles": "spatio-temporel",
    "spatio-temporels": "spatio-temporel",
    "spatules": "spatule",
    "spatulée": "spatulé",
    "spatulées": "spatulé",
    "spatulés": "spatulé",
    "speakerine": "speaker",
    "speakerines": "speakerine",
    "speakers": "speaker",
    "spectacles": "spectacle",
    "spectaculaires": "spectaculaire",
    "spectateurs": "spectateur",
    "spectatrice": "spectateur",
    "spectatrices": "spectateur",
    "spectrale": "spectral",
    "spectrales": "spectral",
    "spectraux": "spectral",
    "spectres": "spectre",
    "spectromètres": "spectromètre",
    "speeches": "speech",
    "speechs": "speech",
    "speede": "speeder",
    "speedes": "speeder",
    "speedé": "speeder",
    "speedée": "speeder",
    "speedés": "speeder",
    "spencers": "spencer",
    "spermacetis": "spermaceti",
    "spermatos": "spermato",
    "spermatozoïdes": "spermatozoïde",
    "spermes": "sperme",
    "spermophiles": "spermophile",
    "sphaignes": "sphaigne",
    "sphincters": "sphincter",
    "sphinges": "sphinge",
    "sphyrènes": "sphyrène",
    "sphères": "sphère",
    "sphénoïdale": "sphénoïdal",
    "sphénoïdales": "sphénoïdal",
    "sphénoïdaux": "sphénoïdal",
    "sphénoïdes": "sphénoïde",
    "sphériques": "sphérique",
    "sphéroïdale": "sphéroïdal",
    "sphéroïdales": "sphéroïdal",
    "sphéroïdaux": "sphéroïdal",
    "sphéroïdes": "sphéroïde",
    "spicilèges": "spicilège",
    "spics": "spic",
    "spicules": "spicule",
    "spiders": "spider",
    "spinale": "spinal",
    "spinales": "spinal",
    "spinaux": "spinal",
    "spinnakers": "spinnaker",
    "spinosante": "spinosant",
    "spinosantes": "spinosant",
    "spinosants": "spinosant",
    "spirale": "spiral",
    "spirales": "spirale",
    "spiralées": "spiralé",
    "spiralés": "spiralé",
    "spiraux": "spiral",
    "spires": "spire",
    "spirilles": "spirille",
    "spirites": "spirite",
    "spiritualisa": "spiritualiser",
    "spiritualisai": "spiritualiser",
    "spiritualisaient": "spiritualiser",
    "spiritualisais": "spiritualiser",
    "spiritualisait": "spiritualiser",
    "spiritualisant": "spiritualiser",
    "spiritualisas": "spiritualiser",
    "spiritualisasse": "spiritualiser",
    "spiritualisassent": "spiritualiser",
    "spiritualisasses": "spiritualiser",
    "spiritualisassiez": "spiritualiser",
    "spiritualisassions": "spiritualiser",
    "spiritualise": "spiritualiser",
    "spiritualisent": "spiritualiser",
    "spiritualisera": "spiritualiser",
    "spiritualiserai": "spiritualiser",
    "spiritualiseraient": "spiritualiser",
    "spiritualiserais": "spiritualiser",
    "spiritualiserait": "spiritualiser",
    "spiritualiseras": "spiritualiser",
    "spiritualiserez": "spiritualiser",
    "spiritualiseriez": "spiritualiser",
    "spiritualiserions": "spiritualiser",
    "spiritualiserons": "spiritualiser",
    "spiritualiseront": "spiritualiser",
    "spiritualises": "spiritualiser",
    "spiritualisez": "spiritualiser",
    "spiritualisiez": "spiritualiser",
    "spiritualisions": "spiritualiser",
    "spiritualisons": "spiritualiser",
    "spiritualistes": "spiritualiste",
    "spiritualisâmes": "spiritualiser",
    "spiritualisât": "spiritualiser",
    "spiritualisâtes": "spiritualiser",
    "spiritualisèrent": "spiritualiser",
    "spiritualisé": "spiritualiser",
    "spiritualisée": "spiritualiser",
    "spiritualisées": "spiritualiser",
    "spiritualisés": "spiritualiser",
    "spiritualités": "spiritualité",
    "spirituals": "spiritual",
    "spirituelle": "spirituel",
    "spirituelles": "spirituel",
    "spirituels": "spirituel",
    "spiritueuse": "spiritueux",
    "spiritueuses": "spiritueux",
    "spirochètes": "spirochète",
    "spirochétoses": "spirochétose",
    "spiromètres": "spiromètre",
    "spirées": "spirée",
    "spleens": "spleen",
    "splendeurs": "splendeur",
    "splendides": "splendide",
    "splittaient": "splitter",
    "spolia": "spolier",
    "spoliai": "spolier",
    "spoliaient": "spolier",
    "spoliais": "spolier",
    "spoliait": "spolier",
    "spoliant": "spolier",
    "spolias": "spolier",
    "spoliasse": "spolier",
    "spoliassent": "spolier",
    "spoliasses": "spolier",
    "spoliassiez": "spolier",
    "spoliassions": "spolier",
    "spoliations": "spoliation",
    "spolie": "spolier",
    "spolient": "spolier",
    "spoliera": "spolier",
    "spolierai": "spolier",
    "spolieraient": "spolier",
    "spolierais": "spolier",
    "spolierait": "spolier",
    "spolieras": "spolier",
    "spolierez": "spolier",
    "spolieriez": "spolier",
    "spolierions": "spolier",
    "spolierons": "spolier",
    "spolieront": "spolier",
    "spolies": "spolier",
    "spoliez": "spolier",
    "spoliiez": "spolier",
    "spoliions": "spolier",
    "spolions": "spolier",
    "spoliâmes": "spolier",
    "spoliât": "spolier",
    "spoliâtes": "spolier",
    "spolièrent": "spolier",
    "spolié": "spolier",
    "spoliée": "spolier",
    "spoliées": "spolier",
    "spoliés": "spolier",
    "spondyles": "spondyle",
    "spondées": "spondée",
    "spongieuse": "spongieux",
    "spongieuses": "spongieux",
    "sponsorings": "sponsoring",
    "sponsorisait": "sponsoriser",
    "sponsorisations": "sponsorisation",
    "sponsorise": "sponsoriser",
    "sponsorisera": "sponsoriser",
    "sponsorisé": "sponsoriser",
    "sponsorisée": "sponsoriser",
    "sponsorisés": "sponsoriser",
    "sponsors": "sponsor",
    "spontanée": "spontané",
    "spontanées": "spontané",
    "spontanéistes": "spontanéiste",
    "spontanéités": "spontanéité",
    "spontanés": "spontané",
    "sporadiques": "sporadique",
    "sporanges": "sporange",
    "spores": "spore",
    "sportifs": "sportif",
    "sportive": "sportif",
    "sportives": "sportif",
    "sports": "sport",
    "sportsmen": "sportsman",
    "sportules": "sportule",
    "spots": "spot",
    "spoutniks": "spoutnik",
    "sprats": "sprat",
    "sprays": "spray",
    "springboks": "springbok",
    "sprinklers": "sprinkler",
    "sprinta": "sprinter",
    "sprintai": "sprinter",
    "sprintaient": "sprinter",
    "sprintais": "sprinter",
    "sprintait": "sprinter",
    "sprintant": "sprinter",
    "sprintas": "sprinter",
    "sprintasse": "sprinter",
    "sprintassent": "sprinter",
    "sprintasses": "sprinter",
    "sprintassiez": "sprinter",
    "sprintassions": "sprinter",
    "sprinte": "sprinter",
    "sprintent": "sprinter",
    "sprintera": "sprinter",
    "sprinterai": "sprinter",
    "sprinteraient": "sprinter",
    "sprinterais": "sprinter",
    "sprinterait": "sprinter",
    "sprinteras": "sprinter",
    "sprinterez": "sprinter",
    "sprinteriez": "sprinter",
    "sprinterions": "sprinter",
    "sprinterons": "sprinter",
    "sprinteront": "sprinter",
    "sprinters": "sprinter",
    "sprintes": "sprinter",
    "sprinteurs": "sprinteur",
    "sprintez": "sprinter",
    "sprintiez": "sprinter",
    "sprintions": "sprinter",
    "sprintons": "sprinter",
    "sprints": "sprint",
    "sprintâmes": "sprinter",
    "sprintât": "sprinter",
    "sprintâtes": "sprinter",
    "sprintèrent": "sprinter",
    "sprinté": "sprinter",
    "spéciale": "spécial",
    "spéciales": "spéciale",
    "spécialisa": "spécialiser",
    "spécialisai": "spécialiser",
    "spécialisaient": "spécialiser",
    "spécialisais": "spécialiser",
    "spécialisait": "spécialiser",
    "spécialisant": "spécialiser",
    "spécialisas": "spécialiser",
    "spécialisasse": "spécialiser",
    "spécialisassent": "spécialiser",
    "spécialisasses": "spécialiser",
    "spécialisassiez": "spécialiser",
    "spécialisassions": "spécialiser",
    "spécialisations": "spécialisation",
    "spécialise": "spécialiser",
    "spécialisent": "spécialiser",
    "spécialisera": "spécialiser",
    "spécialiserai": "spécialiser",
    "spécialiseraient": "spécialiser",
    "spécialiserais": "spécialiser",
    "spécialiserait": "spécialiser",
    "spécialiseras": "spécialiser",
    "spécialiserez": "spécialiser",
    "spécialiseriez": "spécialiser",
    "spécialiserions": "spécialiser",
    "spécialiserons": "spécialiser",
    "spécialiseront": "spécialiser",
    "spécialises": "spécialiser",
    "spécialisez": "spécialiser",
    "spécialisiez": "spécialiser",
    "spécialisions": "spécialiser",
    "spécialisons": "spécialiser",
    "spécialistes": "spécialiste",
    "spécialisâmes": "spécialiser",
    "spécialisât": "spécialiser",
    "spécialisâtes": "spécialiser",
    "spécialisèrent": "spécialiser",
    "spécialisé": "spécialiser",
    "spécialisée": "spécialiser",
    "spécialisées": "spécialiser",
    "spécialisés": "spécialiser",
    "spécialités": "spécialité",
    "spéciaux": "spécial",
    "spécieuse": "spécieux",
    "spécieuses": "spécieux",
    "spécifia": "spécifier",
    "spécifiai": "spécifier",
    "spécifiaient": "spécifier",
    "spécifiais": "spécifier",
    "spécifiait": "spécifier",
    "spécifiant": "spécifier",
    "spécifias": "spécifier",
    "spécifiasse": "spécifier",
    "spécifiassent": "spécifier",
    "spécifiasses": "spécifier",
    "spécifiassiez": "spécifier",
    "spécifiassions": "spécifier",
    "spécifications": "spécification",
    "spécificités": "spécificité",
    "spécifie": "spécifier",
    "spécifient": "spécifier",
    "spécifiera": "spécifier",
    "spécifierai": "spécifier",
    "spécifieraient": "spécifier",
    "spécifierais": "spécifier",
    "spécifierait": "spécifier",
    "spécifieras": "spécifier",
    "spécifierez": "spécifier",
    "spécifieriez": "spécifier",
    "spécifierions": "spécifier",
    "spécifierons": "spécifier",
    "spécifieront": "spécifier",
    "spécifies": "spécifier",
    "spécifiez": "spécifier",
    "spécifiiez": "spécifier",
    "spécifiions": "spécifier",
    "spécifions": "spécifier",
    "spécifiques": "spécifique",
    "spécifiâmes": "spécifier",
    "spécifiât": "spécifier",
    "spécifiâtes": "spécifier",
    "spécifièrent": "spécifier",
    "spécifié": "spécifier",
    "spécifiée": "spécifier",
    "spécifiées": "spécifier",
    "spécifiés": "spécifier",
    "spécimens": "spécimen",
    "spécula": "spéculer",
    "spéculai": "spéculer",
    "spéculaient": "spéculer",
    "spéculaires": "spéculaire",
    "spéculais": "spéculer",
    "spéculait": "spéculer",
    "spéculant": "spéculer",
    "spéculas": "spéculer",
    "spéculasse": "spéculer",
    "spéculassent": "spéculer",
    "spéculasses": "spéculer",
    "spéculassiez": "spéculer",
    "spéculassions": "spéculer",
    "spéculateurs": "spéculateur",
    "spéculatifs": "spéculatif",
    "spéculations": "spéculation",
    "spéculative": "spéculatif",
    "spéculatives": "spéculatif",
    "spéculatrice": "spéculateur",
    "spéculatrices": "spéculateur",
    "spécule": "spéculer",
    "spéculent": "spéculer",
    "spéculera": "spéculer",
    "spéculerai": "spéculer",
    "spéculeraient": "spéculer",
    "spéculerais": "spéculer",
    "spéculerait": "spéculer",
    "spéculeras": "spéculer",
    "spéculerez": "spéculer",
    "spéculeriez": "spéculer",
    "spéculerions": "spéculer",
    "spéculerons": "spéculer",
    "spéculeront": "spéculer",
    "spécules": "spéculer",
    "spéculez": "spéculer",
    "spéculiez": "spéculer",
    "spéculions": "spéculer",
    "spéculons": "spéculer",
    "spéculums": "spéculum",
    "spéculâmes": "spéculer",
    "spéculât": "spéculer",
    "spéculâtes": "spéculer",
    "spéculèrent": "spéculer",
    "spéculé": "spéculer",
    "spéléologies": "spéléologie",
    "spéléologues": "spéléologue",
    "squales": "squale",
    "squames": "squame",
    "squameuse": "squameux",
    "squares": "square",
    "squats": "squat",
    "squattait": "squatter",
    "squatte": "squatter",
    "squatteras": "squatter",
    "squatters": "squatter",
    "squatteurs": "squatteur",
    "squattez": "squatter",
    "squatts": "squatt",
    "squatté": "squatter",
    "squattée": "squatter",
    "squattées": "squatter",
    "squattérisa": "squattériser",
    "squattérisai": "squattériser",
    "squattérisaient": "squattériser",
    "squattérisais": "squattériser",
    "squattérisait": "squattériser",
    "squattérisant": "squattériser",
    "squattérisas": "squattériser",
    "squattérisasse": "squattériser",
    "squattérisassent": "squattériser",
    "squattérisasses": "squattériser",
    "squattérisassiez": "squattériser",
    "squattérisassions": "squattériser",
    "squattérise": "squattériser",
    "squattérisent": "squattériser",
    "squattérisera": "squattériser",
    "squattériserai": "squattériser",
    "squattériseraient": "squattériser",
    "squattériserais": "squattériser",
    "squattériserait": "squattériser",
    "squattériseras": "squattériser",
    "squattériserez": "squattériser",
    "squattériseriez": "squattériser",
    "squattériserions": "squattériser",
    "squattériserons": "squattériser",
    "squattériseront": "squattériser",
    "squattérises": "squattériser",
    "squattérisez": "squattériser",
    "squattérisiez": "squattériser",
    "squattérisions": "squattériser",
    "squattérisons": "squattériser",
    "squattérisâmes": "squattériser",
    "squattérisât": "squattériser",
    "squattérisâtes": "squattériser",
    "squattérisèrent": "squattériser",
    "squattérisé": "squattériser",
    "squattérisée": "squattériser",
    "squattérisées": "squattériser",
    "squattérisés": "squattériser",
    "squattés": "squatter",
    "squaws": "squaw",
    "squeezent": "squeezer",
    "squelettes": "squelette",
    "squelettiques": "squelettique",
    "squires": "squire",
    "squirres": "squirre",
    "squirrhes": "squirrhe",
    "stabilisa": "stabiliser",
    "stabilisai": "stabiliser",
    "stabilisaient": "stabiliser",
    "stabilisais": "stabiliser",
    "stabilisait": "stabiliser",
    "stabilisant": "stabiliser",
    "stabilisante": "stabilisant",
    "stabilisas": "stabiliser",
    "stabilisasse": "stabiliser",
    "stabilisassent": "stabiliser",
    "stabilisasses": "stabiliser",
    "stabilisassiez": "stabiliser",
    "stabilisassions": "stabiliser",
    "stabilisateurs": "stabilisateur",
    "stabilisations": "stabilisation",
    "stabilisatrice": "stabilisateur",
    "stabilisatrices": "stabilisateur",
    "stabilise": "stabiliser",
    "stabilisent": "stabiliser",
    "stabilisera": "stabiliser",
    "stabiliserai": "stabiliser",
    "stabiliseraient": "stabiliser",
    "stabiliserais": "stabiliser",
    "stabiliserait": "stabiliser",
    "stabiliseras": "stabiliser",
    "stabiliserez": "stabiliser",
    "stabiliseriez": "stabiliser",
    "stabiliserions": "stabiliser",
    "stabiliserons": "stabiliser",
    "stabiliseront": "stabiliser",
    "stabilises": "stabiliser",
    "stabilisez": "stabiliser",
    "stabilisiez": "stabiliser",
    "stabilisions": "stabiliser",
    "stabilisons": "stabiliser",
    "stabilisâmes": "stabiliser",
    "stabilisât": "stabiliser",
    "stabilisâtes": "stabiliser",
    "stabilisèrent": "stabiliser",
    "stabilisé": "stabiliser",
    "stabilisée": "stabiliser",
    "stabilisées": "stabiliser",
    "stabilisés": "stabiliser",
    "stabilités": "stabilité",
    "stables": "stable",
    "stabulations": "stabulation",
    "staccatos": "staccato",
    "stades": "stade",
    "staffs": "staff",
    "stages": "stage",
    "stagiaires": "stagiaire",
    "stagna": "stagner",
    "stagnai": "stagner",
    "stagnaient": "stagner",
    "stagnais": "stagner",
    "stagnait": "stagner",
    "stagnant": "stagner",
    "stagnante": "stagnant",
    "stagnantes": "stagnant",
    "stagnants": "stagnant",
    "stagnas": "stagner",
    "stagnasse": "stagner",
    "stagnassent": "stagner",
    "stagnasses": "stagner",
    "stagnassiez": "stagner",
    "stagnassions": "stagner",
    "stagnations": "stagnation",
    "stagne": "stagner",
    "stagnent": "stagner",
    "stagnera": "stagner",
    "stagnerai": "stagner",
    "stagneraient": "stagner",
    "stagnerais": "stagner",
    "stagnerait": "stagner",
    "stagneras": "stagner",
    "stagnerez": "stagner",
    "stagneriez": "stagner",
    "stagnerions": "stagner",
    "stagnerons": "stagner",
    "stagneront": "stagner",
    "stagnes": "stagner",
    "stagnez": "stagner",
    "stagniez": "stagner",
    "stagnions": "stagner",
    "stagnons": "stagner",
    "stagnâmes": "stagner",
    "stagnât": "stagner",
    "stagnâtes": "stagner",
    "stagnèrent": "stagner",
    "stagné": "stagner",
    "stakhanovismes": "stakhanovisme",
    "stalactites": "stalactite",
    "stalagmites": "stalagmite",
    "stalags": "stalag",
    "stalinienne": "stalinien",
    "staliniennes": "stalinien",
    "staliniens": "stalinien",
    "stalinismes": "stalinisme",
    "stalinisée": "staliniser",
    "stalles": "stalle",
    "stals": "stal",
    "stances": "stance",
    "standardisa": "standardiser",
    "standardisai": "standardiser",
    "standardisaient": "standardiser",
    "standardisais": "standardiser",
    "standardisait": "standardiser",
    "standardisant": "standardiser",
    "standardisas": "standardiser",
    "standardisasse": "standardiser",
    "standardisassent": "standardiser",
    "standardisasses": "standardiser",
    "standardisassiez": "standardiser",
    "standardisassions": "standardiser",
    "standardisations": "standardisation",
    "standardise": "standardiser",
    "standardisent": "standardiser",
    "standardisera": "standardiser",
    "standardiserai": "standardiser",
    "standardiseraient": "standardiser",
    "standardiserais": "standardiser",
    "standardiserait": "standardiser",
    "standardiseras": "standardiser",
    "standardiserez": "standardiser",
    "standardiseriez": "standardiser",
    "standardiserions": "standardiser",
    "standardiserons": "standardiser",
    "standardiseront": "standardiser",
    "standardises": "standardiser",
    "standardisez": "standardiser",
    "standardisiez": "standardiser",
    "standardisions": "standardiser",
    "standardisons": "standardiser",
    "standardistes": "standardiste",
    "standardisâmes": "standardiser",
    "standardisât": "standardiser",
    "standardisâtes": "standardiser",
    "standardisèrent": "standardiser",
    "standardisé": "standardiser",
    "standardisée": "standardiser",
    "standardisées": "standardiser",
    "standardisés": "standardiser",
    "standards": "standard",
    "standings": "standing",
    "stands": "stand",
    "staphylococcies": "staphylococcie",
    "staphylocoques": "staphylocoque",
    "star-systems": "star-system",
    "starlettes": "starlette",
    "stars": "star",
    "starters": "starter",
    "starting-blocks": "starting-block",
    "starting-gates": "starting-gate",
    "stases": "stase",
    "state": "stater",
    "statices": "statice",
    "statifs": "statif",
    "stationna": "stationner",
    "stationnai": "stationner",
    "stationnaient": "stationner",
    "stationnaires": "stationnaire",
    "stationnais": "stationner",
    "stationnait": "stationner",
    "stationnant": "stationner",
    "stationnas": "stationner",
    "stationnasse": "stationner",
    "stationnassent": "stationner",
    "stationnasses": "stationner",
    "stationnassiez": "stationner",
    "stationnassions": "stationner",
    "stationne": "stationner",
    "stationnements": "stationnement",
    "stationnent": "stationner",
    "stationnera": "stationner",
    "stationnerai": "stationner",
    "stationneraient": "stationner",
    "stationnerais": "stationner",
    "stationnerait": "stationner",
    "stationneras": "stationner",
    "stationnerez": "stationner",
    "stationneriez": "stationner",
    "stationnerions": "stationner",
    "stationnerons": "stationner",
    "stationneront": "stationner",
    "stationnes": "stationner",
    "stationnez": "stationner",
    "stationniez": "stationner",
    "stationnions": "stationner",
    "stationnons": "stationner",
    "stationnâmes": "stationner",
    "stationnât": "stationner",
    "stationnâtes": "stationner",
    "stationnèrent": "stationner",
    "stationné": "stationner",
    "stationnée": "stationner",
    "stationnées": "stationner",
    "stationnés": "stationner",
    "stations": "station",
    "stations-service": "station-service",
    "statiques": "statique",
    "statisticienne": "statisticien",
    "statisticiennes": "statisticien",
    "statisticiens": "statisticien",
    "statistiques": "statistique",
    "stative": "statif",
    "statives": "statif",
    "statua": "statuer",
    "statuai": "statuer",
    "statuaient": "statuer",
    "statuais": "statuer",
    "statuait": "statuer",
    "statuant": "statuer",
    "statuas": "statuer",
    "statuasse": "statuer",
    "statuassent": "statuer",
    "statuasses": "statuer",
    "statuassiez": "statuer",
    "statuassions": "statuer",
    "statue": "statuer",
    "statuent": "statuer",
    "statuera": "statuer",
    "statuerai": "statuer",
    "statueraient": "statuer",
    "statuerais": "statuer",
    "statuerait": "statuer",
    "statueras": "statuer",
    "statuerez": "statuer",
    "statueriez": "statuer",
    "statuerions": "statuer",
    "statuerons": "statuer",
    "statueront": "statuer",
    "statues": "statuer",
    "statuettes": "statuette",
    "statuez": "statuer",
    "statufia": "statufier",
    "statufiai": "statufier",
    "statufiaient": "statufier",
    "statufiais": "statufier",
    "statufiait": "statufier",
    "statufiant": "statufier",
    "statufias": "statufier",
    "statufiasse": "statufier",
    "statufiassent": "statufier",
    "statufiasses": "statufier",
    "statufiassiez": "statufier",
    "statufiassions": "statufier",
    "statufie": "statufier",
    "statufient": "statufier",
    "statufiera": "statufier",
    "statufierai": "statufier",
    "statufieraient": "statufier",
    "statufierais": "statufier",
    "statufierait": "statufier",
    "statufieras": "statufier",
    "statufierez": "statufier",
    "statufieriez": "statufier",
    "statufierions": "statufier",
    "statufierons": "statufier",
    "statufieront": "statufier",
    "statufies": "statufier",
    "statufiez": "statufier",
    "statufiiez": "statufier",
    "statufiions": "statufier",
    "statufions": "statufier",
    "statufiâmes": "statufier",
    "statufiât": "statufier",
    "statufiâtes": "statufier",
    "statufièrent": "statufier",
    "statufié": "statufier",
    "statufiée": "statufier",
    "statufiées": "statufier",
    "statufiés": "statufier",
    "statuiez": "statuer",
    "statuions": "statuer",
    "statuons": "statuer",
    "statures": "stature",
    "staturo-pondérale": "staturo-pondéral",
    "staturo-pondérales": "staturo-pondéral",
    "staturo-pondéraux": "staturo-pondéral",
    "statutaires": "statutaire",
    "statuts": "statut",
    "statuâmes": "statuer",
    "statuât": "statuer",
    "statuâtes": "statuer",
    "statuèrent": "statuer",
    "statué": "statuer",
    "statères": "statère",
    "statégiques": "statégique",
    "stayers": "stayer",
    "steaks": "steak",
    "steamers": "steamer",
    "steeple-chases": "steeple-chase",
    "steeples": "steeple",
    "stellaires": "stellaire",
    "stencils": "stencil",
    "stentors": "stentor",
    "steppers": "stepper",
    "steppes": "steppe",
    "stercoraires": "stercoraire",
    "sternale": "sternal",
    "sternes": "sterne",
    "sternums": "sternum",
    "stewards": "steward",
    "sticks": "stick",
    "stigmates": "stigmate",
    "stigmatisa": "stigmatiser",
    "stigmatisai": "stigmatiser",
    "stigmatisaient": "stigmatiser",
    "stigmatisais": "stigmatiser",
    "stigmatisait": "stigmatiser",
    "stigmatisant": "stigmatiser",
    "stigmatisas": "stigmatiser",
    "stigmatisasse": "stigmatiser",
    "stigmatisassent": "stigmatiser",
    "stigmatisasses": "stigmatiser",
    "stigmatisassiez": "stigmatiser",
    "stigmatisassions": "stigmatiser",
    "stigmatise": "stigmatiser",
    "stigmatisent": "stigmatiser",
    "stigmatisera": "stigmatiser",
    "stigmatiserai": "stigmatiser",
    "stigmatiseraient": "stigmatiser",
    "stigmatiserais": "stigmatiser",
    "stigmatiserait": "stigmatiser",
    "stigmatiseras": "stigmatiser",
    "stigmatiserez": "stigmatiser",
    "stigmatiseriez": "stigmatiser",
    "stigmatiserions": "stigmatiser",
    "stigmatiserons": "stigmatiser",
    "stigmatiseront": "stigmatiser",
    "stigmatises": "stigmatiser",
    "stigmatisez": "stigmatiser",
    "stigmatisiez": "stigmatiser",
    "stigmatisions": "stigmatiser",
    "stigmatisons": "stigmatiser",
    "stigmatisâmes": "stigmatiser",
    "stigmatisât": "stigmatiser",
    "stigmatisâtes": "stigmatiser",
    "stigmatisèrent": "stigmatiser",
    "stigmatisé": "stigmatiser",
    "stigmatisée": "stigmatiser",
    "stigmatisées": "stigmatiser",
    "stigmatisés": "stigmatiser",
    "stimula": "stimuler",
    "stimulai": "stimuler",
    "stimulaient": "stimuler",
    "stimulais": "stimuler",
    "stimulait": "stimuler",
    "stimulant": "stimuler",
    "stimulante": "stimulant",
    "stimulantes": "stimulant",
    "stimulants": "stimulant",
    "stimulas": "stimuler",
    "stimulasse": "stimuler",
    "stimulassent": "stimuler",
    "stimulasses": "stimuler",
    "stimulassiez": "stimuler",
    "stimulassions": "stimuler",
    "stimulateurs": "stimulateur",
    "stimulations": "stimulation",
    "stimule": "stimuler",
    "stimulent": "stimuler",
    "stimulera": "stimuler",
    "stimulerai": "stimuler",
    "stimuleraient": "stimuler",
    "stimulerais": "stimuler",
    "stimulerait": "stimuler",
    "stimuleras": "stimuler",
    "stimulerez": "stimuler",
    "stimuleriez": "stimuler",
    "stimulerions": "stimuler",
    "stimulerons": "stimuler",
    "stimuleront": "stimuler",
    "stimules": "stimuler",
    "stimulez": "stimuler",
    "stimuli": "stimulus",
    "stimuliez": "stimuler",
    "stimulions": "stimuler",
    "stimulons": "stimuler",
    "stimulâmes": "stimuler",
    "stimulât": "stimuler",
    "stimulâtes": "stimuler",
    "stimulèrent": "stimuler",
    "stimulé": "stimuler",
    "stimulée": "stimuler",
    "stimulées": "stimuler",
    "stimulés": "stimuler",
    "stipendia": "stipendier",
    "stipendiai": "stipendier",
    "stipendiaient": "stipendier",
    "stipendiais": "stipendier",
    "stipendiait": "stipendier",
    "stipendiant": "stipendier",
    "stipendias": "stipendier",
    "stipendiasse": "stipendier",
    "stipendiassent": "stipendier",
    "stipendiasses": "stipendier",
    "stipendiassiez": "stipendier",
    "stipendiassions": "stipendier",
    "stipendie": "stipendier",
    "stipendient": "stipendier",
    "stipendiera": "stipendier",
    "stipendierai": "stipendier",
    "stipendieraient": "stipendier",
    "stipendierais": "stipendier",
    "stipendierait": "stipendier",
    "stipendieras": "stipendier",
    "stipendierez": "stipendier",
    "stipendieriez": "stipendier",
    "stipendierions": "stipendier",
    "stipendierons": "stipendier",
    "stipendieront": "stipendier",
    "stipendies": "stipendier",
    "stipendiez": "stipendier",
    "stipendiiez": "stipendier",
    "stipendiions": "stipendier",
    "stipendions": "stipendier",
    "stipendiâmes": "stipendier",
    "stipendiât": "stipendier",
    "stipendiâtes": "stipendier",
    "stipendièrent": "stipendier",
    "stipendié": "stipendier",
    "stipendiée": "stipendier",
    "stipendiées": "stipendier",
    "stipendiés": "stipendier",
    "stipes": "stipe",
    "stipula": "stipuler",
    "stipulai": "stipuler",
    "stipulaient": "stipuler",
    "stipulais": "stipuler",
    "stipulait": "stipuler",
    "stipulant": "stipuler",
    "stipulas": "stipuler",
    "stipulasse": "stipuler",
    "stipulassent": "stipuler",
    "stipulasses": "stipuler",
    "stipulassiez": "stipuler",
    "stipulassions": "stipuler",
    "stipulations": "stipulation",
    "stipule": "stipuler",
    "stipulent": "stipuler",
    "stipulera": "stipuler",
    "stipulerai": "stipuler",
    "stipuleraient": "stipuler",
    "stipulerais": "stipuler",
    "stipulerait": "stipuler",
    "stipuleras": "stipuler",
    "stipulerez": "stipuler",
    "stipuleriez": "stipuler",
    "stipulerions": "stipuler",
    "stipulerons": "stipuler",
    "stipuleront": "stipuler",
    "stipules": "stipuler",
    "stipulez": "stipuler",
    "stipuliez": "stipuler",
    "stipulions": "stipuler",
    "stipulons": "stipuler",
    "stipulâmes": "stipuler",
    "stipulât": "stipuler",
    "stipulâtes": "stipuler",
    "stipulèrent": "stipuler",
    "stipulé": "stipuler",
    "stipulée": "stipuler",
    "stipulées": "stipuler",
    "stipulés": "stipuler",
    "stochastiques": "stochastique",
    "stock-cars": "stock-car",
    "stock-options": "stock-option",
    "stocka": "stocker",
    "stockables": "stockable",
    "stockages": "stockage",
    "stockai": "stocker",
    "stockaient": "stocker",
    "stockais": "stocker",
    "stockait": "stocker",
    "stockant": "stocker",
    "stockas": "stocker",
    "stockasse": "stocker",
    "stockassent": "stocker",
    "stockasses": "stocker",
    "stockassiez": "stocker",
    "stockassions": "stocker",
    "stocke": "stocker",
    "stockent": "stocker",
    "stockera": "stocker",
    "stockerai": "stocker",
    "stockeraient": "stocker",
    "stockerais": "stocker",
    "stockerait": "stocker",
    "stockeras": "stocker",
    "stockerez": "stocker",
    "stockeriez": "stocker",
    "stockerions": "stocker",
    "stockerons": "stocker",
    "stockeront": "stocker",
    "stockes": "stocker",
    "stockez": "stocker",
    "stockfischs": "stockfisch",
    "stockiez": "stocker",
    "stockions": "stocker",
    "stockons": "stocker",
    "stocks": "stock",
    "stockâmes": "stocker",
    "stockât": "stocker",
    "stockâtes": "stocker",
    "stockèrent": "stocker",
    "stocké": "stocker",
    "stockée": "stocker",
    "stockées": "stocker",
    "stockés": "stocker",
    "stomacale": "stomacal",
    "stomacales": "stomacal",
    "stomacaux": "stomacal",
    "stomachiques": "stomachique",
    "stomates": "stomate",
    "stomatologies": "stomatologie",
    "stones": "stone",
    "stoppa": "stopper",
    "stoppai": "stopper",
    "stoppaient": "stopper",
    "stoppais": "stopper",
    "stoppait": "stopper",
    "stoppant": "stopper",
    "stoppas": "stopper",
    "stoppasse": "stopper",
    "stoppassent": "stopper",
    "stoppasses": "stopper",
    "stoppassiez": "stopper",
    "stoppassions": "stopper",
    "stoppe": "stopper",
    "stoppent": "stopper",
    "stoppera": "stopper",
    "stopperai": "stopper",
    "stopperaient": "stopper",
    "stopperais": "stopper",
    "stopperait": "stopper",
    "stopperas": "stopper",
    "stopperez": "stopper",
    "stopperiez": "stopper",
    "stopperions": "stopper",
    "stopperons": "stopper",
    "stopperont": "stopper",
    "stoppes": "stopper",
    "stoppeurs": "stoppeur",
    "stoppeuse": "stoppeur",
    "stoppez": "stopper",
    "stoppiez": "stopper",
    "stoppions": "stopper",
    "stoppons": "stopper",
    "stoppâmes": "stopper",
    "stoppât": "stopper",
    "stoppâtes": "stopper",
    "stoppèrent": "stopper",
    "stoppé": "stopper",
    "stoppée": "stopper",
    "stoppées": "stopper",
    "stoppés": "stopper",
    "stops": "stop",
    "stores": "store",
    "story board": "story-board",
    "story-boards": "story-board",
    "stouts": "stout",
    "stoïciens": "stoïcien",
    "stoïcismes": "stoïcisme",
    "stoïques": "stoïque",
    "strabismes": "strabisme",
    "strangula": "stranguler",
    "strangulant": "stranguler",
    "strangulations": "strangulation",
    "strangulé": "stranguler",
    "strangulées": "stranguler",
    "strapontins": "strapontin",
    "strasbourgeoise": "strasbourgeois",
    "strasbourgeoises": "strasbourgeois",
    "stratagèmes": "stratagème",
    "strates": "strate",
    "stratifications": "stratification",
    "stratifiée": "stratifier",
    "stratifiées": "stratifié",
    "stratigraphies": "stratigraphie",
    "stratosphères": "stratosphère",
    "stratosphériques": "stratosphérique",
    "stratèges": "stratège",
    "stratégies": "stratégie",
    "stratégiques": "stratégique",
    "streptocoques": "streptocoque",
    "streptomycines": "streptomycine",
    "stressa": "stresser",
    "stressai": "stresser",
    "stressaient": "stresser",
    "stressais": "stresser",
    "stressait": "stresser",
    "stressant": "stresser",
    "stressante": "stressant",
    "stressantes": "stressant",
    "stressants": "stressant",
    "stressas": "stresser",
    "stressasse": "stresser",
    "stressassent": "stresser",
    "stressasses": "stresser",
    "stressassiez": "stresser",
    "stressassions": "stresser",
    "stresse": "stresser",
    "stressent": "stresser",
    "stressera": "stresser",
    "stresserai": "stresser",
    "stresseraient": "stresser",
    "stresserais": "stresser",
    "stresserait": "stresser",
    "stresseras": "stresser",
    "stresserez": "stresser",
    "stresseriez": "stresser",
    "stresserions": "stresser",
    "stresserons": "stresser",
    "stresseront": "stresser",
    "stresses": "stresser",
    "stressez": "stresser",
    "stressiez": "stresser",
    "stressions": "stresser",
    "stressons": "stresser",
    "stressâmes": "stresser",
    "stressât": "stresser",
    "stressâtes": "stresser",
    "stressèrent": "stresser",
    "stressé": "stresser",
    "stressée": "stresser",
    "stressées": "stresser",
    "stressés": "stresser",
    "stria": "strier",
    "striai": "strier",
    "striaient": "strier",
    "striais": "strier",
    "striait": "strier",
    "striant": "strier",
    "strias": "strier",
    "striasse": "strier",
    "striassent": "strier",
    "striasses": "strier",
    "striassiez": "strier",
    "striassions": "strier",
    "striations": "striation",
    "stricte": "strict",
    "strictes": "strict",
    "stricts": "strict",
    "stridences": "stridence",
    "stridente": "strident",
    "stridentes": "strident",
    "stridents": "strident",
    "stridula": "striduler",
    "stridulai": "striduler",
    "stridulaient": "striduler",
    "stridulais": "striduler",
    "stridulait": "striduler",
    "stridulant": "striduler",
    "stridulas": "striduler",
    "stridulasse": "striduler",
    "stridulassent": "striduler",
    "stridulasses": "striduler",
    "stridulassiez": "striduler",
    "stridulassions": "striduler",
    "stridulations": "stridulation",
    "stridule": "striduler",
    "stridulent": "striduler",
    "stridulera": "striduler",
    "stridulerai": "striduler",
    "striduleraient": "striduler",
    "stridulerais": "striduler",
    "stridulerait": "striduler",
    "striduleras": "striduler",
    "stridulerez": "striduler",
    "striduleriez": "striduler",
    "stridulerions": "striduler",
    "stridulerons": "striduler",
    "striduleront": "striduler",
    "stridules": "striduler",
    "striduleuse": "striduleux",
    "stridulez": "striduler",
    "striduliez": "striduler",
    "stridulions": "striduler",
    "stridulons": "striduler",
    "stridulâmes": "striduler",
    "stridulât": "striduler",
    "stridulâtes": "striduler",
    "stridulèrent": "striduler",
    "stridulé": "striduler",
    "strie": "strier",
    "strient": "strier",
    "striera": "strier",
    "strierai": "strier",
    "strieraient": "strier",
    "strierais": "strier",
    "strierait": "strier",
    "strieras": "strier",
    "strierez": "strier",
    "strieriez": "strier",
    "strierions": "strier",
    "strierons": "strier",
    "strieront": "strier",
    "stries": "strier",
    "striez": "strier",
    "striges": "strige",
    "strigiles": "strigile",
    "striiez": "strier",
    "striions": "strier",
    "strings": "string",
    "strions": "strier",
    "strip-teases": "strip-tease",
    "strip-teaseurs": "strip-teaseur",
    "strip-teaseuse": "strip-teaseur",
    "strip-teaseuses": "strip-teaseuse",
    "strippings": "stripping",
    "stripteaseuse": "stripteaseur",
    "stripteaseuses": "stripteaseur",
    "striures": "striure",
    "striâmes": "strier",
    "striât": "strier",
    "striâtes": "strier",
    "strièrent": "strier",
    "strié": "strier",
    "striée": "strier",
    "striées": "strier",
    "striés": "strier",
    "strobiles": "strobile",
    "strongles": "strongle",
    "strongyles": "strongyle",
    "strontiums": "strontium",
    "strophes": "strophe",
    "stropiats": "stropiat",
    "structura": "structurer",
    "structurai": "structurer",
    "structuraient": "structurer",
    "structurais": "structurer",
    "structurait": "structurer",
    "structurale": "structural",
    "structurales": "structural",
    "structuralismes": "structuralisme",
    "structuralistes": "structuraliste",
    "structurant": "structurer",
    "structuras": "structurer",
    "structurasse": "structurer",
    "structurassent": "structurer",
    "structurasses": "structurer",
    "structurassiez": "structurer",
    "structurassions": "structurer",
    "structurations": "structuration",
    "structuraux": "structural",
    "structure": "structurer",
    "structurelle": "structurel",
    "structurelles": "structurel",
    "structurels": "structurel",
    "structurent": "structurer",
    "structurera": "structurer",
    "structurerai": "structurer",
    "structureraient": "structurer",
    "structurerais": "structurer",
    "structurerait": "structurer",
    "structureras": "structurer",
    "structurerez": "structurer",
    "structureriez": "structurer",
    "structurerions": "structurer",
    "structurerons": "structurer",
    "structureront": "structurer",
    "structures": "structurer",
    "structurez": "structurer",
    "structuriez": "structurer",
    "structurions": "structurer",
    "structurons": "structurer",
    "structurâmes": "structurer",
    "structurât": "structurer",
    "structurâtes": "structurer",
    "structurèrent": "structurer",
    "structuré": "structurer",
    "structurée": "structurer",
    "structurées": "structurer",
    "structurés": "structurer",
    "strudels": "strudel",
    "strychnines": "strychnine",
    "stryges": "stryge",
    "stucages": "stucage",
    "stucs": "stuc",
    "stud-books": "stud-book",
    "studettes": "studette",
    "studieuse": "studieux",
    "studieuses": "studieux",
    "studios": "studio",
    "stukas": "stuka",
    "stup": "stups",
    "stupas": "stupa",
    "stupeurs": "stupeur",
    "stupides": "stupide",
    "stupidités": "stupidité",
    "stuporeuse": "stuporeux",
    "stupres": "stupre",
    "stups": "stup",
    "stupéfactions": "stupéfaction",
    "stupéfaite": "stupéfait",
    "stupéfaites": "stupéfait",
    "stupéfaits": "stupéfait",
    "stupéfia": "stupéfier",
    "stupéfiai": "stupéfier",
    "stupéfiaient": "stupéfier",
    "stupéfiais": "stupéfier",
    "stupéfiait": "stupéfier",
    "stupéfiant": "stupéfier",
    "stupéfiante": "stupéfiant",
    "stupéfiantes": "stupéfiant",
    "stupéfiants": "stupéfiant",
    "stupéfias": "stupéfier",
    "stupéfiasse": "stupéfier",
    "stupéfiassent": "stupéfier",
    "stupéfiasses": "stupéfier",
    "stupéfiassiez": "stupéfier",
    "stupéfiassions": "stupéfier",
    "stupéfie": "stupéfier",
    "stupéfient": "stupéfier",
    "stupéfiera": "stupéfier",
    "stupéfierai": "stupéfier",
    "stupéfieraient": "stupéfier",
    "stupéfierais": "stupéfier",
    "stupéfierait": "stupéfier",
    "stupéfieras": "stupéfier",
    "stupéfierez": "stupéfier",
    "stupéfieriez": "stupéfier",
    "stupéfierions": "stupéfier",
    "stupéfierons": "stupéfier",
    "stupéfieront": "stupéfier",
    "stupéfies": "stupéfier",
    "stupéfiez": "stupéfier",
    "stupéfiiez": "stupéfier",
    "stupéfiions": "stupéfier",
    "stupéfions": "stupéfier",
    "stupéfiâmes": "stupéfier",
    "stupéfiât": "stupéfier",
    "stupéfiâtes": "stupéfier",
    "stupéfièrent": "stupéfier",
    "stupéfié": "stupéfier",
    "stupéfiée": "stupéfier",
    "stupéfiées": "stupéfier",
    "stupéfiés": "stupéfier",
    "stuqua": "stuquer",
    "stuquai": "stuquer",
    "stuquaient": "stuquer",
    "stuquais": "stuquer",
    "stuquait": "stuquer",
    "stuquant": "stuquer",
    "stuquas": "stuquer",
    "stuquasse": "stuquer",
    "stuquassent": "stuquer",
    "stuquasses": "stuquer",
    "stuquassiez": "stuquer",
    "stuquassions": "stuquer",
    "stuque": "stuquer",
    "stuquent": "stuquer",
    "stuquera": "stuquer",
    "stuquerai": "stuquer",
    "stuqueraient": "stuquer",
    "stuquerais": "stuquer",
    "stuquerait": "stuquer",
    "stuqueras": "stuquer",
    "stuquerez": "stuquer",
    "stuqueriez": "stuquer",
    "stuquerions": "stuquer",
    "stuquerons": "stuquer",
    "stuqueront": "stuquer",
    "stuques": "stuquer",
    "stuquez": "stuquer",
    "stuquiez": "stuquer",
    "stuquions": "stuquer",
    "stuquons": "stuquer",
    "stuquâmes": "stuquer",
    "stuquât": "stuquer",
    "stuquâtes": "stuquer",
    "stuquèrent": "stuquer",
    "stuqué": "stuquer",
    "stuquée": "stuquer",
    "stuquées": "stuquer",
    "stuqués": "stuquer",
    "style": "styler",
    "styles": "style",
    "stylets": "stylet",
    "stylisa": "styliser",
    "stylisai": "styliser",
    "stylisaient": "styliser",
    "stylisais": "styliser",
    "stylisait": "styliser",
    "stylisant": "styliser",
    "stylisas": "styliser",
    "stylisasse": "styliser",
    "stylisassent": "styliser",
    "stylisasses": "styliser",
    "stylisassiez": "styliser",
    "stylisassions": "styliser",
    "stylise": "styliser",
    "stylisent": "styliser",
    "stylisera": "styliser",
    "styliserai": "styliser",
    "styliseraient": "styliser",
    "styliserais": "styliser",
    "styliserait": "styliser",
    "styliseras": "styliser",
    "styliserez": "styliser",
    "styliseriez": "styliser",
    "styliserions": "styliser",
    "styliserons": "styliser",
    "styliseront": "styliser",
    "stylises": "styliser",
    "stylisez": "styliser",
    "stylisiez": "styliser",
    "stylisions": "styliser",
    "stylisons": "styliser",
    "stylistes": "styliste",
    "stylistiques": "stylistique",
    "stylisâmes": "styliser",
    "stylisât": "styliser",
    "stylisâtes": "styliser",
    "stylisèrent": "styliser",
    "stylisé": "styliser",
    "stylisée": "styliser",
    "stylisées": "styliser",
    "stylisés": "styliser",
    "stylites": "stylite",
    "stylobates": "stylobate",
    "stylographes": "stylographe",
    "stylos": "stylo",
    "stylos-feutres": "stylo-feutre",
    "stylé": "styler",
    "stylée": "styler",
    "stylées": "styler",
    "stylés": "styler",
    "styrènes": "styrène",
    "stèles": "stèle",
    "stères": "stère",
    "stéarates": "stéarate",
    "stéarines": "stéarine",
    "stéatomes": "stéatome",
    "stéatopyges": "stéatopyge",
    "stégosaures": "stégosaure",
    "sténodactylos": "sténodactylo",
    "sténographes": "sténographe",
    "sténographiai": "sténographier",
    "sténographies": "sténographie",
    "sténographiques": "sténographique",
    "sténopés": "sténopé",
    "sténos": "sténo",
    "sténoses": "sténose",
    "sténotypies": "sténotypie",
    "sténotypistes": "sténotypiste",
    "stéphanoise": "stéphanois",
    "stéphanoises": "stéphanois",
    "stériles": "stérile",
    "stérilisa": "stériliser",
    "stérilisai": "stériliser",
    "stérilisaient": "stériliser",
    "stérilisais": "stériliser",
    "stérilisait": "stériliser",
    "stérilisant": "stériliser",
    "stérilisante": "stérilisant",
    "stérilisantes": "stérilisant",
    "stérilisants": "stérilisant",
    "stérilisas": "stériliser",
    "stérilisasse": "stériliser",
    "stérilisassent": "stériliser",
    "stérilisasses": "stériliser",
    "stérilisassiez": "stériliser",
    "stérilisassions": "stériliser",
    "stérilisations": "stérilisation",
    "stérilise": "stériliser",
    "stérilisent": "stériliser",
    "stérilisera": "stériliser",
    "stériliserai": "stériliser",
    "stériliseraient": "stériliser",
    "stériliserais": "stériliser",
    "stériliserait": "stériliser",
    "stériliseras": "stériliser",
    "stériliserez": "stériliser",
    "stériliseriez": "stériliser",
    "stériliserions": "stériliser",
    "stériliserons": "stériliser",
    "stériliseront": "stériliser",
    "stérilises": "stériliser",
    "stérilisez": "stériliser",
    "stérilisiez": "stériliser",
    "stérilisions": "stériliser",
    "stérilisons": "stériliser",
    "stérilisâmes": "stériliser",
    "stérilisât": "stériliser",
    "stérilisâtes": "stériliser",
    "stérilisèrent": "stériliser",
    "stérilisé": "stériliser",
    "stérilisée": "stériliser",
    "stérilisées": "stériliser",
    "stérilisés": "stériliser",
    "stérilités": "stérilité",
    "stéroïdes": "stéroïde",
    "stéréobates": "stéréobate",
    "stéréophonies": "stéréophonie",
    "stéréos": "stéréo",
    "stéréoscopiques": "stéréoscopique",
    "stéréotypa": "stéréotyper",
    "stéréotypai": "stéréotyper",
    "stéréotypaient": "stéréotyper",
    "stéréotypais": "stéréotyper",
    "stéréotypait": "stéréotyper",
    "stéréotypant": "stéréotyper",
    "stéréotypas": "stéréotyper",
    "stéréotypasse": "stéréotyper",
    "stéréotypassent": "stéréotyper",
    "stéréotypasses": "stéréotyper",
    "stéréotypassiez": "stéréotyper",
    "stéréotypassions": "stéréotyper",
    "stéréotype": "stéréotyper",
    "stéréotypent": "stéréotyper",
    "stéréotypera": "stéréotyper",
    "stéréotyperai": "stéréotyper",
    "stéréotyperaient": "stéréotyper",
    "stéréotyperais": "stéréotyper",
    "stéréotyperait": "stéréotyper",
    "stéréotyperas": "stéréotyper",
    "stéréotyperez": "stéréotyper",
    "stéréotyperiez": "stéréotyper",
    "stéréotyperions": "stéréotyper",
    "stéréotyperons": "stéréotyper",
    "stéréotyperont": "stéréotyper",
    "stéréotypes": "stéréotyper",
    "stéréotypez": "stéréotyper",
    "stéréotypiez": "stéréotyper",
    "stéréotypions": "stéréotyper",
    "stéréotypons": "stéréotyper",
    "stéréotypâmes": "stéréotyper",
    "stéréotypât": "stéréotyper",
    "stéréotypâtes": "stéréotyper",
    "stéréotypèrent": "stéréotyper",
    "stéréotypé": "stéréotyper",
    "stéréotypée": "stéréotyper",
    "stéréotypées": "stéréotyper",
    "stéréotypés": "stéréotyper",
    "stéthoscopes": "stéthoscope",
    "su": "savoir",
    "sua": "suer",
    "suai": "suer",
    "suaient": "suer",
    "suaires": "suaire",
    "suais": "suer",
    "suait": "suer",
    "suant": "suer",
    "suante": "suant",
    "suantes": "suant",
    "suants": "suant",
    "suas": "suer",
    "suasse": "suer",
    "suassent": "suer",
    "suasses": "suer",
    "suassiez": "suer",
    "suassions": "suer",
    "suaves": "suave",
    "sub-atomiques": "sub-atomique",
    "sub-nucléaires": "sub-nucléaire",
    "subaigus": "subaigu",
    "subaiguë": "subaigu",
    "subaiguës": "subaigu",
    "subalpine": "subalpin",
    "subalpines": "subalpin",
    "subalpins": "subalpin",
    "subalternes": "subalterne",
    "subaquatiques": "subaquatique",
    "subatomiques": "subatomique",
    "subconsciente": "subconscient",
    "subconscientes": "subconscient",
    "subconscients": "subconscient",
    "subdivisa": "subdiviser",
    "subdivisai": "subdiviser",
    "subdivisaient": "subdiviser",
    "subdivisais": "subdiviser",
    "subdivisait": "subdiviser",
    "subdivisant": "subdiviser",
    "subdivisas": "subdiviser",
    "subdivisasse": "subdiviser",
    "subdivisassent": "subdiviser",
    "subdivisasses": "subdiviser",
    "subdivisassiez": "subdiviser",
    "subdivisassions": "subdiviser",
    "subdivise": "subdiviser",
    "subdivisent": "subdiviser",
    "subdivisera": "subdiviser",
    "subdiviserai": "subdiviser",
    "subdiviseraient": "subdiviser",
    "subdiviserais": "subdiviser",
    "subdiviserait": "subdiviser",
    "subdiviseras": "subdiviser",
    "subdiviserez": "subdiviser",
    "subdiviseriez": "subdiviser",
    "subdiviserions": "subdiviser",
    "subdiviserons": "subdiviser",
    "subdiviseront": "subdiviser",
    "subdivises": "subdiviser",
    "subdivisez": "subdiviser",
    "subdivisiez": "subdiviser",
    "subdivisions": "subdivision",
    "subdivisons": "subdiviser",
    "subdivisâmes": "subdiviser",
    "subdivisât": "subdiviser",
    "subdivisâtes": "subdiviser",
    "subdivisèrent": "subdiviser",
    "subdivisé": "subdiviser",
    "subdivisée": "subdiviser",
    "subdivisées": "subdiviser",
    "subdivisés": "subdiviser",
    "subdélègue": "subdéléguer",
    "subdélèguent": "subdéléguer",
    "subdélègues": "subdéléguer",
    "subdélégua": "subdéléguer",
    "subdéléguai": "subdéléguer",
    "subdéléguaient": "subdéléguer",
    "subdéléguais": "subdéléguer",
    "subdéléguait": "subdéléguer",
    "subdéléguant": "subdéléguer",
    "subdéléguas": "subdéléguer",
    "subdéléguasse": "subdéléguer",
    "subdéléguassent": "subdéléguer",
    "subdéléguasses": "subdéléguer",
    "subdéléguassiez": "subdéléguer",
    "subdéléguassions": "subdéléguer",
    "subdéléguera": "subdéléguer",
    "subdéléguerai": "subdéléguer",
    "subdélégueraient": "subdéléguer",
    "subdéléguerais": "subdéléguer",
    "subdéléguerait": "subdéléguer",
    "subdélégueras": "subdéléguer",
    "subdéléguerez": "subdéléguer",
    "subdélégueriez": "subdéléguer",
    "subdéléguerions": "subdéléguer",
    "subdéléguerons": "subdéléguer",
    "subdélégueront": "subdéléguer",
    "subdéléguez": "subdéléguer",
    "subdéléguiez": "subdéléguer",
    "subdéléguions": "subdéléguer",
    "subdéléguons": "subdéléguer",
    "subdéléguâmes": "subdéléguer",
    "subdéléguât": "subdéléguer",
    "subdéléguâtes": "subdéléguer",
    "subdéléguèrent": "subdéléguer",
    "subdélégué": "subdéléguer",
    "subdéléguée": "subdéléguer",
    "subdéléguées": "subdéléguer",
    "subdélégués": "subdéléguer",
    "subers": "suber",
    "subi": "subir",
    "subie": "subir",
    "subies": "subir",
    "subira": "subir",
    "subirai": "subir",
    "subiraient": "subir",
    "subirais": "subir",
    "subirait": "subir",
    "subiras": "subir",
    "subirent": "subir",
    "subirez": "subir",
    "subiriez": "subir",
    "subirions": "subir",
    "subirons": "subir",
    "subiront": "subir",
    "subis": "subir",
    "subissaient": "subir",
    "subissais": "subir",
    "subissait": "subir",
    "subissant": "subir",
    "subisse": "subir",
    "subissent": "subir",
    "subisses": "subir",
    "subissez": "subir",
    "subissiez": "subir",
    "subissions": "subir",
    "subissons": "subir",
    "subit": "subir",
    "subite": "subit",
    "subites": "subit",
    "subits": "subit",
    "subjectifs": "subjectif",
    "subjective": "subjectiver",
    "subjectives": "subjectif",
    "subjectivités": "subjectivité",
    "subjonctifs": "subjonctif",
    "subjugua": "subjuguer",
    "subjuguai": "subjuguer",
    "subjuguaient": "subjuguer",
    "subjuguais": "subjuguer",
    "subjuguait": "subjuguer",
    "subjuguant": "subjuguer",
    "subjuguas": "subjuguer",
    "subjuguasse": "subjuguer",
    "subjuguassent": "subjuguer",
    "subjuguasses": "subjuguer",
    "subjuguassiez": "subjuguer",
    "subjuguassions": "subjuguer",
    "subjugue": "subjuguer",
    "subjuguent": "subjuguer",
    "subjuguera": "subjuguer",
    "subjuguerai": "subjuguer",
    "subjugueraient": "subjuguer",
    "subjuguerais": "subjuguer",
    "subjuguerait": "subjuguer",
    "subjugueras": "subjuguer",
    "subjuguerez": "subjuguer",
    "subjugueriez": "subjuguer",
    "subjuguerions": "subjuguer",
    "subjuguerons": "subjuguer",
    "subjugueront": "subjuguer",
    "subjugues": "subjuguer",
    "subjuguez": "subjuguer",
    "subjuguiez": "subjuguer",
    "subjuguions": "subjuguer",
    "subjuguons": "subjuguer",
    "subjuguâmes": "subjuguer",
    "subjuguât": "subjuguer",
    "subjuguâtes": "subjuguer",
    "subjuguèrent": "subjuguer",
    "subjugué": "subjuguer",
    "subjuguée": "subjuguer",
    "subjuguées": "subjuguer",
    "subjugués": "subjuguer",
    "sublima": "sublimer",
    "sublimai": "sublimer",
    "sublimaient": "sublimer",
    "sublimais": "sublimer",
    "sublimait": "sublimer",
    "sublimant": "sublimer",
    "sublimas": "sublimer",
    "sublimasse": "sublimer",
    "sublimassent": "sublimer",
    "sublimasses": "sublimer",
    "sublimassiez": "sublimer",
    "sublimassions": "sublimer",
    "sublimations": "sublimation",
    "sublime": "sublimer",
    "subliment": "sublimer",
    "sublimera": "sublimer",
    "sublimerai": "sublimer",
    "sublimeraient": "sublimer",
    "sublimerais": "sublimer",
    "sublimerait": "sublimer",
    "sublimeras": "sublimer",
    "sublimerez": "sublimer",
    "sublimeriez": "sublimer",
    "sublimerions": "sublimer",
    "sublimerons": "sublimer",
    "sublimeront": "sublimer",
    "sublimes": "sublimer",
    "sublimez": "sublimer",
    "sublimiez": "sublimer",
    "subliminale": "subliminal",
    "subliminales": "subliminal",
    "subliminaux": "subliminal",
    "sublimions": "sublimer",
    "sublimités": "sublimité",
    "sublimons": "sublimer",
    "sublimâmes": "sublimer",
    "sublimât": "sublimer",
    "sublimâtes": "sublimer",
    "sublimèrent": "sublimer",
    "sublimé": "sublimer",
    "sublimée": "sublimer",
    "sublimées": "sublimer",
    "sublimés": "sublimer",
    "sublinguale": "sublingual",
    "sublinguales": "sublingual",
    "sublinguaux": "sublingual",
    "sublunaires": "sublunaire",
    "submerge": "submerger",
    "submergea": "submerger",
    "submergeai": "submerger",
    "submergeaient": "submerger",
    "submergeais": "submerger",
    "submergeait": "submerger",
    "submergeant": "submerger",
    "submergeas": "submerger",
    "submergeasse": "submerger",
    "submergeassent": "submerger",
    "submergeasses": "submerger",
    "submergeassiez": "submerger",
    "submergeassions": "submerger",
    "submergent": "submerger",
    "submergeons": "submerger",
    "submergera": "submerger",
    "submergerai": "submerger",
    "submergeraient": "submerger",
    "submergerais": "submerger",
    "submergerait": "submerger",
    "submergeras": "submerger",
    "submergerez": "submerger",
    "submergeriez": "submerger",
    "submergerions": "submerger",
    "submergerons": "submerger",
    "submergeront": "submerger",
    "submerges": "submerger",
    "submergez": "submerger",
    "submergeâmes": "submerger",
    "submergeât": "submerger",
    "submergeâtes": "submerger",
    "submergiez": "submerger",
    "submergions": "submerger",
    "submergèrent": "submerger",
    "submergé": "submerger",
    "submergée": "submerger",
    "submergées": "submerger",
    "submergés": "submerger",
    "submersibles": "submersible",
    "submersions": "submersion",
    "submicroniques": "submicronique",
    "subodora": "subodorer",
    "subodorai": "subodorer",
    "subodoraient": "subodorer",
    "subodorais": "subodorer",
    "subodorait": "subodorer",
    "subodorant": "subodorer",
    "subodoras": "subodorer",
    "subodorasse": "subodorer",
    "subodorassent": "subodorer",
    "subodorasses": "subodorer",
    "subodorassiez": "subodorer",
    "subodorassions": "subodorer",
    "subodore": "subodorer",
    "subodorent": "subodorer",
    "subodorera": "subodorer",
    "subodorerai": "subodorer",
    "subodoreraient": "subodorer",
    "subodorerais": "subodorer",
    "subodorerait": "subodorer",
    "subodoreras": "subodorer",
    "subodorerez": "subodorer",
    "subodoreriez": "subodorer",
    "subodorerions": "subodorer",
    "subodorerons": "subodorer",
    "subodoreront": "subodorer",
    "subodores": "subodorer",
    "subodorez": "subodorer",
    "subodoriez": "subodorer",
    "subodorions": "subodorer",
    "subodorons": "subodorer",
    "subodorâmes": "subodorer",
    "subodorât": "subodorer",
    "subodorâtes": "subodorer",
    "subodorèrent": "subodorer",
    "subodoré": "subodorer",
    "subodorée": "subodorer",
    "subodorées": "subodorer",
    "subodorés": "subodorer",
    "suborbitale": "suborbital",
    "subordinations": "subordination",
    "subordonna": "subordonner",
    "subordonnai": "subordonner",
    "subordonnaient": "subordonner",
    "subordonnais": "subordonner",
    "subordonnait": "subordonner",
    "subordonnant": "subordonner",
    "subordonnas": "subordonner",
    "subordonnasse": "subordonner",
    "subordonnassent": "subordonner",
    "subordonnasses": "subordonner",
    "subordonnassiez": "subordonner",
    "subordonnassions": "subordonner",
    "subordonne": "subordonner",
    "subordonnent": "subordonner",
    "subordonnera": "subordonner",
    "subordonnerai": "subordonner",
    "subordonneraient": "subordonner",
    "subordonnerais": "subordonner",
    "subordonnerait": "subordonner",
    "subordonneras": "subordonner",
    "subordonnerez": "subordonner",
    "subordonneriez": "subordonner",
    "subordonnerions": "subordonner",
    "subordonnerons": "subordonner",
    "subordonneront": "subordonner",
    "subordonnes": "subordonner",
    "subordonnez": "subordonner",
    "subordonniez": "subordonner",
    "subordonnions": "subordonner",
    "subordonnons": "subordonner",
    "subordonnâmes": "subordonner",
    "subordonnât": "subordonner",
    "subordonnâtes": "subordonner",
    "subordonnèrent": "subordonner",
    "subordonné": "subordonner",
    "subordonnée": "subordonner",
    "subordonnées": "subordonner",
    "subordonnés": "subordonner",
    "suborna": "suborner",
    "subornai": "suborner",
    "subornaient": "suborner",
    "subornais": "suborner",
    "subornait": "suborner",
    "subornant": "suborner",
    "subornas": "suborner",
    "subornasse": "suborner",
    "subornassent": "suborner",
    "subornasses": "suborner",
    "subornassiez": "suborner",
    "subornassions": "suborner",
    "suborne": "suborner",
    "subornent": "suborner",
    "subornera": "suborner",
    "subornerai": "suborner",
    "suborneraient": "suborner",
    "subornerais": "suborner",
    "subornerait": "suborner",
    "suborneras": "suborner",
    "subornerez": "suborner",
    "suborneriez": "suborner",
    "subornerions": "suborner",
    "subornerons": "suborner",
    "suborneront": "suborner",
    "subornes": "suborner",
    "suborneurs": "suborneur",
    "subornez": "suborner",
    "suborniez": "suborner",
    "subornions": "suborner",
    "subornons": "suborner",
    "subornâmes": "suborner",
    "subornât": "suborner",
    "subornâtes": "suborner",
    "subornèrent": "suborner",
    "suborné": "suborner",
    "subornée": "suborner",
    "subornées": "suborner",
    "subornés": "suborner",
    "subreptices": "subreptice",
    "subroge": "subroger",
    "subrogea": "subroger",
    "subrogeai": "subroger",
    "subrogeaient": "subroger",
    "subrogeais": "subroger",
    "subrogeait": "subroger",
    "subrogeant": "subroger",
    "subrogeas": "subroger",
    "subrogeasse": "subroger",
    "subrogeassent": "subroger",
    "subrogeasses": "subroger",
    "subrogeassiez": "subroger",
    "subrogeassions": "subroger",
    "subrogent": "subroger",
    "subrogeons": "subroger",
    "subrogera": "subroger",
    "subrogerai": "subroger",
    "subrogeraient": "subroger",
    "subrogerais": "subroger",
    "subrogerait": "subroger",
    "subrogeras": "subroger",
    "subrogerez": "subroger",
    "subrogeriez": "subroger",
    "subrogerions": "subroger",
    "subrogerons": "subroger",
    "subrogeront": "subroger",
    "subroges": "subroger",
    "subrogez": "subroger",
    "subrogeâmes": "subroger",
    "subrogeât": "subroger",
    "subrogeâtes": "subroger",
    "subrogiez": "subroger",
    "subrogions": "subroger",
    "subrogèrent": "subroger",
    "subrogé": "subroger",
    "subrogée": "subroger",
    "subrogées": "subroger",
    "subrogés": "subroger",
    "subrégionale": "subrégional",
    "subrégionales": "subrégional",
    "subrégionaux": "subrégional",
    "subsaharienne": "subsaharien",
    "subsahariennes": "subsaharien",
    "subsahariens": "subsaharien",
    "subsides": "subside",
    "subsidiaires": "subsidiaire",
    "subsidiarités": "subsidiarité",
    "subsista": "subsister",
    "subsistai": "subsister",
    "subsistaient": "subsister",
    "subsistais": "subsister",
    "subsistait": "subsister",
    "subsistances": "subsistance",
    "subsistant": "subsister",
    "subsistante": "subsistant",
    "subsistantes": "subsistant",
    "subsistants": "subsistant",
    "subsistas": "subsister",
    "subsistasse": "subsister",
    "subsistassent": "subsister",
    "subsistasses": "subsister",
    "subsistassiez": "subsister",
    "subsistassions": "subsister",
    "subsiste": "subsister",
    "subsistent": "subsister",
    "subsistera": "subsister",
    "subsisterai": "subsister",
    "subsisteraient": "subsister",
    "subsisterais": "subsister",
    "subsisterait": "subsister",
    "subsisteras": "subsister",
    "subsisterez": "subsister",
    "subsisteriez": "subsister",
    "subsisterions": "subsister",
    "subsisterons": "subsister",
    "subsisteront": "subsister",
    "subsistes": "subsister",
    "subsistez": "subsister",
    "subsistiez": "subsister",
    "subsistions": "subsister",
    "subsistons": "subsister",
    "subsistâmes": "subsister",
    "subsistât": "subsister",
    "subsistâtes": "subsister",
    "subsistèrent": "subsister",
    "subsisté": "subsister",
    "subsoniques": "subsonique",
    "substances": "substance",
    "substantielle": "substantiel",
    "substantielles": "substantiel",
    "substantiels": "substantiel",
    "substantifs": "substantif",
    "substitua": "substituer",
    "substituai": "substituer",
    "substituaient": "substituer",
    "substituais": "substituer",
    "substituait": "substituer",
    "substituant": "substituer",
    "substituas": "substituer",
    "substituasse": "substituer",
    "substituassent": "substituer",
    "substituasses": "substituer",
    "substituassiez": "substituer",
    "substituassions": "substituer",
    "substitue": "substituer",
    "substituent": "substituer",
    "substituera": "substituer",
    "substituerai": "substituer",
    "substitueraient": "substituer",
    "substituerais": "substituer",
    "substituerait": "substituer",
    "substitueras": "substituer",
    "substituerez": "substituer",
    "substitueriez": "substituer",
    "substituerions": "substituer",
    "substituerons": "substituer",
    "substitueront": "substituer",
    "substitues": "substituer",
    "substituez": "substituer",
    "substituiez": "substituer",
    "substituions": "substituer",
    "substituons": "substituer",
    "substitutions": "substitution",
    "substituts": "substitut",
    "substituâmes": "substituer",
    "substituât": "substituer",
    "substituâtes": "substituer",
    "substituèrent": "substituer",
    "substitué": "substituer",
    "substituée": "substituer",
    "substituées": "substituer",
    "substitués": "substituer",
    "substratums": "substratum",
    "subséquente": "subséquent",
    "subséquentes": "subséquent",
    "subséquents": "subséquent",
    "subterfuges": "subterfuge",
    "subtile": "subtil",
    "subtiles": "subtil",
    "subtilisa": "subtiliser",
    "subtilisai": "subtiliser",
    "subtilisaient": "subtiliser",
    "subtilisais": "subtiliser",
    "subtilisait": "subtiliser",
    "subtilisant": "subtiliser",
    "subtilisas": "subtiliser",
    "subtilisasse": "subtiliser",
    "subtilisassent": "subtiliser",
    "subtilisasses": "subtiliser",
    "subtilisassiez": "subtiliser",
    "subtilisassions": "subtiliser",
    "subtilise": "subtiliser",
    "subtilisent": "subtiliser",
    "subtilisera": "subtiliser",
    "subtiliserai": "subtiliser",
    "subtiliseraient": "subtiliser",
    "subtiliserais": "subtiliser",
    "subtiliserait": "subtiliser",
    "subtiliseras": "subtiliser",
    "subtiliserez": "subtiliser",
    "subtiliseriez": "subtiliser",
    "subtiliserions": "subtiliser",
    "subtiliserons": "subtiliser",
    "subtiliseront": "subtiliser",
    "subtilises": "subtiliser",
    "subtilisez": "subtiliser",
    "subtilisiez": "subtiliser",
    "subtilisions": "subtiliser",
    "subtilisons": "subtiliser",
    "subtilisâmes": "subtiliser",
    "subtilisât": "subtiliser",
    "subtilisâtes": "subtiliser",
    "subtilisèrent": "subtiliser",
    "subtilisé": "subtiliser",
    "subtilisée": "subtiliser",
    "subtilisées": "subtiliser",
    "subtilisés": "subtiliser",
    "subtilités": "subtilité",
    "subtils": "subtil",
    "subtropicale": "subtropical",
    "subtropicales": "subtropical",
    "subtropicaux": "subtropical",
    "suburbaine": "suburbain",
    "suburbaines": "suburbain",
    "suburbains": "suburbain",
    "subvenaient": "subvenir",
    "subvenais": "subvenir",
    "subvenait": "subvenir",
    "subvenant": "subvenir",
    "subvenez": "subvenir",
    "subveniez": "subvenir",
    "subvenions": "subvenir",
    "subvenons": "subvenir",
    "subventionna": "subventionner",
    "subventionnai": "subventionner",
    "subventionnaient": "subventionner",
    "subventionnais": "subventionner",
    "subventionnait": "subventionner",
    "subventionnant": "subventionner",
    "subventionnas": "subventionner",
    "subventionnasse": "subventionner",
    "subventionnassent": "subventionner",
    "subventionnasses": "subventionner",
    "subventionnassiez": "subventionner",
    "subventionnassions": "subventionner",
    "subventionne": "subventionner",
    "subventionnements": "subventionnement",
    "subventionnent": "subventionner",
    "subventionnera": "subventionner",
    "subventionnerai": "subventionner",
    "subventionneraient": "subventionner",
    "subventionnerais": "subventionner",
    "subventionnerait": "subventionner",
    "subventionneras": "subventionner",
    "subventionnerez": "subventionner",
    "subventionneriez": "subventionner",
    "subventionnerions": "subventionner",
    "subventionnerons": "subventionner",
    "subventionneront": "subventionner",
    "subventionnes": "subventionner",
    "subventionnez": "subventionner",
    "subventionniez": "subventionner",
    "subventionnions": "subventionner",
    "subventionnons": "subventionner",
    "subventionnâmes": "subventionner",
    "subventionnât": "subventionner",
    "subventionnâtes": "subventionner",
    "subventionnèrent": "subventionner",
    "subventionné": "subventionner",
    "subventionnée": "subventionner",
    "subventionnées": "subventionner",
    "subventionnés": "subventionner",
    "subventions": "subvention",
    "subvenu": "subvenir",
    "subversifs": "subversif",
    "subversions": "subversion",
    "subversive": "subversif",
    "subversives": "subversif",
    "subverti": "subvertir",
    "subvertie": "subvertir",
    "subverties": "subvertir",
    "subvertira": "subvertir",
    "subvertirai": "subvertir",
    "subvertiraient": "subvertir",
    "subvertirais": "subvertir",
    "subvertirait": "subvertir",
    "subvertiras": "subvertir",
    "subvertirent": "subvertir",
    "subvertirez": "subvertir",
    "subvertiriez": "subvertir",
    "subvertirions": "subvertir",
    "subvertirons": "subvertir",
    "subvertiront": "subvertir",
    "subvertis": "subvertir",
    "subvertissaient": "subvertir",
    "subvertissais": "subvertir",
    "subvertissait": "subvertir",
    "subvertissant": "subvertir",
    "subvertisse": "subvertir",
    "subvertissent": "subvertir",
    "subvertisses": "subvertir",
    "subvertissez": "subvertir",
    "subvertissiez": "subvertir",
    "subvertissions": "subvertir",
    "subvertissons": "subvertir",
    "subvertit": "subvertir",
    "subvertîmes": "subvertir",
    "subvertît": "subvertir",
    "subvertîtes": "subvertir",
    "subviendra": "subvenir",
    "subviendrai": "subvenir",
    "subviendraient": "subvenir",
    "subviendrais": "subvenir",
    "subviendrait": "subvenir",
    "subviendras": "subvenir",
    "subviendrez": "subvenir",
    "subviendriez": "subvenir",
    "subviendrions": "subvenir",
    "subviendrons": "subvenir",
    "subviendront": "subvenir",
    "subvienne": "subvenir",
    "subviennent": "subvenir",
    "subviennes": "subvenir",
    "subviens": "subvenir",
    "subvient": "subvenir",
    "subvinrent": "subvenir",
    "subvins": "subvenir",
    "subvinsse": "subvenir",
    "subvinssent": "subvenir",
    "subvinsses": "subvenir",
    "subvinssiez": "subvenir",
    "subvinssions": "subvenir",
    "subvint": "subvenir",
    "subvînmes": "subvenir",
    "subvînt": "subvenir",
    "subvîntes": "subvenir",
    "subéreuse": "subéreux",
    "subéreuses": "subéreux",
    "subérines": "subérine",
    "subîmes": "subir",
    "subît": "subir",
    "subîtes": "subir",
    "successeurs": "successeur",
    "successibles": "successible",
    "successifs": "successif",
    "successions": "succession",
    "successive": "successif",
    "successives": "successif",
    "successorale": "successoral",
    "successorales": "successoral",
    "successoraux": "successoral",
    "succincte": "succinct",
    "succinctes": "succinct",
    "succincts": "succinct",
    "succions": "succion",
    "succomba": "succomber",
    "succombai": "succomber",
    "succombaient": "succomber",
    "succombais": "succomber",
    "succombait": "succomber",
    "succombant": "succomber",
    "succombas": "succomber",
    "succombasse": "succomber",
    "succombassent": "succomber",
    "succombasses": "succomber",
    "succombassiez": "succomber",
    "succombassions": "succomber",
    "succombe": "succomber",
    "succombent": "succomber",
    "succombera": "succomber",
    "succomberai": "succomber",
    "succomberaient": "succomber",
    "succomberais": "succomber",
    "succomberait": "succomber",
    "succomberas": "succomber",
    "succomberez": "succomber",
    "succomberiez": "succomber",
    "succomberions": "succomber",
    "succomberons": "succomber",
    "succomberont": "succomber",
    "succombes": "succomber",
    "succombez": "succomber",
    "succombiez": "succomber",
    "succombions": "succomber",
    "succombons": "succomber",
    "succombâmes": "succomber",
    "succombât": "succomber",
    "succombâtes": "succomber",
    "succombèrent": "succomber",
    "succombé": "succomber",
    "succubes": "succube",
    "succulente": "succulent",
    "succulentes": "succulent",
    "succulents": "succulent",
    "succursales": "succursale",
    "succède": "succéder",
    "succèdent": "succéder",
    "succèdes": "succéder",
    "succéda": "succéder",
    "succédai": "succéder",
    "succédaient": "succéder",
    "succédais": "succéder",
    "succédait": "succéder",
    "succédant": "succéder",
    "succédanés": "succédané",
    "succédas": "succéder",
    "succédasse": "succéder",
    "succédassent": "succéder",
    "succédasses": "succéder",
    "succédassiez": "succéder",
    "succédassions": "succéder",
    "succédera": "succéder",
    "succéderai": "succéder",
    "succéderaient": "succéder",
    "succéderais": "succéder",
    "succéderait": "succéder",
    "succéderas": "succéder",
    "succéderez": "succéder",
    "succéderiez": "succéder",
    "succéderions": "succéder",
    "succéderons": "succéder",
    "succéderont": "succéder",
    "succédez": "succéder",
    "succédiez": "succéder",
    "succédions": "succéder",
    "succédons": "succéder",
    "succédâmes": "succéder",
    "succédât": "succéder",
    "succédâtes": "succéder",
    "succédèrent": "succéder",
    "succédé": "succéder",
    "succédées": "succéder",
    "suce": "sucer",
    "sucent": "sucer",
    "sucera": "sucer",
    "sucerai": "sucer",
    "suceraient": "sucer",
    "sucerais": "sucer",
    "sucerait": "sucer",
    "suceras": "sucer",
    "sucerez": "sucer",
    "suceriez": "sucer",
    "sucerions": "sucer",
    "sucerons": "sucer",
    "suceront": "sucer",
    "suces": "sucer",
    "sucettes": "sucette",
    "suceurs": "suceur",
    "suceuse": "suceur",
    "suceuses": "suceur",
    "sucez": "sucer",
    "suciez": "sucer",
    "sucions": "sucer",
    "sucra": "sucrer",
    "sucrai": "sucrer",
    "sucraient": "sucrer",
    "sucrais": "sucrer",
    "sucrait": "sucrer",
    "sucrant": "sucrer",
    "sucras": "sucrer",
    "sucrasse": "sucrer",
    "sucrassent": "sucrer",
    "sucrasses": "sucrer",
    "sucrassiez": "sucrer",
    "sucrassions": "sucrer",
    "sucre": "sucrer",
    "sucrent": "sucrer",
    "sucrera": "sucrer",
    "sucrerai": "sucrer",
    "sucreraient": "sucrer",
    "sucrerais": "sucrer",
    "sucrerait": "sucrer",
    "sucreras": "sucrer",
    "sucrerez": "sucrer",
    "sucreries": "sucrerie",
    "sucreriez": "sucrer",
    "sucrerions": "sucrer",
    "sucrerons": "sucrer",
    "sucreront": "sucrer",
    "sucres": "sucrer",
    "sucrettes": "sucrette",
    "sucrez": "sucrer",
    "sucriers": "sucrier",
    "sucriez": "sucrer",
    "sucrins": "sucrin",
    "sucrions": "sucrer",
    "sucrière": "sucrier",
    "sucrières": "sucrier",
    "sucrons": "sucrer",
    "sucrâmes": "sucrer",
    "sucrât": "sucrer",
    "sucrâtes": "sucrer",
    "sucrèrent": "sucrer",
    "sucré": "sucrer",
    "sucrée": "sucrer",
    "sucrées": "sucrer",
    "sucrés": "sucrer",
    "sucs": "suc",
    "sucèrent": "sucer",
    "sucé": "sucer",
    "sucée": "sucer",
    "sucées": "sucer",
    "sucés": "sucer",
    "sud-africaine": "sud-africain",
    "sud-africaines": "sud-africain",
    "sud-africains": "sud-africain",
    "sud-américaine": "sud-américain",
    "sud-américaines": "sud-américain",
    "sud-américains": "sud-américain",
    "sud-coréenne": "sud-coréen",
    "sud-coréennes": "sud-coréen",
    "sud-coréens": "sud-coréen",
    "sud-vietnamienne": "sud-vietnamien",
    "sud-vietnamiens": "sud-vietnamien",
    "sudatoires": "sudatoire",
    "sudistes": "sudiste",
    "sudorale": "sudoral",
    "sudorales": "sudoral",
    "sudoraux": "sudoral",
    "sudoripares": "sudoripare",
    "sudètes": "sudète",
    "sue": "suer",
    "suent": "suer",
    "suera": "suer",
    "suerai": "suer",
    "sueraient": "suer",
    "suerais": "suer",
    "suerait": "suer",
    "sueras": "suer",
    "suerez": "suer",
    "sueriez": "suer",
    "suerions": "suer",
    "suerons": "suer",
    "sueront": "suer",
    "sues": "suer",
    "sueurs": "sueur",
    "suez": "suer",
    "suffi": "suffire",
    "suffira": "suffire",
    "suffirai": "suffire",
    "suffiraient": "suffire",
    "suffirais": "suffire",
    "suffirait": "suffire",
    "suffiras": "suffire",
    "suffirent": "suffire",
    "suffirez": "suffire",
    "suffiriez": "suffire",
    "suffirions": "suffire",
    "suffirons": "suffire",
    "suffiront": "suffire",
    "suffis": "suffire",
    "suffisaient": "suffire",
    "suffisais": "suffire",
    "suffisait": "suffire",
    "suffisances": "suffisance",
    "suffisant": "suffire",
    "suffisante": "suffisant",
    "suffisantes": "suffisant",
    "suffisants": "suffisant",
    "suffise": "suffire",
    "suffisent": "suffire",
    "suffises": "suffire",
    "suffisez": "suffire",
    "suffisiez": "suffire",
    "suffisions": "suffire",
    "suffisons": "suffire",
    "suffisse": "suffire",
    "suffissent": "suffire",
    "suffisses": "suffire",
    "suffissiez": "suffire",
    "suffissions": "suffire",
    "suffit": "suffire",
    "suffixa": "suffixer",
    "suffixai": "suffixer",
    "suffixaient": "suffixer",
    "suffixais": "suffixer",
    "suffixait": "suffixer",
    "suffixale": "suffixal",
    "suffixales": "suffixal",
    "suffixant": "suffixer",
    "suffixas": "suffixer",
    "suffixasse": "suffixer",
    "suffixassent": "suffixer",
    "suffixasses": "suffixer",
    "suffixassiez": "suffixer",
    "suffixassions": "suffixer",
    "suffixaux": "suffixal",
    "suffixe": "suffixer",
    "suffixent": "suffixer",
    "suffixera": "suffixer",
    "suffixerai": "suffixer",
    "suffixeraient": "suffixer",
    "suffixerais": "suffixer",
    "suffixerait": "suffixer",
    "suffixeras": "suffixer",
    "suffixerez": "suffixer",
    "suffixeriez": "suffixer",
    "suffixerions": "suffixer",
    "suffixerons": "suffixer",
    "suffixeront": "suffixer",
    "suffixes": "suffixer",
    "suffixez": "suffixer",
    "suffixiez": "suffixer",
    "suffixions": "suffixer",
    "suffixons": "suffixer",
    "suffixâmes": "suffixer",
    "suffixât": "suffixer",
    "suffixâtes": "suffixer",
    "suffixèrent": "suffixer",
    "suffixé": "suffixer",
    "suffixée": "suffixer",
    "suffixées": "suffixer",
    "suffixés": "suffixer",
    "suffocante": "suffocant",
    "suffocantes": "suffocant",
    "suffocants": "suffocant",
    "suffocations": "suffocation",
    "suffoqua": "suffoquer",
    "suffoquai": "suffoquer",
    "suffoquaient": "suffoquer",
    "suffoquais": "suffoquer",
    "suffoquait": "suffoquer",
    "suffoquant": "suffoquer",
    "suffoquas": "suffoquer",
    "suffoquasse": "suffoquer",
    "suffoquassent": "suffoquer",
    "suffoquasses": "suffoquer",
    "suffoquassiez": "suffoquer",
    "suffoquassions": "suffoquer",
    "suffoque": "suffoquer",
    "suffoquent": "suffoquer",
    "suffoquera": "suffoquer",
    "suffoquerai": "suffoquer",
    "suffoqueraient": "suffoquer",
    "suffoquerais": "suffoquer",
    "suffoquerait": "suffoquer",
    "suffoqueras": "suffoquer",
    "suffoquerez": "suffoquer",
    "suffoqueriez": "suffoquer",
    "suffoquerions": "suffoquer",
    "suffoquerons": "suffoquer",
    "suffoqueront": "suffoquer",
    "suffoques": "suffoquer",
    "suffoquez": "suffoquer",
    "suffoquiez": "suffoquer",
    "suffoquions": "suffoquer",
    "suffoquons": "suffoquer",
    "suffoquâmes": "suffoquer",
    "suffoquât": "suffoquer",
    "suffoquâtes": "suffoquer",
    "suffoquèrent": "suffoquer",
    "suffoqué": "suffoquer",
    "suffoquée": "suffoquer",
    "suffoquées": "suffoquer",
    "suffoqués": "suffoquer",
    "suffrages": "suffrage",
    "suffragettes": "suffragette",
    "suffîmes": "suffire",
    "suffît": "suffire",
    "suffîtes": "suffire",
    "suggestifs": "suggestif",
    "suggestionna": "suggestionner",
    "suggestionnai": "suggestionner",
    "suggestionnaient": "suggestionner",
    "suggestionnais": "suggestionner",
    "suggestionnait": "suggestionner",
    "suggestionnant": "suggestionner",
    "suggestionnas": "suggestionner",
    "suggestionnasse": "suggestionner",
    "suggestionnassent": "suggestionner",
    "suggestionnasses": "suggestionner",
    "suggestionnassiez": "suggestionner",
    "suggestionnassions": "suggestionner",
    "suggestionne": "suggestionner",
    "suggestionnent": "suggestionner",
    "suggestionnera": "suggestionner",
    "suggestionnerai": "suggestionner",
    "suggestionneraient": "suggestionner",
    "suggestionnerais": "suggestionner",
    "suggestionnerait": "suggestionner",
    "suggestionneras": "suggestionner",
    "suggestionnerez": "suggestionner",
    "suggestionneriez": "suggestionner",
    "suggestionnerions": "suggestionner",
    "suggestionnerons": "suggestionner",
    "suggestionneront": "suggestionner",
    "suggestionnes": "suggestionner",
    "suggestionnez": "suggestionner",
    "suggestionniez": "suggestionner",
    "suggestionnions": "suggestionner",
    "suggestionnons": "suggestionner",
    "suggestionnâmes": "suggestionner",
    "suggestionnât": "suggestionner",
    "suggestionnâtes": "suggestionner",
    "suggestionnèrent": "suggestionner",
    "suggestionné": "suggestionner",
    "suggestionnée": "suggestionner",
    "suggestionnées": "suggestionner",
    "suggestionnés": "suggestionner",
    "suggestions": "suggestion",
    "suggestive": "suggestif",
    "suggestives": "suggestif",
    "suggère": "suggérer",
    "suggèrent": "suggérer",
    "suggères": "suggérer",
    "suggéra": "suggérer",
    "suggérai": "suggérer",
    "suggéraient": "suggérer",
    "suggérais": "suggérer",
    "suggérait": "suggérer",
    "suggérant": "suggérer",
    "suggéras": "suggérer",
    "suggérasse": "suggérer",
    "suggérassent": "suggérer",
    "suggérasses": "suggérer",
    "suggérassiez": "suggérer",
    "suggérassions": "suggérer",
    "suggérera": "suggérer",
    "suggérerai": "suggérer",
    "suggéreraient": "suggérer",
    "suggérerais": "suggérer",
    "suggérerait": "suggérer",
    "suggéreras": "suggérer",
    "suggérerez": "suggérer",
    "suggéreriez": "suggérer",
    "suggérerions": "suggérer",
    "suggérerons": "suggérer",
    "suggéreront": "suggérer",
    "suggérez": "suggérer",
    "suggériez": "suggérer",
    "suggérions": "suggérer",
    "suggérons": "suggérer",
    "suggérâmes": "suggérer",
    "suggérât": "suggérer",
    "suggérâtes": "suggérer",
    "suggérèrent": "suggérer",
    "suggéré": "suggérer",
    "suggérée": "suggérer",
    "suggérées": "suggérer",
    "suggérés": "suggérer",
    "suicida": "suicider",
    "suicidai": "suicider",
    "suicidaient": "suicider",
    "suicidaires": "suicidaire",
    "suicidais": "suicider",
    "suicidait": "suicider",
    "suicidant": "suicider",
    "suicidants": "suicidant",
    "suicidas": "suicider",
    "suicidasse": "suicider",
    "suicidassent": "suicider",
    "suicidasses": "suicider",
    "suicidassiez": "suicider",
    "suicidassions": "suicider",
    "suicide": "suicider",
    "suicident": "suicider",
    "suicidera": "suicider",
    "suiciderai": "suicider",
    "suicideraient": "suicider",
    "suiciderais": "suicider",
    "suiciderait": "suicider",
    "suicideras": "suicider",
    "suiciderez": "suicider",
    "suicideriez": "suicider",
    "suiciderions": "suicider",
    "suiciderons": "suicider",
    "suicideront": "suicider",
    "suicides": "suicider",
    "suicidez": "suicider",
    "suicidiez": "suicider",
    "suicidions": "suicider",
    "suicidons": "suicider",
    "suicidâmes": "suicider",
    "suicidât": "suicider",
    "suicidâtes": "suicider",
    "suicidèrent": "suicider",
    "suicidé": "suicider",
    "suicidée": "suicider",
    "suicidées": "suicider",
    "suicidés": "suicider",
    "suies": "suie",
    "suiez": "suer",
    "suiffeuse": "suiffeux",
    "suiffeuses": "suiffeux",
    "suiffé": "suiffer",
    "suiffée": "suiffer",
    "suiffés": "suiffer",
    "suifs": "suif",
    "suifés": "suifer",
    "suinta": "suinter",
    "suintai": "suinter",
    "suintaient": "suinter",
    "suintais": "suinter",
    "suintait": "suinter",
    "suintant": "suinter",
    "suintante": "suintant",
    "suintantes": "suintant",
    "suintants": "suintant",
    "suintas": "suinter",
    "suintasse": "suinter",
    "suintassent": "suinter",
    "suintasses": "suinter",
    "suintassiez": "suinter",
    "suintassions": "suinter",
    "suinte": "suinter",
    "suintements": "suintement",
    "suintent": "suinter",
    "suintera": "suinter",
    "suinterai": "suinter",
    "suinteraient": "suinter",
    "suinterais": "suinter",
    "suinterait": "suinter",
    "suinteras": "suinter",
    "suinterez": "suinter",
    "suinteriez": "suinter",
    "suinterions": "suinter",
    "suinterons": "suinter",
    "suinteront": "suinter",
    "suintes": "suinter",
    "suintez": "suinter",
    "suintiez": "suinter",
    "suintions": "suinter",
    "suintons": "suinter",
    "suints": "suint",
    "suintâmes": "suinter",
    "suintât": "suinter",
    "suintâtes": "suinter",
    "suintèrent": "suinter",
    "suinté": "suinter",
    "suions": "suer",
    "suis": "suivre",
    "suisses": "suisse",
    "suissesse": "suisse",
    "suissesses": "suisse",
    "suit": "suivre",
    "suites": "suite",
    "suivaient": "suivre",
    "suivais": "suivre",
    "suivait": "suivre",
    "suivant": "suivre",
    "suivante": "suivant",
    "suivantes": "suivant",
    "suivants": "suivant",
    "suive": "suivre",
    "suivent": "suivre",
    "suives": "suivre",
    "suiveurs": "suiveur",
    "suiveuse": "suiveur",
    "suiveuses": "suiveur",
    "suivez": "suivre",
    "suivi": "suivre",
    "suivie": "suivre",
    "suivies": "suivre",
    "suiviez": "suivre",
    "suivions": "suivre",
    "suivirent": "suivre",
    "suivis": "suivre",
    "suivismes": "suivisme",
    "suivisse": "suivre",
    "suivissent": "suivre",
    "suivisses": "suivre",
    "suivissiez": "suivre",
    "suivissions": "suivre",
    "suivistes": "suiviste",
    "suivit": "suivre",
    "suivons": "suivre",
    "suivra": "suivre",
    "suivrai": "suivre",
    "suivraient": "suivre",
    "suivrais": "suivre",
    "suivrait": "suivre",
    "suivras": "suivre",
    "suivrez": "suivre",
    "suivriez": "suivre",
    "suivrions": "suivre",
    "suivrons": "suivre",
    "suivront": "suivre",
    "suivîmes": "suivre",
    "suivît": "suivre",
    "suivîtes": "suivre",
    "sujets": "sujet",
    "sujette": "sujet",
    "sujettes": "sujette",
    "sujétions": "sujétion",
    "sulfamides": "sulfamide",
    "sulfatages": "sulfatage",
    "sulfatant": "sulfater",
    "sulfate": "sulfater",
    "sulfates": "sulfate",
    "sulfateuse": "sulfateur",
    "sulfateuses": "sulfateur",
    "sulfatées": "sulfaté",
    "sulfites": "sulfite",
    "sulfonée": "sulfoner",
    "sulfonés": "sulfoner",
    "sulfures": "sulfure",
    "sulfureuse": "sulfureux",
    "sulfureuses": "sulfureux",
    "sulfuriques": "sulfurique",
    "sulfurée": "sulfuré",
    "sulkys": "sulky",
    "sulpicienne": "sulpicien",
    "sulpiciennes": "sulpicien",
    "sultane": "sultan",
    "sultanes": "sultan",
    "sultanines": "sultanine",
    "sultans": "sultan",
    "sumacs": "sumac",
    "summums": "summum",
    "sunlights": "sunlight",
    "sunnites": "sunnite",
    "suons": "suer",
    "super-grands": "super-grand",
    "super-puissances": "super-puissance",
    "superbes": "superbe",
    "supercarburants": "supercarburant",
    "superchampions": "superchampion",
    "supercheries": "supercherie",
    "superdominances": "superdominance",
    "superficialités": "superficialité",
    "superficielle": "superficiel",
    "superficielles": "superficiel",
    "superficiels": "superficiel",
    "superficies": "superficie",
    "superfine": "superfin",
    "superfines": "superfin",
    "superfini": "superfinir",
    "superfinie": "superfinir",
    "superfinies": "superfinir",
    "superfinira": "superfinir",
    "superfinirai": "superfinir",
    "superfiniraient": "superfinir",
    "superfinirais": "superfinir",
    "superfinirait": "superfinir",
    "superfiniras": "superfinir",
    "superfinirent": "superfinir",
    "superfinirez": "superfinir",
    "superfiniriez": "superfinir",
    "superfinirions": "superfinir",
    "superfinirons": "superfinir",
    "superfiniront": "superfinir",
    "superfinis": "superfinir",
    "superfinissaient": "superfinir",
    "superfinissais": "superfinir",
    "superfinissait": "superfinir",
    "superfinissant": "superfinir",
    "superfinisse": "superfinir",
    "superfinissent": "superfinir",
    "superfinisses": "superfinir",
    "superfinissez": "superfinir",
    "superfinissiez": "superfinir",
    "superfinissions": "superfinir",
    "superfinissons": "superfinir",
    "superfinit": "superfinir",
    "superfins": "superfin",
    "superfinîmes": "superfinir",
    "superfinît": "superfinir",
    "superfinîtes": "superfinir",
    "superflue": "superflu",
    "superflues": "superflu",
    "superfluités": "superfluité",
    "superflus": "superflu",
    "superforteresses": "superforteresse",
    "superfétatoires": "superfétatoire",
    "superintendante": "superintendant",
    "superintendantes": "superintendant",
    "superintendants": "superintendant",
    "superlatifs": "superlatif",
    "superlative": "superlatif",
    "supermans": "superman",
    "supermarchés": "supermarché",
    "supermen": "superman",
    "supernovas": "supernova",
    "superphosphates": "superphosphate",
    "superposa": "superposer",
    "superposables": "superposable",
    "superposai": "superposer",
    "superposaient": "superposer",
    "superposais": "superposer",
    "superposait": "superposer",
    "superposant": "superposer",
    "superposas": "superposer",
    "superposasse": "superposer",
    "superposassent": "superposer",
    "superposasses": "superposer",
    "superposassiez": "superposer",
    "superposassions": "superposer",
    "superpose": "superposer",
    "superposent": "superposer",
    "superposera": "superposer",
    "superposerai": "superposer",
    "superposeraient": "superposer",
    "superposerais": "superposer",
    "superposerait": "superposer",
    "superposeras": "superposer",
    "superposerez": "superposer",
    "superposeriez": "superposer",
    "superposerions": "superposer",
    "superposerons": "superposer",
    "superposeront": "superposer",
    "superposes": "superposer",
    "superposez": "superposer",
    "superposiez": "superposer",
    "superposions": "superposer",
    "superpositions": "superposition",
    "superposons": "superposer",
    "superposâmes": "superposer",
    "superposât": "superposer",
    "superposâtes": "superposer",
    "superposèrent": "superposer",
    "superposé": "superposer",
    "superposée": "superposer",
    "superposées": "superposer",
    "superposés": "superposer",
    "superpouvoirs": "superpouvoir",
    "superproductions": "superproduction",
    "superprofits": "superprofit",
    "superprélèvements": "superprélèvement",
    "superpuissances": "superpuissance",
    "superpuissante": "superpuissant",
    "superpuissantes": "superpuissant",
    "superpuissants": "superpuissant",
    "superpétroliers": "superpétrolier",
    "supers": "super",
    "supersoniques": "supersonique",
    "superstars": "superstar",
    "superstitieuse": "superstitieux",
    "superstitieuses": "superstitieux",
    "superstitions": "superstition",
    "superstructures": "superstructure",
    "supertankers": "supertanker",
    "supervisa": "superviser",
    "supervisai": "superviser",
    "supervisaient": "superviser",
    "supervisais": "superviser",
    "supervisait": "superviser",
    "supervisant": "superviser",
    "supervisas": "superviser",
    "supervisasse": "superviser",
    "supervisassent": "superviser",
    "supervisasses": "superviser",
    "supervisassiez": "superviser",
    "supervisassions": "superviser",
    "supervise": "superviser",
    "supervisent": "superviser",
    "supervisera": "superviser",
    "superviserai": "superviser",
    "superviseraient": "superviser",
    "superviserais": "superviser",
    "superviserait": "superviser",
    "superviseras": "superviser",
    "superviserez": "superviser",
    "superviseriez": "superviser",
    "superviserions": "superviser",
    "superviserons": "superviser",
    "superviseront": "superviser",
    "supervises": "superviser",
    "superviseurs": "superviseur",
    "supervisez": "superviser",
    "supervisiez": "superviser",
    "supervisions": "supervision",
    "supervisons": "superviser",
    "supervisâmes": "superviser",
    "supervisât": "superviser",
    "supervisâtes": "superviser",
    "supervisèrent": "superviser",
    "supervisé": "superviser",
    "supervisée": "superviser",
    "supervisées": "superviser",
    "supervisés": "superviser",
    "supinations": "supination",
    "supins": "supin",
    "supplanta": "supplanter",
    "supplantai": "supplanter",
    "supplantaient": "supplanter",
    "supplantais": "supplanter",
    "supplantait": "supplanter",
    "supplantant": "supplanter",
    "supplantas": "supplanter",
    "supplantasse": "supplanter",
    "supplantassent": "supplanter",
    "supplantasses": "supplanter",
    "supplantassiez": "supplanter",
    "supplantassions": "supplanter",
    "supplante": "supplanter",
    "supplantent": "supplanter",
    "supplantera": "supplanter",
    "supplanterai": "supplanter",
    "supplanteraient": "supplanter",
    "supplanterais": "supplanter",
    "supplanterait": "supplanter",
    "supplanteras": "supplanter",
    "supplanterez": "supplanter",
    "supplanteriez": "supplanter",
    "supplanterions": "supplanter",
    "supplanterons": "supplanter",
    "supplanteront": "supplanter",
    "supplantes": "supplanter",
    "supplantez": "supplanter",
    "supplantiez": "supplanter",
    "supplantions": "supplanter",
    "supplantons": "supplanter",
    "supplantâmes": "supplanter",
    "supplantât": "supplanter",
    "supplantâtes": "supplanter",
    "supplantèrent": "supplanter",
    "supplanté": "supplanter",
    "supplantée": "supplanter",
    "supplantées": "supplanter",
    "supplantés": "supplanter",
    "supplia": "supplier",
    "suppliai": "supplier",
    "suppliaient": "supplier",
    "suppliais": "supplier",
    "suppliait": "supplier",
    "suppliant": "supplier",
    "suppliante": "suppliant",
    "suppliantes": "suppliant",
    "suppliants": "suppliant",
    "supplias": "supplier",
    "suppliasse": "supplier",
    "suppliassent": "supplier",
    "suppliasses": "supplier",
    "suppliassiez": "supplier",
    "suppliassions": "supplier",
    "supplications": "supplication",
    "supplices": "supplice",
    "supplicia": "supplicier",
    "suppliciai": "supplicier",
    "suppliciaient": "supplicier",
    "suppliciais": "supplicier",
    "suppliciait": "supplicier",
    "suppliciant": "supplicier",
    "suppliciantes": "suppliciant",
    "supplicias": "supplicier",
    "suppliciasse": "supplicier",
    "suppliciassent": "supplicier",
    "suppliciasses": "supplicier",
    "suppliciassiez": "supplicier",
    "suppliciassions": "supplicier",
    "supplicie": "supplicier",
    "supplicient": "supplicier",
    "suppliciera": "supplicier",
    "supplicierai": "supplicier",
    "supplicieraient": "supplicier",
    "supplicierais": "supplicier",
    "supplicierait": "supplicier",
    "supplicieras": "supplicier",
    "supplicierez": "supplicier",
    "supplicieriez": "supplicier",
    "supplicierions": "supplicier",
    "supplicierons": "supplicier",
    "supplicieront": "supplicier",
    "supplicies": "supplicier",
    "suppliciez": "supplicier",
    "suppliciiez": "supplicier",
    "suppliciions": "supplicier",
    "supplicions": "supplicier",
    "suppliciâmes": "supplicier",
    "suppliciât": "supplicier",
    "suppliciâtes": "supplicier",
    "supplicièrent": "supplicier",
    "supplicié": "supplicier",
    "suppliciée": "supplicier",
    "suppliciées": "supplicier",
    "suppliciés": "supplicier",
    "supplie": "supplier",
    "supplient": "supplier",
    "suppliera": "supplier",
    "supplierai": "supplier",
    "supplieraient": "supplier",
    "supplierais": "supplier",
    "supplierait": "supplier",
    "supplieras": "supplier",
    "supplierez": "supplier",
    "supplieriez": "supplier",
    "supplierions": "supplier",
    "supplierons": "supplier",
    "supplieront": "supplier",
    "supplies": "supplier",
    "suppliez": "supplier",
    "suppliiez": "supplier",
    "suppliions": "supplier",
    "supplions": "supplier",
    "suppliques": "supplique",
    "suppliâmes": "supplier",
    "suppliât": "supplier",
    "suppliâtes": "supplier",
    "supplièrent": "supplier",
    "supplié": "supplier",
    "suppliée": "supplier",
    "suppliées": "supplier",
    "suppliés": "supplier",
    "suppléa": "suppléer",
    "suppléai": "suppléer",
    "suppléaient": "suppléer",
    "suppléais": "suppléer",
    "suppléait": "suppléer",
    "suppléances": "suppléance",
    "suppléant": "suppléer",
    "suppléante": "suppléant",
    "suppléantes": "suppléant",
    "suppléants": "suppléant",
    "suppléas": "suppléer",
    "suppléasse": "suppléer",
    "suppléassent": "suppléer",
    "suppléasses": "suppléer",
    "suppléassiez": "suppléer",
    "suppléassions": "suppléer",
    "supplée": "suppléer",
    "suppléent": "suppléer",
    "suppléera": "suppléer",
    "suppléerai": "suppléer",
    "suppléeraient": "suppléer",
    "suppléerais": "suppléer",
    "suppléerait": "suppléer",
    "suppléeras": "suppléer",
    "suppléerez": "suppléer",
    "suppléeriez": "suppléer",
    "suppléerions": "suppléer",
    "suppléerons": "suppléer",
    "suppléeront": "suppléer",
    "supplées": "suppléer",
    "suppléez": "suppléer",
    "suppléiez": "suppléer",
    "suppléions": "suppléer",
    "supplémentaires": "supplémentaire",
    "suppléments": "supplément",
    "supplémentée": "supplémenté",
    "supplémentées": "supplémenter",
    "supplémentés": "supplémenté",
    "suppléons": "suppléer",
    "supplétifs": "supplétif",
    "supplétive": "supplétif",
    "supplétives": "supplétif",
    "suppléâmes": "suppléer",
    "suppléât": "suppléer",
    "suppléâtes": "suppléer",
    "suppléèrent": "suppléer",
    "suppléé": "suppléer",
    "suppléée": "suppléer",
    "suppléées": "suppléer",
    "suppléés": "suppléer",
    "supporta": "supporter",
    "supportables": "supportable",
    "supportai": "supporter",
    "supportaient": "supporter",
    "supportais": "supporter",
    "supportait": "supporter",
    "supportant": "supporter",
    "supportas": "supporter",
    "supportasse": "supporter",
    "supportassent": "supporter",
    "supportasses": "supporter",
    "supportassiez": "supporter",
    "supportassions": "supporter",
    "supporte": "supporter",
    "supportent": "supporter",
    "supportera": "supporter",
    "supporterai": "supporter",
    "supporteraient": "supporter",
    "supporterais": "supporter",
    "supporterait": "supporter",
    "supporteras": "supporter",
    "supporterez": "supporter",
    "supporteriez": "supporter",
    "supporterions": "supporter",
    "supporterons": "supporter",
    "supporteront": "supporter",
    "supporters": "supporter",
    "supportes": "supporter",
    "supportez": "supporter",
    "supportiez": "supporter",
    "supportions": "supporter",
    "supportons": "supporter",
    "supportrice": "supporteur",
    "supportrices": "supporteur",
    "supports": "support",
    "supports-chaussettes": "support-chaussette",
    "supportâmes": "supporter",
    "supportât": "supporter",
    "supportâtes": "supporter",
    "supportèrent": "supporter",
    "supporté": "supporter",
    "supportée": "supporter",
    "supportées": "supporter",
    "supportés": "supporter",
    "supposa": "supposer",
    "supposai": "supposer",
    "supposaient": "supposer",
    "supposais": "supposer",
    "supposait": "supposer",
    "supposant": "supposer",
    "supposas": "supposer",
    "supposasse": "supposer",
    "supposassent": "supposer",
    "supposasses": "supposer",
    "supposassiez": "supposer",
    "supposassions": "supposer",
    "suppose": "supposer",
    "supposent": "supposer",
    "supposera": "supposer",
    "supposerai": "supposer",
    "supposeraient": "supposer",
    "supposerais": "supposer",
    "supposerait": "supposer",
    "supposeras": "supposer",
    "supposerez": "supposer",
    "supposeriez": "supposer",
    "supposerions": "supposer",
    "supposerons": "supposer",
    "supposeront": "supposer",
    "supposes": "supposer",
    "supposez": "supposer",
    "supposiez": "supposer",
    "supposions": "supposer",
    "suppositions": "supposition",
    "suppositoires": "suppositoire",
    "supposons": "supposer",
    "supposâmes": "supposer",
    "supposât": "supposer",
    "supposâtes": "supposer",
    "supposèrent": "supposer",
    "supposé": "supposer",
    "supposée": "supposer",
    "supposées": "supposer",
    "supposés": "supposer",
    "suppressions": "suppression",
    "supprima": "supprimer",
    "supprimai": "supprimer",
    "supprimaient": "supprimer",
    "supprimais": "supprimer",
    "supprimait": "supprimer",
    "supprimant": "supprimer",
    "supprimas": "supprimer",
    "supprimasse": "supprimer",
    "supprimassent": "supprimer",
    "supprimasses": "supprimer",
    "supprimassiez": "supprimer",
    "supprimassions": "supprimer",
    "supprime": "supprimer",
    "suppriment": "supprimer",
    "supprimera": "supprimer",
    "supprimerai": "supprimer",
    "supprimeraient": "supprimer",
    "supprimerais": "supprimer",
    "supprimerait": "supprimer",
    "supprimeras": "supprimer",
    "supprimerez": "supprimer",
    "supprimeriez": "supprimer",
    "supprimerions": "supprimer",
    "supprimerons": "supprimer",
    "supprimeront": "supprimer",
    "supprimes": "supprimer",
    "supprimez": "supprimer",
    "supprimiez": "supprimer",
    "supprimions": "supprimer",
    "supprimons": "supprimer",
    "supprimâmes": "supprimer",
    "supprimât": "supprimer",
    "supprimâtes": "supprimer",
    "supprimèrent": "supprimer",
    "supprimé": "supprimer",
    "supprimée": "supprimer",
    "supprimées": "supprimer",
    "supprimés": "supprimer",
    "suppura": "suppurer",
    "suppurai": "suppurer",
    "suppuraient": "suppurer",
    "suppurais": "suppurer",
    "suppurait": "suppurer",
    "suppurant": "suppurer",
    "suppurante": "suppurant",
    "suppurantes": "suppurant",
    "suppuras": "suppurer",
    "suppurasse": "suppurer",
    "suppurassent": "suppurer",
    "suppurasses": "suppurer",
    "suppurassiez": "suppurer",
    "suppurassions": "suppurer",
    "suppurations": "suppuration",
    "suppure": "suppurer",
    "suppurent": "suppurer",
    "suppurera": "suppurer",
    "suppurerai": "suppurer",
    "suppureraient": "suppurer",
    "suppurerais": "suppurer",
    "suppurerait": "suppurer",
    "suppureras": "suppurer",
    "suppurerez": "suppurer",
    "suppureriez": "suppurer",
    "suppurerions": "suppurer",
    "suppurerons": "suppurer",
    "suppureront": "suppurer",
    "suppures": "suppurer",
    "suppurez": "suppurer",
    "suppuriez": "suppurer",
    "suppurions": "suppurer",
    "suppurons": "suppurer",
    "suppurâmes": "suppurer",
    "suppurât": "suppurer",
    "suppurâtes": "suppurer",
    "suppurèrent": "suppurer",
    "suppuré": "suppurer",
    "supputa": "supputer",
    "supputai": "supputer",
    "supputaient": "supputer",
    "supputais": "supputer",
    "supputait": "supputer",
    "supputant": "supputer",
    "supputas": "supputer",
    "supputasse": "supputer",
    "supputassent": "supputer",
    "supputasses": "supputer",
    "supputassiez": "supputer",
    "supputassions": "supputer",
    "supputations": "supputation",
    "suppute": "supputer",
    "supputent": "supputer",
    "supputera": "supputer",
    "supputerai": "supputer",
    "supputeraient": "supputer",
    "supputerais": "supputer",
    "supputerait": "supputer",
    "supputeras": "supputer",
    "supputerez": "supputer",
    "supputeriez": "supputer",
    "supputerions": "supputer",
    "supputerons": "supputer",
    "supputeront": "supputer",
    "supputes": "supputer",
    "supputez": "supputer",
    "supputiez": "supputer",
    "supputions": "supputer",
    "supputons": "supputer",
    "supputâmes": "supputer",
    "supputât": "supputer",
    "supputâtes": "supputer",
    "supputèrent": "supputer",
    "supputé": "supputer",
    "supputée": "supputer",
    "supputées": "supputer",
    "supputés": "supputer",
    "suppôts": "suppôt",
    "supraconducteurs": "supraconducteur",
    "supraconductions": "supraconduction",
    "supraconductrice": "supraconducteur",
    "supranationale": "supranational",
    "supranationales": "supranational",
    "supranationalités": "supranationalité",
    "supranationaux": "supranational",
    "suprématies": "suprématie",
    "suprêmes": "suprême",
    "supérieure": "supérieur",
    "supérieures": "supérieur",
    "supérieurs": "supérieur",
    "supériorités": "supériorité",
    "surabonda": "surabonder",
    "surabondai": "surabonder",
    "surabondaient": "surabonder",
    "surabondais": "surabonder",
    "surabondait": "surabonder",
    "surabondances": "surabondance",
    "surabondant": "surabonder",
    "surabondante": "surabondant",
    "surabondantes": "surabondant",
    "surabondas": "surabonder",
    "surabondasse": "surabonder",
    "surabondassent": "surabonder",
    "surabondasses": "surabonder",
    "surabondassiez": "surabonder",
    "surabondassions": "surabonder",
    "surabonde": "surabonder",
    "surabondent": "surabonder",
    "surabondera": "surabonder",
    "surabonderai": "surabonder",
    "surabonderaient": "surabonder",
    "surabonderais": "surabonder",
    "surabonderait": "surabonder",
    "surabonderas": "surabonder",
    "surabonderez": "surabonder",
    "surabonderiez": "surabonder",
    "surabonderions": "surabonder",
    "surabonderons": "surabonder",
    "surabonderont": "surabonder",
    "surabondes": "surabonder",
    "surabondez": "surabonder",
    "surabondiez": "surabonder",
    "surabondions": "surabonder",
    "surabondons": "surabonder",
    "surabondâmes": "surabonder",
    "surabondât": "surabonder",
    "surabondâtes": "surabonder",
    "surabondèrent": "surabonder",
    "surabondé": "surabonder",
    "suractivée": "suractivé",
    "suraigus": "suraigu",
    "suraiguë": "suraigu",
    "suraiguës": "suraigu",
    "surajouta": "surajouter",
    "surajoutai": "surajouter",
    "surajoutaient": "surajouter",
    "surajoutais": "surajouter",
    "surajoutait": "surajouter",
    "surajoutant": "surajouter",
    "surajoutas": "surajouter",
    "surajoutasse": "surajouter",
    "surajoutassent": "surajouter",
    "surajoutasses": "surajouter",
    "surajoutassiez": "surajouter",
    "surajoutassions": "surajouter",
    "surajoute": "surajouter",
    "surajoutent": "surajouter",
    "surajoutera": "surajouter",
    "surajouterai": "surajouter",
    "surajouteraient": "surajouter",
    "surajouterais": "surajouter",
    "surajouterait": "surajouter",
    "surajouteras": "surajouter",
    "surajouterez": "surajouter",
    "surajouteriez": "surajouter",
    "surajouterions": "surajouter",
    "surajouterons": "surajouter",
    "surajouteront": "surajouter",
    "surajoutes": "surajouter",
    "surajoutez": "surajouter",
    "surajoutiez": "surajouter",
    "surajoutions": "surajouter",
    "surajoutons": "surajouter",
    "surajoutâmes": "surajouter",
    "surajoutât": "surajouter",
    "surajoutâtes": "surajouter",
    "surajoutèrent": "surajouter",
    "surajouté": "surajouter",
    "surajoutée": "surajouter",
    "surajoutées": "surajouter",
    "surajoutés": "surajouter",
    "surale": "sural",
    "surales": "sural",
    "suralimenta": "suralimenter",
    "suralimentai": "suralimenter",
    "suralimentaient": "suralimenter",
    "suralimentais": "suralimenter",
    "suralimentait": "suralimenter",
    "suralimentant": "suralimenter",
    "suralimentas": "suralimenter",
    "suralimentasse": "suralimenter",
    "suralimentassent": "suralimenter",
    "suralimentasses": "suralimenter",
    "suralimentassiez": "suralimenter",
    "suralimentassions": "suralimenter",
    "suralimente": "suralimenter",
    "suralimentent": "suralimenter",
    "suralimentera": "suralimenter",
    "suralimenterai": "suralimenter",
    "suralimenteraient": "suralimenter",
    "suralimenterais": "suralimenter",
    "suralimenterait": "suralimenter",
    "suralimenteras": "suralimenter",
    "suralimenterez": "suralimenter",
    "suralimenteriez": "suralimenter",
    "suralimenterions": "suralimenter",
    "suralimenterons": "suralimenter",
    "suralimenteront": "suralimenter",
    "suralimentes": "suralimenter",
    "suralimentez": "suralimenter",
    "suralimentiez": "suralimenter",
    "suralimentions": "suralimenter",
    "suralimentons": "suralimenter",
    "suralimentâmes": "suralimenter",
    "suralimentât": "suralimenter",
    "suralimentâtes": "suralimenter",
    "suralimentèrent": "suralimenter",
    "suralimenté": "suralimenter",
    "suralimentée": "suralimenter",
    "suralimentées": "suralimenter",
    "suralimentés": "suralimenter",
    "surannée": "suranné",
    "surannées": "suranné",
    "surannés": "suranné",
    "surarmements": "surarmement",
    "surarmé": "surarmer",
    "surarmée": "surarmer",
    "surarmées": "surarmé",
    "surarmés": "surarmer",
    "surates": "surate",
    "suraux": "sural",
    "surbaissa": "surbaisser",
    "surbaissai": "surbaisser",
    "surbaissaient": "surbaisser",
    "surbaissais": "surbaisser",
    "surbaissait": "surbaisser",
    "surbaissant": "surbaisser",
    "surbaissas": "surbaisser",
    "surbaissasse": "surbaisser",
    "surbaissassent": "surbaisser",
    "surbaissasses": "surbaisser",
    "surbaissassiez": "surbaisser",
    "surbaissassions": "surbaisser",
    "surbaisse": "surbaisser",
    "surbaissent": "surbaisser",
    "surbaissera": "surbaisser",
    "surbaisserai": "surbaisser",
    "surbaisseraient": "surbaisser",
    "surbaisserais": "surbaisser",
    "surbaisserait": "surbaisser",
    "surbaisseras": "surbaisser",
    "surbaisserez": "surbaisser",
    "surbaisseriez": "surbaisser",
    "surbaisserions": "surbaisser",
    "surbaisserons": "surbaisser",
    "surbaisseront": "surbaisser",
    "surbaisses": "surbaisser",
    "surbaissez": "surbaisser",
    "surbaissiez": "surbaisser",
    "surbaissions": "surbaisser",
    "surbaissons": "surbaisser",
    "surbaissâmes": "surbaisser",
    "surbaissât": "surbaisser",
    "surbaissâtes": "surbaisser",
    "surbaissèrent": "surbaisser",
    "surbaissé": "surbaisser",
    "surbaissée": "surbaisser",
    "surbaissées": "surbaisser",
    "surbaissés": "surbaisser",
    "surbookée": "surbooké",
    "surbookées": "surbooké",
    "surboums": "surboum",
    "surcapacités": "surcapacité",
    "surcharge": "surcharger",
    "surchargea": "surcharger",
    "surchargeai": "surcharger",
    "surchargeaient": "surcharger",
    "surchargeais": "surcharger",
    "surchargeait": "surcharger",
    "surchargeant": "surcharger",
    "surchargeas": "surcharger",
    "surchargeasse": "surcharger",
    "surchargeassent": "surcharger",
    "surchargeasses": "surcharger",
    "surchargeassiez": "surcharger",
    "surchargeassions": "surcharger",
    "surchargent": "surcharger",
    "surchargeons": "surcharger",
    "surchargera": "surcharger",
    "surchargerai": "surcharger",
    "surchargeraient": "surcharger",
    "surchargerais": "surcharger",
    "surchargerait": "surcharger",
    "surchargeras": "surcharger",
    "surchargerez": "surcharger",
    "surchargeriez": "surcharger",
    "surchargerions": "surcharger",
    "surchargerons": "surcharger",
    "surchargeront": "surcharger",
    "surcharges": "surcharger",
    "surchargez": "surcharger",
    "surchargeâmes": "surcharger",
    "surchargeât": "surcharger",
    "surchargeâtes": "surcharger",
    "surchargiez": "surcharger",
    "surchargions": "surcharger",
    "surchargèrent": "surcharger",
    "surchargé": "surcharger",
    "surchargée": "surcharger",
    "surchargées": "surcharger",
    "surchargés": "surcharger",
    "surchauffa": "surchauffer",
    "surchauffai": "surchauffer",
    "surchauffaient": "surchauffer",
    "surchauffais": "surchauffer",
    "surchauffait": "surchauffer",
    "surchauffant": "surchauffer",
    "surchauffas": "surchauffer",
    "surchauffasse": "surchauffer",
    "surchauffassent": "surchauffer",
    "surchauffasses": "surchauffer",
    "surchauffassiez": "surchauffer",
    "surchauffassions": "surchauffer",
    "surchauffe": "surchauffer",
    "surchauffent": "surchauffer",
    "surchauffera": "surchauffer",
    "surchaufferai": "surchauffer",
    "surchaufferaient": "surchauffer",
    "surchaufferais": "surchauffer",
    "surchaufferait": "surchauffer",
    "surchaufferas": "surchauffer",
    "surchaufferez": "surchauffer",
    "surchaufferiez": "surchauffer",
    "surchaufferions": "surchauffer",
    "surchaufferons": "surchauffer",
    "surchaufferont": "surchauffer",
    "surchauffes": "surchauffer",
    "surchauffez": "surchauffer",
    "surchauffiez": "surchauffer",
    "surchauffions": "surchauffer",
    "surchauffons": "surchauffer",
    "surchauffâmes": "surchauffer",
    "surchauffât": "surchauffer",
    "surchauffâtes": "surchauffer",
    "surchauffèrent": "surchauffer",
    "surchauffé": "surchauffer",
    "surchauffée": "surchauffer",
    "surchauffées": "surchauffer",
    "surchauffés": "surchauffer",
    "surclassait": "surclasser",
    "surclassant": "surclasser",
    "surclasse": "surclasser",
    "surclassent": "surclasser",
    "surclasserais": "surclasser",
    "surclasserait": "surclasser",
    "surclasseras": "surclasser",
    "surclassé": "surclasser",
    "surclassés": "surclasser",
    "surcompensé": "surcompenser",
    "surcomprima": "surcomprimer",
    "surcomprimai": "surcomprimer",
    "surcomprimaient": "surcomprimer",
    "surcomprimais": "surcomprimer",
    "surcomprimait": "surcomprimer",
    "surcomprimant": "surcomprimer",
    "surcomprimas": "surcomprimer",
    "surcomprimasse": "surcomprimer",
    "surcomprimassent": "surcomprimer",
    "surcomprimasses": "surcomprimer",
    "surcomprimassiez": "surcomprimer",
    "surcomprimassions": "surcomprimer",
    "surcomprime": "surcomprimer",
    "surcompriment": "surcomprimer",
    "surcomprimera": "surcomprimer",
    "surcomprimerai": "surcomprimer",
    "surcomprimeraient": "surcomprimer",
    "surcomprimerais": "surcomprimer",
    "surcomprimerait": "surcomprimer",
    "surcomprimeras": "surcomprimer",
    "surcomprimerez": "surcomprimer",
    "surcomprimeriez": "surcomprimer",
    "surcomprimerions": "surcomprimer",
    "surcomprimerons": "surcomprimer",
    "surcomprimeront": "surcomprimer",
    "surcomprimes": "surcomprimer",
    "surcomprimez": "surcomprimer",
    "surcomprimiez": "surcomprimer",
    "surcomprimions": "surcomprimer",
    "surcomprimons": "surcomprimer",
    "surcomprimâmes": "surcomprimer",
    "surcomprimât": "surcomprimer",
    "surcomprimâtes": "surcomprimer",
    "surcomprimèrent": "surcomprimer",
    "surcomprimé": "surcomprimer",
    "surcomprimée": "surcomprimer",
    "surcomprimées": "surcomprimer",
    "surcomprimés": "surcomprimer",
    "surconsomme": "surconsommer",
    "surcontres": "surcontre",
    "surcots": "surcot",
    "surcoupa": "surcouper",
    "surcoupai": "surcouper",
    "surcoupaient": "surcouper",
    "surcoupais": "surcouper",
    "surcoupait": "surcouper",
    "surcoupant": "surcouper",
    "surcoupas": "surcouper",
    "surcoupasse": "surcouper",
    "surcoupassent": "surcouper",
    "surcoupasses": "surcouper",
    "surcoupassiez": "surcouper",
    "surcoupassions": "surcouper",
    "surcoupe": "surcouper",
    "surcoupent": "surcouper",
    "surcoupera": "surcouper",
    "surcouperai": "surcouper",
    "surcouperaient": "surcouper",
    "surcouperais": "surcouper",
    "surcouperait": "surcouper",
    "surcouperas": "surcouper",
    "surcouperez": "surcouper",
    "surcouperiez": "surcouper",
    "surcouperions": "surcouper",
    "surcouperons": "surcouper",
    "surcouperont": "surcouper",
    "surcoupes": "surcouper",
    "surcoupez": "surcouper",
    "surcoupiez": "surcouper",
    "surcoupions": "surcouper",
    "surcoupons": "surcouper",
    "surcoupâmes": "surcouper",
    "surcoupât": "surcouper",
    "surcoupâtes": "surcouper",
    "surcoupèrent": "surcouper",
    "surcoupé": "surcouper",
    "surcoupée": "surcouper",
    "surcoupées": "surcouper",
    "surcoupés": "surcouper",
    "surcoûts": "surcoût",
    "surcroîts": "surcroît",
    "surdi-mutités": "surdi-mutité",
    "surdimensionnée": "surdimensionné",
    "surdiplômée": "surdiplômé",
    "surdiplômées": "surdiplômé",
    "surdiplômés": "surdiplômé",
    "surdités": "surdité",
    "surdora": "surdorer",
    "surdorai": "surdorer",
    "surdoraient": "surdorer",
    "surdorais": "surdorer",
    "surdorait": "surdorer",
    "surdorant": "surdorer",
    "surdoras": "surdorer",
    "surdorasse": "surdorer",
    "surdorassent": "surdorer",
    "surdorasses": "surdorer",
    "surdorassiez": "surdorer",
    "surdorassions": "surdorer",
    "surdore": "surdorer",
    "surdorent": "surdorer",
    "surdorera": "surdorer",
    "surdorerai": "surdorer",
    "surdoreraient": "surdorer",
    "surdorerais": "surdorer",
    "surdorerait": "surdorer",
    "surdoreras": "surdorer",
    "surdorerez": "surdorer",
    "surdoreriez": "surdorer",
    "surdorerions": "surdorer",
    "surdorerons": "surdorer",
    "surdoreront": "surdorer",
    "surdores": "surdorer",
    "surdorez": "surdorer",
    "surdoriez": "surdorer",
    "surdorions": "surdorer",
    "surdorons": "surdorer",
    "surdorâmes": "surdorer",
    "surdorât": "surdorer",
    "surdorâtes": "surdorer",
    "surdorèrent": "surdorer",
    "surdoré": "surdorer",
    "surdorée": "surdorer",
    "surdorées": "surdorer",
    "surdorés": "surdorer",
    "surdouée": "surdoué",
    "surdouées": "surdoué",
    "surdoués": "surdoué",
    "surdétermina": "surdéterminer",
    "surdéterminai": "surdéterminer",
    "surdéterminaient": "surdéterminer",
    "surdéterminais": "surdéterminer",
    "surdéterminait": "surdéterminer",
    "surdéterminant": "surdéterminer",
    "surdéterminas": "surdéterminer",
    "surdéterminasse": "surdéterminer",
    "surdéterminassent": "surdéterminer",
    "surdéterminasses": "surdéterminer",
    "surdéterminassiez": "surdéterminer",
    "surdéterminassions": "surdéterminer",
    "surdétermine": "surdéterminer",
    "surdéterminent": "surdéterminer",
    "surdéterminera": "surdéterminer",
    "surdéterminerai": "surdéterminer",
    "surdétermineraient": "surdéterminer",
    "surdéterminerais": "surdéterminer",
    "surdéterminerait": "surdéterminer",
    "surdétermineras": "surdéterminer",
    "surdéterminerez": "surdéterminer",
    "surdétermineriez": "surdéterminer",
    "surdéterminerions": "surdéterminer",
    "surdéterminerons": "surdéterminer",
    "surdétermineront": "surdéterminer",
    "surdétermines": "surdéterminer",
    "surdéterminez": "surdéterminer",
    "surdéterminiez": "surdéterminer",
    "surdéterminions": "surdéterminer",
    "surdéterminons": "surdéterminer",
    "surdéterminâmes": "surdéterminer",
    "surdéterminât": "surdéterminer",
    "surdéterminâtes": "surdéterminer",
    "surdéterminèrent": "surdéterminer",
    "surdéterminé": "surdéterminer",
    "surdéterminée": "surdéterminer",
    "surdéterminées": "surdéterminer",
    "surdéterminés": "surdéterminer",
    "surdéveloppée": "surdéveloppé",
    "surdéveloppées": "surdéveloppé",
    "surdéveloppés": "surdéveloppé",
    "sure": "sur",
    "sureaux": "sureau",
    "sureffectifs": "sureffectif",
    "surenchères": "surenchère",
    "surenchéri": "surenchérir",
    "surenchérie": "surenchérir",
    "surenchéries": "surenchérir",
    "surenchérira": "surenchérir",
    "surenchérirai": "surenchérir",
    "surenchériraient": "surenchérir",
    "surenchérirais": "surenchérir",
    "surenchérirait": "surenchérir",
    "surenchériras": "surenchérir",
    "surenchérirent": "surenchérir",
    "surenchérirez": "surenchérir",
    "surenchéririez": "surenchérir",
    "surenchéririons": "surenchérir",
    "surenchérirons": "surenchérir",
    "surenchériront": "surenchérir",
    "surenchéris": "surenchérir",
    "surenchérissaient": "surenchérir",
    "surenchérissais": "surenchérir",
    "surenchérissait": "surenchérir",
    "surenchérissant": "surenchérir",
    "surenchérisse": "surenchérir",
    "surenchérissent": "surenchérir",
    "surenchérisses": "surenchérir",
    "surenchérissez": "surenchérir",
    "surenchérissiez": "surenchérir",
    "surenchérissions": "surenchérir",
    "surenchérissons": "surenchérir",
    "surenchérit": "surenchérir",
    "surenchérîmes": "surenchérir",
    "surenchérît": "surenchérir",
    "surenchérîtes": "surenchérir",
    "surencombrée": "surencombré",
    "surendettements": "surendettement",
    "surendettés": "surendetté",
    "surent": "savoir",
    "surentraîna": "surentraîner",
    "surentraînai": "surentraîner",
    "surentraînaient": "surentraîner",
    "surentraînais": "surentraîner",
    "surentraînait": "surentraîner",
    "surentraînant": "surentraîner",
    "surentraînas": "surentraîner",
    "surentraînasse": "surentraîner",
    "surentraînassent": "surentraîner",
    "surentraînasses": "surentraîner",
    "surentraînassiez": "surentraîner",
    "surentraînassions": "surentraîner",
    "surentraîne": "surentraîner",
    "surentraînent": "surentraîner",
    "surentraînera": "surentraîner",
    "surentraînerai": "surentraîner",
    "surentraîneraient": "surentraîner",
    "surentraînerais": "surentraîner",
    "surentraînerait": "surentraîner",
    "surentraîneras": "surentraîner",
    "surentraînerez": "surentraîner",
    "surentraîneriez": "surentraîner",
    "surentraînerions": "surentraîner",
    "surentraînerons": "surentraîner",
    "surentraîneront": "surentraîner",
    "surentraînes": "surentraîner",
    "surentraînez": "surentraîner",
    "surentraîniez": "surentraîner",
    "surentraînions": "surentraîner",
    "surentraînons": "surentraîner",
    "surentraînâmes": "surentraîner",
    "surentraînât": "surentraîner",
    "surentraînâtes": "surentraîner",
    "surentraînèrent": "surentraîner",
    "surentraîné": "surentraîner",
    "surentraînée": "surentraîner",
    "surentraînées": "surentraîner",
    "surentraînés": "surentraîner",
    "sures": "sur",
    "surestima": "surestimer",
    "surestimai": "surestimer",
    "surestimaient": "surestimer",
    "surestimais": "surestimer",
    "surestimait": "surestimer",
    "surestimant": "surestimer",
    "surestimas": "surestimer",
    "surestimasse": "surestimer",
    "surestimassent": "surestimer",
    "surestimasses": "surestimer",
    "surestimassiez": "surestimer",
    "surestimassions": "surestimer",
    "surestime": "surestimer",
    "surestiment": "surestimer",
    "surestimera": "surestimer",
    "surestimerai": "surestimer",
    "surestimeraient": "surestimer",
    "surestimerais": "surestimer",
    "surestimerait": "surestimer",
    "surestimeras": "surestimer",
    "surestimerez": "surestimer",
    "surestimeriez": "surestimer",
    "surestimerions": "surestimer",
    "surestimerons": "surestimer",
    "surestimeront": "surestimer",
    "surestimes": "surestimer",
    "surestimez": "surestimer",
    "surestimiez": "surestimer",
    "surestimions": "surestimer",
    "surestimons": "surestimer",
    "surestimâmes": "surestimer",
    "surestimât": "surestimer",
    "surestimâtes": "surestimer",
    "surestimèrent": "surestimer",
    "surestimé": "surestimer",
    "surestimée": "surestimer",
    "surestimées": "surestimer",
    "surestimés": "surestimer",
    "surets": "suret",
    "surette": "suret",
    "surexcita": "surexciter",
    "surexcitai": "surexciter",
    "surexcitaient": "surexciter",
    "surexcitais": "surexciter",
    "surexcitait": "surexciter",
    "surexcitant": "surexciter",
    "surexcitas": "surexciter",
    "surexcitasse": "surexciter",
    "surexcitassent": "surexciter",
    "surexcitasses": "surexciter",
    "surexcitassiez": "surexciter",
    "surexcitassions": "surexciter",
    "surexcitations": "surexcitation",
    "surexcite": "surexciter",
    "surexcitent": "surexciter",
    "surexcitera": "surexciter",
    "surexciterai": "surexciter",
    "surexciteraient": "surexciter",
    "surexciterais": "surexciter",
    "surexciterait": "surexciter",
    "surexciteras": "surexciter",
    "surexciterez": "surexciter",
    "surexciteriez": "surexciter",
    "surexciterions": "surexciter",
    "surexciterons": "surexciter",
    "surexciteront": "surexciter",
    "surexcites": "surexciter",
    "surexcitez": "surexciter",
    "surexcitiez": "surexciter",
    "surexcitions": "surexciter",
    "surexcitons": "surexciter",
    "surexcitâmes": "surexciter",
    "surexcitât": "surexciter",
    "surexcitâtes": "surexciter",
    "surexcitèrent": "surexciter",
    "surexcité": "surexciter",
    "surexcitée": "surexciter",
    "surexcitées": "surexciter",
    "surexcités": "surexciter",
    "surexploitations": "surexploitation",
    "surexploité": "surexploiter",
    "surexposa": "surexposer",
    "surexposai": "surexposer",
    "surexposaient": "surexposer",
    "surexposais": "surexposer",
    "surexposait": "surexposer",
    "surexposant": "surexposer",
    "surexposas": "surexposer",
    "surexposasse": "surexposer",
    "surexposassent": "surexposer",
    "surexposasses": "surexposer",
    "surexposassiez": "surexposer",
    "surexposassions": "surexposer",
    "surexpose": "surexposer",
    "surexposent": "surexposer",
    "surexposera": "surexposer",
    "surexposerai": "surexposer",
    "surexposeraient": "surexposer",
    "surexposerais": "surexposer",
    "surexposerait": "surexposer",
    "surexposeras": "surexposer",
    "surexposerez": "surexposer",
    "surexposeriez": "surexposer",
    "surexposerions": "surexposer",
    "surexposerons": "surexposer",
    "surexposeront": "surexposer",
    "surexposes": "surexposer",
    "surexposez": "surexposer",
    "surexposiez": "surexposer",
    "surexposions": "surexposer",
    "surexpositions": "surexposition",
    "surexposons": "surexposer",
    "surexposâmes": "surexposer",
    "surexposât": "surexposer",
    "surexposâtes": "surexposer",
    "surexposèrent": "surexposer",
    "surexposé": "surexposer",
    "surexposée": "surexposer",
    "surexposées": "surexposer",
    "surexposés": "surexposer",
    "surfa": "surfer",
    "surfaces": "surface",
    "surfacturations": "surfacturation",
    "surfacture": "surfacturer",
    "surfacturé": "surfacturer",
    "surfacturée": "surfacturé",
    "surfacturées": "surfacturé",
    "surfacturés": "surfacturer",
    "surfai": "surfer",
    "surfaient": "surfer",
    "surfais": "surfer",
    "surfaisaient": "surfaire",
    "surfaisais": "surfaire",
    "surfaisait": "surfaire",
    "surfaisant": "surfaire",
    "surfaisiez": "surfaire",
    "surfaisions": "surfaire",
    "surfaisons": "surfaire",
    "surfait": "surfer",
    "surfaite": "surfait",
    "surfaites": "surfait",
    "surfaits": "surfait",
    "surfant": "surfer",
    "surfas": "surfer",
    "surfasse": "surfer",
    "surfassent": "surfer",
    "surfasses": "surfer",
    "surfassiez": "surfer",
    "surfassions": "surfer",
    "surfe": "surfer",
    "surfent": "surfer",
    "surfera": "surfer",
    "surferai": "surfer",
    "surferaient": "surfer",
    "surferais": "surfer",
    "surferait": "surfer",
    "surferas": "surfer",
    "surferez": "surfer",
    "surferiez": "surfer",
    "surferions": "surfer",
    "surferons": "surfer",
    "surferont": "surfer",
    "surfes": "surfer",
    "surfeurs": "surfeur",
    "surfeuse": "surfeur",
    "surfeuses": "surfeur",
    "surfez": "surfer",
    "surfiez": "surfer",
    "surfila": "surfiler",
    "surfilai": "surfiler",
    "surfilaient": "surfiler",
    "surfilais": "surfiler",
    "surfilait": "surfiler",
    "surfilant": "surfiler",
    "surfilas": "surfiler",
    "surfilasse": "surfiler",
    "surfilassent": "surfiler",
    "surfilasses": "surfiler",
    "surfilassiez": "surfiler",
    "surfilassions": "surfiler",
    "surfile": "surfiler",
    "surfilent": "surfiler",
    "surfilera": "surfiler",
    "surfilerai": "surfiler",
    "surfileraient": "surfiler",
    "surfilerais": "surfiler",
    "surfilerait": "surfiler",
    "surfileras": "surfiler",
    "surfilerez": "surfiler",
    "surfileriez": "surfiler",
    "surfilerions": "surfiler",
    "surfilerons": "surfiler",
    "surfileront": "surfiler",
    "surfiles": "surfiler",
    "surfilez": "surfiler",
    "surfiliez": "surfiler",
    "surfilions": "surfiler",
    "surfilons": "surfiler",
    "surfils": "surfil",
    "surfilâmes": "surfiler",
    "surfilât": "surfiler",
    "surfilâtes": "surfiler",
    "surfilèrent": "surfiler",
    "surfilé": "surfiler",
    "surfilée": "surfiler",
    "surfilées": "surfiler",
    "surfilés": "surfiler",
    "surfine": "surfin",
    "surfines": "surfin",
    "surfins": "surfin",
    "surfions": "surfer",
    "surfirent": "surfaire",
    "surfis": "surfaire",
    "surfisse": "surfaire",
    "surfissent": "surfaire",
    "surfisses": "surfaire",
    "surfissiez": "surfaire",
    "surfissions": "surfaire",
    "surfit": "surfaire",
    "surfons": "surfer",
    "surfont": "surfaire",
    "surfs": "surf",
    "surfâmes": "surfer",
    "surfât": "surfer",
    "surfâtes": "surfer",
    "surfèrent": "surfer",
    "surfé": "surfer",
    "surfée": "surfer",
    "surfées": "surfer",
    "surfés": "surfer",
    "surfîmes": "surfaire",
    "surfît": "surfaire",
    "surfîtes": "surfaire",
    "surgela": "surgeler",
    "surgelai": "surgeler",
    "surgelaient": "surgeler",
    "surgelais": "surgeler",
    "surgelait": "surgeler",
    "surgelant": "surgeler",
    "surgelas": "surgeler",
    "surgelasse": "surgeler",
    "surgelassent": "surgeler",
    "surgelasses": "surgeler",
    "surgelassiez": "surgeler",
    "surgelassions": "surgeler",
    "surgelez": "surgeler",
    "surgeliez": "surgeler",
    "surgelions": "surgeler",
    "surgelons": "surgeler",
    "surgelâmes": "surgeler",
    "surgelât": "surgeler",
    "surgelâtes": "surgeler",
    "surgelèrent": "surgeler",
    "surgelé": "surgeler",
    "surgelée": "surgeler",
    "surgelées": "surgeler",
    "surgelés": "surgeler",
    "surgeonnent": "surgeonner",
    "surgeons": "surgeon",
    "surgi": "surgir",
    "surgie": "surgir",
    "surgies": "surgir",
    "surgira": "surgir",
    "surgirai": "surgir",
    "surgiraient": "surgir",
    "surgirais": "surgir",
    "surgirait": "surgir",
    "surgiras": "surgir",
    "surgirent": "surgir",
    "surgirez": "surgir",
    "surgiriez": "surgir",
    "surgirions": "surgir",
    "surgirons": "surgir",
    "surgiront": "surgir",
    "surgis": "surgir",
    "surgissaient": "surgir",
    "surgissais": "surgir",
    "surgissait": "surgir",
    "surgissant": "surgir",
    "surgisse": "surgir",
    "surgissements": "surgissement",
    "surgissent": "surgir",
    "surgisses": "surgir",
    "surgissez": "surgir",
    "surgissiez": "surgir",
    "surgissions": "surgir",
    "surgissons": "surgir",
    "surgit": "surgir",
    "surglace": "surglacer",
    "surglacent": "surglacer",
    "surglacera": "surglacer",
    "surglacerai": "surglacer",
    "surglaceraient": "surglacer",
    "surglacerais": "surglacer",
    "surglacerait": "surglacer",
    "surglaceras": "surglacer",
    "surglacerez": "surglacer",
    "surglaceriez": "surglacer",
    "surglacerions": "surglacer",
    "surglacerons": "surglacer",
    "surglaceront": "surglacer",
    "surglaces": "surglacer",
    "surglacez": "surglacer",
    "surglaciez": "surglacer",
    "surglacions": "surglacer",
    "surglacèrent": "surglacer",
    "surglacé": "surglacer",
    "surglacée": "surglacer",
    "surglacées": "surglacer",
    "surglacés": "surglacer",
    "surglaça": "surglacer",
    "surglaçai": "surglacer",
    "surglaçaient": "surglacer",
    "surglaçais": "surglacer",
    "surglaçait": "surglacer",
    "surglaçant": "surglacer",
    "surglaças": "surglacer",
    "surglaçasse": "surglacer",
    "surglaçassent": "surglacer",
    "surglaçasses": "surglacer",
    "surglaçassiez": "surglacer",
    "surglaçassions": "surglacer",
    "surglaçons": "surglacer",
    "surglaçâmes": "surglacer",
    "surglaçât": "surglacer",
    "surglaçâtes": "surglacer",
    "surgèle": "surgeler",
    "surgèlent": "surgeler",
    "surgèlera": "surgeler",
    "surgèlerai": "surgeler",
    "surgèleraient": "surgeler",
    "surgèlerais": "surgeler",
    "surgèlerait": "surgeler",
    "surgèleras": "surgeler",
    "surgèlerez": "surgeler",
    "surgèleriez": "surgeler",
    "surgèlerions": "surgeler",
    "surgèlerons": "surgeler",
    "surgèleront": "surgeler",
    "surgèles": "surgeler",
    "surgélations": "surgélation",
    "surgénérateurs": "surgénérateur",
    "surgîmes": "surgir",
    "surgît": "surgir",
    "surgîtes": "surgir",
    "surhaussa": "surhausser",
    "surhaussai": "surhausser",
    "surhaussaient": "surhausser",
    "surhaussais": "surhausser",
    "surhaussait": "surhausser",
    "surhaussant": "surhausser",
    "surhaussas": "surhausser",
    "surhaussasse": "surhausser",
    "surhaussassent": "surhausser",
    "surhaussasses": "surhausser",
    "surhaussassiez": "surhausser",
    "surhaussassions": "surhausser",
    "surhausse": "surhausser",
    "surhaussent": "surhausser",
    "surhaussera": "surhausser",
    "surhausserai": "surhausser",
    "surhausseraient": "surhausser",
    "surhausserais": "surhausser",
    "surhausserait": "surhausser",
    "surhausseras": "surhausser",
    "surhausserez": "surhausser",
    "surhausseriez": "surhausser",
    "surhausserions": "surhausser",
    "surhausserons": "surhausser",
    "surhausseront": "surhausser",
    "surhausses": "surhausser",
    "surhaussez": "surhausser",
    "surhaussiez": "surhausser",
    "surhaussions": "surhausser",
    "surhaussons": "surhausser",
    "surhaussâmes": "surhausser",
    "surhaussât": "surhausser",
    "surhaussâtes": "surhausser",
    "surhaussèrent": "surhausser",
    "surhaussé": "surhausser",
    "surhaussée": "surhausser",
    "surhaussées": "surhausser",
    "surhaussés": "surhausser",
    "surhommes": "surhomme",
    "surhumaine": "surhumain",
    "surhumaines": "surhumain",
    "surhumains": "surhumain",
    "suri": "surir",
    "surie": "surir",
    "suries": "surir",
    "surimis": "surimi",
    "surimposa": "surimposer",
    "surimposai": "surimposer",
    "surimposaient": "surimposer",
    "surimposais": "surimposer",
    "surimposait": "surimposer",
    "surimposant": "surimposer",
    "surimposas": "surimposer",
    "surimposasse": "surimposer",
    "surimposassent": "surimposer",
    "surimposasses": "surimposer",
    "surimposassiez": "surimposer",
    "surimposassions": "surimposer",
    "surimpose": "surimposer",
    "surimposent": "surimposer",
    "surimposera": "surimposer",
    "surimposerai": "surimposer",
    "surimposeraient": "surimposer",
    "surimposerais": "surimposer",
    "surimposerait": "surimposer",
    "surimposeras": "surimposer",
    "surimposerez": "surimposer",
    "surimposeriez": "surimposer",
    "surimposerions": "surimposer",
    "surimposerons": "surimposer",
    "surimposeront": "surimposer",
    "surimposes": "surimposer",
    "surimposez": "surimposer",
    "surimposiez": "surimposer",
    "surimposions": "surimposer",
    "surimposons": "surimposer",
    "surimposâmes": "surimposer",
    "surimposât": "surimposer",
    "surimposâtes": "surimposer",
    "surimposèrent": "surimposer",
    "surimposé": "surimposer",
    "surimposée": "surimposer",
    "surimposées": "surimposer",
    "surimposés": "surimposer",
    "surimpressions": "surimpression",
    "surinait": "suriner",
    "surinamienne": "surinamien",
    "surinamiennes": "surinamien",
    "surinamiens": "surinamien",
    "surine": "suriner",
    "surinent": "suriner",
    "surinerais": "suriner",
    "surinfections": "surinfection",
    "surinformé": "surinformer",
    "surins": "surin",
    "surintendances": "surintendance",
    "surintendante": "surintendant",
    "surintendants": "surintendant",
    "suriné": "suriner",
    "surira": "surir",
    "surirai": "surir",
    "suriraient": "surir",
    "surirais": "surir",
    "surirait": "surir",
    "suriras": "surir",
    "surirent": "surir",
    "surirez": "surir",
    "suririez": "surir",
    "suririons": "surir",
    "surirons": "surir",
    "suriront": "surir",
    "suris": "surir",
    "surissaient": "surir",
    "surissais": "surir",
    "surissait": "surir",
    "surissant": "surir",
    "surisse": "surir",
    "surissent": "surir",
    "surisses": "surir",
    "surissez": "surir",
    "surissiez": "surir",
    "surissions": "surir",
    "surissons": "surir",
    "surit": "surir",
    "surjeta": "surjeter",
    "surjetai": "surjeter",
    "surjetaient": "surjeter",
    "surjetais": "surjeter",
    "surjetait": "surjeter",
    "surjetant": "surjeter",
    "surjetas": "surjeter",
    "surjetasse": "surjeter",
    "surjetassent": "surjeter",
    "surjetasses": "surjeter",
    "surjetassiez": "surjeter",
    "surjetassions": "surjeter",
    "surjeteuse": "jeteur",
    "surjetez": "surjeter",
    "surjetiez": "surjeter",
    "surjetions": "surjeter",
    "surjetons": "surjeter",
    "surjets": "surjet",
    "surjette": "surjeter",
    "surjettent": "surjeter",
    "surjettera": "surjeter",
    "surjetterai": "surjeter",
    "surjetteraient": "surjeter",
    "surjetterais": "surjeter",
    "surjetterait": "surjeter",
    "surjetteras": "surjeter",
    "surjetterez": "surjeter",
    "surjetteriez": "surjeter",
    "surjetterions": "surjeter",
    "surjetterons": "surjeter",
    "surjetteront": "surjeter",
    "surjettes": "surjeter",
    "surjetâmes": "surjeter",
    "surjetât": "surjeter",
    "surjetâtes": "surjeter",
    "surjetèrent": "surjeter",
    "surjeté": "surjeter",
    "surjetée": "surjeter",
    "surjetées": "surjeter",
    "surjetés": "surjeter",
    "surlendemains": "surlendemain",
    "surlia": "surlier",
    "surliai": "surlier",
    "surliaient": "surlier",
    "surliais": "surlier",
    "surliait": "surlier",
    "surliant": "surlier",
    "surlias": "surlier",
    "surliasse": "surlier",
    "surliassent": "surlier",
    "surliasses": "surlier",
    "surliassiez": "surlier",
    "surliassions": "surlier",
    "surlie": "surlier",
    "surlient": "surlier",
    "surliera": "surlier",
    "surlierai": "surlier",
    "surlieraient": "surlier",
    "surlierais": "surlier",
    "surlierait": "surlier",
    "surlieras": "surlier",
    "surlierez": "surlier",
    "surlieriez": "surlier",
    "surlierions": "surlier",
    "surlierons": "surlier",
    "surlieront": "surlier",
    "surlies": "surlier",
    "surliez": "surlier",
    "surligné": "surligner",
    "surliiez": "surlier",
    "surliions": "surlier",
    "surlions": "surlier",
    "surliâmes": "surlier",
    "surliât": "surlier",
    "surliâtes": "surlier",
    "surlièrent": "surlier",
    "surlié": "surlier",
    "surliée": "surlier",
    "surliées": "surlier",
    "surliés": "surlier",
    "surmena": "surmener",
    "surmenages": "surmenage",
    "surmenai": "surmener",
    "surmenaient": "surmener",
    "surmenais": "surmener",
    "surmenait": "surmener",
    "surmenant": "surmener",
    "surmenas": "surmener",
    "surmenasse": "surmener",
    "surmenassent": "surmener",
    "surmenasses": "surmener",
    "surmenassiez": "surmener",
    "surmenassions": "surmener",
    "surmenez": "surmener",
    "surmeniez": "surmener",
    "surmenions": "surmener",
    "surmenons": "surmener",
    "surmenâmes": "surmener",
    "surmenât": "surmener",
    "surmenâtes": "surmener",
    "surmenèrent": "surmener",
    "surmené": "surmener",
    "surmenée": "surmener",
    "surmenées": "surmener",
    "surmenés": "surmener",
    "surmonta": "surmonter",
    "surmontai": "surmonter",
    "surmontaient": "surmonter",
    "surmontais": "surmonter",
    "surmontait": "surmonter",
    "surmontant": "surmonter",
    "surmontas": "surmonter",
    "surmontasse": "surmonter",
    "surmontassent": "surmonter",
    "surmontasses": "surmonter",
    "surmontassiez": "surmonter",
    "surmontassions": "surmonter",
    "surmonte": "surmonter",
    "surmontent": "surmonter",
    "surmontera": "surmonter",
    "surmonterai": "surmonter",
    "surmonteraient": "surmonter",
    "surmonterais": "surmonter",
    "surmonterait": "surmonter",
    "surmonteras": "surmonter",
    "surmonterez": "surmonter",
    "surmonteriez": "surmonter",
    "surmonterions": "surmonter",
    "surmonterons": "surmonter",
    "surmonteront": "surmonter",
    "surmontes": "surmonter",
    "surmontez": "surmonter",
    "surmontiez": "surmonter",
    "surmontions": "surmonter",
    "surmontons": "surmonter",
    "surmontâmes": "surmonter",
    "surmontât": "surmonter",
    "surmontâtes": "surmonter",
    "surmontèrent": "surmonter",
    "surmonté": "surmonter",
    "surmontée": "surmonter",
    "surmontées": "surmonter",
    "surmontés": "surmonter",
    "surmoula": "surmouler",
    "surmoulai": "surmouler",
    "surmoulaient": "surmouler",
    "surmoulais": "surmouler",
    "surmoulait": "surmouler",
    "surmoulant": "surmouler",
    "surmoulas": "surmouler",
    "surmoulasse": "surmouler",
    "surmoulassent": "surmouler",
    "surmoulasses": "surmouler",
    "surmoulassiez": "surmouler",
    "surmoulassions": "surmouler",
    "surmoule": "surmouler",
    "surmoulent": "surmouler",
    "surmoulera": "surmouler",
    "surmoulerai": "surmouler",
    "surmouleraient": "surmouler",
    "surmoulerais": "surmouler",
    "surmoulerait": "surmouler",
    "surmouleras": "surmouler",
    "surmoulerez": "surmouler",
    "surmouleriez": "surmouler",
    "surmoulerions": "surmouler",
    "surmoulerons": "surmouler",
    "surmouleront": "surmouler",
    "surmoules": "surmouler",
    "surmoulez": "surmouler",
    "surmouliez": "surmouler",
    "surmoulions": "surmouler",
    "surmoulons": "surmouler",
    "surmoulâmes": "surmouler",
    "surmoulât": "surmouler",
    "surmoulâtes": "surmouler",
    "surmoulèrent": "surmouler",
    "surmoulé": "surmouler",
    "surmoulée": "surmouler",
    "surmoulées": "surmouler",
    "surmoulés": "surmouler",
    "surmulots": "surmulot",
    "surmultipliée": "surmultiplier",
    "surmultipliées": "surmultiplié",
    "surmultipliés": "surmultiplié",
    "surmène": "surmener",
    "surmènent": "surmener",
    "surmènera": "surmener",
    "surmènerai": "surmener",
    "surmèneraient": "surmener",
    "surmènerais": "surmener",
    "surmènerait": "surmener",
    "surmèneras": "surmener",
    "surmènerez": "surmener",
    "surmèneriez": "surmener",
    "surmènerions": "surmener",
    "surmènerons": "surmener",
    "surmèneront": "surmener",
    "surmènes": "surmener",
    "surnage": "surnager",
    "surnagea": "surnager",
    "surnageai": "surnager",
    "surnageaient": "surnager",
    "surnageais": "surnager",
    "surnageait": "surnager",
    "surnageant": "surnager",
    "surnageants": "surnageant",
    "surnageas": "surnager",
    "surnageasse": "surnager",
    "surnageassent": "surnager",
    "surnageasses": "surnager",
    "surnageassiez": "surnager",
    "surnageassions": "surnager",
    "surnagent": "surnager",
    "surnageons": "surnager",
    "surnagera": "surnager",
    "surnagerai": "surnager",
    "surnageraient": "surnager",
    "surnagerais": "surnager",
    "surnagerait": "surnager",
    "surnageras": "surnager",
    "surnagerez": "surnager",
    "surnageriez": "surnager",
    "surnagerions": "surnager",
    "surnagerons": "surnager",
    "surnageront": "surnager",
    "surnages": "surnager",
    "surnagez": "surnager",
    "surnageâmes": "surnager",
    "surnageât": "surnager",
    "surnageâtes": "surnager",
    "surnagiez": "surnager",
    "surnagions": "surnager",
    "surnagèrent": "surnager",
    "surnagé": "surnager",
    "surnaturelle": "surnaturel",
    "surnaturelles": "surnaturel",
    "surnaturels": "surnaturel",
    "surnombres": "surnombre",
    "surnomma": "surnommer",
    "surnommai": "surnommer",
    "surnommaient": "surnommer",
    "surnommais": "surnommer",
    "surnommait": "surnommer",
    "surnommant": "surnommer",
    "surnommas": "surnommer",
    "surnommasse": "surnommer",
    "surnommassent": "surnommer",
    "surnommasses": "surnommer",
    "surnommassiez": "surnommer",
    "surnommassions": "surnommer",
    "surnomme": "surnommer",
    "surnomment": "surnommer",
    "surnommera": "surnommer",
    "surnommerai": "surnommer",
    "surnommeraient": "surnommer",
    "surnommerais": "surnommer",
    "surnommerait": "surnommer",
    "surnommeras": "surnommer",
    "surnommerez": "surnommer",
    "surnommeriez": "surnommer",
    "surnommerions": "surnommer",
    "surnommerons": "surnommer",
    "surnommeront": "surnommer",
    "surnommes": "surnommer",
    "surnommez": "surnommer",
    "surnommiez": "surnommer",
    "surnommions": "surnommer",
    "surnommons": "surnommer",
    "surnommâmes": "surnommer",
    "surnommât": "surnommer",
    "surnommâtes": "surnommer",
    "surnommèrent": "surnommer",
    "surnommé": "surnommer",
    "surnommée": "surnommer",
    "surnommées": "surnommer",
    "surnommés": "surnommer",
    "surnoms": "surnom",
    "surnuméraires": "surnuméraire",
    "suroxyda": "suroxyder",
    "suroxydai": "suroxyder",
    "suroxydaient": "suroxyder",
    "suroxydais": "suroxyder",
    "suroxydait": "suroxyder",
    "suroxydant": "suroxyder",
    "suroxydas": "suroxyder",
    "suroxydasse": "suroxyder",
    "suroxydassent": "suroxyder",
    "suroxydasses": "suroxyder",
    "suroxydassiez": "suroxyder",
    "suroxydassions": "suroxyder",
    "suroxyde": "suroxyder",
    "suroxydent": "suroxyder",
    "suroxydera": "suroxyder",
    "suroxyderai": "suroxyder",
    "suroxyderaient": "suroxyder",
    "suroxyderais": "suroxyder",
    "suroxyderait": "suroxyder",
    "suroxyderas": "suroxyder",
    "suroxyderez": "suroxyder",
    "suroxyderiez": "suroxyder",
    "suroxyderions": "suroxyder",
    "suroxyderons": "suroxyder",
    "suroxyderont": "suroxyder",
    "suroxydes": "suroxyder",
    "suroxydez": "suroxyder",
    "suroxydiez": "suroxyder",
    "suroxydions": "suroxyder",
    "suroxydons": "suroxyder",
    "suroxydâmes": "suroxyder",
    "suroxydât": "suroxyder",
    "suroxydâtes": "suroxyder",
    "suroxydèrent": "suroxyder",
    "suroxydé": "suroxyder",
    "suroxydée": "suroxyder",
    "suroxydées": "suroxyder",
    "suroxydés": "suroxyder",
    "suroîts": "suroît",
    "surpaie": "surpayer",
    "surpaient": "surpayer",
    "surpaiera": "surpayer",
    "surpaierai": "surpayer",
    "surpaieraient": "surpayer",
    "surpaierais": "surpayer",
    "surpaierait": "surpayer",
    "surpaieras": "surpayer",
    "surpaierez": "surpayer",
    "surpaieriez": "surpayer",
    "surpaierions": "surpayer",
    "surpaierons": "surpayer",
    "surpaieront": "surpayer",
    "surpaies": "surpayer",
    "surpassa": "surpasser",
    "surpassai": "surpasser",
    "surpassaient": "surpasser",
    "surpassais": "surpasser",
    "surpassait": "surpasser",
    "surpassant": "surpasser",
    "surpassas": "surpasser",
    "surpassasse": "surpasser",
    "surpassassent": "surpasser",
    "surpassasses": "surpasser",
    "surpassassiez": "surpasser",
    "surpassassions": "surpasser",
    "surpasse": "surpasser",
    "surpassent": "surpasser",
    "surpassera": "surpasser",
    "surpasserai": "surpasser",
    "surpasseraient": "surpasser",
    "surpasserais": "surpasser",
    "surpasserait": "surpasser",
    "surpasseras": "surpasser",
    "surpasserez": "surpasser",
    "surpasseriez": "surpasser",
    "surpasserions": "surpasser",
    "surpasserons": "surpasser",
    "surpasseront": "surpasser",
    "surpasses": "surpasser",
    "surpassez": "surpasser",
    "surpassiez": "surpasser",
    "surpassions": "surpasser",
    "surpassons": "surpasser",
    "surpassâmes": "surpasser",
    "surpassât": "surpasser",
    "surpassâtes": "surpasser",
    "surpassèrent": "surpasser",
    "surpassé": "surpasser",
    "surpassée": "surpasser",
    "surpassées": "surpasser",
    "surpassés": "surpasser",
    "surpattes": "surpatte",
    "surpaya": "surpayer",
    "surpayai": "surpayer",
    "surpayaient": "surpayer",
    "surpayais": "surpayer",
    "surpayait": "surpayer",
    "surpayant": "surpayer",
    "surpayas": "surpayer",
    "surpayasse": "surpayer",
    "surpayassent": "surpayer",
    "surpayasses": "surpayer",
    "surpayassiez": "surpayer",
    "surpayassions": "surpayer",
    "surpaye": "surpayer",
    "surpayent": "surpayer",
    "surpayera": "surpayer",
    "surpayerai": "surpayer",
    "surpayeraient": "surpayer",
    "surpayerais": "surpayer",
    "surpayerait": "surpayer",
    "surpayeras": "surpayer",
    "surpayerez": "surpayer",
    "surpayeriez": "surpayer",
    "surpayerions": "surpayer",
    "surpayerons": "surpayer",
    "surpayeront": "surpayer",
    "surpayes": "surpayer",
    "surpayez": "surpayer",
    "surpayiez": "surpayer",
    "surpayions": "surpayer",
    "surpayons": "surpayer",
    "surpayâmes": "surpayer",
    "surpayât": "surpayer",
    "surpayâtes": "surpayer",
    "surpayèrent": "surpayer",
    "surpayé": "surpayer",
    "surpayée": "surpayer",
    "surpayées": "surpayer",
    "surpayés": "surpayer",
    "surpeuplée": "surpeuplé",
    "surpeuplées": "surpeuplé",
    "surpeuplés": "surpeuplé",
    "surpiqûres": "surpiqûre",
    "surplaces": "surplace",
    "surplomba": "surplomber",
    "surplombai": "surplomber",
    "surplombaient": "surplomber",
    "surplombais": "surplomber",
    "surplombait": "surplomber",
    "surplombant": "surplomber",
    "surplombante": "surplombant",
    "surplombas": "surplomber",
    "surplombasse": "surplomber",
    "surplombassent": "surplomber",
    "surplombasses": "surplomber",
    "surplombassiez": "surplomber",
    "surplombassions": "surplomber",
    "surplombe": "surplomber",
    "surplombent": "surplomber",
    "surplombera": "surplomber",
    "surplomberai": "surplomber",
    "surplomberaient": "surplomber",
    "surplomberais": "surplomber",
    "surplomberait": "surplomber",
    "surplomberas": "surplomber",
    "surplomberez": "surplomber",
    "surplomberiez": "surplomber",
    "surplomberions": "surplomber",
    "surplomberons": "surplomber",
    "surplomberont": "surplomber",
    "surplombes": "surplomber",
    "surplombez": "surplomber",
    "surplombiez": "surplomber",
    "surplombions": "surplomber",
    "surplombons": "surplomber",
    "surplombs": "surplomb",
    "surplombâmes": "surplomber",
    "surplombât": "surplomber",
    "surplombâtes": "surplomber",
    "surplombèrent": "surplomber",
    "surplombé": "surplomber",
    "surplombée": "surplomber",
    "surplombées": "surplomber",
    "surplombés": "surplomber",
    "surprenaient": "surprendre",
    "surprenais": "surprendre",
    "surprenait": "surprendre",
    "surprenant": "surprendre",
    "surprenante": "surprenant",
    "surprenantes": "surprenant",
    "surprenants": "surprenant",
    "surprend": "surprendre",
    "surprendra": "surprendre",
    "surprendrai": "surprendre",
    "surprendraient": "surprendre",
    "surprendrais": "surprendre",
    "surprendrait": "surprendre",
    "surprendras": "surprendre",
    "surprendrez": "surprendre",
    "surprendriez": "surprendre",
    "surprendrions": "surprendre",
    "surprendrons": "surprendre",
    "surprendront": "surprendre",
    "surprends": "surprendre",
    "surprenez": "surprendre",
    "surpreniez": "surprendre",
    "surprenions": "surprendre",
    "surprenne": "surprendre",
    "surprennent": "surprendre",
    "surprennes": "surprendre",
    "surprenons": "surprendre",
    "surprirent": "surprendre",
    "surpris": "surprendre",
    "surprise": "surpris",
    "surprises": "surprise",
    "surprises-parties": "surprise-partie",
    "surprisse": "surprendre",
    "surprissent": "surprendre",
    "surprisses": "surprendre",
    "surprissiez": "surprendre",
    "surprissions": "surprendre",
    "surprit": "surprendre",
    "surproductions": "surproduction",
    "surprotectrice": "surprotecteur",
    "surprotège": "surprotéger",
    "surprotégeais": "surprotéger",
    "surprotégé": "surprotéger",
    "surprîmes": "surprendre",
    "surprît": "surprendre",
    "surprîtes": "surprendre",
    "surpuissante": "surpuissant",
    "surpuissants": "surpuissant",
    "surqualifiée": "surqualifié",
    "surqualifiées": "surqualifié",
    "surqualifiés": "surqualifié",
    "surréalismes": "surréalisme",
    "surréalistes": "surréaliste",
    "surréelle": "surréel",
    "surréelles": "surréel",
    "surréels": "surréel",
    "surrénale": "surrénal",
    "surrénales": "surrénale",
    "surs": "sur",
    "sursatura": "sursaturer",
    "sursaturai": "sursaturer",
    "sursaturaient": "sursaturer",
    "sursaturais": "sursaturer",
    "sursaturait": "sursaturer",
    "sursaturant": "sursaturer",
    "sursaturas": "sursaturer",
    "sursaturasse": "sursaturer",
    "sursaturassent": "sursaturer",
    "sursaturasses": "sursaturer",
    "sursaturassiez": "sursaturer",
    "sursaturassions": "sursaturer",
    "sursature": "sursaturer",
    "sursaturent": "sursaturer",
    "sursaturera": "sursaturer",
    "sursaturerai": "sursaturer",
    "sursatureraient": "sursaturer",
    "sursaturerais": "sursaturer",
    "sursaturerait": "sursaturer",
    "sursatureras": "sursaturer",
    "sursaturerez": "sursaturer",
    "sursatureriez": "sursaturer",
    "sursaturerions": "sursaturer",
    "sursaturerons": "sursaturer",
    "sursatureront": "sursaturer",
    "sursatures": "sursaturer",
    "sursaturez": "sursaturer",
    "sursaturiez": "sursaturer",
    "sursaturions": "sursaturer",
    "sursaturons": "sursaturer",
    "sursaturâmes": "sursaturer",
    "sursaturât": "sursaturer",
    "sursaturâtes": "sursaturer",
    "sursaturèrent": "sursaturer",
    "sursaturé": "sursaturer",
    "sursaturée": "sursaturer",
    "sursaturées": "sursaturer",
    "sursaturés": "sursaturer",
    "sursauta": "sursauter",
    "sursautai": "sursauter",
    "sursautaient": "sursauter",
    "sursautais": "sursauter",
    "sursautait": "sursauter",
    "sursautant": "sursauter",
    "sursautas": "sursauter",
    "sursautasse": "sursauter",
    "sursautassent": "sursauter",
    "sursautasses": "sursauter",
    "sursautassiez": "sursauter",
    "sursautassions": "sursauter",
    "sursaute": "sursauter",
    "sursautent": "sursauter",
    "sursautera": "sursauter",
    "sursauterai": "sursauter",
    "sursauteraient": "sursauter",
    "sursauterais": "sursauter",
    "sursauterait": "sursauter",
    "sursauteras": "sursauter",
    "sursauterez": "sursauter",
    "sursauteriez": "sursauter",
    "sursauterions": "sursauter",
    "sursauterons": "sursauter",
    "sursauteront": "sursauter",
    "sursautes": "sursauter",
    "sursautez": "sursauter",
    "sursautiez": "sursauter",
    "sursautions": "sursauter",
    "sursautons": "sursauter",
    "sursauts": "sursaut",
    "sursautâmes": "sursauter",
    "sursautât": "sursauter",
    "sursautâtes": "sursauter",
    "sursautèrent": "sursauter",
    "sursauté": "sursauter",
    "sursautée": "sursauter",
    "sursautées": "sursauter",
    "sursautés": "sursauter",
    "sursema": "sursemer",
    "sursemai": "sursemer",
    "sursemaient": "sursemer",
    "sursemais": "sursemer",
    "sursemait": "sursemer",
    "sursemant": "sursemer",
    "sursemas": "sursemer",
    "sursemasse": "sursemer",
    "sursemassent": "sursemer",
    "sursemasses": "sursemer",
    "sursemassiez": "sursemer",
    "sursemassions": "sursemer",
    "sursemez": "sursemer",
    "sursemiez": "sursemer",
    "sursemions": "sursemer",
    "sursemons": "sursemer",
    "sursemâmes": "sursemer",
    "sursemât": "sursemer",
    "sursemâtes": "sursemer",
    "sursemèrent": "sursemer",
    "sursemé": "sursemer",
    "sursemée": "sursemer",
    "sursemées": "sursemer",
    "sursemés": "sursemer",
    "surseoira": "surseoir",
    "surseoirai": "surseoir",
    "surseoiraient": "surseoir",
    "surseoirais": "surseoir",
    "surseoirait": "surseoir",
    "surseoiras": "surseoir",
    "surseoirez": "surseoir",
    "surseoiriez": "surseoir",
    "surseoirions": "surseoir",
    "surseoirons": "surseoir",
    "surseoiront": "surseoir",
    "sursirent": "surseoir",
    "sursis": "surseoir",
    "sursise": "surseoir",
    "sursises": "surseoir",
    "sursisse": "surseoir",
    "sursissent": "surseoir",
    "sursisses": "surseoir",
    "sursissiez": "surseoir",
    "sursissions": "surseoir",
    "sursit": "surseoir",
    "sursitaires": "sursitaire",
    "sursoie": "surseoir",
    "sursoient": "surseoir",
    "sursoies": "surseoir",
    "sursois": "surseoir",
    "sursoit": "surseoir",
    "sursoyaient": "surseoir",
    "sursoyais": "surseoir",
    "sursoyait": "surseoir",
    "sursoyant": "surseoir",
    "sursoyez": "surseoir",
    "sursoyiez": "surseoir",
    "sursoyions": "surseoir",
    "sursoyons": "surseoir",
    "sursème": "sursemer",
    "sursèment": "sursemer",
    "sursèmera": "sursemer",
    "sursèmerai": "sursemer",
    "sursèmeraient": "sursemer",
    "sursèmerais": "sursemer",
    "sursèmerait": "sursemer",
    "sursèmeras": "sursemer",
    "sursèmerez": "sursemer",
    "sursèmeriez": "sursemer",
    "sursèmerions": "sursemer",
    "sursèmerons": "sursemer",
    "sursèmeront": "sursemer",
    "sursèmes": "sursemer",
    "sursîmes": "surseoir",
    "sursît": "surseoir",
    "sursîtes": "surseoir",
    "surtaxa": "surtaxer",
    "surtaxai": "surtaxer",
    "surtaxaient": "surtaxer",
    "surtaxais": "surtaxer",
    "surtaxait": "surtaxer",
    "surtaxant": "surtaxer",
    "surtaxas": "surtaxer",
    "surtaxasse": "surtaxer",
    "surtaxassent": "surtaxer",
    "surtaxasses": "surtaxer",
    "surtaxassiez": "surtaxer",
    "surtaxassions": "surtaxer",
    "surtaxe": "surtaxer",
    "surtaxent": "surtaxer",
    "surtaxera": "surtaxer",
    "surtaxerai": "surtaxer",
    "surtaxeraient": "surtaxer",
    "surtaxerais": "surtaxer",
    "surtaxerait": "surtaxer",
    "surtaxeras": "surtaxer",
    "surtaxerez": "surtaxer",
    "surtaxeriez": "surtaxer",
    "surtaxerions": "surtaxer",
    "surtaxerons": "surtaxer",
    "surtaxeront": "surtaxer",
    "surtaxes": "surtaxer",
    "surtaxez": "surtaxer",
    "surtaxiez": "surtaxer",
    "surtaxions": "surtaxer",
    "surtaxons": "surtaxer",
    "surtaxâmes": "surtaxer",
    "surtaxât": "surtaxer",
    "surtaxâtes": "surtaxer",
    "surtaxèrent": "surtaxer",
    "surtaxé": "surtaxer",
    "surtaxée": "surtaxer",
    "surtaxées": "surtaxer",
    "surtaxés": "surtaxer",
    "surtensions": "surtension",
    "surtond": "surtondre",
    "surtondaient": "surtondre",
    "surtondais": "surtondre",
    "surtondait": "surtondre",
    "surtondant": "surtondre",
    "surtonde": "surtondre",
    "surtondent": "surtondre",
    "surtondes": "surtondre",
    "surtondez": "surtondre",
    "surtondiez": "surtondre",
    "surtondions": "surtondre",
    "surtondirent": "surtondre",
    "surtondis": "surtondre",
    "surtondisse": "surtondre",
    "surtondissent": "surtondre",
    "surtondisses": "surtondre",
    "surtondissiez": "surtondre",
    "surtondissions": "surtondre",
    "surtondit": "surtondre",
    "surtondons": "surtondre",
    "surtondra": "surtondre",
    "surtondrai": "surtondre",
    "surtondraient": "surtondre",
    "surtondrais": "surtondre",
    "surtondrait": "surtondre",
    "surtondras": "surtondre",
    "surtondrez": "surtondre",
    "surtondriez": "surtondre",
    "surtondrions": "surtondre",
    "surtondrons": "surtondre",
    "surtondront": "surtondre",
    "surtonds": "surtondre",
    "surtondu": "surtondre",
    "surtondue": "surtondre",
    "surtondues": "surtondre",
    "surtondus": "surtondre",
    "surtondîmes": "surtondre",
    "surtondît": "surtondre",
    "surtondîtes": "surtondre",
    "surtours": "surtour",
    "surtouts": "surtout",
    "surveilla": "surveiller",
    "surveillai": "surveiller",
    "surveillaient": "surveiller",
    "surveillais": "surveiller",
    "surveillait": "surveiller",
    "surveillances": "surveillance",
    "surveillant": "surveiller",
    "surveillante": "surveillant",
    "surveillantes": "surveillant",
    "surveillants": "surveillant",
    "surveillas": "surveiller",
    "surveillasse": "surveiller",
    "surveillassent": "surveiller",
    "surveillasses": "surveiller",
    "surveillassiez": "surveiller",
    "surveillassions": "surveiller",
    "surveille": "surveiller",
    "surveillent": "surveiller",
    "surveillera": "surveiller",
    "surveillerai": "surveiller",
    "surveilleraient": "surveiller",
    "surveillerais": "surveiller",
    "surveillerait": "surveiller",
    "surveilleras": "surveiller",
    "surveillerez": "surveiller",
    "surveilleriez": "surveiller",
    "surveillerions": "surveiller",
    "surveillerons": "surveiller",
    "surveilleront": "surveiller",
    "surveilles": "surveiller",
    "surveillez": "surveiller",
    "surveilliez": "surveiller",
    "surveillions": "surveiller",
    "surveillons": "surveiller",
    "surveillâmes": "surveiller",
    "surveillât": "surveiller",
    "surveillâtes": "surveiller",
    "surveillèrent": "surveiller",
    "surveillé": "surveiller",
    "surveillée": "surveiller",
    "surveillées": "surveiller",
    "surveillés": "surveiller",
    "survenaient": "survenir",
    "survenais": "survenir",
    "survenait": "survenir",
    "survenant": "survenir",
    "survenants": "survenant",
    "survenez": "survenir",
    "surveniez": "survenir",
    "survenions": "survenir",
    "survenons": "survenir",
    "survenu": "survenir",
    "survenue": "survenir",
    "survenues": "survenue",
    "survenus": "survenir",
    "surviendra": "survenir",
    "surviendrai": "survenir",
    "surviendraient": "survenir",
    "surviendrais": "survenir",
    "surviendrait": "survenir",
    "surviendras": "survenir",
    "surviendrez": "survenir",
    "surviendriez": "survenir",
    "surviendrions": "survenir",
    "surviendrons": "survenir",
    "surviendront": "survenir",
    "survienne": "survenir",
    "surviennent": "survenir",
    "surviennes": "survenir",
    "surviens": "survenir",
    "survient": "survenir",
    "survies": "survie",
    "survinrent": "survenir",
    "survins": "survenir",
    "survinsse": "survenir",
    "survinssent": "survenir",
    "survinsses": "survenir",
    "survinssiez": "survenir",
    "survinssions": "survenir",
    "survint": "survenir",
    "survira": "survirer",
    "survirai": "survirer",
    "surviraient": "survirer",
    "survirais": "survirer",
    "survirait": "survirer",
    "survirant": "survirer",
    "surviras": "survirer",
    "survirasse": "survirer",
    "survirassent": "survirer",
    "survirasses": "survirer",
    "survirassiez": "survirer",
    "survirassions": "survirer",
    "survire": "survirer",
    "survirent": "survirer",
    "survirera": "survirer",
    "survirerai": "survirer",
    "survireraient": "survirer",
    "survirerais": "survirer",
    "survirerait": "survirer",
    "survireras": "survirer",
    "survirerez": "survirer",
    "survireriez": "survirer",
    "survirerions": "survirer",
    "survirerons": "survirer",
    "survireront": "survirer",
    "survires": "survirer",
    "survirez": "survirer",
    "surviriez": "survirer",
    "survirions": "survirer",
    "survirons": "survirer",
    "survirâmes": "survirer",
    "survirât": "survirer",
    "survirâtes": "survirer",
    "survirèrent": "survirer",
    "surviré": "survirer",
    "survis": "survivre",
    "survit": "survivre",
    "survivaient": "survivre",
    "survivais": "survivre",
    "survivait": "survivre",
    "survivances": "survivance",
    "survivant": "survivre",
    "survivante": "survivant",
    "survivantes": "survivant",
    "survivants": "survivant",
    "survive": "survivre",
    "survivent": "survivre",
    "survives": "survivre",
    "survivez": "survivre",
    "surviviez": "survivre",
    "survivions": "survivre",
    "survivons": "survivre",
    "survivra": "survivre",
    "survivrai": "survivre",
    "survivraient": "survivre",
    "survivrais": "survivre",
    "survivrait": "survivre",
    "survivras": "survivre",
    "survivrez": "survivre",
    "survivriez": "survivre",
    "survivrions": "survivre",
    "survivrons": "survivre",
    "survivront": "survivre",
    "survola": "survoler",
    "survolai": "survoler",
    "survolaient": "survoler",
    "survolais": "survoler",
    "survolait": "survoler",
    "survolant": "survoler",
    "survolas": "survoler",
    "survolasse": "survoler",
    "survolassent": "survoler",
    "survolasses": "survoler",
    "survolassiez": "survoler",
    "survolassions": "survoler",
    "survole": "survoler",
    "survolent": "survoler",
    "survolera": "survoler",
    "survolerai": "survoler",
    "survoleraient": "survoler",
    "survolerais": "survoler",
    "survolerait": "survoler",
    "survoleras": "survoler",
    "survolerez": "survoler",
    "survoleriez": "survoler",
    "survolerions": "survoler",
    "survolerons": "survoler",
    "survoleront": "survoler",
    "survoles": "survoler",
    "survolez": "survoler",
    "survoliez": "survoler",
    "survolions": "survoler",
    "survolons": "survoler",
    "survols": "survol",
    "survolta": "survolter",
    "survoltai": "survolter",
    "survoltaient": "survolter",
    "survoltais": "survolter",
    "survoltait": "survolter",
    "survoltant": "survolter",
    "survoltas": "survolter",
    "survoltasse": "survolter",
    "survoltassent": "survolter",
    "survoltasses": "survolter",
    "survoltassiez": "survolter",
    "survoltassions": "survolter",
    "survolte": "survolter",
    "survoltent": "survolter",
    "survoltera": "survolter",
    "survolterai": "survolter",
    "survolteraient": "survolter",
    "survolterais": "survolter",
    "survolterait": "survolter",
    "survolteras": "survolter",
    "survolterez": "survolter",
    "survolteriez": "survolter",
    "survolterions": "survolter",
    "survolterons": "survolter",
    "survolteront": "survolter",
    "survoltes": "survolter",
    "survoltez": "survolter",
    "survoltiez": "survolter",
    "survoltions": "survolter",
    "survoltons": "survolter",
    "survoltâmes": "survolter",
    "survoltât": "survolter",
    "survoltâtes": "survolter",
    "survoltèrent": "survolter",
    "survolté": "survolter",
    "survoltée": "survolter",
    "survoltées": "survolter",
    "survoltés": "survolter",
    "survolâmes": "survoler",
    "survolât": "survoler",
    "survolâtes": "survoler",
    "survolèrent": "survoler",
    "survolé": "survoler",
    "survolée": "survoler",
    "survolées": "survoler",
    "survolés": "survoler",
    "survécu": "survivre",
    "survécurent": "survivre",
    "survécus": "survivre",
    "survécusse": "survivre",
    "survécussent": "survivre",
    "survécusses": "survivre",
    "survécussiez": "survivre",
    "survécussions": "survivre",
    "survécut": "survivre",
    "survécûmes": "survivre",
    "survécût": "survivre",
    "survécûtes": "survivre",
    "survêtements": "survêtement",
    "survêts": "survêt",
    "survînmes": "survenir",
    "survînt": "survenir",
    "survîntes": "survenir",
    "suréleva": "surélever",
    "surélevai": "surélever",
    "surélevaient": "surélever",
    "surélevais": "surélever",
    "surélevait": "surélever",
    "surélevant": "surélever",
    "surélevas": "surélever",
    "surélevasse": "surélever",
    "surélevassent": "surélever",
    "surélevasses": "surélever",
    "surélevassiez": "surélever",
    "surélevassions": "surélever",
    "surélevez": "surélever",
    "suréleviez": "surélever",
    "surélevions": "surélever",
    "surélevons": "surélever",
    "surélevâmes": "surélever",
    "surélevât": "surélever",
    "surélevâtes": "surélever",
    "surélevèrent": "surélever",
    "surélevé": "surélever",
    "surélevée": "surélever",
    "surélevées": "surélever",
    "surélevés": "surélever",
    "surélève": "surélever",
    "surélèvent": "surélever",
    "surélèvera": "surélever",
    "surélèverai": "surélever",
    "surélèveraient": "surélever",
    "surélèverais": "surélever",
    "surélèverait": "surélever",
    "surélèveras": "surélever",
    "surélèverez": "surélever",
    "surélèveriez": "surélever",
    "surélèverions": "surélever",
    "surélèverons": "surélever",
    "surélèveront": "surélever",
    "surélèves": "surélever",
    "surélévations": "surélévation",
    "suréminente": "suréminent",
    "suréminentes": "suréminent",
    "suréminents": "suréminent",
    "suréquipa": "suréquiper",
    "suréquipai": "suréquiper",
    "suréquipaient": "suréquiper",
    "suréquipais": "suréquiper",
    "suréquipait": "suréquiper",
    "suréquipant": "suréquiper",
    "suréquipas": "suréquiper",
    "suréquipasse": "suréquiper",
    "suréquipassent": "suréquiper",
    "suréquipasses": "suréquiper",
    "suréquipassiez": "suréquiper",
    "suréquipassions": "suréquiper",
    "suréquipe": "suréquiper",
    "suréquipent": "suréquiper",
    "suréquipera": "suréquiper",
    "suréquiperai": "suréquiper",
    "suréquiperaient": "suréquiper",
    "suréquiperais": "suréquiper",
    "suréquiperait": "suréquiper",
    "suréquiperas": "suréquiper",
    "suréquiperez": "suréquiper",
    "suréquiperiez": "suréquiper",
    "suréquiperions": "suréquiper",
    "suréquiperons": "suréquiper",
    "suréquiperont": "suréquiper",
    "suréquipes": "suréquiper",
    "suréquipez": "suréquiper",
    "suréquipiez": "suréquiper",
    "suréquipions": "suréquiper",
    "suréquipons": "suréquiper",
    "suréquipâmes": "suréquiper",
    "suréquipât": "suréquiper",
    "suréquipâtes": "suréquiper",
    "suréquipèrent": "suréquiper",
    "suréquipé": "suréquiper",
    "suréquipée": "suréquiper",
    "suréquipées": "suréquiper",
    "suréquipés": "suréquiper",
    "surévalua": "surévaluer",
    "surévaluai": "surévaluer",
    "surévaluaient": "surévaluer",
    "surévaluais": "surévaluer",
    "surévaluait": "surévaluer",
    "surévaluant": "surévaluer",
    "surévaluas": "surévaluer",
    "surévaluasse": "surévaluer",
    "surévaluassent": "surévaluer",
    "surévaluasses": "surévaluer",
    "surévaluassiez": "surévaluer",
    "surévaluassions": "surévaluer",
    "surévalue": "surévaluer",
    "surévaluent": "surévaluer",
    "surévaluera": "surévaluer",
    "surévaluerai": "surévaluer",
    "surévalueraient": "surévaluer",
    "surévaluerais": "surévaluer",
    "surévaluerait": "surévaluer",
    "surévalueras": "surévaluer",
    "surévaluerez": "surévaluer",
    "surévalueriez": "surévaluer",
    "surévaluerions": "surévaluer",
    "surévaluerons": "surévaluer",
    "surévalueront": "surévaluer",
    "surévalues": "surévaluer",
    "surévaluez": "surévaluer",
    "surévaluiez": "surévaluer",
    "surévaluions": "surévaluer",
    "surévaluons": "surévaluer",
    "surévaluâmes": "surévaluer",
    "surévaluât": "surévaluer",
    "surévaluâtes": "surévaluer",
    "surévaluèrent": "surévaluer",
    "surévalué": "surévaluer",
    "surévaluée": "surévaluer",
    "surévaluées": "surévaluer",
    "surévalués": "surévaluer",
    "surîmes": "surir",
    "surît": "surir",
    "surîtes": "surir",
    "sus": "savoir",
    "susceptibilités": "susceptibilité",
    "susceptibles": "susceptible",
    "suscita": "susciter",
    "suscitai": "susciter",
    "suscitaient": "susciter",
    "suscitais": "susciter",
    "suscitait": "susciter",
    "suscitant": "susciter",
    "suscitas": "susciter",
    "suscitasse": "susciter",
    "suscitassent": "susciter",
    "suscitasses": "susciter",
    "suscitassiez": "susciter",
    "suscitassions": "susciter",
    "suscite": "susciter",
    "suscitent": "susciter",
    "suscitera": "susciter",
    "susciterai": "susciter",
    "susciteraient": "susciter",
    "susciterais": "susciter",
    "susciterait": "susciter",
    "susciteras": "susciter",
    "susciterez": "susciter",
    "susciteriez": "susciter",
    "susciterions": "susciter",
    "susciterons": "susciter",
    "susciteront": "susciter",
    "suscites": "susciter",
    "suscitez": "susciter",
    "suscitiez": "susciter",
    "suscitions": "susciter",
    "suscitons": "susciter",
    "suscitâmes": "susciter",
    "suscitât": "susciter",
    "suscitâtes": "susciter",
    "suscitèrent": "susciter",
    "suscité": "susciter",
    "suscitée": "susciter",
    "suscitées": "susciter",
    "suscités": "susciter",
    "suscriptions": "suscription",
    "susdite": "susdit",
    "susdites": "susdit",
    "susdits": "susdit",
    "susmentionnée": "susmentionné",
    "susmentionnées": "susmentionné",
    "susmentionnés": "susmentionné",
    "susnommée": "susnommé",
    "susnommées": "susnommé",
    "susnommés": "susnommé",
    "suspecta": "suspecter",
    "suspectai": "suspecter",
    "suspectaient": "suspecter",
    "suspectais": "suspecter",
    "suspectait": "suspecter",
    "suspectant": "suspecter",
    "suspectas": "suspecter",
    "suspectasse": "suspecter",
    "suspectassent": "suspecter",
    "suspectasses": "suspecter",
    "suspectassiez": "suspecter",
    "suspectassions": "suspecter",
    "suspecte": "suspecter",
    "suspectent": "suspecter",
    "suspectera": "suspecter",
    "suspecterai": "suspecter",
    "suspecteraient": "suspecter",
    "suspecterais": "suspecter",
    "suspecterait": "suspecter",
    "suspecteras": "suspecter",
    "suspecterez": "suspecter",
    "suspecteriez": "suspecter",
    "suspecterions": "suspecter",
    "suspecterons": "suspecter",
    "suspecteront": "suspecter",
    "suspectes": "suspecter",
    "suspectez": "suspecter",
    "suspectiez": "suspecter",
    "suspections": "suspecter",
    "suspectons": "suspecter",
    "suspects": "suspect",
    "suspectâmes": "suspecter",
    "suspectât": "suspecter",
    "suspectâtes": "suspecter",
    "suspectèrent": "suspecter",
    "suspecté": "suspecter",
    "suspectée": "suspecter",
    "suspectées": "suspecter",
    "suspectés": "suspecter",
    "suspend": "suspendre",
    "suspendaient": "suspendre",
    "suspendais": "suspendre",
    "suspendait": "suspendre",
    "suspendant": "suspendre",
    "suspende": "suspendre",
    "suspendent": "suspendre",
    "suspendes": "suspendre",
    "suspendez": "suspendre",
    "suspendiez": "suspendre",
    "suspendions": "suspendre",
    "suspendirent": "suspendre",
    "suspendis": "suspendre",
    "suspendisse": "suspendre",
    "suspendissent": "suspendre",
    "suspendisses": "suspendre",
    "suspendissiez": "suspendre",
    "suspendissions": "suspendre",
    "suspendit": "suspendre",
    "suspendons": "suspendre",
    "suspendra": "suspendre",
    "suspendrai": "suspendre",
    "suspendraient": "suspendre",
    "suspendrais": "suspendre",
    "suspendrait": "suspendre",
    "suspendras": "suspendre",
    "suspendrez": "suspendre",
    "suspendriez": "suspendre",
    "suspendrions": "suspendre",
    "suspendrons": "suspendre",
    "suspendront": "suspendre",
    "suspends": "suspendre",
    "suspendu": "suspendre",
    "suspendue": "suspendu",
    "suspendues": "suspendu",
    "suspendus": "suspendu",
    "suspendîmes": "suspendre",
    "suspendît": "suspendre",
    "suspendîtes": "suspendre",
    "suspenses": "suspense",
    "suspenseurs": "suspenseur",
    "suspensifs": "suspensif",
    "suspensions": "suspension",
    "suspensive": "suspensif",
    "suspensives": "suspensif",
    "suspensoirs": "suspensoir",
    "suspentes": "suspente",
    "suspicieuse": "suspicieux",
    "suspicieuses": "suspicieux",
    "suspicions": "suspicion",
    "susse": "savoir",
    "sussent": "savoir",
    "susses": "savoir",
    "sussiez": "savoir",
    "sussions": "savoir",
    "sustenta": "sustenter",
    "sustentai": "sustenter",
    "sustentaient": "sustenter",
    "sustentais": "sustenter",
    "sustentait": "sustenter",
    "sustentant": "sustenter",
    "sustentas": "sustenter",
    "sustentasse": "sustenter",
    "sustentassent": "sustenter",
    "sustentasses": "sustenter",
    "sustentassiez": "sustenter",
    "sustentassions": "sustenter",
    "sustentations": "sustentation",
    "sustente": "sustenter",
    "sustentent": "sustenter",
    "sustentera": "sustenter",
    "sustenterai": "sustenter",
    "sustenteraient": "sustenter",
    "sustenterais": "sustenter",
    "sustenterait": "sustenter",
    "sustenteras": "sustenter",
    "sustenterez": "sustenter",
    "sustenteriez": "sustenter",
    "sustenterions": "sustenter",
    "sustenterons": "sustenter",
    "sustenteront": "sustenter",
    "sustentes": "sustenter",
    "sustentez": "sustenter",
    "sustentiez": "sustenter",
    "sustentions": "sustenter",
    "sustentons": "sustenter",
    "sustentâmes": "sustenter",
    "sustentât": "sustenter",
    "sustentâtes": "sustenter",
    "sustentèrent": "sustenter",
    "sustenté": "sustenter",
    "sustentée": "sustenter",
    "sustentées": "sustenter",
    "sustentés": "sustenter",
    "susurra": "susurrer",
    "susurrai": "susurrer",
    "susurraient": "susurrer",
    "susurrais": "susurrer",
    "susurrait": "susurrer",
    "susurrant": "susurrer",
    "susurras": "susurrer",
    "susurrasse": "susurrer",
    "susurrassent": "susurrer",
    "susurrasses": "susurrer",
    "susurrassiez": "susurrer",
    "susurrassions": "susurrer",
    "susurre": "susurrer",
    "susurrements": "susurrement",
    "susurrent": "susurrer",
    "susurrera": "susurrer",
    "susurrerai": "susurrer",
    "susurreraient": "susurrer",
    "susurrerais": "susurrer",
    "susurrerait": "susurrer",
    "susurreras": "susurrer",
    "susurrerez": "susurrer",
    "susurreriez": "susurrer",
    "susurrerions": "susurrer",
    "susurrerons": "susurrer",
    "susurreront": "susurrer",
    "susurres": "susurrer",
    "susurrez": "susurrer",
    "susurriez": "susurrer",
    "susurrions": "susurrer",
    "susurrons": "susurrer",
    "susurrâmes": "susurrer",
    "susurrât": "susurrer",
    "susurrâtes": "susurrer",
    "susurrèrent": "susurrer",
    "susurré": "susurrer",
    "susurrée": "susurrer",
    "susurrées": "susurrer",
    "susurrés": "susurrer",
    "susvisée": "susvisé",
    "susvisées": "susvisé",
    "susvisés": "susvisé",
    "sut": "savoir",
    "sutura": "suturer",
    "suturai": "suturer",
    "suturaient": "suturer",
    "suturais": "suturer",
    "suturait": "suturer",
    "suturale": "sutural",
    "suturales": "sutural",
    "suturant": "suturer",
    "suturas": "suturer",
    "suturasse": "suturer",
    "suturassent": "suturer",
    "suturasses": "suturer",
    "suturassiez": "suturer",
    "suturassions": "suturer",
    "suturaux": "sutural",
    "suture": "suturer",
    "suturent": "suturer",
    "suturera": "suturer",
    "suturerai": "suturer",
    "sutureraient": "suturer",
    "suturerais": "suturer",
    "suturerait": "suturer",
    "sutureras": "suturer",
    "suturerez": "suturer",
    "sutureriez": "suturer",
    "suturerions": "suturer",
    "suturerons": "suturer",
    "sutureront": "suturer",
    "sutures": "suturer",
    "suturez": "suturer",
    "suturiez": "suturer",
    "suturions": "suturer",
    "suturons": "suturer",
    "suturâmes": "suturer",
    "suturât": "suturer",
    "suturâtes": "suturer",
    "suturèrent": "suturer",
    "suturé": "suturer",
    "suturée": "suturer",
    "suturées": "suturer",
    "suturés": "suturer",
    "suzeraine": "suzerain",
    "suzeraines": "suzerain",
    "suzerains": "suzerain",
    "suâmes": "suer",
    "suât": "suer",
    "suâtes": "suer",
    "suça": "sucer",
    "suçages": "suçage",
    "suçai": "sucer",
    "suçaient": "sucer",
    "suçais": "sucer",
    "suçait": "sucer",
    "suçant": "sucer",
    "suças": "sucer",
    "suçasse": "sucer",
    "suçassent": "sucer",
    "suçasses": "sucer",
    "suçassiez": "sucer",
    "suçassions": "sucer",
    "suçoirs": "suçoir",
    "suçons": "suçon",
    "suçota": "suçoter",
    "suçotait": "suçoter",
    "suçotant": "suçoter",
    "suçote": "suçoter",
    "suçotements": "suçotement",
    "suçotent": "suçoter",
    "suçoté": "suçoter",
    "suçâmes": "sucer",
    "suçât": "sucer",
    "suçâtes": "sucer",
    "suèrent": "suer",
    "sué": "suer",
    "suédoise": "suédois",
    "suédoises": "suédois",
    "suée": "suer",
    "suées": "suer",
    "sués": "suer",
    "svastikas": "svastika",
    "sveltes": "svelte",
    "swappée": "swappé",
    "swappées": "swappé",
    "swappés": "swappé",
    "swaps": "swap",
    "sweat-shirts": "sweat-shirt",
    "sweaters": "sweater",
    "sweating-systems": "sweating-system",
    "sweepstakes": "sweepstake",
    "swiftiennes": "swiftien",
    "swings": "swing",
    "swingua": "swinguer",
    "swinguai": "swinguer",
    "swinguaient": "swinguer",
    "swinguais": "swinguer",
    "swinguait": "swinguer",
    "swinguant": "swinguer",
    "swinguas": "swinguer",
    "swinguasse": "swinguer",
    "swinguassent": "swinguer",
    "swinguasses": "swinguer",
    "swinguassiez": "swinguer",
    "swinguassions": "swinguer",
    "swingue": "swinguer",
    "swinguent": "swinguer",
    "swinguera": "swinguer",
    "swinguerai": "swinguer",
    "swingueraient": "swinguer",
    "swinguerais": "swinguer",
    "swinguerait": "swinguer",
    "swingueras": "swinguer",
    "swinguerez": "swinguer",
    "swingueriez": "swinguer",
    "swinguerions": "swinguer",
    "swinguerons": "swinguer",
    "swingueront": "swinguer",
    "swingues": "swinguer",
    "swinguez": "swinguer",
    "swinguiez": "swinguer",
    "swinguions": "swinguer",
    "swinguons": "swinguer",
    "swinguâmes": "swinguer",
    "swinguât": "swinguer",
    "swinguâtes": "swinguer",
    "swinguèrent": "swinguer",
    "swingué": "swinguer",
    "swinguée": "swinguer",
    "swinguées": "swinguer",
    "swingués": "swinguer",
    "sybarites": "sybarite",
    "sycomores": "sycomore",
    "sycophantes": "sycophante",
    "syllabes": "syllabe",
    "syllepses": "syllepse",
    "syllogismes": "syllogisme",
    "syllogistiques": "syllogistique",
    "sylphes": "sylphe",
    "sylphides": "sylphide",
    "sylvains": "sylvain",
    "sylvestres": "sylvestre",
    "sylvicoles": "sylvicole",
    "sylviculteurs": "sylviculteur",
    "sylvicultrice": "sylviculteur",
    "sylvicultrices": "sylviculteur",
    "sylvicultures": "sylviculture",
    "symbioses": "symbiose",
    "symbiotes": "symbiote",
    "symboles": "symbole",
    "symboliques": "symbolique",
    "symbolisa": "symboliser",
    "symbolisai": "symboliser",
    "symbolisaient": "symboliser",
    "symbolisais": "symboliser",
    "symbolisait": "symboliser",
    "symbolisant": "symboliser",
    "symbolisas": "symboliser",
    "symbolisasse": "symboliser",
    "symbolisassent": "symboliser",
    "symbolisasses": "symboliser",
    "symbolisassiez": "symboliser",
    "symbolisassions": "symboliser",
    "symbolise": "symboliser",
    "symbolisent": "symboliser",
    "symbolisera": "symboliser",
    "symboliserai": "symboliser",
    "symboliseraient": "symboliser",
    "symboliserais": "symboliser",
    "symboliserait": "symboliser",
    "symboliseras": "symboliser",
    "symboliserez": "symboliser",
    "symboliseriez": "symboliser",
    "symboliserions": "symboliser",
    "symboliserons": "symboliser",
    "symboliseront": "symboliser",
    "symbolises": "symboliser",
    "symbolisez": "symboliser",
    "symbolisiez": "symboliser",
    "symbolisions": "symboliser",
    "symbolismes": "symbolisme",
    "symbolisons": "symboliser",
    "symbolisâmes": "symboliser",
    "symbolisât": "symboliser",
    "symbolisâtes": "symboliser",
    "symbolisèrent": "symboliser",
    "symbolisé": "symboliser",
    "symbolisée": "symboliser",
    "symbolisées": "symboliser",
    "symbolisés": "symboliser",
    "sympas": "sympa",
    "sympathies": "sympathie",
    "sympathiques": "sympathique",
    "sympathisa": "sympathiser",
    "sympathisai": "sympathiser",
    "sympathisaient": "sympathiser",
    "sympathisais": "sympathiser",
    "sympathisait": "sympathiser",
    "sympathisant": "sympathiser",
    "sympathisante": "sympathisant",
    "sympathisantes": "sympathisant",
    "sympathisants": "sympathisant",
    "sympathisas": "sympathiser",
    "sympathisasse": "sympathiser",
    "sympathisassent": "sympathiser",
    "sympathisasses": "sympathiser",
    "sympathisassiez": "sympathiser",
    "sympathisassions": "sympathiser",
    "sympathise": "sympathiser",
    "sympathisent": "sympathiser",
    "sympathisera": "sympathiser",
    "sympathiserai": "sympathiser",
    "sympathiseraient": "sympathiser",
    "sympathiserais": "sympathiser",
    "sympathiserait": "sympathiser",
    "sympathiseras": "sympathiser",
    "sympathiserez": "sympathiser",
    "sympathiseriez": "sympathiser",
    "sympathiserions": "sympathiser",
    "sympathiserons": "sympathiser",
    "sympathiseront": "sympathiser",
    "sympathises": "sympathiser",
    "sympathisez": "sympathiser",
    "sympathisiez": "sympathiser",
    "sympathisions": "sympathiser",
    "sympathisons": "sympathiser",
    "sympathisâmes": "sympathiser",
    "sympathisât": "sympathiser",
    "sympathisâtes": "sympathiser",
    "sympathisèrent": "sympathiser",
    "sympathisé": "sympathiser",
    "symphonies": "symphonie",
    "symphoniques": "symphonique",
    "symphorines": "symphorine",
    "symphyses": "symphyse",
    "symposiums": "symposium",
    "symptomatiques": "symptomatique",
    "symptômes": "symptôme",
    "symétries": "symétrie",
    "symétriques": "symétrique",
    "synagogale": "synagogal",
    "synagogaux": "synagogal",
    "synagogues": "synagogue",
    "synalèphes": "synalèphe",
    "synapses": "synapse",
    "synaptiques": "synaptique",
    "synarchies": "synarchie",
    "synchrones": "synchrone",
    "synchronisa": "synchroniser",
    "synchronisai": "synchroniser",
    "synchronisaient": "synchroniser",
    "synchronisais": "synchroniser",
    "synchronisait": "synchroniser",
    "synchronisant": "synchroniser",
    "synchronisas": "synchroniser",
    "synchronisasse": "synchroniser",
    "synchronisassent": "synchroniser",
    "synchronisasses": "synchroniser",
    "synchronisassiez": "synchroniser",
    "synchronisassions": "synchroniser",
    "synchronise": "synchroniser",
    "synchronisent": "synchroniser",
    "synchronisera": "synchroniser",
    "synchroniserai": "synchroniser",
    "synchroniseraient": "synchroniser",
    "synchroniserais": "synchroniser",
    "synchroniserait": "synchroniser",
    "synchroniseras": "synchroniser",
    "synchroniserez": "synchroniser",
    "synchroniseriez": "synchroniser",
    "synchroniserions": "synchroniser",
    "synchroniserons": "synchroniser",
    "synchroniseront": "synchroniser",
    "synchronises": "synchroniser",
    "synchronisez": "synchroniser",
    "synchronisiez": "synchroniser",
    "synchronisions": "synchroniser",
    "synchronismes": "synchronisme",
    "synchronisons": "synchroniser",
    "synchronisâmes": "synchroniser",
    "synchronisât": "synchroniser",
    "synchronisâtes": "synchroniser",
    "synchronisèrent": "synchroniser",
    "synchronisé": "synchroniser",
    "synchronisée": "synchroniser",
    "synchronisées": "synchroniser",
    "synchronisés": "synchroniser",
    "synchros": "synchro",
    "synchrotrons": "synchrotron",
    "syncinésies": "syncinésie",
    "synclinaux": "synclinal",
    "syncopes": "syncope",
    "syncopé": "syncoper",
    "syncopée": "syncoper",
    "syncopées": "syncopé",
    "syncopés": "syncoper",
    "syncrétismes": "syncrétisme",
    "syndicale": "syndical",
    "syndicales": "syndical",
    "syndicalisations": "syndicalisation",
    "syndicalismes": "syndicalisme",
    "syndicalistes": "syndicaliste",
    "syndications": "syndication",
    "syndicats": "syndicat",
    "syndicaux": "syndical",
    "syndics": "syndic",
    "syndiqua": "syndiquer",
    "syndiquai": "syndiquer",
    "syndiquaient": "syndiquer",
    "syndiquais": "syndiquer",
    "syndiquait": "syndiquer",
    "syndiquant": "syndiquer",
    "syndiquas": "syndiquer",
    "syndiquasse": "syndiquer",
    "syndiquassent": "syndiquer",
    "syndiquasses": "syndiquer",
    "syndiquassiez": "syndiquer",
    "syndiquassions": "syndiquer",
    "syndique": "syndiquer",
    "syndiquent": "syndiquer",
    "syndiquera": "syndiquer",
    "syndiquerai": "syndiquer",
    "syndiqueraient": "syndiquer",
    "syndiquerais": "syndiquer",
    "syndiquerait": "syndiquer",
    "syndiqueras": "syndiquer",
    "syndiquerez": "syndiquer",
    "syndiqueriez": "syndiquer",
    "syndiquerions": "syndiquer",
    "syndiquerons": "syndiquer",
    "syndiqueront": "syndiquer",
    "syndiques": "syndiquer",
    "syndiquez": "syndiquer",
    "syndiquiez": "syndiquer",
    "syndiquions": "syndiquer",
    "syndiquons": "syndiquer",
    "syndiquâmes": "syndiquer",
    "syndiquât": "syndiquer",
    "syndiquâtes": "syndiquer",
    "syndiquèrent": "syndiquer",
    "syndiqué": "syndiquer",
    "syndiquée": "syndiquer",
    "syndiquées": "syndiquer",
    "syndiqués": "syndiquer",
    "syndromes": "syndrome",
    "synecdoques": "synecdoque",
    "synergies": "synergie",
    "synodale": "synodal",
    "synodales": "synodal",
    "synodaux": "synodal",
    "synodes": "synode",
    "synonymes": "synonyme",
    "synoviale": "synovial",
    "synoviales": "synovial",
    "synoviaux": "synovial",
    "synovies": "synovie",
    "syntacticienne": "syntacticien",
    "syntacticiennes": "syntacticien",
    "syntacticiens": "syntacticien",
    "syntagmes": "syntagme",
    "syntaxes": "syntaxe",
    "synthèses": "synthèse",
    "synthés": "synthé",
    "synthétiques": "synthétique",
    "synthétise": "synthétiser",
    "synthétisent": "synthétiser",
    "synthétisera": "synthétiser",
    "synthétiseurs": "synthétiseur",
    "synthétisé": "synthétiser",
    "synthétisée": "synthétiser",
    "synthétisés": "synthétiser",
    "synérèses": "synérèse",
    "syphilitiques": "syphilitique",
    "syriaques": "syriaque",
    "syrienne": "syrien",
    "syriennes": "syrien",
    "syriens": "syrien",
    "syrtes": "syrte",
    "systoles": "systole",
    "systoliques": "systolique",
    "systèmes": "système",
    "systèmes-clés": "systèmes-clé",
    "systématiques": "systématique",
    "systématisations": "systématisation",
    "systématisée": "systématisé",
    "systématisés": "systématisé",
    "systémiques": "systémique",
    "syzygies": "syzygie",
    "sèche": "sécher",
    "sèchent": "sécher",
    "sèches": "sécher",
    "sème": "semer",
    "sèment": "semer",
    "sèmera": "semer",
    "sèmerai": "semer",
    "sèmeraient": "semer",
    "sèmerais": "semer",
    "sèmerait": "semer",
    "sèmeras": "semer",
    "sèmerez": "semer",
    "sèmeriez": "semer",
    "sèmerions": "semer",
    "sèmerons": "semer",
    "sèmeront": "semer",
    "sèmes": "semer",
    "sèves": "sève",
    "sèvre": "sevrer",
    "sèvrent": "sevrer",
    "sèvrera": "sevrer",
    "sèvrerai": "sevrer",
    "sèvreraient": "sevrer",
    "sèvrerais": "sevrer",
    "sèvrerait": "sevrer",
    "sèvreras": "sevrer",
    "sèvrerez": "sevrer",
    "sèvreriez": "sevrer",
    "sèvrerions": "sevrer",
    "sèvrerons": "sevrer",
    "sèvreront": "sevrer",
    "sèvres": "sevrer",
    "séances": "séance",
    "séant": "seoir",
    "séante": "séant",
    "séants": "séant",
    "sébacée": "sébacé",
    "sébacées": "sébacé",
    "sébacés": "sébacé",
    "sébiles": "sébile",
    "séborrhées": "séborrhée",
    "sébums": "sébum",
    "sécables": "sécable",
    "sécante": "sécant",
    "sécantes": "sécante",
    "sécants": "sécant",
    "sécateurs": "sécateur",
    "sécessionnistes": "sécessionniste",
    "sécessions": "sécession",
    "sécha": "sécher",
    "séchages": "séchage",
    "séchai": "sécher",
    "séchaient": "sécher",
    "séchais": "sécher",
    "séchait": "sécher",
    "séchant": "sécher",
    "séchas": "sécher",
    "séchasse": "sécher",
    "séchassent": "sécher",
    "séchasses": "sécher",
    "séchassiez": "sécher",
    "séchassions": "sécher",
    "séchera": "sécher",
    "sécherai": "sécher",
    "sécheraient": "sécher",
    "sécherais": "sécher",
    "sécherait": "sécher",
    "sécheras": "sécher",
    "sécheresses": "sécheresse",
    "sécherez": "sécher",
    "sécheries": "sécherie",
    "sécheriez": "sécher",
    "sécherions": "sécher",
    "sécherons": "sécher",
    "sécheront": "sécher",
    "sécheuse": "sécheur",
    "séchez": "sécher",
    "séchiez": "sécher",
    "séchions": "sécher",
    "séchoirs": "séchoir",
    "séchons": "sécher",
    "séchâmes": "sécher",
    "séchât": "sécher",
    "séchâtes": "sécher",
    "séchèrent": "sécher",
    "séché": "sécher",
    "séchée": "sécher",
    "séchées": "sécher",
    "séchés": "sécher",
    "sécrète": "sécréter",
    "sécrètent": "sécréter",
    "sécrètes": "sécréter",
    "sécréta": "sécréter",
    "sécrétai": "sécréter",
    "sécrétaient": "sécréter",
    "sécrétais": "sécréter",
    "sécrétait": "sécréter",
    "sécrétant": "sécréter",
    "sécrétas": "sécréter",
    "sécrétasse": "sécréter",
    "sécrétassent": "sécréter",
    "sécrétasses": "sécréter",
    "sécrétassiez": "sécréter",
    "sécrétassions": "sécréter",
    "sécrétera": "sécréter",
    "sécréterai": "sécréter",
    "sécréteraient": "sécréter",
    "sécréterais": "sécréter",
    "sécréterait": "sécréter",
    "sécréteras": "sécréter",
    "sécréterez": "sécréter",
    "sécréteriez": "sécréter",
    "sécréterions": "sécréter",
    "sécréterons": "sécréter",
    "sécréteront": "sécréter",
    "sécréteurs": "sécréteur",
    "sécrétez": "sécréter",
    "sécrétiez": "sécréter",
    "sécrétions": "sécrétion",
    "sécrétons": "sécréter",
    "sécrétâmes": "sécréter",
    "sécrétât": "sécréter",
    "sécrétâtes": "sécréter",
    "sécrétèrent": "sécréter",
    "sécrété": "sécréter",
    "sécrétée": "sécréter",
    "sécrétées": "sécréter",
    "sécrétés": "sécréter",
    "séculaires": "séculaire",
    "sécularisée": "sécularisé",
    "sécularisées": "séculariser",
    "sécularisés": "sécularisé",
    "séculiers": "séculier",
    "séculière": "séculier",
    "séculières": "séculier",
    "sécurisa": "sécuriser",
    "sécurisai": "sécuriser",
    "sécurisaient": "sécuriser",
    "sécurisais": "sécuriser",
    "sécurisait": "sécuriser",
    "sécurisant": "sécuriser",
    "sécurisante": "sécurisant",
    "sécurisas": "sécuriser",
    "sécurisasse": "sécuriser",
    "sécurisassent": "sécuriser",
    "sécurisasses": "sécuriser",
    "sécurisassiez": "sécuriser",
    "sécurisassions": "sécuriser",
    "sécurise": "sécuriser",
    "sécurisent": "sécuriser",
    "sécurisera": "sécuriser",
    "sécuriserai": "sécuriser",
    "sécuriseraient": "sécuriser",
    "sécuriserais": "sécuriser",
    "sécuriserait": "sécuriser",
    "sécuriseras": "sécuriser",
    "sécuriserez": "sécuriser",
    "sécuriseriez": "sécuriser",
    "sécuriserions": "sécuriser",
    "sécuriserons": "sécuriser",
    "sécuriseront": "sécuriser",
    "sécurises": "sécuriser",
    "sécurisez": "sécuriser",
    "sécurisiez": "sécuriser",
    "sécurisions": "sécuriser",
    "sécurisons": "sécuriser",
    "sécuristes": "sécuriste",
    "sécurisâmes": "sécuriser",
    "sécurisât": "sécuriser",
    "sécurisâtes": "sécuriser",
    "sécurisèrent": "sécuriser",
    "sécurisé": "sécuriser",
    "sécurisée": "sécuriser",
    "sécurisées": "sécuriser",
    "sécurisés": "sécuriser",
    "sécurités": "sécurité",
    "sédatifs": "sédatif",
    "sédative": "sédatif",
    "sédatives": "sédatif",
    "sédentaires": "sédentaire",
    "sédentarisaient": "sédentariser",
    "sédentarise": "sédentariser",
    "sédimentaires": "sédimentaire",
    "sédimentations": "sédimentation",
    "sédimente": "sédimenter",
    "sédiments": "sédiment",
    "sédimentée": "sédimenter",
    "séditieuse": "séditieux",
    "séditieuses": "séditieux",
    "séditions": "sédition",
    "séducteurs": "séducteur",
    "séductions": "séduction",
    "séductrice": "séducteur",
    "séductrices": "séducteur",
    "séduira": "séduire",
    "séduirai": "séduire",
    "séduiraient": "séduire",
    "séduirais": "séduire",
    "séduirait": "séduire",
    "séduiras": "séduire",
    "séduirez": "séduire",
    "séduiriez": "séduire",
    "séduirions": "séduire",
    "séduirons": "séduire",
    "séduiront": "séduire",
    "séduis": "séduire",
    "séduisaient": "séduire",
    "séduisais": "séduire",
    "séduisait": "séduire",
    "séduisant": "séduire",
    "séduisante": "séduisant",
    "séduisantes": "séduisant",
    "séduisants": "séduisant",
    "séduise": "séduire",
    "séduisent": "séduire",
    "séduises": "séduire",
    "séduisez": "séduire",
    "séduisiez": "séduire",
    "séduisions": "séduire",
    "séduisirent": "séduire",
    "séduisis": "séduire",
    "séduisisse": "séduire",
    "séduisissent": "séduire",
    "séduisisses": "séduire",
    "séduisissiez": "séduire",
    "séduisissions": "séduire",
    "séduisit": "séduire",
    "séduisons": "séduire",
    "séduisîmes": "séduire",
    "séduisît": "séduire",
    "séduisîtes": "séduire",
    "séduit": "séduire",
    "séduite": "séduit",
    "séduites": "séduit",
    "séduits": "séduit",
    "séfarades": "séfarade",
    "ségalas": "ségala",
    "ségrégations": "ségrégation",
    "séguedilles": "séguedille",
    "séguinistes": "séguiniste",
    "séides": "séide",
    "séismale": "séismal",
    "séismales": "séismal",
    "séismaux": "séismal",
    "séismes": "séisme",
    "séismiques": "séismique",
    "séjourna": "séjourner",
    "séjournai": "séjourner",
    "séjournaient": "séjourner",
    "séjournais": "séjourner",
    "séjournait": "séjourner",
    "séjournant": "séjourner",
    "séjournas": "séjourner",
    "séjournasse": "séjourner",
    "séjournassent": "séjourner",
    "séjournasses": "séjourner",
    "séjournassiez": "séjourner",
    "séjournassions": "séjourner",
    "séjourne": "séjourner",
    "séjournent": "séjourner",
    "séjournera": "séjourner",
    "séjournerai": "séjourner",
    "séjourneraient": "séjourner",
    "séjournerais": "séjourner",
    "séjournerait": "séjourner",
    "séjourneras": "séjourner",
    "séjournerez": "séjourner",
    "séjourneriez": "séjourner",
    "séjournerions": "séjourner",
    "séjournerons": "séjourner",
    "séjourneront": "séjourner",
    "séjournes": "séjourner",
    "séjournez": "séjourner",
    "séjourniez": "séjourner",
    "séjournions": "séjourner",
    "séjournons": "séjourner",
    "séjournâmes": "séjourner",
    "séjournât": "séjourner",
    "séjournâtes": "séjourner",
    "séjournèrent": "séjourner",
    "séjourné": "séjourner",
    "séjours": "séjour",
    "sélaginelles": "sélaginelle",
    "sélecte": "sélect",
    "sélectes": "sélect",
    "sélecteurs": "sélecteur",
    "sélectifs": "sélectif",
    "sélectionna": "sélectionner",
    "sélectionnai": "sélectionner",
    "sélectionnaient": "sélectionner",
    "sélectionnais": "sélectionner",
    "sélectionnait": "sélectionner",
    "sélectionnant": "sélectionner",
    "sélectionnas": "sélectionner",
    "sélectionnasse": "sélectionner",
    "sélectionnassent": "sélectionner",
    "sélectionnasses": "sélectionner",
    "sélectionnassiez": "sélectionner",
    "sélectionnassions": "sélectionner",
    "sélectionne": "sélectionner",
    "sélectionnent": "sélectionner",
    "sélectionnera": "sélectionner",
    "sélectionnerai": "sélectionner",
    "sélectionneraient": "sélectionner",
    "sélectionnerais": "sélectionner",
    "sélectionnerait": "sélectionner",
    "sélectionneras": "sélectionner",
    "sélectionnerez": "sélectionner",
    "sélectionneriez": "sélectionner",
    "sélectionnerions": "sélectionner",
    "sélectionnerons": "sélectionner",
    "sélectionneront": "sélectionner",
    "sélectionnes": "sélectionner",
    "sélectionneurs": "sélectionneur",
    "sélectionneuse": "sélectionneur",
    "sélectionneuses": "sélectionneur",
    "sélectionnez": "sélectionner",
    "sélectionniez": "sélectionner",
    "sélectionnions": "sélectionner",
    "sélectionnons": "sélectionner",
    "sélectionnâmes": "sélectionner",
    "sélectionnât": "sélectionner",
    "sélectionnâtes": "sélectionner",
    "sélectionnèrent": "sélectionner",
    "sélectionné": "sélectionner",
    "sélectionnée": "sélectionner",
    "sélectionnées": "sélectionner",
    "sélectionnés": "sélectionner",
    "sélections": "sélection",
    "sélective": "sélectif",
    "sélectives": "sélectif",
    "sélectivités": "sélectivité",
    "sélects": "sélect",
    "sélénites": "sélénite",
    "séléniums": "sélénium",
    "sémantiques": "sémantique",
    "sémaphores": "sémaphore",
    "sémaphoriques": "sémaphorique",
    "sémillante": "sémillant",
    "sémillantes": "sémillant",
    "sémillants": "sémillant",
    "séminaires": "séminaire",
    "séminale": "séminal",
    "séminales": "séminal",
    "séminaristes": "séminariste",
    "séminaux": "séminal",
    "séminoles": "séminole",
    "sémiologies": "sémiologie",
    "sémiotiques": "sémiotique",
    "sémites": "sémite",
    "sémitiques": "sémitique",
    "séméiologies": "séméiologie",
    "sénateurs": "sénateur",
    "sénatoriale": "sénatorial",
    "sénatoriales": "sénatorial",
    "sénatoriaux": "sénatorial",
    "sénatrice": "sénateur",
    "sénats": "sénat",
    "sénatus-consultes": "sénatus-consulte",
    "sénescences": "sénescence",
    "sénescente": "sénescent",
    "sénescentes": "sénescent",
    "sénescents": "sénescent",
    "sénestres": "sénestre",
    "sénevés": "sénevé",
    "séniles": "sénile",
    "sénilités": "sénilité",
    "sénéchaussées": "sénéchaussée",
    "sénéchaux": "sénéchal",
    "sénégalaise": "sénégalais",
    "sénégalaises": "sénégalais",
    "sénés": "séné",
    "sépales": "sépale",
    "sépara": "séparer",
    "séparai": "séparer",
    "séparaient": "séparer",
    "séparais": "séparer",
    "séparait": "séparer",
    "séparant": "séparer",
    "séparas": "séparer",
    "séparasse": "séparer",
    "séparassent": "séparer",
    "séparasses": "séparer",
    "séparassiez": "séparer",
    "séparassions": "séparer",
    "séparations": "séparation",
    "séparatismes": "séparatisme",
    "séparatistes": "séparatiste",
    "séparatrice": "séparateur",
    "sépare": "séparer",
    "séparent": "séparer",
    "séparera": "séparer",
    "séparerai": "séparer",
    "sépareraient": "séparer",
    "séparerais": "séparer",
    "séparerait": "séparer",
    "sépareras": "séparer",
    "séparerez": "séparer",
    "sépareriez": "séparer",
    "séparerions": "séparer",
    "séparerons": "séparer",
    "sépareront": "séparer",
    "sépares": "séparer",
    "séparez": "séparer",
    "sépariez": "séparer",
    "séparions": "séparer",
    "séparons": "séparer",
    "séparâmes": "séparer",
    "séparât": "séparer",
    "séparâtes": "séparer",
    "séparèrent": "séparer",
    "séparé": "séparer",
    "séparée": "séparer",
    "séparées": "séparer",
    "séparés": "séparer",
    "sépharades": "sépharade",
    "sépias": "sépia",
    "sépioles": "sépiole",
    "sépulcrale": "sépulcral",
    "sépulcrales": "sépulcral",
    "sépulcraux": "sépulcral",
    "sépulcres": "sépulcre",
    "sépultures": "sépulture",
    "séquanaise": "séquanais",
    "séquelles": "séquelle",
    "séquences": "séquence",
    "séquentielle": "séquentiel",
    "séquentielles": "séquentiel",
    "séquentiels": "séquentiel",
    "séquençages": "séquençage",
    "séquestra": "séquestrer",
    "séquestrai": "séquestrer",
    "séquestraient": "séquestrer",
    "séquestrais": "séquestrer",
    "séquestrait": "séquestrer",
    "séquestrant": "séquestrer",
    "séquestras": "séquestrer",
    "séquestrasse": "séquestrer",
    "séquestrassent": "séquestrer",
    "séquestrasses": "séquestrer",
    "séquestrassiez": "séquestrer",
    "séquestrassions": "séquestrer",
    "séquestrations": "séquestration",
    "séquestre": "séquestrer",
    "séquestrent": "séquestrer",
    "séquestrera": "séquestrer",
    "séquestrerai": "séquestrer",
    "séquestreraient": "séquestrer",
    "séquestrerais": "séquestrer",
    "séquestrerait": "séquestrer",
    "séquestreras": "séquestrer",
    "séquestrerez": "séquestrer",
    "séquestreriez": "séquestrer",
    "séquestrerions": "séquestrer",
    "séquestrerons": "séquestrer",
    "séquestreront": "séquestrer",
    "séquestres": "séquestrer",
    "séquestrez": "séquestrer",
    "séquestriez": "séquestrer",
    "séquestrions": "séquestrer",
    "séquestrons": "séquestrer",
    "séquestrâmes": "séquestrer",
    "séquestrât": "séquestrer",
    "séquestrâtes": "séquestrer",
    "séquestrèrent": "séquestrer",
    "séquestré": "séquestrer",
    "séquestrée": "séquestrer",
    "séquestrées": "séquestrer",
    "séquestrés": "séquestrer",
    "séquoias": "séquoia",
    "séracs": "sérac",
    "sérails": "sérail",
    "séraphins": "séraphin",
    "séraphiques": "séraphique",
    "séreuse": "séreux",
    "séreuses": "séreux",
    "sériant": "sérier",
    "séricicoles": "séricicole",
    "sérielle": "sériel",
    "sérielles": "sériel",
    "sériels": "sériel",
    "séries": "série",
    "sérieuse": "sérieux",
    "sérieuses": "sérieux",
    "sérigraphies": "sérigraphie",
    "sériques": "sérique",
    "séronégatifs": "séronégatif",
    "séronégative": "séronégatif",
    "séropositifs": "séropositif",
    "séropositive": "séropositif",
    "séropositives": "séropositif",
    "séropositivités": "séropositivité",
    "sérosités": "sérosité",
    "sérotonines": "sérotonine",
    "sérums": "sérum",
    "sérénades": "sérénade",
    "sérénités": "sérénité",
    "sésames": "sésame",
    "sésamoïdes": "sésamoïde",
    "sétons": "séton",
    "sévi": "sévir",
    "sévice": "sévices",
    "sévillane": "sévillan",
    "sévira": "sévir",
    "sévirai": "sévir",
    "séviraient": "sévir",
    "sévirais": "sévir",
    "sévirait": "sévir",
    "séviras": "sévir",
    "sévirent": "sévir",
    "sévirez": "sévir",
    "séviriez": "sévir",
    "sévirions": "sévir",
    "sévirons": "sévir",
    "séviront": "sévir",
    "sévis": "sévir",
    "sévissaient": "sévir",
    "sévissais": "sévir",
    "sévissait": "sévir",
    "sévissant": "sévir",
    "sévisse": "sévir",
    "sévissent": "sévir",
    "sévisses": "sévir",
    "sévissez": "sévir",
    "sévissiez": "sévir",
    "sévissions": "sévir",
    "sévissons": "sévir",
    "sévit": "sévir",
    "sévriennes": "sévrienne",
    "sévères": "sévère",
    "sévérisations": "sévérisation",
    "sévérités": "sévérité",
    "sévîmes": "sévir",
    "sévît": "sévir",
    "sévîtes": "sévir",
    "sûmes": "savoir",
    "sûre": "sûr",
    "sûres": "sûr",
    "sûretés": "sûreté",
    "sûrs": "sûr",
    "sût": "savoir",
    "sûtes": "savoir",
    "t'": "t",
    "t-shirts": "t-shirt",
    "ta": "ton",
    "tabacs": "tabac",
    "tabagies": "tabagie",
    "tabagismes": "tabagisme",
    "tabassages": "tabassage",
    "tabassaient": "tabasser",
    "tabassais": "tabasser",
    "tabassait": "tabasser",
    "tabassant": "tabasser",
    "tabasse": "tabasser",
    "tabassent": "tabasser",
    "tabassera": "tabasser",
    "tabasseraient": "tabasser",
    "tabasserais": "tabasser",
    "tabasses": "tabasser",
    "tabassez": "tabasser",
    "tabassons": "tabasser",
    "tabassèrent": "tabasser",
    "tabassé": "tabasser",
    "tabassée": "tabasser",
    "tabassés": "tabasser",
    "tabatières": "tabatière",
    "tabellions": "tabellion",
    "tabernacles": "tabernacle",
    "tabla": "tabler",
    "tablai": "tabler",
    "tablaient": "tabler",
    "tablais": "tabler",
    "tablait": "tabler",
    "tablant": "tabler",
    "tablas": "tabler",
    "tablasse": "tabler",
    "tablassent": "tabler",
    "tablasses": "tabler",
    "tablassiez": "tabler",
    "tablassions": "tabler",
    "tablatures": "tablature",
    "table": "tabler",
    "tableautins": "tableautin",
    "tableaux": "tableau",
    "tablent": "tabler",
    "tablera": "tabler",
    "tablerai": "tabler",
    "tableraient": "tabler",
    "tablerais": "tabler",
    "tablerait": "tabler",
    "tableras": "tabler",
    "tablerez": "tabler",
    "tableriez": "tabler",
    "tablerions": "tabler",
    "tablerons": "tabler",
    "tableront": "tabler",
    "tables": "tabler",
    "tables-coiffeuses": "table-coiffeuse",
    "tabletteries": "tabletterie",
    "tablettes": "tablette",
    "tablez": "tabler",
    "tabliers": "tablier",
    "tabliez": "tabler",
    "tablions": "tabler",
    "tablons": "tabler",
    "tabloïdes": "tabloïde",
    "tabloïds": "tabloïd",
    "tablâmes": "tabler",
    "tablât": "tabler",
    "tablâtes": "tabler",
    "tablèrent": "tabler",
    "tablé": "tabler",
    "tablées": "tabler",
    "taborites": "taborite",
    "tabors": "tabor",
    "taboue": "tabouer",
    "taboues": "tabou",
    "tabourets": "tabouret",
    "tabous": "tabou",
    "tabula": "tabuler",
    "tabulateurs": "tabulateur",
    "tabulations": "tabulation",
    "tabétiques": "tabétique",
    "tacauds": "tacaud",
    "tacha": "tacher",
    "tachai": "tacher",
    "tachaient": "tacher",
    "tachais": "tacher",
    "tachait": "tacher",
    "tachant": "tacher",
    "tachas": "tacher",
    "tachasse": "tacher",
    "tachassent": "tacher",
    "tachasses": "tacher",
    "tachassiez": "tacher",
    "tachassions": "tacher",
    "tache": "tacher",
    "tachent": "tacher",
    "tachera": "tacher",
    "tacherai": "tacher",
    "tacheraient": "tacher",
    "tacherais": "tacher",
    "tacherait": "tacher",
    "tacheras": "tacher",
    "tacherez": "tacher",
    "tacheriez": "tacher",
    "tacherions": "tacher",
    "tacherons": "tacher",
    "tacheront": "tacher",
    "taches": "tacher",
    "tacheta": "tacheter",
    "tachetai": "tacheter",
    "tachetaient": "tacheter",
    "tachetais": "tacheter",
    "tachetait": "tacheter",
    "tachetant": "tacheter",
    "tachetas": "tacheter",
    "tachetasse": "tacheter",
    "tachetassent": "tacheter",
    "tachetasses": "tacheter",
    "tachetassiez": "tacheter",
    "tachetassions": "tacheter",
    "tachetez": "tacheter",
    "tachetiez": "tacheter",
    "tachetions": "tacheter",
    "tachetons": "tacheter",
    "tachette": "tacheter",
    "tachettent": "tacheter",
    "tachettera": "tacheter",
    "tachetterai": "tacheter",
    "tachetteraient": "tacheter",
    "tachetterais": "tacheter",
    "tachetterait": "tacheter",
    "tachetteras": "tacheter",
    "tachetterez": "tacheter",
    "tachetteriez": "tacheter",
    "tachetterions": "tacheter",
    "tachetterons": "tacheter",
    "tachetteront": "tacheter",
    "tachettes": "tacheter",
    "tachetures": "tacheture",
    "tachetâmes": "tacheter",
    "tachetât": "tacheter",
    "tachetâtes": "tacheter",
    "tachetèrent": "tacheter",
    "tacheté": "tacheter",
    "tachetée": "tacheter",
    "tachetées": "tacheter",
    "tachetés": "tacheter",
    "tachez": "tacher",
    "tachiez": "tacher",
    "tachions": "tacher",
    "tachons": "tacher",
    "tachycarde": "tachycarder",
    "tachycardies": "tachycardie",
    "tachygraphes": "tachygraphe",
    "tachyons": "tachyon",
    "tachâmes": "tacher",
    "tachât": "tacher",
    "tachâtes": "tacher",
    "tachèrent": "tacher",
    "taché": "tacher",
    "tachée": "tacher",
    "tachées": "tacher",
    "tachés": "tacher",
    "tacites": "tacite",
    "taciturnes": "taciturne",
    "tacos": "taco",
    "tacots": "tacot",
    "tacs": "tac",
    "tacticienne": "tacticien",
    "tacticiennes": "tacticien",
    "tacticiens": "tacticien",
    "tactiles": "tactile",
    "tactiques": "tactique",
    "tacts": "tact",
    "tadornes": "tadorne",
    "taels": "tael",
    "taenias": "taenia",
    "taffes": "taffe",
    "tafias": "tafia",
    "tafs": "taf",
    "tagliatelles": "tagliatelle",
    "taguais": "taguer",
    "tague": "taguer",
    "tagueurs": "tagueur",
    "tahitienne": "tahitien",
    "tahitiennes": "tahitien",
    "tahitiens": "tahitien",
    "taies": "taie",
    "taifas": "taifa",
    "tailla": "tailler",
    "taillables": "taillable",
    "taillada": "taillader",
    "tailladait": "taillader",
    "tailladant": "taillader",
    "taillade": "taillader",
    "tailladent": "taillader",
    "tailladez": "taillader",
    "tailladé": "taillader",
    "tailladée": "taillader",
    "tailladées": "taillader",
    "tailladés": "taillader",
    "taillai": "tailler",
    "taillaient": "tailler",
    "taillais": "tailler",
    "taillait": "tailler",
    "taillant": "tailler",
    "taillants": "taillant",
    "taillas": "tailler",
    "taillasse": "tailler",
    "taillassent": "tailler",
    "taillasses": "tailler",
    "taillassiez": "tailler",
    "taillassions": "tailler",
    "taille": "tailler",
    "taille-crayons": "taille-crayon",
    "taille-haies": "taille-haie",
    "taillent": "tailler",
    "taillera": "tailler",
    "taillerai": "tailler",
    "tailleraient": "tailler",
    "taillerais": "tailler",
    "taillerait": "tailler",
    "tailleras": "tailler",
    "taillerez": "tailler",
    "tailleriez": "tailler",
    "taillerions": "tailler",
    "taillerons": "tailler",
    "tailleront": "tailler",
    "tailles": "tailler",
    "tailles-douces": "taille-douce",
    "tailleurs": "tailleur",
    "taillez": "tailler",
    "tailliez": "tailler",
    "taillions": "tailler",
    "tailloirs": "tailloir",
    "taillons": "taillon",
    "taillâmes": "tailler",
    "taillât": "tailler",
    "taillâtes": "tailler",
    "taillèrent": "tailler",
    "taillé": "tailler",
    "taillée": "tailler",
    "taillées": "tailler",
    "taillés": "tailler",
    "tains": "tain",
    "taira": "taire",
    "tairai": "taire",
    "tairaient": "taire",
    "tairais": "taire",
    "tairait": "taire",
    "tairas": "taire",
    "tairez": "taire",
    "tairiez": "taire",
    "tairions": "taire",
    "tairons": "taire",
    "tairont": "taire",
    "tais": "taire",
    "taisaient": "taire",
    "taisais": "taire",
    "taisait": "taire",
    "taisant": "taire",
    "taise": "taire",
    "taisent": "taire",
    "taises": "taire",
    "taisez": "taire",
    "taisiez": "taire",
    "taisions": "taire",
    "taisons": "taire",
    "tait": "taire",
    "taiwanaise": "taiwanais",
    "taiwanaises": "taiwanais",
    "tajines": "tajine",
    "talait": "taler",
    "talas": "tala",
    "talbins": "talbin",
    "talcs": "talc",
    "tale": "taler",
    "talent": "taler",
    "talents": "talent",
    "talentueuse": "talentueux",
    "talentueuses": "talentueux",
    "taleths": "taleth",
    "talibans": "taliban",
    "talions": "talion",
    "talismans": "talisman",
    "talk-shows": "talk-show",
    "talkie-walkies": "talkie-walkie",
    "talkies": "talkie",
    "talkies-walkies": "talkie-walkie",
    "talla": "taller",
    "tallai": "taller",
    "tallaient": "taller",
    "tallais": "taller",
    "tallait": "taller",
    "tallant": "taller",
    "tallas": "taller",
    "tallasse": "taller",
    "tallassent": "taller",
    "tallasses": "taller",
    "tallassiez": "taller",
    "tallassions": "taller",
    "talle": "taller",
    "tallent": "taller",
    "tallera": "taller",
    "tallerai": "taller",
    "talleraient": "taller",
    "tallerais": "taller",
    "tallerait": "taller",
    "talleras": "taller",
    "tallerez": "taller",
    "talleriez": "taller",
    "tallerions": "taller",
    "tallerons": "taller",
    "talleront": "taller",
    "talles": "taller",
    "tallez": "taller",
    "talliez": "taller",
    "tallions": "taller",
    "tallons": "taller",
    "tallâmes": "taller",
    "tallât": "taller",
    "tallâtes": "taller",
    "tallèrent": "taller",
    "tallé": "taller",
    "tallée": "taller",
    "tallées": "taller",
    "tallés": "taller",
    "talmudiques": "talmudique",
    "talmudistes": "talmudiste",
    "talochaient": "talocher",
    "talochait": "talocher",
    "taloche": "talocher",
    "taloches": "taloche",
    "talonna": "talonner",
    "talonnades": "talonnade",
    "talonnai": "talonner",
    "talonnaient": "talonner",
    "talonnais": "talonner",
    "talonnait": "talonner",
    "talonnant": "talonner",
    "talonnas": "talonner",
    "talonnasse": "talonner",
    "talonnassent": "talonner",
    "talonnasses": "talonner",
    "talonnassiez": "talonner",
    "talonnassions": "talonner",
    "talonne": "talonner",
    "talonnent": "talonner",
    "talonnera": "talonner",
    "talonnerai": "talonner",
    "talonneraient": "talonner",
    "talonnerais": "talonner",
    "talonnerait": "talonner",
    "talonneras": "talonner",
    "talonnerez": "talonner",
    "talonneriez": "talonner",
    "talonnerions": "talonner",
    "talonnerons": "talonner",
    "talonneront": "talonner",
    "talonnes": "talonner",
    "talonnettes": "talonnette",
    "talonnez": "talonner",
    "talonniez": "talonner",
    "talonnions": "talonner",
    "talonnons": "talonner",
    "talonnâmes": "talonner",
    "talonnât": "talonner",
    "talonnâtes": "talonner",
    "talonnèrent": "talonner",
    "talonné": "talonner",
    "talonnée": "talonner",
    "talonnées": "talonner",
    "talonnés": "talonner",
    "talons": "talon",
    "talqua": "talquer",
    "talquai": "talquer",
    "talquaient": "talquer",
    "talquais": "talquer",
    "talquait": "talquer",
    "talquant": "talquer",
    "talquas": "talquer",
    "talquasse": "talquer",
    "talquassent": "talquer",
    "talquasses": "talquer",
    "talquassiez": "talquer",
    "talquassions": "talquer",
    "talque": "talquer",
    "talquent": "talquer",
    "talquera": "talquer",
    "talquerai": "talquer",
    "talqueraient": "talquer",
    "talquerais": "talquer",
    "talquerait": "talquer",
    "talqueras": "talquer",
    "talquerez": "talquer",
    "talqueriez": "talquer",
    "talquerions": "talquer",
    "talquerons": "talquer",
    "talqueront": "talquer",
    "talques": "talquer",
    "talquez": "talquer",
    "talquiez": "talquer",
    "talquions": "talquer",
    "talquons": "talquer",
    "talquâmes": "talquer",
    "talquât": "talquer",
    "talquâtes": "talquer",
    "talquèrent": "talquer",
    "talqué": "talquer",
    "talquée": "talquer",
    "talquées": "talquer",
    "talqués": "talquer",
    "talures": "talure",
    "talwegs": "talweg",
    "talée": "taler",
    "talées": "talé",
    "talés": "talé",
    "tam-tams": "tam-tam",
    "tamanoirs": "tamanoir",
    "tamariniers": "tamarinier",
    "tamarins": "tamarin",
    "tambouilles": "tambouille",
    "tambourina": "tambouriner",
    "tambourinai": "tambouriner",
    "tambourinaient": "tambouriner",
    "tambourinaires": "tambourinaire",
    "tambourinais": "tambouriner",
    "tambourinait": "tambouriner",
    "tambourinant": "tambouriner",
    "tambourinas": "tambouriner",
    "tambourinasse": "tambouriner",
    "tambourinassent": "tambouriner",
    "tambourinasses": "tambouriner",
    "tambourinassiez": "tambouriner",
    "tambourinassions": "tambouriner",
    "tambourine": "tambouriner",
    "tambourinent": "tambouriner",
    "tambourinera": "tambouriner",
    "tambourinerai": "tambouriner",
    "tambourineraient": "tambouriner",
    "tambourinerais": "tambouriner",
    "tambourinerait": "tambouriner",
    "tambourineras": "tambouriner",
    "tambourinerez": "tambouriner",
    "tambourineriez": "tambouriner",
    "tambourinerions": "tambouriner",
    "tambourinerons": "tambouriner",
    "tambourineront": "tambouriner",
    "tambourines": "tambouriner",
    "tambourinez": "tambouriner",
    "tambouriniez": "tambouriner",
    "tambourinions": "tambouriner",
    "tambourinons": "tambouriner",
    "tambourins": "tambourin",
    "tambourinâmes": "tambouriner",
    "tambourinât": "tambouriner",
    "tambourinâtes": "tambouriner",
    "tambourinèrent": "tambouriner",
    "tambouriné": "tambouriner",
    "tambourinée": "tambouriner",
    "tambourinées": "tambouriner",
    "tambourinés": "tambouriner",
    "tambours": "tambour",
    "tambours-majors": "tambour-major",
    "tamiers": "tamier",
    "tamisa": "tamiser",
    "tamisai": "tamiser",
    "tamisaient": "tamiser",
    "tamisais": "tamiser",
    "tamisait": "tamiser",
    "tamisant": "tamiser",
    "tamisas": "tamiser",
    "tamisasse": "tamiser",
    "tamisassent": "tamiser",
    "tamisasses": "tamiser",
    "tamisassiez": "tamiser",
    "tamisassions": "tamiser",
    "tamise": "tamiser",
    "tamisent": "tamiser",
    "tamisera": "tamiser",
    "tamiserai": "tamiser",
    "tamiseraient": "tamiser",
    "tamiserais": "tamiser",
    "tamiserait": "tamiser",
    "tamiseras": "tamiser",
    "tamiserez": "tamiser",
    "tamiseriez": "tamiser",
    "tamiserions": "tamiser",
    "tamiserons": "tamiser",
    "tamiseront": "tamiser",
    "tamises": "tamiser",
    "tamisez": "tamiser",
    "tamisiez": "tamiser",
    "tamisions": "tamiser",
    "tamisons": "tamiser",
    "tamisâmes": "tamiser",
    "tamisât": "tamiser",
    "tamisâtes": "tamiser",
    "tamisèrent": "tamiser",
    "tamisé": "tamiser",
    "tamisée": "tamiser",
    "tamisées": "tamiser",
    "tamisés": "tamiser",
    "tamouls": "tamoul",
    "tampicos": "tampico",
    "tamponna": "tamponner",
    "tamponnages": "tamponnage",
    "tamponnai": "tamponner",
    "tamponnaient": "tamponner",
    "tamponnais": "tamponner",
    "tamponnait": "tamponner",
    "tamponnant": "tamponner",
    "tamponnas": "tamponner",
    "tamponnasse": "tamponner",
    "tamponnassent": "tamponner",
    "tamponnasses": "tamponner",
    "tamponnassiez": "tamponner",
    "tamponnassions": "tamponner",
    "tamponne": "tamponner",
    "tamponnent": "tamponner",
    "tamponnera": "tamponner",
    "tamponnerai": "tamponner",
    "tamponneraient": "tamponner",
    "tamponnerais": "tamponner",
    "tamponnerait": "tamponner",
    "tamponneras": "tamponner",
    "tamponnerez": "tamponner",
    "tamponneriez": "tamponner",
    "tamponnerions": "tamponner",
    "tamponnerons": "tamponner",
    "tamponneront": "tamponner",
    "tamponnes": "tamponner",
    "tamponneuse": "tamponneur",
    "tamponneuses": "tamponneur",
    "tamponnez": "tamponner",
    "tamponniez": "tamponner",
    "tamponnions": "tamponner",
    "tamponnoirs": "tamponnoir",
    "tamponnons": "tamponner",
    "tamponnâmes": "tamponner",
    "tamponnât": "tamponner",
    "tamponnâtes": "tamponner",
    "tamponnèrent": "tamponner",
    "tamponné": "tamponner",
    "tamponnée": "tamponner",
    "tamponnées": "tamponner",
    "tamponnés": "tamponner",
    "tampons": "tampon",
    "tams-tams": "tams-tam",
    "tan-sads": "tan-sad",
    "tance": "tancer",
    "tancent": "tancer",
    "tancera": "tancer",
    "tancerai": "tancer",
    "tanceraient": "tancer",
    "tancerais": "tancer",
    "tancerait": "tancer",
    "tanceras": "tancer",
    "tancerez": "tancer",
    "tanceriez": "tancer",
    "tancerions": "tancer",
    "tancerons": "tancer",
    "tanceront": "tancer",
    "tances": "tancer",
    "tancez": "tancer",
    "tanches": "tanche",
    "tanciez": "tancer",
    "tancions": "tancer",
    "tancèrent": "tancer",
    "tancé": "tancer",
    "tancée": "tancer",
    "tancées": "tancer",
    "tancés": "tancer",
    "tandems": "tandem",
    "tangages": "tangage",
    "tangaras": "tangara",
    "tangente": "tangent",
    "tangentes": "tangente",
    "tangentielle": "tangentiel",
    "tangentielles": "tangentiel",
    "tangentiels": "tangentiel",
    "tangents": "tangent",
    "tangibles": "tangible",
    "tangos": "tango",
    "tangua": "tanguer",
    "tanguai": "tanguer",
    "tanguaient": "tanguer",
    "tanguais": "tanguer",
    "tanguait": "tanguer",
    "tanguant": "tanguer",
    "tanguas": "tanguer",
    "tanguasse": "tanguer",
    "tanguassent": "tanguer",
    "tanguasses": "tanguer",
    "tanguassiez": "tanguer",
    "tanguassions": "tanguer",
    "tangue": "tanguer",
    "tanguent": "tanguer",
    "tanguera": "tanguer",
    "tanguerai": "tanguer",
    "tangueraient": "tanguer",
    "tanguerais": "tanguer",
    "tanguerait": "tanguer",
    "tangueras": "tanguer",
    "tanguerez": "tanguer",
    "tangueriez": "tanguer",
    "tanguerions": "tanguer",
    "tanguerons": "tanguer",
    "tangueront": "tanguer",
    "tangues": "tanguer",
    "tanguez": "tanguer",
    "tanguiez": "tanguer",
    "tanguions": "tanguer",
    "tanguons": "tanguer",
    "tanguâmes": "tanguer",
    "tanguât": "tanguer",
    "tanguâtes": "tanguer",
    "tanguèrent": "tanguer",
    "tangué": "tanguer",
    "tanins": "tanin",
    "tanières": "tanière",
    "tankers": "tanker",
    "tankistes": "tankiste",
    "tanks": "tank",
    "tanna": "tanner",
    "tannages": "tannage",
    "tannai": "tanner",
    "tannaient": "tanner",
    "tannais": "tanner",
    "tannait": "tanner",
    "tannant": "tanner",
    "tannante": "tannant",
    "tannantes": "tannant",
    "tannas": "tanner",
    "tannasse": "tanner",
    "tannassent": "tanner",
    "tannasses": "tanner",
    "tannassiez": "tanner",
    "tannassions": "tanner",
    "tanne": "tanner",
    "tannent": "tanner",
    "tannera": "tanner",
    "tannerai": "tanner",
    "tanneraient": "tanner",
    "tannerais": "tanner",
    "tannerait": "tanner",
    "tanneras": "tanner",
    "tannerez": "tanner",
    "tanneries": "tannerie",
    "tanneriez": "tanner",
    "tannerions": "tanner",
    "tannerons": "tanner",
    "tanneront": "tanner",
    "tannes": "tanner",
    "tanneurs": "tanneur",
    "tannez": "tanner",
    "tanniez": "tanner",
    "tannins": "tannin",
    "tannions": "tanner",
    "tannons": "tanner",
    "tannâmes": "tanner",
    "tannât": "tanner",
    "tannâtes": "tanner",
    "tannèrent": "tanner",
    "tanné": "tanner",
    "tannée": "tanner",
    "tannées": "tanner",
    "tannés": "tanner",
    "tans": "tan",
    "tantes": "tante",
    "tantines": "tantine",
    "tantinets": "tantinet",
    "tantièmes": "tantième",
    "tantouses": "tantouse",
    "tantouzes": "tantouze",
    "tantriques": "tantrique",
    "tança": "tancer",
    "tançai": "tancer",
    "tançaient": "tancer",
    "tançais": "tancer",
    "tançait": "tancer",
    "tançant": "tancer",
    "tanças": "tancer",
    "tançasse": "tancer",
    "tançassent": "tancer",
    "tançasses": "tancer",
    "tançassiez": "tancer",
    "tançassions": "tancer",
    "tançons": "tancer",
    "tançâmes": "tancer",
    "tançât": "tancer",
    "tançâtes": "tancer",
    "taons": "taon",
    "taoïsmes": "taoïsme",
    "taoïstes": "taoïste",
    "tapa": "taper",
    "tapageait": "tapager",
    "tapages": "tapage",
    "tapageurs": "tapageur",
    "tapageuse": "tapageur",
    "tapageuses": "tapageur",
    "tapai": "taper",
    "tapaient": "taper",
    "tapais": "taper",
    "tapait": "taper",
    "tapant": "taper",
    "tapante": "tapant",
    "tapantes": "tapant",
    "tapants": "tapant",
    "tapas": "taper",
    "tapasse": "taper",
    "tapassent": "taper",
    "tapasses": "taper",
    "tapassiez": "taper",
    "tapassions": "taper",
    "tape": "taper",
    "tapeculs": "tapecul",
    "tapements": "tapement",
    "tapenades": "tapenade",
    "tapent": "taper",
    "tapera": "taper",
    "taperai": "taper",
    "taperaient": "taper",
    "taperais": "taper",
    "taperait": "taper",
    "taperas": "taper",
    "taperez": "taper",
    "taperiez": "taper",
    "taperions": "taper",
    "taperons": "taper",
    "taperont": "taper",
    "tapes": "taper",
    "tapettes": "tapette",
    "tapeurs": "tapeur",
    "tapeuses": "tapeur",
    "tapez": "taper",
    "tapi": "tapir",
    "tapie": "tapir",
    "tapies": "tapir",
    "tapiez": "taper",
    "tapinaient": "tapiner",
    "tapinais": "tapiner",
    "tapinait": "tapiner",
    "tapinant": "tapiner",
    "tapine": "tapiner",
    "tapinent": "tapiner",
    "tapinera": "tapiner",
    "tapinerai": "tapiner",
    "tapinerais": "tapiner",
    "tapines": "tapiner",
    "tapineuse": "tapineur",
    "tapineuses": "tapineur",
    "tapins": "tapin",
    "tapiné": "tapiner",
    "tapinée": "tapiner",
    "tapiocas": "tapioca",
    "tapions": "taper",
    "tapira": "tapir",
    "tapirai": "tapir",
    "tapiraient": "tapir",
    "tapirais": "tapir",
    "tapirait": "tapir",
    "tapiras": "tapir",
    "tapirent": "tapir",
    "tapirez": "tapir",
    "tapiriez": "tapir",
    "tapirions": "tapir",
    "tapirons": "tapir",
    "tapiront": "tapir",
    "tapirs": "tapir",
    "tapis": "tapir",
    "tapis-brosses": "tapis-brosse",
    "tapissa": "tapisser",
    "tapissai": "tapisser",
    "tapissaient": "tapisser",
    "tapissais": "tapisser",
    "tapissait": "tapisser",
    "tapissant": "tapisser",
    "tapissas": "tapisser",
    "tapissasse": "tapisser",
    "tapissassent": "tapisser",
    "tapissasses": "tapisser",
    "tapissassiez": "tapisser",
    "tapissassions": "tapisser",
    "tapisse": "tapisser",
    "tapissent": "tapisser",
    "tapissera": "tapisser",
    "tapisserai": "tapisser",
    "tapisseraient": "tapisser",
    "tapisserais": "tapisser",
    "tapisserait": "tapisser",
    "tapisseras": "tapisser",
    "tapisserez": "tapisser",
    "tapisseries": "tapisserie",
    "tapisseriez": "tapisser",
    "tapisserions": "tapisser",
    "tapisserons": "tapisser",
    "tapisseront": "tapisser",
    "tapisses": "tapisser",
    "tapissez": "tapisser",
    "tapissiers": "tapissier",
    "tapissiez": "tapisser",
    "tapissions": "tapisser",
    "tapissière": "tapissier",
    "tapissons": "tapisser",
    "tapissâmes": "tapisser",
    "tapissât": "tapisser",
    "tapissâtes": "tapisser",
    "tapissèrent": "tapisser",
    "tapissé": "tapisser",
    "tapissée": "tapisser",
    "tapissées": "tapisser",
    "tapissés": "tapisser",
    "tapit": "tapir",
    "tapons": "tapon",
    "tapota": "tapoter",
    "tapotai": "tapoter",
    "tapotaient": "tapoter",
    "tapotais": "tapoter",
    "tapotait": "tapoter",
    "tapotant": "tapoter",
    "tapotas": "tapoter",
    "tapotasse": "tapoter",
    "tapotassent": "tapoter",
    "tapotasses": "tapoter",
    "tapotassiez": "tapoter",
    "tapotassions": "tapoter",
    "tapote": "tapoter",
    "tapotements": "tapotement",
    "tapotent": "tapoter",
    "tapotera": "tapoter",
    "tapoterai": "tapoter",
    "tapoteraient": "tapoter",
    "tapoterais": "tapoter",
    "tapoterait": "tapoter",
    "tapoteras": "tapoter",
    "tapoterez": "tapoter",
    "tapoteriez": "tapoter",
    "tapoterions": "tapoter",
    "tapoterons": "tapoter",
    "tapoteront": "tapoter",
    "tapotes": "tapoter",
    "tapotez": "tapoter",
    "tapotiez": "tapoter",
    "tapotions": "tapoter",
    "tapotons": "tapoter",
    "tapotâmes": "tapoter",
    "tapotât": "tapoter",
    "tapotâtes": "tapoter",
    "tapotèrent": "tapoter",
    "tapoté": "tapoter",
    "tapotée": "tapoter",
    "tapotées": "tapoter",
    "tapotés": "tapoter",
    "tapâmes": "taper",
    "tapât": "taper",
    "tapâtes": "taper",
    "tapèrent": "taper",
    "tapé": "taper",
    "tapée": "taper",
    "tapées": "taper",
    "tapés": "taper",
    "tapîmes": "tapir",
    "tapît": "tapir",
    "tapîtes": "tapir",
    "taqua": "taquer",
    "taquai": "taquer",
    "taquaient": "taquer",
    "taquais": "taquer",
    "taquait": "taquer",
    "taquant": "taquer",
    "taquas": "taquer",
    "taquasse": "taquer",
    "taquassent": "taquer",
    "taquasses": "taquer",
    "taquassiez": "taquer",
    "taquassions": "taquer",
    "taque": "taquer",
    "taquent": "taquer",
    "taquera": "taquer",
    "taquerai": "taquer",
    "taqueraient": "taquer",
    "taquerais": "taquer",
    "taquerait": "taquer",
    "taqueras": "taquer",
    "taquerez": "taquer",
    "taqueriez": "taquer",
    "taquerions": "taquer",
    "taquerons": "taquer",
    "taqueront": "taquer",
    "taques": "taquer",
    "taquets": "taquet",
    "taquez": "taquer",
    "taquiez": "taquer",
    "taquina": "taquiner",
    "taquinai": "taquiner",
    "taquinaient": "taquiner",
    "taquinais": "taquiner",
    "taquinait": "taquiner",
    "taquinant": "taquiner",
    "taquinas": "taquiner",
    "taquinasse": "taquiner",
    "taquinassent": "taquiner",
    "taquinasses": "taquiner",
    "taquinassiez": "taquiner",
    "taquinassions": "taquiner",
    "taquine": "taquiner",
    "taquinent": "taquiner",
    "taquinera": "taquiner",
    "taquinerai": "taquiner",
    "taquineraient": "taquiner",
    "taquinerais": "taquiner",
    "taquinerait": "taquiner",
    "taquineras": "taquiner",
    "taquinerez": "taquiner",
    "taquineries": "taquinerie",
    "taquineriez": "taquiner",
    "taquinerions": "taquiner",
    "taquinerons": "taquiner",
    "taquineront": "taquiner",
    "taquines": "taquiner",
    "taquinez": "taquiner",
    "taquiniez": "taquiner",
    "taquinions": "taquiner",
    "taquinons": "taquiner",
    "taquins": "taquin",
    "taquinâmes": "taquiner",
    "taquinât": "taquiner",
    "taquinâtes": "taquiner",
    "taquinèrent": "taquiner",
    "taquiné": "taquiner",
    "taquinée": "taquiner",
    "taquinées": "taquiner",
    "taquinés": "taquiner",
    "taquions": "taquer",
    "taquons": "taquer",
    "taquâmes": "taquer",
    "taquât": "taquer",
    "taquâtes": "taquer",
    "taquèrent": "taquer",
    "taqué": "taquer",
    "taquée": "taquer",
    "taquées": "taquer",
    "taqués": "taquer",
    "tara": "tarer",
    "tarabiscotages": "tarabiscotage",
    "tarabiscotée": "tarabiscoter",
    "tarabiscotées": "tarabiscoté",
    "tarabiscotés": "tarabiscoter",
    "tarabusta": "tarabuster",
    "tarabustai": "tarabuster",
    "tarabustaient": "tarabuster",
    "tarabustais": "tarabuster",
    "tarabustait": "tarabuster",
    "tarabustant": "tarabuster",
    "tarabustas": "tarabuster",
    "tarabustasse": "tarabuster",
    "tarabustassent": "tarabuster",
    "tarabustasses": "tarabuster",
    "tarabustassiez": "tarabuster",
    "tarabustassions": "tarabuster",
    "tarabuste": "tarabuster",
    "tarabustent": "tarabuster",
    "tarabustera": "tarabuster",
    "tarabusterai": "tarabuster",
    "tarabusteraient": "tarabuster",
    "tarabusterais": "tarabuster",
    "tarabusterait": "tarabuster",
    "tarabusteras": "tarabuster",
    "tarabusterez": "tarabuster",
    "tarabusteriez": "tarabuster",
    "tarabusterions": "tarabuster",
    "tarabusterons": "tarabuster",
    "tarabusteront": "tarabuster",
    "tarabustes": "tarabuster",
    "tarabustez": "tarabuster",
    "tarabustiez": "tarabuster",
    "tarabustions": "tarabuster",
    "tarabustons": "tarabuster",
    "tarabustâmes": "tarabuster",
    "tarabustât": "tarabuster",
    "tarabustâtes": "tarabuster",
    "tarabustèrent": "tarabuster",
    "tarabusté": "tarabuster",
    "tarabustée": "tarabuster",
    "tarabustées": "tarabuster",
    "tarabustés": "tarabuster",
    "tarasques": "tarasque",
    "tarauda": "tarauder",
    "taraudai": "tarauder",
    "taraudaient": "tarauder",
    "taraudais": "tarauder",
    "taraudait": "tarauder",
    "taraudant": "tarauder",
    "taraudas": "tarauder",
    "taraudasse": "tarauder",
    "taraudassent": "tarauder",
    "taraudasses": "tarauder",
    "taraudassiez": "tarauder",
    "taraudassions": "tarauder",
    "taraude": "tarauder",
    "taraudent": "tarauder",
    "taraudera": "tarauder",
    "tarauderai": "tarauder",
    "tarauderaient": "tarauder",
    "tarauderais": "tarauder",
    "tarauderait": "tarauder",
    "tarauderas": "tarauder",
    "tarauderez": "tarauder",
    "tarauderiez": "tarauder",
    "tarauderions": "tarauder",
    "tarauderons": "tarauder",
    "tarauderont": "tarauder",
    "taraudes": "tarauder",
    "taraudez": "tarauder",
    "taraudiez": "tarauder",
    "taraudions": "tarauder",
    "taraudons": "tarauder",
    "tarauds": "taraud",
    "taraudâmes": "tarauder",
    "taraudât": "tarauder",
    "taraudâtes": "tarauder",
    "taraudèrent": "tarauder",
    "taraudé": "tarauder",
    "taraudée": "tarauder",
    "taraudées": "tarauder",
    "taraudés": "tarauder",
    "tarbouches": "tarbouche",
    "tarbouchs": "tarbouch",
    "tard-venue": "tard-venu",
    "tard-venues": "tard-venu",
    "tard-venus": "tard-venu",
    "tarda": "tarder",
    "tardai": "tarder",
    "tardaient": "tarder",
    "tardais": "tarder",
    "tardait": "tarder",
    "tardant": "tarder",
    "tardas": "tarder",
    "tardasse": "tarder",
    "tardassent": "tarder",
    "tardasses": "tarder",
    "tardassiez": "tarder",
    "tardassions": "tarder",
    "tarde": "tarder",
    "tardent": "tarder",
    "tardera": "tarder",
    "tarderai": "tarder",
    "tarderaient": "tarder",
    "tarderais": "tarder",
    "tarderait": "tarder",
    "tarderas": "tarder",
    "tarderez": "tarder",
    "tarderies": "tarderie",
    "tarderiez": "tarder",
    "tarderions": "tarder",
    "tarderons": "tarder",
    "tarderont": "tarder",
    "tardes": "tarder",
    "tardez": "tarder",
    "tardiez": "tarder",
    "tardifs": "tardif",
    "tardions": "tarder",
    "tardive": "tardif",
    "tardives": "tardif",
    "tardons": "tarder",
    "tardâmes": "tarder",
    "tardât": "tarder",
    "tardâtes": "tarder",
    "tardèrent": "tarder",
    "tardé": "tarder",
    "tardée": "tarder",
    "tarentelles": "tarentelle",
    "tarentules": "tarentule",
    "tares": "tarer",
    "tarets": "taret",
    "targes": "targe",
    "targettes": "targette",
    "targua": "targuer",
    "targuai": "targuer",
    "targuaient": "targuer",
    "targuais": "targuer",
    "targuait": "targuer",
    "targuant": "targuer",
    "targuas": "targuer",
    "targuasse": "targuer",
    "targuassent": "targuer",
    "targuasses": "targuer",
    "targuassiez": "targuer",
    "targuassions": "targuer",
    "targue": "targuer",
    "targuent": "targuer",
    "targuera": "targuer",
    "targuerai": "targuer",
    "targueraient": "targuer",
    "targuerais": "targuer",
    "targuerait": "targuer",
    "targueras": "targuer",
    "targuerez": "targuer",
    "targueriez": "targuer",
    "targuerions": "targuer",
    "targuerons": "targuer",
    "targueront": "targuer",
    "targues": "targuer",
    "targuez": "targuer",
    "targuiez": "targuer",
    "targuions": "targuer",
    "targuons": "targuer",
    "targuâmes": "targuer",
    "targuât": "targuer",
    "targuâtes": "targuer",
    "targuèrent": "targuer",
    "targué": "targuer",
    "targuée": "targuer",
    "targuées": "targuer",
    "targués": "targuer",
    "tari": "tarir",
    "tarie": "tarir",
    "taries": "tarir",
    "tarifa": "tarifer",
    "tarifai": "tarifer",
    "tarifaient": "tarifer",
    "tarifaires": "tarifaire",
    "tarifais": "tarifer",
    "tarifait": "tarifer",
    "tarifant": "tarifer",
    "tarifas": "tarifer",
    "tarifasse": "tarifer",
    "tarifassent": "tarifer",
    "tarifasses": "tarifer",
    "tarifassiez": "tarifer",
    "tarifassions": "tarifer",
    "tarife": "tarifer",
    "tarifent": "tarifer",
    "tarifera": "tarifer",
    "tariferai": "tarifer",
    "tariferaient": "tarifer",
    "tariferais": "tarifer",
    "tariferait": "tarifer",
    "tariferas": "tarifer",
    "tariferez": "tarifer",
    "tariferiez": "tarifer",
    "tariferions": "tarifer",
    "tariferons": "tarifer",
    "tariferont": "tarifer",
    "tarifes": "tarifer",
    "tarifez": "tarifer",
    "tarifications": "tarification",
    "tarifiez": "tarifer",
    "tarifions": "tarifer",
    "tarifié": "tarifier",
    "tarifons": "tarifer",
    "tarifs": "tarif",
    "tarifâmes": "tarifer",
    "tarifât": "tarifer",
    "tarifâtes": "tarifer",
    "tarifèrent": "tarifer",
    "tarifé": "tarifer",
    "tarifée": "tarifer",
    "tarifées": "tarifer",
    "tarifés": "tarifer",
    "tarins": "tarin",
    "tarira": "tarir",
    "tarirai": "tarir",
    "tariraient": "tarir",
    "tarirais": "tarir",
    "tarirait": "tarir",
    "tariras": "tarir",
    "tarirent": "tarir",
    "tarirez": "tarir",
    "taririez": "tarir",
    "taririons": "tarir",
    "tarirons": "tarir",
    "tariront": "tarir",
    "taris": "tarir",
    "tarissaient": "tarir",
    "tarissais": "tarir",
    "tarissait": "tarir",
    "tarissant": "tarir",
    "tarisse": "tarir",
    "tarissent": "tarir",
    "tarisses": "tarir",
    "tarissez": "tarir",
    "tarissiez": "tarir",
    "tarissions": "tarir",
    "tarissons": "tarir",
    "tarit": "tarir",
    "tarières": "tarière",
    "tarlatanes": "tarlatane",
    "taros": "taro",
    "tarots": "tarot",
    "tarpans": "tarpan",
    "tarses": "tarse",
    "tarsienne": "tarsien",
    "tarsiens": "tarsien",
    "tartane": "tartan",
    "tartanes": "tartane",
    "tartans": "tartan",
    "tartares": "tartare",
    "tartarinades": "tartarinade",
    "tartarins": "tartarin",
    "tartelettes": "tartelette",
    "tartes": "tarte",
    "tartignolles": "tartignolle",
    "tartina": "tartiner",
    "tartinai": "tartiner",
    "tartinaient": "tartiner",
    "tartinais": "tartiner",
    "tartinait": "tartiner",
    "tartinant": "tartiner",
    "tartinas": "tartiner",
    "tartinasse": "tartiner",
    "tartinassent": "tartiner",
    "tartinasses": "tartiner",
    "tartinassiez": "tartiner",
    "tartinassions": "tartiner",
    "tartine": "tartiner",
    "tartinent": "tartiner",
    "tartinera": "tartiner",
    "tartinerai": "tartiner",
    "tartineraient": "tartiner",
    "tartinerais": "tartiner",
    "tartinerait": "tartiner",
    "tartineras": "tartiner",
    "tartinerez": "tartiner",
    "tartineriez": "tartiner",
    "tartinerions": "tartiner",
    "tartinerons": "tartiner",
    "tartineront": "tartiner",
    "tartines": "tartiner",
    "tartinez": "tartiner",
    "tartiniez": "tartiner",
    "tartinions": "tartiner",
    "tartinons": "tartiner",
    "tartinâmes": "tartiner",
    "tartinât": "tartiner",
    "tartinâtes": "tartiner",
    "tartinèrent": "tartiner",
    "tartiné": "tartiner",
    "tartinée": "tartiner",
    "tartinées": "tartiner",
    "tartinés": "tartiner",
    "tartissent": "tartir",
    "tartisses": "tartir",
    "tartouilles": "tartouille",
    "tartres": "tartre",
    "tartuferies": "tartuferie",
    "tartufes": "tartufe",
    "tartuffes": "tartuffe",
    "tarzans": "tarzan",
    "taré": "tarer",
    "tarée": "tarer",
    "tarées": "tarer",
    "tarés": "tarer",
    "tarîmes": "tarir",
    "tarît": "tarir",
    "tarîtes": "tarir",
    "tassa": "tasser",
    "tassai": "tasser",
    "tassaient": "tasser",
    "tassais": "tasser",
    "tassait": "tasser",
    "tassant": "tasser",
    "tassas": "tasser",
    "tassasse": "tasser",
    "tassassent": "tasser",
    "tassasses": "tasser",
    "tassassiez": "tasser",
    "tassassions": "tasser",
    "tasse": "tasser",
    "tasseaux": "tasseau",
    "tassements": "tassement",
    "tassent": "tasser",
    "tassera": "tasser",
    "tasserai": "tasser",
    "tasseraient": "tasser",
    "tasserais": "tasser",
    "tasserait": "tasser",
    "tasseras": "tasser",
    "tasserez": "tasser",
    "tasseriez": "tasser",
    "tasserions": "tasser",
    "tasserons": "tasser",
    "tasseront": "tasser",
    "tasses": "tasser",
    "tassettes": "tassette",
    "tassez": "tasser",
    "tassiez": "tasser",
    "tassions": "tasser",
    "tassons": "tasser",
    "tassâmes": "tasser",
    "tassât": "tasser",
    "tassâtes": "tasser",
    "tassèrent": "tasser",
    "tassé": "tasser",
    "tassée": "tasser",
    "tassées": "tasser",
    "tassés": "tasser",
    "tatamis": "tatami",
    "tatanes": "tatane",
    "tatars": "tatar",
    "tatas": "tata",
    "tatillonne": "tatillon",
    "tatillonnes": "tatillon",
    "tatillons": "tatillon",
    "tatoua": "tatouer",
    "tatouages": "tatouage",
    "tatouai": "tatouer",
    "tatouaient": "tatouer",
    "tatouais": "tatouer",
    "tatouait": "tatouer",
    "tatouant": "tatouer",
    "tatouas": "tatouer",
    "tatouasse": "tatouer",
    "tatouassent": "tatouer",
    "tatouasses": "tatouer",
    "tatouassiez": "tatouer",
    "tatouassions": "tatouer",
    "tatoue": "tatouer",
    "tatouent": "tatouer",
    "tatouera": "tatouer",
    "tatouerai": "tatouer",
    "tatoueraient": "tatouer",
    "tatouerais": "tatouer",
    "tatouerait": "tatouer",
    "tatoueras": "tatouer",
    "tatouerez": "tatouer",
    "tatoueriez": "tatouer",
    "tatouerions": "tatouer",
    "tatouerons": "tatouer",
    "tatoueront": "tatouer",
    "tatoues": "tatouer",
    "tatoueurs": "tatoueur",
    "tatoueuse": "tatoueur",
    "tatouez": "tatouer",
    "tatouiez": "tatouer",
    "tatouions": "tatouer",
    "tatouons": "tatouer",
    "tatous": "tatou",
    "tatouâmes": "tatouer",
    "tatouât": "tatouer",
    "tatouâtes": "tatouer",
    "tatouèrent": "tatouer",
    "tatoué": "tatouer",
    "tatouée": "tatouer",
    "tatouées": "tatouer",
    "tatoués": "tatouer",
    "taularde": "taulard",
    "taulardes": "taulard",
    "taulards": "taulard",
    "taules": "taule",
    "tauliers": "taulier",
    "taulière": "taulier",
    "taulières": "taulier",
    "taupes": "taupe",
    "taupes-grillons": "taupe-grillon",
    "taupinières": "taupinière",
    "taupins": "taupin",
    "taupinées": "taupinée",
    "taupés": "taupé",
    "taure": "taureau",
    "taureaux": "taureau",
    "taures": "taureau",
    "taurillons": "taurillon",
    "taurine": "taurin",
    "taurins": "taurin",
    "tauromachies": "tauromachie",
    "tautologies": "tautologie",
    "tavela": "taveler",
    "tavelai": "taveler",
    "tavelaient": "taveler",
    "tavelais": "taveler",
    "tavelait": "taveler",
    "tavelant": "taveler",
    "tavelas": "taveler",
    "tavelasse": "taveler",
    "tavelassent": "taveler",
    "tavelasses": "taveler",
    "tavelassiez": "taveler",
    "tavelassions": "taveler",
    "tavelez": "taveler",
    "taveliez": "taveler",
    "tavelions": "taveler",
    "tavelle": "taveler",
    "tavellent": "taveler",
    "tavellera": "taveler",
    "tavellerai": "taveler",
    "tavelleraient": "taveler",
    "tavellerais": "taveler",
    "tavellerait": "taveler",
    "tavelleras": "taveler",
    "tavellerez": "taveler",
    "tavelleriez": "taveler",
    "tavellerions": "taveler",
    "tavellerons": "taveler",
    "tavelleront": "taveler",
    "tavelles": "taveler",
    "tavelons": "taveler",
    "tavelures": "tavelure",
    "tavelâmes": "taveler",
    "tavelât": "taveler",
    "tavelâtes": "taveler",
    "tavelèrent": "taveler",
    "tavelé": "taveler",
    "tavelée": "taveler",
    "tavelées": "taveler",
    "tavelés": "taveler",
    "tavernes": "taverne",
    "taverniers": "tavernier",
    "taxa": "taxer",
    "taxables": "taxable",
    "taxai": "taxer",
    "taxaient": "taxer",
    "taxais": "taxer",
    "taxait": "taxer",
    "taxant": "taxer",
    "taxas": "taxer",
    "taxasse": "taxer",
    "taxassent": "taxer",
    "taxasses": "taxer",
    "taxassiez": "taxer",
    "taxassions": "taxer",
    "taxations": "taxation",
    "taxe": "taxer",
    "taxent": "taxer",
    "taxera": "taxer",
    "taxerai": "taxer",
    "taxeraient": "taxer",
    "taxerais": "taxer",
    "taxerait": "taxer",
    "taxeras": "taxer",
    "taxerez": "taxer",
    "taxeriez": "taxer",
    "taxerions": "taxer",
    "taxerons": "taxer",
    "taxeront": "taxer",
    "taxes": "taxer",
    "taxez": "taxer",
    "taxi-girls": "taxi-girl",
    "taxidermistes": "taxidermiste",
    "taxiez": "taxer",
    "taximen": "taximan",
    "taximètres": "taximètre",
    "taxinomies": "taxinomie",
    "taxions": "taxer",
    "taxiphones": "taxiphone",
    "taxis": "taxi",
    "taxons": "taxer",
    "taxâmes": "taxer",
    "taxât": "taxer",
    "taxâtes": "taxer",
    "taxèrent": "taxer",
    "taxé": "taxer",
    "taxée": "taxer",
    "taxées": "taxer",
    "taxés": "taxer",
    "taylorienne": "taylorien",
    "tayloriennes": "taylorien",
    "tayloriens": "taylorien",
    "taylorismes": "taylorisme",
    "taylorisé": "tayloriser",
    "taëls": "taël",
    "taïgas": "taïga",
    "taïwanaise": "taïwanais",
    "taïwanaises": "taïwanais",
    "tchadienne": "tchadien",
    "tchadiennes": "tchadien",
    "tchadiens": "tchadien",
    "tchadors": "tchador",
    "tchatchant": "tchatcher",
    "tchatche": "tchatcher",
    "tchatchent": "tchatcher",
    "tchatches": "tchatcher",
    "tchatché": "tchatcher",
    "tchernozioms": "tchernoziom",
    "tchetniks": "tchetnik",
    "tchèques": "tchèque",
    "tchécoslovaques": "tchécoslovaque",
    "tchékhoviennes": "tchékhovien",
    "tchékistes": "tchékiste",
    "tchétchènes": "tchétchène",
    "te": "se",
    "teams": "team",
    "technicienne": "technicien",
    "techniciennes": "technicien",
    "techniciens": "technicien",
    "technicités": "technicité",
    "technico-commerciale": "technico-commercial",
    "technico-commerciales": "technico-commercial",
    "technico-commerciaux": "technico-commercial",
    "techniques": "technique",
    "technocrates": "technocrate",
    "technocraties": "technocratie",
    "technocratiques": "technocratique",
    "technologies": "technologie",
    "technologiques": "technologique",
    "technopoles": "technopole",
    "technostructures": "technostructure",
    "teckels": "teckel",
    "tecks": "teck",
    "tectoniques": "tectonique",
    "tee-shirts": "tee-shirt",
    "teen-agers": "teen-ager",
    "teenagers": "teenager",
    "tees": "tee",
    "teignaient": "teindre",
    "teignais": "teindre",
    "teignait": "teindre",
    "teignant": "teindre",
    "teigne": "teindre",
    "teignent": "teindre",
    "teignes": "teindre",
    "teigneuse": "teigneux",
    "teigneuses": "teigneux",
    "teignez": "teindre",
    "teigniez": "teindre",
    "teignions": "teindre",
    "teignirent": "teindre",
    "teignis": "teindre",
    "teignisse": "teindre",
    "teignissent": "teindre",
    "teignisses": "teindre",
    "teignissiez": "teindre",
    "teignissions": "teindre",
    "teignit": "teindre",
    "teignons": "teindre",
    "teignîmes": "teindre",
    "teignît": "teindre",
    "teignîtes": "teindre",
    "teille": "teiller",
    "teilles": "teille",
    "teindra": "teindre",
    "teindrai": "teindre",
    "teindraient": "teindre",
    "teindrais": "teindre",
    "teindrait": "teindre",
    "teindras": "teindre",
    "teindrez": "teindre",
    "teindriez": "teindre",
    "teindrions": "teindre",
    "teindrons": "teindre",
    "teindront": "teindre",
    "teins": "teindre",
    "teint": "teindre",
    "teinta": "teinter",
    "teintai": "teinter",
    "teintaient": "teinter",
    "teintais": "teinter",
    "teintait": "teinter",
    "teintant": "teinter",
    "teintas": "teinter",
    "teintasse": "teinter",
    "teintassent": "teinter",
    "teintasses": "teinter",
    "teintassiez": "teinter",
    "teintassions": "teinter",
    "teinte": "teinter",
    "teintent": "teinter",
    "teintera": "teinter",
    "teinterai": "teinter",
    "teinteraient": "teinter",
    "teinterais": "teinter",
    "teinterait": "teinter",
    "teinteras": "teinter",
    "teinterez": "teinter",
    "teinteriez": "teinter",
    "teinterions": "teinter",
    "teinterons": "teinter",
    "teinteront": "teinter",
    "teintes": "teinter",
    "teintez": "teinter",
    "teintiez": "teinter",
    "teintions": "teinter",
    "teintons": "teinter",
    "teints": "teint",
    "teintureries": "teinturerie",
    "teintures": "teinture",
    "teinturiers": "teinturier",
    "teinturière": "teinturier",
    "teintâmes": "teinter",
    "teintât": "teinter",
    "teintâtes": "teinter",
    "teintèrent": "teinter",
    "teinté": "teinter",
    "teintée": "teinter",
    "teintées": "teinter",
    "teintés": "teinter",
    "teks": "tek",
    "telle": "tel",
    "telles": "tel",
    "tellurienne": "tellurien",
    "telluriennes": "tellurien",
    "telluriens": "tellurien",
    "telluriques": "tellurique",
    "tels": "tel",
    "tempes": "tempe",
    "tempi": "tempo",
    "temples": "temple",
    "templiers": "templier",
    "templière": "templier",
    "temporaires": "temporaire",
    "temporale": "temporal",
    "temporales": "temporal",
    "temporalités": "temporalité",
    "temporaux": "temporal",
    "temporelle": "temporel",
    "temporelles": "temporel",
    "temporels": "temporel",
    "temporisa": "temporiser",
    "temporisai": "temporiser",
    "temporisaient": "temporiser",
    "temporisais": "temporiser",
    "temporisait": "temporiser",
    "temporisant": "temporiser",
    "temporisas": "temporiser",
    "temporisasse": "temporiser",
    "temporisassent": "temporiser",
    "temporisasses": "temporiser",
    "temporisassiez": "temporiser",
    "temporisassions": "temporiser",
    "temporisateurs": "temporisateur",
    "temporisations": "temporisation",
    "temporisatrice": "temporisateur",
    "temporisatrices": "temporisateur",
    "temporise": "temporiser",
    "temporisent": "temporiser",
    "temporisera": "temporiser",
    "temporiserai": "temporiser",
    "temporiseraient": "temporiser",
    "temporiserais": "temporiser",
    "temporiserait": "temporiser",
    "temporiseras": "temporiser",
    "temporiserez": "temporiser",
    "temporiseriez": "temporiser",
    "temporiserions": "temporiser",
    "temporiserons": "temporiser",
    "temporiseront": "temporiser",
    "temporises": "temporiser",
    "temporisez": "temporiser",
    "temporisiez": "temporiser",
    "temporisions": "temporiser",
    "temporisons": "temporiser",
    "temporisâmes": "temporiser",
    "temporisât": "temporiser",
    "temporisâtes": "temporiser",
    "temporisèrent": "temporiser",
    "temporisé": "temporiser",
    "temporisée": "temporiser",
    "tempos": "tempo",
    "tempuras": "tempura",
    "tempère": "tempérer",
    "tempèrent": "tempérer",
    "tempères": "tempérer",
    "tempéra": "tempérer",
    "tempérai": "tempérer",
    "tempéraient": "tempérer",
    "tempérais": "tempérer",
    "tempérait": "tempérer",
    "tempéraments": "tempérament",
    "tempérances": "tempérance",
    "tempérant": "tempérer",
    "tempérante": "tempérant",
    "tempérantes": "tempérant",
    "tempérants": "tempérant",
    "tempéras": "tempérer",
    "tempérasse": "tempérer",
    "tempérassent": "tempérer",
    "tempérasses": "tempérer",
    "tempérassiez": "tempérer",
    "tempérassions": "tempérer",
    "températures": "température",
    "tempérera": "tempérer",
    "tempérerai": "tempérer",
    "tempéreraient": "tempérer",
    "tempérerais": "tempérer",
    "tempérerait": "tempérer",
    "tempéreras": "tempérer",
    "tempérerez": "tempérer",
    "tempéreriez": "tempérer",
    "tempérerions": "tempérer",
    "tempérerons": "tempérer",
    "tempéreront": "tempérer",
    "tempérez": "tempérer",
    "tempériez": "tempérer",
    "tempérions": "tempérer",
    "tempérons": "tempérer",
    "tempérâmes": "tempérer",
    "tempérât": "tempérer",
    "tempérâtes": "tempérer",
    "tempérèrent": "tempérer",
    "tempéré": "tempérer",
    "tempérée": "tempérer",
    "tempérées": "tempérer",
    "tempérés": "tempérer",
    "tempêta": "tempêter",
    "tempêtai": "tempêter",
    "tempêtaient": "tempêter",
    "tempêtais": "tempêter",
    "tempêtait": "tempêter",
    "tempêtant": "tempêter",
    "tempêtas": "tempêter",
    "tempêtasse": "tempêter",
    "tempêtassent": "tempêter",
    "tempêtasses": "tempêter",
    "tempêtassiez": "tempêter",
    "tempêtassions": "tempêter",
    "tempête": "tempêter",
    "tempêtent": "tempêter",
    "tempêtera": "tempêter",
    "tempêterai": "tempêter",
    "tempêteraient": "tempêter",
    "tempêterais": "tempêter",
    "tempêterait": "tempêter",
    "tempêteras": "tempêter",
    "tempêterez": "tempêter",
    "tempêteriez": "tempêter",
    "tempêterions": "tempêter",
    "tempêterons": "tempêter",
    "tempêteront": "tempêter",
    "tempêtes": "tempêter",
    "tempêtez": "tempêter",
    "tempêtiez": "tempêter",
    "tempêtions": "tempêter",
    "tempêtons": "tempêter",
    "tempêtâmes": "tempêter",
    "tempêtât": "tempêter",
    "tempêtâtes": "tempêter",
    "tempêtèrent": "tempêter",
    "tempêté": "tempêter",
    "tenables": "tenable",
    "tenaces": "tenace",
    "tenaient": "tenir",
    "tenaillaient": "tenailler",
    "tenaillait": "tenailler",
    "tenaillant": "tenailler",
    "tenaille": "tenailler",
    "tenaillent": "tenailler",
    "tenailles": "tenaille",
    "tenaillé": "tenailler",
    "tenaillée": "tenailler",
    "tenais": "tenir",
    "tenait": "tenir",
    "tenanciers": "tenancier",
    "tenancière": "tenancier",
    "tenancières": "tenancier",
    "tenant": "tenir",
    "tenante": "tenant",
    "tenantes": "tenant",
    "tenants": "tenant",
    "tend": "tendre",
    "tendaient": "tendre",
    "tendais": "tendre",
    "tendait": "tendre",
    "tendances": "tendance",
    "tendancieuse": "tendancieux",
    "tendancieuses": "tendancieux",
    "tendant": "tendre",
    "tende": "tendre",
    "tendent": "tendre",
    "tenders": "tender",
    "tendes": "tendre",
    "tendeurs": "tendeur",
    "tendez": "tendre",
    "tendiez": "tendre",
    "tendineuses": "tendineux",
    "tendinites": "tendinite",
    "tendions": "tendre",
    "tendirent": "tendre",
    "tendis": "tendre",
    "tendisse": "tendre",
    "tendissent": "tendre",
    "tendisses": "tendre",
    "tendissiez": "tendre",
    "tendissions": "tendre",
    "tendit": "tendre",
    "tendons": "tendre",
    "tendra": "tendre",
    "tendrai": "tendre",
    "tendraient": "tendre",
    "tendrais": "tendre",
    "tendrait": "tendre",
    "tendras": "tendre",
    "tendres": "tendre",
    "tendresses": "tendresse",
    "tendrez": "tendre",
    "tendriez": "tendre",
    "tendrions": "tendre",
    "tendrons": "tendron",
    "tendront": "tendre",
    "tends": "tendre",
    "tendu": "tendre",
    "tendue": "tendu",
    "tendues": "tendu",
    "tendus": "tendu",
    "tendîmes": "tendre",
    "tendît": "tendre",
    "tendîtes": "tendre",
    "teneurs": "teneur",
    "tenez": "tenir",
    "teniez": "tenir",
    "tenions": "tenir",
    "tennis-elbows": "tennis-elbow",
    "tennismans": "tennisman",
    "tennismen": "tennisman",
    "tenons": "tenon",
    "tensions": "tension",
    "tenta": "tenter",
    "tentaculaires": "tentaculaire",
    "tentacules": "tentacule",
    "tentai": "tenter",
    "tentaient": "tenter",
    "tentais": "tenter",
    "tentait": "tenter",
    "tentant": "tenter",
    "tentante": "tentant",
    "tentantes": "tentant",
    "tentants": "tentant",
    "tentas": "tenter",
    "tentasse": "tenter",
    "tentassent": "tenter",
    "tentasses": "tenter",
    "tentassiez": "tenter",
    "tentassions": "tenter",
    "tentateurs": "tentateur",
    "tentations": "tentation",
    "tentatives": "tentative",
    "tentatrice": "tentateur",
    "tentatrices": "tentateur",
    "tente": "tenter",
    "tentent": "tenter",
    "tentera": "tenter",
    "tenterai": "tenter",
    "tenteraient": "tenter",
    "tenterais": "tenter",
    "tenterait": "tenter",
    "tenteras": "tenter",
    "tenterez": "tenter",
    "tenteriez": "tenter",
    "tenterions": "tenter",
    "tenterons": "tenter",
    "tenteront": "tenter",
    "tentes": "tenter",
    "tentes-abris": "tente-abri",
    "tentez": "tenter",
    "tentiez": "tenter",
    "tentions": "tenter",
    "tentons": "tenter",
    "tentures": "tenture",
    "tentâmes": "tenter",
    "tentât": "tenter",
    "tentâtes": "tenter",
    "tentèrent": "tenter",
    "tenté": "tenter",
    "tentée": "tenter",
    "tentées": "tenter",
    "tentés": "tenter",
    "tenu": "tenir",
    "tenue": "tenu",
    "tenues": "tenue",
    "tenus": "tenu",
    "tequilas": "tequila",
    "terce": "tercer",
    "tercets": "tercet",
    "tergiversa": "tergiverser",
    "tergiversai": "tergiverser",
    "tergiversaient": "tergiverser",
    "tergiversais": "tergiverser",
    "tergiversait": "tergiverser",
    "tergiversant": "tergiverser",
    "tergiversas": "tergiverser",
    "tergiversasse": "tergiverser",
    "tergiversassent": "tergiverser",
    "tergiversasses": "tergiverser",
    "tergiversassiez": "tergiverser",
    "tergiversassions": "tergiverser",
    "tergiversations": "tergiversation",
    "tergiverse": "tergiverser",
    "tergiversent": "tergiverser",
    "tergiversera": "tergiverser",
    "tergiverserai": "tergiverser",
    "tergiverseraient": "tergiverser",
    "tergiverserais": "tergiverser",
    "tergiverserait": "tergiverser",
    "tergiverseras": "tergiverser",
    "tergiverserez": "tergiverser",
    "tergiverseriez": "tergiverser",
    "tergiverserions": "tergiverser",
    "tergiverserons": "tergiverser",
    "tergiverseront": "tergiverser",
    "tergiverses": "tergiverser",
    "tergiversez": "tergiverser",
    "tergiversiez": "tergiverser",
    "tergiversions": "tergiverser",
    "tergiversons": "tergiverser",
    "tergiversâmes": "tergiverser",
    "tergiversât": "tergiverser",
    "tergiversâtes": "tergiverser",
    "tergiversèrent": "tergiverser",
    "tergiversé": "tergiverser",
    "termes": "terme",
    "termina": "terminer",
    "terminai": "terminer",
    "terminaient": "terminer",
    "terminais": "terminer",
    "terminaisons": "terminaison",
    "terminait": "terminer",
    "terminale": "terminal",
    "terminales": "terminale",
    "terminant": "terminer",
    "terminas": "terminer",
    "terminasse": "terminer",
    "terminassent": "terminer",
    "terminasses": "terminer",
    "terminassiez": "terminer",
    "terminassions": "terminer",
    "terminatrice": "terminateur",
    "terminaux": "terminal",
    "termine": "terminer",
    "terminent": "terminer",
    "terminera": "terminer",
    "terminerai": "terminer",
    "termineraient": "terminer",
    "terminerais": "terminer",
    "terminerait": "terminer",
    "termineras": "terminer",
    "terminerez": "terminer",
    "termineriez": "terminer",
    "terminerions": "terminer",
    "terminerons": "terminer",
    "termineront": "terminer",
    "termines": "terminer",
    "terminez": "terminer",
    "terminiez": "terminer",
    "terminions": "terminer",
    "terminologies": "terminologie",
    "terminologiques": "terminologique",
    "terminons": "terminer",
    "terminâmes": "terminer",
    "terminât": "terminer",
    "terminâtes": "terminer",
    "terminèrent": "terminer",
    "terminé": "terminer",
    "terminée": "terminer",
    "terminées": "terminer",
    "terminés": "terminer",
    "termites": "termite",
    "termitières": "termitière",
    "ternaires": "ternaire",
    "ternes": "terne",
    "terni": "ternir",
    "ternie": "ternir",
    "ternies": "ternir",
    "ternira": "ternir",
    "ternirai": "ternir",
    "terniraient": "ternir",
    "ternirais": "ternir",
    "ternirait": "ternir",
    "terniras": "ternir",
    "ternirent": "ternir",
    "ternirez": "ternir",
    "terniriez": "ternir",
    "ternirions": "ternir",
    "ternirons": "ternir",
    "terniront": "ternir",
    "ternis": "ternir",
    "ternissaient": "ternir",
    "ternissais": "ternir",
    "ternissait": "ternir",
    "ternissant": "ternir",
    "ternisse": "ternir",
    "ternissent": "ternir",
    "ternisses": "ternir",
    "ternissez": "ternir",
    "ternissiez": "ternir",
    "ternissions": "ternir",
    "ternissons": "ternir",
    "ternit": "ternir",
    "ternîmes": "ternir",
    "ternît": "ternir",
    "ternîtes": "ternir",
    "terra": "terrer",
    "terrai": "terrer",
    "terraient": "terrer",
    "terrains": "terrain",
    "terrais": "terrer",
    "terrait": "terrer",
    "terrant": "terrer",
    "terrariums": "terrarium",
    "terras": "terrer",
    "terrassa": "terrasser",
    "terrassai": "terrasser",
    "terrassaient": "terrasser",
    "terrassais": "terrasser",
    "terrassait": "terrasser",
    "terrassant": "terrasser",
    "terrassas": "terrasser",
    "terrassasse": "terrasser",
    "terrassassent": "terrasser",
    "terrassasses": "terrasser",
    "terrassassiez": "terrasser",
    "terrassassions": "terrasser",
    "terrasse": "terrer",
    "terrassements": "terrassement",
    "terrassent": "terrer",
    "terrassera": "terrasser",
    "terrasserai": "terrasser",
    "terrasseraient": "terrasser",
    "terrasserais": "terrasser",
    "terrasserait": "terrasser",
    "terrasseras": "terrasser",
    "terrasserez": "terrasser",
    "terrasseriez": "terrasser",
    "terrasserions": "terrasser",
    "terrasserons": "terrasser",
    "terrasseront": "terrasser",
    "terrasses": "terrer",
    "terrassez": "terrasser",
    "terrassiers": "terrassier",
    "terrassiez": "terrer",
    "terrassions": "terrer",
    "terrassons": "terrasser",
    "terrassâmes": "terrasser",
    "terrassât": "terrasser",
    "terrassâtes": "terrasser",
    "terrassèrent": "terrasser",
    "terrassé": "terrasser",
    "terrassée": "terrasser",
    "terrassées": "terrasser",
    "terrassés": "terrasser",
    "terre": "terrer",
    "terre-pleins": "terre-plein",
    "terreaux": "terreau",
    "terrent": "terrer",
    "terrera": "terrer",
    "terrerai": "terrer",
    "terreraient": "terrer",
    "terrerais": "terrer",
    "terrerait": "terrer",
    "terreras": "terrer",
    "terrerez": "terrer",
    "terreriez": "terrer",
    "terrerions": "terrer",
    "terrerons": "terrer",
    "terreront": "terrer",
    "terres": "terrer",
    "terrestres": "terrestre",
    "terreurs": "terreur",
    "terreuse": "terreux",
    "terreuses": "terreux",
    "terrez": "terrer",
    "terri": "terrir",
    "terribles": "terrible",
    "terrie": "terrir",
    "terrienne": "terrien",
    "terriennes": "terrien",
    "terriens": "terrien",
    "terriers": "terrier",
    "terries": "terrir",
    "terriez": "terrer",
    "terrifia": "terrifier",
    "terrifiai": "terrifier",
    "terrifiaient": "terrifier",
    "terrifiais": "terrifier",
    "terrifiait": "terrifier",
    "terrifiant": "terrifier",
    "terrifiante": "terrifiant",
    "terrifiantes": "terrifiant",
    "terrifiants": "terrifiant",
    "terrifias": "terrifier",
    "terrifiasse": "terrifier",
    "terrifiassent": "terrifier",
    "terrifiasses": "terrifier",
    "terrifiassiez": "terrifier",
    "terrifiassions": "terrifier",
    "terrifie": "terrifier",
    "terrifient": "terrifier",
    "terrifiera": "terrifier",
    "terrifierai": "terrifier",
    "terrifieraient": "terrifier",
    "terrifierais": "terrifier",
    "terrifierait": "terrifier",
    "terrifieras": "terrifier",
    "terrifierez": "terrifier",
    "terrifieriez": "terrifier",
    "terrifierions": "terrifier",
    "terrifierons": "terrifier",
    "terrifieront": "terrifier",
    "terrifies": "terrifier",
    "terrifiez": "terrifier",
    "terrifiiez": "terrifier",
    "terrifiions": "terrifier",
    "terrifions": "terrifier",
    "terrifiâmes": "terrifier",
    "terrifiât": "terrifier",
    "terrifiâtes": "terrifier",
    "terrifièrent": "terrifier",
    "terrifié": "terrifier",
    "terrifiée": "terrifier",
    "terrifiées": "terrifier",
    "terrifiés": "terrifier",
    "terrils": "terril",
    "terrines": "terrine",
    "terrions": "terrer",
    "terrira": "terrir",
    "terrirai": "terrir",
    "terriraient": "terrir",
    "terrirais": "terrir",
    "terrirait": "terrir",
    "terriras": "terrir",
    "terrirent": "terrir",
    "terrirez": "terrir",
    "terririez": "terrir",
    "terririons": "terrir",
    "terrirons": "terrir",
    "terriront": "terrir",
    "terris": "terrir",
    "terrissaient": "terrir",
    "terrissais": "terrir",
    "terrissait": "terrir",
    "terrissant": "terrir",
    "terrisse": "terrir",
    "terrissent": "terrir",
    "terrisses": "terrir",
    "terrissez": "terrir",
    "terrissiez": "terrir",
    "terrissions": "terrir",
    "terrissons": "terrir",
    "territ": "terrir",
    "territoires": "territoire",
    "territoriale": "territorial",
    "territoriales": "territorial",
    "territoriaux": "territorial",
    "terroirs": "terroir",
    "terrons": "terrer",
    "terrorisa": "terroriser",
    "terrorisai": "terroriser",
    "terrorisaient": "terroriser",
    "terrorisais": "terroriser",
    "terrorisait": "terroriser",
    "terrorisant": "terroriser",
    "terrorisante": "terrorisant",
    "terrorisants": "terrorisant",
    "terrorisas": "terroriser",
    "terrorisasse": "terroriser",
    "terrorisassent": "terroriser",
    "terrorisasses": "terroriser",
    "terrorisassiez": "terroriser",
    "terrorisassions": "terroriser",
    "terrorise": "terroriser",
    "terrorisent": "terroriser",
    "terrorisera": "terroriser",
    "terroriserai": "terroriser",
    "terroriseraient": "terroriser",
    "terroriserais": "terroriser",
    "terroriserait": "terroriser",
    "terroriseras": "terroriser",
    "terroriserez": "terroriser",
    "terroriseriez": "terroriser",
    "terroriserions": "terroriser",
    "terroriserons": "terroriser",
    "terroriseront": "terroriser",
    "terrorises": "terroriser",
    "terrorisez": "terroriser",
    "terrorisiez": "terroriser",
    "terrorisions": "terroriser",
    "terrorismes": "terrorisme",
    "terrorisons": "terroriser",
    "terroristes": "terroriste",
    "terrorisâmes": "terroriser",
    "terrorisât": "terroriser",
    "terrorisâtes": "terroriser",
    "terrorisèrent": "terroriser",
    "terrorisé": "terroriser",
    "terrorisée": "terroriser",
    "terrorisées": "terroriser",
    "terrorisés": "terroriser",
    "terrâmes": "terrer",
    "terrât": "terrer",
    "terrâtes": "terrer",
    "terrèrent": "terrer",
    "terré": "terrer",
    "terrée": "terrer",
    "terrées": "terrer",
    "terrés": "terrer",
    "terrîmes": "terrir",
    "terrît": "terrir",
    "terrîtes": "terrir",
    "tertiaires": "tertiaire",
    "tertres": "tertre",
    "tes": "ton",
    "tessitures": "tessiture",
    "tessons": "tesson",
    "testa": "tester",
    "testai": "tester",
    "testaient": "tester",
    "testais": "tester",
    "testait": "tester",
    "testamentaires": "testamentaire",
    "testaments": "testament",
    "testant": "tester",
    "testas": "tester",
    "testasse": "tester",
    "testassent": "tester",
    "testasses": "tester",
    "testassiez": "tester",
    "testassions": "tester",
    "teste": "tester",
    "testent": "tester",
    "testera": "tester",
    "testerai": "tester",
    "testeraient": "tester",
    "testerais": "tester",
    "testerait": "tester",
    "testeras": "tester",
    "testerez": "tester",
    "testeriez": "tester",
    "testerions": "tester",
    "testerons": "tester",
    "testeront": "tester",
    "testes": "tester",
    "testeuse": "testeur",
    "testez": "tester",
    "testicules": "testicule",
    "testiez": "tester",
    "testimoniale": "testimonial",
    "testimoniales": "testimonial",
    "testimoniaux": "testimonial",
    "testions": "tester",
    "testons": "teston",
    "testostérones": "testostérone",
    "tests": "test",
    "testâmes": "tester",
    "testât": "tester",
    "testâtes": "tester",
    "testèrent": "tester",
    "testé": "tester",
    "testée": "tester",
    "testées": "tester",
    "testés": "tester",
    "teutoniques": "teutonique",
    "teutonne": "teuton",
    "teutonnes": "teutonne",
    "teutons": "teuton",
    "texane": "texan",
    "texanes": "texan",
    "texans": "texan",
    "textes": "texte",
    "textiles": "textile",
    "textuelle": "textuel",
    "textuelles": "textuel",
    "textuels": "textuel",
    "textures": "texture",
    "texturisations": "texturisation",
    "thalassothérapeutes": "thalassothérapeute",
    "thalassothérapies": "thalassothérapie",
    "thalers": "thaler",
    "thalles": "thalle",
    "thalliums": "thallium",
    "thallophytes": "thallophyte",
    "thalwegs": "thalweg",
    "thatchérienne": "thatchérien",
    "thatchériennes": "thatchérien",
    "thatchériens": "thatchérien",
    "thaumaturges": "thaumaturge",
    "thaïe": "thaï",
    "thaïlandaise": "thaïlandais",
    "thaïlandaises": "thaïlandais",
    "thaïs": "thaï",
    "thermale": "thermal",
    "thermales": "thermal",
    "thermaux": "thermal",
    "thermidorienne": "thermidorien",
    "thermidors": "thermidor",
    "thermies": "thermie",
    "thermiques": "thermique",
    "thermocautères": "thermocautère",
    "thermocollants": "thermocollant",
    "thermodestructions": "thermodestruction",
    "thermodynamiques": "thermodynamique",
    "thermogènes": "thermogène",
    "thermoluminescences": "thermoluminescence",
    "thermomètres": "thermomètre",
    "thermonucléaires": "thermonucléaire",
    "thermoplastiques": "thermoplastique",
    "thermos": "thermo",
    "thermostats": "thermostat",
    "thermoélectriques": "thermoélectrique",
    "thessaliens": "thessalien",
    "thibaudes": "thibaude",
    "thoniers": "thonier",
    "thonniers": "thonnier",
    "thons": "thon",
    "thoraciques": "thoracique",
    "thraces": "thrace",
    "thrillers": "thriller",
    "thrombines": "thrombine",
    "thromboses": "thrombose",
    "thrènes": "thrène",
    "thugs": "thug",
    "thunes": "thune",
    "thuriféraires": "thuriféraire",
    "thuyas": "thuya",
    "thymiques": "thymique",
    "thymols": "thymol",
    "thyms": "thym",
    "thyroïdes": "thyroïde",
    "thyroïdienne": "thyroïdien",
    "thyrses": "thyrse",
    "thèmes": "thème",
    "thèses": "thèse",
    "thébaïdes": "thébaïde",
    "théismes": "théisme",
    "théières": "théière",
    "thématiques": "thématique",
    "thénars": "thénar",
    "théocraties": "théocratie",
    "théodicées": "théodicée",
    "théodolites": "théodolite",
    "théogonies": "théogonie",
    "théologale": "théologal",
    "théologales": "théologal",
    "théologaux": "théologal",
    "théologienne": "théologien",
    "théologiennes": "théologien",
    "théologiens": "théologien",
    "théologies": "théologie",
    "théologiques": "théologique",
    "théorbes": "théorbe",
    "théoricienne": "théoricien",
    "théoriciennes": "théoricien",
    "théoriciens": "théoricien",
    "théories": "théorie",
    "théoriques": "théorique",
    "théorisa": "théoriser",
    "théorisai": "théoriser",
    "théorisaient": "théoriser",
    "théorisais": "théoriser",
    "théorisait": "théoriser",
    "théorisant": "théoriser",
    "théorisas": "théoriser",
    "théorisasse": "théoriser",
    "théorisassent": "théoriser",
    "théorisasses": "théoriser",
    "théorisassiez": "théoriser",
    "théorisassions": "théoriser",
    "théorise": "théoriser",
    "théorisent": "théoriser",
    "théorisera": "théoriser",
    "théoriserai": "théoriser",
    "théoriseraient": "théoriser",
    "théoriserais": "théoriser",
    "théoriserait": "théoriser",
    "théoriseras": "théoriser",
    "théoriserez": "théoriser",
    "théoriseriez": "théoriser",
    "théoriserions": "théoriser",
    "théoriserons": "théoriser",
    "théoriseront": "théoriser",
    "théorises": "théoriser",
    "théorisez": "théoriser",
    "théorisiez": "théoriser",
    "théorisions": "théoriser",
    "théorisons": "théoriser",
    "théorisâmes": "théoriser",
    "théorisât": "théoriser",
    "théorisâtes": "théoriser",
    "théorisèrent": "théoriser",
    "théorisé": "théoriser",
    "théorisée": "théoriser",
    "théorisées": "théoriser",
    "théorisés": "théoriser",
    "théorèmes": "théorème",
    "théosophes": "théosophe",
    "théosophies": "théosophie",
    "thérapeutes": "thérapeute",
    "thérapeutiques": "thérapeutique",
    "thérapies": "thérapie",
    "thés": "thé",
    "thésarde": "thésard",
    "thésardes": "thésard",
    "thésards": "thésard",
    "thésaurisa": "thésauriser",
    "thésaurisai": "thésauriser",
    "thésaurisaient": "thésauriser",
    "thésaurisais": "thésauriser",
    "thésaurisait": "thésauriser",
    "thésaurisant": "thésauriser",
    "thésaurisas": "thésauriser",
    "thésaurisasse": "thésauriser",
    "thésaurisassent": "thésauriser",
    "thésaurisasses": "thésauriser",
    "thésaurisassiez": "thésauriser",
    "thésaurisassions": "thésauriser",
    "thésaurise": "thésauriser",
    "thésaurisent": "thésauriser",
    "thésaurisera": "thésauriser",
    "thésauriserai": "thésauriser",
    "thésauriseraient": "thésauriser",
    "thésauriserais": "thésauriser",
    "thésauriserait": "thésauriser",
    "thésauriseras": "thésauriser",
    "thésauriserez": "thésauriser",
    "thésauriseriez": "thésauriser",
    "thésauriserions": "thésauriser",
    "thésauriserons": "thésauriser",
    "thésauriseront": "thésauriser",
    "thésaurises": "thésauriser",
    "thésaurisez": "thésauriser",
    "thésaurisiez": "thésauriser",
    "thésaurisions": "thésauriser",
    "thésaurisons": "thésauriser",
    "thésaurisâmes": "thésauriser",
    "thésaurisât": "thésauriser",
    "thésaurisâtes": "thésauriser",
    "thésaurisèrent": "thésauriser",
    "thésaurisé": "thésauriser",
    "thésaurisée": "thésauriser",
    "thésaurisées": "thésauriser",
    "thésaurisés": "thésauriser",
    "théurgiques": "théurgique",
    "théâtrale": "théâtral",
    "théâtrales": "théâtral",
    "théâtralisant": "théâtraliser",
    "théâtralisé": "théâtraliser",
    "théâtralisée": "théâtraliser",
    "théâtraux": "théâtral",
    "théâtres": "théâtre",
    "théâtreuse": "théâtreux",
    "tiares": "tiare",
    "tibiale": "tibial",
    "tibiales": "tibial",
    "tibias": "tibia",
    "tibiaux": "tibial",
    "tibétaine": "tibétain",
    "tibétaines": "tibétain",
    "tibétains": "tibétain",
    "tickets": "ticket",
    "tics": "tic",
    "ticsons": "ticson",
    "tie-breaks": "tie-break",
    "tiendra": "tenir",
    "tiendrai": "tenir",
    "tiendraient": "tenir",
    "tiendrais": "tenir",
    "tiendrait": "tenir",
    "tiendras": "tenir",
    "tiendrez": "tenir",
    "tiendriez": "tenir",
    "tiendrions": "tenir",
    "tiendrons": "tenir",
    "tiendront": "tenir",
    "tienne": "tien",
    "tiennent": "tenir",
    "tiennes": "tien",
    "tiens": "tien",
    "tient": "tenir",
    "tierce": "tiers",
    "tiercelets": "tiercelet",
    "tiercent": "tiercer",
    "tiercera": "tiercer",
    "tiercerai": "tiercer",
    "tierceraient": "tiercer",
    "tiercerais": "tiercer",
    "tiercerait": "tiercer",
    "tierceras": "tiercer",
    "tiercerez": "tiercer",
    "tierceriez": "tiercer",
    "tiercerions": "tiercer",
    "tiercerons": "tiercer",
    "tierceront": "tiercer",
    "tierces": "tiers",
    "tiercez": "tiercer",
    "tierciez": "tiercer",
    "tiercions": "tiercer",
    "tiercèrent": "tiercer",
    "tiercé": "tiercer",
    "tiercée": "tiercer",
    "tiercées": "tiercer",
    "tiercés": "tiercer",
    "tiers-mondes": "tiers-monde",
    "tiers-mondistes": "tiers-mondiste",
    "tiers-points": "tiers-point",
    "tierça": "tiercer",
    "tierçai": "tiercer",
    "tierçaient": "tiercer",
    "tierçais": "tiercer",
    "tierçait": "tiercer",
    "tierçant": "tiercer",
    "tierças": "tiercer",
    "tierçasse": "tiercer",
    "tierçassent": "tiercer",
    "tierçasses": "tiercer",
    "tierçassiez": "tiercer",
    "tierçassions": "tiercer",
    "tierçons": "tiercer",
    "tierçâmes": "tiercer",
    "tierçât": "tiercer",
    "tierçâtes": "tiercer",
    "tifs": "tif",
    "tigelles": "tigelle",
    "tiges": "tige",
    "tignasses": "tignasse",
    "tigres": "tigre",
    "tigresse": "tigre",
    "tigresses": "tigre",
    "tigré": "tigrer",
    "tigrée": "tigrer",
    "tigrées": "tigré",
    "tigrés": "tigrer",
    "tilburys": "tilbury",
    "tildes": "tilde",
    "tillacs": "tillac",
    "tilles": "tille",
    "tilleuls": "tilleul",
    "tilts": "tilt",
    "timbales": "timbale",
    "timbaliers": "timbalier",
    "timbra": "timbrer",
    "timbrai": "timbrer",
    "timbraient": "timbrer",
    "timbrais": "timbrer",
    "timbrait": "timbrer",
    "timbrant": "timbrer",
    "timbras": "timbrer",
    "timbrasse": "timbrer",
    "timbrassent": "timbrer",
    "timbrasses": "timbrer",
    "timbrassiez": "timbrer",
    "timbrassions": "timbrer",
    "timbre": "timbrer",
    "timbrent": "timbrer",
    "timbrera": "timbrer",
    "timbrerai": "timbrer",
    "timbreraient": "timbrer",
    "timbrerais": "timbrer",
    "timbrerait": "timbrer",
    "timbreras": "timbrer",
    "timbrerez": "timbrer",
    "timbreriez": "timbrer",
    "timbrerions": "timbrer",
    "timbrerons": "timbrer",
    "timbreront": "timbrer",
    "timbres": "timbrer",
    "timbres-poste": "timbre-poste",
    "timbres-quittances": "timbre-quittance",
    "timbrez": "timbrer",
    "timbriez": "timbrer",
    "timbrions": "timbrer",
    "timbrons": "timbrer",
    "timbrâmes": "timbrer",
    "timbrât": "timbrer",
    "timbrâtes": "timbrer",
    "timbrèrent": "timbrer",
    "timbré": "timbrer",
    "timbrée": "timbrer",
    "timbrées": "timbrer",
    "timbrés": "timbrer",
    "timides": "timide",
    "timidités": "timidité",
    "timings": "timing",
    "timoneries": "timonerie",
    "timoniers": "timonier",
    "timons": "timon",
    "timorée": "timoré",
    "timorées": "timoré",
    "timorés": "timoré",
    "tinamous": "tinamou",
    "tincals": "tincal",
    "tinctoriale": "tinctorial",
    "tinctoriales": "tinctorial",
    "tinctoriaux": "tinctorial",
    "tinettes": "tinette",
    "tinrent": "tenir",
    "tins": "tin",
    "tinsse": "tenir",
    "tinssent": "tenir",
    "tinsses": "tenir",
    "tinssiez": "tenir",
    "tinssions": "tenir",
    "tint": "tenir",
    "tinta": "tinter",
    "tintai": "tinter",
    "tintaient": "tinter",
    "tintais": "tinter",
    "tintait": "tinter",
    "tintamarrent": "tintamarrer",
    "tintamarres": "tintamarre",
    "tintamarresques": "tintamarresque",
    "tintant": "tinter",
    "tintas": "tinter",
    "tintasse": "tinter",
    "tintassent": "tinter",
    "tintasses": "tinter",
    "tintassiez": "tinter",
    "tintassions": "tinter",
    "tinte": "tinter",
    "tintements": "tintement",
    "tintent": "tinter",
    "tintera": "tinter",
    "tinterai": "tinter",
    "tinteraient": "tinter",
    "tinterais": "tinter",
    "tinterait": "tinter",
    "tinteras": "tinter",
    "tinterez": "tinter",
    "tinteriez": "tinter",
    "tinterions": "tinter",
    "tinterons": "tinter",
    "tinteront": "tinter",
    "tintes": "tinter",
    "tintez": "tinter",
    "tintiez": "tinter",
    "tintinnabula": "tintinnabuler",
    "tintinnabulai": "tintinnabuler",
    "tintinnabulaient": "tintinnabuler",
    "tintinnabulais": "tintinnabuler",
    "tintinnabulait": "tintinnabuler",
    "tintinnabulant": "tintinnabuler",
    "tintinnabulante": "tintinnabulant",
    "tintinnabulantes": "tintinnabulant",
    "tintinnabulants": "tintinnabulant",
    "tintinnabulas": "tintinnabuler",
    "tintinnabulasse": "tintinnabuler",
    "tintinnabulassent": "tintinnabuler",
    "tintinnabulasses": "tintinnabuler",
    "tintinnabulassiez": "tintinnabuler",
    "tintinnabulassions": "tintinnabuler",
    "tintinnabule": "tintinnabuler",
    "tintinnabulements": "tintinnabulement",
    "tintinnabulent": "tintinnabuler",
    "tintinnabulera": "tintinnabuler",
    "tintinnabulerai": "tintinnabuler",
    "tintinnabuleraient": "tintinnabuler",
    "tintinnabulerais": "tintinnabuler",
    "tintinnabulerait": "tintinnabuler",
    "tintinnabuleras": "tintinnabuler",
    "tintinnabulerez": "tintinnabuler",
    "tintinnabuleriez": "tintinnabuler",
    "tintinnabulerions": "tintinnabuler",
    "tintinnabulerons": "tintinnabuler",
    "tintinnabuleront": "tintinnabuler",
    "tintinnabules": "tintinnabuler",
    "tintinnabulez": "tintinnabuler",
    "tintinnabuliez": "tintinnabuler",
    "tintinnabulions": "tintinnabuler",
    "tintinnabulons": "tintinnabuler",
    "tintinnabulâmes": "tintinnabuler",
    "tintinnabulât": "tintinnabuler",
    "tintinnabulâtes": "tintinnabuler",
    "tintinnabulèrent": "tintinnabuler",
    "tintinnabulé": "tintinnabuler",
    "tintions": "tinter",
    "tintons": "tinter",
    "tintouins": "tintouin",
    "tintâmes": "tinter",
    "tintât": "tinter",
    "tintâtes": "tinter",
    "tintèrent": "tinter",
    "tinté": "tinter",
    "tintée": "tinter",
    "tintées": "tinter",
    "tintés": "tinter",
    "tipe": "tiper",
    "tipis": "tipi",
    "tiqua": "tiquer",
    "tiquai": "tiquer",
    "tiquaient": "tiquer",
    "tiquais": "tiquer",
    "tiquait": "tiquer",
    "tiquant": "tiquer",
    "tiquas": "tiquer",
    "tiquasse": "tiquer",
    "tiquassent": "tiquer",
    "tiquasses": "tiquer",
    "tiquassiez": "tiquer",
    "tiquassions": "tiquer",
    "tique": "tiquer",
    "tiquent": "tiquer",
    "tiquera": "tiquer",
    "tiquerai": "tiquer",
    "tiqueraient": "tiquer",
    "tiquerais": "tiquer",
    "tiquerait": "tiquer",
    "tiqueras": "tiquer",
    "tiquerez": "tiquer",
    "tiqueriez": "tiquer",
    "tiquerions": "tiquer",
    "tiquerons": "tiquer",
    "tiqueront": "tiquer",
    "tiques": "tiquer",
    "tiquetée": "tiqueté",
    "tiquetées": "tiqueté",
    "tiquetés": "tiqueté",
    "tiquez": "tiquer",
    "tiquiez": "tiquer",
    "tiquions": "tiquer",
    "tiquons": "tiquer",
    "tiquâmes": "tiquer",
    "tiquât": "tiquer",
    "tiquâtes": "tiquer",
    "tiquèrent": "tiquer",
    "tiqué": "tiquer",
    "tira": "tirer",
    "tirades": "tirade",
    "tirages": "tirage",
    "tirai": "tirer",
    "tiraient": "tirer",
    "tirailla": "tirailler",
    "tiraillai": "tirailler",
    "tiraillaient": "tirailler",
    "tiraillais": "tirailler",
    "tiraillait": "tirailler",
    "tiraillant": "tirailler",
    "tiraillas": "tirailler",
    "tiraillasse": "tirailler",
    "tiraillassent": "tirailler",
    "tiraillasses": "tirailler",
    "tiraillassiez": "tirailler",
    "tiraillassions": "tirailler",
    "tiraille": "tirailler",
    "tiraillements": "tiraillement",
    "tiraillent": "tirailler",
    "tiraillera": "tirailler",
    "tiraillerai": "tirailler",
    "tirailleraient": "tirailler",
    "tiraillerais": "tirailler",
    "tiraillerait": "tirailler",
    "tirailleras": "tirailler",
    "tiraillerez": "tirailler",
    "tirailleries": "tiraillerie",
    "tirailleriez": "tirailler",
    "tiraillerions": "tirailler",
    "tiraillerons": "tirailler",
    "tirailleront": "tirailler",
    "tirailles": "tirailler",
    "tirailleurs": "tirailleur",
    "tiraillez": "tirailler",
    "tirailliez": "tirailler",
    "tiraillions": "tirailler",
    "tiraillons": "tirailler",
    "tiraillâmes": "tirailler",
    "tiraillât": "tirailler",
    "tiraillâtes": "tirailler",
    "tiraillèrent": "tirailler",
    "tiraillé": "tirailler",
    "tiraillée": "tirailler",
    "tiraillées": "tirailler",
    "tiraillés": "tirailler",
    "tirais": "tirer",
    "tirait": "tirer",
    "tirant": "tirer",
    "tirants": "tirant",
    "tiras": "tirer",
    "tirasse": "tirer",
    "tirassent": "tirer",
    "tirasses": "tirer",
    "tirassiez": "tirer",
    "tirassions": "tirer",
    "tire": "tirer",
    "tire-bottes": "tire-botte",
    "tire-bouchonnaient": "tire-bouchonner",
    "tire-bouchonnant": "tire-bouchonner",
    "tire-bouchonne": "tire-bouchonner",
    "tire-bouchonnent": "tire-bouchonner",
    "tire-bouchonné": "tire-bouchonner",
    "tire-bouchonnés": "tire-bouchonner",
    "tire-bouchons": "tire-bouchon",
    "tire-clous": "tire-clou",
    "tire-fonds": "tire-fond",
    "tire-laits": "tire-lait",
    "tire-lignes": "tire-ligne",
    "tirebouchonné": "tirebouchonner",
    "tirebouchonnée": "tirebouchonner",
    "tirelirent": "tirelirer",
    "tirelires": "tirelire",
    "tirent": "tirer",
    "tirera": "tirer",
    "tirerai": "tirer",
    "tireraient": "tirer",
    "tirerais": "tirer",
    "tirerait": "tirer",
    "tireras": "tirer",
    "tirerez": "tirer",
    "tireriez": "tirer",
    "tirerions": "tirer",
    "tirerons": "tirer",
    "tireront": "tirer",
    "tires": "tirer",
    "tiretaines": "tiretaine",
    "tirets": "tiret",
    "tirettes": "tirette",
    "tireurs": "tireur",
    "tireuse": "tireur",
    "tireuses": "tireur",
    "tirez": "tirer",
    "tiriez": "tirer",
    "tirions": "tirer",
    "tiroirs": "tiroir",
    "tiroirs-caisses": "tiroir-caisse",
    "tirons": "tirer",
    "tirs": "tir",
    "tirâmes": "tirer",
    "tirât": "tirer",
    "tirâtes": "tirer",
    "tirèrent": "tirer",
    "tiré": "tirer",
    "tirée": "tirer",
    "tirées": "tirer",
    "tirés": "tirer",
    "tisa": "tiser",
    "tisanes": "tisane",
    "tisané": "tisaner",
    "tisonna": "tisonner",
    "tisonnai": "tisonner",
    "tisonnaient": "tisonner",
    "tisonnais": "tisonner",
    "tisonnait": "tisonner",
    "tisonnant": "tisonner",
    "tisonnas": "tisonner",
    "tisonnasse": "tisonner",
    "tisonnassent": "tisonner",
    "tisonnasses": "tisonner",
    "tisonnassiez": "tisonner",
    "tisonnassions": "tisonner",
    "tisonne": "tisonner",
    "tisonnent": "tisonner",
    "tisonnera": "tisonner",
    "tisonnerai": "tisonner",
    "tisonneraient": "tisonner",
    "tisonnerais": "tisonner",
    "tisonnerait": "tisonner",
    "tisonneras": "tisonner",
    "tisonnerez": "tisonner",
    "tisonneriez": "tisonner",
    "tisonnerions": "tisonner",
    "tisonnerons": "tisonner",
    "tisonneront": "tisonner",
    "tisonnes": "tisonner",
    "tisonnez": "tisonner",
    "tisonniers": "tisonnier",
    "tisonniez": "tisonner",
    "tisonnions": "tisonner",
    "tisonnons": "tisonner",
    "tisonnâmes": "tisonner",
    "tisonnât": "tisonner",
    "tisonnâtes": "tisonner",
    "tisonnèrent": "tisonner",
    "tisonné": "tisonner",
    "tisonnée": "tisonner",
    "tisonnées": "tisonner",
    "tisonnés": "tisonner",
    "tisons": "tison",
    "tissa": "tisser",
    "tissages": "tissage",
    "tissai": "tisser",
    "tissaient": "tisser",
    "tissais": "tisser",
    "tissait": "tisser",
    "tissant": "tisser",
    "tissas": "tisser",
    "tissasse": "tisser",
    "tissassent": "tisser",
    "tissasses": "tisser",
    "tissassiez": "tisser",
    "tissassions": "tisser",
    "tisse": "tisser",
    "tissent": "tisser",
    "tissera": "tisser",
    "tisserai": "tisser",
    "tisseraient": "tisser",
    "tisserais": "tisser",
    "tisserait": "tisser",
    "tisserande": "tisserand",
    "tisserandes": "tisserand",
    "tisserands": "tisserand",
    "tisseras": "tisser",
    "tisserez": "tisser",
    "tisseriez": "tisser",
    "tisserions": "tisser",
    "tisserons": "tisser",
    "tisseront": "tisser",
    "tisses": "tisser",
    "tisseuse": "tisseur",
    "tissez": "tisser",
    "tissiez": "tisser",
    "tissions": "tisser",
    "tissons": "tisser",
    "tissue": "tissu",
    "tissues": "tissu",
    "tissulaires": "tissulaire",
    "tissus": "tissu",
    "tissus-éponge": "tissu-éponge",
    "tissâmes": "tisser",
    "tissât": "tisser",
    "tissâtes": "tisser",
    "tissèrent": "tisser",
    "tissé": "tisser",
    "tissée": "tisser",
    "tissées": "tisser",
    "tissés": "tisser",
    "titanes": "titane",
    "titanesques": "titanesque",
    "titans": "titan",
    "titilla": "titiller",
    "titillai": "titiller",
    "titillaient": "titiller",
    "titillais": "titiller",
    "titillait": "titiller",
    "titillant": "titiller",
    "titillas": "titiller",
    "titillasse": "titiller",
    "titillassent": "titiller",
    "titillasses": "titiller",
    "titillassiez": "titiller",
    "titillassions": "titiller",
    "titillations": "titillation",
    "titille": "titiller",
    "titillements": "titillement",
    "titillent": "titiller",
    "titillera": "titiller",
    "titillerai": "titiller",
    "titilleraient": "titiller",
    "titillerais": "titiller",
    "titillerait": "titiller",
    "titilleras": "titiller",
    "titillerez": "titiller",
    "titilleriez": "titiller",
    "titillerions": "titiller",
    "titillerons": "titiller",
    "titilleront": "titiller",
    "titilles": "titiller",
    "titillez": "titiller",
    "titilliez": "titiller",
    "titillions": "titiller",
    "titillons": "titiller",
    "titillâmes": "titiller",
    "titillât": "titiller",
    "titillâtes": "titiller",
    "titillèrent": "titiller",
    "titillé": "titiller",
    "titillée": "titiller",
    "titillées": "titiller",
    "titillés": "titiller",
    "titis": "titi",
    "titra": "titrer",
    "titrai": "titrer",
    "titraient": "titrer",
    "titrais": "titrer",
    "titrait": "titrer",
    "titrant": "titrer",
    "titras": "titrer",
    "titrasse": "titrer",
    "titrassent": "titrer",
    "titrasses": "titrer",
    "titrassiez": "titrer",
    "titrassions": "titrer",
    "titre": "titrer",
    "titrent": "titrer",
    "titrera": "titrer",
    "titrerai": "titrer",
    "titreraient": "titrer",
    "titrerais": "titrer",
    "titrerait": "titrer",
    "titreras": "titrer",
    "titrerez": "titrer",
    "titreriez": "titrer",
    "titrerions": "titrer",
    "titrerons": "titrer",
    "titreront": "titrer",
    "titres": "titrer",
    "titrez": "titrer",
    "titriez": "titrer",
    "titrions": "titrer",
    "titrons": "titrer",
    "titrâmes": "titrer",
    "titrât": "titrer",
    "titrâtes": "titrer",
    "titrèrent": "titrer",
    "titré": "titrer",
    "titrée": "titrer",
    "titrées": "titrer",
    "titrés": "titrer",
    "tituba": "tituber",
    "titubai": "tituber",
    "titubaient": "tituber",
    "titubais": "tituber",
    "titubait": "tituber",
    "titubant": "tituber",
    "titubante": "titubant",
    "titubantes": "titubant",
    "titubants": "titubant",
    "titubas": "tituber",
    "titubasse": "tituber",
    "titubassent": "tituber",
    "titubasses": "tituber",
    "titubassiez": "tituber",
    "titubassions": "tituber",
    "titubations": "titubation",
    "titube": "tituber",
    "titubent": "tituber",
    "titubera": "tituber",
    "tituberai": "tituber",
    "tituberaient": "tituber",
    "tituberais": "tituber",
    "tituberait": "tituber",
    "tituberas": "tituber",
    "tituberez": "tituber",
    "tituberiez": "tituber",
    "tituberions": "tituber",
    "tituberons": "tituber",
    "tituberont": "tituber",
    "titubes": "tituber",
    "titubez": "tituber",
    "titubiez": "tituber",
    "titubions": "tituber",
    "titubons": "tituber",
    "titubâmes": "tituber",
    "titubât": "tituber",
    "titubâtes": "tituber",
    "titubèrent": "tituber",
    "titubé": "tituber",
    "titulaires": "titulaire",
    "titularisations": "titularisation",
    "titularisé": "titulariser",
    "titularisée": "titulariser",
    "titularisées": "titularisé",
    "titularisés": "titularisé",
    "tièdes": "tiède",
    "tiédasses": "tiédasse",
    "tiédeurs": "tiédeur",
    "tiédi": "tiédir",
    "tiédie": "tiédir",
    "tiédies": "tiédir",
    "tiédira": "tiédir",
    "tiédirai": "tiédir",
    "tiédiraient": "tiédir",
    "tiédirais": "tiédir",
    "tiédirait": "tiédir",
    "tiédiras": "tiédir",
    "tiédirent": "tiédir",
    "tiédirez": "tiédir",
    "tiédiriez": "tiédir",
    "tiédirions": "tiédir",
    "tiédirons": "tiédir",
    "tiédiront": "tiédir",
    "tiédis": "tiédir",
    "tiédissaient": "tiédir",
    "tiédissais": "tiédir",
    "tiédissait": "tiédir",
    "tiédissant": "tiédir",
    "tiédisse": "tiédir",
    "tiédissent": "tiédir",
    "tiédisses": "tiédir",
    "tiédissez": "tiédir",
    "tiédissiez": "tiédir",
    "tiédissions": "tiédir",
    "tiédissons": "tiédir",
    "tiédit": "tiédir",
    "tiédîmes": "tiédir",
    "tiédît": "tiédir",
    "tiédîtes": "tiédir",
    "tmèses": "tmèse",
    "toasts": "toast",
    "toasté": "toaster",
    "toboggans": "toboggan",
    "toc": "toc.",
    "tocantes": "tocante",
    "tocarde": "tocard",
    "tocardes": "tocard",
    "tocards": "tocard",
    "toccatas": "toccata",
    "toccate": "toccata",
    "tocs": "toc",
    "tocsins": "tocsin",
    "toges": "toge",
    "togolaise": "togolais",
    "togolaises": "togolais",
    "toi": "lui",
    "toilasses": "toiler",
    "toiles": "toile",
    "toiletta": "toiletter",
    "toilettages": "toilettage",
    "toilettai": "toiletter",
    "toilettaient": "toiletter",
    "toilettais": "toiletter",
    "toilettait": "toiletter",
    "toilettant": "toiletter",
    "toilettas": "toiletter",
    "toilettasse": "toiletter",
    "toilettassent": "toiletter",
    "toilettasses": "toiletter",
    "toilettassiez": "toiletter",
    "toilettassions": "toiletter",
    "toilette": "toiletter",
    "toilettent": "toiletter",
    "toilettera": "toiletter",
    "toiletterai": "toiletter",
    "toiletteraient": "toiletter",
    "toiletterais": "toiletter",
    "toiletterait": "toiletter",
    "toiletteras": "toiletter",
    "toiletterez": "toiletter",
    "toiletteriez": "toiletter",
    "toiletterions": "toiletter",
    "toiletterons": "toiletter",
    "toiletteront": "toiletter",
    "toilettes": "toiletter",
    "toilettez": "toiletter",
    "toilettiez": "toiletter",
    "toilettions": "toiletter",
    "toilettons": "toiletter",
    "toilettâmes": "toiletter",
    "toilettât": "toiletter",
    "toilettâtes": "toiletter",
    "toilettèrent": "toiletter",
    "toiletté": "toiletter",
    "toilettée": "toiletter",
    "toilettées": "toiletter",
    "toilettés": "toiletter",
    "toilé": "toiler",
    "toilée": "toiler",
    "toilés": "toiler",
    "toisa": "toiser",
    "toisai": "toiser",
    "toisaient": "toiser",
    "toisais": "toiser",
    "toisait": "toiser",
    "toisant": "toiser",
    "toisas": "toiser",
    "toisasse": "toiser",
    "toisassent": "toiser",
    "toisasses": "toiser",
    "toisassiez": "toiser",
    "toisassions": "toiser",
    "toise": "toiser",
    "toisent": "toiser",
    "toisera": "toiser",
    "toiserai": "toiser",
    "toiseraient": "toiser",
    "toiserais": "toiser",
    "toiserait": "toiser",
    "toiseras": "toiser",
    "toiserez": "toiser",
    "toiseriez": "toiser",
    "toiserions": "toiser",
    "toiserons": "toiser",
    "toiseront": "toiser",
    "toises": "toiser",
    "toisez": "toiser",
    "toisiez": "toiser",
    "toisions": "toiser",
    "toisons": "toison",
    "toisâmes": "toiser",
    "toisât": "toiser",
    "toisâtes": "toiser",
    "toisèrent": "toiser",
    "toisé": "toiser",
    "toisée": "toiser",
    "toisées": "toiser",
    "toisés": "toiser",
    "toits": "toit",
    "toitures": "toiture",
    "tolets": "tolet",
    "tolites": "tolite",
    "tollés": "tollé",
    "toltèques": "toltèque",
    "toluols": "toluol",
    "tolus": "tolu",
    "toluènes": "toluène",
    "tolère": "tolérer",
    "tolèrent": "tolérer",
    "tolères": "tolérer",
    "toléra": "tolérer",
    "tolérables": "tolérable",
    "tolérai": "tolérer",
    "toléraient": "tolérer",
    "tolérais": "tolérer",
    "tolérait": "tolérer",
    "tolérances": "tolérance",
    "tolérant": "tolérer",
    "tolérante": "tolérant",
    "tolérantes": "tolérant",
    "tolérants": "tolérant",
    "toléras": "tolérer",
    "tolérasse": "tolérer",
    "tolérassent": "tolérer",
    "tolérasses": "tolérer",
    "tolérassiez": "tolérer",
    "tolérassions": "tolérer",
    "tolérera": "tolérer",
    "tolérerai": "tolérer",
    "toléreraient": "tolérer",
    "tolérerais": "tolérer",
    "tolérerait": "tolérer",
    "toléreras": "tolérer",
    "tolérerez": "tolérer",
    "toléreriez": "tolérer",
    "tolérerions": "tolérer",
    "tolérerons": "tolérer",
    "toléreront": "tolérer",
    "tolérez": "tolérer",
    "tolériez": "tolérer",
    "tolérions": "tolérer",
    "tolérons": "tolérer",
    "tolérâmes": "tolérer",
    "tolérât": "tolérer",
    "tolérâtes": "tolérer",
    "tolérèrent": "tolérer",
    "toléré": "tolérer",
    "tolérée": "tolérer",
    "tolérées": "tolérer",
    "tolérés": "tolérer",
    "toma": "tomer",
    "tomahawks": "tomahawk",
    "tomaisons": "tomaison",
    "tomates": "tomate",
    "tomba": "tomber",
    "tombai": "tomber",
    "tombaient": "tomber",
    "tombais": "tomber",
    "tombait": "tomber",
    "tombale": "tombal",
    "tombales": "tombal",
    "tombant": "tomber",
    "tombante": "tombant",
    "tombantes": "tombant",
    "tombants": "tombant",
    "tombas": "tomber",
    "tombasse": "tomber",
    "tombassent": "tomber",
    "tombasses": "tomber",
    "tombassiez": "tomber",
    "tombassions": "tomber",
    "tombaux": "tombal",
    "tombe": "tomber",
    "tombeaux": "tombeau",
    "tombent": "tomber",
    "tombera": "tomber",
    "tomberai": "tomber",
    "tomberaient": "tomber",
    "tomberais": "tomber",
    "tomberait": "tomber",
    "tomberas": "tomber",
    "tombereaux": "tombereau",
    "tomberez": "tomber",
    "tomberiez": "tomber",
    "tomberions": "tomber",
    "tomberons": "tomber",
    "tomberont": "tomber",
    "tombes": "tomber",
    "tombeurs": "tombeur",
    "tombeuse": "tombeur",
    "tombeuses": "tombeur",
    "tombez": "tomber",
    "tombiez": "tomber",
    "tombions": "tomber",
    "tombolas": "tombola",
    "tombons": "tomber",
    "tombâmes": "tomber",
    "tombât": "tomber",
    "tombâtes": "tomber",
    "tombèrent": "tomber",
    "tombé": "tomber",
    "tombée": "tomber",
    "tombées": "tomber",
    "tombés": "tomber",
    "tomes": "tome",
    "tomettes": "tomette",
    "tommes": "tomme",
    "tommettes": "tommette",
    "tommys": "tommy",
    "tonale": "tonal",
    "tonales": "tonal",
    "tonalités": "tonalité",
    "tonals": "tonal",
    "tond": "tondre",
    "tondaient": "tondre",
    "tondais": "tondre",
    "tondait": "tondre",
    "tondant": "tondre",
    "tonde": "tondre",
    "tondent": "tondre",
    "tondes": "tondre",
    "tondeuse": "tondeur",
    "tondeuses": "tondeur",
    "tondez": "tondre",
    "tondiez": "tondre",
    "tondions": "tondre",
    "tondirent": "tondre",
    "tondis": "tondre",
    "tondisse": "tondre",
    "tondissent": "tondre",
    "tondisses": "tondre",
    "tondissiez": "tondre",
    "tondissions": "tondre",
    "tondit": "tondre",
    "tondons": "tondre",
    "tondra": "tondre",
    "tondrai": "tondre",
    "tondraient": "tondre",
    "tondrais": "tondre",
    "tondrait": "tondre",
    "tondras": "tondre",
    "tondrez": "tondre",
    "tondriez": "tondre",
    "tondrions": "tondre",
    "tondrons": "tondre",
    "tondront": "tondre",
    "tonds": "tondre",
    "tondu": "tondre",
    "tondue": "tondu",
    "tondues": "tondu",
    "tondus": "tondu",
    "tondîmes": "tondre",
    "tondît": "tondre",
    "tondîtes": "tondre",
    "tongs": "tong",
    "tonicités": "tonicité",
    "tonics": "tonic",
    "tonifia": "tonifier",
    "tonifiai": "tonifier",
    "tonifiaient": "tonifier",
    "tonifiais": "tonifier",
    "tonifiait": "tonifier",
    "tonifiant": "tonifier",
    "tonifiante": "tonifiant",
    "tonifiants": "tonifiant",
    "tonifias": "tonifier",
    "tonifiasse": "tonifier",
    "tonifiassent": "tonifier",
    "tonifiasses": "tonifier",
    "tonifiassiez": "tonifier",
    "tonifiassions": "tonifier",
    "tonifie": "tonifier",
    "tonifient": "tonifier",
    "tonifiera": "tonifier",
    "tonifierai": "tonifier",
    "tonifieraient": "tonifier",
    "tonifierais": "tonifier",
    "tonifierait": "tonifier",
    "tonifieras": "tonifier",
    "tonifierez": "tonifier",
    "tonifieriez": "tonifier",
    "tonifierions": "tonifier",
    "tonifierons": "tonifier",
    "tonifieront": "tonifier",
    "tonifies": "tonifier",
    "tonifiez": "tonifier",
    "tonifiiez": "tonifier",
    "tonifiions": "tonifier",
    "tonifions": "tonifier",
    "tonifiâmes": "tonifier",
    "tonifiât": "tonifier",
    "tonifiâtes": "tonifier",
    "tonifièrent": "tonifier",
    "tonifié": "tonifier",
    "tonifiée": "tonifier",
    "tonifiées": "tonifier",
    "tonifiés": "tonifier",
    "toniques": "tonique",
    "tonitrua": "tonitruer",
    "tonitruai": "tonitruer",
    "tonitruaient": "tonitruer",
    "tonitruais": "tonitruer",
    "tonitruait": "tonitruer",
    "tonitruances": "tonitruance",
    "tonitruant": "tonitruer",
    "tonitruante": "tonitruant",
    "tonitruantes": "tonitruant",
    "tonitruants": "tonitruant",
    "tonitruas": "tonitruer",
    "tonitruasse": "tonitruer",
    "tonitruassent": "tonitruer",
    "tonitruasses": "tonitruer",
    "tonitruassiez": "tonitruer",
    "tonitruassions": "tonitruer",
    "tonitrue": "tonitruer",
    "tonitruent": "tonitruer",
    "tonitruera": "tonitruer",
    "tonitruerai": "tonitruer",
    "tonitrueraient": "tonitruer",
    "tonitruerais": "tonitruer",
    "tonitruerait": "tonitruer",
    "tonitrueras": "tonitruer",
    "tonitruerez": "tonitruer",
    "tonitrueriez": "tonitruer",
    "tonitruerions": "tonitruer",
    "tonitruerons": "tonitruer",
    "tonitrueront": "tonitruer",
    "tonitrues": "tonitruer",
    "tonitruez": "tonitruer",
    "tonitruiez": "tonitruer",
    "tonitruions": "tonitruer",
    "tonitruons": "tonitruer",
    "tonitruâmes": "tonitruer",
    "tonitruât": "tonitruer",
    "tonitruâtes": "tonitruer",
    "tonitruèrent": "tonitruer",
    "tonitrué": "tonitruer",
    "tonkinoise": "tonkinois",
    "tonna": "tonner",
    "tonnages": "tonnage",
    "tonnaient": "tonner",
    "tonnais": "tonner",
    "tonnait": "tonner",
    "tonnant": "tonner",
    "tonnante": "tonnant",
    "tonnantes": "tonnant",
    "tonnants": "tonnant",
    "tonnassent": "tonner",
    "tonne": "tonner",
    "tonneaux": "tonneau",
    "tonnelets": "tonnelet",
    "tonneliers": "tonnelier",
    "tonnelleries": "tonnellerie",
    "tonnelles": "tonnelle",
    "tonnent": "tonner",
    "tonnera": "tonner",
    "tonneraient": "tonner",
    "tonnerait": "tonner",
    "tonneront": "tonner",
    "tonnerres": "tonnerre",
    "tonnes": "tonner",
    "tonnez": "tonner",
    "tonnât": "tonner",
    "tonnèrent": "tonner",
    "tonné": "tonner",
    "tons": "ton",
    "tonsures": "tonsure",
    "tonsuré": "tonsurer",
    "tontes": "tonte",
    "tontines": "tontine",
    "tontons": "tonton",
    "top models": "top model",
    "top-modèles": "top-modèle",
    "topa": "toper",
    "topai": "toper",
    "topaient": "toper",
    "topais": "toper",
    "topait": "toper",
    "topant": "toper",
    "topas": "toper",
    "topasse": "toper",
    "topassent": "toper",
    "topasses": "toper",
    "topassiez": "toper",
    "topassions": "toper",
    "topazes": "topaze",
    "tope": "toper",
    "topent": "toper",
    "topera": "toper",
    "toperai": "toper",
    "toperaient": "toper",
    "toperais": "toper",
    "toperait": "toper",
    "toperas": "toper",
    "toperez": "toper",
    "toperiez": "toper",
    "toperions": "toper",
    "toperons": "toper",
    "toperont": "toper",
    "topes": "toper",
    "topettes": "topette",
    "topez": "toper",
    "topiez": "toper",
    "topinambours": "topinambour",
    "topions": "toper",
    "topiques": "topique",
    "topographies": "topographie",
    "topographiques": "topographique",
    "topologies": "topologie",
    "topons": "toper",
    "toponymies": "toponymie",
    "topos": "topo",
    "tops": "top",
    "topâmes": "toper",
    "topât": "toper",
    "topâtes": "toper",
    "topèrent": "toper",
    "topé": "toper",
    "topés": "toper",
    "toqua": "toquer",
    "toquades": "toquade",
    "toquai": "toquer",
    "toquaient": "toquer",
    "toquais": "toquer",
    "toquait": "toquer",
    "toquant": "toquer",
    "toquantes": "toquante",
    "toquarde": "toquard",
    "toquardes": "toquard",
    "toquards": "toquard",
    "toquas": "toquer",
    "toquasse": "toquer",
    "toquassent": "toquer",
    "toquasses": "toquer",
    "toquassiez": "toquer",
    "toquassions": "toquer",
    "toque": "toquer",
    "toquent": "toquer",
    "toquera": "toquer",
    "toquerai": "toquer",
    "toqueraient": "toquer",
    "toquerais": "toquer",
    "toquerait": "toquer",
    "toqueras": "toquer",
    "toquerez": "toquer",
    "toqueriez": "toquer",
    "toquerions": "toquer",
    "toquerons": "toquer",
    "toqueront": "toquer",
    "toques": "toquer",
    "toquez": "toquer",
    "toquiez": "toquer",
    "toquions": "toquer",
    "toquons": "toquer",
    "toquâmes": "toquer",
    "toquât": "toquer",
    "toquâtes": "toquer",
    "toquèrent": "toquer",
    "toqué": "toquer",
    "toquée": "toquer",
    "toquées": "toquer",
    "toqués": "toquer",
    "torcha": "torcher",
    "torchai": "torcher",
    "torchaient": "torcher",
    "torchais": "torcher",
    "torchait": "torcher",
    "torchant": "torcher",
    "torchas": "torcher",
    "torchasse": "torcher",
    "torchassent": "torcher",
    "torchasses": "torcher",
    "torchassiez": "torcher",
    "torchassions": "torcher",
    "torche": "torcher",
    "torchent": "torcher",
    "torchera": "torcher",
    "torcherai": "torcher",
    "torcheraient": "torcher",
    "torcherais": "torcher",
    "torcherait": "torcher",
    "torcheras": "torcher",
    "torcherez": "torcher",
    "torcheriez": "torcher",
    "torcherions": "torcher",
    "torcherons": "torcher",
    "torcheront": "torcher",
    "torches": "torcher",
    "torchez": "torcher",
    "torchiez": "torcher",
    "torchions": "torcher",
    "torchonna": "torchonner",
    "torchonnai": "torchonner",
    "torchonnaient": "torchonner",
    "torchonnais": "torchonner",
    "torchonnait": "torchonner",
    "torchonnant": "torchonner",
    "torchonnas": "torchonner",
    "torchonnasse": "torchonner",
    "torchonnassent": "torchonner",
    "torchonnasses": "torchonner",
    "torchonnassiez": "torchonner",
    "torchonnassions": "torchonner",
    "torchonne": "torchonner",
    "torchonnent": "torchonner",
    "torchonnera": "torchonner",
    "torchonnerai": "torchonner",
    "torchonneraient": "torchonner",
    "torchonnerais": "torchonner",
    "torchonnerait": "torchonner",
    "torchonneras": "torchonner",
    "torchonnerez": "torchonner",
    "torchonneriez": "torchonner",
    "torchonnerions": "torchonner",
    "torchonnerons": "torchonner",
    "torchonneront": "torchonner",
    "torchonnes": "torchonner",
    "torchonnez": "torchonner",
    "torchonniez": "torchonner",
    "torchonnions": "torchonner",
    "torchonnons": "torchonner",
    "torchonnâmes": "torchonner",
    "torchonnât": "torchonner",
    "torchonnâtes": "torchonner",
    "torchonnèrent": "torchonner",
    "torchonné": "torchonner",
    "torchonnée": "torchonner",
    "torchonnées": "torchonner",
    "torchonnés": "torchonner",
    "torchons": "torchon",
    "torchâmes": "torcher",
    "torchât": "torcher",
    "torchâtes": "torcher",
    "torchèrent": "torcher",
    "torchères": "torchère",
    "torché": "torcher",
    "torchée": "torcher",
    "torchées": "torcher",
    "torchés": "torcher",
    "tord": "tordre",
    "tordaient": "tordre",
    "tordais": "tordre",
    "tordait": "tordre",
    "tordant": "tordre",
    "tordante": "tordant",
    "tordantes": "tordant",
    "tordants": "tordant",
    "torde": "tordre",
    "tordent": "tordre",
    "tordes": "tordre",
    "tordeurs": "tordeur",
    "tordez": "tordre",
    "tordiez": "tordre",
    "tordions": "tordre",
    "tordirent": "tordre",
    "tordis": "tordre",
    "tordisse": "tordre",
    "tordissent": "tordre",
    "tordisses": "tordre",
    "tordissiez": "tordre",
    "tordissions": "tordre",
    "tordit": "tordre",
    "tordons": "tordre",
    "tordra": "tordre",
    "tordrai": "tordre",
    "tordraient": "tordre",
    "tordrais": "tordre",
    "tordrait": "tordre",
    "tordras": "tordre",
    "tordrez": "tordre",
    "tordriez": "tordre",
    "tordrions": "tordre",
    "tordrons": "tordre",
    "tordront": "tordre",
    "tords": "tordre",
    "tordu": "tordre",
    "tordue": "tordu",
    "tordues": "tordu",
    "tordus": "tordu",
    "tordîmes": "tordre",
    "tordît": "tordre",
    "tordîtes": "tordre",
    "toreros": "torero",
    "tores": "tore",
    "torgnoles": "torgnole",
    "torils": "toril",
    "tornades": "tornade",
    "torons": "toron",
    "torpeurs": "torpeur",
    "torpides": "torpide",
    "torpilla": "torpiller",
    "torpillages": "torpillage",
    "torpillai": "torpiller",
    "torpillaient": "torpiller",
    "torpillais": "torpiller",
    "torpillait": "torpiller",
    "torpillant": "torpiller",
    "torpillas": "torpiller",
    "torpillasse": "torpiller",
    "torpillassent": "torpiller",
    "torpillasses": "torpiller",
    "torpillassiez": "torpiller",
    "torpillassions": "torpiller",
    "torpille": "torpiller",
    "torpillent": "torpiller",
    "torpillera": "torpiller",
    "torpillerai": "torpiller",
    "torpilleraient": "torpiller",
    "torpillerais": "torpiller",
    "torpillerait": "torpiller",
    "torpilleras": "torpiller",
    "torpillerez": "torpiller",
    "torpilleriez": "torpiller",
    "torpillerions": "torpiller",
    "torpillerons": "torpiller",
    "torpilleront": "torpiller",
    "torpilles": "torpiller",
    "torpilleurs": "torpilleur",
    "torpillez": "torpiller",
    "torpilliez": "torpiller",
    "torpillions": "torpiller",
    "torpillons": "torpiller",
    "torpillâmes": "torpiller",
    "torpillât": "torpiller",
    "torpillâtes": "torpiller",
    "torpillèrent": "torpiller",
    "torpillé": "torpiller",
    "torpillée": "torpiller",
    "torpillées": "torpiller",
    "torpillés": "torpiller",
    "torpédos": "torpédo",
    "torrentielle": "torrentiel",
    "torrentielles": "torrentiel",
    "torrentiels": "torrentiel",
    "torrents": "torrent",
    "torrentueuse": "torrentueux",
    "torrentueuses": "torrentueux",
    "torrides": "torride",
    "torréfia": "torréfier",
    "torréfiai": "torréfier",
    "torréfiaient": "torréfier",
    "torréfiais": "torréfier",
    "torréfiait": "torréfier",
    "torréfiant": "torréfier",
    "torréfias": "torréfier",
    "torréfiasse": "torréfier",
    "torréfiassent": "torréfier",
    "torréfiasses": "torréfier",
    "torréfiassiez": "torréfier",
    "torréfiassions": "torréfier",
    "torréfie": "torréfier",
    "torréfient": "torréfier",
    "torréfiera": "torréfier",
    "torréfierai": "torréfier",
    "torréfieraient": "torréfier",
    "torréfierais": "torréfier",
    "torréfierait": "torréfier",
    "torréfieras": "torréfier",
    "torréfierez": "torréfier",
    "torréfieriez": "torréfier",
    "torréfierions": "torréfier",
    "torréfierons": "torréfier",
    "torréfieront": "torréfier",
    "torréfies": "torréfier",
    "torréfiez": "torréfier",
    "torréfiiez": "torréfier",
    "torréfiions": "torréfier",
    "torréfions": "torréfier",
    "torréfiâmes": "torréfier",
    "torréfiât": "torréfier",
    "torréfiâtes": "torréfier",
    "torréfièrent": "torréfier",
    "torréfié": "torréfier",
    "torréfiée": "torréfier",
    "torréfiées": "torréfier",
    "torréfiés": "torréfier",
    "torsada": "torsader",
    "torsades": "torsade",
    "torsadé": "torsader",
    "torsadée": "torsader",
    "torsadées": "torsader",
    "torsadés": "torsader",
    "torse": "tors",
    "torses": "torse",
    "torsiomètres": "torsiomètre",
    "torsions": "torsion",
    "torss": "tors",
    "tortellinis": "tortellini",
    "tortilla": "tortiller",
    "tortillai": "tortiller",
    "tortillaient": "tortiller",
    "tortillais": "tortiller",
    "tortillait": "tortiller",
    "tortillant": "tortiller",
    "tortillards": "tortillard",
    "tortillas": "tortiller",
    "tortillasse": "tortiller",
    "tortillassent": "tortiller",
    "tortillasses": "tortiller",
    "tortillassiez": "tortiller",
    "tortillassions": "tortiller",
    "tortille": "tortiller",
    "tortillements": "tortillement",
    "tortillent": "tortiller",
    "tortillera": "tortiller",
    "tortillerai": "tortiller",
    "tortilleraient": "tortiller",
    "tortillerais": "tortiller",
    "tortillerait": "tortiller",
    "tortilleras": "tortiller",
    "tortillerez": "tortiller",
    "tortilleriez": "tortiller",
    "tortillerions": "tortiller",
    "tortillerons": "tortiller",
    "tortilleront": "tortiller",
    "tortilles": "tortiller",
    "tortillez": "tortiller",
    "tortilliez": "tortiller",
    "tortillions": "tortiller",
    "tortillons": "tortillon",
    "tortillâmes": "tortiller",
    "tortillât": "tortiller",
    "tortillâtes": "tortiller",
    "tortillèrent": "tortiller",
    "tortillé": "tortiller",
    "tortillée": "tortiller",
    "tortillées": "tortiller",
    "tortillés": "tortiller",
    "tortils": "tortil",
    "tortionnaires": "tortionnaire",
    "tortora": "tortorer",
    "tortorait": "tortorer",
    "tortorant": "tortorer",
    "tortorent": "tortorer",
    "tortoré": "tortorer",
    "torts": "tort",
    "tortue": "tortu",
    "tortues": "tortue",
    "tortueuse": "tortueux",
    "tortueuses": "tortueux",
    "tortura": "torturer",
    "torturai": "torturer",
    "torturaient": "torturer",
    "torturais": "torturer",
    "torturait": "torturer",
    "torturant": "torturer",
    "torturante": "torturant",
    "torturantes": "torturant",
    "torturants": "torturant",
    "torturas": "torturer",
    "torturasse": "torturer",
    "torturassent": "torturer",
    "torturasses": "torturer",
    "torturassiez": "torturer",
    "torturassions": "torturer",
    "torture": "torturer",
    "torturent": "torturer",
    "torturera": "torturer",
    "torturerai": "torturer",
    "tortureraient": "torturer",
    "torturerais": "torturer",
    "torturerait": "torturer",
    "tortureras": "torturer",
    "torturerez": "torturer",
    "tortureriez": "torturer",
    "torturerions": "torturer",
    "torturerons": "torturer",
    "tortureront": "torturer",
    "tortures": "torturer",
    "tortureurs": "tortureur",
    "torturez": "torturer",
    "torturiez": "torturer",
    "torturions": "torturer",
    "torturons": "torturer",
    "torturâmes": "torturer",
    "torturât": "torturer",
    "torturâtes": "torturer",
    "torturèrent": "torturer",
    "torturé": "torturer",
    "torturée": "torturer",
    "torturées": "torturer",
    "torturés": "torturer",
    "tortus": "tortu",
    "torves": "torve",
    "torys": "tory",
    "toréa": "toréer",
    "toréadors": "toréador",
    "toréai": "toréer",
    "toréaient": "toréer",
    "toréais": "toréer",
    "toréait": "toréer",
    "toréant": "toréer",
    "toréas": "toréer",
    "toréasse": "toréer",
    "toréassent": "toréer",
    "toréasses": "toréer",
    "toréassiez": "toréer",
    "toréassions": "toréer",
    "torée": "toréer",
    "toréent": "toréer",
    "toréera": "toréer",
    "toréerai": "toréer",
    "toréeraient": "toréer",
    "toréerais": "toréer",
    "toréerait": "toréer",
    "toréeras": "toréer",
    "toréerez": "toréer",
    "toréeriez": "toréer",
    "toréerions": "toréer",
    "toréerons": "toréer",
    "toréeront": "toréer",
    "torées": "toréer",
    "toréez": "toréer",
    "toréiez": "toréer",
    "toréions": "toréer",
    "toréons": "toréer",
    "toréâmes": "toréer",
    "toréât": "toréer",
    "toréâtes": "toréer",
    "toréèrent": "toréer",
    "toréé": "toréer",
    "toréée": "toréer",
    "toréées": "toréer",
    "toréés": "toréer",
    "tos": "to",
    "toscane": "toscan",
    "toscanes": "toscan",
    "toscans": "toscan",
    "tossé": "tosser",
    "totale": "total",
    "totales": "total",
    "totalisa": "totaliser",
    "totalisai": "totaliser",
    "totalisaient": "totaliser",
    "totalisais": "totaliser",
    "totalisait": "totaliser",
    "totalisant": "totaliser",
    "totalisas": "totaliser",
    "totalisasse": "totaliser",
    "totalisassent": "totaliser",
    "totalisasses": "totaliser",
    "totalisassiez": "totaliser",
    "totalisassions": "totaliser",
    "totalisations": "totalisation",
    "totalise": "totaliser",
    "totalisent": "totaliser",
    "totalisera": "totaliser",
    "totaliserai": "totaliser",
    "totaliseraient": "totaliser",
    "totaliserais": "totaliser",
    "totaliserait": "totaliser",
    "totaliseras": "totaliser",
    "totaliserez": "totaliser",
    "totaliseriez": "totaliser",
    "totaliserions": "totaliser",
    "totaliserons": "totaliser",
    "totaliseront": "totaliser",
    "totalises": "totaliser",
    "totalisez": "totaliser",
    "totalisiez": "totaliser",
    "totalisions": "totaliser",
    "totalisons": "totaliser",
    "totalisâmes": "totaliser",
    "totalisât": "totaliser",
    "totalisâtes": "totaliser",
    "totalisèrent": "totaliser",
    "totalisé": "totaliser",
    "totalisée": "totaliser",
    "totalisées": "totaliser",
    "totalisés": "totaliser",
    "totalitaires": "totalitaire",
    "totalitarismes": "totalitarisme",
    "totalités": "totalité",
    "totaux": "total",
    "totems": "totem",
    "totoches": "totoche",
    "totons": "toton",
    "totos": "toto",
    "totémiques": "totémique",
    "totémismes": "totémisme",
    "toua": "touer",
    "touai": "touer",
    "touaient": "touer",
    "touais": "touer",
    "touait": "touer",
    "touant": "touer",
    "touaregs": "touareg",
    "touas": "touer",
    "touasse": "touer",
    "touassent": "touer",
    "touasses": "touer",
    "touassiez": "touer",
    "touassions": "touer",
    "toubabs": "toubab",
    "toubibs": "toubib",
    "toucans": "toucan",
    "toucha": "toucher",
    "touchai": "toucher",
    "touchaient": "toucher",
    "touchais": "toucher",
    "touchait": "toucher",
    "touchant": "toucher",
    "touchante": "touchant",
    "touchantes": "touchant",
    "touchants": "touchant",
    "touchas": "toucher",
    "touchasse": "toucher",
    "touchassent": "toucher",
    "touchasses": "toucher",
    "touchassiez": "toucher",
    "touchassions": "toucher",
    "touche": "toucher",
    "touchent": "toucher",
    "touchera": "toucher",
    "toucherai": "toucher",
    "toucheraient": "toucher",
    "toucherais": "toucher",
    "toucherait": "toucher",
    "toucheras": "toucher",
    "toucherez": "toucher",
    "toucheriez": "toucher",
    "toucherions": "toucher",
    "toucherons": "toucher",
    "toucheront": "toucher",
    "touchers": "toucher",
    "touches": "toucher",
    "touchez": "toucher",
    "touchiez": "toucher",
    "touchions": "toucher",
    "touchons": "toucher",
    "touchâmes": "toucher",
    "touchât": "toucher",
    "touchâtes": "toucher",
    "touchèrent": "toucher",
    "touché": "toucher",
    "touchée": "toucher",
    "touchées": "toucher",
    "touchés": "toucher",
    "toue": "touer",
    "touent": "touer",
    "touera": "touer",
    "touerai": "touer",
    "toueraient": "touer",
    "touerais": "touer",
    "touerait": "touer",
    "toueras": "touer",
    "touerez": "touer",
    "toueriez": "touer",
    "touerions": "touer",
    "touerons": "touer",
    "toueront": "touer",
    "toues": "touer",
    "touez": "touer",
    "touffes": "touffe",
    "touffeurs": "touffeur",
    "touffue": "touffu",
    "touffues": "touffu",
    "touffus": "touffu",
    "touiez": "touer",
    "touilla": "touiller",
    "touillai": "touiller",
    "touillaient": "touiller",
    "touillais": "touiller",
    "touillait": "touiller",
    "touillant": "touiller",
    "touillas": "touiller",
    "touillasse": "touiller",
    "touillassent": "touiller",
    "touillasses": "touiller",
    "touillassiez": "touiller",
    "touillassions": "touiller",
    "touille": "touiller",
    "touillent": "touiller",
    "touillera": "touiller",
    "touillerai": "touiller",
    "touilleraient": "touiller",
    "touillerais": "touiller",
    "touillerait": "touiller",
    "touilleras": "touiller",
    "touillerez": "touiller",
    "touilleriez": "touiller",
    "touillerions": "touiller",
    "touillerons": "touiller",
    "touilleront": "touiller",
    "touilles": "touiller",
    "touillez": "touiller",
    "touilliez": "touiller",
    "touillions": "touiller",
    "touillons": "touiller",
    "touillâmes": "touiller",
    "touillât": "touiller",
    "touillâtes": "touiller",
    "touillèrent": "touiller",
    "touillé": "touiller",
    "touillée": "touiller",
    "touillées": "touiller",
    "touillés": "touiller",
    "touions": "touer",
    "touloupes": "touloupe",
    "toulousaine": "toulousain",
    "toulousaines": "toulousain",
    "toulousains": "toulousain",
    "toundras": "toundra",
    "touons": "touer",
    "toupets": "toupet",
    "toupies": "toupie",
    "toupinant": "toupiner",
    "touques": "touque",
    "tourailles": "touraille",
    "tourangeaux": "tourangeau",
    "tourangelle": "tourangeau",
    "tourangelles": "tourangeau",
    "tourbes": "tourbe",
    "tourbeuse": "tourbeux",
    "tourbiers": "tourbier",
    "tourbillonna": "tourbillonner",
    "tourbillonnai": "tourbillonner",
    "tourbillonnaient": "tourbillonner",
    "tourbillonnais": "tourbillonner",
    "tourbillonnait": "tourbillonner",
    "tourbillonnant": "tourbillonner",
    "tourbillonnante": "tourbillonnant",
    "tourbillonnantes": "tourbillonnant",
    "tourbillonnants": "tourbillonnant",
    "tourbillonnas": "tourbillonner",
    "tourbillonnasse": "tourbillonner",
    "tourbillonnassent": "tourbillonner",
    "tourbillonnasses": "tourbillonner",
    "tourbillonnassiez": "tourbillonner",
    "tourbillonnassions": "tourbillonner",
    "tourbillonne": "tourbillonner",
    "tourbillonnements": "tourbillonnement",
    "tourbillonnent": "tourbillonner",
    "tourbillonnera": "tourbillonner",
    "tourbillonnerai": "tourbillonner",
    "tourbillonneraient": "tourbillonner",
    "tourbillonnerais": "tourbillonner",
    "tourbillonnerait": "tourbillonner",
    "tourbillonneras": "tourbillonner",
    "tourbillonnerez": "tourbillonner",
    "tourbillonneriez": "tourbillonner",
    "tourbillonnerions": "tourbillonner",
    "tourbillonnerons": "tourbillonner",
    "tourbillonneront": "tourbillonner",
    "tourbillonnes": "tourbillonner",
    "tourbillonnez": "tourbillonner",
    "tourbillonniez": "tourbillonner",
    "tourbillonnions": "tourbillonner",
    "tourbillonnons": "tourbillonner",
    "tourbillonnâmes": "tourbillonner",
    "tourbillonnât": "tourbillonner",
    "tourbillonnâtes": "tourbillonner",
    "tourbillonnèrent": "tourbillonner",
    "tourbillonné": "tourbillonner",
    "tourbillons": "tourbillon",
    "tourbières": "tourbière",
    "tourde": "tourd",
    "tourdilles": "tourdille",
    "tourelles": "tourelle",
    "tourets": "touret",
    "touries": "tourie",
    "tourillons": "tourillon",
    "tourins": "tourin",
    "tourismes": "tourisme",
    "touristes": "touriste",
    "touristiques": "touristique",
    "tourière": "tourier",
    "tourmalines": "tourmaline",
    "tourmenta": "tourmenter",
    "tourmentai": "tourmenter",
    "tourmentaient": "tourmenter",
    "tourmentais": "tourmenter",
    "tourmentait": "tourmenter",
    "tourmentant": "tourmenter",
    "tourmentante": "tourmentant",
    "tourmentantes": "tourmentant",
    "tourmentas": "tourmenter",
    "tourmentasse": "tourmenter",
    "tourmentassent": "tourmenter",
    "tourmentasses": "tourmenter",
    "tourmentassiez": "tourmenter",
    "tourmentassions": "tourmenter",
    "tourmente": "tourmenter",
    "tourmentent": "tourmenter",
    "tourmentera": "tourmenter",
    "tourmenterai": "tourmenter",
    "tourmenteraient": "tourmenter",
    "tourmenterais": "tourmenter",
    "tourmenterait": "tourmenter",
    "tourmenteras": "tourmenter",
    "tourmenterez": "tourmenter",
    "tourmenteriez": "tourmenter",
    "tourmenterions": "tourmenter",
    "tourmenterons": "tourmenter",
    "tourmenteront": "tourmenter",
    "tourmentes": "tourmenter",
    "tourmenteurs": "tourmenteur",
    "tourmentez": "tourmenter",
    "tourmentiez": "tourmenter",
    "tourmentins": "tourmentin",
    "tourmentions": "tourmenter",
    "tourmentons": "tourmenter",
    "tourments": "tourment",
    "tourmentâmes": "tourmenter",
    "tourmentât": "tourmenter",
    "tourmentâtes": "tourmenter",
    "tourmentèrent": "tourmenter",
    "tourmenté": "tourmenter",
    "tourmentée": "tourmenter",
    "tourmentées": "tourmenter",
    "tourmentés": "tourmenter",
    "tourna": "tourner",
    "tournages": "tournage",
    "tournai": "tourner",
    "tournaient": "tourner",
    "tournaillaient": "tournailler",
    "tournaillé": "tournailler",
    "tournais": "tourner",
    "tournait": "tourner",
    "tournant": "tourner",
    "tournante": "tournant",
    "tournantes": "tournant",
    "tournants": "tournant",
    "tournas": "tourner",
    "tournasse": "tourner",
    "tournassent": "tourner",
    "tournasses": "tourner",
    "tournassiez": "tourner",
    "tournassions": "tourner",
    "tourne": "tourner",
    "tourne-disques": "tourne-disque",
    "tourne-pierres": "tourne-pierre",
    "tourneboulant": "tournebouler",
    "tourneboule": "tournebouler",
    "tourneboulé": "tournebouler",
    "tourneboulée": "tournebouler",
    "tourneboulés": "tournebouler",
    "tournebroches": "tournebroche",
    "tournements": "tournement",
    "tournent": "tourner",
    "tournera": "tourner",
    "tournerai": "tourner",
    "tourneraient": "tourner",
    "tournerais": "tourner",
    "tournerait": "tourner",
    "tourneras": "tourner",
    "tournerez": "tourner",
    "tourneries": "tournerie",
    "tourneriez": "tourner",
    "tournerions": "tourner",
    "tournerons": "tourner",
    "tourneront": "tourner",
    "tournes": "tourner",
    "tournesols": "tournesol",
    "tourneurs": "tourneur",
    "tourneuses": "tourneur",
    "tournez": "tourner",
    "tournicota": "tournicoter",
    "tournicotais": "tournicoter",
    "tournicotait": "tournicoter",
    "tournicotant": "tournicoter",
    "tournicote": "tournicoter",
    "tournicotent": "tournicoter",
    "tournicoterais": "tournicoter",
    "tournicoté": "tournicoter",
    "tournicotés": "tournicoter",
    "tourniez": "tourner",
    "tournillant": "tourniller",
    "tournions": "tourner",
    "tourniquant": "tourniquer",
    "tournique": "tourniquer",
    "tourniquets": "tourniquet",
    "tournoie": "tournoyer",
    "tournoiements": "tournoiement",
    "tournoient": "tournoyer",
    "tournoiera": "tournoyer",
    "tournoierai": "tournoyer",
    "tournoieraient": "tournoyer",
    "tournoierais": "tournoyer",
    "tournoierait": "tournoyer",
    "tournoieras": "tournoyer",
    "tournoierez": "tournoyer",
    "tournoieriez": "tournoyer",
    "tournoierions": "tournoyer",
    "tournoierons": "tournoyer",
    "tournoieront": "tournoyer",
    "tournoies": "tournoyer",
    "tournois": "tournoi",
    "tournons": "tourner",
    "tournoya": "tournoyer",
    "tournoyai": "tournoyer",
    "tournoyaient": "tournoyer",
    "tournoyais": "tournoyer",
    "tournoyait": "tournoyer",
    "tournoyant": "tournoyer",
    "tournoyante": "tournoyant",
    "tournoyantes": "tournoyant",
    "tournoyants": "tournoyant",
    "tournoyas": "tournoyer",
    "tournoyasse": "tournoyer",
    "tournoyassent": "tournoyer",
    "tournoyasses": "tournoyer",
    "tournoyassiez": "tournoyer",
    "tournoyassions": "tournoyer",
    "tournoyez": "tournoyer",
    "tournoyiez": "tournoyer",
    "tournoyions": "tournoyer",
    "tournoyons": "tournoyer",
    "tournoyâmes": "tournoyer",
    "tournoyât": "tournoyer",
    "tournoyâtes": "tournoyer",
    "tournoyèrent": "tournoyer",
    "tournoyé": "tournoyer",
    "tournures": "tournure",
    "tournâmes": "tourner",
    "tournât": "tourner",
    "tournâtes": "tourner",
    "tournèrent": "tourner",
    "tourné": "tourner",
    "tournée": "tourner",
    "tournées": "tourner",
    "tournés": "tourner",
    "tourons": "touron",
    "tours": "tour",
    "tours-opérateurs": "tour-opérateur",
    "tourteaux": "tourteau",
    "tourtereaux": "tourtereau",
    "tourterelle": "tourtereau",
    "tourterelles": "tourterelle",
    "tourtes": "tourte",
    "tourtières": "tourtière",
    "tous": "tout",
    "toussa": "tousser",
    "toussai": "tousser",
    "toussaient": "tousser",
    "toussais": "tousser",
    "toussait": "tousser",
    "toussant": "tousser",
    "toussas": "tousser",
    "toussasse": "tousser",
    "toussassent": "tousser",
    "toussasses": "tousser",
    "toussassiez": "tousser",
    "toussassions": "tousser",
    "tousse": "tousser",
    "toussent": "tousser",
    "toussera": "tousser",
    "tousserai": "tousser",
    "tousseraient": "tousser",
    "tousserais": "tousser",
    "tousserait": "tousser",
    "tousseras": "tousser",
    "tousserez": "tousser",
    "tousseriez": "tousser",
    "tousserions": "tousser",
    "tousserons": "tousser",
    "tousseront": "tousser",
    "tousses": "tousser",
    "tousseurs": "tousseur",
    "toussez": "tousser",
    "toussiez": "tousser",
    "toussions": "tousser",
    "toussons": "tousser",
    "toussota": "toussoter",
    "toussotai": "toussoter",
    "toussotaient": "toussoter",
    "toussotait": "toussoter",
    "toussotant": "toussoter",
    "toussote": "toussoter",
    "toussotements": "toussotement",
    "toussotent": "toussoter",
    "toussotiez": "toussoter",
    "toussoté": "toussoter",
    "toussâmes": "tousser",
    "toussât": "tousser",
    "toussâtes": "tousser",
    "toussèrent": "tousser",
    "toussé": "tousser",
    "tout-petits": "tout-petit",
    "tout-puissants": "tout-puissant",
    "tout-terrains": "tout-terrain",
    "toute": "tout",
    "toute-puissante": "tout-puissant",
    "toutes": "toute",
    "toutes-puissantes": "tout-puissant",
    "toutous": "toutou",
    "touts": "tout",
    "touâmes": "touer",
    "touât": "touer",
    "touâtes": "touer",
    "touèrent": "touer",
    "toué": "touer",
    "touée": "touer",
    "touées": "touer",
    "toués": "touer",
    "townships": "township",
    "toxicités": "toxicité",
    "toxicologies": "toxicologie",
    "toxicologiques": "toxicologique",
    "toxicologues": "toxicologue",
    "toxicomanes": "toxicomane",
    "toxicomaniaques": "toxicomaniaque",
    "toxicomanies": "toxicomanie",
    "toxicos": "toxico",
    "toxines": "toxine",
    "toxiques": "toxique",
    "trabans": "traban",
    "traboules": "traboule",
    "tracassa": "tracasser",
    "tracassai": "tracasser",
    "tracassaient": "tracasser",
    "tracassais": "tracasser",
    "tracassait": "tracasser",
    "tracassant": "tracasser",
    "tracassas": "tracasser",
    "tracassasse": "tracasser",
    "tracassassent": "tracasser",
    "tracassasses": "tracasser",
    "tracassassiez": "tracasser",
    "tracassassions": "tracasser",
    "tracasse": "tracasser",
    "tracassent": "tracasser",
    "tracassera": "tracasser",
    "tracasserai": "tracasser",
    "tracasseraient": "tracasser",
    "tracasserais": "tracasser",
    "tracasserait": "tracasser",
    "tracasseras": "tracasser",
    "tracasserez": "tracasser",
    "tracasseries": "tracasserie",
    "tracasseriez": "tracasser",
    "tracasserions": "tracasser",
    "tracasserons": "tracasser",
    "tracasseront": "tracasser",
    "tracasses": "tracasser",
    "tracassez": "tracasser",
    "tracassiers": "tracassier",
    "tracassiez": "tracasser",
    "tracassins": "tracassin",
    "tracassions": "tracasser",
    "tracassière": "tracassier",
    "tracassières": "tracassier",
    "tracassons": "tracasser",
    "tracassâmes": "tracasser",
    "tracassât": "tracasser",
    "tracassâtes": "tracasser",
    "tracassèrent": "tracasser",
    "tracassé": "tracasser",
    "tracassée": "tracasser",
    "tracassées": "tracasser",
    "tracassés": "tracasser",
    "trace": "tracer",
    "tracent": "tracer",
    "tracera": "tracer",
    "tracerai": "tracer",
    "traceraient": "tracer",
    "tracerais": "tracer",
    "tracerait": "tracer",
    "traceras": "tracer",
    "tracerez": "tracer",
    "traceriez": "tracer",
    "tracerions": "tracer",
    "tracerons": "tracer",
    "traceront": "tracer",
    "traces": "tracer",
    "traceurs": "traceur",
    "traceuse": "traceur",
    "traceuses": "traceur",
    "tracez": "tracer",
    "trachomes": "trachome",
    "trachéale": "trachéal",
    "trachéales": "trachéal",
    "trachéaux": "trachéal",
    "trachées": "trachée",
    "trachées-artères": "trachée-artère",
    "traciez": "tracer",
    "tracions": "tracer",
    "tracs": "trac",
    "tracta": "tracter",
    "tractai": "tracter",
    "tractaient": "tracter",
    "tractais": "tracter",
    "tractait": "tracter",
    "tractant": "tracter",
    "tractas": "tracter",
    "tractasse": "tracter",
    "tractassent": "tracter",
    "tractasses": "tracter",
    "tractassiez": "tracter",
    "tractassions": "tracter",
    "tractations": "tractation",
    "tracte": "tracter",
    "tractent": "tracter",
    "tractera": "tracter",
    "tracterai": "tracter",
    "tracteraient": "tracter",
    "tracterais": "tracter",
    "tracterait": "tracter",
    "tracteras": "tracter",
    "tracterez": "tracter",
    "tracteriez": "tracter",
    "tracterions": "tracter",
    "tracterons": "tracter",
    "tracteront": "tracter",
    "tractes": "tracter",
    "tracteurs": "tracteur",
    "tractez": "tracter",
    "tractiez": "tracter",
    "tractions": "traction",
    "tractons": "tracter",
    "tractoristes": "tractoriste",
    "tracts": "tract",
    "tractâmes": "tracter",
    "tractât": "tracter",
    "tractâtes": "tracter",
    "tractèrent": "tracter",
    "tracté": "tracter",
    "tractée": "tracter",
    "tractées": "tracter",
    "tractés": "tracter",
    "tracèrent": "tracer",
    "tracé": "tracer",
    "tracée": "tracer",
    "tracées": "tracer",
    "tracés": "tracer",
    "trade-unions": "trade-union",
    "traditionalismes": "traditionalisme",
    "traditionalistes": "traditionaliste",
    "traditionnelle": "traditionnel",
    "traditionnelles": "traditionnel",
    "traditionnels": "traditionnel",
    "traditions": "tradition",
    "traducteurs": "traducteur",
    "traductions": "traduction",
    "traductrice": "traducteur",
    "traductrices": "traducteur",
    "traduira": "traduire",
    "traduirai": "traduire",
    "traduiraient": "traduire",
    "traduirais": "traduire",
    "traduirait": "traduire",
    "traduiras": "traduire",
    "traduirez": "traduire",
    "traduiriez": "traduire",
    "traduirions": "traduire",
    "traduirons": "traduire",
    "traduiront": "traduire",
    "traduis": "traduire",
    "traduisaient": "traduire",
    "traduisais": "traduire",
    "traduisait": "traduire",
    "traduisant": "traduire",
    "traduise": "traduire",
    "traduisent": "traduire",
    "traduises": "traduire",
    "traduisez": "traduire",
    "traduisibles": "traduisible",
    "traduisiez": "traduire",
    "traduisions": "traduire",
    "traduisirent": "traduire",
    "traduisis": "traduire",
    "traduisisse": "traduire",
    "traduisissent": "traduire",
    "traduisisses": "traduire",
    "traduisissiez": "traduire",
    "traduisissions": "traduire",
    "traduisit": "traduire",
    "traduisons": "traduire",
    "traduisîmes": "traduire",
    "traduisît": "traduire",
    "traduisîtes": "traduire",
    "traduit": "traduire",
    "traduite": "traduire",
    "traduites": "traduire",
    "traduits": "traduire",
    "traficotaient": "traficoter",
    "traficotait": "traficoter",
    "traficote": "traficoter",
    "traficotes": "traficoter",
    "traficoteurs": "traficoteur",
    "traficotez": "traficoter",
    "traficoté": "traficoter",
    "trafics": "trafic",
    "trafiqua": "trafiquer",
    "trafiquai": "trafiquer",
    "trafiquaient": "trafiquer",
    "trafiquais": "trafiquer",
    "trafiquait": "trafiquer",
    "trafiquant": "trafiquer",
    "trafiquante": "trafiquant",
    "trafiquantes": "trafiquant",
    "trafiquants": "trafiquant",
    "trafiquas": "trafiquer",
    "trafiquasse": "trafiquer",
    "trafiquassent": "trafiquer",
    "trafiquasses": "trafiquer",
    "trafiquassiez": "trafiquer",
    "trafiquassions": "trafiquer",
    "trafique": "trafiquer",
    "trafiquent": "trafiquer",
    "trafiquera": "trafiquer",
    "trafiquerai": "trafiquer",
    "trafiqueraient": "trafiquer",
    "trafiquerais": "trafiquer",
    "trafiquerait": "trafiquer",
    "trafiqueras": "trafiquer",
    "trafiquerez": "trafiquer",
    "trafiqueriez": "trafiquer",
    "trafiquerions": "trafiquer",
    "trafiquerons": "trafiquer",
    "trafiqueront": "trafiquer",
    "trafiques": "trafiquer",
    "trafiquez": "trafiquer",
    "trafiquiez": "trafiquer",
    "trafiquions": "trafiquer",
    "trafiquons": "trafiquer",
    "trafiquâmes": "trafiquer",
    "trafiquât": "trafiquer",
    "trafiquâtes": "trafiquer",
    "trafiquèrent": "trafiquer",
    "trafiqué": "trafiquer",
    "trafiquée": "trafiquer",
    "trafiquées": "trafiquer",
    "trafiqués": "trafiquer",
    "tragi-comiques": "tragi-comique",
    "tragi-comédies": "tragi-comédie",
    "tragicomédies": "tragicomédie",
    "tragiques": "tragique",
    "tragédienne": "tragédien",
    "tragédiennes": "tragédien",
    "tragédiens": "tragédien",
    "tragédies": "tragédie",
    "trahi": "trahir",
    "trahie": "trahir",
    "trahies": "trahir",
    "trahira": "trahir",
    "trahirai": "trahir",
    "trahiraient": "trahir",
    "trahirais": "trahir",
    "trahirait": "trahir",
    "trahiras": "trahir",
    "trahirent": "trahir",
    "trahirez": "trahir",
    "trahiriez": "trahir",
    "trahirions": "trahir",
    "trahirons": "trahir",
    "trahiront": "trahir",
    "trahis": "trahir",
    "trahisons": "trahison",
    "trahissaient": "trahir",
    "trahissais": "trahir",
    "trahissait": "trahir",
    "trahissant": "trahir",
    "trahisse": "trahir",
    "trahissent": "trahir",
    "trahisses": "trahir",
    "trahissez": "trahir",
    "trahissiez": "trahir",
    "trahissions": "trahir",
    "trahissons": "trahir",
    "trahit": "trahir",
    "trahîmes": "trahir",
    "trahît": "trahir",
    "trahîtes": "trahir",
    "traie": "traire",
    "traient": "traire",
    "traies": "traire",
    "train-ferries": "train-ferry",
    "trainglots": "trainglot",
    "trainings": "training",
    "trains": "train",
    "traira": "traire",
    "trairai": "traire",
    "trairaient": "traire",
    "trairais": "traire",
    "trairait": "traire",
    "trairas": "traire",
    "trairez": "traire",
    "trairiez": "traire",
    "trairions": "traire",
    "trairons": "traire",
    "trairont": "traire",
    "trais": "traire",
    "trait": "traire",
    "traita": "traiter",
    "traitables": "traitable",
    "traitai": "traiter",
    "traitaient": "traiter",
    "traitais": "traiter",
    "traitait": "traiter",
    "traitant": "traiter",
    "traitante": "traitant",
    "traitants": "traitant",
    "traitas": "traiter",
    "traitasse": "traiter",
    "traitassent": "traiter",
    "traitasses": "traiter",
    "traitassiez": "traiter",
    "traitassions": "traiter",
    "traite": "traiter",
    "traitements": "traitement",
    "traitent": "traiter",
    "traitera": "traiter",
    "traiterai": "traiter",
    "traiteraient": "traiter",
    "traiterais": "traiter",
    "traiterait": "traiter",
    "traiteras": "traiter",
    "traiterez": "traiter",
    "traiteriez": "traiter",
    "traiterions": "traiter",
    "traiterons": "traiter",
    "traiteront": "traiter",
    "traites": "traiter",
    "traiteurs": "traiteur",
    "traitez": "traiter",
    "traitiez": "traiter",
    "traitions": "traiter",
    "traitons": "traiter",
    "traits": "trait",
    "traitâmes": "traiter",
    "traitât": "traiter",
    "traitâtes": "traiter",
    "traitèrent": "traiter",
    "traité": "traiter",
    "traitée": "traiter",
    "traitées": "traiter",
    "traités": "traiter",
    "trajectoires": "trajectoire",
    "trajets": "trajet",
    "tralalas": "tralala",
    "trama": "tramer",
    "tramai": "tramer",
    "tramaient": "tramer",
    "tramails": "tramail",
    "tramais": "tramer",
    "tramait": "tramer",
    "tramant": "tramer",
    "tramas": "tramer",
    "tramasse": "tramer",
    "tramassent": "tramer",
    "tramasses": "tramer",
    "tramassiez": "tramer",
    "tramassions": "tramer",
    "trame": "tramer",
    "trament": "tramer",
    "tramera": "tramer",
    "tramerai": "tramer",
    "trameraient": "tramer",
    "tramerais": "tramer",
    "tramerait": "tramer",
    "trameras": "tramer",
    "tramerez": "tramer",
    "trameriez": "tramer",
    "tramerions": "tramer",
    "tramerons": "tramer",
    "trameront": "tramer",
    "trames": "tramer",
    "tramez": "tramer",
    "tramiez": "tramer",
    "traminots": "traminot",
    "tramions": "tramer",
    "tramons": "tramer",
    "tramontanes": "tramontane",
    "trampolines": "trampoline",
    "trams": "tram",
    "tramways": "tramway",
    "tramâmes": "tramer",
    "tramât": "tramer",
    "tramâtes": "tramer",
    "tramèrent": "tramer",
    "tramé": "tramer",
    "tramée": "tramer",
    "tramées": "tramer",
    "tramés": "tramer",
    "trancha": "trancher",
    "tranchai": "trancher",
    "tranchaient": "trancher",
    "tranchais": "trancher",
    "tranchait": "trancher",
    "tranchant": "trancher",
    "tranchante": "tranchant",
    "tranchantes": "tranchant",
    "tranchants": "tranchant",
    "tranchas": "trancher",
    "tranchasse": "trancher",
    "tranchassent": "trancher",
    "tranchasses": "trancher",
    "tranchassiez": "trancher",
    "tranchassions": "trancher",
    "tranche": "trancher",
    "tranchelards": "tranchelard",
    "tranchent": "trancher",
    "tranchera": "trancher",
    "trancherai": "trancher",
    "trancheraient": "trancher",
    "trancherais": "trancher",
    "trancherait": "trancher",
    "trancheras": "trancher",
    "trancherez": "trancher",
    "trancheriez": "trancher",
    "trancherions": "trancher",
    "trancherons": "trancher",
    "trancheront": "trancher",
    "tranches": "trancher",
    "tranchets": "tranchet",
    "trancheuse": "trancheur",
    "tranchez": "trancher",
    "tranchiez": "trancher",
    "tranchions": "trancher",
    "tranchoirs": "tranchoir",
    "tranchons": "trancher",
    "tranchâmes": "trancher",
    "tranchât": "trancher",
    "tranchâtes": "trancher",
    "tranchèrent": "trancher",
    "tranché": "trancher",
    "tranchée": "trancher",
    "tranchées": "trancher",
    "tranchées-abris": "tranchée-abri",
    "tranchés": "trancher",
    "tranquilles": "tranquille",
    "tranquillisa": "tranquilliser",
    "tranquillisai": "tranquilliser",
    "tranquillisaient": "tranquilliser",
    "tranquillisais": "tranquilliser",
    "tranquillisait": "tranquilliser",
    "tranquillisant": "tranquilliser",
    "tranquillisante": "tranquillisant",
    "tranquillisantes": "tranquillisant",
    "tranquillisants": "tranquillisant",
    "tranquillisas": "tranquilliser",
    "tranquillisasse": "tranquilliser",
    "tranquillisassent": "tranquilliser",
    "tranquillisasses": "tranquilliser",
    "tranquillisassiez": "tranquilliser",
    "tranquillisassions": "tranquilliser",
    "tranquillise": "tranquilliser",
    "tranquillisent": "tranquilliser",
    "tranquillisera": "tranquilliser",
    "tranquilliserai": "tranquilliser",
    "tranquilliseraient": "tranquilliser",
    "tranquilliserais": "tranquilliser",
    "tranquilliserait": "tranquilliser",
    "tranquilliseras": "tranquilliser",
    "tranquilliserez": "tranquilliser",
    "tranquilliseriez": "tranquilliser",
    "tranquilliserions": "tranquilliser",
    "tranquilliserons": "tranquilliser",
    "tranquilliseront": "tranquilliser",
    "tranquillises": "tranquilliser",
    "tranquillisez": "tranquilliser",
    "tranquillisiez": "tranquilliser",
    "tranquillisions": "tranquilliser",
    "tranquillisons": "tranquilliser",
    "tranquillisâmes": "tranquilliser",
    "tranquillisât": "tranquilliser",
    "tranquillisâtes": "tranquilliser",
    "tranquillisèrent": "tranquilliser",
    "tranquillisé": "tranquilliser",
    "tranquillisée": "tranquilliser",
    "tranquillisées": "tranquilliser",
    "tranquillisés": "tranquilliser",
    "tranquillités": "tranquillité",
    "transactionnelle": "transactionnel",
    "transactionnelles": "transactionnel",
    "transactionnels": "transactionnel",
    "transactions": "transaction",
    "transalpine": "transalpin",
    "transalpines": "transalpin",
    "transalpins": "transalpin",
    "transamazonienne": "transamazonien",
    "transaminases": "transaminase",
    "transatlantiques": "transatlantique",
    "transats": "transat",
    "transbahutaient": "transbahuter",
    "transbahutant": "transbahuter",
    "transbahute": "transbahuter",
    "transbahutent": "transbahuter",
    "transbahutez": "transbahuter",
    "transbahuté": "transbahuter",
    "transbahutée": "transbahuter",
    "transbahutés": "transbahuter",
    "transborda": "transborder",
    "transbordai": "transborder",
    "transbordaient": "transborder",
    "transbordais": "transborder",
    "transbordait": "transborder",
    "transbordant": "transborder",
    "transbordas": "transborder",
    "transbordasse": "transborder",
    "transbordassent": "transborder",
    "transbordasses": "transborder",
    "transbordassiez": "transborder",
    "transbordassions": "transborder",
    "transborde": "transborder",
    "transbordements": "transbordement",
    "transbordent": "transborder",
    "transbordera": "transborder",
    "transborderai": "transborder",
    "transborderaient": "transborder",
    "transborderais": "transborder",
    "transborderait": "transborder",
    "transborderas": "transborder",
    "transborderez": "transborder",
    "transborderiez": "transborder",
    "transborderions": "transborder",
    "transborderons": "transborder",
    "transborderont": "transborder",
    "transbordes": "transborder",
    "transbordeurs": "transbordeur",
    "transbordez": "transborder",
    "transbordiez": "transborder",
    "transbordions": "transborder",
    "transbordons": "transborder",
    "transbordâmes": "transborder",
    "transbordât": "transborder",
    "transbordâtes": "transborder",
    "transbordèrent": "transborder",
    "transbordé": "transborder",
    "transbordée": "transborder",
    "transbordées": "transborder",
    "transbordés": "transborder",
    "transcenda": "transcender",
    "transcendai": "transcender",
    "transcendaient": "transcender",
    "transcendais": "transcender",
    "transcendait": "transcender",
    "transcendances": "transcendance",
    "transcendant": "transcender",
    "transcendantale": "transcendantal",
    "transcendantales": "transcendantal",
    "transcendantalistes": "transcendantaliste",
    "transcendantaux": "transcendantal",
    "transcendante": "transcendant",
    "transcendantes": "transcendant",
    "transcendants": "transcendant",
    "transcendas": "transcender",
    "transcendasse": "transcender",
    "transcendassent": "transcender",
    "transcendasses": "transcender",
    "transcendassiez": "transcender",
    "transcendassions": "transcender",
    "transcende": "transcender",
    "transcendent": "transcender",
    "transcendera": "transcender",
    "transcenderai": "transcender",
    "transcenderaient": "transcender",
    "transcenderais": "transcender",
    "transcenderait": "transcender",
    "transcenderas": "transcender",
    "transcenderez": "transcender",
    "transcenderiez": "transcender",
    "transcenderions": "transcender",
    "transcenderons": "transcender",
    "transcenderont": "transcender",
    "transcendes": "transcender",
    "transcendez": "transcender",
    "transcendiez": "transcender",
    "transcendions": "transcender",
    "transcendons": "transcender",
    "transcendâmes": "transcender",
    "transcendât": "transcender",
    "transcendâtes": "transcender",
    "transcendèrent": "transcender",
    "transcendé": "transcender",
    "transcendée": "transcender",
    "transcendées": "transcender",
    "transcendés": "transcender",
    "transcoda": "transcoder",
    "transcodai": "transcoder",
    "transcodaient": "transcoder",
    "transcodais": "transcoder",
    "transcodait": "transcoder",
    "transcodant": "transcoder",
    "transcodas": "transcoder",
    "transcodasse": "transcoder",
    "transcodassent": "transcoder",
    "transcodasses": "transcoder",
    "transcodassiez": "transcoder",
    "transcodassions": "transcoder",
    "transcode": "transcoder",
    "transcodent": "transcoder",
    "transcodera": "transcoder",
    "transcoderai": "transcoder",
    "transcoderaient": "transcoder",
    "transcoderais": "transcoder",
    "transcoderait": "transcoder",
    "transcoderas": "transcoder",
    "transcoderez": "transcoder",
    "transcoderiez": "transcoder",
    "transcoderions": "transcoder",
    "transcoderons": "transcoder",
    "transcoderont": "transcoder",
    "transcodes": "transcoder",
    "transcodez": "transcoder",
    "transcodiez": "transcoder",
    "transcodions": "transcoder",
    "transcodons": "transcoder",
    "transcodâmes": "transcoder",
    "transcodât": "transcoder",
    "transcodâtes": "transcoder",
    "transcodèrent": "transcoder",
    "transcodé": "transcoder",
    "transcodée": "transcoder",
    "transcodées": "transcoder",
    "transcodés": "transcoder",
    "transcommunautaires": "transcommunautaire",
    "transcontinentale": "transcontinental",
    "transcriptions": "transcription",
    "transcrira": "transcrire",
    "transcrirai": "transcrire",
    "transcriraient": "transcrire",
    "transcrirais": "transcrire",
    "transcrirait": "transcrire",
    "transcriras": "transcrire",
    "transcrirez": "transcrire",
    "transcririez": "transcrire",
    "transcririons": "transcrire",
    "transcrirons": "transcrire",
    "transcriront": "transcrire",
    "transcris": "transcrire",
    "transcrit": "transcrire",
    "transcrite": "transcrire",
    "transcrites": "transcrire",
    "transcrits": "transcrire",
    "transcrivaient": "transcrire",
    "transcrivais": "transcrire",
    "transcrivait": "transcrire",
    "transcrivant": "transcrire",
    "transcrive": "transcrire",
    "transcrivent": "transcrire",
    "transcrives": "transcrire",
    "transcrivez": "transcrire",
    "transcriviez": "transcrire",
    "transcrivions": "transcrire",
    "transcrivirent": "transcrire",
    "transcrivis": "transcrire",
    "transcrivisse": "transcrire",
    "transcrivissent": "transcrire",
    "transcrivisses": "transcrire",
    "transcrivissiez": "transcrire",
    "transcrivissions": "transcrire",
    "transcrivit": "transcrire",
    "transcrivons": "transcrire",
    "transcrivîmes": "transcrire",
    "transcrivît": "transcrire",
    "transcrivîtes": "transcrire",
    "transducteurs": "transducteur",
    "transepts": "transept",
    "transes": "transe",
    "transeuropéenne": "transeuropéen",
    "transeuropéennes": "transeuropéen",
    "transeuropéens": "transeuropéen",
    "transferts": "transfert",
    "transfigura": "transfigurer",
    "transfigurai": "transfigurer",
    "transfiguraient": "transfigurer",
    "transfigurais": "transfigurer",
    "transfigurait": "transfigurer",
    "transfigurant": "transfigurer",
    "transfiguras": "transfigurer",
    "transfigurasse": "transfigurer",
    "transfigurassent": "transfigurer",
    "transfigurasses": "transfigurer",
    "transfigurassiez": "transfigurer",
    "transfigurassions": "transfigurer",
    "transfigurations": "transfiguration",
    "transfiguratrice": "transfigurateur",
    "transfigure": "transfigurer",
    "transfigurent": "transfigurer",
    "transfigurera": "transfigurer",
    "transfigurerai": "transfigurer",
    "transfigureraient": "transfigurer",
    "transfigurerais": "transfigurer",
    "transfigurerait": "transfigurer",
    "transfigureras": "transfigurer",
    "transfigurerez": "transfigurer",
    "transfigureriez": "transfigurer",
    "transfigurerions": "transfigurer",
    "transfigurerons": "transfigurer",
    "transfigureront": "transfigurer",
    "transfigures": "transfigurer",
    "transfigurez": "transfigurer",
    "transfiguriez": "transfigurer",
    "transfigurions": "transfigurer",
    "transfigurons": "transfigurer",
    "transfigurâmes": "transfigurer",
    "transfigurât": "transfigurer",
    "transfigurâtes": "transfigurer",
    "transfigurèrent": "transfigurer",
    "transfiguré": "transfigurer",
    "transfigurée": "transfigurer",
    "transfigurées": "transfigurer",
    "transfigurés": "transfigurer",
    "transfilaient": "transfiler",
    "transfilée": "transfiler",
    "transforma": "transformer",
    "transformables": "transformable",
    "transformai": "transformer",
    "transformaient": "transformer",
    "transformais": "transformer",
    "transformait": "transformer",
    "transformant": "transformer",
    "transformas": "transformer",
    "transformasse": "transformer",
    "transformassent": "transformer",
    "transformasses": "transformer",
    "transformassiez": "transformer",
    "transformassions": "transformer",
    "transformateurs": "transformateur",
    "transformationnelle": "transformationnel",
    "transformationnelles": "transformationnel",
    "transformationnels": "transformationnel",
    "transformations": "transformation",
    "transformatrice": "transformateur",
    "transformatrices": "transformateur",
    "transforme": "transformer",
    "transforment": "transformer",
    "transformera": "transformer",
    "transformerai": "transformer",
    "transformeraient": "transformer",
    "transformerais": "transformer",
    "transformerait": "transformer",
    "transformeras": "transformer",
    "transformerez": "transformer",
    "transformeriez": "transformer",
    "transformerions": "transformer",
    "transformerons": "transformer",
    "transformeront": "transformer",
    "transformes": "transformer",
    "transformez": "transformer",
    "transformiez": "transformer",
    "transformions": "transformer",
    "transformons": "transformer",
    "transformâmes": "transformer",
    "transformât": "transformer",
    "transformâtes": "transformer",
    "transformèrent": "transformer",
    "transformé": "transformer",
    "transformée": "transformer",
    "transformées": "transformer",
    "transformés": "transformer",
    "transfos": "transfo",
    "transfrontaliers": "transfrontalier",
    "transfrontalière": "transfrontalier",
    "transfrontalières": "transfrontalier",
    "transfrontières": "transfrontière",
    "transfuges": "transfuge",
    "transfusa": "transfuser",
    "transfusai": "transfuser",
    "transfusaient": "transfuser",
    "transfusais": "transfuser",
    "transfusait": "transfuser",
    "transfusant": "transfuser",
    "transfusas": "transfuser",
    "transfusasse": "transfuser",
    "transfusassent": "transfuser",
    "transfusasses": "transfuser",
    "transfusassiez": "transfuser",
    "transfusassions": "transfuser",
    "transfuse": "transfuser",
    "transfusent": "transfuser",
    "transfusera": "transfuser",
    "transfuserai": "transfuser",
    "transfuseraient": "transfuser",
    "transfuserais": "transfuser",
    "transfuserait": "transfuser",
    "transfuseras": "transfuser",
    "transfuserez": "transfuser",
    "transfuseriez": "transfuser",
    "transfuserions": "transfuser",
    "transfuserons": "transfuser",
    "transfuseront": "transfuser",
    "transfuses": "transfuser",
    "transfusez": "transfuser",
    "transfusiez": "transfuser",
    "transfusionnelle": "transfusionnel",
    "transfusionnelles": "transfusionnel",
    "transfusionnels": "transfusionnel",
    "transfusions": "transfusion",
    "transfusons": "transfuser",
    "transfusâmes": "transfuser",
    "transfusât": "transfuser",
    "transfusâtes": "transfuser",
    "transfusèrent": "transfuser",
    "transfusé": "transfuser",
    "transfusée": "transfuser",
    "transfusées": "transfuser",
    "transfusés": "transfuser",
    "transfère": "transférer",
    "transfèrements": "transfèrement",
    "transfèrent": "transférer",
    "transfères": "transférer",
    "transféra": "transférer",
    "transférables": "transférable",
    "transférai": "transférer",
    "transféraient": "transférer",
    "transférais": "transférer",
    "transférait": "transférer",
    "transférant": "transférer",
    "transféras": "transférer",
    "transférasse": "transférer",
    "transférassent": "transférer",
    "transférasses": "transférer",
    "transférassiez": "transférer",
    "transférassions": "transférer",
    "transférera": "transférer",
    "transférerai": "transférer",
    "transféreraient": "transférer",
    "transférerais": "transférer",
    "transférerait": "transférer",
    "transféreras": "transférer",
    "transférerez": "transférer",
    "transféreriez": "transférer",
    "transférerions": "transférer",
    "transférerons": "transférer",
    "transféreront": "transférer",
    "transféreurs": "transféreur",
    "transférez": "transférer",
    "transfériez": "transférer",
    "transférions": "transférer",
    "transférons": "transférer",
    "transférâmes": "transférer",
    "transférât": "transférer",
    "transférâtes": "transférer",
    "transférèrent": "transférer",
    "transféré": "transférer",
    "transférée": "transférer",
    "transférées": "transférer",
    "transférés": "transférer",
    "transgressa": "transgresser",
    "transgressai": "transgresser",
    "transgressaient": "transgresser",
    "transgressais": "transgresser",
    "transgressait": "transgresser",
    "transgressant": "transgresser",
    "transgressas": "transgresser",
    "transgressasse": "transgresser",
    "transgressassent": "transgresser",
    "transgressasses": "transgresser",
    "transgressassiez": "transgresser",
    "transgressassions": "transgresser",
    "transgresse": "transgresser",
    "transgressent": "transgresser",
    "transgressera": "transgresser",
    "transgresserai": "transgresser",
    "transgresseraient": "transgresser",
    "transgresserais": "transgresser",
    "transgresserait": "transgresser",
    "transgresseras": "transgresser",
    "transgresserez": "transgresser",
    "transgresseriez": "transgresser",
    "transgresserions": "transgresser",
    "transgresserons": "transgresser",
    "transgresseront": "transgresser",
    "transgresses": "transgresser",
    "transgressez": "transgresser",
    "transgressiez": "transgresser",
    "transgressions": "transgression",
    "transgressons": "transgresser",
    "transgressâmes": "transgresser",
    "transgressât": "transgresser",
    "transgressâtes": "transgresser",
    "transgressèrent": "transgresser",
    "transgressé": "transgresser",
    "transgressée": "transgresser",
    "transgressées": "transgresser",
    "transgressés": "transgresser",
    "transgéniques": "transgénique",
    "transhuma": "transhumer",
    "transhumai": "transhumer",
    "transhumaient": "transhumer",
    "transhumais": "transhumer",
    "transhumait": "transhumer",
    "transhumances": "transhumance",
    "transhumant": "transhumer",
    "transhumantes": "transhumant",
    "transhumants": "transhumant",
    "transhumas": "transhumer",
    "transhumasse": "transhumer",
    "transhumassent": "transhumer",
    "transhumasses": "transhumer",
    "transhumassiez": "transhumer",
    "transhumassions": "transhumer",
    "transhume": "transhumer",
    "transhument": "transhumer",
    "transhumera": "transhumer",
    "transhumerai": "transhumer",
    "transhumeraient": "transhumer",
    "transhumerais": "transhumer",
    "transhumerait": "transhumer",
    "transhumeras": "transhumer",
    "transhumerez": "transhumer",
    "transhumeriez": "transhumer",
    "transhumerions": "transhumer",
    "transhumerons": "transhumer",
    "transhumeront": "transhumer",
    "transhumes": "transhumer",
    "transhumez": "transhumer",
    "transhumiez": "transhumer",
    "transhumions": "transhumer",
    "transhumons": "transhumer",
    "transhumâmes": "transhumer",
    "transhumât": "transhumer",
    "transhumâtes": "transhumer",
    "transhumèrent": "transhumer",
    "transhumé": "transhumer",
    "transhumée": "transhumer",
    "transhumées": "transhumer",
    "transhumés": "transhumer",
    "transi": "transir",
    "transie": "transir",
    "transies": "transir",
    "transige": "transiger",
    "transigea": "transiger",
    "transigeai": "transiger",
    "transigeaient": "transiger",
    "transigeais": "transiger",
    "transigeait": "transiger",
    "transigeant": "transiger",
    "transigeas": "transiger",
    "transigeasse": "transiger",
    "transigeassent": "transiger",
    "transigeasses": "transiger",
    "transigeassiez": "transiger",
    "transigeassions": "transiger",
    "transigent": "transiger",
    "transigeons": "transiger",
    "transigera": "transiger",
    "transigerai": "transiger",
    "transigeraient": "transiger",
    "transigerais": "transiger",
    "transigerait": "transiger",
    "transigeras": "transiger",
    "transigerez": "transiger",
    "transigeriez": "transiger",
    "transigerions": "transiger",
    "transigerons": "transiger",
    "transigeront": "transiger",
    "transiges": "transiger",
    "transigez": "transiger",
    "transigeâmes": "transiger",
    "transigeât": "transiger",
    "transigeâtes": "transiger",
    "transigiez": "transiger",
    "transigions": "transiger",
    "transigèrent": "transiger",
    "transigé": "transiger",
    "transira": "transir",
    "transirai": "transir",
    "transiraient": "transir",
    "transirais": "transir",
    "transirait": "transir",
    "transiras": "transir",
    "transirent": "transir",
    "transirez": "transir",
    "transiriez": "transir",
    "transirions": "transir",
    "transirons": "transir",
    "transiront": "transir",
    "transis": "transir",
    "transissaient": "transir",
    "transissais": "transir",
    "transissait": "transir",
    "transissant": "transir",
    "transisse": "transir",
    "transissent": "transir",
    "transisses": "transir",
    "transissez": "transir",
    "transissiez": "transir",
    "transissions": "transir",
    "transissons": "transir",
    "transistorisées": "transistorisé",
    "transistorisés": "transistoriser",
    "transistors": "transistor",
    "transit": "transir",
    "transita": "transiter",
    "transitai": "transiter",
    "transitaient": "transiter",
    "transitaires": "transitaire",
    "transitais": "transiter",
    "transitait": "transiter",
    "transitant": "transiter",
    "transitas": "transiter",
    "transitasse": "transiter",
    "transitassent": "transiter",
    "transitasses": "transiter",
    "transitassiez": "transiter",
    "transitassions": "transiter",
    "transite": "transiter",
    "transitent": "transiter",
    "transitera": "transiter",
    "transiterai": "transiter",
    "transiteraient": "transiter",
    "transiterais": "transiter",
    "transiterait": "transiter",
    "transiteras": "transiter",
    "transiterez": "transiter",
    "transiteriez": "transiter",
    "transiterions": "transiter",
    "transiterons": "transiter",
    "transiteront": "transiter",
    "transites": "transiter",
    "transitez": "transiter",
    "transitiez": "transiter",
    "transitifs": "transitif",
    "transitionnelle": "transitionnel",
    "transitions": "transition",
    "transitive": "transitif",
    "transitives": "transitif",
    "transitoires": "transitoire",
    "transitons": "transiter",
    "transits": "transit",
    "transitâmes": "transiter",
    "transitât": "transiter",
    "transitâtes": "transiter",
    "transitèrent": "transiter",
    "transité": "transiter",
    "transitée": "transiter",
    "transitées": "transiter",
    "transités": "transiter",
    "translates": "translater",
    "translations": "translation",
    "translucides": "translucide",
    "transmet": "transmettre",
    "transmets": "transmettre",
    "transmettaient": "transmettre",
    "transmettais": "transmettre",
    "transmettait": "transmettre",
    "transmettant": "transmettre",
    "transmette": "transmettre",
    "transmettent": "transmettre",
    "transmettes": "transmettre",
    "transmetteurs": "transmetteur",
    "transmettez": "transmettre",
    "transmettiez": "transmettre",
    "transmettions": "transmettre",
    "transmettons": "transmettre",
    "transmettra": "transmettre",
    "transmettrai": "transmettre",
    "transmettraient": "transmettre",
    "transmettrais": "transmettre",
    "transmettrait": "transmettre",
    "transmettras": "transmettre",
    "transmettrez": "transmettre",
    "transmettriez": "transmettre",
    "transmettrions": "transmettre",
    "transmettrons": "transmettre",
    "transmettront": "transmettre",
    "transmigra": "transmigrer",
    "transmigrai": "transmigrer",
    "transmigraient": "transmigrer",
    "transmigrais": "transmigrer",
    "transmigrait": "transmigrer",
    "transmigrant": "transmigrer",
    "transmigras": "transmigrer",
    "transmigrasse": "transmigrer",
    "transmigrassent": "transmigrer",
    "transmigrasses": "transmigrer",
    "transmigrassiez": "transmigrer",
    "transmigrassions": "transmigrer",
    "transmigre": "transmigrer",
    "transmigrent": "transmigrer",
    "transmigrera": "transmigrer",
    "transmigrerai": "transmigrer",
    "transmigreraient": "transmigrer",
    "transmigrerais": "transmigrer",
    "transmigrerait": "transmigrer",
    "transmigreras": "transmigrer",
    "transmigrerez": "transmigrer",
    "transmigreriez": "transmigrer",
    "transmigrerions": "transmigrer",
    "transmigrerons": "transmigrer",
    "transmigreront": "transmigrer",
    "transmigres": "transmigrer",
    "transmigrez": "transmigrer",
    "transmigriez": "transmigrer",
    "transmigrions": "transmigrer",
    "transmigrons": "transmigrer",
    "transmigrâmes": "transmigrer",
    "transmigrât": "transmigrer",
    "transmigrâtes": "transmigrer",
    "transmigrèrent": "transmigrer",
    "transmigré": "transmigrer",
    "transmirent": "transmettre",
    "transmis": "transmettre",
    "transmise": "transmis",
    "transmises": "transmis",
    "transmisse": "transmettre",
    "transmissent": "transmettre",
    "transmisses": "transmettre",
    "transmissibles": "transmissible",
    "transmissiez": "transmettre",
    "transmissions": "transmission",
    "transmit": "transmettre",
    "transmua": "transmuer",
    "transmuai": "transmuer",
    "transmuaient": "transmuer",
    "transmuais": "transmuer",
    "transmuait": "transmuer",
    "transmuant": "transmuer",
    "transmuas": "transmuer",
    "transmuasse": "transmuer",
    "transmuassent": "transmuer",
    "transmuasses": "transmuer",
    "transmuassiez": "transmuer",
    "transmuassions": "transmuer",
    "transmue": "transmuer",
    "transmuent": "transmuer",
    "transmuera": "transmuer",
    "transmuerai": "transmuer",
    "transmueraient": "transmuer",
    "transmuerais": "transmuer",
    "transmuerait": "transmuer",
    "transmueras": "transmuer",
    "transmuerez": "transmuer",
    "transmueriez": "transmuer",
    "transmuerions": "transmuer",
    "transmuerons": "transmuer",
    "transmueront": "transmuer",
    "transmues": "transmuer",
    "transmuez": "transmuer",
    "transmuiez": "transmuer",
    "transmuions": "transmuer",
    "transmuons": "transmuer",
    "transmutait": "transmuter",
    "transmutant": "transmuter",
    "transmutations": "transmutation",
    "transmute": "transmuter",
    "transmutent": "transmuter",
    "transmuté": "transmuter",
    "transmuâmes": "transmuer",
    "transmuât": "transmuer",
    "transmuâtes": "transmuer",
    "transmuèrent": "transmuer",
    "transmué": "transmuer",
    "transmuée": "transmuer",
    "transmuées": "transmuer",
    "transmués": "transmuer",
    "transmîmes": "transmettre",
    "transmît": "transmettre",
    "transmîtes": "transmettre",
    "transnationale": "transnational",
    "transnationales": "transnational",
    "transnationaux": "transnational",
    "transnucléaires": "transnucléaire",
    "transocéaniques": "transocéanique",
    "transparais": "transparaître",
    "transparaissaient": "transparaître",
    "transparaissais": "transparaître",
    "transparaissait": "transparaître",
    "transparaissant": "transparaître",
    "transparaisse": "transparaître",
    "transparaissent": "transparaître",
    "transparaisses": "transparaître",
    "transparaissez": "transparaître",
    "transparaissiez": "transparaître",
    "transparaissions": "transparaître",
    "transparaissons": "transparaître",
    "transparaît": "transparaître",
    "transparaîtra": "transparaître",
    "transparaîtrai": "transparaître",
    "transparaîtraient": "transparaître",
    "transparaîtrais": "transparaître",
    "transparaîtrait": "transparaître",
    "transparaîtras": "transparaître",
    "transparaîtrez": "transparaître",
    "transparaîtriez": "transparaître",
    "transparaîtrions": "transparaître",
    "transparaîtrons": "transparaître",
    "transparaîtront": "transparaître",
    "transparences": "transparence",
    "transparente": "transparent",
    "transparentes": "transparent",
    "transparents": "transparent",
    "transparu": "transparaître",
    "transparue": "transparaître",
    "transparues": "transparaître",
    "transparurent": "transparaître",
    "transparus": "transparaître",
    "transparusse": "transparaître",
    "transparussent": "transparaître",
    "transparusses": "transparaître",
    "transparussiez": "transparaître",
    "transparussions": "transparaître",
    "transparut": "transparaître",
    "transparûmes": "transparaître",
    "transparût": "transparaître",
    "transparûtes": "transparaître",
    "transperce": "transpercer",
    "transpercent": "transpercer",
    "transpercera": "transpercer",
    "transpercerai": "transpercer",
    "transperceraient": "transpercer",
    "transpercerais": "transpercer",
    "transpercerait": "transpercer",
    "transperceras": "transpercer",
    "transpercerez": "transpercer",
    "transperceriez": "transpercer",
    "transpercerions": "transpercer",
    "transpercerons": "transpercer",
    "transperceront": "transpercer",
    "transperces": "transpercer",
    "transpercez": "transpercer",
    "transperciez": "transpercer",
    "transpercions": "transpercer",
    "transpercèrent": "transpercer",
    "transpercé": "transpercer",
    "transpercée": "transpercer",
    "transpercées": "transpercer",
    "transpercés": "transpercer",
    "transperça": "transpercer",
    "transperçai": "transpercer",
    "transperçaient": "transpercer",
    "transperçais": "transpercer",
    "transperçait": "transpercer",
    "transperçant": "transpercer",
    "transperças": "transpercer",
    "transperçasse": "transpercer",
    "transperçassent": "transpercer",
    "transperçasses": "transpercer",
    "transperçassiez": "transpercer",
    "transperçassions": "transpercer",
    "transperçons": "transpercer",
    "transperçâmes": "transpercer",
    "transperçât": "transpercer",
    "transperçâtes": "transpercer",
    "transpira": "transpirer",
    "transpirai": "transpirer",
    "transpiraient": "transpirer",
    "transpirais": "transpirer",
    "transpirait": "transpirer",
    "transpirant": "transpirer",
    "transpirante": "transpirant",
    "transpirants": "transpirant",
    "transpiras": "transpirer",
    "transpirasse": "transpirer",
    "transpirassent": "transpirer",
    "transpirasses": "transpirer",
    "transpirassiez": "transpirer",
    "transpirassions": "transpirer",
    "transpirations": "transpiration",
    "transpire": "transpirer",
    "transpirent": "transpirer",
    "transpirera": "transpirer",
    "transpirerai": "transpirer",
    "transpireraient": "transpirer",
    "transpirerais": "transpirer",
    "transpirerait": "transpirer",
    "transpireras": "transpirer",
    "transpirerez": "transpirer",
    "transpireriez": "transpirer",
    "transpirerions": "transpirer",
    "transpirerons": "transpirer",
    "transpireront": "transpirer",
    "transpires": "transpirer",
    "transpirez": "transpirer",
    "transpiriez": "transpirer",
    "transpirions": "transpirer",
    "transpirons": "transpirer",
    "transpirâmes": "transpirer",
    "transpirât": "transpirer",
    "transpirâtes": "transpirer",
    "transpirèrent": "transpirer",
    "transpiré": "transpirer",
    "transpirée": "transpirer",
    "transpirées": "transpirer",
    "transpirés": "transpirer",
    "transplanta": "transplanter",
    "transplantai": "transplanter",
    "transplantaient": "transplanter",
    "transplantais": "transplanter",
    "transplantait": "transplanter",
    "transplantant": "transplanter",
    "transplantas": "transplanter",
    "transplantasse": "transplanter",
    "transplantassent": "transplanter",
    "transplantasses": "transplanter",
    "transplantassiez": "transplanter",
    "transplantassions": "transplanter",
    "transplantations": "transplantation",
    "transplante": "transplanter",
    "transplantent": "transplanter",
    "transplantera": "transplanter",
    "transplanterai": "transplanter",
    "transplanteraient": "transplanter",
    "transplanterais": "transplanter",
    "transplanterait": "transplanter",
    "transplanteras": "transplanter",
    "transplanterez": "transplanter",
    "transplanteriez": "transplanter",
    "transplanterions": "transplanter",
    "transplanterons": "transplanter",
    "transplanteront": "transplanter",
    "transplantes": "transplanter",
    "transplantez": "transplanter",
    "transplantiez": "transplanter",
    "transplantions": "transplanter",
    "transplantons": "transplanter",
    "transplants": "transplant",
    "transplantâmes": "transplanter",
    "transplantât": "transplanter",
    "transplantâtes": "transplanter",
    "transplantèrent": "transplanter",
    "transplanté": "transplanter",
    "transplantée": "transplanter",
    "transplantées": "transplanter",
    "transplantés": "transplanter",
    "transporta": "transporter",
    "transportables": "transportable",
    "transportai": "transporter",
    "transportaient": "transporter",
    "transportais": "transporter",
    "transportait": "transporter",
    "transportant": "transporter",
    "transportas": "transporter",
    "transportasse": "transporter",
    "transportassent": "transporter",
    "transportasses": "transporter",
    "transportassiez": "transporter",
    "transportassions": "transporter",
    "transporte": "transporter",
    "transportent": "transporter",
    "transportera": "transporter",
    "transporterai": "transporter",
    "transporteraient": "transporter",
    "transporterais": "transporter",
    "transporterait": "transporter",
    "transporteras": "transporter",
    "transporterez": "transporter",
    "transporteriez": "transporter",
    "transporterions": "transporter",
    "transporterons": "transporter",
    "transporteront": "transporter",
    "transportes": "transporter",
    "transporteurs": "transporteur",
    "transporteuse": "transporteur",
    "transportez": "transporter",
    "transportiez": "transporter",
    "transportions": "transporter",
    "transportons": "transporter",
    "transports": "transport",
    "transportâmes": "transporter",
    "transportât": "transporter",
    "transportâtes": "transporter",
    "transportèrent": "transporter",
    "transporté": "transporter",
    "transportée": "transporter",
    "transportées": "transporter",
    "transportés": "transporter",
    "transposa": "transposer",
    "transposables": "transposable",
    "transposai": "transposer",
    "transposaient": "transposer",
    "transposais": "transposer",
    "transposait": "transposer",
    "transposant": "transposer",
    "transposas": "transposer",
    "transposasse": "transposer",
    "transposassent": "transposer",
    "transposasses": "transposer",
    "transposassiez": "transposer",
    "transposassions": "transposer",
    "transpose": "transposer",
    "transposent": "transposer",
    "transposera": "transposer",
    "transposerai": "transposer",
    "transposeraient": "transposer",
    "transposerais": "transposer",
    "transposerait": "transposer",
    "transposeras": "transposer",
    "transposerez": "transposer",
    "transposeriez": "transposer",
    "transposerions": "transposer",
    "transposerons": "transposer",
    "transposeront": "transposer",
    "transposes": "transposer",
    "transposez": "transposer",
    "transposiez": "transposer",
    "transposions": "transposer",
    "transpositions": "transposition",
    "transposons": "transposer",
    "transposâmes": "transposer",
    "transposât": "transposer",
    "transposâtes": "transposer",
    "transposèrent": "transposer",
    "transposé": "transposer",
    "transposée": "transposer",
    "transposées": "transposer",
    "transposés": "transposer",
    "transrégionale": "transrégional",
    "transrégionales": "transrégional",
    "transrégionaux": "transrégional",
    "transsaharienne": "transsaharien",
    "transsahariennes": "transsaharien",
    "transsahariens": "transsaharien",
    "transsexuelle": "transsexuel",
    "transsexuels": "transsexuel",
    "transsibérienne": "transsibérien",
    "transsoniques": "transsonique",
    "transsubstantiations": "transsubstantiation",
    "transsuda": "transsuder",
    "transsudai": "transsuder",
    "transsudaient": "transsuder",
    "transsudais": "transsuder",
    "transsudait": "transsuder",
    "transsudant": "transsuder",
    "transsudas": "transsuder",
    "transsudasse": "transsuder",
    "transsudassent": "transsuder",
    "transsudasses": "transsuder",
    "transsudassiez": "transsuder",
    "transsudassions": "transsuder",
    "transsude": "transsuder",
    "transsudent": "transsuder",
    "transsudera": "transsuder",
    "transsuderai": "transsuder",
    "transsuderaient": "transsuder",
    "transsuderais": "transsuder",
    "transsuderait": "transsuder",
    "transsuderas": "transsuder",
    "transsuderez": "transsuder",
    "transsuderiez": "transsuder",
    "transsuderions": "transsuder",
    "transsuderons": "transsuder",
    "transsuderont": "transsuder",
    "transsudes": "transsuder",
    "transsudez": "transsuder",
    "transsudiez": "transsuder",
    "transsudions": "transsuder",
    "transsudons": "transsuder",
    "transsudâmes": "transsuder",
    "transsudât": "transsuder",
    "transsudâtes": "transsuder",
    "transsudèrent": "transsuder",
    "transsudé": "transsuder",
    "transuranienne": "transuranien",
    "transvasa": "transvaser",
    "transvasai": "transvaser",
    "transvasaient": "transvaser",
    "transvasais": "transvaser",
    "transvasait": "transvaser",
    "transvasant": "transvaser",
    "transvasas": "transvaser",
    "transvasasse": "transvaser",
    "transvasassent": "transvaser",
    "transvasasses": "transvaser",
    "transvasassiez": "transvaser",
    "transvasassions": "transvaser",
    "transvase": "transvaser",
    "transvasent": "transvaser",
    "transvasera": "transvaser",
    "transvaserai": "transvaser",
    "transvaseraient": "transvaser",
    "transvaserais": "transvaser",
    "transvaserait": "transvaser",
    "transvaseras": "transvaser",
    "transvaserez": "transvaser",
    "transvaseriez": "transvaser",
    "transvaserions": "transvaser",
    "transvaserons": "transvaser",
    "transvaseront": "transvaser",
    "transvases": "transvaser",
    "transvasez": "transvaser",
    "transvasiez": "transvaser",
    "transvasions": "transvaser",
    "transvasons": "transvaser",
    "transvasâmes": "transvaser",
    "transvasât": "transvaser",
    "transvasâtes": "transvaser",
    "transvasèrent": "transvaser",
    "transvasé": "transvaser",
    "transvasée": "transvaser",
    "transvasées": "transvaser",
    "transvasés": "transvaser",
    "transversale": "transversal",
    "transversales": "transversal",
    "transversaux": "transversal",
    "transvida": "transvider",
    "transvidai": "transvider",
    "transvidaient": "transvider",
    "transvidais": "transvider",
    "transvidait": "transvider",
    "transvidant": "transvider",
    "transvidas": "transvider",
    "transvidasse": "transvider",
    "transvidassent": "transvider",
    "transvidasses": "transvider",
    "transvidassiez": "transvider",
    "transvidassions": "transvider",
    "transvide": "transvider",
    "transvident": "transvider",
    "transvidera": "transvider",
    "transviderai": "transvider",
    "transvideraient": "transvider",
    "transviderais": "transvider",
    "transviderait": "transvider",
    "transvideras": "transvider",
    "transviderez": "transvider",
    "transvideriez": "transvider",
    "transviderions": "transvider",
    "transviderons": "transvider",
    "transvideront": "transvider",
    "transvides": "transvider",
    "transvidez": "transvider",
    "transvidiez": "transvider",
    "transvidions": "transvider",
    "transvidons": "transvider",
    "transvidâmes": "transvider",
    "transvidât": "transvider",
    "transvidâtes": "transvider",
    "transvidèrent": "transvider",
    "transvidé": "transvider",
    "transvidée": "transvider",
    "transvidées": "transvider",
    "transvidés": "transvider",
    "transylvanienne": "transylvanien",
    "transîmes": "transir",
    "transît": "transir",
    "transîtes": "transir",
    "trappes": "trappe",
    "trappeurs": "trappeur",
    "trappistes": "trappiste",
    "trapue": "trapu",
    "trapues": "trapu",
    "trapus": "trapu",
    "trapèzes": "trapèze",
    "trapézistes": "trapéziste",
    "trapézoïdale": "trapézoïdal",
    "trapézoïdales": "trapézoïdal",
    "trapézoïdaux": "trapézoïdal",
    "traqua": "traquer",
    "traquai": "traquer",
    "traquaient": "traquer",
    "traquais": "traquer",
    "traquait": "traquer",
    "traquant": "traquer",
    "traquas": "traquer",
    "traquasse": "traquer",
    "traquassent": "traquer",
    "traquasses": "traquer",
    "traquassiez": "traquer",
    "traquassions": "traquer",
    "traque": "traquer",
    "traquenards": "traquenard",
    "traquent": "traquer",
    "traquera": "traquer",
    "traquerai": "traquer",
    "traqueraient": "traquer",
    "traquerais": "traquer",
    "traquerait": "traquer",
    "traqueras": "traquer",
    "traquerez": "traquer",
    "traqueriez": "traquer",
    "traquerions": "traquer",
    "traquerons": "traquer",
    "traqueront": "traquer",
    "traques": "traquer",
    "traquets": "traquet",
    "traqueurs": "traqueur",
    "traqueuse": "traqueur",
    "traquez": "traquer",
    "traquiez": "traquer",
    "traquions": "traquer",
    "traquons": "traquer",
    "traquâmes": "traquer",
    "traquât": "traquer",
    "traquâtes": "traquer",
    "traquèrent": "traquer",
    "traqué": "traquer",
    "traquée": "traquer",
    "traquées": "traquer",
    "traqués": "traquer",
    "trattorias": "trattoria",
    "traumas": "trauma",
    "traumatiques": "traumatique",
    "traumatisa": "traumatiser",
    "traumatisai": "traumatiser",
    "traumatisaient": "traumatiser",
    "traumatisais": "traumatiser",
    "traumatisait": "traumatiser",
    "traumatisant": "traumatiser",
    "traumatisante": "traumatisant",
    "traumatisantes": "traumatisant",
    "traumatisants": "traumatisant",
    "traumatisas": "traumatiser",
    "traumatisasse": "traumatiser",
    "traumatisassent": "traumatiser",
    "traumatisasses": "traumatiser",
    "traumatisassiez": "traumatiser",
    "traumatisassions": "traumatiser",
    "traumatise": "traumatiser",
    "traumatisent": "traumatiser",
    "traumatisera": "traumatiser",
    "traumatiserai": "traumatiser",
    "traumatiseraient": "traumatiser",
    "traumatiserais": "traumatiser",
    "traumatiserait": "traumatiser",
    "traumatiseras": "traumatiser",
    "traumatiserez": "traumatiser",
    "traumatiseriez": "traumatiser",
    "traumatiserions": "traumatiser",
    "traumatiserons": "traumatiser",
    "traumatiseront": "traumatiser",
    "traumatises": "traumatiser",
    "traumatisez": "traumatiser",
    "traumatisiez": "traumatiser",
    "traumatisions": "traumatiser",
    "traumatismes": "traumatisme",
    "traumatisons": "traumatiser",
    "traumatisâmes": "traumatiser",
    "traumatisât": "traumatiser",
    "traumatisâtes": "traumatiser",
    "traumatisèrent": "traumatiser",
    "traumatisé": "traumatiser",
    "traumatisée": "traumatiser",
    "traumatisées": "traumatiser",
    "traumatisés": "traumatiser",
    "traumatologies": "traumatologie",
    "travailla": "travailler",
    "travaillai": "travailler",
    "travaillaient": "travailler",
    "travaillais": "travailler",
    "travaillait": "travailler",
    "travaillant": "travailler",
    "travaillas": "travailler",
    "travaillasse": "travailler",
    "travaillassent": "travailler",
    "travaillasses": "travailler",
    "travaillassiez": "travailler",
    "travaillassions": "travailler",
    "travaille": "travailler",
    "travaillent": "travailler",
    "travaillera": "travailler",
    "travaillerai": "travailler",
    "travailleraient": "travailler",
    "travaillerais": "travailler",
    "travaillerait": "travailler",
    "travailleras": "travailler",
    "travaillerez": "travailler",
    "travailleriez": "travailler",
    "travaillerions": "travailler",
    "travaillerons": "travailler",
    "travailleront": "travailler",
    "travailles": "travailler",
    "travailleurs": "travailleur",
    "travailleuse": "travailleur",
    "travailleuses": "travailleur",
    "travaillez": "travailler",
    "travailliez": "travailler",
    "travaillions": "travailler",
    "travaillismes": "travaillisme",
    "travaillistes": "travailliste",
    "travaillons": "travailler",
    "travaillâmes": "travailler",
    "travaillât": "travailler",
    "travaillâtes": "travailler",
    "travaillèrent": "travailler",
    "travaillé": "travailler",
    "travaillée": "travailler",
    "travaillées": "travailler",
    "travaillés": "travailler",
    "travaux": "travail",
    "traveller's chèques": "traveller's chèque",
    "travellers": "traveller",
    "travellings": "travelling",
    "travelos": "travelo",
    "traversa": "traverser",
    "traversables": "traversable",
    "traversai": "traverser",
    "traversaient": "traverser",
    "traversais": "traverser",
    "traversait": "traverser",
    "traversant": "traverser",
    "traversas": "traverser",
    "traversasse": "traverser",
    "traversassent": "traverser",
    "traversasses": "traverser",
    "traversassiez": "traverser",
    "traversassions": "traverser",
    "traverse": "traverser",
    "traversent": "traverser",
    "traversera": "traverser",
    "traverserai": "traverser",
    "traverseraient": "traverser",
    "traverserais": "traverser",
    "traverserait": "traverser",
    "traverseras": "traverser",
    "traverserez": "traverser",
    "traverseriez": "traverser",
    "traverserions": "traverser",
    "traverserons": "traverser",
    "traverseront": "traverser",
    "traverses": "traverser",
    "traversez": "traverser",
    "traversiez": "traverser",
    "traversins": "traversin",
    "traversions": "traverser",
    "traversière": "traversier",
    "traversières": "traversier",
    "traversons": "traverser",
    "traversâmes": "traverser",
    "traversât": "traverser",
    "traversâtes": "traverser",
    "traversèrent": "traverser",
    "traversé": "traverser",
    "traversée": "traverser",
    "traversées": "traverser",
    "traversés": "traverser",
    "travertins": "travertin",
    "travesti": "travestir",
    "travestie": "travestir",
    "travesties": "travestir",
    "travestira": "travestir",
    "travestirai": "travestir",
    "travestiraient": "travestir",
    "travestirais": "travestir",
    "travestirait": "travestir",
    "travestiras": "travestir",
    "travestirent": "travestir",
    "travestirez": "travestir",
    "travestiriez": "travestir",
    "travestirions": "travestir",
    "travestirons": "travestir",
    "travestiront": "travestir",
    "travestis": "travestir",
    "travestissaient": "travestir",
    "travestissais": "travestir",
    "travestissait": "travestir",
    "travestissant": "travestir",
    "travestisse": "travestir",
    "travestissements": "travestissement",
    "travestissent": "travestir",
    "travestisses": "travestir",
    "travestissez": "travestir",
    "travestissiez": "travestir",
    "travestissions": "travestir",
    "travestissons": "travestir",
    "travestit": "travestir",
    "travestîmes": "travestir",
    "travestît": "travestir",
    "travestîtes": "travestir",
    "travées": "travée",
    "trayaient": "traire",
    "trayais": "traire",
    "trayait": "traire",
    "trayant": "traire",
    "trayeuse": "trayeur",
    "trayeuses": "trayeur",
    "trayez": "traire",
    "trayiez": "traire",
    "trayions": "traire",
    "trayons": "trayon",
    "traça": "tracer",
    "traçai": "tracer",
    "traçaient": "tracer",
    "traçais": "tracer",
    "traçait": "tracer",
    "traçant": "tracer",
    "traçante": "traçant",
    "traçantes": "traçant",
    "traças": "tracer",
    "traçasse": "tracer",
    "traçassent": "tracer",
    "traçasses": "tracer",
    "traçassiez": "tracer",
    "traçassions": "tracer",
    "traçons": "tracer",
    "traçâmes": "tracer",
    "traçât": "tracer",
    "traçâtes": "tracer",
    "traîna": "traîner",
    "traînai": "traîner",
    "traînaient": "traîner",
    "traînaillait": "traînailler",
    "traînaillant": "traînailler",
    "traînaille": "traînailler",
    "traînaillons": "traînailler",
    "traînaillé": "traînailler",
    "traînais": "traîner",
    "traînait": "traîner",
    "traînant": "traîner",
    "traînante": "traînant",
    "traînantes": "traînant",
    "traînants": "traînant",
    "traînarde": "traînard",
    "traînardes": "traînard",
    "traînards": "traînard",
    "traînas": "traîner",
    "traînassaient": "traînasser",
    "traînassais": "traînasser",
    "traînassait": "traînasser",
    "traînassant": "traînasser",
    "traînasse": "traîner",
    "traînassent": "traîner",
    "traînasserai": "traînasser",
    "traînasses": "traîner",
    "traînassez": "traînasser",
    "traînassiez": "traîner",
    "traînassions": "traîner",
    "traînassons": "traînasser",
    "traînassé": "traînasser",
    "traîne": "traîner",
    "traîne-savates": "traîne-savate",
    "traîneaux": "traineaux",
    "traînent": "traîner",
    "traînera": "traîner",
    "traînerai": "traîner",
    "traîneraient": "traîner",
    "traînerais": "traîner",
    "traînerait": "traîner",
    "traîneras": "traîner",
    "traînerez": "traîner",
    "traîneriez": "traîner",
    "traînerions": "traîner",
    "traînerons": "traîner",
    "traîneront": "traîner",
    "traînes": "traîner",
    "traîneurs": "traîneur",
    "traîneuses": "traîneuse",
    "traînez": "traîner",
    "traîniez": "traîner",
    "traînions": "traîner",
    "traînons": "traîner",
    "traînâmes": "traîner",
    "traînât": "traîner",
    "traînâtes": "traîner",
    "traînèrent": "traîner",
    "traîné": "traîner",
    "traînée": "traîner",
    "traînées": "traîner",
    "traînés": "traîner",
    "traîtres": "traître",
    "traîtresse": "traître",
    "traîtresses": "traîtresse",
    "traîtrises": "traîtrise",
    "treillages": "treillage",
    "treilles": "treille",
    "treillissa": "treillisser",
    "treillissai": "treillisser",
    "treillissaient": "treillisser",
    "treillissais": "treillisser",
    "treillissait": "treillisser",
    "treillissant": "treillisser",
    "treillissas": "treillisser",
    "treillissasse": "treillisser",
    "treillissassent": "treillisser",
    "treillissasses": "treillisser",
    "treillissassiez": "treillisser",
    "treillissassions": "treillisser",
    "treillisse": "treillisser",
    "treillissent": "treillisser",
    "treillissera": "treillisser",
    "treillisserai": "treillisser",
    "treillisseraient": "treillisser",
    "treillisserais": "treillisser",
    "treillisserait": "treillisser",
    "treillisseras": "treillisser",
    "treillisserez": "treillisser",
    "treillisseriez": "treillisser",
    "treillisserions": "treillisser",
    "treillisserons": "treillisser",
    "treillisseront": "treillisser",
    "treillisses": "treillisser",
    "treillissez": "treillisser",
    "treillissiez": "treillisser",
    "treillissions": "treillisser",
    "treillissons": "treillisser",
    "treillissâmes": "treillisser",
    "treillissât": "treillisser",
    "treillissâtes": "treillisser",
    "treillissèrent": "treillisser",
    "treillissé": "treillisser",
    "treillissée": "treillisser",
    "treillissées": "treillisser",
    "treillissés": "treillisser",
    "treizaine": "treizain",
    "treizièmes": "treizième",
    "trembla": "trembler",
    "tremblai": "trembler",
    "tremblaient": "trembler",
    "tremblais": "trembler",
    "tremblait": "trembler",
    "tremblant": "trembler",
    "tremblante": "tremblant",
    "tremblantes": "tremblant",
    "tremblants": "tremblant",
    "tremblas": "trembler",
    "tremblasse": "trembler",
    "tremblassent": "trembler",
    "tremblasses": "trembler",
    "tremblassiez": "trembler",
    "tremblassions": "trembler",
    "tremble": "trembler",
    "tremblements": "tremblement",
    "tremblent": "trembler",
    "tremblera": "trembler",
    "tremblerai": "trembler",
    "trembleraient": "trembler",
    "tremblerais": "trembler",
    "tremblerait": "trembler",
    "trembleras": "trembler",
    "tremblerez": "trembler",
    "trembleriez": "trembler",
    "tremblerions": "trembler",
    "tremblerons": "trembler",
    "trembleront": "trembler",
    "trembles": "trembler",
    "trembleurs": "trembleur",
    "tremblez": "trembler",
    "trembliez": "trembler",
    "tremblions": "trembler",
    "tremblochant": "tremblocher",
    "tremblons": "trembler",
    "tremblota": "trembloter",
    "tremblotaient": "trembloter",
    "tremblotait": "trembloter",
    "tremblotant": "trembloter",
    "tremblotante": "tremblotant",
    "tremblotantes": "tremblotant",
    "tremblotants": "tremblotant",
    "tremblote": "trembloter",
    "tremblotements": "tremblotement",
    "tremblotent": "trembloter",
    "trembloté": "trembloter",
    "tremblâmes": "trembler",
    "tremblât": "trembler",
    "tremblâtes": "trembler",
    "tremblèrent": "trembler",
    "tremblé": "trembler",
    "tremblée": "trembler",
    "tremblées": "trembler",
    "tremblés": "trembler",
    "tremolos": "tremolo",
    "trempa": "tremper",
    "trempages": "trempage",
    "trempai": "tremper",
    "trempaient": "tremper",
    "trempais": "tremper",
    "trempait": "tremper",
    "trempant": "tremper",
    "trempas": "tremper",
    "trempasse": "tremper",
    "trempassent": "tremper",
    "trempasses": "tremper",
    "trempassiez": "tremper",
    "trempassions": "tremper",
    "trempe": "tremper",
    "trempent": "tremper",
    "trempera": "tremper",
    "tremperai": "tremper",
    "tremperaient": "tremper",
    "tremperais": "tremper",
    "tremperait": "tremper",
    "tremperas": "tremper",
    "tremperez": "tremper",
    "tremperiez": "tremper",
    "tremperions": "tremper",
    "tremperons": "tremper",
    "tremperont": "tremper",
    "trempes": "tremper",
    "trempez": "tremper",
    "trempiez": "tremper",
    "trempions": "tremper",
    "tremplins": "tremplin",
    "trempons": "tremper",
    "trempâmes": "tremper",
    "trempât": "tremper",
    "trempâtes": "tremper",
    "trempèrent": "tremper",
    "trempé": "tremper",
    "trempée": "tremper",
    "trempées": "tremper",
    "trempés": "tremper",
    "trench-coats": "trench-coat",
    "trentaines": "trentaine",
    "trente-cinquièmes": "trente-cinquième",
    "trente-deuxièmes": "trente-deuxième",
    "trente-et-unièmes": "trente-et-unième",
    "trente-huitièmes": "trente-huitième",
    "trente-neuvièmes": "trente-neuvième",
    "trente-quatrièmes": "trente-quatrième",
    "trente-septièmes": "trente-septième",
    "trente-sixièmes": "trente-sixième",
    "trente-troisièmes": "trente-troisième",
    "trentenaires": "trentenaire",
    "trentièmes": "trentième",
    "tressa": "tresser",
    "tressai": "tresser",
    "tressaient": "tresser",
    "tressaillaient": "tressaillir",
    "tressaillais": "tressaillir",
    "tressaillait": "tressaillir",
    "tressaillant": "tressaillir",
    "tressaille": "tressaillir",
    "tressaillements": "tressaillement",
    "tressaillent": "tressaillir",
    "tressailles": "tressaillir",
    "tressaillez": "tressaillir",
    "tressailli": "tressaillir",
    "tressailliez": "tressaillir",
    "tressaillions": "tressaillir",
    "tressaillira": "tressaillir",
    "tressaillirai": "tressaillir",
    "tressailliraient": "tressaillir",
    "tressaillirais": "tressaillir",
    "tressaillirait": "tressaillir",
    "tressailliras": "tressaillir",
    "tressaillirent": "tressaillir",
    "tressaillirez": "tressaillir",
    "tressailliriez": "tressaillir",
    "tressaillirions": "tressaillir",
    "tressaillirons": "tressaillir",
    "tressailliront": "tressaillir",
    "tressaillis": "tressaillir",
    "tressaillisse": "tressaillir",
    "tressaillissent": "tressaillir",
    "tressaillisses": "tressaillir",
    "tressaillissiez": "tressaillir",
    "tressaillissions": "tressaillir",
    "tressaillit": "tressaillir",
    "tressaillons": "tressaillir",
    "tressaillîmes": "tressaillir",
    "tressaillît": "tressaillir",
    "tressaillîtes": "tressaillir",
    "tressais": "tresser",
    "tressait": "tresser",
    "tressant": "tresser",
    "tressas": "tresser",
    "tressasse": "tresser",
    "tressassent": "tresser",
    "tressasses": "tresser",
    "tressassiez": "tresser",
    "tressassions": "tresser",
    "tressauta": "tressauter",
    "tressautai": "tressauter",
    "tressautaient": "tressauter",
    "tressautais": "tressauter",
    "tressautait": "tressauter",
    "tressautant": "tressauter",
    "tressautante": "tressautant",
    "tressautas": "tressauter",
    "tressautasse": "tressauter",
    "tressautassent": "tressauter",
    "tressautasses": "tressauter",
    "tressautassiez": "tressauter",
    "tressautassions": "tressauter",
    "tressaute": "tressauter",
    "tressautements": "tressautement",
    "tressautent": "tressauter",
    "tressautera": "tressauter",
    "tressauterai": "tressauter",
    "tressauteraient": "tressauter",
    "tressauterais": "tressauter",
    "tressauterait": "tressauter",
    "tressauteras": "tressauter",
    "tressauterez": "tressauter",
    "tressauteriez": "tressauter",
    "tressauterions": "tressauter",
    "tressauterons": "tressauter",
    "tressauteront": "tressauter",
    "tressautes": "tressauter",
    "tressautez": "tressauter",
    "tressautiez": "tressauter",
    "tressautions": "tressauter",
    "tressautons": "tressauter",
    "tressautâmes": "tressauter",
    "tressautât": "tressauter",
    "tressautâtes": "tressauter",
    "tressautèrent": "tressauter",
    "tressauté": "tressauter",
    "tressautés": "tressauter",
    "tresse": "tresser",
    "tressent": "tresser",
    "tressera": "tresser",
    "tresserai": "tresser",
    "tresseraient": "tresser",
    "tresserais": "tresser",
    "tresserait": "tresser",
    "tresseras": "tresser",
    "tresserez": "tresser",
    "tresseriez": "tresser",
    "tresserions": "tresser",
    "tresserons": "tresser",
    "tresseront": "tresser",
    "tresses": "tresser",
    "tresseurs": "tresseur",
    "tressez": "tresser",
    "tressiez": "tresser",
    "tressions": "tresser",
    "tressons": "tresser",
    "tressâmes": "tresser",
    "tressât": "tresser",
    "tressâtes": "tresser",
    "tressèrent": "tresser",
    "tressé": "tresser",
    "tressée": "tresser",
    "tressées": "tresser",
    "tressés": "tresser",
    "treuils": "treuil",
    "tria": "trier",
    "triades": "triade",
    "triages": "triage",
    "triai": "trier",
    "triaient": "trier",
    "triais": "trier",
    "triait": "trier",
    "trials": "trial",
    "triangles": "triangle",
    "triangulaires": "triangulaire",
    "triangulez": "trianguler",
    "triant": "trier",
    "trias": "trier",
    "triasse": "trier",
    "triassent": "trier",
    "triasses": "trier",
    "triassiez": "trier",
    "triassions": "trier",
    "tribale": "tribal",
    "tribales": "tribal",
    "tribaux": "tribal",
    "tribords": "tribord",
    "tribulations": "tribulation",
    "tribunaux": "tribunal",
    "tribunes": "tribune",
    "tribuns": "tribun",
    "tribus": "tribu",
    "tributaires": "tributaire",
    "tributs": "tribut",
    "tricarde": "tricard",
    "tricards": "tricard",
    "tricennale": "tricennal",
    "tricennales": "tricennal",
    "tricennaux": "tricennal",
    "tricentenaires": "tricentenaire",
    "tricha": "tricher",
    "trichai": "tricher",
    "trichaient": "tricher",
    "trichais": "tricher",
    "trichait": "tricher",
    "trichant": "tricher",
    "trichas": "tricher",
    "trichasse": "tricher",
    "trichassent": "tricher",
    "trichasses": "tricher",
    "trichassiez": "tricher",
    "trichassions": "tricher",
    "triche": "tricher",
    "trichent": "tricher",
    "trichera": "tricher",
    "tricherai": "tricher",
    "tricheraient": "tricher",
    "tricherais": "tricher",
    "tricherait": "tricher",
    "tricheras": "tricher",
    "tricherez": "tricher",
    "tricheries": "tricherie",
    "tricheriez": "tricher",
    "tricherions": "tricher",
    "tricherons": "tricher",
    "tricheront": "tricher",
    "triches": "tricher",
    "tricheurs": "tricheur",
    "tricheuse": "tricheur",
    "tricheuses": "tricheur",
    "trichez": "tricher",
    "trichiez": "tricher",
    "trichines": "trichine",
    "trichions": "tricher",
    "trichomes": "trichome",
    "trichons": "tricher",
    "trichophyties": "trichophytie",
    "trichâmes": "tricher",
    "trichât": "tricher",
    "trichâtes": "tricher",
    "trichèrent": "tricher",
    "triché": "tricher",
    "trichée": "tricher",
    "trichées": "tricher",
    "tricks": "trick",
    "tricliniums": "triclinium",
    "tricolores": "tricolore",
    "tricornes": "tricorne",
    "tricota": "tricoter",
    "tricotages": "tricotage",
    "tricotai": "tricoter",
    "tricotaient": "tricoter",
    "tricotais": "tricoter",
    "tricotait": "tricoter",
    "tricotant": "tricoter",
    "tricotas": "tricoter",
    "tricotasse": "tricoter",
    "tricotassent": "tricoter",
    "tricotasses": "tricoter",
    "tricotassiez": "tricoter",
    "tricotassions": "tricoter",
    "tricote": "tricoter",
    "tricotent": "tricoter",
    "tricotera": "tricoter",
    "tricoterai": "tricoter",
    "tricoteraient": "tricoter",
    "tricoterais": "tricoter",
    "tricoterait": "tricoter",
    "tricoteras": "tricoter",
    "tricoterez": "tricoter",
    "tricoteriez": "tricoter",
    "tricoterions": "tricoter",
    "tricoterons": "tricoter",
    "tricoteront": "tricoter",
    "tricotes": "tricoter",
    "tricoteuse": "tricoteur",
    "tricoteuses": "tricoteur",
    "tricotez": "tricoter",
    "tricotiez": "tricoter",
    "tricotions": "tricoter",
    "tricotons": "tricoter",
    "tricots": "tricot",
    "tricotâmes": "tricoter",
    "tricotât": "tricoter",
    "tricotâtes": "tricoter",
    "tricotèrent": "tricoter",
    "tricoté": "tricoter",
    "tricotée": "tricoter",
    "tricotées": "tricoter",
    "tricotés": "tricoter",
    "trictracs": "trictrac",
    "tricycles": "tricycle",
    "tridents": "trident",
    "tridimensionnelle": "tridimensionnel",
    "trie": "trier",
    "triennale": "triennal",
    "triennales": "triennal",
    "triennaux": "triennal",
    "trient": "trier",
    "triera": "trier",
    "trierai": "trier",
    "trieraient": "trier",
    "trierais": "trier",
    "trierait": "trier",
    "trieras": "trier",
    "trierez": "trier",
    "trieriez": "trier",
    "trierions": "trier",
    "trierons": "trier",
    "trieront": "trier",
    "tries": "trier",
    "trieurs": "trieur",
    "trieuse": "trieur",
    "trieuses": "trieur",
    "triez": "trier",
    "triforiums": "triforium",
    "trifouilla": "trifouiller",
    "trifouillai": "trifouiller",
    "trifouillaient": "trifouiller",
    "trifouillais": "trifouiller",
    "trifouillait": "trifouiller",
    "trifouillant": "trifouiller",
    "trifouillas": "trifouiller",
    "trifouillasse": "trifouiller",
    "trifouillassent": "trifouiller",
    "trifouillasses": "trifouiller",
    "trifouillassiez": "trifouiller",
    "trifouillassions": "trifouiller",
    "trifouille": "trifouiller",
    "trifouillent": "trifouiller",
    "trifouillera": "trifouiller",
    "trifouillerai": "trifouiller",
    "trifouilleraient": "trifouiller",
    "trifouillerais": "trifouiller",
    "trifouillerait": "trifouiller",
    "trifouilleras": "trifouiller",
    "trifouillerez": "trifouiller",
    "trifouilleriez": "trifouiller",
    "trifouillerions": "trifouiller",
    "trifouillerons": "trifouiller",
    "trifouilleront": "trifouiller",
    "trifouilles": "trifouiller",
    "trifouillez": "trifouiller",
    "trifouilliez": "trifouiller",
    "trifouillions": "trifouiller",
    "trifouillons": "trifouiller",
    "trifouillâmes": "trifouiller",
    "trifouillât": "trifouiller",
    "trifouillâtes": "trifouiller",
    "trifouillèrent": "trifouiller",
    "trifouillé": "trifouiller",
    "trigles": "trigle",
    "triglycérides": "triglycéride",
    "trigones": "trigone",
    "trigonométries": "trigonométrie",
    "trigrammes": "trigramme",
    "triiez": "trier",
    "triions": "trier",
    "trijumeaux": "trijumeau",
    "trilatérale": "trilatéral",
    "trilatérales": "trilatéral",
    "trilatéraux": "trilatéral",
    "trilingues": "trilingue",
    "trilinguismes": "trilinguisme",
    "trillant": "triller",
    "trilles": "trille",
    "trillions": "trillion",
    "trillé": "triller",
    "trilobée": "trilobé",
    "trilobés": "trilobé",
    "trilogies": "trilogie",
    "trima": "trimer",
    "trimai": "trimer",
    "trimaient": "trimer",
    "trimais": "trimer",
    "trimait": "trimer",
    "trimant": "trimer",
    "trimarans": "trimaran",
    "trimarde": "trimarder",
    "trimardeurs": "trimardeur",
    "trimards": "trimard",
    "trimas": "trimer",
    "trimasse": "trimer",
    "trimassent": "trimer",
    "trimasses": "trimer",
    "trimassiez": "trimer",
    "trimassions": "trimer",
    "trimbala": "trimbaler",
    "trimbalai": "trimbaler",
    "trimbalaient": "trimbaler",
    "trimbalais": "trimbaler",
    "trimbalait": "trimbaler",
    "trimbalant": "trimbaler",
    "trimbalas": "trimbaler",
    "trimbalasse": "trimbaler",
    "trimbalassent": "trimbaler",
    "trimbalasses": "trimbaler",
    "trimbalassiez": "trimbaler",
    "trimbalassions": "trimbaler",
    "trimbale": "trimbaler",
    "trimbalent": "trimbaler",
    "trimbalera": "trimbaler",
    "trimbalerai": "trimbaler",
    "trimbaleraient": "trimbaler",
    "trimbalerais": "trimbaler",
    "trimbalerait": "trimbaler",
    "trimbaleras": "trimbaler",
    "trimbalerez": "trimbaler",
    "trimbaleriez": "trimbaler",
    "trimbalerions": "trimbaler",
    "trimbalerons": "trimbaler",
    "trimbaleront": "trimbaler",
    "trimbales": "trimbaler",
    "trimbalez": "trimbaler",
    "trimbaliez": "trimbaler",
    "trimbalions": "trimbaler",
    "trimballa": "trimballer",
    "trimballai": "trimballer",
    "trimballaient": "trimballer",
    "trimballais": "trimballer",
    "trimballait": "trimballer",
    "trimballant": "trimballer",
    "trimballas": "trimballer",
    "trimballasse": "trimballer",
    "trimballassent": "trimballer",
    "trimballasses": "trimballer",
    "trimballassiez": "trimballer",
    "trimballassions": "trimballer",
    "trimballe": "trimballer",
    "trimballent": "trimballer",
    "trimballera": "trimballer",
    "trimballerai": "trimballer",
    "trimballeraient": "trimballer",
    "trimballerais": "trimballer",
    "trimballerait": "trimballer",
    "trimballeras": "trimballer",
    "trimballerez": "trimballer",
    "trimballeriez": "trimballer",
    "trimballerions": "trimballer",
    "trimballerons": "trimballer",
    "trimballeront": "trimballer",
    "trimballes": "trimballer",
    "trimballez": "trimballer",
    "trimballiez": "trimballer",
    "trimballions": "trimballer",
    "trimballons": "trimballer",
    "trimballâmes": "trimballer",
    "trimballât": "trimballer",
    "trimballâtes": "trimballer",
    "trimballèrent": "trimballer",
    "trimballé": "trimballer",
    "trimballée": "trimballer",
    "trimballées": "trimballer",
    "trimballés": "trimballer",
    "trimbalons": "trimbaler",
    "trimbalâmes": "trimbaler",
    "trimbalât": "trimbaler",
    "trimbalâtes": "trimbaler",
    "trimbalèrent": "trimbaler",
    "trimbalé": "trimbaler",
    "trimbalée": "trimbaler",
    "trimbalées": "trimbaler",
    "trimbalés": "trimbaler",
    "trime": "trimer",
    "triment": "trimer",
    "trimera": "trimer",
    "trimerai": "trimer",
    "trimeraient": "trimer",
    "trimerais": "trimer",
    "trimerait": "trimer",
    "trimeras": "trimer",
    "trimerez": "trimer",
    "trimeriez": "trimer",
    "trimerions": "trimer",
    "trimerons": "trimer",
    "trimeront": "trimer",
    "trimes": "trimer",
    "trimestres": "trimestre",
    "trimestrielle": "trimestriel",
    "trimestrielles": "trimestriel",
    "trimestriels": "trimestriel",
    "trimeurs": "trimeur",
    "trimez": "trimer",
    "trimiez": "trimer",
    "trimions": "trimer",
    "trimons": "trimer",
    "trimâmes": "trimer",
    "trimât": "trimer",
    "trimâtes": "trimer",
    "trimèrent": "trimer",
    "trimé": "trimer",
    "trine": "trin",
    "tringlaient": "tringler",
    "tringlais": "tringler",
    "tringlait": "tringler",
    "tringle": "tringler",
    "tringlerais": "tringler",
    "tringles": "tringler",
    "tringlots": "tringlot",
    "tringlé": "tringler",
    "tringlée": "tringler",
    "trinitrines": "trinitrine",
    "trinitrotoluènes": "trinitrotoluène",
    "trinités": "trinité",
    "trinqua": "trinquer",
    "trinquai": "trinquer",
    "trinquaient": "trinquer",
    "trinquais": "trinquer",
    "trinquait": "trinquer",
    "trinquant": "trinquer",
    "trinquas": "trinquer",
    "trinquasse": "trinquer",
    "trinquassent": "trinquer",
    "trinquasses": "trinquer",
    "trinquassiez": "trinquer",
    "trinquassions": "trinquer",
    "trinque": "trinquer",
    "trinqueballes": "trinqueballe",
    "trinquent": "trinquer",
    "trinquera": "trinquer",
    "trinquerai": "trinquer",
    "trinqueraient": "trinquer",
    "trinquerais": "trinquer",
    "trinquerait": "trinquer",
    "trinqueras": "trinquer",
    "trinquerez": "trinquer",
    "trinqueriez": "trinquer",
    "trinquerions": "trinquer",
    "trinquerons": "trinquer",
    "trinqueront": "trinquer",
    "trinques": "trinquer",
    "trinquets": "trinquet",
    "trinquez": "trinquer",
    "trinquiez": "trinquer",
    "trinquions": "trinquer",
    "trinquons": "trinquer",
    "trinquâmes": "trinquer",
    "trinquât": "trinquer",
    "trinquâtes": "trinquer",
    "trinquèrent": "trinquer",
    "trinqué": "trinquer",
    "trinômes": "trinôme",
    "triolets": "triolet",
    "triompha": "triompher",
    "triomphai": "triompher",
    "triomphaient": "triompher",
    "triomphais": "triompher",
    "triomphait": "triompher",
    "triomphale": "triomphal",
    "triomphales": "triomphal",
    "triomphalismes": "triomphalisme",
    "triomphalistes": "triomphaliste",
    "triomphant": "triompher",
    "triomphante": "triomphant",
    "triomphantes": "triomphant",
    "triomphants": "triomphant",
    "triomphas": "triompher",
    "triomphasse": "triompher",
    "triomphassent": "triompher",
    "triomphasses": "triompher",
    "triomphassiez": "triompher",
    "triomphassions": "triompher",
    "triomphateurs": "triomphateur",
    "triomphatrice": "triomphateur",
    "triomphatrices": "triomphateur",
    "triomphaux": "triomphal",
    "triomphe": "triompher",
    "triomphent": "triompher",
    "triomphera": "triompher",
    "triompherai": "triompher",
    "triompheraient": "triompher",
    "triompherais": "triompher",
    "triompherait": "triompher",
    "triompheras": "triompher",
    "triompherez": "triompher",
    "triompheriez": "triompher",
    "triompherions": "triompher",
    "triompherons": "triompher",
    "triompheront": "triompher",
    "triomphes": "triompher",
    "triomphez": "triompher",
    "triomphiez": "triompher",
    "triomphions": "triompher",
    "triomphons": "triompher",
    "triomphâmes": "triompher",
    "triomphât": "triompher",
    "triomphâtes": "triompher",
    "triomphèrent": "triompher",
    "triomphé": "triompher",
    "trions": "trier",
    "trios": "trio",
    "tripailles": "tripaille",
    "tripangs": "tripang",
    "tripartie": "triparti",
    "triparties": "triparti",
    "tripartis": "triparti",
    "tripartites": "tripartite",
    "tripartitions": "tripartition",
    "tripatouilla": "tripatouiller",
    "tripatouillages": "tripatouillage",
    "tripatouillai": "tripatouiller",
    "tripatouillaient": "tripatouiller",
    "tripatouillais": "tripatouiller",
    "tripatouillait": "tripatouiller",
    "tripatouillant": "tripatouiller",
    "tripatouillas": "tripatouiller",
    "tripatouillasse": "tripatouiller",
    "tripatouillassent": "tripatouiller",
    "tripatouillasses": "tripatouiller",
    "tripatouillassiez": "tripatouiller",
    "tripatouillassions": "tripatouiller",
    "tripatouille": "tripatouiller",
    "tripatouillent": "tripatouiller",
    "tripatouillera": "tripatouiller",
    "tripatouillerai": "tripatouiller",
    "tripatouilleraient": "tripatouiller",
    "tripatouillerais": "tripatouiller",
    "tripatouillerait": "tripatouiller",
    "tripatouilleras": "tripatouiller",
    "tripatouillerez": "tripatouiller",
    "tripatouilleriez": "tripatouiller",
    "tripatouillerions": "tripatouiller",
    "tripatouillerons": "tripatouiller",
    "tripatouilleront": "tripatouiller",
    "tripatouilles": "tripatouiller",
    "tripatouillez": "tripatouiller",
    "tripatouilliez": "tripatouiller",
    "tripatouillions": "tripatouiller",
    "tripatouillons": "tripatouiller",
    "tripatouillâmes": "tripatouiller",
    "tripatouillât": "tripatouiller",
    "tripatouillâtes": "tripatouiller",
    "tripatouillèrent": "tripatouiller",
    "tripatouillé": "tripatouiller",
    "tripatouillée": "tripatouiller",
    "tripatouillées": "tripatouiller",
    "tripatouillés": "tripatouiller",
    "triperies": "triperie",
    "tripes": "tripe",
    "triphasée": "triphasé",
    "triphasées": "triphasé",
    "triphasés": "triphasé",
    "triphtongues": "triphtongue",
    "tripiers": "tripier",
    "tripière": "tripier",
    "tripla": "tripler",
    "triplai": "tripler",
    "triplaient": "tripler",
    "triplais": "tripler",
    "triplait": "tripler",
    "triplant": "tripler",
    "triplas": "tripler",
    "triplasse": "tripler",
    "triplassent": "tripler",
    "triplasses": "tripler",
    "triplassiez": "tripler",
    "triplassions": "tripler",
    "triple": "tripler",
    "triplements": "triplement",
    "triplent": "tripler",
    "triplera": "tripler",
    "triplerai": "tripler",
    "tripleraient": "tripler",
    "triplerais": "tripler",
    "triplerait": "tripler",
    "tripleras": "tripler",
    "triplerez": "tripler",
    "tripleriez": "tripler",
    "triplerions": "tripler",
    "triplerons": "tripler",
    "tripleront": "tripler",
    "triples": "tripler",
    "triplets": "triplet",
    "triplez": "tripler",
    "tripliez": "tripler",
    "triplions": "tripler",
    "triplons": "tripler",
    "triplâmes": "tripler",
    "triplât": "tripler",
    "triplâtes": "tripler",
    "triplèrent": "tripler",
    "triplé": "tripler",
    "triplée": "tripler",
    "triplées": "tripler",
    "triplés": "tripler",
    "triporteurs": "triporteur",
    "tripota": "tripoter",
    "tripotages": "tripotage",
    "tripotai": "tripoter",
    "tripotaient": "tripoter",
    "tripotais": "tripoter",
    "tripotait": "tripoter",
    "tripotant": "tripoter",
    "tripotas": "tripoter",
    "tripotasse": "tripoter",
    "tripotassent": "tripoter",
    "tripotasses": "tripoter",
    "tripotassiez": "tripoter",
    "tripotassions": "tripoter",
    "tripote": "tripoter",
    "tripotent": "tripoter",
    "tripotera": "tripoter",
    "tripoterai": "tripoter",
    "tripoteraient": "tripoter",
    "tripoterais": "tripoter",
    "tripoterait": "tripoter",
    "tripoteras": "tripoter",
    "tripoterez": "tripoter",
    "tripoteriez": "tripoter",
    "tripoterions": "tripoter",
    "tripoterons": "tripoter",
    "tripoteront": "tripoter",
    "tripotes": "tripoter",
    "tripoteuse": "tripoteur",
    "tripotez": "tripoter",
    "tripotiez": "tripoter",
    "tripotions": "tripoter",
    "tripotons": "tripoter",
    "tripots": "tripot",
    "tripotâmes": "tripoter",
    "tripotât": "tripoter",
    "tripotâtes": "tripoter",
    "tripotèrent": "tripoter",
    "tripoté": "tripoter",
    "tripotée": "tripoter",
    "tripotées": "tripoter",
    "tripotés": "tripoter",
    "trips": "trip",
    "triptyques": "triptyque",
    "triquais": "triquer",
    "triquait": "triquer",
    "trique": "triquer",
    "triqueballes": "triqueballe",
    "triques": "trique",
    "trirèmes": "trirème",
    "tris": "tri",
    "trisannuelle": "trisannuel",
    "trisannuelles": "trisannuel",
    "trisannuels": "trisannuel",
    "trisaïeule": "trisaïeul",
    "trisaïeules": "trisaïeul",
    "trisaïeuls": "trisaïeul",
    "trismes": "trisme",
    "trisocs": "trisoc",
    "trissa": "trisser",
    "trissai": "trisser",
    "trissaient": "trisser",
    "trissais": "trisser",
    "trissait": "trisser",
    "trissant": "trisser",
    "trissas": "trisser",
    "trissasse": "trisser",
    "trissassent": "trisser",
    "trissasses": "trisser",
    "trissassiez": "trisser",
    "trissassions": "trisser",
    "trisse": "trisser",
    "trissent": "trisser",
    "trissera": "trisser",
    "trisserai": "trisser",
    "trisseraient": "trisser",
    "trisserais": "trisser",
    "trisserait": "trisser",
    "trisseras": "trisser",
    "trisserez": "trisser",
    "trisseriez": "trisser",
    "trisserions": "trisser",
    "trisserons": "trisser",
    "trisseront": "trisser",
    "trisses": "trisser",
    "trissez": "trisser",
    "trissiez": "trisser",
    "trissions": "trisser",
    "trissons": "trisser",
    "trissâmes": "trisser",
    "trissât": "trisser",
    "trissâtes": "trisser",
    "trissèrent": "trisser",
    "trissé": "trisser",
    "trissés": "trisser",
    "tristes": "triste",
    "tristesses": "tristesse",
    "tristouillarde": "tristouillard",
    "tristouilles": "tristouille",
    "tristounette": "tristounet",
    "tristounettes": "tristounet",
    "trisyllabes": "trisyllabe",
    "tritiums": "tritium",
    "tritons": "triton",
    "tritura": "triturer",
    "triturai": "triturer",
    "trituraient": "triturer",
    "triturais": "triturer",
    "triturait": "triturer",
    "triturant": "triturer",
    "trituras": "triturer",
    "triturasse": "triturer",
    "triturassent": "triturer",
    "triturasses": "triturer",
    "triturassiez": "triturer",
    "triturassions": "triturer",
    "triturations": "trituration",
    "triture": "triturer",
    "triturent": "triturer",
    "triturera": "triturer",
    "triturerai": "triturer",
    "tritureraient": "triturer",
    "triturerais": "triturer",
    "triturerait": "triturer",
    "tritureras": "triturer",
    "triturerez": "triturer",
    "tritureriez": "triturer",
    "triturerions": "triturer",
    "triturerons": "triturer",
    "tritureront": "triturer",
    "tritures": "triturer",
    "triturez": "triturer",
    "trituriez": "triturer",
    "triturions": "triturer",
    "triturons": "triturer",
    "triturâmes": "triturer",
    "triturât": "triturer",
    "triturâtes": "triturer",
    "triturèrent": "triturer",
    "trituré": "triturer",
    "triturée": "triturer",
    "triturées": "triturer",
    "triturés": "triturer",
    "triumvirale": "triumviral",
    "triumvirales": "triumviral",
    "triumvirats": "triumvirat",
    "triumviraux": "triumviral",
    "triumvirs": "triumvir",
    "trivalente": "trivalent",
    "trivalentes": "trivalent",
    "trivalents": "trivalent",
    "triviale": "trivial",
    "triviales": "trivial",
    "trivialités": "trivialité",
    "triviaux": "trivial",
    "triâmes": "trier",
    "triât": "trier",
    "triâtes": "trier",
    "trièdres": "trièdre",
    "trièrent": "trier",
    "trières": "trière",
    "trié": "trier",
    "triée": "trier",
    "triées": "trier",
    "triés": "trier",
    "trocarts": "trocart",
    "trochanters": "trochanter",
    "trochaïques": "trochaïque",
    "troches": "troche",
    "trochures": "trochure",
    "trochées": "trochée",
    "trocs": "troc",
    "troglodytes": "troglodyte",
    "troglodytiques": "troglodytique",
    "trognes": "trogne",
    "trognons": "trognon",
    "troisièmes": "troisième",
    "trolleys": "trolley",
    "trolls": "troll",
    "trombes": "trombe",
    "trombidions": "trombidion",
    "trombines": "trombine",
    "tromblons": "tromblon",
    "trombones": "trombone",
    "trompa": "tromper",
    "trompai": "tromper",
    "trompaient": "tromper",
    "trompais": "tromper",
    "trompait": "tromper",
    "trompant": "tromper",
    "trompas": "tromper",
    "trompasse": "tromper",
    "trompassent": "tromper",
    "trompasses": "tromper",
    "trompassiez": "tromper",
    "trompassions": "tromper",
    "trompe": "tromper",
    "trompent": "tromper",
    "trompera": "tromper",
    "tromperai": "tromper",
    "tromperaient": "tromper",
    "tromperais": "tromper",
    "tromperait": "tromper",
    "tromperas": "tromper",
    "tromperez": "tromper",
    "tromperies": "tromperie",
    "tromperiez": "tromper",
    "tromperions": "tromper",
    "tromperons": "tromper",
    "tromperont": "tromper",
    "trompes": "tromper",
    "trompeta": "trompeter",
    "trompetai": "trompeter",
    "trompetaient": "trompeter",
    "trompetais": "trompeter",
    "trompetait": "trompeter",
    "trompetant": "trompeter",
    "trompetas": "trompeter",
    "trompetasse": "trompeter",
    "trompetassent": "trompeter",
    "trompetasses": "trompeter",
    "trompetassiez": "trompeter",
    "trompetassions": "trompeter",
    "trompetez": "trompeter",
    "trompetiez": "trompeter",
    "trompetions": "trompeter",
    "trompetons": "trompeter",
    "trompette": "trompeter",
    "trompettent": "trompeter",
    "trompettera": "trompeter",
    "trompetterai": "trompeter",
    "trompetteraient": "trompeter",
    "trompetterais": "trompeter",
    "trompetterait": "trompeter",
    "trompetteras": "trompeter",
    "trompetterez": "trompeter",
    "trompetteriez": "trompeter",
    "trompetterions": "trompeter",
    "trompetterons": "trompeter",
    "trompetteront": "trompeter",
    "trompettes": "trompette",
    "trompettes-de-la-mort": "trompette-de-la-mort",
    "trompettes-des-morts": "trompette-des-morts",
    "trompettistes": "trompettiste",
    "trompetâmes": "trompeter",
    "trompetât": "trompeter",
    "trompetâtes": "trompeter",
    "trompetèrent": "trompeter",
    "trompeté": "trompeter",
    "trompetée": "trompeter",
    "trompetées": "trompeter",
    "trompetés": "trompeter",
    "trompeurs": "trompeur",
    "trompeuse": "trompeux",
    "trompeuses": "trompeux",
    "trompez": "tromper",
    "trompiez": "tromper",
    "trompions": "tromper",
    "trompons": "tromper",
    "trompâmes": "tromper",
    "trompât": "tromper",
    "trompâtes": "tromper",
    "trompèrent": "tromper",
    "trompé": "tromper",
    "trompée": "tromper",
    "trompées": "tromper",
    "trompés": "tromper",
    "troncations": "troncation",
    "tronchais": "troncher",
    "tronches": "tronche",
    "tronché": "troncher",
    "tronchée": "troncher",
    "troncs": "tronc",
    "tronqua": "tronquer",
    "tronquai": "tronquer",
    "tronquaient": "tronquer",
    "tronquais": "tronquer",
    "tronquait": "tronquer",
    "tronquant": "tronquer",
    "tronquas": "tronquer",
    "tronquasse": "tronquer",
    "tronquassent": "tronquer",
    "tronquasses": "tronquer",
    "tronquassiez": "tronquer",
    "tronquassions": "tronquer",
    "tronque": "tronquer",
    "tronquent": "tronquer",
    "tronquera": "tronquer",
    "tronquerai": "tronquer",
    "tronqueraient": "tronquer",
    "tronquerais": "tronquer",
    "tronquerait": "tronquer",
    "tronqueras": "tronquer",
    "tronquerez": "tronquer",
    "tronqueriez": "tronquer",
    "tronquerions": "tronquer",
    "tronquerons": "tronquer",
    "tronqueront": "tronquer",
    "tronques": "tronquer",
    "tronquez": "tronquer",
    "tronquiez": "tronquer",
    "tronquions": "tronquer",
    "tronquons": "tronquer",
    "tronquâmes": "tronquer",
    "tronquât": "tronquer",
    "tronquâtes": "tronquer",
    "tronquèrent": "tronquer",
    "tronqué": "tronquer",
    "tronquée": "tronquer",
    "tronquées": "tronquer",
    "tronqués": "tronquer",
    "tronçonna": "tronçonner",
    "tronçonnai": "tronçonner",
    "tronçonnaient": "tronçonner",
    "tronçonnais": "tronçonner",
    "tronçonnait": "tronçonner",
    "tronçonnant": "tronçonner",
    "tronçonnas": "tronçonner",
    "tronçonnasse": "tronçonner",
    "tronçonnassent": "tronçonner",
    "tronçonnasses": "tronçonner",
    "tronçonnassiez": "tronçonner",
    "tronçonnassions": "tronçonner",
    "tronçonne": "tronçonner",
    "tronçonnent": "tronçonner",
    "tronçonnera": "tronçonner",
    "tronçonnerai": "tronçonner",
    "tronçonneraient": "tronçonner",
    "tronçonnerais": "tronçonner",
    "tronçonnerait": "tronçonner",
    "tronçonneras": "tronçonner",
    "tronçonnerez": "tronçonner",
    "tronçonneriez": "tronçonner",
    "tronçonnerions": "tronçonner",
    "tronçonnerons": "tronçonner",
    "tronçonneront": "tronçonner",
    "tronçonnes": "tronçonner",
    "tronçonneuse": "tronçonneur",
    "tronçonneuses": "tronçonneuse",
    "tronçonnez": "tronçonner",
    "tronçonniez": "tronçonner",
    "tronçonnions": "tronçonner",
    "tronçonnons": "tronçonner",
    "tronçonnâmes": "tronçonner",
    "tronçonnât": "tronçonner",
    "tronçonnâtes": "tronçonner",
    "tronçonnèrent": "tronçonner",
    "tronçonné": "tronçonner",
    "tronçonnée": "tronçonner",
    "tronçonnées": "tronçonner",
    "tronçonnés": "tronçonner",
    "tronçons": "tronçon",
    "trop-perçus": "trop-perçu",
    "trop-pleins": "trop-plein",
    "tropes": "trope",
    "trophées": "trophée",
    "tropicale": "tropical",
    "tropicales": "tropical",
    "tropicaux": "tropical",
    "tropiques": "tropique",
    "tropismes": "tropisme",
    "troposphères": "troposphère",
    "troposphériques": "troposphérique",
    "tropézienne": "tropézien",
    "tropéziens": "tropézien",
    "troqua": "troquer",
    "troquai": "troquer",
    "troquaient": "troquer",
    "troquais": "troquer",
    "troquait": "troquer",
    "troquant": "troquer",
    "troquas": "troquer",
    "troquasse": "troquer",
    "troquassent": "troquer",
    "troquasses": "troquer",
    "troquassiez": "troquer",
    "troquassions": "troquer",
    "troque": "troquer",
    "troquent": "troquer",
    "troquera": "troquer",
    "troquerai": "troquer",
    "troqueraient": "troquer",
    "troquerais": "troquer",
    "troquerait": "troquer",
    "troqueras": "troquer",
    "troquerez": "troquer",
    "troqueriez": "troquer",
    "troquerions": "troquer",
    "troquerons": "troquer",
    "troqueront": "troquer",
    "troques": "troquer",
    "troquets": "troquet",
    "troquez": "troquer",
    "troquiez": "troquer",
    "troquions": "troquer",
    "troquons": "troquer",
    "troquâmes": "troquer",
    "troquât": "troquer",
    "troquâtes": "troquer",
    "troquèrent": "troquer",
    "troqué": "troquer",
    "troquée": "troquer",
    "troquées": "troquer",
    "troqués": "troquer",
    "trots": "trot",
    "trotskistes": "trotskiste",
    "trotskystes": "trotskyste",
    "trotta": "trotter",
    "trottai": "trotter",
    "trottaient": "trotter",
    "trottais": "trotter",
    "trottait": "trotter",
    "trottant": "trotter",
    "trottas": "trotter",
    "trottasse": "trotter",
    "trottassent": "trotter",
    "trottasses": "trotter",
    "trottassiez": "trotter",
    "trottassions": "trotter",
    "trotte": "trotter",
    "trottent": "trotter",
    "trottera": "trotter",
    "trotterai": "trotter",
    "trotteraient": "trotter",
    "trotterais": "trotter",
    "trotterait": "trotter",
    "trotteras": "trotter",
    "trotterez": "trotter",
    "trotteriez": "trotter",
    "trotterions": "trotter",
    "trotterons": "trotter",
    "trotteront": "trotter",
    "trottes": "trotter",
    "trotteurs": "trotteur",
    "trotteuse": "trotteur",
    "trotteuses": "trotteuse",
    "trottez": "trotter",
    "trottiez": "trotter",
    "trottignolles": "trottignolle",
    "trottina": "trottiner",
    "trottinai": "trottiner",
    "trottinaient": "trottiner",
    "trottinais": "trottiner",
    "trottinait": "trottiner",
    "trottinant": "trottiner",
    "trottinas": "trottiner",
    "trottinasse": "trottiner",
    "trottinassent": "trottiner",
    "trottinasses": "trottiner",
    "trottinassiez": "trottiner",
    "trottinassions": "trottiner",
    "trottine": "trottiner",
    "trottinements": "trottinement",
    "trottinent": "trottiner",
    "trottinera": "trottiner",
    "trottinerai": "trottiner",
    "trottineraient": "trottiner",
    "trottinerais": "trottiner",
    "trottinerait": "trottiner",
    "trottineras": "trottiner",
    "trottinerez": "trottiner",
    "trottineriez": "trottiner",
    "trottinerions": "trottiner",
    "trottinerons": "trottiner",
    "trottineront": "trottiner",
    "trottines": "trottiner",
    "trottinettes": "trottinette",
    "trottinez": "trottiner",
    "trottiniez": "trottiner",
    "trottinions": "trottiner",
    "trottinons": "trottiner",
    "trottins": "trottin",
    "trottinâmes": "trottiner",
    "trottinât": "trottiner",
    "trottinâtes": "trottiner",
    "trottinèrent": "trottiner",
    "trottiné": "trottiner",
    "trottions": "trotter",
    "trottoirs": "trottoir",
    "trottons": "trotter",
    "trottâmes": "trotter",
    "trottât": "trotter",
    "trottâtes": "trotter",
    "trottèrent": "trotter",
    "trotté": "trotter",
    "trottée": "trotter",
    "trottées": "trotter",
    "trottés": "trotter",
    "trou-trous": "trou-trou",
    "troua": "trouer",
    "trouai": "trouer",
    "trouaient": "trouer",
    "trouais": "trouer",
    "trouait": "trouer",
    "trouant": "trouer",
    "trouas": "trouer",
    "trouasse": "trouer",
    "trouassent": "trouer",
    "trouasses": "trouer",
    "trouassiez": "trouer",
    "trouassions": "trouer",
    "troubades": "troubade",
    "troubadours": "troubadour",
    "troubla": "troubler",
    "troublai": "troubler",
    "troublaient": "troubler",
    "troublais": "troubler",
    "troublait": "troubler",
    "troublant": "troubler",
    "troublante": "troublant",
    "troublantes": "troublant",
    "troublants": "troublant",
    "troublas": "troubler",
    "troublasse": "troubler",
    "troublassent": "troubler",
    "troublasses": "troubler",
    "troublassiez": "troubler",
    "troublassions": "troubler",
    "trouble": "troubler",
    "trouble-fêtes": "trouble-fête",
    "troublent": "troubler",
    "troublera": "troubler",
    "troublerai": "troubler",
    "troubleraient": "troubler",
    "troublerais": "troubler",
    "troublerait": "troubler",
    "troubleras": "troubler",
    "troublerez": "troubler",
    "troubleriez": "troubler",
    "troublerions": "troubler",
    "troublerons": "troubler",
    "troubleront": "troubler",
    "troubles": "troubler",
    "troublez": "troubler",
    "troubliez": "troubler",
    "troublions": "troubler",
    "troublons": "troubler",
    "troublâmes": "troubler",
    "troublât": "troubler",
    "troublâtes": "troubler",
    "troublèrent": "troubler",
    "troublé": "troubler",
    "troublée": "troubler",
    "troublées": "troubler",
    "troublés": "troubler",
    "trouducuteries": "trouducuterie",
    "troue": "trouer",
    "trouent": "trouer",
    "trouera": "trouer",
    "trouerai": "trouer",
    "troueraient": "trouer",
    "trouerais": "trouer",
    "trouerait": "trouer",
    "troueras": "trouer",
    "trouerez": "trouer",
    "troueriez": "trouer",
    "trouerions": "trouer",
    "trouerons": "trouer",
    "troueront": "trouer",
    "troues": "trouer",
    "trouez": "trouer",
    "troufignons": "troufignon",
    "troufions": "troufion",
    "trouiez": "trouer",
    "trouillait": "trouiller",
    "trouillarde": "trouillard",
    "trouillards": "trouillard",
    "trouilles": "trouille",
    "trouions": "trouer",
    "trouons": "trouer",
    "troupeaux": "troupeau",
    "troupes": "troupe",
    "troupiers": "troupier",
    "trous": "trou",
    "trous-du-cul": "trou-du-cul",
    "troussa": "trousser",
    "troussai": "trousser",
    "troussaient": "trousser",
    "troussais": "trousser",
    "troussait": "trousser",
    "troussant": "trousser",
    "troussas": "trousser",
    "troussasse": "trousser",
    "troussassent": "trousser",
    "troussasses": "trousser",
    "troussassiez": "trousser",
    "troussassions": "trousser",
    "trousse": "trousser",
    "trousse-queues": "trousse-queue",
    "trousseaux": "trousseau",
    "troussent": "trousser",
    "troussequins": "troussequin",
    "troussera": "trousser",
    "trousserai": "trousser",
    "trousseraient": "trousser",
    "trousserais": "trousser",
    "trousserait": "trousser",
    "trousseras": "trousser",
    "trousserez": "trousser",
    "trousseriez": "trousser",
    "trousserions": "trousser",
    "trousserons": "trousser",
    "trousseront": "trousser",
    "trousses": "trousser",
    "troussez": "trousser",
    "troussiez": "trousser",
    "troussions": "trousser",
    "troussons": "trousser",
    "troussâmes": "trousser",
    "troussât": "trousser",
    "troussâtes": "trousser",
    "troussèrent": "trousser",
    "troussé": "trousser",
    "troussée": "trousser",
    "troussées": "trousser",
    "troussés": "trousser",
    "trouva": "trouver",
    "trouvai": "trouver",
    "trouvaient": "trouver",
    "trouvailles": "trouvaille",
    "trouvais": "trouver",
    "trouvait": "trouver",
    "trouvant": "trouver",
    "trouvas": "trouver",
    "trouvasse": "trouver",
    "trouvassent": "trouver",
    "trouvasses": "trouver",
    "trouvassiez": "trouver",
    "trouvassions": "trouver",
    "trouve": "trouver",
    "trouvent": "trouver",
    "trouvera": "trouver",
    "trouverai": "trouver",
    "trouveraient": "trouver",
    "trouverais": "trouver",
    "trouverait": "trouver",
    "trouveras": "trouver",
    "trouverez": "trouver",
    "trouveriez": "trouver",
    "trouverions": "trouver",
    "trouverons": "trouver",
    "trouveront": "trouver",
    "trouves": "trouver",
    "trouveurs": "trouveur",
    "trouvez": "trouver",
    "trouviez": "trouver",
    "trouvions": "trouver",
    "trouvons": "trouver",
    "trouvâmes": "trouver",
    "trouvât": "trouver",
    "trouvâtes": "trouver",
    "trouvèrent": "trouver",
    "trouvères": "trouvère",
    "trouvé": "trouver",
    "trouvée": "trouver",
    "trouvées": "trouver",
    "trouvés": "trouver",
    "trouâmes": "trouer",
    "trouât": "trouer",
    "trouâtes": "trouer",
    "trouèrent": "trouer",
    "troué": "trouer",
    "trouée": "trouer",
    "trouées": "trouer",
    "troués": "trouer",
    "troyenne": "troyen",
    "troènes": "troène",
    "troïkas": "troïka",
    "truandages": "truandage",
    "truande": "truander",
    "truandes": "truander",
    "truands": "truand",
    "truandé": "truander",
    "trublions": "trublion",
    "trucages": "trucage",
    "truchements": "truchement",
    "trucida": "trucider",
    "trucidai": "trucider",
    "trucidaient": "trucider",
    "trucidais": "trucider",
    "trucidait": "trucider",
    "trucidant": "trucider",
    "trucidas": "trucider",
    "trucidasse": "trucider",
    "trucidassent": "trucider",
    "trucidasses": "trucider",
    "trucidassiez": "trucider",
    "trucidassions": "trucider",
    "trucide": "trucider",
    "trucident": "trucider",
    "trucidera": "trucider",
    "truciderai": "trucider",
    "trucideraient": "trucider",
    "truciderais": "trucider",
    "truciderait": "trucider",
    "trucideras": "trucider",
    "truciderez": "trucider",
    "trucideriez": "trucider",
    "truciderions": "trucider",
    "truciderons": "trucider",
    "trucideront": "trucider",
    "trucides": "trucider",
    "trucidez": "trucider",
    "trucidiez": "trucider",
    "trucidions": "trucider",
    "trucidons": "trucider",
    "trucidâmes": "trucider",
    "trucidât": "trucider",
    "trucidâtes": "trucider",
    "trucidèrent": "trucider",
    "trucidé": "trucider",
    "trucidée": "trucider",
    "trucidées": "trucider",
    "trucidés": "trucider",
    "trucks": "truck",
    "trucs": "truc",
    "truculences": "truculence",
    "truculente": "truculent",
    "truculentes": "truculent",
    "truculents": "truculent",
    "truelles": "truelle",
    "truffaient": "truffer",
    "truffait": "truffer",
    "truffant": "truffer",
    "truffe": "truffer",
    "truffes": "truffe",
    "truffiers": "truffier",
    "truffons": "truffer",
    "truffé": "truffer",
    "truffée": "truffer",
    "truffées": "truffer",
    "truffés": "truffer",
    "truies": "truie",
    "truismes": "truisme",
    "truites": "truite",
    "trumeaux": "trumeau",
    "truqua": "truquer",
    "truquages": "truquage",
    "truquai": "truquer",
    "truquaient": "truquer",
    "truquais": "truquer",
    "truquait": "truquer",
    "truquant": "truquer",
    "truquas": "truquer",
    "truquasse": "truquer",
    "truquassent": "truquer",
    "truquasses": "truquer",
    "truquassiez": "truquer",
    "truquassions": "truquer",
    "truque": "truquer",
    "truquent": "truquer",
    "truquera": "truquer",
    "truquerai": "truquer",
    "truqueraient": "truquer",
    "truquerais": "truquer",
    "truquerait": "truquer",
    "truqueras": "truquer",
    "truquerez": "truquer",
    "truqueriez": "truquer",
    "truquerions": "truquer",
    "truquerons": "truquer",
    "truqueront": "truquer",
    "truques": "truquer",
    "truqueurs": "truqueur",
    "truqueuse": "truqueur",
    "truqueuses": "truqueur",
    "truquez": "truquer",
    "truquiez": "truquer",
    "truquions": "truquer",
    "truquons": "truquer",
    "truquâmes": "truquer",
    "truquât": "truquer",
    "truquâtes": "truquer",
    "truquèrent": "truquer",
    "truqué": "truquer",
    "truquée": "truquer",
    "truquées": "truquer",
    "truqués": "truquer",
    "trusquins": "trusquin",
    "trusta": "truster",
    "trustai": "truster",
    "trustaient": "truster",
    "trustais": "truster",
    "trustait": "truster",
    "trustant": "truster",
    "trustas": "truster",
    "trustasse": "truster",
    "trustassent": "truster",
    "trustasses": "truster",
    "trustassiez": "truster",
    "trustassions": "truster",
    "truste": "truster",
    "trustees": "trustee",
    "trusteeships": "trusteeship",
    "trustent": "truster",
    "trustera": "truster",
    "trusterai": "truster",
    "trusteraient": "truster",
    "trusterais": "truster",
    "trusterait": "truster",
    "trusteras": "truster",
    "trusterez": "truster",
    "trusteriez": "truster",
    "trusterions": "truster",
    "trusterons": "truster",
    "trusteront": "truster",
    "trustes": "truster",
    "trustez": "truster",
    "trustiez": "truster",
    "trustions": "truster",
    "trustons": "truster",
    "trusts": "trust",
    "trustâmes": "truster",
    "trustât": "truster",
    "trustâtes": "truster",
    "trustèrent": "truster",
    "trusté": "truster",
    "trustée": "truster",
    "trustées": "truster",
    "trustés": "truster",
    "trypanosomes": "trypanosome",
    "trypsines": "trypsine",
    "trèfles": "trèfle",
    "trébucha": "trébucher",
    "trébuchai": "trébucher",
    "trébuchaient": "trébucher",
    "trébuchais": "trébucher",
    "trébuchait": "trébucher",
    "trébuchant": "trébucher",
    "trébuchante": "trébuchant",
    "trébuchantes": "trébuchant",
    "trébuchants": "trébuchant",
    "trébuchas": "trébucher",
    "trébuchasse": "trébucher",
    "trébuchassent": "trébucher",
    "trébuchasses": "trébucher",
    "trébuchassiez": "trébucher",
    "trébuchassions": "trébucher",
    "trébuche": "trébucher",
    "trébuchements": "trébuchement",
    "trébuchent": "trébucher",
    "trébuchera": "trébucher",
    "trébucherai": "trébucher",
    "trébucheraient": "trébucher",
    "trébucherais": "trébucher",
    "trébucherait": "trébucher",
    "trébucheras": "trébucher",
    "trébucherez": "trébucher",
    "trébucheriez": "trébucher",
    "trébucherions": "trébucher",
    "trébucherons": "trébucher",
    "trébucheront": "trébucher",
    "trébuches": "trébucher",
    "trébuchets": "trébuchet",
    "trébuchez": "trébucher",
    "trébuchiez": "trébucher",
    "trébuchions": "trébucher",
    "trébuchons": "trébucher",
    "trébuchâmes": "trébucher",
    "trébuchât": "trébucher",
    "trébuchâtes": "trébucher",
    "trébuchèrent": "trébucher",
    "trébuché": "trébucher",
    "tréfila": "tréfiler",
    "tréfilai": "tréfiler",
    "tréfilaient": "tréfiler",
    "tréfilais": "tréfiler",
    "tréfilait": "tréfiler",
    "tréfilant": "tréfiler",
    "tréfilas": "tréfiler",
    "tréfilasse": "tréfiler",
    "tréfilassent": "tréfiler",
    "tréfilasses": "tréfiler",
    "tréfilassiez": "tréfiler",
    "tréfilassions": "tréfiler",
    "tréfile": "tréfiler",
    "tréfilent": "tréfiler",
    "tréfilera": "tréfiler",
    "tréfilerai": "tréfiler",
    "tréfileraient": "tréfiler",
    "tréfilerais": "tréfiler",
    "tréfilerait": "tréfiler",
    "tréfileras": "tréfiler",
    "tréfilerez": "tréfiler",
    "tréfileriez": "tréfiler",
    "tréfilerions": "tréfiler",
    "tréfilerons": "tréfiler",
    "tréfileront": "tréfiler",
    "tréfiles": "tréfiler",
    "tréfilez": "tréfiler",
    "tréfiliez": "tréfiler",
    "tréfilions": "tréfiler",
    "tréfilons": "tréfiler",
    "tréfilâmes": "tréfiler",
    "tréfilât": "tréfiler",
    "tréfilâtes": "tréfiler",
    "tréfilèrent": "tréfiler",
    "tréfilé": "tréfiler",
    "tréfilée": "tréfiler",
    "tréfilées": "tréfiler",
    "tréfilés": "tréfiler",
    "tréflières": "tréflière",
    "tréfond": "tréfondre",
    "tréfondaient": "tréfondre",
    "tréfondais": "tréfondre",
    "tréfondait": "tréfondre",
    "tréfondant": "tréfondre",
    "tréfonde": "tréfondre",
    "tréfondent": "tréfondre",
    "tréfondes": "tréfondre",
    "tréfondez": "tréfondre",
    "tréfondiez": "tréfondre",
    "tréfondions": "tréfondre",
    "tréfondirent": "tréfondre",
    "tréfondis": "tréfondre",
    "tréfondisse": "tréfondre",
    "tréfondissent": "tréfondre",
    "tréfondisses": "tréfondre",
    "tréfondissiez": "tréfondre",
    "tréfondissions": "tréfondre",
    "tréfondit": "tréfondre",
    "tréfondons": "tréfondre",
    "tréfondra": "tréfondre",
    "tréfondrai": "tréfondre",
    "tréfondraient": "tréfondre",
    "tréfondrais": "tréfondre",
    "tréfondrait": "tréfondre",
    "tréfondras": "tréfondre",
    "tréfondrez": "tréfondre",
    "tréfondriez": "tréfondre",
    "tréfondrions": "tréfondre",
    "tréfondrons": "tréfondre",
    "tréfondront": "tréfondre",
    "tréfonds": "tréfondre",
    "tréfondu": "tréfondre",
    "tréfondue": "tréfondre",
    "tréfondues": "tréfondre",
    "tréfondus": "tréfondre",
    "tréfondîmes": "tréfondre",
    "tréfondît": "tréfondre",
    "tréfondîtes": "tréfondre",
    "trémails": "trémail",
    "trémas": "tréma",
    "trémata": "trémater",
    "trématai": "trémater",
    "trémataient": "trémater",
    "trématais": "trémater",
    "trématait": "trémater",
    "trématant": "trémater",
    "trématas": "trémater",
    "trématasse": "trémater",
    "trématassent": "trémater",
    "trématasses": "trémater",
    "trématassiez": "trémater",
    "trématassions": "trémater",
    "trémate": "trémater",
    "trématent": "trémater",
    "trématera": "trémater",
    "trématerai": "trémater",
    "trémateraient": "trémater",
    "trématerais": "trémater",
    "trématerait": "trémater",
    "trémateras": "trémater",
    "trématerez": "trémater",
    "trémateriez": "trémater",
    "trématerions": "trémater",
    "trématerons": "trémater",
    "trémateront": "trémater",
    "trémates": "trémater",
    "trématez": "trémater",
    "trématiez": "trémater",
    "trémations": "trémater",
    "trématons": "trémater",
    "trématâmes": "trémater",
    "trématât": "trémater",
    "trématâtes": "trémater",
    "trématèrent": "trémater",
    "trématé": "trémater",
    "trématée": "trémater",
    "trématées": "trémater",
    "trématés": "trémater",
    "trémies": "trémie",
    "trémières": "trémière",
    "trémolos": "trémolo",
    "trémoussa": "trémousser",
    "trémoussai": "trémousser",
    "trémoussaient": "trémousser",
    "trémoussais": "trémousser",
    "trémoussait": "trémousser",
    "trémoussant": "trémousser",
    "trémoussas": "trémousser",
    "trémoussasse": "trémousser",
    "trémoussassent": "trémousser",
    "trémoussasses": "trémousser",
    "trémoussassiez": "trémousser",
    "trémoussassions": "trémousser",
    "trémousse": "trémousser",
    "trémoussements": "trémoussement",
    "trémoussent": "trémousser",
    "trémoussera": "trémousser",
    "trémousserai": "trémousser",
    "trémousseraient": "trémousser",
    "trémousserais": "trémousser",
    "trémousserait": "trémousser",
    "trémousseras": "trémousser",
    "trémousserez": "trémousser",
    "trémousseriez": "trémousser",
    "trémousserions": "trémousser",
    "trémousserons": "trémousser",
    "trémousseront": "trémousser",
    "trémousses": "trémousser",
    "trémoussez": "trémousser",
    "trémoussiez": "trémousser",
    "trémoussions": "trémousser",
    "trémoussons": "trémousser",
    "trémoussâmes": "trémousser",
    "trémoussât": "trémousser",
    "trémoussâtes": "trémousser",
    "trémoussèrent": "trémousser",
    "trémoussé": "trémousser",
    "trémoussée": "trémousser",
    "trémoussées": "trémousser",
    "trémoussés": "trémousser",
    "trémulant": "trémuler",
    "trémulante": "trémulant",
    "trémulations": "trémulation",
    "trépana": "trépaner",
    "trépanai": "trépaner",
    "trépanaient": "trépaner",
    "trépanais": "trépaner",
    "trépanait": "trépaner",
    "trépanant": "trépaner",
    "trépanas": "trépaner",
    "trépanasse": "trépaner",
    "trépanassent": "trépaner",
    "trépanasses": "trépaner",
    "trépanassiez": "trépaner",
    "trépanassions": "trépaner",
    "trépane": "trépaner",
    "trépanent": "trépaner",
    "trépanera": "trépaner",
    "trépanerai": "trépaner",
    "trépaneraient": "trépaner",
    "trépanerais": "trépaner",
    "trépanerait": "trépaner",
    "trépaneras": "trépaner",
    "trépanerez": "trépaner",
    "trépaneriez": "trépaner",
    "trépanerions": "trépaner",
    "trépanerons": "trépaner",
    "trépaneront": "trépaner",
    "trépanes": "trépaner",
    "trépanez": "trépaner",
    "trépaniez": "trépaner",
    "trépanions": "trépaner",
    "trépanons": "trépaner",
    "trépans": "trépan",
    "trépanâmes": "trépaner",
    "trépanât": "trépaner",
    "trépanâtes": "trépaner",
    "trépanèrent": "trépaner",
    "trépané": "trépaner",
    "trépanée": "trépaner",
    "trépanées": "trépaner",
    "trépanés": "trépaner",
    "trépassa": "trépasser",
    "trépassai": "trépasser",
    "trépassaient": "trépasser",
    "trépassais": "trépasser",
    "trépassait": "trépasser",
    "trépassant": "trépasser",
    "trépassas": "trépasser",
    "trépassasse": "trépasser",
    "trépassassent": "trépasser",
    "trépassasses": "trépasser",
    "trépassassiez": "trépasser",
    "trépassassions": "trépasser",
    "trépasse": "trépasser",
    "trépassent": "trépasser",
    "trépassera": "trépasser",
    "trépasserai": "trépasser",
    "trépasseraient": "trépasser",
    "trépasserais": "trépasser",
    "trépasserait": "trépasser",
    "trépasseras": "trépasser",
    "trépasserez": "trépasser",
    "trépasseriez": "trépasser",
    "trépasserions": "trépasser",
    "trépasserons": "trépasser",
    "trépasseront": "trépasser",
    "trépasses": "trépasser",
    "trépassez": "trépasser",
    "trépassiez": "trépasser",
    "trépassions": "trépasser",
    "trépassons": "trépasser",
    "trépassâmes": "trépasser",
    "trépassât": "trépasser",
    "trépassâtes": "trépasser",
    "trépassèrent": "trépasser",
    "trépassé": "trépasser",
    "trépassée": "trépasser",
    "trépassées": "trépasser",
    "trépassés": "trépasser",
    "trépida": "trépider",
    "trépidai": "trépider",
    "trépidaient": "trépider",
    "trépidais": "trépider",
    "trépidait": "trépider",
    "trépidant": "trépider",
    "trépidante": "trépidant",
    "trépidantes": "trépidant",
    "trépidants": "trépidant",
    "trépidas": "trépider",
    "trépidasse": "trépider",
    "trépidassent": "trépider",
    "trépidasses": "trépider",
    "trépidassiez": "trépider",
    "trépidassions": "trépider",
    "trépidations": "trépidation",
    "trépide": "trépider",
    "trépident": "trépider",
    "trépidera": "trépider",
    "trépiderai": "trépider",
    "trépideraient": "trépider",
    "trépiderais": "trépider",
    "trépiderait": "trépider",
    "trépideras": "trépider",
    "trépiderez": "trépider",
    "trépideriez": "trépider",
    "trépiderions": "trépider",
    "trépiderons": "trépider",
    "trépideront": "trépider",
    "trépides": "trépider",
    "trépidez": "trépider",
    "trépidiez": "trépider",
    "trépidions": "trépider",
    "trépidons": "trépider",
    "trépidâmes": "trépider",
    "trépidât": "trépider",
    "trépidâtes": "trépider",
    "trépidèrent": "trépider",
    "trépidé": "trépider",
    "trépieds": "trépied",
    "trépigna": "trépigner",
    "trépignai": "trépigner",
    "trépignaient": "trépigner",
    "trépignais": "trépigner",
    "trépignait": "trépigner",
    "trépignant": "trépigner",
    "trépignante": "trépignant",
    "trépignants": "trépignant",
    "trépignas": "trépigner",
    "trépignasse": "trépigner",
    "trépignassent": "trépigner",
    "trépignasses": "trépigner",
    "trépignassiez": "trépigner",
    "trépignassions": "trépigner",
    "trépigne": "trépigner",
    "trépignements": "trépignement",
    "trépignent": "trépigner",
    "trépignera": "trépigner",
    "trépignerai": "trépigner",
    "trépigneraient": "trépigner",
    "trépignerais": "trépigner",
    "trépignerait": "trépigner",
    "trépigneras": "trépigner",
    "trépignerez": "trépigner",
    "trépigneriez": "trépigner",
    "trépignerions": "trépigner",
    "trépignerons": "trépigner",
    "trépigneront": "trépigner",
    "trépignes": "trépigner",
    "trépignez": "trépigner",
    "trépigniez": "trépigner",
    "trépignions": "trépigner",
    "trépignons": "trépigner",
    "trépignâmes": "trépigner",
    "trépignât": "trépigner",
    "trépignâtes": "trépigner",
    "trépignèrent": "trépigner",
    "trépigné": "trépigner",
    "trépignée": "trépigner",
    "tréponèmes": "tréponème",
    "trésoreries": "trésorerie",
    "trésoriers": "trésorier",
    "trésorière": "trésorier",
    "trésorières": "trésorier",
    "trésors": "trésor",
    "tréteaux": "tréteau",
    "trêves": "trêve",
    "trôna": "trôner",
    "trônai": "trôner",
    "trônaient": "trôner",
    "trônais": "trôner",
    "trônait": "trôner",
    "trônant": "trôner",
    "trônas": "trôner",
    "trônasse": "trôner",
    "trônassent": "trôner",
    "trônasses": "trôner",
    "trônassiez": "trôner",
    "trônassions": "trôner",
    "trône": "trôner",
    "trônent": "trôner",
    "trônera": "trôner",
    "trônerai": "trôner",
    "trôneraient": "trôner",
    "trônerais": "trôner",
    "trônerait": "trôner",
    "trôneras": "trôner",
    "trônerez": "trôner",
    "trôneriez": "trôner",
    "trônerions": "trôner",
    "trônerons": "trôner",
    "trôneront": "trôner",
    "trônes": "trôner",
    "trônez": "trôner",
    "trôniez": "trôner",
    "trônions": "trôner",
    "trônons": "trôner",
    "trônâmes": "trôner",
    "trônât": "trôner",
    "trônâtes": "trôner",
    "trônèrent": "trôner",
    "trôné": "trôner",
    "tsarine": "tsar",
    "tsarines": "tsar",
    "tsaristes": "tsariste",
    "tsars": "tsar",
    "tsarévitchs": "tsarévitch",
    "tsiganes": "tsigane",
    "tss tss": "tss-tss",
    "tu": "taire",
    "tua": "tuer",
    "tuai": "tuer",
    "tuaient": "tuer",
    "tuais": "tuer",
    "tuait": "tuer",
    "tuant": "tuer",
    "tuante": "tuant",
    "tuantes": "tuant",
    "tuants": "tuant",
    "tuas": "tuer",
    "tuasse": "tuer",
    "tuassent": "tuer",
    "tuasses": "tuer",
    "tuassiez": "tuer",
    "tuassions": "tuer",
    "tuba": "tuber",
    "tubages": "tubage",
    "tubai": "tuber",
    "tubaient": "tuber",
    "tubais": "tuber",
    "tubait": "tuber",
    "tubant": "tuber",
    "tubarde": "tubard",
    "tubards": "tubard",
    "tubas": "tuber",
    "tubasse": "tuber",
    "tubassent": "tuber",
    "tubasses": "tuber",
    "tubassiez": "tuber",
    "tubassions": "tuber",
    "tube": "tuber",
    "tubent": "tuber",
    "tubera": "tuber",
    "tuberai": "tuber",
    "tuberaient": "tuber",
    "tuberais": "tuber",
    "tuberait": "tuber",
    "tuberas": "tuber",
    "tubercules": "tubercule",
    "tuberculeuse": "tuberculeux",
    "tuberculeuses": "tuberculeux",
    "tuberculoses": "tuberculose",
    "tuberez": "tuber",
    "tuberiez": "tuber",
    "tuberions": "tuber",
    "tuberons": "tuber",
    "tuberont": "tuber",
    "tubes": "tuber",
    "tubez": "tuber",
    "tubiez": "tuber",
    "tubions": "tuber",
    "tubons": "tuber",
    "tubs": "tub",
    "tubulaires": "tubulaire",
    "tubuleuses": "tubuleux",
    "tubulures": "tubulure",
    "tubâmes": "tuber",
    "tubât": "tuber",
    "tubâtes": "tuber",
    "tubèrent": "tuber",
    "tubé": "tuber",
    "tubée": "tuber",
    "tubées": "tuber",
    "tubéreuse": "tubéreux",
    "tubéreuses": "tubéreux",
    "tubérosités": "tubérosité",
    "tubés": "tuber",
    "tudesques": "tudesque",
    "tue": "tuer",
    "tue-loups": "tue-loup",
    "tue-mouches": "tue-mouche",
    "tuent": "tuer",
    "tuera": "tuer",
    "tuerai": "tuer",
    "tueraient": "tuer",
    "tuerais": "tuer",
    "tuerait": "tuer",
    "tueras": "tuer",
    "tuerez": "tuer",
    "tueries": "tuerie",
    "tueriez": "tuer",
    "tuerions": "tuer",
    "tuerons": "tuer",
    "tueront": "tuer",
    "tues": "tuer",
    "tueurs": "tueur",
    "tueuse": "tueur",
    "tueuses": "tueur",
    "tuez": "tuer",
    "tufeaux": "tufeau",
    "tuffeaux": "tuffeau",
    "tufs": "tuf",
    "tuiez": "tuer",
    "tuileaux": "tuileau",
    "tuileries": "tuilerie",
    "tuiles": "tuile",
    "tuions": "tuer",
    "tulipes": "tulipe",
    "tulipiers": "tulipier",
    "tulles": "tulle",
    "tumescente": "tumescent",
    "tumescentes": "tumescent",
    "tumescents": "tumescent",
    "tumeurs": "tumeur",
    "tumorale": "tumoral",
    "tumorales": "tumoral",
    "tumoraux": "tumoral",
    "tumulaires": "tumulaire",
    "tumuli": "tumulus",
    "tumultes": "tumulte",
    "tumultueuse": "tumultueux",
    "tumultueuses": "tumultueux",
    "tuméfia": "tuméfier",
    "tuméfiai": "tuméfier",
    "tuméfiaient": "tuméfier",
    "tuméfiais": "tuméfier",
    "tuméfiait": "tuméfier",
    "tuméfiant": "tuméfier",
    "tuméfias": "tuméfier",
    "tuméfiasse": "tuméfier",
    "tuméfiassent": "tuméfier",
    "tuméfiasses": "tuméfier",
    "tuméfiassiez": "tuméfier",
    "tuméfiassions": "tuméfier",
    "tuméfie": "tuméfier",
    "tuméfient": "tuméfier",
    "tuméfiera": "tuméfier",
    "tuméfierai": "tuméfier",
    "tuméfieraient": "tuméfier",
    "tuméfierais": "tuméfier",
    "tuméfierait": "tuméfier",
    "tuméfieras": "tuméfier",
    "tuméfierez": "tuméfier",
    "tuméfieriez": "tuméfier",
    "tuméfierions": "tuméfier",
    "tuméfierons": "tuméfier",
    "tuméfieront": "tuméfier",
    "tuméfies": "tuméfier",
    "tuméfiez": "tuméfier",
    "tuméfiiez": "tuméfier",
    "tuméfiions": "tuméfier",
    "tuméfions": "tuméfier",
    "tuméfiâmes": "tuméfier",
    "tuméfiât": "tuméfier",
    "tuméfiâtes": "tuméfier",
    "tuméfièrent": "tuméfier",
    "tuméfié": "tuméfier",
    "tuméfiée": "tuméfier",
    "tuméfiées": "tuméfier",
    "tuméfiés": "tuméfier",
    "tuners": "tuner",
    "tunes": "tune",
    "tungstènes": "tungstène",
    "tuniques": "tunique",
    "tunisienne": "tunisien",
    "tunisiennes": "tunisien",
    "tunisiens": "tunisien",
    "tunisoise": "tunisois",
    "tunisoises": "tunisois",
    "tunnels": "tunnel",
    "tuons": "tuer",
    "tupis": "tupi",
    "turbans": "turban",
    "turbidités": "turbidité",
    "turbina": "turbiner",
    "turbinaient": "turbiner",
    "turbinait": "turbiner",
    "turbine": "turbiner",
    "turbines": "turbiner",
    "turbinez": "turbiner",
    "turbins": "turbin",
    "turbiné": "turbiner",
    "turbocompresseurs": "turbocompresseur",
    "turbomoteurs": "turbomoteur",
    "turboréacteurs": "turboréacteur",
    "turbos": "turbo",
    "turbotières": "turbotière",
    "turbots": "turbot",
    "turbulences": "turbulence",
    "turbulente": "turbulent",
    "turbulentes": "turbulent",
    "turbulents": "turbulent",
    "turbés": "turbé",
    "turcomans": "turcoman",
    "turcos": "turco",
    "turcs": "turc",
    "turent": "taire",
    "turfistes": "turfiste",
    "turfs": "turf",
    "turgescente": "turgescent",
    "turgescentes": "turgescent",
    "turgescents": "turgescent",
    "turinoise": "turinois",
    "turistas": "turista",
    "turkmènes": "turkmène",
    "turlupina": "turlupiner",
    "turlupinades": "turlupinade",
    "turlupinai": "turlupiner",
    "turlupinaient": "turlupiner",
    "turlupinais": "turlupiner",
    "turlupinait": "turlupiner",
    "turlupinant": "turlupiner",
    "turlupinas": "turlupiner",
    "turlupinasse": "turlupiner",
    "turlupinassent": "turlupiner",
    "turlupinasses": "turlupiner",
    "turlupinassiez": "turlupiner",
    "turlupinassions": "turlupiner",
    "turlupine": "turlupiner",
    "turlupinent": "turlupiner",
    "turlupinera": "turlupiner",
    "turlupinerai": "turlupiner",
    "turlupineraient": "turlupiner",
    "turlupinerais": "turlupiner",
    "turlupinerait": "turlupiner",
    "turlupineras": "turlupiner",
    "turlupinerez": "turlupiner",
    "turlupineriez": "turlupiner",
    "turlupinerions": "turlupiner",
    "turlupinerons": "turlupiner",
    "turlupineront": "turlupiner",
    "turlupines": "turlupiner",
    "turlupinez": "turlupiner",
    "turlupiniez": "turlupiner",
    "turlupinions": "turlupiner",
    "turlupinons": "turlupiner",
    "turlupins": "turlupin",
    "turlupinâmes": "turlupiner",
    "turlupinât": "turlupiner",
    "turlupinâtes": "turlupiner",
    "turlupinèrent": "turlupiner",
    "turlupiné": "turlupiner",
    "turlupinée": "turlupiner",
    "turlupinées": "turlupiner",
    "turlupinés": "turlupiner",
    "turlutaines": "turlutaine",
    "turlute": "turluter",
    "turlutent": "turluter",
    "turlutes": "turluter",
    "turluttes": "turlutte",
    "turnes": "turne",
    "turpides": "turpide",
    "turpitudes": "turpitude",
    "turque": "turc",
    "turqueries": "turquerie",
    "turques": "turc",
    "turquoises": "turquoise",
    "tus": "tu",
    "tusse": "taire",
    "tussent": "taire",
    "tusses": "taire",
    "tussiez": "taire",
    "tussions": "taire",
    "tut": "taire",
    "tutelles": "tutelle",
    "tuteurs": "tuteur",
    "tutoie": "tutoyer",
    "tutoiements": "tutoiement",
    "tutoient": "tutoyer",
    "tutoiera": "tutoyer",
    "tutoierai": "tutoyer",
    "tutoieraient": "tutoyer",
    "tutoierais": "tutoyer",
    "tutoierait": "tutoyer",
    "tutoieras": "tutoyer",
    "tutoierez": "tutoyer",
    "tutoieriez": "tutoyer",
    "tutoierions": "tutoyer",
    "tutoierons": "tutoyer",
    "tutoieront": "tutoyer",
    "tutoies": "tutoyer",
    "tutoriaux": "tutorial",
    "tutoya": "tutoyer",
    "tutoyai": "tutoyer",
    "tutoyaient": "tutoyer",
    "tutoyais": "tutoyer",
    "tutoyait": "tutoyer",
    "tutoyant": "tutoyer",
    "tutoyas": "tutoyer",
    "tutoyasse": "tutoyer",
    "tutoyassent": "tutoyer",
    "tutoyasses": "tutoyer",
    "tutoyassiez": "tutoyer",
    "tutoyassions": "tutoyer",
    "tutoyeuses": "tutoyeur",
    "tutoyez": "tutoyer",
    "tutoyiez": "tutoyer",
    "tutoyions": "tutoyer",
    "tutoyons": "tutoyer",
    "tutoyâmes": "tutoyer",
    "tutoyât": "tutoyer",
    "tutoyâtes": "tutoyer",
    "tutoyèrent": "tutoyer",
    "tutoyé": "tutoyer",
    "tutoyée": "tutoyer",
    "tutoyées": "tutoyer",
    "tutoyés": "tutoyer",
    "tutrice": "tuteur",
    "tutrices": "tuteur",
    "tutus": "tutu",
    "tutute": "tutut",
    "tutélaires": "tutélaire",
    "tuyauta": "tuyauter",
    "tuyautages": "tuyautage",
    "tuyautai": "tuyauter",
    "tuyautaient": "tuyauter",
    "tuyautais": "tuyauter",
    "tuyautait": "tuyauter",
    "tuyautant": "tuyauter",
    "tuyautas": "tuyauter",
    "tuyautasse": "tuyauter",
    "tuyautassent": "tuyauter",
    "tuyautasses": "tuyauter",
    "tuyautassiez": "tuyauter",
    "tuyautassions": "tuyauter",
    "tuyaute": "tuyauter",
    "tuyautent": "tuyauter",
    "tuyautera": "tuyauter",
    "tuyauterai": "tuyauter",
    "tuyauteraient": "tuyauter",
    "tuyauterais": "tuyauter",
    "tuyauterait": "tuyauter",
    "tuyauteras": "tuyauter",
    "tuyauterez": "tuyauter",
    "tuyauteries": "tuyauterie",
    "tuyauteriez": "tuyauter",
    "tuyauterions": "tuyauter",
    "tuyauterons": "tuyauter",
    "tuyauteront": "tuyauter",
    "tuyautes": "tuyauter",
    "tuyauteurs": "tuyauteur",
    "tuyautez": "tuyauter",
    "tuyautiez": "tuyauter",
    "tuyautions": "tuyauter",
    "tuyautons": "tuyauter",
    "tuyautâmes": "tuyauter",
    "tuyautât": "tuyauter",
    "tuyautâtes": "tuyauter",
    "tuyautèrent": "tuyauter",
    "tuyauté": "tuyauter",
    "tuyautée": "tuyauter",
    "tuyautées": "tuyauter",
    "tuyautés": "tuyauter",
    "tuyaux": "tuyau",
    "tuyères": "tuyère",
    "tuâmes": "tuer",
    "tuât": "tuer",
    "tuâtes": "tuer",
    "tuèrent": "tuer",
    "tué": "tuer",
    "tuée": "tuer",
    "tuées": "tuer",
    "tués": "tuer",
    "tweeds": "tweed",
    "twin-sets": "twin-set",
    "twistant": "twister",
    "twists": "twist",
    "twistées": "twister",
    "tympanons": "tympanon",
    "tympans": "tympan",
    "typa": "typer",
    "typai": "typer",
    "typaient": "typer",
    "typais": "typer",
    "typait": "typer",
    "typant": "typer",
    "typas": "typer",
    "typasse": "typer",
    "typassent": "typer",
    "typasses": "typer",
    "typassiez": "typer",
    "typassions": "typer",
    "type": "typer",
    "typent": "typer",
    "typera": "typer",
    "typerai": "typer",
    "typeraient": "typer",
    "typerais": "typer",
    "typerait": "typer",
    "typeras": "typer",
    "typerez": "typer",
    "typeriez": "typer",
    "typerions": "typer",
    "typerons": "typer",
    "typeront": "typer",
    "types": "typer",
    "typesse": "type",
    "typesses": "type",
    "typez": "typer",
    "typhiques": "typhique",
    "typhons": "typhon",
    "typhoïdes": "typhoïde",
    "typiez": "typer",
    "typions": "typer",
    "typiques": "typique",
    "typographes": "typographe",
    "typographies": "typographie",
    "typographiques": "typographique",
    "typologies": "typologie",
    "typologiques": "typologique",
    "typons": "typer",
    "typos": "typo",
    "typtologies": "typtologie",
    "typâmes": "typer",
    "typât": "typer",
    "typâtes": "typer",
    "typèrent": "typer",
    "typé": "typer",
    "typée": "typer",
    "typées": "typer",
    "typés": "typer",
    "tyranneaux": "tyranneau",
    "tyrannicides": "tyrannicide",
    "tyrannies": "tyrannie",
    "tyranniques": "tyrannique",
    "tyrannisais": "tyranniser",
    "tyrannisait": "tyranniser",
    "tyrannisant": "tyranniser",
    "tyrannise": "tyranniser",
    "tyrannisent": "tyranniser",
    "tyrannisèrent": "tyranniser",
    "tyrannisé": "tyranniser",
    "tyrannisée": "tyranniser",
    "tyrannosaures": "tyrannosaure",
    "tyrans": "tyran",
    "tyrienne": "tyrien",
    "tyrolienne": "tyrolien",
    "tyroliennes": "tyrolien",
    "tyroliens": "tyrolien",
    "tyrosines": "tyrosine",
    "tyrrhénienne": "tyrrhénien",
    "tzarine": "tzar",
    "tzarines": "tzar",
    "tzars": "tzar",
    "tzarévitchs": "tzarévitch",
    "tziganes": "tzigane",
    "tâcha": "tâcher",
    "tâchai": "tâcher",
    "tâchaient": "tâcher",
    "tâchais": "tâcher",
    "tâchait": "tâcher",
    "tâchant": "tâcher",
    "tâchas": "tâcher",
    "tâchasse": "tâcher",
    "tâchassent": "tâcher",
    "tâchasses": "tâcher",
    "tâchassiez": "tâcher",
    "tâchassions": "tâcher",
    "tâche": "tâcher",
    "tâchent": "tâcher",
    "tâchera": "tâcher",
    "tâcherai": "tâcher",
    "tâcheraient": "tâcher",
    "tâcherais": "tâcher",
    "tâcherait": "tâcher",
    "tâcheras": "tâcher",
    "tâcherez": "tâcher",
    "tâcheriez": "tâcher",
    "tâcherions": "tâcher",
    "tâcherons": "tâcheron",
    "tâcheront": "tâcher",
    "tâches": "tâcher",
    "tâchez": "tâcher",
    "tâchiez": "tâcher",
    "tâchions": "tâcher",
    "tâchons": "tâcher",
    "tâchâmes": "tâcher",
    "tâchât": "tâcher",
    "tâchâtes": "tâcher",
    "tâchèrent": "tâcher",
    "tâché": "tâcher",
    "tâchée": "tâcher",
    "tâchés": "tâcher",
    "tâta": "tâter",
    "tâtai": "tâter",
    "tâtaient": "tâter",
    "tâtais": "tâter",
    "tâtait": "tâter",
    "tâtant": "tâter",
    "tâtas": "tâter",
    "tâtasse": "tâter",
    "tâtassent": "tâter",
    "tâtasses": "tâter",
    "tâtassiez": "tâter",
    "tâtassions": "tâter",
    "tâte": "tâter",
    "tâtent": "tâter",
    "tâtera": "tâter",
    "tâterai": "tâter",
    "tâteraient": "tâter",
    "tâterais": "tâter",
    "tâterait": "tâter",
    "tâteras": "tâter",
    "tâterez": "tâter",
    "tâteriez": "tâter",
    "tâterions": "tâter",
    "tâterons": "tâter",
    "tâteront": "tâter",
    "tâtes": "tâter",
    "tâtez": "tâter",
    "tâtiez": "tâter",
    "tâtions": "tâter",
    "tâtonna": "tâtonner",
    "tâtonnai": "tâtonner",
    "tâtonnaient": "tâtonner",
    "tâtonnais": "tâtonner",
    "tâtonnait": "tâtonner",
    "tâtonnant": "tâtonner",
    "tâtonnante": "tâtonnant",
    "tâtonnantes": "tâtonnant",
    "tâtonnants": "tâtonnant",
    "tâtonnas": "tâtonner",
    "tâtonnasse": "tâtonner",
    "tâtonnassent": "tâtonner",
    "tâtonnasses": "tâtonner",
    "tâtonnassiez": "tâtonner",
    "tâtonnassions": "tâtonner",
    "tâtonne": "tâtonner",
    "tâtonnements": "tâtonnement",
    "tâtonnent": "tâtonner",
    "tâtonnera": "tâtonner",
    "tâtonnerai": "tâtonner",
    "tâtonneraient": "tâtonner",
    "tâtonnerais": "tâtonner",
    "tâtonnerait": "tâtonner",
    "tâtonneras": "tâtonner",
    "tâtonnerez": "tâtonner",
    "tâtonneriez": "tâtonner",
    "tâtonnerions": "tâtonner",
    "tâtonnerons": "tâtonner",
    "tâtonneront": "tâtonner",
    "tâtonnes": "tâtonner",
    "tâtonnez": "tâtonner",
    "tâtonniez": "tâtonner",
    "tâtonnions": "tâtonner",
    "tâtonnons": "tâtonner",
    "tâtonnâmes": "tâtonner",
    "tâtonnât": "tâtonner",
    "tâtonnâtes": "tâtonner",
    "tâtonnèrent": "tâtonner",
    "tâtonné": "tâtonner",
    "tâtonnée": "tâtonner",
    "tâtons": "tâter",
    "tâtâmes": "tâter",
    "tâtât": "tâter",
    "tâtâtes": "tâter",
    "tâtèrent": "tâter",
    "tâté": "tâter",
    "tâtée": "tâter",
    "tâtées": "tâter",
    "tâtés": "tâter",
    "tète": "téter",
    "tètent": "téter",
    "tètes": "téter",
    "téguments": "tégument",
    "tégénaires": "tégénaire",
    "télescopa": "télescoper",
    "télescopages": "télescopage",
    "télescopai": "télescoper",
    "télescopaient": "télescoper",
    "télescopais": "télescoper",
    "télescopait": "télescoper",
    "télescopant": "télescoper",
    "télescopas": "télescoper",
    "télescopasse": "télescoper",
    "télescopassent": "télescoper",
    "télescopasses": "télescoper",
    "télescopassiez": "télescoper",
    "télescopassions": "télescoper",
    "télescope": "télescoper",
    "télescopent": "télescoper",
    "télescopera": "télescoper",
    "télescoperai": "télescoper",
    "télescoperaient": "télescoper",
    "télescoperais": "télescoper",
    "télescoperait": "télescoper",
    "télescoperas": "télescoper",
    "télescoperez": "télescoper",
    "télescoperiez": "télescoper",
    "télescoperions": "télescoper",
    "télescoperons": "télescoper",
    "télescoperont": "télescoper",
    "télescopes": "télescoper",
    "télescopez": "télescoper",
    "télescopiez": "télescoper",
    "télescopions": "télescoper",
    "télescopiques": "télescopique",
    "télescopons": "télescoper",
    "télescopâmes": "télescoper",
    "télescopât": "télescoper",
    "télescopâtes": "télescoper",
    "télescopèrent": "télescoper",
    "télescopé": "télescoper",
    "télescopée": "télescoper",
    "télescopées": "télescoper",
    "télescopés": "télescoper",
    "télescripteurs": "télescripteur",
    "télespectateurs": "télespectateur",
    "télespectatrice": "télespectateur",
    "télespectatrices": "télespectateur",
    "télexa": "télexer",
    "télexes": "télexer",
    "télexé": "télexer",
    "télé-enseignements": "télé-enseignement",
    "téléastes": "téléaste",
    "télécabines": "télécabine",
    "télécartes": "télécarte",
    "télécharge": "télécharger",
    "téléchargeables": "téléchargeable",
    "téléchargent": "télécharger",
    "téléchargeons": "télécharger",
    "téléchargera": "télécharger",
    "téléchargerai": "télécharger",
    "téléchargerons": "télécharger",
    "téléchargez": "télécharger",
    "téléchargé": "télécharger",
    "téléchargée": "télécharger",
    "téléchargées": "télécharger",
    "téléchargés": "télécharger",
    "télécinémas": "télécinéma",
    "télécommanda": "télécommander",
    "télécommandai": "télécommander",
    "télécommandaient": "télécommander",
    "télécommandais": "télécommander",
    "télécommandait": "télécommander",
    "télécommandant": "télécommander",
    "télécommandas": "télécommander",
    "télécommandasse": "télécommander",
    "télécommandassent": "télécommander",
    "télécommandasses": "télécommander",
    "télécommandassiez": "télécommander",
    "télécommandassions": "télécommander",
    "télécommande": "télécommander",
    "télécommandent": "télécommander",
    "télécommandera": "télécommander",
    "télécommanderai": "télécommander",
    "télécommanderaient": "télécommander",
    "télécommanderais": "télécommander",
    "télécommanderait": "télécommander",
    "télécommanderas": "télécommander",
    "télécommanderez": "télécommander",
    "télécommanderiez": "télécommander",
    "télécommanderions": "télécommander",
    "télécommanderons": "télécommander",
    "télécommanderont": "télécommander",
    "télécommandes": "télécommander",
    "télécommandez": "télécommander",
    "télécommandiez": "télécommander",
    "télécommandions": "télécommander",
    "télécommandons": "télécommander",
    "télécommandâmes": "télécommander",
    "télécommandât": "télécommander",
    "télécommandâtes": "télécommander",
    "télécommandèrent": "télécommander",
    "télécommandé": "télécommander",
    "télécommandée": "télécommander",
    "télécommandées": "télécommander",
    "télécommandés": "télécommander",
    "télécommunications": "télécommunication",
    "télécoms": "télécom",
    "téléconsultations": "téléconsultation",
    "télécopia": "télécopier",
    "télécopiai": "télécopier",
    "télécopiaient": "télécopier",
    "télécopiais": "télécopier",
    "télécopiait": "télécopier",
    "télécopiant": "télécopier",
    "télécopias": "télécopier",
    "télécopiasse": "télécopier",
    "télécopiassent": "télécopier",
    "télécopiasses": "télécopier",
    "télécopiassiez": "télécopier",
    "télécopiassions": "télécopier",
    "télécopie": "télécopier",
    "télécopient": "télécopier",
    "télécopiera": "télécopier",
    "télécopierai": "télécopier",
    "télécopieraient": "télécopier",
    "télécopierais": "télécopier",
    "télécopierait": "télécopier",
    "télécopieras": "télécopier",
    "télécopierez": "télécopier",
    "télécopieriez": "télécopier",
    "télécopierions": "télécopier",
    "télécopierons": "télécopier",
    "télécopieront": "télécopier",
    "télécopies": "télécopier",
    "télécopiez": "télécopier",
    "télécopiiez": "télécopier",
    "télécopiions": "télécopier",
    "télécopions": "télécopier",
    "télécopiâmes": "télécopier",
    "télécopiât": "télécopier",
    "télécopiâtes": "télécopier",
    "télécopièrent": "télécopier",
    "télécopié": "télécopier",
    "télécopiée": "télécopier",
    "télécopiées": "télécopier",
    "télécopiés": "télécopier",
    "télécrans": "télécran",
    "télédiffusa": "télédiffuser",
    "télédiffusai": "télédiffuser",
    "télédiffusaient": "télédiffuser",
    "télédiffusais": "télédiffuser",
    "télédiffusait": "télédiffuser",
    "télédiffusant": "télédiffuser",
    "télédiffusas": "télédiffuser",
    "télédiffusasse": "télédiffuser",
    "télédiffusassent": "télédiffuser",
    "télédiffusasses": "télédiffuser",
    "télédiffusassiez": "télédiffuser",
    "télédiffusassions": "télédiffuser",
    "télédiffuse": "télédiffuser",
    "télédiffusent": "télédiffuser",
    "télédiffusera": "télédiffuser",
    "télédiffuserai": "télédiffuser",
    "télédiffuseraient": "télédiffuser",
    "télédiffuserais": "télédiffuser",
    "télédiffuserait": "télédiffuser",
    "télédiffuseras": "télédiffuser",
    "télédiffuserez": "télédiffuser",
    "télédiffuseriez": "télédiffuser",
    "télédiffuserions": "télédiffuser",
    "télédiffuserons": "télédiffuser",
    "télédiffuseront": "télédiffuser",
    "télédiffuses": "télédiffuser",
    "télédiffusez": "télédiffuser",
    "télédiffusiez": "télédiffuser",
    "télédiffusions": "télédiffuser",
    "télédiffusons": "télédiffuser",
    "télédiffusâmes": "télédiffuser",
    "télédiffusât": "télédiffuser",
    "télédiffusâtes": "télédiffuser",
    "télédiffusèrent": "télédiffuser",
    "télédiffusé": "télédiffuser",
    "télédiffusée": "télédiffuser",
    "télédiffusées": "télédiffuser",
    "télédiffusés": "télédiffuser",
    "télédistributions": "télédistribution",
    "télédétections": "télédétection",
    "téléfaxe": "téléfaxer",
    "téléfaxez": "téléfaxer",
    "téléfilms": "téléfilm",
    "téléfériques": "téléférique",
    "télégrammes": "télégramme",
    "télégraphes": "télégraphe",
    "télégraphia": "télégraphier",
    "télégraphiai": "télégraphier",
    "télégraphiaient": "télégraphier",
    "télégraphiais": "télégraphier",
    "télégraphiait": "télégraphier",
    "télégraphiant": "télégraphier",
    "télégraphias": "télégraphier",
    "télégraphiasse": "télégraphier",
    "télégraphiassent": "télégraphier",
    "télégraphiasses": "télégraphier",
    "télégraphiassiez": "télégraphier",
    "télégraphiassions": "télégraphier",
    "télégraphie": "télégraphier",
    "télégraphient": "télégraphier",
    "télégraphiera": "télégraphier",
    "télégraphierai": "télégraphier",
    "télégraphieraient": "télégraphier",
    "télégraphierais": "télégraphier",
    "télégraphierait": "télégraphier",
    "télégraphieras": "télégraphier",
    "télégraphierez": "télégraphier",
    "télégraphieriez": "télégraphier",
    "télégraphierions": "télégraphier",
    "télégraphierons": "télégraphier",
    "télégraphieront": "télégraphier",
    "télégraphies": "télégraphier",
    "télégraphiez": "télégraphier",
    "télégraphiiez": "télégraphier",
    "télégraphiions": "télégraphier",
    "télégraphions": "télégraphier",
    "télégraphiques": "télégraphique",
    "télégraphistes": "télégraphiste",
    "télégraphiâmes": "télégraphier",
    "télégraphiât": "télégraphier",
    "télégraphiâtes": "télégraphier",
    "télégraphièrent": "télégraphier",
    "télégraphié": "télégraphier",
    "télégraphiée": "télégraphier",
    "télégraphiées": "télégraphier",
    "télégraphiés": "télégraphier",
    "téléguida": "téléguider",
    "téléguidai": "téléguider",
    "téléguidaient": "téléguider",
    "téléguidais": "téléguider",
    "téléguidait": "téléguider",
    "téléguidant": "téléguider",
    "téléguidas": "téléguider",
    "téléguidasse": "téléguider",
    "téléguidassent": "téléguider",
    "téléguidasses": "téléguider",
    "téléguidassiez": "téléguider",
    "téléguidassions": "téléguider",
    "téléguide": "téléguider",
    "téléguident": "téléguider",
    "téléguidera": "téléguider",
    "téléguiderai": "téléguider",
    "téléguideraient": "téléguider",
    "téléguiderais": "téléguider",
    "téléguiderait": "téléguider",
    "téléguideras": "téléguider",
    "téléguiderez": "téléguider",
    "téléguideriez": "téléguider",
    "téléguiderions": "téléguider",
    "téléguiderons": "téléguider",
    "téléguideront": "téléguider",
    "téléguides": "téléguider",
    "téléguidez": "téléguider",
    "téléguidiez": "téléguider",
    "téléguidions": "téléguider",
    "téléguidons": "téléguider",
    "téléguidâmes": "téléguider",
    "téléguidât": "téléguider",
    "téléguidâtes": "téléguider",
    "téléguidèrent": "téléguider",
    "téléguidé": "téléguider",
    "téléguidée": "téléguider",
    "téléguidées": "téléguider",
    "téléguidés": "téléguider",
    "télématiques": "télématique",
    "télémesures": "télémesure",
    "télémètres": "télémètre",
    "télémédecines": "télémédecine",
    "télémétriques": "télémétrique",
    "téléobjectifs": "téléobjectif",
    "télépathes": "télépathe",
    "télépathies": "télépathie",
    "télépathiques": "télépathique",
    "téléphona": "téléphoner",
    "téléphonai": "téléphoner",
    "téléphonaient": "téléphoner",
    "téléphonais": "téléphoner",
    "téléphonait": "téléphoner",
    "téléphonant": "téléphoner",
    "téléphonas": "téléphoner",
    "téléphonasse": "téléphoner",
    "téléphonassent": "téléphoner",
    "téléphonasses": "téléphoner",
    "téléphonassiez": "téléphoner",
    "téléphonassions": "téléphoner",
    "téléphone": "téléphoner",
    "téléphonent": "téléphoner",
    "téléphonera": "téléphoner",
    "téléphonerai": "téléphoner",
    "téléphoneraient": "téléphoner",
    "téléphonerais": "téléphoner",
    "téléphonerait": "téléphoner",
    "téléphoneras": "téléphoner",
    "téléphonerez": "téléphoner",
    "téléphoneriez": "téléphoner",
    "téléphonerions": "téléphoner",
    "téléphonerons": "téléphoner",
    "téléphoneront": "téléphoner",
    "téléphones": "téléphoner",
    "téléphonez": "téléphoner",
    "téléphonies": "téléphonie",
    "téléphoniez": "téléphoner",
    "téléphonions": "téléphoner",
    "téléphoniques": "téléphonique",
    "téléphonistes": "téléphoniste",
    "téléphonons": "téléphoner",
    "téléphonâmes": "téléphoner",
    "téléphonât": "téléphoner",
    "téléphonâtes": "téléphoner",
    "téléphonèrent": "téléphoner",
    "téléphoné": "téléphoner",
    "téléphonée": "téléphoner",
    "téléphonées": "téléphoner",
    "téléphonés": "téléphoner",
    "téléphériques": "téléphérique",
    "téléprompteurs": "téléprompteur",
    "télés": "télé",
    "téléscripteurs": "téléscripteur",
    "télésièges": "télésiège",
    "téléskis": "téléski",
    "téléspectateurs": "téléspectateur",
    "téléspectatrice": "téléspectateur",
    "téléspectatrices": "téléspectateur",
    "télésurveillances": "télésurveillance",
    "télétravailleuse": "télétravailleur",
    "télétypes": "télétype",
    "télévangélistes": "télévangéliste",
    "télévisa": "téléviser",
    "télévisai": "téléviser",
    "télévisaient": "téléviser",
    "télévisais": "téléviser",
    "télévisait": "téléviser",
    "télévisant": "téléviser",
    "télévisas": "téléviser",
    "télévisasse": "téléviser",
    "télévisassent": "téléviser",
    "télévisasses": "téléviser",
    "télévisassiez": "téléviser",
    "télévisassions": "téléviser",
    "télévise": "téléviser",
    "télévisent": "téléviser",
    "télévisera": "téléviser",
    "téléviserai": "téléviser",
    "téléviseraient": "téléviser",
    "téléviserais": "téléviser",
    "téléviserait": "téléviser",
    "téléviseras": "téléviser",
    "téléviserez": "téléviser",
    "téléviseriez": "téléviser",
    "téléviserions": "téléviser",
    "téléviserons": "téléviser",
    "téléviseront": "téléviser",
    "télévises": "téléviser",
    "téléviseurs": "téléviseur",
    "télévisez": "téléviser",
    "télévisiez": "téléviser",
    "télévisions": "télévision",
    "télévisons": "téléviser",
    "télévisuelle": "télévisuel",
    "télévisuelles": "télévisuel",
    "télévisuels": "télévisuel",
    "télévisâmes": "téléviser",
    "télévisât": "téléviser",
    "télévisâtes": "téléviser",
    "télévisèrent": "téléviser",
    "télévisé": "téléviser",
    "télévisée": "téléviser",
    "télévisées": "téléviser",
    "télévisés": "téléviser",
    "témoigna": "témoigner",
    "témoignages": "témoignage",
    "témoignai": "témoigner",
    "témoignaient": "témoigner",
    "témoignais": "témoigner",
    "témoignait": "témoigner",
    "témoignant": "témoigner",
    "témoignas": "témoigner",
    "témoignasse": "témoigner",
    "témoignassent": "témoigner",
    "témoignasses": "témoigner",
    "témoignassiez": "témoigner",
    "témoignassions": "témoigner",
    "témoigne": "témoigner",
    "témoignent": "témoigner",
    "témoignera": "témoigner",
    "témoignerai": "témoigner",
    "témoigneraient": "témoigner",
    "témoignerais": "témoigner",
    "témoignerait": "témoigner",
    "témoigneras": "témoigner",
    "témoignerez": "témoigner",
    "témoigneriez": "témoigner",
    "témoignerions": "témoigner",
    "témoignerons": "témoigner",
    "témoigneront": "témoigner",
    "témoignes": "témoigner",
    "témoignez": "témoigner",
    "témoigniez": "témoigner",
    "témoignions": "témoigner",
    "témoignons": "témoigner",
    "témoignâmes": "témoigner",
    "témoignât": "témoigner",
    "témoignâtes": "témoigner",
    "témoignèrent": "témoigner",
    "témoigné": "témoigner",
    "témoignée": "témoigner",
    "témoignées": "témoigner",
    "témoignés": "témoigner",
    "témoins": "témoin",
    "témoins-clés": "témoin-clé",
    "téméraires": "téméraire",
    "témérités": "témérité",
    "ténacités": "ténacité",
    "ténias": "ténia",
    "ténorinos": "ténorino",
    "ténors": "ténor",
    "ténue": "ténu",
    "ténues": "ténu",
    "ténus": "ténu",
    "ténébreuse": "ténébreux",
    "ténébreuses": "ténébreux",
    "téorbes": "téorbe",
    "téraoctets": "téraoctet",
    "tératologies": "tératologie",
    "tératologiques": "tératologique",
    "térébinthes": "térébinthe",
    "térébrante": "térébrant",
    "térébrantes": "térébrant",
    "térébrants": "térébrant",
    "tés": "té",
    "téta": "téter",
    "tétai": "téter",
    "tétaient": "téter",
    "tétais": "téter",
    "tétait": "téter",
    "tétaniques": "tétanique",
    "tétanisait": "tétaniser",
    "tétanisant": "tétaniser",
    "tétanisent": "tétaniser",
    "tétanisé": "tétaniser",
    "tétanisée": "tétaniser",
    "tétanisées": "tétanisé",
    "tétanisés": "tétanisé",
    "tétant": "téter",
    "tétas": "téter",
    "tétasse": "téter",
    "tétassent": "téter",
    "tétasses": "téter",
    "tétassiez": "téter",
    "tétassions": "téter",
    "tétera": "téter",
    "téterai": "téter",
    "téteraient": "téter",
    "téterais": "téter",
    "téterait": "téter",
    "téteras": "téter",
    "téterez": "téter",
    "téteriez": "téter",
    "téterions": "téter",
    "téterons": "téter",
    "téteront": "téter",
    "tétez": "téter",
    "tétiez": "téter",
    "tétines": "tétine",
    "tétins": "tétin",
    "tétions": "téter",
    "tétons": "téton",
    "tétrachlorures": "tétrachlorure",
    "tétracordes": "tétracorde",
    "tétragones": "tétragone",
    "tétragrammes": "tétragramme",
    "tétralogies": "tétralogie",
    "tétraplégies": "tétraplégie",
    "tétrarchies": "tétrarchie",
    "tétrarques": "tétrarque",
    "tétraèdres": "tétraèdre",
    "tétraédriques": "tétraédrique",
    "tétâmes": "téter",
    "tétât": "téter",
    "tétâtes": "téter",
    "tétère": "téter",
    "tétèrent": "téter",
    "tété": "téter",
    "tétée": "téter",
    "tétées": "téter",
    "tétés": "téter",
    "têtards": "têtard",
    "têteaux": "têteau",
    "têtes": "tête",
    "têtes-de-Maure": "tête-de-Maure",
    "têtes-de-clou": "tête-de-clou",
    "têtes-de-loup": "tête-de-loup",
    "têtes-de-nègre": "tête-de-nègre",
    "têtières": "têtière",
    "têtue": "têtu",
    "têtues": "têtu",
    "têtus": "têtu",
    "tînmes": "tenir",
    "tînt": "tenir",
    "tîntes": "tenir",
    "tôlarde": "tôlard",
    "tôles": "tôle",
    "tôliers": "tôlier",
    "tôlière": "tôlier",
    "tôlières": "tôlier",
    "tûmes": "taire",
    "tût": "taire",
    "tûtes": "taire",
    "ubacs": "ubac",
    "ubiquités": "ubiquité",
    "ubuesques": "ubuesque",
    "uhlans": "uhlan",
    "ukases": "ukase",
    "ukrainienne": "ukrainien",
    "ukrainiennes": "ukrainien",
    "ukrainiens": "ukrainien",
    "ulcère": "ulcérer",
    "ulcèrent": "ulcérer",
    "ulcères": "ulcérer",
    "ulcéra": "ulcérer",
    "ulcérai": "ulcérer",
    "ulcéraient": "ulcérer",
    "ulcérais": "ulcérer",
    "ulcérait": "ulcérer",
    "ulcérant": "ulcérer",
    "ulcéras": "ulcérer",
    "ulcérasse": "ulcérer",
    "ulcérassent": "ulcérer",
    "ulcérasses": "ulcérer",
    "ulcérassiez": "ulcérer",
    "ulcérassions": "ulcérer",
    "ulcérations": "ulcération",
    "ulcérative": "ulcératif",
    "ulcérera": "ulcérer",
    "ulcérerai": "ulcérer",
    "ulcéreraient": "ulcérer",
    "ulcérerais": "ulcérer",
    "ulcérerait": "ulcérer",
    "ulcéreras": "ulcérer",
    "ulcérerez": "ulcérer",
    "ulcéreriez": "ulcérer",
    "ulcérerions": "ulcérer",
    "ulcérerons": "ulcérer",
    "ulcéreront": "ulcérer",
    "ulcéreuse": "ulcéreux",
    "ulcéreuses": "ulcéreux",
    "ulcérez": "ulcérer",
    "ulcériez": "ulcérer",
    "ulcérions": "ulcérer",
    "ulcérons": "ulcérer",
    "ulcérâmes": "ulcérer",
    "ulcérât": "ulcérer",
    "ulcérâtes": "ulcérer",
    "ulcérèrent": "ulcérer",
    "ulcéré": "ulcérer",
    "ulcérée": "ulcérer",
    "ulcérées": "ulcérer",
    "ulcérés": "ulcérer",
    "ulmaires": "ulmaire",
    "ultimatums": "ultimatum",
    "ultimes": "ultime",
    "ultra-chics": "ultra-chic",
    "ultra-courtes": "ultra-court",
    "ultra-courts": "ultra-court",
    "ultra-sons": "ultra-son",
    "ultra-violets": "ultra-violet",
    "ultracentrifugeuses": "ultracentrifugeuse",
    "ultracourte": "ultracourt",
    "ultracourtes": "ultracourt",
    "ultracourts": "ultracourt",
    "ultralibérale": "ultralibéral",
    "ultralibérales": "ultralibéral",
    "ultralibérauxs": "ultralibéral",
    "ultramarine": "ultramarin",
    "ultramodernes": "ultramoderne",
    "ultramontaine": "ultramontain",
    "ultramontaines": "ultramontain",
    "ultramontains": "ultramontain",
    "ultrarapides": "ultrarapide",
    "ultraroyalistes": "ultraroyaliste",
    "ultras": "ultra",
    "ultrasecrète": "ultrasecret",
    "ultrasensibles": "ultrasensible",
    "ultrasons": "ultrason",
    "ultraviolets": "ultraviolet",
    "ultraviolette": "ultraviolet",
    "ultraviolettes": "ultraviolet",
    "ultérieure": "ultérieur",
    "ultérieures": "ultérieur",
    "ultérieurs": "ultérieur",
    "ulula": "ululer",
    "ululai": "ululer",
    "ululaient": "ululer",
    "ululais": "ululer",
    "ululait": "ululer",
    "ululant": "ululer",
    "ululas": "ululer",
    "ululasse": "ululer",
    "ululassent": "ululer",
    "ululasses": "ululer",
    "ululassiez": "ululer",
    "ululassions": "ululer",
    "ulule": "ululer",
    "ululements": "ululement",
    "ululent": "ululer",
    "ululera": "ululer",
    "ululerai": "ululer",
    "ululeraient": "ululer",
    "ululerais": "ululer",
    "ululerait": "ululer",
    "ululeras": "ululer",
    "ululerez": "ululer",
    "ululeriez": "ululer",
    "ululerions": "ululer",
    "ululerons": "ululer",
    "ululeront": "ululer",
    "ulules": "ululer",
    "ululez": "ululer",
    "ululiez": "ululer",
    "ululions": "ululer",
    "ululons": "ululer",
    "ululâmes": "ululer",
    "ululât": "ululer",
    "ululâtes": "ululer",
    "ululèrent": "ululer",
    "ululé": "ululer",
    "ulémas": "uléma",
    "unanimes": "unanime",
    "unanimismes": "unanimisme",
    "unanimistes": "unanimiste",
    "unanimités": "unanimité",
    "unaus": "unau",
    "une": "un",
    "unes": "un",
    "unguéale": "unguéal",
    "unguéales": "unguéal",
    "unguéaux": "unguéal",
    "uni": "unir",
    "uniates": "uniate",
    "unicellulaires": "unicellulaire",
    "unicités": "unicité",
    "unicolores": "unicolore",
    "unidimensionnelle": "unidimensionnel",
    "unidirectionnelle": "unidirectionnel",
    "unidirectionnelles": "unidirectionnel",
    "unidirectionnels": "unidirectionnel",
    "unie": "unir",
    "unies": "unir",
    "unifia": "unifier",
    "unifiai": "unifier",
    "unifiaient": "unifier",
    "unifiais": "unifier",
    "unifiait": "unifier",
    "unifiant": "unifier",
    "unifias": "unifier",
    "unifiasse": "unifier",
    "unifiassent": "unifier",
    "unifiasses": "unifier",
    "unifiassiez": "unifier",
    "unifiassions": "unifier",
    "unifications": "unification",
    "unificatrice": "unificateur",
    "unifie": "unifier",
    "unifient": "unifier",
    "unifiera": "unifier",
    "unifierai": "unifier",
    "unifieraient": "unifier",
    "unifierais": "unifier",
    "unifierait": "unifier",
    "unifieras": "unifier",
    "unifierez": "unifier",
    "unifieriez": "unifier",
    "unifierions": "unifier",
    "unifierons": "unifier",
    "unifieront": "unifier",
    "unifies": "unifier",
    "unifiez": "unifier",
    "unifiiez": "unifier",
    "unifiions": "unifier",
    "unifions": "unifier",
    "unifiâmes": "unifier",
    "unifiât": "unifier",
    "unifiâtes": "unifier",
    "unifièrent": "unifier",
    "unifié": "unifier",
    "unifiée": "unifier",
    "unifiées": "unifier",
    "unifiés": "unifier",
    "uniformes": "uniforme",
    "uniformisa": "uniformiser",
    "uniformisai": "uniformiser",
    "uniformisaient": "uniformiser",
    "uniformisais": "uniformiser",
    "uniformisait": "uniformiser",
    "uniformisant": "uniformiser",
    "uniformisas": "uniformiser",
    "uniformisasse": "uniformiser",
    "uniformisassent": "uniformiser",
    "uniformisasses": "uniformiser",
    "uniformisassiez": "uniformiser",
    "uniformisassions": "uniformiser",
    "uniformisations": "uniformisation",
    "uniformise": "uniformiser",
    "uniformisent": "uniformiser",
    "uniformisera": "uniformiser",
    "uniformiserai": "uniformiser",
    "uniformiseraient": "uniformiser",
    "uniformiserais": "uniformiser",
    "uniformiserait": "uniformiser",
    "uniformiseras": "uniformiser",
    "uniformiserez": "uniformiser",
    "uniformiseriez": "uniformiser",
    "uniformiserions": "uniformiser",
    "uniformiserons": "uniformiser",
    "uniformiseront": "uniformiser",
    "uniformises": "uniformiser",
    "uniformisez": "uniformiser",
    "uniformisiez": "uniformiser",
    "uniformisions": "uniformiser",
    "uniformisons": "uniformiser",
    "uniformisâmes": "uniformiser",
    "uniformisât": "uniformiser",
    "uniformisâtes": "uniformiser",
    "uniformisèrent": "uniformiser",
    "uniformisé": "uniformiser",
    "uniformisée": "uniformiser",
    "uniformisées": "uniformiser",
    "uniformisés": "uniformiser",
    "uniformités": "uniformité",
    "unijambistes": "unijambiste",
    "unilatérale": "unilatéral",
    "unilatérales": "unilatéral",
    "unilatéraux": "unilatéral",
    "unilingues": "unilingue",
    "uniloculaires": "uniloculaire",
    "uninominale": "uninominal",
    "uninominales": "uninominal",
    "uninominaux": "uninominal",
    "unionismes": "unionisme",
    "unionistes": "unioniste",
    "unions": "union",
    "unipersonnelle": "unipersonnel",
    "unipersonnelles": "unipersonnel",
    "unipersonnels": "unipersonnel",
    "uniques": "unique",
    "unira": "unir",
    "unirai": "unir",
    "uniraient": "unir",
    "unirais": "unir",
    "unirait": "unir",
    "uniras": "unir",
    "unirent": "unir",
    "unirez": "unir",
    "uniriez": "unir",
    "unirions": "unir",
    "unirons": "unir",
    "uniront": "unir",
    "unis": "unir",
    "unisexes": "unisexe",
    "unisexuelle": "unisexuel",
    "unisexuelles": "unisexuel",
    "unisexuels": "unisexuel",
    "unisexuée": "unisexué",
    "unisexuées": "unisexué",
    "unisexués": "unisexué",
    "unissaient": "unir",
    "unissais": "unir",
    "unissait": "unir",
    "unissant": "unir",
    "unisse": "unir",
    "unissent": "unir",
    "unisses": "unir",
    "unissez": "unir",
    "unissiez": "unir",
    "unissions": "unir",
    "unissons": "unisson",
    "unit": "unir",
    "unitaires": "unitaire",
    "unitarienne": "unitarien",
    "unités": "unité",
    "univalves": "univalve",
    "universalisa": "universaliser",
    "universalisai": "universaliser",
    "universalisaient": "universaliser",
    "universalisais": "universaliser",
    "universalisait": "universaliser",
    "universalisant": "universaliser",
    "universalisas": "universaliser",
    "universalisasse": "universaliser",
    "universalisassent": "universaliser",
    "universalisasses": "universaliser",
    "universalisassiez": "universaliser",
    "universalisassions": "universaliser",
    "universalisations": "universalisation",
    "universalise": "universaliser",
    "universalisent": "universaliser",
    "universalisera": "universaliser",
    "universaliserai": "universaliser",
    "universaliseraient": "universaliser",
    "universaliserais": "universaliser",
    "universaliserait": "universaliser",
    "universaliseras": "universaliser",
    "universaliserez": "universaliser",
    "universaliseriez": "universaliser",
    "universaliserions": "universaliser",
    "universaliserons": "universaliser",
    "universaliseront": "universaliser",
    "universalises": "universaliser",
    "universalisez": "universaliser",
    "universalisiez": "universaliser",
    "universalisions": "universaliser",
    "universalisons": "universaliser",
    "universalisâmes": "universaliser",
    "universalisât": "universaliser",
    "universalisâtes": "universaliser",
    "universalisèrent": "universaliser",
    "universalisé": "universaliser",
    "universalisée": "universaliser",
    "universalisées": "universaliser",
    "universalisés": "universaliser",
    "universalités": "universalité",
    "universelle": "universel",
    "universelles": "universel",
    "universels": "universel",
    "universitaires": "universitaire",
    "universités": "université",
    "univocités": "univocité",
    "univoques": "univoque",
    "unièmes": "unième",
    "uns": "un",
    "untelle": "untel",
    "untelles": "untel",
    "untels": "untel",
    "unîmes": "unir",
    "unît": "unir",
    "unîtes": "unir",
    "upanisads": "upanisad",
    "upgradée": "upgrader",
    "uppercuts": "uppercut",
    "upsilons": "upsilon",
    "upérisa": "upériser",
    "upérisai": "upériser",
    "upérisaient": "upériser",
    "upérisais": "upériser",
    "upérisait": "upériser",
    "upérisant": "upériser",
    "upérisas": "upériser",
    "upérisasse": "upériser",
    "upérisassent": "upériser",
    "upérisasses": "upériser",
    "upérisassiez": "upériser",
    "upérisassions": "upériser",
    "upérise": "upériser",
    "upérisent": "upériser",
    "upérisera": "upériser",
    "upériserai": "upériser",
    "upériseraient": "upériser",
    "upériserais": "upériser",
    "upériserait": "upériser",
    "upériseras": "upériser",
    "upériserez": "upériser",
    "upériseriez": "upériser",
    "upériserions": "upériser",
    "upériserons": "upériser",
    "upériseront": "upériser",
    "upérises": "upériser",
    "upérisez": "upériser",
    "upérisiez": "upériser",
    "upérisions": "upériser",
    "upérisons": "upériser",
    "upérisâmes": "upériser",
    "upérisât": "upériser",
    "upérisâtes": "upériser",
    "upérisèrent": "upériser",
    "upérisé": "upériser",
    "upérisée": "upériser",
    "upérisées": "upériser",
    "upérisés": "upériser",
    "uraniens": "uranien",
    "uraniums": "uranium",
    "urates": "urate",
    "uraètes": "uraète",
    "urbaine": "urbain",
    "urbaines": "urbain",
    "urbains": "urbain",
    "urbanisations": "urbanisation",
    "urbanismes": "urbanisme",
    "urbanistes": "urbaniste",
    "urbanistiques": "urbanistique",
    "urbanisé": "urbaniser",
    "urbanisée": "urbaniser",
    "urbanisées": "urbanisé",
    "urbanisés": "urbanisé",
    "urbanités": "urbanité",
    "ures": "ure",
    "uretères": "uretère",
    "urge": "urger",
    "urgea": "urger",
    "urgeaient": "urger",
    "urgeait": "urger",
    "urgeant": "urger",
    "urgeassent": "urger",
    "urgences": "urgence",
    "urgent": "urger",
    "urgente": "urgent",
    "urgentes": "urgent",
    "urgents": "urgent",
    "urgera": "urger",
    "urgeraient": "urger",
    "urgerait": "urger",
    "urgeront": "urger",
    "urgeât": "urger",
    "urgèrent": "urger",
    "urgé": "urger",
    "uricémies": "uricémie",
    "urina": "uriner",
    "urinai": "uriner",
    "urinaient": "uriner",
    "urinaires": "urinaire",
    "urinais": "uriner",
    "urinait": "uriner",
    "urinant": "uriner",
    "urinas": "uriner",
    "urinasse": "uriner",
    "urinassent": "uriner",
    "urinasses": "uriner",
    "urinassiez": "uriner",
    "urinassions": "uriner",
    "urinaux": "urinal",
    "urine": "uriner",
    "urinent": "uriner",
    "urinera": "uriner",
    "urinerai": "uriner",
    "urineraient": "uriner",
    "urinerais": "uriner",
    "urinerait": "uriner",
    "urineras": "uriner",
    "urinerez": "uriner",
    "urineriez": "uriner",
    "urinerions": "uriner",
    "urinerons": "uriner",
    "urineront": "uriner",
    "urines": "uriner",
    "urineuse": "urineux",
    "urinez": "uriner",
    "uriniez": "uriner",
    "urinions": "uriner",
    "urinoirs": "urinoir",
    "urinons": "uriner",
    "urinâmes": "uriner",
    "urinât": "uriner",
    "urinâtes": "uriner",
    "urinèrent": "uriner",
    "uriné": "uriner",
    "urinée": "uriner",
    "urinées": "uriner",
    "urinés": "uriner",
    "uriques": "urique",
    "urnes": "urne",
    "urobilines": "urobiline",
    "urodèles": "urodèle",
    "urologies": "urologie",
    "ursulines": "ursuline",
    "urticaires": "urticaire",
    "urticante": "urticant",
    "urticantes": "urticant",
    "urticants": "urticant",
    "urubus": "urubu",
    "uruguayenne": "uruguayen",
    "uruguayennes": "uruguayen",
    "uruguayens": "uruguayen",
    "urètres": "urètre",
    "urées": "urée",
    "urémies": "urémie",
    "urétrale": "urétral",
    "urétrales": "urétral",
    "urétraux": "urétral",
    "urétérale": "urétéral",
    "urétérales": "urétéral",
    "urétéraux": "urétéral",
    "usa": "user",
    "usagers": "usager",
    "usages": "usage",
    "usagères": "usager",
    "usagée": "usagé",
    "usagées": "usagé",
    "usagés": "usagé",
    "usai": "user",
    "usaient": "user",
    "usais": "user",
    "usait": "user",
    "usant": "user",
    "usante": "usant",
    "usas": "user",
    "usasse": "user",
    "usassent": "user",
    "usasses": "user",
    "usassiez": "user",
    "usassions": "user",
    "use": "user",
    "usent": "user",
    "usera": "user",
    "userai": "user",
    "useraient": "user",
    "userais": "user",
    "userait": "user",
    "useras": "user",
    "userez": "user",
    "useriez": "user",
    "userions": "user",
    "userons": "user",
    "useront": "user",
    "uses": "user",
    "usez": "user",
    "usiez": "user",
    "usina": "usiner",
    "usinai": "usiner",
    "usinaient": "usiner",
    "usinais": "usiner",
    "usinait": "usiner",
    "usinant": "usiner",
    "usinas": "usiner",
    "usinasse": "usiner",
    "usinassent": "usiner",
    "usinasses": "usiner",
    "usinassiez": "usiner",
    "usinassions": "usiner",
    "usine": "usiner",
    "usinent": "usiner",
    "usinera": "usiner",
    "usinerai": "usiner",
    "usineraient": "usiner",
    "usinerais": "usiner",
    "usinerait": "usiner",
    "usineras": "usiner",
    "usinerez": "usiner",
    "usineriez": "usiner",
    "usinerions": "usiner",
    "usinerons": "usiner",
    "usineront": "usiner",
    "usines": "usiner",
    "usinez": "usiner",
    "usiniers": "usinier",
    "usiniez": "usiner",
    "usinions": "usiner",
    "usinière": "usinier",
    "usinons": "usiner",
    "usinâmes": "usiner",
    "usinât": "usiner",
    "usinâtes": "usiner",
    "usinèrent": "usiner",
    "usiné": "usiner",
    "usinée": "usiner",
    "usinées": "usiner",
    "usinés": "usiner",
    "usions": "user",
    "usitée": "usité",
    "usitées": "usité",
    "usités": "usité",
    "usons": "user",
    "ustensiles": "ustensile",
    "usuelle": "usuel",
    "usuelles": "usuel",
    "usuels": "usuel",
    "usufructuaires": "usufructuaire",
    "usufruitiers": "usufruitier",
    "usufruitière": "usufruitier",
    "usufruitières": "usufruitier",
    "usufruits": "usufruit",
    "usuraires": "usuraire",
    "usures": "usure",
    "usuriers": "usurier",
    "usurière": "usurier",
    "usurières": "usurier",
    "usurpa": "usurper",
    "usurpai": "usurper",
    "usurpaient": "usurper",
    "usurpais": "usurper",
    "usurpait": "usurper",
    "usurpant": "usurper",
    "usurpas": "usurper",
    "usurpasse": "usurper",
    "usurpassent": "usurper",
    "usurpasses": "usurper",
    "usurpassiez": "usurper",
    "usurpassions": "usurper",
    "usurpateurs": "usurpateur",
    "usurpatrice": "usurpateur",
    "usurpatrices": "usurpateur",
    "usurpe": "usurper",
    "usurpent": "usurper",
    "usurpera": "usurper",
    "usurperai": "usurper",
    "usurperaient": "usurper",
    "usurperais": "usurper",
    "usurperait": "usurper",
    "usurperas": "usurper",
    "usurperez": "usurper",
    "usurperiez": "usurper",
    "usurperions": "usurper",
    "usurperons": "usurper",
    "usurperont": "usurper",
    "usurpes": "usurper",
    "usurpez": "usurper",
    "usurpiez": "usurper",
    "usurpions": "usurper",
    "usurpons": "usurper",
    "usurpâmes": "usurper",
    "usurpât": "usurper",
    "usurpâtes": "usurper",
    "usurpèrent": "usurper",
    "usurpé": "usurper",
    "usurpée": "usurper",
    "usurpées": "usurper",
    "usurpés": "usurper",
    "usâmes": "user",
    "usât": "user",
    "usâtes": "user",
    "usèrent": "user",
    "usé": "user",
    "usée": "user",
    "usées": "user",
    "usés": "user",
    "utiles": "utile",
    "utilisa": "utiliser",
    "utilisables": "utilisable",
    "utilisai": "utiliser",
    "utilisaient": "utiliser",
    "utilisais": "utiliser",
    "utilisait": "utiliser",
    "utilisant": "utiliser",
    "utilisas": "utiliser",
    "utilisasse": "utiliser",
    "utilisassent": "utiliser",
    "utilisasses": "utiliser",
    "utilisassiez": "utiliser",
    "utilisassions": "utiliser",
    "utilisateurs": "utilisateur",
    "utilisations": "utilisation",
    "utilisatrice": "utilisateur",
    "utilisatrices": "utilisateur",
    "utilise": "utiliser",
    "utilisent": "utiliser",
    "utilisera": "utiliser",
    "utiliserai": "utiliser",
    "utiliseraient": "utiliser",
    "utiliserais": "utiliser",
    "utiliserait": "utiliser",
    "utiliseras": "utiliser",
    "utiliserez": "utiliser",
    "utiliseriez": "utiliser",
    "utiliserions": "utiliser",
    "utiliserons": "utiliser",
    "utiliseront": "utiliser",
    "utilises": "utiliser",
    "utilisez": "utiliser",
    "utilisiez": "utiliser",
    "utilisions": "utiliser",
    "utilisons": "utiliser",
    "utilisâmes": "utiliser",
    "utilisât": "utiliser",
    "utilisâtes": "utiliser",
    "utilisèrent": "utiliser",
    "utilisé": "utiliser",
    "utilisée": "utiliser",
    "utilisées": "utiliser",
    "utilisés": "utiliser",
    "utilitaires": "utilitaire",
    "utilités": "utilité",
    "utopies": "utopie",
    "utopiques": "utopique",
    "utopistes": "utopiste",
    "utérine": "utérin",
    "utérines": "utérin",
    "utérins": "utérin",
    "uvale": "uval",
    "uvales": "uval",
    "uvaux": "uval",
    "uvules": "uvule",
    "uxorilocale": "uxorilocal",
    "uxorilocales": "uxorilocal",
    "uxorilocaux": "uxorilocal",
    "va": "aller",
    "vacances": "vacance",
    "vacanciers": "vacancier",
    "vacancière": "vacancier",
    "vacancières": "vacancier",
    "vacante": "vacant",
    "vacantes": "vacant",
    "vacants": "vacant",
    "vacarmes": "vacarme",
    "vacataires": "vacataire",
    "vacations": "vacation",
    "vaccina": "vacciner",
    "vaccinai": "vacciner",
    "vaccinaient": "vacciner",
    "vaccinais": "vacciner",
    "vaccinait": "vacciner",
    "vaccinale": "vaccinal",
    "vaccinales": "vaccinal",
    "vaccinant": "vacciner",
    "vaccinas": "vacciner",
    "vaccinasse": "vacciner",
    "vaccinassent": "vacciner",
    "vaccinasses": "vacciner",
    "vaccinassiez": "vacciner",
    "vaccinassions": "vacciner",
    "vaccinations": "vaccination",
    "vaccinaux": "vaccinal",
    "vaccine": "vacciner",
    "vaccinent": "vacciner",
    "vaccinera": "vacciner",
    "vaccinerai": "vacciner",
    "vaccineraient": "vacciner",
    "vaccinerais": "vacciner",
    "vaccinerait": "vacciner",
    "vaccineras": "vacciner",
    "vaccinerez": "vacciner",
    "vaccineriez": "vacciner",
    "vaccinerions": "vacciner",
    "vaccinerons": "vacciner",
    "vaccineront": "vacciner",
    "vaccines": "vacciner",
    "vaccinez": "vacciner",
    "vacciniez": "vacciner",
    "vaccinions": "vacciner",
    "vaccinons": "vacciner",
    "vaccins": "vaccin",
    "vaccinâmes": "vacciner",
    "vaccinât": "vacciner",
    "vaccinâtes": "vacciner",
    "vaccinèrent": "vacciner",
    "vacciné": "vacciner",
    "vaccinée": "vacciner",
    "vaccinées": "vacciner",
    "vaccinés": "vacciner",
    "vacharde": "vachard",
    "vachardes": "vachard",
    "vachards": "vachard",
    "vacheries": "vacherie",
    "vacherins": "vacherin",
    "vachers": "vacher",
    "vaches": "vache",
    "vachettes": "vachette",
    "vachères": "vachère",
    "vacilla": "vaciller",
    "vacillai": "vaciller",
    "vacillaient": "vaciller",
    "vacillais": "vaciller",
    "vacillait": "vaciller",
    "vacillant": "vaciller",
    "vacillante": "vacillant",
    "vacillantes": "vacillant",
    "vacillants": "vacillant",
    "vacillas": "vaciller",
    "vacillasse": "vaciller",
    "vacillassent": "vaciller",
    "vacillasses": "vaciller",
    "vacillassiez": "vaciller",
    "vacillassions": "vaciller",
    "vacillations": "vacillation",
    "vacille": "vaciller",
    "vacillent": "vaciller",
    "vacillera": "vaciller",
    "vacillerai": "vaciller",
    "vacilleraient": "vaciller",
    "vacillerais": "vaciller",
    "vacillerait": "vaciller",
    "vacilleras": "vaciller",
    "vacillerez": "vaciller",
    "vacilleriez": "vaciller",
    "vacillerions": "vaciller",
    "vacillerons": "vaciller",
    "vacilleront": "vaciller",
    "vacilles": "vaciller",
    "vacillez": "vaciller",
    "vacilliez": "vaciller",
    "vacillions": "vaciller",
    "vacillons": "vaciller",
    "vacillâmes": "vaciller",
    "vacillât": "vaciller",
    "vacillâtes": "vaciller",
    "vacillèrent": "vaciller",
    "vacillé": "vaciller",
    "vacuités": "vacuité",
    "vadrouilla": "vadrouiller",
    "vadrouillai": "vadrouiller",
    "vadrouillaient": "vadrouiller",
    "vadrouillais": "vadrouiller",
    "vadrouillait": "vadrouiller",
    "vadrouillant": "vadrouiller",
    "vadrouillas": "vadrouiller",
    "vadrouillasse": "vadrouiller",
    "vadrouillassent": "vadrouiller",
    "vadrouillasses": "vadrouiller",
    "vadrouillassiez": "vadrouiller",
    "vadrouillassions": "vadrouiller",
    "vadrouille": "vadrouiller",
    "vadrouillent": "vadrouiller",
    "vadrouillera": "vadrouiller",
    "vadrouillerai": "vadrouiller",
    "vadrouilleraient": "vadrouiller",
    "vadrouillerais": "vadrouiller",
    "vadrouillerait": "vadrouiller",
    "vadrouilleras": "vadrouiller",
    "vadrouillerez": "vadrouiller",
    "vadrouilleriez": "vadrouiller",
    "vadrouillerions": "vadrouiller",
    "vadrouillerons": "vadrouiller",
    "vadrouilleront": "vadrouiller",
    "vadrouilles": "vadrouiller",
    "vadrouilleurs": "vadrouilleur",
    "vadrouilleuse": "vadrouilleur",
    "vadrouilleuses": "vadrouilleur",
    "vadrouillez": "vadrouiller",
    "vadrouilliez": "vadrouiller",
    "vadrouillions": "vadrouiller",
    "vadrouillons": "vadrouiller",
    "vadrouillâmes": "vadrouiller",
    "vadrouillât": "vadrouiller",
    "vadrouillâtes": "vadrouiller",
    "vadrouillèrent": "vadrouiller",
    "vadrouillé": "vadrouiller",
    "vadrouillée": "vadrouiller",
    "vadrouillées": "vadrouiller",
    "vadrouillés": "vadrouiller",
    "vagabonda": "vagabonder",
    "vagabondages": "vagabondage",
    "vagabondai": "vagabonder",
    "vagabondaient": "vagabonder",
    "vagabondais": "vagabonder",
    "vagabondait": "vagabonder",
    "vagabondant": "vagabonder",
    "vagabondas": "vagabonder",
    "vagabondasse": "vagabonder",
    "vagabondassent": "vagabonder",
    "vagabondasses": "vagabonder",
    "vagabondassiez": "vagabonder",
    "vagabondassions": "vagabonder",
    "vagabonde": "vagabonder",
    "vagabondent": "vagabonder",
    "vagabondera": "vagabonder",
    "vagabonderai": "vagabonder",
    "vagabonderaient": "vagabonder",
    "vagabonderais": "vagabonder",
    "vagabonderait": "vagabonder",
    "vagabonderas": "vagabonder",
    "vagabonderez": "vagabonder",
    "vagabonderiez": "vagabonder",
    "vagabonderions": "vagabonder",
    "vagabonderons": "vagabonder",
    "vagabonderont": "vagabonder",
    "vagabondes": "vagabonder",
    "vagabondez": "vagabonder",
    "vagabondiez": "vagabonder",
    "vagabondions": "vagabonder",
    "vagabondons": "vagabonder",
    "vagabonds": "vagabond",
    "vagabondâmes": "vagabonder",
    "vagabondât": "vagabonder",
    "vagabondâtes": "vagabonder",
    "vagabondèrent": "vagabonder",
    "vagabondé": "vagabonder",
    "vagabondée": "vagabonder",
    "vagabondées": "vagabonder",
    "vagabondés": "vagabonder",
    "vagi": "vagir",
    "vaginale": "vaginal",
    "vaginales": "vaginal",
    "vaginaux": "vaginal",
    "vagins": "vagin",
    "vagira": "vagir",
    "vagirai": "vagir",
    "vagiraient": "vagir",
    "vagirais": "vagir",
    "vagirait": "vagir",
    "vagiras": "vagir",
    "vagirent": "vagir",
    "vagirez": "vagir",
    "vagiriez": "vagir",
    "vagirions": "vagir",
    "vagirons": "vagir",
    "vagiront": "vagir",
    "vagis": "vagir",
    "vagissaient": "vagir",
    "vagissais": "vagir",
    "vagissait": "vagir",
    "vagissant": "vagir",
    "vagisse": "vagir",
    "vagissements": "vagissement",
    "vagissent": "vagir",
    "vagisses": "vagir",
    "vagissez": "vagir",
    "vagissiez": "vagir",
    "vagissions": "vagir",
    "vagissons": "vagir",
    "vagit": "vagir",
    "vagua": "vaguer",
    "vaguai": "vaguer",
    "vaguaient": "vaguer",
    "vaguais": "vaguer",
    "vaguait": "vaguer",
    "vaguant": "vaguer",
    "vaguas": "vaguer",
    "vaguasse": "vaguer",
    "vaguassent": "vaguer",
    "vaguasses": "vaguer",
    "vaguassiez": "vaguer",
    "vaguassions": "vaguer",
    "vague": "vaguer",
    "vaguelettes": "vaguelette",
    "vaguemestres": "vaguemestre",
    "vaguent": "vaguer",
    "vaguera": "vaguer",
    "vaguerai": "vaguer",
    "vagueraient": "vaguer",
    "vaguerais": "vaguer",
    "vaguerait": "vaguer",
    "vagueras": "vaguer",
    "vaguerez": "vaguer",
    "vagueriez": "vaguer",
    "vaguerions": "vaguer",
    "vaguerons": "vaguer",
    "vagueront": "vaguer",
    "vagues": "vaguer",
    "vaguez": "vaguer",
    "vaguiez": "vaguer",
    "vaguions": "vaguer",
    "vaguons": "vaguer",
    "vaguâmes": "vaguer",
    "vaguât": "vaguer",
    "vaguâtes": "vaguer",
    "vaguèrent": "vaguer",
    "vagué": "vaguer",
    "vagîmes": "vagir",
    "vagît": "vagir",
    "vagîtes": "vagir",
    "vahinés": "vahiné",
    "vaillante": "vaillant",
    "vaillantes": "vaillant",
    "vaillants": "vaillant",
    "vaille": "valoir",
    "vaillent": "valoir",
    "vailles": "valoir",
    "vainc": "vaincre",
    "vaincra": "vaincre",
    "vaincrai": "vaincre",
    "vaincraient": "vaincre",
    "vaincrais": "vaincre",
    "vaincrait": "vaincre",
    "vaincras": "vaincre",
    "vaincrez": "vaincre",
    "vaincriez": "vaincre",
    "vaincrions": "vaincre",
    "vaincrons": "vaincre",
    "vaincront": "vaincre",
    "vaincs": "vaincre",
    "vaincu": "vaincre",
    "vaincue": "vaincu",
    "vaincues": "vaincu",
    "vaincus": "vaincu",
    "vaine": "vain",
    "vaines": "vain",
    "vainquaient": "vaincre",
    "vainquais": "vaincre",
    "vainquait": "vaincre",
    "vainquant": "vaincre",
    "vainque": "vaincre",
    "vainquent": "vaincre",
    "vainques": "vaincre",
    "vainqueurs": "vainqueur",
    "vainquez": "vaincre",
    "vainquiez": "vaincre",
    "vainquions": "vaincre",
    "vainquirent": "vaincre",
    "vainquis": "vaincre",
    "vainquisse": "vaincre",
    "vainquissent": "vaincre",
    "vainquisses": "vaincre",
    "vainquissiez": "vaincre",
    "vainquissions": "vaincre",
    "vainquit": "vaincre",
    "vainquons": "vaincre",
    "vainquîmes": "vaincre",
    "vainquît": "vaincre",
    "vainquîtes": "vaincre",
    "vains": "vain",
    "vairons": "vairon",
    "vairs": "vair",
    "vais": "aller",
    "vaisseaux": "vaisseau",
    "vaisseliers": "vaisselier",
    "vaisselles": "vaisselle",
    "valables": "valable",
    "valaient": "valoir",
    "valais": "valoir",
    "valait": "valoir",
    "valant": "valoir",
    "valdingua": "valdinguer",
    "valdingue": "valdinguer",
    "valdingues": "valdinguer",
    "valdingué": "valdinguer",
    "valdingués": "valdinguer",
    "valdôtains": "valdôtain",
    "valences": "valence",
    "valencienne": "valencien",
    "valent": "valoir",
    "valentine": "valentin",
    "valetailles": "valetaille",
    "valets": "valet",
    "valeureuse": "valeureux",
    "valeureuses": "valeureux",
    "valeurs": "valeur",
    "valez": "valoir",
    "valgas": "valga",
    "valida": "valider",
    "validai": "valider",
    "validaient": "valider",
    "validais": "valider",
    "validait": "valider",
    "validant": "valider",
    "validas": "valider",
    "validasse": "valider",
    "validassent": "valider",
    "validasses": "valider",
    "validassiez": "valider",
    "validassions": "valider",
    "validations": "validation",
    "valide": "valider",
    "valident": "valider",
    "validera": "valider",
    "validerai": "valider",
    "valideraient": "valider",
    "validerais": "valider",
    "validerait": "valider",
    "valideras": "valider",
    "validerez": "valider",
    "valideriez": "valider",
    "validerions": "valider",
    "validerons": "valider",
    "valideront": "valider",
    "valides": "valider",
    "validez": "valider",
    "validiez": "valider",
    "validions": "valider",
    "validités": "validité",
    "validons": "valider",
    "validâmes": "valider",
    "validât": "valider",
    "validâtes": "valider",
    "validèrent": "valider",
    "validé": "valider",
    "validée": "valider",
    "validées": "valider",
    "validés": "valider",
    "valiez": "valoir",
    "valions": "valoir",
    "valises": "valise",
    "valisé": "valiser",
    "valkyries": "valkyrie",
    "vallonnaient": "vallonner",
    "vallonnait": "vallonner",
    "vallonnements": "vallonnement",
    "vallonnée": "vallonner",
    "vallonnées": "vallonné",
    "vallonnés": "vallonné",
    "vallons": "vallon",
    "vallées": "vallée",
    "valoches": "valoche",
    "valoisienne": "valoisien",
    "valoisiennes": "valoisien",
    "valoisiens": "valoisien",
    "valons": "valoir",
    "valorisa": "valoriser",
    "valorisai": "valoriser",
    "valorisaient": "valoriser",
    "valorisais": "valoriser",
    "valorisait": "valoriser",
    "valorisant": "valoriser",
    "valorisante": "valorisant",
    "valorisantes": "valorisant",
    "valorisants": "valorisant",
    "valorisas": "valoriser",
    "valorisasse": "valoriser",
    "valorisassent": "valoriser",
    "valorisasses": "valoriser",
    "valorisassiez": "valoriser",
    "valorisassions": "valoriser",
    "valorisations": "valorisation",
    "valorise": "valoriser",
    "valorisent": "valoriser",
    "valorisera": "valoriser",
    "valoriserai": "valoriser",
    "valoriseraient": "valoriser",
    "valoriserais": "valoriser",
    "valoriserait": "valoriser",
    "valoriseras": "valoriser",
    "valoriserez": "valoriser",
    "valoriseriez": "valoriser",
    "valoriserions": "valoriser",
    "valoriserons": "valoriser",
    "valoriseront": "valoriser",
    "valorises": "valoriser",
    "valorisez": "valoriser",
    "valorisiez": "valoriser",
    "valorisions": "valoriser",
    "valorisons": "valoriser",
    "valorisâmes": "valoriser",
    "valorisât": "valoriser",
    "valorisâtes": "valoriser",
    "valorisèrent": "valoriser",
    "valorisé": "valoriser",
    "valorisée": "valoriser",
    "valorisées": "valoriser",
    "valorisés": "valoriser",
    "vals": "val",
    "valsa": "valser",
    "valsai": "valser",
    "valsaient": "valser",
    "valsais": "valser",
    "valsait": "valser",
    "valsant": "valser",
    "valsas": "valser",
    "valsasse": "valser",
    "valsassent": "valser",
    "valsasses": "valser",
    "valsassiez": "valser",
    "valsassions": "valser",
    "valse": "valser",
    "valsent": "valser",
    "valsera": "valser",
    "valserai": "valser",
    "valseraient": "valser",
    "valserais": "valser",
    "valserait": "valser",
    "valseras": "valser",
    "valserez": "valser",
    "valseriez": "valser",
    "valserions": "valser",
    "valserons": "valser",
    "valseront": "valser",
    "valses": "valser",
    "valses-hésitations": "valse-hésitation",
    "valseurs": "valseur",
    "valseuse": "valseur",
    "valseuses": "valseur",
    "valsez": "valser",
    "valsiez": "valser",
    "valsions": "valser",
    "valsons": "valser",
    "valsâmes": "valser",
    "valsât": "valser",
    "valsâtes": "valser",
    "valsèrent": "valser",
    "valsé": "valser",
    "valsée": "valser",
    "valsées": "valser",
    "valsés": "valser",
    "valu": "valoir",
    "value": "valoir",
    "values": "valoir",
    "valurent": "valoir",
    "valus": "valoir",
    "valusse": "valoir",
    "valussent": "valoir",
    "valusses": "valoir",
    "valussiez": "valoir",
    "valussions": "valoir",
    "valut": "valoir",
    "valves": "valve",
    "valvulaires": "valvulaire",
    "valvules": "valvule",
    "valérianes": "valériane",
    "valétudinaires": "valétudinaire",
    "valûmes": "valoir",
    "valût": "valoir",
    "valûtes": "valoir",
    "vampa": "vamper",
    "vampai": "vamper",
    "vampaient": "vamper",
    "vampais": "vamper",
    "vampait": "vamper",
    "vampant": "vamper",
    "vampas": "vamper",
    "vampasse": "vamper",
    "vampassent": "vamper",
    "vampasses": "vamper",
    "vampassiez": "vamper",
    "vampassions": "vamper",
    "vampe": "vamper",
    "vampent": "vamper",
    "vampera": "vamper",
    "vamperai": "vamper",
    "vamperaient": "vamper",
    "vamperais": "vamper",
    "vamperait": "vamper",
    "vamperas": "vamper",
    "vamperez": "vamper",
    "vamperiez": "vamper",
    "vamperions": "vamper",
    "vamperons": "vamper",
    "vamperont": "vamper",
    "vampes": "vamper",
    "vampez": "vamper",
    "vampiez": "vamper",
    "vampions": "vamper",
    "vampires": "vampire",
    "vampirisant": "vampiriser",
    "vampirise": "vampiriser",
    "vampirisé": "vampiriser",
    "vampirisée": "vampiriser",
    "vampirisées": "vampiriser",
    "vampons": "vamper",
    "vamps": "vamp",
    "vampâmes": "vamper",
    "vampât": "vamper",
    "vampâtes": "vamper",
    "vampèrent": "vamper",
    "vampé": "vamper",
    "vampée": "vamper",
    "vampées": "vamper",
    "vampés": "vamper",
    "vanadiums": "vanadium",
    "vandales": "vandale",
    "vandalisent": "vandaliser",
    "vandalismes": "vandalisme",
    "vandalisé": "vandaliser",
    "vandoises": "vandoise",
    "vanesses": "vanesse",
    "vanilles": "vanille",
    "vanillée": "vanillé",
    "vanillées": "vanillé",
    "vaniteuse": "vaniteux",
    "vaniteuses": "vaniteux",
    "vanités": "vanité",
    "vanna": "vanner",
    "vannai": "vanner",
    "vannaient": "vanner",
    "vannais": "vanner",
    "vannait": "vanner",
    "vannant": "vanner",
    "vannas": "vanner",
    "vannasse": "vanner",
    "vannassent": "vanner",
    "vannasses": "vanner",
    "vannassiez": "vanner",
    "vannassions": "vanner",
    "vanne": "vanner",
    "vanneaux": "vanneau",
    "vannent": "vanner",
    "vannera": "vanner",
    "vannerai": "vanner",
    "vanneraient": "vanner",
    "vannerais": "vanner",
    "vannerait": "vanner",
    "vanneras": "vanner",
    "vannerez": "vanner",
    "vanneries": "vannerie",
    "vanneriez": "vanner",
    "vannerions": "vanner",
    "vannerons": "vanner",
    "vanneront": "vanner",
    "vannes": "vanner",
    "vanneurs": "vanneur",
    "vannez": "vanner",
    "vanniers": "vannier",
    "vanniez": "vanner",
    "vannions": "vanner",
    "vannières": "vannière",
    "vannons": "vanner",
    "vannâmes": "vanner",
    "vannât": "vanner",
    "vannâtes": "vanner",
    "vannèrent": "vanner",
    "vanné": "vanner",
    "vannée": "vanner",
    "vannées": "vanner",
    "vannés": "vanner",
    "vans": "van",
    "vanta": "vanter",
    "vantai": "vanter",
    "vantaient": "vanter",
    "vantais": "vanter",
    "vantait": "vanter",
    "vantant": "vanter",
    "vantarde": "vantard",
    "vantardes": "vantard",
    "vantardises": "vantardise",
    "vantards": "vantard",
    "vantas": "vanter",
    "vantasse": "vanter",
    "vantassent": "vanter",
    "vantasses": "vanter",
    "vantassiez": "vanter",
    "vantassions": "vanter",
    "vantaux": "vantail",
    "vante": "vanter",
    "vantent": "vanter",
    "vantera": "vanter",
    "vanterai": "vanter",
    "vanteraient": "vanter",
    "vanterais": "vanter",
    "vanterait": "vanter",
    "vanteras": "vanter",
    "vanterez": "vanter",
    "vanteries": "vanterie",
    "vanteriez": "vanter",
    "vanterions": "vanter",
    "vanterons": "vanter",
    "vanteront": "vanter",
    "vantes": "vanter",
    "vantez": "vanter",
    "vantiez": "vanter",
    "vantions": "vanter",
    "vantons": "vanter",
    "vantâmes": "vanter",
    "vantât": "vanter",
    "vantâtes": "vanter",
    "vantèrent": "vanter",
    "vanté": "vanter",
    "vantée": "vanter",
    "vantées": "vanter",
    "vantés": "vanter",
    "vapes": "vape",
    "vapeurs": "vapeur",
    "vaporeuse": "vaporeux",
    "vaporeuses": "vaporeux",
    "vaporisa": "vaporiser",
    "vaporisai": "vaporiser",
    "vaporisaient": "vaporiser",
    "vaporisais": "vaporiser",
    "vaporisait": "vaporiser",
    "vaporisant": "vaporiser",
    "vaporisas": "vaporiser",
    "vaporisasse": "vaporiser",
    "vaporisassent": "vaporiser",
    "vaporisasses": "vaporiser",
    "vaporisassiez": "vaporiser",
    "vaporisassions": "vaporiser",
    "vaporisateurs": "vaporisateur",
    "vaporisations": "vaporisation",
    "vaporise": "vaporiser",
    "vaporisent": "vaporiser",
    "vaporisera": "vaporiser",
    "vaporiserai": "vaporiser",
    "vaporiseraient": "vaporiser",
    "vaporiserais": "vaporiser",
    "vaporiserait": "vaporiser",
    "vaporiseras": "vaporiser",
    "vaporiserez": "vaporiser",
    "vaporiseriez": "vaporiser",
    "vaporiserions": "vaporiser",
    "vaporiserons": "vaporiser",
    "vaporiseront": "vaporiser",
    "vaporises": "vaporiser",
    "vaporisez": "vaporiser",
    "vaporisiez": "vaporiser",
    "vaporisions": "vaporiser",
    "vaporisons": "vaporiser",
    "vaporisâmes": "vaporiser",
    "vaporisât": "vaporiser",
    "vaporisâtes": "vaporiser",
    "vaporisèrent": "vaporiser",
    "vaporisé": "vaporiser",
    "vaporisée": "vaporiser",
    "vaporisées": "vaporiser",
    "vaporisés": "vaporiser",
    "vaqua": "vaquer",
    "vaquai": "vaquer",
    "vaquaient": "vaquer",
    "vaquais": "vaquer",
    "vaquait": "vaquer",
    "vaquant": "vaquer",
    "vaquas": "vaquer",
    "vaquasse": "vaquer",
    "vaquassent": "vaquer",
    "vaquasses": "vaquer",
    "vaquassiez": "vaquer",
    "vaquassions": "vaquer",
    "vaque": "vaquer",
    "vaquent": "vaquer",
    "vaquera": "vaquer",
    "vaquerai": "vaquer",
    "vaqueraient": "vaquer",
    "vaquerais": "vaquer",
    "vaquerait": "vaquer",
    "vaqueras": "vaquer",
    "vaquerez": "vaquer",
    "vaqueriez": "vaquer",
    "vaquerions": "vaquer",
    "vaquerons": "vaquer",
    "vaqueront": "vaquer",
    "vaqueros": "vaquero",
    "vaques": "vaquer",
    "vaquez": "vaquer",
    "vaquiez": "vaquer",
    "vaquions": "vaquer",
    "vaquons": "vaquer",
    "vaquâmes": "vaquer",
    "vaquât": "vaquer",
    "vaquâtes": "vaquer",
    "vaquèrent": "vaquer",
    "vaqué": "vaquer",
    "varangues": "varangue",
    "varans": "varan",
    "varappes": "varappe",
    "varas": "vara",
    "varechs": "varech",
    "varennes": "varenne",
    "vareuses": "vareuse",
    "varia": "varier",
    "variabilités": "variabilité",
    "variables": "variable",
    "variai": "varier",
    "variaient": "varier",
    "variais": "varier",
    "variait": "varier",
    "variant": "varier",
    "variante": "variant",
    "variantes": "variante",
    "varias": "varier",
    "variasse": "varier",
    "variassent": "varier",
    "variasses": "varier",
    "variassiez": "varier",
    "variassions": "varier",
    "variations": "variation",
    "varicelles": "varicelle",
    "varices": "varice",
    "varicocèles": "varicocèle",
    "varie": "varier",
    "varient": "varier",
    "variera": "varier",
    "varierai": "varier",
    "varieraient": "varier",
    "varierais": "varier",
    "varierait": "varier",
    "varieras": "varier",
    "varierez": "varier",
    "varieriez": "varier",
    "varierions": "varier",
    "varierons": "varier",
    "varieront": "varier",
    "varies": "varier",
    "variez": "varier",
    "variiez": "varier",
    "variions": "varier",
    "varioles": "variole",
    "varions": "varier",
    "variqueuse": "variqueux",
    "variqueuses": "variqueux",
    "variâmes": "varier",
    "variât": "varier",
    "variâtes": "varier",
    "varièrent": "varier",
    "varié": "varier",
    "variée": "varier",
    "variées": "varier",
    "variés": "varier",
    "variétale": "variétal",
    "variétales": "variétal",
    "variétaux": "variétal",
    "variétés": "variété",
    "varlopes": "varlope",
    "vas": "aller",
    "vasa": "vaser",
    "vasait": "vaser",
    "vasards": "vasard",
    "vasculaires": "vasculaire",
    "vaselines": "vaseline",
    "vaselinez": "vaseliner",
    "vaseliné": "vaseliner",
    "vases": "vase",
    "vaseuse": "vaseux",
    "vaseuses": "vaseux",
    "vasières": "vasière",
    "vasoconstricteurs": "vasoconstricteur",
    "vasoconstrictrice": "vasoconstricteur",
    "vasoconstrictrices": "vasoconstricteur",
    "vasodilatateurs": "vasodilatateur",
    "vasodilatatrice": "vasodilatateur",
    "vasodilatatrices": "vasodilatateur",
    "vasomoteurs": "vasomoteur",
    "vasomotrice": "vasomoteur",
    "vasomotrices": "vasomoteur",
    "vasouillarde": "vasouillard",
    "vasouille": "vasouiller",
    "vasouilles": "vasouiller",
    "vasques": "vasque",
    "vassale": "vassal",
    "vassales": "vassal",
    "vassaux": "vassal",
    "vastes": "vaste",
    "vastitudes": "vastitude",
    "vaticanes": "vaticane",
    "vaticina": "vaticiner",
    "vaticinai": "vaticiner",
    "vaticinaient": "vaticiner",
    "vaticinais": "vaticiner",
    "vaticinait": "vaticiner",
    "vaticinant": "vaticiner",
    "vaticinas": "vaticiner",
    "vaticinasse": "vaticiner",
    "vaticinassent": "vaticiner",
    "vaticinasses": "vaticiner",
    "vaticinassiez": "vaticiner",
    "vaticinassions": "vaticiner",
    "vaticinations": "vaticination",
    "vaticine": "vaticiner",
    "vaticinent": "vaticiner",
    "vaticinera": "vaticiner",
    "vaticinerai": "vaticiner",
    "vaticineraient": "vaticiner",
    "vaticinerais": "vaticiner",
    "vaticinerait": "vaticiner",
    "vaticineras": "vaticiner",
    "vaticinerez": "vaticiner",
    "vaticineriez": "vaticiner",
    "vaticinerions": "vaticiner",
    "vaticinerons": "vaticiner",
    "vaticineront": "vaticiner",
    "vaticines": "vaticiner",
    "vaticinez": "vaticiner",
    "vaticiniez": "vaticiner",
    "vaticinions": "vaticiner",
    "vaticinons": "vaticiner",
    "vaticinâmes": "vaticiner",
    "vaticinât": "vaticiner",
    "vaticinâtes": "vaticiner",
    "vaticinèrent": "vaticiner",
    "vaticiné": "vaticiner",
    "vatères": "vatère",
    "vauclusiennes": "vauclusien",
    "vaudevilles": "vaudeville",
    "vaudevillesques": "vaudevillesque",
    "vaudoise": "vaudois",
    "vaudoises": "vaudois",
    "vaudoue": "vaudou",
    "vaudoues": "vaudou",
    "vaudous": "vaudou",
    "vaudra": "valoir",
    "vaudrai": "valoir",
    "vaudraient": "valoir",
    "vaudrais": "valoir",
    "vaudrait": "valoir",
    "vaudras": "valoir",
    "vaudrez": "valoir",
    "vaudriez": "valoir",
    "vaudrions": "valoir",
    "vaudrons": "valoir",
    "vaudront": "valoir",
    "vaurienne": "vaurien",
    "vauriennes": "vaurien",
    "vauriens": "vaurien",
    "vaut": "valoir",
    "vautours": "vautour",
    "vautra": "vautrer",
    "vautrai": "vautrer",
    "vautraient": "vautrer",
    "vautrais": "vautrer",
    "vautrait": "vautrer",
    "vautrant": "vautrer",
    "vautras": "vautrer",
    "vautrasse": "vautrer",
    "vautrassent": "vautrer",
    "vautrasses": "vautrer",
    "vautrassiez": "vautrer",
    "vautrassions": "vautrer",
    "vautre": "vautrer",
    "vautrent": "vautrer",
    "vautrera": "vautrer",
    "vautrerai": "vautrer",
    "vautreraient": "vautrer",
    "vautrerais": "vautrer",
    "vautrerait": "vautrer",
    "vautreras": "vautrer",
    "vautrerez": "vautrer",
    "vautreriez": "vautrer",
    "vautrerions": "vautrer",
    "vautrerons": "vautrer",
    "vautreront": "vautrer",
    "vautres": "vautrer",
    "vautrez": "vautrer",
    "vautriez": "vautrer",
    "vautrions": "vautrer",
    "vautrons": "vautrer",
    "vautrâmes": "vautrer",
    "vautrât": "vautrer",
    "vautrâtes": "vautrer",
    "vautrèrent": "vautrer",
    "vautré": "vautrer",
    "vautrée": "vautrer",
    "vautrées": "vautrer",
    "vautrés": "vautrer",
    "vaux": "valoir",
    "veaux": "veau",
    "vecteurs": "vecteur",
    "vectorielle": "vectoriel",
    "vectorielles": "vectoriel",
    "vectoriels": "vectoriel",
    "vedettariats": "vedettariat",
    "vedettes": "vedette",
    "veilla": "veiller",
    "veillai": "veiller",
    "veillaient": "veiller",
    "veillais": "veiller",
    "veillait": "veiller",
    "veillant": "veiller",
    "veillas": "veiller",
    "veillasse": "veiller",
    "veillassent": "veiller",
    "veillasses": "veiller",
    "veillassiez": "veiller",
    "veillassions": "veiller",
    "veille": "veiller",
    "veillent": "veiller",
    "veillera": "veiller",
    "veillerai": "veiller",
    "veilleraient": "veiller",
    "veillerais": "veiller",
    "veillerait": "veiller",
    "veilleras": "veiller",
    "veillerez": "veiller",
    "veilleriez": "veiller",
    "veillerions": "veiller",
    "veillerons": "veiller",
    "veilleront": "veiller",
    "veilles": "veiller",
    "veilleurs": "veilleur",
    "veilleuse": "veilleur",
    "veilleuses": "veilleuse",
    "veillez": "veiller",
    "veilliez": "veiller",
    "veillions": "veiller",
    "veillons": "veiller",
    "veillâmes": "veiller",
    "veillât": "veiller",
    "veillâtes": "veiller",
    "veillèrent": "veiller",
    "veillé": "veiller",
    "veillée": "veiller",
    "veillées": "veiller",
    "veillés": "veiller",
    "veina": "veiner",
    "veinai": "veiner",
    "veinaient": "veiner",
    "veinais": "veiner",
    "veinait": "veiner",
    "veinant": "veiner",
    "veinarde": "veinard",
    "veinardes": "veinard",
    "veinards": "veinard",
    "veinas": "veiner",
    "veinasse": "veiner",
    "veinassent": "veiner",
    "veinasses": "veiner",
    "veinassiez": "veiner",
    "veinassions": "veiner",
    "veine": "veiner",
    "veinent": "veiner",
    "veinera": "veiner",
    "veinerai": "veiner",
    "veineraient": "veiner",
    "veinerais": "veiner",
    "veinerait": "veiner",
    "veineras": "veiner",
    "veinerez": "veiner",
    "veineriez": "veiner",
    "veinerions": "veiner",
    "veinerons": "veiner",
    "veineront": "veiner",
    "veines": "veiner",
    "veineuse": "veineux",
    "veinez": "veiner",
    "veiniez": "veiner",
    "veinions": "veiner",
    "veinons": "veiner",
    "veinules": "veinule",
    "veinures": "veinure",
    "veinâmes": "veiner",
    "veinât": "veiner",
    "veinâtes": "veiner",
    "veinèrent": "veiner",
    "veiné": "veiner",
    "veinée": "veiner",
    "veinées": "veiner",
    "veinés": "veiner",
    "velléitaires": "velléitaire",
    "velléités": "velléité",
    "velouta": "velouter",
    "veloutai": "velouter",
    "veloutaient": "velouter",
    "veloutais": "velouter",
    "veloutait": "velouter",
    "veloutant": "velouter",
    "veloutas": "velouter",
    "veloutasse": "velouter",
    "veloutassent": "velouter",
    "veloutasses": "velouter",
    "veloutassiez": "velouter",
    "veloutassions": "velouter",
    "veloute": "velouter",
    "veloutent": "velouter",
    "veloutera": "velouter",
    "velouterai": "velouter",
    "velouteraient": "velouter",
    "velouterais": "velouter",
    "velouterait": "velouter",
    "velouteras": "velouter",
    "velouterez": "velouter",
    "velouteriez": "velouter",
    "velouterions": "velouter",
    "velouterons": "velouter",
    "velouteront": "velouter",
    "veloutes": "velouter",
    "velouteuse": "velouteux",
    "veloutez": "velouter",
    "veloutiez": "velouter",
    "veloutions": "velouter",
    "veloutons": "velouter",
    "veloutâmes": "velouter",
    "veloutât": "velouter",
    "veloutâtes": "velouter",
    "veloutèrent": "velouter",
    "velouté": "velouter",
    "veloutée": "velouter",
    "veloutées": "velouter",
    "veloutés": "velouter",
    "velue": "velu",
    "velues": "velu",
    "velus": "velu",
    "venaient": "venir",
    "venais": "venir",
    "venaisons": "venaison",
    "venait": "venir",
    "venant": "venir",
    "vend": "vendre",
    "vendables": "vendable",
    "vendaient": "vendre",
    "vendais": "vendre",
    "vendait": "vendre",
    "vendange": "vendanger",
    "vendangea": "vendanger",
    "vendangeai": "vendanger",
    "vendangeaient": "vendanger",
    "vendangeais": "vendanger",
    "vendangeait": "vendanger",
    "vendangeant": "vendanger",
    "vendangeas": "vendanger",
    "vendangeasse": "vendanger",
    "vendangeassent": "vendanger",
    "vendangeasses": "vendanger",
    "vendangeassiez": "vendanger",
    "vendangeassions": "vendanger",
    "vendangent": "vendanger",
    "vendangeons": "vendanger",
    "vendangera": "vendanger",
    "vendangerai": "vendanger",
    "vendangeraient": "vendanger",
    "vendangerais": "vendanger",
    "vendangerait": "vendanger",
    "vendangeras": "vendanger",
    "vendangerez": "vendanger",
    "vendangeriez": "vendanger",
    "vendangerions": "vendanger",
    "vendangerons": "vendanger",
    "vendangeront": "vendanger",
    "vendanges": "vendanger",
    "vendangeurs": "vendangeur",
    "vendangeuses": "vendangeur",
    "vendangez": "vendanger",
    "vendangeâmes": "vendanger",
    "vendangeât": "vendanger",
    "vendangeâtes": "vendanger",
    "vendangiez": "vendanger",
    "vendangions": "vendanger",
    "vendangèrent": "vendanger",
    "vendangé": "vendanger",
    "vendangée": "vendanger",
    "vendangées": "vendanger",
    "vendangés": "vendanger",
    "vendant": "vendre",
    "vende": "vendre",
    "vendent": "vendre",
    "vendes": "vendre",
    "vendettas": "vendetta",
    "vendeurs": "vendeur",
    "vendeuse": "vendeur",
    "vendeuses": "vendeur",
    "vendez": "vendre",
    "vendiez": "vendre",
    "vendions": "vendre",
    "vendirent": "vendre",
    "vendis": "vendre",
    "vendisse": "vendre",
    "vendissent": "vendre",
    "vendisses": "vendre",
    "vendissiez": "vendre",
    "vendissions": "vendre",
    "vendit": "vendre",
    "vendons": "vendre",
    "vendra": "vendre",
    "vendrai": "vendre",
    "vendraient": "vendre",
    "vendrais": "vendre",
    "vendrait": "vendre",
    "vendras": "vendre",
    "vendredis": "vendredi",
    "vendrez": "vendre",
    "vendriez": "vendre",
    "vendrions": "vendre",
    "vendrons": "vendre",
    "vendront": "vendre",
    "vends": "vendre",
    "vendu": "vendre",
    "vendue": "vendu",
    "vendues": "vendu",
    "vendus": "vendu",
    "vendéenne": "vendéen",
    "vendéennes": "vendéen",
    "vendéens": "vendéen",
    "vendémiaires": "vendémiaire",
    "vendîmes": "vendre",
    "vendît": "vendre",
    "vendîtes": "vendre",
    "venelles": "venelle",
    "veneurs": "veneur",
    "venez": "venir",
    "venge": "venger",
    "vengea": "venger",
    "vengeai": "venger",
    "vengeaient": "venger",
    "vengeais": "venger",
    "vengeait": "venger",
    "vengeances": "vengeance",
    "vengeant": "venger",
    "vengeas": "venger",
    "vengeasse": "venger",
    "vengeassent": "venger",
    "vengeasses": "venger",
    "vengeassiez": "venger",
    "vengeassions": "venger",
    "vengent": "venger",
    "vengeons": "venger",
    "vengera": "venger",
    "vengerai": "venger",
    "vengeraient": "venger",
    "vengerais": "venger",
    "vengerait": "venger",
    "vengeras": "venger",
    "vengeresse": "vengeur",
    "vengeresses": "vengeur",
    "vengerez": "venger",
    "vengeriez": "venger",
    "vengerions": "venger",
    "vengerons": "venger",
    "vengeront": "venger",
    "venges": "venger",
    "vengeurs": "vengeur",
    "vengez": "venger",
    "vengeâmes": "venger",
    "vengeât": "venger",
    "vengeâtes": "venger",
    "vengiez": "venger",
    "vengions": "venger",
    "vengèrent": "venger",
    "vengé": "venger",
    "vengée": "venger",
    "vengées": "venger",
    "vengés": "venger",
    "veniez": "venir",
    "venimeuse": "venimeux",
    "venimeuses": "venimeux",
    "venins": "venin",
    "venions": "venir",
    "venons": "venir",
    "venta": "venter",
    "ventailles": "ventaille",
    "ventait": "venter",
    "ventant": "venter",
    "ventas": "venter",
    "ventaux": "ventail",
    "vente": "venter",
    "ventera": "venter",
    "venterait": "venter",
    "ventes": "vente",
    "venteuse": "venteux",
    "venteuses": "venteux",
    "ventila": "ventiler",
    "ventilai": "ventiler",
    "ventilaient": "ventiler",
    "ventilais": "ventiler",
    "ventilait": "ventiler",
    "ventilant": "ventiler",
    "ventilas": "ventiler",
    "ventilasse": "ventiler",
    "ventilassent": "ventiler",
    "ventilasses": "ventiler",
    "ventilassiez": "ventiler",
    "ventilassions": "ventiler",
    "ventilateurs": "ventilateur",
    "ventilations": "ventilation",
    "ventile": "ventiler",
    "ventilent": "ventiler",
    "ventilera": "ventiler",
    "ventilerai": "ventiler",
    "ventileraient": "ventiler",
    "ventilerais": "ventiler",
    "ventilerait": "ventiler",
    "ventileras": "ventiler",
    "ventilerez": "ventiler",
    "ventileriez": "ventiler",
    "ventilerions": "ventiler",
    "ventilerons": "ventiler",
    "ventileront": "ventiler",
    "ventiles": "ventiler",
    "ventilez": "ventiler",
    "ventiliez": "ventiler",
    "ventilions": "ventiler",
    "ventilons": "ventiler",
    "ventilos": "ventilo",
    "ventilâmes": "ventiler",
    "ventilât": "ventiler",
    "ventilâtes": "ventiler",
    "ventilèrent": "ventiler",
    "ventilé": "ventiler",
    "ventilée": "ventiler",
    "ventilées": "ventiler",
    "ventilés": "ventiler",
    "ventousent": "ventouser",
    "ventouses": "ventouse",
    "ventousé": "ventouser",
    "ventousée": "ventouser",
    "ventrale": "ventral",
    "ventrales": "ventral",
    "ventraux": "ventral",
    "ventres": "ventre",
    "ventricules": "ventricule",
    "ventriloques": "ventriloque",
    "ventripotente": "ventripotent",
    "ventripotentes": "ventripotent",
    "ventripotents": "ventripotent",
    "ventrue": "ventru",
    "ventrues": "ventru",
    "ventrus": "ventru",
    "ventrées": "ventrée",
    "vents": "vent",
    "ventât": "venter",
    "venté": "venter",
    "ventée": "venté",
    "ventées": "venté",
    "ventés": "venter",
    "ventôses": "ventôse",
    "venu": "venir",
    "venue": "venu",
    "venues": "venue",
    "venus": "venu",
    "verbale": "verbal",
    "verbales": "verbal",
    "verbalise": "verbaliser",
    "verbalisez": "verbaliser",
    "verbalisé": "verbaliser",
    "verbalisée": "verbaliser",
    "verbaux": "verbal",
    "verbes": "verbe",
    "verbeuse": "verbeux",
    "verbeuses": "verbeux",
    "verbiages": "verbiage",
    "verbosités": "verbosité",
    "verdets": "verdet",
    "verdeurs": "verdeur",
    "verdi": "verdir",
    "verdicts": "verdict",
    "verdie": "verdir",
    "verdiers": "verdier",
    "verdies": "verdir",
    "verdine": "verdin",
    "verdira": "verdir",
    "verdirai": "verdir",
    "verdiraient": "verdir",
    "verdirais": "verdir",
    "verdirait": "verdir",
    "verdiras": "verdir",
    "verdirent": "verdir",
    "verdirez": "verdir",
    "verdiriez": "verdir",
    "verdirions": "verdir",
    "verdirons": "verdir",
    "verdiront": "verdir",
    "verdis": "verdir",
    "verdissaient": "verdir",
    "verdissais": "verdir",
    "verdissait": "verdir",
    "verdissant": "verdir",
    "verdissante": "verdissant",
    "verdissants": "verdissant",
    "verdisse": "verdir",
    "verdissent": "verdir",
    "verdisses": "verdir",
    "verdissez": "verdir",
    "verdissiez": "verdir",
    "verdissions": "verdir",
    "verdissons": "verdir",
    "verdit": "verdir",
    "verdoie": "verdoyer",
    "verdoiements": "verdoiement",
    "verdoient": "verdoyer",
    "verdoiera": "verdoyer",
    "verdoierai": "verdoyer",
    "verdoieraient": "verdoyer",
    "verdoierais": "verdoyer",
    "verdoierait": "verdoyer",
    "verdoieras": "verdoyer",
    "verdoierez": "verdoyer",
    "verdoieriez": "verdoyer",
    "verdoierions": "verdoyer",
    "verdoierons": "verdoyer",
    "verdoieront": "verdoyer",
    "verdoies": "verdoyer",
    "verdoya": "verdoyer",
    "verdoyai": "verdoyer",
    "verdoyaient": "verdoyer",
    "verdoyais": "verdoyer",
    "verdoyait": "verdoyer",
    "verdoyant": "verdoyer",
    "verdoyante": "verdoyant",
    "verdoyantes": "verdoyant",
    "verdoyants": "verdoyant",
    "verdoyas": "verdoyer",
    "verdoyasse": "verdoyer",
    "verdoyassent": "verdoyer",
    "verdoyasses": "verdoyer",
    "verdoyassiez": "verdoyer",
    "verdoyassions": "verdoyer",
    "verdoyez": "verdoyer",
    "verdoyiez": "verdoyer",
    "verdoyions": "verdoyer",
    "verdoyons": "verdoyer",
    "verdoyâmes": "verdoyer",
    "verdoyât": "verdoyer",
    "verdoyâtes": "verdoyer",
    "verdoyèrent": "verdoyer",
    "verdoyé": "verdoyer",
    "verdures": "verdure",
    "verdâtres": "verdâtre",
    "verdîmes": "verdir",
    "verdît": "verdir",
    "verdîtes": "verdir",
    "vergers": "verger",
    "verges": "verge",
    "vergetures": "vergeture",
    "vergetée": "vergeté",
    "vergetées": "vergeté",
    "vergetés": "vergeté",
    "verglace": "verglacer",
    "verglacera": "verglacer",
    "verglacerait": "verglacer",
    "verglacé": "verglacer",
    "verglacée": "verglacer",
    "verglacées": "verglacer",
    "verglacés": "verglacer",
    "verglaça": "verglacer",
    "verglaçait": "verglacer",
    "verglaçant": "verglacer",
    "verglaçât": "verglacer",
    "vergnes": "vergne",
    "vergognes": "vergogne",
    "vergues": "vergue",
    "vergée": "vergé",
    "vergées": "vergé",
    "vergés": "vergé",
    "verjutée": "verjuté",
    "verjutées": "verjuté",
    "verjutés": "verjuté",
    "vermeille": "vermeil",
    "vermeilles": "vermeil",
    "vermeils": "vermeil",
    "vermicelles": "vermicelle",
    "vermicides": "vermicide",
    "vermiculaires": "vermiculaire",
    "vermiculées": "vermiculé",
    "vermifuges": "vermifuge",
    "vermilla": "vermiller",
    "vermillai": "vermiller",
    "vermillaient": "vermiller",
    "vermillais": "vermiller",
    "vermillait": "vermiller",
    "vermillant": "vermiller",
    "vermillas": "vermiller",
    "vermillasse": "vermiller",
    "vermillassent": "vermiller",
    "vermillasses": "vermiller",
    "vermillassiez": "vermiller",
    "vermillassions": "vermiller",
    "vermille": "vermiller",
    "vermillent": "vermiller",
    "vermillera": "vermiller",
    "vermillerai": "vermiller",
    "vermilleraient": "vermiller",
    "vermillerais": "vermiller",
    "vermillerait": "vermiller",
    "vermilleras": "vermiller",
    "vermillerez": "vermiller",
    "vermilleriez": "vermiller",
    "vermillerions": "vermiller",
    "vermillerons": "vermiller",
    "vermilleront": "vermiller",
    "vermilles": "vermiller",
    "vermillez": "vermiller",
    "vermilliez": "vermiller",
    "vermillions": "vermiller",
    "vermillonna": "vermillonner",
    "vermillonnai": "vermillonner",
    "vermillonnaient": "vermillonner",
    "vermillonnais": "vermillonner",
    "vermillonnait": "vermillonner",
    "vermillonnant": "vermillonner",
    "vermillonnas": "vermillonner",
    "vermillonnasse": "vermillonner",
    "vermillonnassent": "vermillonner",
    "vermillonnasses": "vermillonner",
    "vermillonnassiez": "vermillonner",
    "vermillonnassions": "vermillonner",
    "vermillonne": "vermillonner",
    "vermillonnent": "vermillonner",
    "vermillonnera": "vermillonner",
    "vermillonnerai": "vermillonner",
    "vermillonneraient": "vermillonner",
    "vermillonnerais": "vermillonner",
    "vermillonnerait": "vermillonner",
    "vermillonneras": "vermillonner",
    "vermillonnerez": "vermillonner",
    "vermillonneriez": "vermillonner",
    "vermillonnerions": "vermillonner",
    "vermillonnerons": "vermillonner",
    "vermillonneront": "vermillonner",
    "vermillonnes": "vermillonner",
    "vermillonnez": "vermillonner",
    "vermillonniez": "vermillonner",
    "vermillonnions": "vermillonner",
    "vermillonnons": "vermillonner",
    "vermillonnâmes": "vermillonner",
    "vermillonnât": "vermillonner",
    "vermillonnâtes": "vermillonner",
    "vermillonnèrent": "vermillonner",
    "vermillonné": "vermillonner",
    "vermillonnée": "vermillonner",
    "vermillonnées": "vermillonner",
    "vermillonnés": "vermillonner",
    "vermillons": "vermillon",
    "vermillâmes": "vermiller",
    "vermillât": "vermiller",
    "vermillâtes": "vermiller",
    "vermillèrent": "vermiller",
    "vermillé": "vermiller",
    "vermillée": "vermiller",
    "vermillées": "vermiller",
    "vermillés": "vermiller",
    "vermines": "vermine",
    "vermisseaux": "vermisseau",
    "vermoulue": "vermoulu",
    "vermoulues": "vermoulu",
    "vermoulures": "vermoulure",
    "vermoulus": "vermoulu",
    "vermouths": "vermouth",
    "vernaculaires": "vernaculaire",
    "vernale": "vernal",
    "vernales": "vernal",
    "vernaux": "vernal",
    "verni": "vernir",
    "vernie": "vernir",
    "vernies": "vernir",
    "vernira": "vernir",
    "vernirai": "vernir",
    "verniraient": "vernir",
    "vernirais": "vernir",
    "vernirait": "vernir",
    "verniras": "vernir",
    "vernirent": "vernir",
    "vernirez": "vernir",
    "verniriez": "vernir",
    "vernirions": "vernir",
    "vernirons": "vernir",
    "verniront": "vernir",
    "vernis": "vernir",
    "vernissa": "vernisser",
    "vernissages": "vernissage",
    "vernissai": "vernisser",
    "vernissaient": "vernisser",
    "vernissais": "vernisser",
    "vernissait": "vernisser",
    "vernissant": "vernisser",
    "vernissas": "vernisser",
    "vernissasse": "vernisser",
    "vernissassent": "vernisser",
    "vernissasses": "vernisser",
    "vernissassiez": "vernisser",
    "vernissassions": "vernisser",
    "vernisse": "vernisser",
    "vernissent": "vernisser",
    "vernissera": "vernisser",
    "vernisserai": "vernisser",
    "vernisseraient": "vernisser",
    "vernisserais": "vernisser",
    "vernisserait": "vernisser",
    "vernisseras": "vernisser",
    "vernisserez": "vernisser",
    "vernisseriez": "vernisser",
    "vernisserions": "vernisser",
    "vernisserons": "vernisser",
    "vernisseront": "vernisser",
    "vernisses": "vernisser",
    "vernissez": "vernisser",
    "vernissiez": "vernisser",
    "vernissions": "vernisser",
    "vernissons": "vernisser",
    "vernissâmes": "vernisser",
    "vernissât": "vernisser",
    "vernissâtes": "vernisser",
    "vernissèrent": "vernisser",
    "vernissé": "vernisser",
    "vernissée": "vernisser",
    "vernissées": "vernisser",
    "vernissés": "vernisser",
    "vernit": "vernir",
    "vernîmes": "vernir",
    "vernît": "vernir",
    "vernîtes": "vernir",
    "verra": "voir",
    "verrai": "voir",
    "verraient": "voir",
    "verrais": "voir",
    "verrait": "voir",
    "verras": "voir",
    "verrats": "verrat",
    "verreries": "verrerie",
    "verres": "verre",
    "verrez": "voir",
    "verriers": "verrier",
    "verriez": "voir",
    "verrions": "voir",
    "verrières": "verrière",
    "verrons": "voir",
    "verront": "voir",
    "verroteries": "verroterie",
    "verrouilla": "verrouiller",
    "verrouillages": "verrouillage",
    "verrouillai": "verrouiller",
    "verrouillaient": "verrouiller",
    "verrouillais": "verrouiller",
    "verrouillait": "verrouiller",
    "verrouillant": "verrouiller",
    "verrouillas": "verrouiller",
    "verrouillasse": "verrouiller",
    "verrouillassent": "verrouiller",
    "verrouillasses": "verrouiller",
    "verrouillassiez": "verrouiller",
    "verrouillassions": "verrouiller",
    "verrouille": "verrouiller",
    "verrouillent": "verrouiller",
    "verrouillera": "verrouiller",
    "verrouillerai": "verrouiller",
    "verrouilleraient": "verrouiller",
    "verrouillerais": "verrouiller",
    "verrouillerait": "verrouiller",
    "verrouilleras": "verrouiller",
    "verrouillerez": "verrouiller",
    "verrouilleriez": "verrouiller",
    "verrouillerions": "verrouiller",
    "verrouillerons": "verrouiller",
    "verrouilleront": "verrouiller",
    "verrouilles": "verrouiller",
    "verrouillez": "verrouiller",
    "verrouilliez": "verrouiller",
    "verrouillions": "verrouiller",
    "verrouillons": "verrouiller",
    "verrouillâmes": "verrouiller",
    "verrouillât": "verrouiller",
    "verrouillâtes": "verrouiller",
    "verrouillèrent": "verrouiller",
    "verrouillé": "verrouiller",
    "verrouillée": "verrouiller",
    "verrouillées": "verrouiller",
    "verrouillés": "verrouiller",
    "verrous": "verrou",
    "verrues": "verrue",
    "verruqueuse": "verruqueux",
    "verruqueuses": "verruqueux",
    "vers": "ver",
    "vers-libristes": "vers-libriste",
    "versa": "verser",
    "versai": "verser",
    "versaient": "verser",
    "versaillaise": "versaillais",
    "versaillaises": "versaillais",
    "versais": "verser",
    "versait": "verser",
    "versant": "verser",
    "versants": "versant",
    "versas": "verser",
    "versasse": "verser",
    "versassent": "verser",
    "versasses": "verser",
    "versassiez": "verser",
    "versassions": "verser",
    "versatiles": "versatile",
    "verse": "verser",
    "verseaux": "verseau",
    "versements": "versement",
    "versent": "verser",
    "versera": "verser",
    "verserai": "verser",
    "verseraient": "verser",
    "verserais": "verser",
    "verserait": "verser",
    "verseras": "verser",
    "verserez": "verser",
    "verseriez": "verser",
    "verserions": "verser",
    "verserons": "verser",
    "verseront": "verser",
    "verses": "verser",
    "versets": "verset",
    "verseurs": "verseur",
    "verseuse": "verseur",
    "verseuses": "verseur",
    "versez": "verser",
    "versicolores": "versicolore",
    "versiculets": "versiculet",
    "versiez": "verser",
    "versifia": "versifier",
    "versifiai": "versifier",
    "versifiaient": "versifier",
    "versifiais": "versifier",
    "versifiait": "versifier",
    "versifiant": "versifier",
    "versifias": "versifier",
    "versifiasse": "versifier",
    "versifiassent": "versifier",
    "versifiasses": "versifier",
    "versifiassiez": "versifier",
    "versifiassions": "versifier",
    "versifie": "versifier",
    "versifient": "versifier",
    "versifiera": "versifier",
    "versifierai": "versifier",
    "versifieraient": "versifier",
    "versifierais": "versifier",
    "versifierait": "versifier",
    "versifieras": "versifier",
    "versifierez": "versifier",
    "versifieriez": "versifier",
    "versifierions": "versifier",
    "versifierons": "versifier",
    "versifieront": "versifier",
    "versifies": "versifier",
    "versifiez": "versifier",
    "versifiiez": "versifier",
    "versifiions": "versifier",
    "versifions": "versifier",
    "versifiâmes": "versifier",
    "versifiât": "versifier",
    "versifiâtes": "versifier",
    "versifièrent": "versifier",
    "versifié": "versifier",
    "versifiée": "versifier",
    "versifiées": "versifier",
    "versifiés": "versifier",
    "versions": "version",
    "versons": "verser",
    "versos": "verso",
    "verstes": "verste",
    "versâmes": "verser",
    "versât": "verser",
    "versâtes": "verser",
    "versèrent": "verser",
    "versé": "verser",
    "versée": "verser",
    "versées": "verser",
    "versés": "verser",
    "vert-de-grisée": "vert-de-grisé",
    "vert-de-grisées": "vert-de-grisé",
    "vert-de-grisés": "vert-de-grisé",
    "verte": "vert",
    "vertes": "vert",
    "verticale": "vertical",
    "verticales": "verticale",
    "verticalités": "verticalité",
    "verticals": "vertical",
    "verticaux": "vertical",
    "vertiges": "vertige",
    "vertigineuse": "vertigineux",
    "vertigineuses": "vertigineux",
    "vertigos": "vertigo",
    "verts": "vert",
    "vertueuse": "vertueux",
    "vertueuses": "vertueux",
    "vertugadins": "vertugadin",
    "vertus": "vertu",
    "vertèbres": "vertèbre",
    "vertébrale": "vertébral",
    "vertébrales": "vertébral",
    "vertébraux": "vertébral",
    "vertébrés": "vertébré",
    "verveines": "verveine",
    "verves": "verve",
    "vesces": "vesce",
    "vesous": "vesou",
    "vespas": "vespa",
    "vespasienne": "vespasien",
    "vespasiennes": "vespasienne",
    "vespérale": "vespéral",
    "vespérales": "vespéral",
    "vespéraux": "vespéral",
    "vesses": "vesse",
    "vesses-de-loup": "vesse-de-loup",
    "vessies": "vessie",
    "vestales": "vestale",
    "vestes": "veste",
    "vestiaires": "vestiaire",
    "vestibules": "vestibule",
    "vestiges": "vestige",
    "vestimentaires": "vestimentaire",
    "vestons": "veston",
    "veufs": "veuf",
    "veuille": "vouloir",
    "veuillent": "vouloir",
    "veuilles": "vouloir",
    "veuillez": "vouloir",
    "veulent": "vouloir",
    "veuleries": "veulerie",
    "veules": "veule",
    "veut": "vouloir",
    "veuvages": "veuvage",
    "veuve": "veuf",
    "veuves": "veuf",
    "veux": "vouloir",
    "vexa": "vexer",
    "vexai": "vexer",
    "vexaient": "vexer",
    "vexais": "vexer",
    "vexait": "vexer",
    "vexant": "vexer",
    "vexante": "vexant",
    "vexantes": "vexant",
    "vexants": "vexant",
    "vexas": "vexer",
    "vexasse": "vexer",
    "vexassent": "vexer",
    "vexasses": "vexer",
    "vexassiez": "vexer",
    "vexassions": "vexer",
    "vexations": "vexation",
    "vexatoires": "vexatoire",
    "vexe": "vexer",
    "vexent": "vexer",
    "vexera": "vexer",
    "vexerai": "vexer",
    "vexeraient": "vexer",
    "vexerais": "vexer",
    "vexerait": "vexer",
    "vexeras": "vexer",
    "vexerez": "vexer",
    "vexeriez": "vexer",
    "vexerions": "vexer",
    "vexerons": "vexer",
    "vexeront": "vexer",
    "vexes": "vexer",
    "vexez": "vexer",
    "vexiez": "vexer",
    "vexilles": "vexille",
    "vexions": "vexer",
    "vexons": "vexer",
    "vexâmes": "vexer",
    "vexât": "vexer",
    "vexâtes": "vexer",
    "vexèrent": "vexer",
    "vexé": "vexer",
    "vexée": "vexer",
    "vexées": "vexer",
    "vexés": "vexer",
    "viabilités": "viabilité",
    "viables": "viable",
    "viaducs": "viaduc",
    "viagers": "viager",
    "viagère": "viager",
    "viagères": "viager",
    "viandasse": "viander",
    "viandes": "viande",
    "viandeuse": "viandeux",
    "viandé": "viander",
    "viatiques": "viatique",
    "vibra": "vibrer",
    "vibrai": "vibrer",
    "vibraient": "vibrer",
    "vibrais": "vibrer",
    "vibrait": "vibrer",
    "vibrant": "vibrer",
    "vibrante": "vibrant",
    "vibrantes": "vibrant",
    "vibrants": "vibrant",
    "vibraphones": "vibraphone",
    "vibras": "vibrer",
    "vibrasse": "vibrer",
    "vibrassent": "vibrer",
    "vibrasses": "vibrer",
    "vibrassiez": "vibrer",
    "vibrassions": "vibrer",
    "vibrateurs": "vibrateur",
    "vibratiles": "vibratile",
    "vibrations": "vibration",
    "vibratoires": "vibratoire",
    "vibratos": "vibrato",
    "vibre": "vibrer",
    "vibrent": "vibrer",
    "vibrera": "vibrer",
    "vibrerai": "vibrer",
    "vibreraient": "vibrer",
    "vibrerais": "vibrer",
    "vibrerait": "vibrer",
    "vibreras": "vibrer",
    "vibrerez": "vibrer",
    "vibreriez": "vibrer",
    "vibrerions": "vibrer",
    "vibrerons": "vibrer",
    "vibreront": "vibrer",
    "vibres": "vibrer",
    "vibrez": "vibrer",
    "vibriez": "vibrer",
    "vibrionnaient": "vibrionner",
    "vibrionnait": "vibrionner",
    "vibrionnant": "vibrionner",
    "vibrionne": "vibrionner",
    "vibrions": "vibrion",
    "vibrisses": "vibrisse",
    "vibromasseurs": "vibromasseur",
    "vibrons": "vibrer",
    "vibrâmes": "vibrer",
    "vibrât": "vibrer",
    "vibrâtes": "vibrer",
    "vibrèrent": "vibrer",
    "vibré": "vibrer",
    "vibrée": "vibrer",
    "vibrées": "vibrer",
    "vibrés": "vibrer",
    "vibura": "viburer",
    "viburait": "viburer",
    "vibure": "viburer",
    "vicaires": "vicaire",
    "vicariances": "vicariance",
    "vicariats": "vicariat",
    "vice-amiraux": "vice-amiral",
    "vice-chanceliers": "vice-chancelier",
    "vice-consuls": "vice-consul",
    "vice-directeurs": "vice-directeur",
    "vice-ministres": "vice-ministre",
    "vice-présidente": "vice-président",
    "vice-présidentes": "vice-président",
    "vice-présidents": "vice-président",
    "vice-recteurs": "vice-recteur",
    "vice-rois": "vice-roi",
    "vice-royautés": "vice-royauté",
    "vicelarde": "vicelard",
    "vicelardes": "vicelard",
    "vicelardises": "vicelardise",
    "vicelards": "vicelard",
    "vicennale": "vicennal",
    "vicennales": "vicennal",
    "vicennaux": "vicennal",
    "vices": "vice",
    "vichys": "vichy",
    "vichyssoise": "vichyssois",
    "vichyssoises": "vichyssois",
    "vichystes": "vichyste",
    "vicia": "vicier",
    "viciai": "vicier",
    "viciaient": "vicier",
    "viciais": "vicier",
    "viciait": "vicier",
    "viciant": "vicier",
    "vicias": "vicier",
    "viciasse": "vicier",
    "viciassent": "vicier",
    "viciasses": "vicier",
    "viciassiez": "vicier",
    "viciassions": "vicier",
    "vicie": "vicier",
    "vicient": "vicier",
    "viciera": "vicier",
    "vicierai": "vicier",
    "vicieraient": "vicier",
    "vicierais": "vicier",
    "vicierait": "vicier",
    "vicieras": "vicier",
    "vicierez": "vicier",
    "vicieriez": "vicier",
    "vicierions": "vicier",
    "vicierons": "vicier",
    "vicieront": "vicier",
    "vicies": "vicier",
    "vicieuse": "vicieux",
    "vicieuses": "vicieux",
    "viciez": "vicier",
    "viciiez": "vicier",
    "viciions": "vicier",
    "vicinale": "vicinal",
    "vicinales": "vicinal",
    "vicinaux": "vicinal",
    "vicions": "vicier",
    "vicissitudes": "vicissitude",
    "viciâmes": "vicier",
    "viciât": "vicier",
    "viciâtes": "vicier",
    "vicièrent": "vicier",
    "vicié": "vicier",
    "viciée": "vicier",
    "viciées": "vicier",
    "viciés": "vicier",
    "vicomtes": "vicomte",
    "vicomtesse": "vicomte",
    "vicomtesses": "vicomte",
    "vicomtés": "vicomté",
    "victimes": "victime",
    "victoires": "victoire",
    "victorias": "victoria",
    "victorienne": "victorien",
    "victoriennes": "victorien",
    "victoriens": "victorien",
    "victorieuse": "victorieux",
    "victorieuses": "victorieux",
    "victuailles": "victuaille",
    "vicésimale": "vicésimal",
    "vicésimales": "vicésimal",
    "vicésimaux": "vicésimal",
    "vida": "vider",
    "vidai": "vider",
    "vidaient": "vider",
    "vidais": "vider",
    "vidait": "vider",
    "vidames": "vidame",
    "vidange": "vidanger",
    "vidangea": "vidanger",
    "vidangeai": "vidanger",
    "vidangeaient": "vidanger",
    "vidangeais": "vidanger",
    "vidangeait": "vidanger",
    "vidangeant": "vidanger",
    "vidangeas": "vidanger",
    "vidangeasse": "vidanger",
    "vidangeassent": "vidanger",
    "vidangeasses": "vidanger",
    "vidangeassiez": "vidanger",
    "vidangeassions": "vidanger",
    "vidangent": "vidanger",
    "vidangeons": "vidanger",
    "vidangera": "vidanger",
    "vidangerai": "vidanger",
    "vidangeraient": "vidanger",
    "vidangerais": "vidanger",
    "vidangerait": "vidanger",
    "vidangeras": "vidanger",
    "vidangerez": "vidanger",
    "vidangeriez": "vidanger",
    "vidangerions": "vidanger",
    "vidangerons": "vidanger",
    "vidangeront": "vidanger",
    "vidanges": "vidanger",
    "vidangeurs": "vidangeur",
    "vidangez": "vidanger",
    "vidangeâmes": "vidanger",
    "vidangeât": "vidanger",
    "vidangeâtes": "vidanger",
    "vidangiez": "vidanger",
    "vidangions": "vidanger",
    "vidangèrent": "vidanger",
    "vidangé": "vidanger",
    "vidangée": "vidanger",
    "vidangées": "vidanger",
    "vidangés": "vidanger",
    "vidant": "vider",
    "vidas": "vider",
    "vidasse": "vider",
    "vidassent": "vider",
    "vidasses": "vider",
    "vidassiez": "vider",
    "vidassions": "vider",
    "vide": "vider",
    "vide-bouteilles": "vide-bouteille",
    "vide-caves": "vide-cave",
    "vide-poches": "vide-poche",
    "vide-pommes": "vide-pomme",
    "vident": "vider",
    "videra": "vider",
    "viderai": "vider",
    "videraient": "vider",
    "viderais": "vider",
    "viderait": "vider",
    "videras": "vider",
    "viderez": "vider",
    "videriez": "vider",
    "viderions": "vider",
    "viderons": "vider",
    "videront": "vider",
    "vides": "vider",
    "videurs": "videur",
    "videz": "vider",
    "vidiez": "vider",
    "vidions": "vider",
    "vidons": "vider",
    "viduités": "viduité",
    "vidures": "vidure",
    "vidâmes": "vider",
    "vidât": "vider",
    "vidâtes": "vider",
    "vidèrent": "vider",
    "vidé": "vider",
    "vidéastes": "vidéaste",
    "vidée": "vider",
    "vidées": "vider",
    "vidéo-clips": "vidéo-clip",
    "vidéocassettes": "vidéocassette",
    "vidéodisques": "vidéodisque",
    "vidéogrammes": "vidéogramme",
    "vidéophones": "vidéophone",
    "vidéos": "vidéo",
    "vidéothèques": "vidéothèque",
    "vidéotéléphones": "vidéotéléphone",
    "vidés": "vider",
    "vieil": "vieux",
    "vieillarde": "vieillard",
    "vieillardes": "vieillard",
    "vieillards": "vieillard",
    "vieille": "vieux",
    "vieilleries": "vieillerie",
    "vieilles": "vieux",
    "vieillesses": "vieillesse",
    "vieilli": "vieillir",
    "vieillie": "vieillir",
    "vieillies": "vieillir",
    "vieillira": "vieillir",
    "vieillirai": "vieillir",
    "vieilliraient": "vieillir",
    "vieillirais": "vieillir",
    "vieillirait": "vieillir",
    "vieilliras": "vieillir",
    "vieillirent": "vieillir",
    "vieillirez": "vieillir",
    "vieilliriez": "vieillir",
    "vieillirions": "vieillir",
    "vieillirons": "vieillir",
    "vieilliront": "vieillir",
    "vieillis": "vieillir",
    "vieillissaient": "vieillir",
    "vieillissais": "vieillir",
    "vieillissait": "vieillir",
    "vieillissant": "vieillir",
    "vieillissante": "vieillissant",
    "vieillissantes": "vieillissant",
    "vieillissants": "vieillissant",
    "vieillisse": "vieillir",
    "vieillissements": "vieillissement",
    "vieillissent": "vieillir",
    "vieillisses": "vieillir",
    "vieillissez": "vieillir",
    "vieillissiez": "vieillir",
    "vieillissions": "vieillir",
    "vieillissons": "vieillir",
    "vieillit": "vieillir",
    "vieillots": "vieillot",
    "vieillotte": "vieillot",
    "vieillottes": "vieillot",
    "vieillîmes": "vieillir",
    "vieillît": "vieillir",
    "vieillîtes": "vieillir",
    "vielles": "vielle",
    "viendra": "venir",
    "viendrai": "venir",
    "viendraient": "venir",
    "viendrais": "venir",
    "viendrait": "venir",
    "viendras": "venir",
    "viendrez": "venir",
    "viendriez": "venir",
    "viendrions": "venir",
    "viendrons": "venir",
    "viendront": "venir",
    "vienne": "venir",
    "viennent": "venir",
    "viennes": "venir",
    "viennoise": "viennois",
    "viennoiseries": "viennoiserie",
    "viennoises": "viennois",
    "viens": "venir",
    "vient": "venir",
    "vierges": "vierge",
    "vies": "vie",
    "vietnamienne": "vietnamien",
    "vietnamiennes": "vietnamien",
    "vietnamiens": "vietnamien",
    "vifs": "vif",
    "vifs-argents": "vif-argent",
    "vigies": "vigie",
    "vigilances": "vigilance",
    "vigilant": "vigiler",
    "vigilante": "vigilant",
    "vigilantes": "vigilant",
    "vigilants": "vigilant",
    "vigile": "vigil",
    "vigiles": "vigile",
    "vigneaux": "vigneau",
    "vigneronne": "vigneron",
    "vigneronnes": "vigneron",
    "vignerons": "vigneron",
    "vignes": "vigne",
    "vignettes": "vignette",
    "vignobles": "vignoble",
    "vignots": "vignot",
    "vigognes": "vigogne",
    "vigoureuse": "vigoureux",
    "vigoureuses": "vigoureux",
    "vigueurs": "vigueur",
    "viguiers": "viguier",
    "vikings": "viking",
    "vilaine": "vilain",
    "vilaines": "vilain",
    "vilains": "vilain",
    "vile": "vil",
    "vilebrequins": "vilebrequin",
    "vilenies": "vilenie",
    "viles": "vil",
    "vilipenda": "vilipender",
    "vilipendai": "vilipender",
    "vilipendaient": "vilipender",
    "vilipendais": "vilipender",
    "vilipendait": "vilipender",
    "vilipendant": "vilipender",
    "vilipendas": "vilipender",
    "vilipendasse": "vilipender",
    "vilipendassent": "vilipender",
    "vilipendasses": "vilipender",
    "vilipendassiez": "vilipender",
    "vilipendassions": "vilipender",
    "vilipende": "vilipender",
    "vilipendent": "vilipender",
    "vilipendera": "vilipender",
    "vilipenderai": "vilipender",
    "vilipenderaient": "vilipender",
    "vilipenderais": "vilipender",
    "vilipenderait": "vilipender",
    "vilipenderas": "vilipender",
    "vilipenderez": "vilipender",
    "vilipenderiez": "vilipender",
    "vilipenderions": "vilipender",
    "vilipenderons": "vilipender",
    "vilipenderont": "vilipender",
    "vilipendes": "vilipender",
    "vilipendez": "vilipender",
    "vilipendiez": "vilipender",
    "vilipendions": "vilipender",
    "vilipendons": "vilipender",
    "vilipendâmes": "vilipender",
    "vilipendât": "vilipender",
    "vilipendâtes": "vilipender",
    "vilipendèrent": "vilipender",
    "vilipendé": "vilipender",
    "vilipendée": "vilipender",
    "vilipendées": "vilipender",
    "vilipendés": "vilipender",
    "villageoise": "villageois",
    "villageoises": "villageois",
    "villages": "village",
    "villanelles": "villanelle",
    "villas": "villa",
    "villes": "ville",
    "villes-champignons": "ville-champignon",
    "villes-clés": "villes-clé",
    "villes-dortoirs": "ville-dortoir",
    "villeuse": "villeux",
    "villeuses": "villeux",
    "villosités": "villosité",
    "villégiaturait": "villégiaturer",
    "villégiatures": "villégiature",
    "villégiaturé": "villégiaturer",
    "vils": "vil",
    "vina": "viner",
    "vinai": "viner",
    "vinaient": "viner",
    "vinaigre": "vinaigrer",
    "vinaigres": "vinaigre",
    "vinaigrettes": "vinaigrette",
    "vinaigré": "vinaigrer",
    "vinaigrée": "vinaigrer",
    "vinais": "viner",
    "vinait": "viner",
    "vinant": "viner",
    "vinas": "viner",
    "vinasse": "viner",
    "vinassent": "viner",
    "vinasses": "viner",
    "vinassiez": "viner",
    "vinassions": "viner",
    "vindicatifs": "vindicatif",
    "vindicative": "vindicatif",
    "vindicatives": "vindicatif",
    "vindictes": "vindicte",
    "vine": "viner",
    "vinent": "viner",
    "vinera": "viner",
    "vinerai": "viner",
    "vineraient": "viner",
    "vinerais": "viner",
    "vinerait": "viner",
    "vineras": "viner",
    "vinerez": "viner",
    "vineriez": "viner",
    "vinerions": "viner",
    "vinerons": "viner",
    "vineront": "viner",
    "vines": "viner",
    "vineuse": "vineux",
    "vineuses": "vineux",
    "vinez": "viner",
    "vingt-et-une": "vingt-et-un",
    "vingt-et-unièmes": "vingt-et-unième",
    "vingtaines": "vingtaine",
    "vingtièmes": "vingtième",
    "vinicoles": "vinicole",
    "viniez": "viner",
    "vinifications": "vinification",
    "vinificatrice": "vinificateur",
    "vinions": "viner",
    "vinons": "viner",
    "vinrent": "venir",
    "vins": "vin",
    "vinsse": "venir",
    "vinssent": "venir",
    "vinsses": "venir",
    "vinssiez": "venir",
    "vinssions": "venir",
    "vint": "venir",
    "vinyles": "vinyle",
    "vinâmes": "viner",
    "vinât": "viner",
    "vinâtes": "viner",
    "vinèrent": "viner",
    "viné": "viner",
    "vinée": "viner",
    "vinées": "viner",
    "vinés": "viner",
    "viocs": "vioc",
    "viola": "violer",
    "violacé": "violacer",
    "violacée": "violacer",
    "violacées": "violacer",
    "violacés": "violacer",
    "violai": "violer",
    "violaient": "violer",
    "violais": "violer",
    "violait": "violer",
    "violant": "violer",
    "violas": "violer",
    "violasse": "violer",
    "violassent": "violer",
    "violasses": "violer",
    "violassiez": "violer",
    "violassions": "violer",
    "violations": "violation",
    "violaçait": "violacer",
    "viole": "violer",
    "violences": "violence",
    "violent": "violer",
    "violentaient": "violenter",
    "violentait": "violenter",
    "violente": "violenter",
    "violentes": "violent",
    "violents": "violent",
    "violenté": "violenter",
    "violentée": "violenter",
    "violera": "violer",
    "violerai": "violer",
    "violeraient": "violer",
    "violerais": "violer",
    "violerait": "violer",
    "violeras": "violer",
    "violerez": "violer",
    "violeriez": "violer",
    "violerions": "violer",
    "violerons": "violer",
    "violeront": "violer",
    "violes": "violer",
    "violeta": "violeter",
    "violets": "violet",
    "violette": "violet",
    "violettes": "violette",
    "violeurs": "violeur",
    "violeuses": "violeur",
    "violez": "violer",
    "violiez": "violer",
    "violines": "violine",
    "violions": "violer",
    "violoncelles": "violoncelle",
    "violoncellistes": "violoncelliste",
    "violone": "violoner",
    "violonistes": "violoniste",
    "violons": "violon",
    "viols": "viol",
    "violâmes": "violer",
    "violât": "violer",
    "violâtes": "violer",
    "violâtres": "violâtre",
    "violèrent": "violer",
    "violé": "violer",
    "violée": "violer",
    "violées": "violer",
    "violés": "violer",
    "vioques": "vioque",
    "viornes": "viorne",
    "vipereaux": "vipereau",
    "vipères": "vipère",
    "vipéreaux": "vipéreau",
    "vipérine": "vipérin",
    "vipérines": "vipérin",
    "vipérins": "vipérin",
    "vira": "virer",
    "virages": "virage",
    "viragos": "virago",
    "virai": "virer",
    "viraient": "virer",
    "virais": "virer",
    "virait": "virer",
    "virale": "viral",
    "virales": "viral",
    "virant": "virer",
    "viras": "virer",
    "virasse": "virer",
    "virassent": "virer",
    "virasses": "virer",
    "virassiez": "virer",
    "virassions": "virer",
    "viraux": "viral",
    "vire": "virer",
    "virelais": "virelai",
    "virements": "virement",
    "virent": "voir",
    "virera": "virer",
    "virerai": "virer",
    "vireraient": "virer",
    "virerais": "virer",
    "virerait": "virer",
    "vireras": "virer",
    "virerez": "virer",
    "vireriez": "virer",
    "virerions": "virer",
    "virerons": "virer",
    "vireront": "virer",
    "vires": "virer",
    "vireuse": "vireux",
    "virevolta": "virevolter",
    "virevoltaient": "virevolter",
    "virevoltait": "virevolter",
    "virevoltant": "virevolter",
    "virevoltante": "virevoltant",
    "virevoltantes": "virevoltant",
    "virevoltants": "virevoltant",
    "virevolte": "virevolter",
    "virevoltent": "virevolter",
    "virevoltes": "virevolter",
    "virevolté": "virevolter",
    "virez": "virer",
    "virgilienne": "virgilien",
    "virginale": "virginal",
    "virginales": "virginal",
    "virginals": "virginal",
    "virginaux": "virginal",
    "virginiens": "virginien",
    "virginies": "virginie",
    "virginités": "virginité",
    "virgules": "virgule",
    "viriez": "virer",
    "virile": "viril",
    "viriles": "viril",
    "virilise": "viriliser",
    "virilisé": "viriliser",
    "virilisés": "viriliser",
    "virilités": "virilité",
    "virilocale": "virilocal",
    "virilocales": "virilocal",
    "virilocaux": "virilocal",
    "virils": "viril",
    "virions": "virer",
    "viroles": "virole",
    "virologues": "virologue",
    "virons": "virer",
    "virtualités": "virtualité",
    "virtuelle": "virtuel",
    "virtuelles": "virtuel",
    "virtuels": "virtuel",
    "virtuoses": "virtuose",
    "virtuosités": "virtuosité",
    "virulences": "virulence",
    "virulente": "virulent",
    "virulentes": "virulent",
    "virulents": "virulent",
    "virures": "virure",
    "virâmes": "virer",
    "virât": "virer",
    "virâtes": "virer",
    "virèrent": "virer",
    "viré": "virer",
    "virée": "virer",
    "virées": "virer",
    "virés": "virer",
    "vis": "voir",
    "visa": "viser",
    "visages": "visage",
    "visai": "viser",
    "visaient": "viser",
    "visais": "viser",
    "visait": "viser",
    "visant": "viser",
    "visas": "viser",
    "visasse": "viser",
    "visassent": "viser",
    "visasses": "viser",
    "visassiez": "viser",
    "visassions": "viser",
    "viscaches": "viscache",
    "viscoses": "viscose",
    "viscosités": "viscosité",
    "viscères": "viscère",
    "viscérale": "viscéral",
    "viscérales": "viscéral",
    "viscéraux": "viscéral",
    "vise": "viser",
    "visent": "viser",
    "visera": "viser",
    "viserai": "viser",
    "viseraient": "viser",
    "viserais": "viser",
    "viserait": "viser",
    "viseras": "viser",
    "viserez": "viser",
    "viseriez": "viser",
    "viserions": "viser",
    "viserons": "viser",
    "viseront": "viser",
    "vises": "viser",
    "viseurs": "viseur",
    "visez": "viser",
    "visibilités": "visibilité",
    "visibles": "visible",
    "visiez": "viser",
    "visionna": "visionner",
    "visionnai": "visionner",
    "visionnaient": "visionner",
    "visionnaires": "visionnaire",
    "visionnais": "visionner",
    "visionnait": "visionner",
    "visionnant": "visionner",
    "visionnas": "visionner",
    "visionnasse": "visionner",
    "visionnassent": "visionner",
    "visionnasses": "visionner",
    "visionnassiez": "visionner",
    "visionnassions": "visionner",
    "visionne": "visionner",
    "visionnent": "visionner",
    "visionnera": "visionner",
    "visionnerai": "visionner",
    "visionneraient": "visionner",
    "visionnerais": "visionner",
    "visionnerait": "visionner",
    "visionneras": "visionner",
    "visionnerez": "visionner",
    "visionneriez": "visionner",
    "visionnerions": "visionner",
    "visionnerons": "visionner",
    "visionneront": "visionner",
    "visionnes": "visionner",
    "visionneuse": "visionneur",
    "visionnez": "visionner",
    "visionniez": "visionner",
    "visionnions": "visionner",
    "visionnons": "visionner",
    "visionnâmes": "visionner",
    "visionnât": "visionner",
    "visionnâtes": "visionner",
    "visionnèrent": "visionner",
    "visionné": "visionner",
    "visionnée": "visionner",
    "visionnées": "visionner",
    "visionnés": "visionner",
    "visions": "vision",
    "visita": "visiter",
    "visitai": "visiter",
    "visitaient": "visiter",
    "visitais": "visiter",
    "visitait": "visiter",
    "visitandines": "visitandine",
    "visitant": "visiter",
    "visitas": "visiter",
    "visitasse": "visiter",
    "visitassent": "visiter",
    "visitasses": "visiter",
    "visitassiez": "visiter",
    "visitassions": "visiter",
    "visite": "visiter",
    "visitent": "visiter",
    "visitera": "visiter",
    "visiterai": "visiter",
    "visiteraient": "visiter",
    "visiterais": "visiter",
    "visiterait": "visiter",
    "visiteras": "visiter",
    "visiterez": "visiter",
    "visiteriez": "visiter",
    "visiterions": "visiter",
    "visiterons": "visiter",
    "visiteront": "visiter",
    "visites": "visiter",
    "visiteurs": "visiteur",
    "visiteuse": "visiteur",
    "visiteuses": "visiteur",
    "visitez": "visiter",
    "visitiez": "visiter",
    "visitions": "visiter",
    "visitons": "visiter",
    "visitâmes": "visiter",
    "visitât": "visiter",
    "visitâtes": "visiter",
    "visitèrent": "visiter",
    "visité": "visiter",
    "visitée": "visiter",
    "visitées": "visiter",
    "visités": "visiter",
    "visières": "visière",
    "visons": "vison",
    "visqueuse": "visqueux",
    "visqueuses": "visqueux",
    "vissa": "visser",
    "vissai": "visser",
    "vissaient": "visser",
    "vissais": "visser",
    "vissait": "visser",
    "vissant": "visser",
    "vissas": "visser",
    "vissasse": "visser",
    "vissassent": "visser",
    "vissasses": "visser",
    "vissassiez": "visser",
    "vissassions": "visser",
    "visse": "voir",
    "vissent": "voir",
    "vissera": "visser",
    "visserai": "visser",
    "visseraient": "visser",
    "visserais": "visser",
    "visserait": "visser",
    "visseras": "visser",
    "visserez": "visser",
    "visseriez": "visser",
    "visserions": "visser",
    "visserons": "visser",
    "visseront": "visser",
    "visses": "voir",
    "vissez": "visser",
    "vissiez": "voir",
    "vissions": "voir",
    "vissons": "visser",
    "vissâmes": "visser",
    "vissât": "visser",
    "vissâtes": "visser",
    "vissèrent": "visser",
    "vissé": "visser",
    "vissée": "visser",
    "vissées": "visser",
    "vissés": "visser",
    "visualisa": "visualiser",
    "visualisai": "visualiser",
    "visualisaient": "visualiser",
    "visualisais": "visualiser",
    "visualisait": "visualiser",
    "visualisant": "visualiser",
    "visualisas": "visualiser",
    "visualisasse": "visualiser",
    "visualisassent": "visualiser",
    "visualisasses": "visualiser",
    "visualisassiez": "visualiser",
    "visualisassions": "visualiser",
    "visualise": "visualiser",
    "visualisent": "visualiser",
    "visualisera": "visualiser",
    "visualiserai": "visualiser",
    "visualiseraient": "visualiser",
    "visualiserais": "visualiser",
    "visualiserait": "visualiser",
    "visualiseras": "visualiser",
    "visualiserez": "visualiser",
    "visualiseriez": "visualiser",
    "visualiserions": "visualiser",
    "visualiserons": "visualiser",
    "visualiseront": "visualiser",
    "visualises": "visualiser",
    "visualisez": "visualiser",
    "visualisiez": "visualiser",
    "visualisions": "visualiser",
    "visualisons": "visualiser",
    "visualisâmes": "visualiser",
    "visualisât": "visualiser",
    "visualisâtes": "visualiser",
    "visualisèrent": "visualiser",
    "visualisé": "visualiser",
    "visualisée": "visualiser",
    "visualisées": "visualiser",
    "visualisés": "visualiser",
    "visuelle": "visuel",
    "visuelles": "visuel",
    "visuels": "visuel",
    "visâmes": "viser",
    "visât": "viser",
    "visâtes": "viser",
    "visèrent": "viser",
    "visé": "viser",
    "visée": "viser",
    "visées": "viser",
    "visés": "viser",
    "vit": "voir",
    "vitale": "vital",
    "vitales": "vital",
    "vitalités": "vitalité",
    "vitamines": "vitamine",
    "vitaminée": "vitaminé",
    "vitaminées": "vitaminé",
    "vitaminés": "vitaminé",
    "vitaux": "vital",
    "vitelline": "vitellin",
    "vitellines": "vitellin",
    "vitellins": "vitellin",
    "vitesses": "vitesse",
    "viticoles": "viticole",
    "viticulteurs": "viticulteur",
    "viticultrice": "viticulteur",
    "viticultrices": "viticulteur",
    "viticultures": "viticulture",
    "vitivinicoles": "vitivinicole",
    "vitrages": "vitrage",
    "vitraux": "vitrail",
    "vitre": "vitrer",
    "vitres": "vitrer",
    "vitreuse": "vitreux",
    "vitreuses": "vitreux",
    "vitriers": "vitrier",
    "vitrifia": "vitrifier",
    "vitrifiai": "vitrifier",
    "vitrifiaient": "vitrifier",
    "vitrifiais": "vitrifier",
    "vitrifiait": "vitrifier",
    "vitrifiant": "vitrifier",
    "vitrifias": "vitrifier",
    "vitrifiasse": "vitrifier",
    "vitrifiassent": "vitrifier",
    "vitrifiasses": "vitrifier",
    "vitrifiassiez": "vitrifier",
    "vitrifiassions": "vitrifier",
    "vitrifie": "vitrifier",
    "vitrifient": "vitrifier",
    "vitrifiera": "vitrifier",
    "vitrifierai": "vitrifier",
    "vitrifieraient": "vitrifier",
    "vitrifierais": "vitrifier",
    "vitrifierait": "vitrifier",
    "vitrifieras": "vitrifier",
    "vitrifierez": "vitrifier",
    "vitrifieriez": "vitrifier",
    "vitrifierions": "vitrifier",
    "vitrifierons": "vitrifier",
    "vitrifieront": "vitrifier",
    "vitrifies": "vitrifier",
    "vitrifiez": "vitrifier",
    "vitrifiiez": "vitrifier",
    "vitrifiions": "vitrifier",
    "vitrifions": "vitrifier",
    "vitrifiâmes": "vitrifier",
    "vitrifiât": "vitrifier",
    "vitrifiâtes": "vitrifier",
    "vitrifièrent": "vitrifier",
    "vitrifié": "vitrifier",
    "vitrifiée": "vitrifier",
    "vitrifiées": "vitrifier",
    "vitrifiés": "vitrifier",
    "vitrines": "vitrine",
    "vitrioleurs": "vitrioleur",
    "vitriols": "vitriol",
    "vitriolé": "vitrioler",
    "vitré": "vitrer",
    "vitrée": "vitrer",
    "vitrées": "vitrer",
    "vitrés": "vitrer",
    "vits": "vit",
    "vitupère": "vitupérer",
    "vitupèrent": "vitupérer",
    "vitupères": "vitupérer",
    "vitupéra": "vitupérer",
    "vitupérai": "vitupérer",
    "vitupéraient": "vitupérer",
    "vitupérais": "vitupérer",
    "vitupérait": "vitupérer",
    "vitupérant": "vitupérer",
    "vitupéras": "vitupérer",
    "vitupérasse": "vitupérer",
    "vitupérassent": "vitupérer",
    "vitupérasses": "vitupérer",
    "vitupérassiez": "vitupérer",
    "vitupérassions": "vitupérer",
    "vitupérations": "vitupération",
    "vitupérera": "vitupérer",
    "vitupérerai": "vitupérer",
    "vitupéreraient": "vitupérer",
    "vitupérerais": "vitupérer",
    "vitupérerait": "vitupérer",
    "vitupéreras": "vitupérer",
    "vitupérerez": "vitupérer",
    "vitupéreriez": "vitupérer",
    "vitupérerions": "vitupérer",
    "vitupérerons": "vitupérer",
    "vitupéreront": "vitupérer",
    "vitupérez": "vitupérer",
    "vitupériez": "vitupérer",
    "vitupérions": "vitupérer",
    "vitupérons": "vitupérer",
    "vitupérâmes": "vitupérer",
    "vitupérât": "vitupérer",
    "vitupérâtes": "vitupérer",
    "vitupérèrent": "vitupérer",
    "vitupéré": "vitupérer",
    "vitupérée": "vitupérer",
    "vitupérées": "vitupérer",
    "vitupérés": "vitupérer",
    "vivables": "vivable",
    "vivaces": "vivace",
    "vivacités": "vivacité",
    "vivaient": "vivre",
    "vivais": "vivre",
    "vivait": "vivre",
    "vivandiers": "vivandier",
    "vivandière": "vivandier",
    "vivandières": "vivandier",
    "vivant": "vivre",
    "vivante": "vivant",
    "vivantes": "vivant",
    "vivants": "vivant",
    "vivariums": "vivarium",
    "vivats": "vivat",
    "vive": "vivre",
    "vivent": "vivre",
    "vives": "vivre",
    "vives-eaux": "vive-eau",
    "viveurs": "viveur",
    "viveuse": "viveur",
    "viveuses": "viveur",
    "vivez": "vivre",
    "viviers": "vivier",
    "viviez": "vivre",
    "vivifia": "vivifier",
    "vivifiai": "vivifier",
    "vivifiaient": "vivifier",
    "vivifiais": "vivifier",
    "vivifiait": "vivifier",
    "vivifiant": "vivifier",
    "vivifiante": "vivifiant",
    "vivifiantes": "vivifiant",
    "vivifiants": "vivifiant",
    "vivifias": "vivifier",
    "vivifiasse": "vivifier",
    "vivifiassent": "vivifier",
    "vivifiasses": "vivifier",
    "vivifiassiez": "vivifier",
    "vivifiassions": "vivifier",
    "vivifie": "vivifier",
    "vivifient": "vivifier",
    "vivifiera": "vivifier",
    "vivifierai": "vivifier",
    "vivifieraient": "vivifier",
    "vivifierais": "vivifier",
    "vivifierait": "vivifier",
    "vivifieras": "vivifier",
    "vivifierez": "vivifier",
    "vivifieriez": "vivifier",
    "vivifierions": "vivifier",
    "vivifierons": "vivifier",
    "vivifieront": "vivifier",
    "vivifies": "vivifier",
    "vivifiez": "vivifier",
    "vivifiiez": "vivifier",
    "vivifiions": "vivifier",
    "vivifions": "vivifier",
    "vivifiâmes": "vivifier",
    "vivifiât": "vivifier",
    "vivifiâtes": "vivifier",
    "vivifièrent": "vivifier",
    "vivifié": "vivifier",
    "vivifiée": "vivifier",
    "vivifiées": "vivifier",
    "vivifiés": "vivifier",
    "vivions": "vivre",
    "vivipares": "vivipare",
    "vivisections": "vivisection",
    "vivons": "vivre",
    "vivota": "vivoter",
    "vivotai": "vivoter",
    "vivotaient": "vivoter",
    "vivotais": "vivoter",
    "vivotait": "vivoter",
    "vivotant": "vivoter",
    "vivotas": "vivoter",
    "vivotasse": "vivoter",
    "vivotassent": "vivoter",
    "vivotasses": "vivoter",
    "vivotassiez": "vivoter",
    "vivotassions": "vivoter",
    "vivote": "vivoter",
    "vivotent": "vivoter",
    "vivotera": "vivoter",
    "vivoterai": "vivoter",
    "vivoteraient": "vivoter",
    "vivoterais": "vivoter",
    "vivoterait": "vivoter",
    "vivoteras": "vivoter",
    "vivoterez": "vivoter",
    "vivoteriez": "vivoter",
    "vivoterions": "vivoter",
    "vivoterons": "vivoter",
    "vivoteront": "vivoter",
    "vivotes": "vivoter",
    "vivotez": "vivoter",
    "vivotiez": "vivoter",
    "vivotions": "vivoter",
    "vivotons": "vivoter",
    "vivotâmes": "vivoter",
    "vivotât": "vivoter",
    "vivotâtes": "vivoter",
    "vivotèrent": "vivoter",
    "vivoté": "vivoter",
    "vivra": "vivre",
    "vivrai": "vivre",
    "vivraient": "vivre",
    "vivrais": "vivre",
    "vivrait": "vivre",
    "vivras": "vivre",
    "vivres": "vivre",
    "vivrez": "vivre",
    "vivriers": "vivrier",
    "vivriez": "vivre",
    "vivrions": "vivre",
    "vivrons": "vivre",
    "vivront": "vivre",
    "vizirs": "vizir",
    "vocables": "vocable",
    "vocabulaires": "vocabulaire",
    "vocale": "vocal",
    "vocales": "vocal",
    "vocalisa": "vocaliser",
    "vocalisai": "vocaliser",
    "vocalisaient": "vocaliser",
    "vocalisais": "vocaliser",
    "vocalisait": "vocaliser",
    "vocalisant": "vocaliser",
    "vocalisas": "vocaliser",
    "vocalisasse": "vocaliser",
    "vocalisassent": "vocaliser",
    "vocalisasses": "vocaliser",
    "vocalisassiez": "vocaliser",
    "vocalisassions": "vocaliser",
    "vocalisations": "vocalisation",
    "vocalise": "vocaliser",
    "vocalisent": "vocaliser",
    "vocalisera": "vocaliser",
    "vocaliserai": "vocaliser",
    "vocaliseraient": "vocaliser",
    "vocaliserais": "vocaliser",
    "vocaliserait": "vocaliser",
    "vocaliseras": "vocaliser",
    "vocaliserez": "vocaliser",
    "vocaliseriez": "vocaliser",
    "vocaliserions": "vocaliser",
    "vocaliserons": "vocaliser",
    "vocaliseront": "vocaliser",
    "vocalises": "vocaliser",
    "vocalisez": "vocaliser",
    "vocalisiez": "vocaliser",
    "vocalisions": "vocaliser",
    "vocalismes": "vocalisme",
    "vocalisons": "vocaliser",
    "vocalisâmes": "vocaliser",
    "vocalisât": "vocaliser",
    "vocalisâtes": "vocaliser",
    "vocalisèrent": "vocaliser",
    "vocalisé": "vocaliser",
    "vocalisée": "vocaliser",
    "vocalisées": "vocaliser",
    "vocalisés": "vocaliser",
    "vocatifs": "vocatif",
    "vocations": "vocation",
    "vocaux": "vocal",
    "voceratrices": "voceratrice",
    "voceri": "vocero",
    "vocifère": "vociférer",
    "vocifèrent": "vociférer",
    "vocifères": "vociférer",
    "vociféra": "vociférer",
    "vociférai": "vociférer",
    "vociféraient": "vociférer",
    "vociférais": "vociférer",
    "vociférait": "vociférer",
    "vociférant": "vociférer",
    "vociférante": "vociférant",
    "vociférantes": "vociférant",
    "vociférants": "vociférant",
    "vociféras": "vociférer",
    "vociférasse": "vociférer",
    "vociférassent": "vociférer",
    "vociférasses": "vociférer",
    "vociférassiez": "vociférer",
    "vociférassions": "vociférer",
    "vociférations": "vocifération",
    "vociférera": "vociférer",
    "vociférerai": "vociférer",
    "vociféreraient": "vociférer",
    "vociférerais": "vociférer",
    "vociférerait": "vociférer",
    "vociféreras": "vociférer",
    "vociférerez": "vociférer",
    "vociféreriez": "vociférer",
    "vociférerions": "vociférer",
    "vociférerons": "vociférer",
    "vociféreront": "vociférer",
    "vociférez": "vociférer",
    "vocifériez": "vociférer",
    "vociférions": "vociférer",
    "vociférons": "vociférer",
    "vociférâmes": "vociférer",
    "vociférât": "vociférer",
    "vociférâtes": "vociférer",
    "vociférèrent": "vociférer",
    "vociféré": "vociférer",
    "vociférée": "vociférer",
    "vociférées": "vociférer",
    "vociférés": "vociférer",
    "vodkas": "vodka",
    "vodous": "vodou",
    "voeux": "voeu",
    "vogua": "voguer",
    "voguai": "voguer",
    "voguaient": "voguer",
    "voguais": "voguer",
    "voguait": "voguer",
    "voguant": "voguer",
    "voguas": "voguer",
    "voguasse": "voguer",
    "voguassent": "voguer",
    "voguasses": "voguer",
    "voguassiez": "voguer",
    "voguassions": "voguer",
    "vogue": "voguer",
    "voguent": "voguer",
    "voguera": "voguer",
    "voguerai": "voguer",
    "vogueraient": "voguer",
    "voguerais": "voguer",
    "voguerait": "voguer",
    "vogueras": "voguer",
    "voguerez": "voguer",
    "vogueriez": "voguer",
    "voguerions": "voguer",
    "voguerons": "voguer",
    "vogueront": "voguer",
    "vogues": "voguer",
    "voguez": "voguer",
    "voguiez": "voguer",
    "voguions": "voguer",
    "voguons": "voguer",
    "voguâmes": "voguer",
    "voguât": "voguer",
    "voguâtes": "voguer",
    "voguèrent": "voguer",
    "vogué": "voguer",
    "voie": "voir",
    "voient": "voir",
    "voieries": "voierie",
    "voies": "voir",
    "voila": "voiler",
    "voilages": "voilage",
    "voilai": "voiler",
    "voilaient": "voiler",
    "voilais": "voiler",
    "voilait": "voiler",
    "voilant": "voiler",
    "voilas": "voiler",
    "voilasse": "voiler",
    "voilassent": "voiler",
    "voilasses": "voiler",
    "voilassiez": "voiler",
    "voilassions": "voiler",
    "voile": "voiler",
    "voilent": "voiler",
    "voilera": "voiler",
    "voilerai": "voiler",
    "voileraient": "voiler",
    "voilerais": "voiler",
    "voilerait": "voiler",
    "voileras": "voiler",
    "voilerez": "voiler",
    "voileriez": "voiler",
    "voilerions": "voiler",
    "voilerons": "voiler",
    "voileront": "voiler",
    "voiles": "voiler",
    "voilettes": "voilette",
    "voilez": "voiler",
    "voiliers": "voilier",
    "voiliez": "voiler",
    "voilions": "voiler",
    "voilons": "voiler",
    "voilures": "voilure",
    "voilâmes": "voiler",
    "voilât": "voiler",
    "voilâtes": "voiler",
    "voilèrent": "voiler",
    "voilé": "voiler",
    "voilée": "voiler",
    "voilées": "voiler",
    "voilés": "voiler",
    "voiries": "voirie",
    "vois": "voir",
    "voisina": "voisiner",
    "voisinages": "voisinage",
    "voisinai": "voisiner",
    "voisinaient": "voisiner",
    "voisinais": "voisiner",
    "voisinait": "voisiner",
    "voisinant": "voisiner",
    "voisinas": "voisiner",
    "voisinasse": "voisiner",
    "voisinassent": "voisiner",
    "voisinasses": "voisiner",
    "voisinassiez": "voisiner",
    "voisinassions": "voisiner",
    "voisine": "voisiner",
    "voisinent": "voisiner",
    "voisinera": "voisiner",
    "voisinerai": "voisiner",
    "voisineraient": "voisiner",
    "voisinerais": "voisiner",
    "voisinerait": "voisiner",
    "voisineras": "voisiner",
    "voisinerez": "voisiner",
    "voisineriez": "voisiner",
    "voisinerions": "voisiner",
    "voisinerons": "voisiner",
    "voisineront": "voisiner",
    "voisines": "voisiner",
    "voisinez": "voisiner",
    "voisiniez": "voisiner",
    "voisinions": "voisiner",
    "voisinons": "voisiner",
    "voisins": "voisin",
    "voisinâmes": "voisiner",
    "voisinât": "voisiner",
    "voisinâtes": "voisiner",
    "voisinèrent": "voisiner",
    "voisiné": "voisiner",
    "voisinée": "voisiner",
    "voisinées": "voisiner",
    "voisinés": "voisiner",
    "voit": "voir",
    "voituraient": "voiturer",
    "voiturait": "voiturer",
    "voiture": "voiturer",
    "voitureront": "voiturer",
    "voitures": "voiturer",
    "voitures-balais": "voiture-balai",
    "voitures-restaurants": "voiture-restaurant",
    "voiturettes": "voiturette",
    "voituriers": "voiturier",
    "voituré": "voiturer",
    "vola": "voler",
    "volages": "volage",
    "volai": "voler",
    "volaient": "voler",
    "volaillers": "volailler",
    "volailles": "volaille",
    "volais": "voler",
    "volait": "voler",
    "volant": "voler",
    "volante": "volanter",
    "volantes": "volanter",
    "volants": "volant",
    "volanté": "volanter",
    "volas": "voler",
    "volasse": "voler",
    "volassent": "voler",
    "volasses": "voler",
    "volassiez": "voler",
    "volassions": "voler",
    "volatile": "volatil",
    "volatiles": "volatile",
    "volatilisa": "volatiliser",
    "volatilisai": "volatiliser",
    "volatilisaient": "volatiliser",
    "volatilisais": "volatiliser",
    "volatilisait": "volatiliser",
    "volatilisant": "volatiliser",
    "volatilisas": "volatiliser",
    "volatilisasse": "volatiliser",
    "volatilisassent": "volatiliser",
    "volatilisasses": "volatiliser",
    "volatilisassiez": "volatiliser",
    "volatilisassions": "volatiliser",
    "volatilise": "volatiliser",
    "volatilisent": "volatiliser",
    "volatilisera": "volatiliser",
    "volatiliserai": "volatiliser",
    "volatiliseraient": "volatiliser",
    "volatiliserais": "volatiliser",
    "volatiliserait": "volatiliser",
    "volatiliseras": "volatiliser",
    "volatiliserez": "volatiliser",
    "volatiliseriez": "volatiliser",
    "volatiliserions": "volatiliser",
    "volatiliserons": "volatiliser",
    "volatiliseront": "volatiliser",
    "volatilises": "volatiliser",
    "volatilisez": "volatiliser",
    "volatilisiez": "volatiliser",
    "volatilisions": "volatiliser",
    "volatilisons": "volatiliser",
    "volatilisâmes": "volatiliser",
    "volatilisât": "volatiliser",
    "volatilisâtes": "volatiliser",
    "volatilisèrent": "volatiliser",
    "volatilisé": "volatiliser",
    "volatilisée": "volatiliser",
    "volatilisées": "volatiliser",
    "volatilisés": "volatiliser",
    "volatilités": "volatilité",
    "volatils": "volatil",
    "volcaniques": "volcanique",
    "volcanologies": "volcanologie",
    "volcans": "volcan",
    "vole": "voler",
    "volent": "voler",
    "volera": "voler",
    "volerai": "voler",
    "voleraient": "voler",
    "volerais": "voler",
    "volerait": "voler",
    "voleras": "voler",
    "volerez": "voler",
    "voleriez": "voler",
    "volerions": "voler",
    "volerons": "voler",
    "voleront": "voler",
    "voles": "voler",
    "voleta": "voleter",
    "voletai": "voleter",
    "voletaient": "voleter",
    "voletais": "voleter",
    "voletait": "voleter",
    "voletant": "voleter",
    "voletante": "voletant",
    "voletantes": "voletant",
    "voletas": "voleter",
    "voletasse": "voleter",
    "voletassent": "voleter",
    "voletasses": "voleter",
    "voletassiez": "voleter",
    "voletassions": "voleter",
    "voletez": "voleter",
    "voletiez": "voleter",
    "voletions": "voleter",
    "voletons": "voleter",
    "volets": "volet",
    "volette": "voleter",
    "volettent": "voleter",
    "volettera": "voleter",
    "voletterai": "voleter",
    "voletteraient": "voleter",
    "voletterais": "voleter",
    "voletterait": "voleter",
    "voletteras": "voleter",
    "voletterez": "voleter",
    "voletteriez": "voleter",
    "voletterions": "voleter",
    "voletterons": "voleter",
    "voletteront": "voleter",
    "volettes": "voleter",
    "voletâmes": "voleter",
    "voletât": "voleter",
    "voletâtes": "voleter",
    "voletèrent": "voleter",
    "voleté": "voleter",
    "voleurs": "voleur",
    "voleuse": "voleur",
    "voleuses": "voleur",
    "volez": "voler",
    "voliez": "voler",
    "voliges": "volige",
    "volions": "voler",
    "volitifs": "volitif",
    "volitions": "volition",
    "volitive": "volitif",
    "volitives": "volitif",
    "volières": "volière",
    "volley-balls": "volley-ball",
    "volleyeurs": "volleyeur",
    "volleyeuse": "volleyeur",
    "volleyeuses": "volleyeur",
    "volons": "voler",
    "volontaires": "volontaire",
    "volontariats": "volontariat",
    "volontarismes": "volontarisme",
    "volontaristes": "volontariste",
    "volontés": "volonté",
    "vols": "vol",
    "voltages": "voltage",
    "voltaient": "volter",
    "voltaires": "voltaire",
    "voltes": "volte",
    "voltige": "voltiger",
    "voltigea": "voltiger",
    "voltigeai": "voltiger",
    "voltigeaient": "voltiger",
    "voltigeais": "voltiger",
    "voltigeait": "voltiger",
    "voltigeant": "voltiger",
    "voltigeas": "voltiger",
    "voltigeasse": "voltiger",
    "voltigeassent": "voltiger",
    "voltigeasses": "voltiger",
    "voltigeassiez": "voltiger",
    "voltigeassions": "voltiger",
    "voltigent": "voltiger",
    "voltigeons": "voltiger",
    "voltigera": "voltiger",
    "voltigerai": "voltiger",
    "voltigeraient": "voltiger",
    "voltigerais": "voltiger",
    "voltigerait": "voltiger",
    "voltigeras": "voltiger",
    "voltigerez": "voltiger",
    "voltigeriez": "voltiger",
    "voltigerions": "voltiger",
    "voltigerons": "voltiger",
    "voltigeront": "voltiger",
    "voltiges": "voltiger",
    "voltigeurs": "voltigeur",
    "voltigeuse": "voltigeur",
    "voltigeuses": "voltigeur",
    "voltigez": "voltiger",
    "voltigeâmes": "voltiger",
    "voltigeât": "voltiger",
    "voltigeâtes": "voltiger",
    "voltigiez": "voltiger",
    "voltigions": "voltiger",
    "voltigèrent": "voltiger",
    "voltigé": "voltiger",
    "volts": "volt",
    "volubiles": "volubile",
    "volubilités": "volubilité",
    "volumes": "volume",
    "volumineuse": "volumineux",
    "volumineuses": "volumineux",
    "voluptueuse": "voluptueux",
    "voluptueuses": "voluptueux",
    "voluptés": "volupté",
    "volutes": "volute",
    "volvaires": "volvaire",
    "volves": "volve",
    "volâmes": "voler",
    "volât": "voler",
    "volâtes": "voler",
    "volèrent": "voler",
    "volé": "voler",
    "volée": "voler",
    "volées": "voler",
    "volés": "voler",
    "vomers": "vomer",
    "vomi": "vomir",
    "vomie": "vomir",
    "vomies": "vomir",
    "vomiques": "vomique",
    "vomira": "vomir",
    "vomirai": "vomir",
    "vomiraient": "vomir",
    "vomirais": "vomir",
    "vomirait": "vomir",
    "vomiras": "vomir",
    "vomirent": "vomir",
    "vomirez": "vomir",
    "vomiriez": "vomir",
    "vomirions": "vomir",
    "vomirons": "vomir",
    "vomiront": "vomir",
    "vomis": "vomir",
    "vomissaient": "vomir",
    "vomissais": "vomir",
    "vomissait": "vomir",
    "vomissant": "vomir",
    "vomisse": "vomir",
    "vomissements": "vomissement",
    "vomissent": "vomir",
    "vomisses": "vomir",
    "vomissez": "vomir",
    "vomissiez": "vomir",
    "vomissions": "vomir",
    "vomissons": "vomir",
    "vomissures": "vomissure",
    "vomit": "vomir",
    "vomitifs": "vomitif",
    "vomitives": "vomitif",
    "vomitoires": "vomitoire",
    "vomîmes": "vomir",
    "vomît": "vomir",
    "vomîtes": "vomir",
    "vont": "aller",
    "voraces": "vorace",
    "voracités": "voracité",
    "vos": "votre",
    "vosgienne": "vosgien",
    "vota": "voter",
    "votai": "voter",
    "votaient": "voter",
    "votais": "voter",
    "votait": "voter",
    "votant": "voter",
    "votante": "votant",
    "votantes": "votant",
    "votants": "votant",
    "votas": "voter",
    "votasse": "voter",
    "votassent": "voter",
    "votasses": "voter",
    "votassiez": "voter",
    "votassions": "voter",
    "vote": "voter",
    "votent": "voter",
    "votera": "voter",
    "voterai": "voter",
    "voteraient": "voter",
    "voterais": "voter",
    "voterait": "voter",
    "voteras": "voter",
    "voterez": "voter",
    "voteriez": "voter",
    "voterions": "voter",
    "voterons": "voter",
    "voteront": "voter",
    "votes": "voter",
    "votez": "voter",
    "votiez": "voter",
    "votifs": "votif",
    "votions": "voter",
    "votive": "votif",
    "votives": "votif",
    "votons": "voter",
    "votâmes": "voter",
    "votât": "voter",
    "votâtes": "voter",
    "votèrent": "voter",
    "voté": "voter",
    "votée": "voter",
    "votées": "voter",
    "votés": "voter",
    "voua": "vouer",
    "vouai": "vouer",
    "vouaient": "vouer",
    "vouais": "vouer",
    "vouait": "vouer",
    "vouant": "vouer",
    "vouas": "vouer",
    "vouasse": "vouer",
    "vouassent": "vouer",
    "vouasses": "vouer",
    "vouassiez": "vouer",
    "vouassions": "vouer",
    "voudra": "vouloir",
    "voudrai": "vouloir",
    "voudraient": "vouloir",
    "voudrais": "vouloir",
    "voudrait": "vouloir",
    "voudras": "vouloir",
    "voudrez": "vouloir",
    "voudriez": "vouloir",
    "voudrions": "vouloir",
    "voudrons": "vouloir",
    "voudront": "vouloir",
    "voue": "vouer",
    "vouent": "vouer",
    "vouera": "vouer",
    "vouerai": "vouer",
    "voueraient": "vouer",
    "vouerais": "vouer",
    "vouerait": "vouer",
    "voueras": "vouer",
    "vouerez": "vouer",
    "voueriez": "vouer",
    "vouerions": "vouer",
    "vouerons": "vouer",
    "voueront": "vouer",
    "voues": "vouer",
    "vouez": "vouer",
    "vouiez": "vouer",
    "vouions": "vouer",
    "vouivres": "vouivre",
    "voulaient": "vouloir",
    "voulais": "vouloir",
    "voulait": "vouloir",
    "voulant": "vouloir",
    "voulez": "vouloir",
    "vouliez": "vouloir",
    "voulions": "vouloir",
    "vouloirs": "vouloir",
    "voulons": "vouloir",
    "voulu": "vouloir",
    "voulue": "voulu",
    "voulues": "voulu",
    "voulurent": "vouloir",
    "voulus": "voulu",
    "voulusse": "vouloir",
    "voulussent": "vouloir",
    "voulusses": "vouloir",
    "voulussiez": "vouloir",
    "voulussions": "vouloir",
    "voulut": "vouloir",
    "voulûmes": "vouloir",
    "voulût": "vouloir",
    "voulûtes": "vouloir",
    "vouons": "vouer",
    "vous": "se",
    "vousoyait": "vousoyer",
    "vousoyez": "vousoyer",
    "voussoie": "voussoyer",
    "voussoient": "voussoyer",
    "voussoirs": "voussoir",
    "voussoyait": "voussoyer",
    "voussoyez": "voussoyer",
    "voussures": "voussure",
    "vouvoie": "vouvoyer",
    "vouvoiements": "vouvoiement",
    "vouvoient": "vouvoyer",
    "vouvoiera": "vouvoyer",
    "vouvoierai": "vouvoyer",
    "vouvoieraient": "vouvoyer",
    "vouvoierais": "vouvoyer",
    "vouvoierait": "vouvoyer",
    "vouvoieras": "vouvoyer",
    "vouvoierez": "vouvoyer",
    "vouvoieriez": "vouvoyer",
    "vouvoierions": "vouvoyer",
    "vouvoierons": "vouvoyer",
    "vouvoieront": "vouvoyer",
    "vouvoies": "vouvoyer",
    "vouvoya": "vouvoyer",
    "vouvoyai": "vouvoyer",
    "vouvoyaient": "vouvoyer",
    "vouvoyais": "vouvoyer",
    "vouvoyait": "vouvoyer",
    "vouvoyant": "vouvoyer",
    "vouvoyas": "vouvoyer",
    "vouvoyasse": "vouvoyer",
    "vouvoyassent": "vouvoyer",
    "vouvoyasses": "vouvoyer",
    "vouvoyassiez": "vouvoyer",
    "vouvoyassions": "vouvoyer",
    "vouvoyez": "vouvoyer",
    "vouvoyiez": "vouvoyer",
    "vouvoyions": "vouvoyer",
    "vouvoyons": "vouvoyer",
    "vouvoyâmes": "vouvoyer",
    "vouvoyât": "vouvoyer",
    "vouvoyâtes": "vouvoyer",
    "vouvoyèrent": "vouvoyer",
    "vouvoyé": "vouvoyer",
    "vouvoyée": "vouvoyer",
    "vouvoyées": "vouvoyer",
    "vouvoyés": "vouvoyer",
    "vouvrays": "vouvray",
    "vouâmes": "vouer",
    "vouât": "vouer",
    "vouâtes": "vouer",
    "vouèrent": "vouer",
    "voué": "vouer",
    "vouée": "vouer",
    "vouées": "vouer",
    "voués": "vouer",
    "voyage": "voyager",
    "voyagea": "voyager",
    "voyageai": "voyager",
    "voyageaient": "voyager",
    "voyageais": "voyager",
    "voyageait": "voyager",
    "voyageant": "voyager",
    "voyageas": "voyager",
    "voyageasse": "voyager",
    "voyageassent": "voyager",
    "voyageasses": "voyager",
    "voyageassiez": "voyager",
    "voyageassions": "voyager",
    "voyagent": "voyager",
    "voyageons": "voyager",
    "voyagera": "voyager",
    "voyagerai": "voyager",
    "voyageraient": "voyager",
    "voyagerais": "voyager",
    "voyagerait": "voyager",
    "voyageras": "voyager",
    "voyagerez": "voyager",
    "voyageriez": "voyager",
    "voyagerions": "voyager",
    "voyagerons": "voyager",
    "voyageront": "voyager",
    "voyages": "voyager",
    "voyages-éclair": "voyage-éclair",
    "voyageurs": "voyageur",
    "voyageuse": "voyageur",
    "voyageuses": "voyageur",
    "voyagez": "voyager",
    "voyageâmes": "voyager",
    "voyageât": "voyager",
    "voyageâtes": "voyager",
    "voyagiez": "voyager",
    "voyagions": "voyager",
    "voyagistes": "voyagiste",
    "voyagèrent": "voyager",
    "voyagé": "voyager",
    "voyaient": "voir",
    "voyais": "voir",
    "voyait": "voir",
    "voyances": "voyance",
    "voyant": "voir",
    "voyante": "voyant",
    "voyantes": "voyant",
    "voyants": "voyant",
    "voyelles": "voyelle",
    "voyers": "voyer",
    "voyeurismes": "voyeurisme",
    "voyeurs": "voyeur",
    "voyeuse": "voyeur",
    "voyeuses": "voyeur",
    "voyez": "voir",
    "voyiez": "voir",
    "voyions": "voir",
    "voyons": "voir",
    "voyous": "voyou",
    "voyoute": "voyou",
    "voyoutes": "voyou",
    "voïvodies": "voïvodie",
    "voûta": "voûter",
    "voûtai": "voûter",
    "voûtaient": "voûter",
    "voûtains": "voûtain",
    "voûtais": "voûter",
    "voûtait": "voûter",
    "voûtant": "voûter",
    "voûtas": "voûter",
    "voûtasse": "voûter",
    "voûtassent": "voûter",
    "voûtasses": "voûter",
    "voûtassiez": "voûter",
    "voûtassions": "voûter",
    "voûte": "voûter",
    "voûtent": "voûter",
    "voûtera": "voûter",
    "voûterai": "voûter",
    "voûteraient": "voûter",
    "voûterais": "voûter",
    "voûterait": "voûter",
    "voûteras": "voûter",
    "voûterez": "voûter",
    "voûteriez": "voûter",
    "voûterions": "voûter",
    "voûterons": "voûter",
    "voûteront": "voûter",
    "voûtes": "voûter",
    "voûtez": "voûter",
    "voûtiez": "voûter",
    "voûtions": "voûter",
    "voûtons": "voûter",
    "voûtâmes": "voûter",
    "voûtât": "voûter",
    "voûtâtes": "voûter",
    "voûtèrent": "voûter",
    "voûté": "voûter",
    "voûtée": "voûter",
    "voûtées": "voûter",
    "voûtés": "voûter",
    "vracs": "vrac",
    "vraie": "vrai",
    "vraies": "vrai",
    "vrais": "vrai",
    "vraisemblables": "vraisemblable",
    "vraisemblances": "vraisemblance",
    "vrilla": "vriller",
    "vrillai": "vriller",
    "vrillaient": "vriller",
    "vrillais": "vriller",
    "vrillait": "vriller",
    "vrillant": "vriller",
    "vrillas": "vriller",
    "vrillasse": "vriller",
    "vrillassent": "vriller",
    "vrillasses": "vriller",
    "vrillassiez": "vriller",
    "vrillassions": "vriller",
    "vrille": "vriller",
    "vrillent": "vriller",
    "vrillera": "vriller",
    "vrillerai": "vriller",
    "vrilleraient": "vriller",
    "vrillerais": "vriller",
    "vrillerait": "vriller",
    "vrilleras": "vriller",
    "vrillerez": "vriller",
    "vrilleriez": "vriller",
    "vrillerions": "vriller",
    "vrillerons": "vriller",
    "vrilleront": "vriller",
    "vrilles": "vriller",
    "vrillettes": "vrillette",
    "vrillez": "vriller",
    "vrilliez": "vriller",
    "vrillions": "vriller",
    "vrillons": "vriller",
    "vrillâmes": "vriller",
    "vrillât": "vriller",
    "vrillâtes": "vriller",
    "vrillèrent": "vriller",
    "vrillé": "vriller",
    "vrillée": "vriller",
    "vrillées": "vriller",
    "vrillés": "vriller",
    "vrombi": "vrombir",
    "vrombira": "vrombir",
    "vrombirai": "vrombir",
    "vrombiraient": "vrombir",
    "vrombirais": "vrombir",
    "vrombirait": "vrombir",
    "vrombiras": "vrombir",
    "vrombirent": "vrombir",
    "vrombirez": "vrombir",
    "vrombiriez": "vrombir",
    "vrombirions": "vrombir",
    "vrombirons": "vrombir",
    "vrombiront": "vrombir",
    "vrombis": "vrombir",
    "vrombissaient": "vrombir",
    "vrombissais": "vrombir",
    "vrombissait": "vrombir",
    "vrombissant": "vrombir",
    "vrombissante": "vrombissant",
    "vrombissantes": "vrombissant",
    "vrombisse": "vrombir",
    "vrombissements": "vrombissement",
    "vrombissent": "vrombir",
    "vrombisses": "vrombir",
    "vrombissez": "vrombir",
    "vrombissiez": "vrombir",
    "vrombissions": "vrombir",
    "vrombissons": "vrombir",
    "vrombit": "vrombir",
    "vrombîmes": "vrombir",
    "vrombît": "vrombir",
    "vrombîtes": "vrombir",
    "vu": "voir",
    "vue": "vu",
    "vues": "vue",
    "vulcains": "vulcain",
    "vulcanisa": "vulcaniser",
    "vulcanisai": "vulcaniser",
    "vulcanisaient": "vulcaniser",
    "vulcanisais": "vulcaniser",
    "vulcanisait": "vulcaniser",
    "vulcanisant": "vulcaniser",
    "vulcanisas": "vulcaniser",
    "vulcanisasse": "vulcaniser",
    "vulcanisassent": "vulcaniser",
    "vulcanisasses": "vulcaniser",
    "vulcanisassiez": "vulcaniser",
    "vulcanisassions": "vulcaniser",
    "vulcanise": "vulcaniser",
    "vulcanisent": "vulcaniser",
    "vulcanisera": "vulcaniser",
    "vulcaniserai": "vulcaniser",
    "vulcaniseraient": "vulcaniser",
    "vulcaniserais": "vulcaniser",
    "vulcaniserait": "vulcaniser",
    "vulcaniseras": "vulcaniser",
    "vulcaniserez": "vulcaniser",
    "vulcaniseriez": "vulcaniser",
    "vulcaniserions": "vulcaniser",
    "vulcaniserons": "vulcaniser",
    "vulcaniseront": "vulcaniser",
    "vulcanises": "vulcaniser",
    "vulcanisez": "vulcaniser",
    "vulcanisiez": "vulcaniser",
    "vulcanisions": "vulcaniser",
    "vulcanisons": "vulcaniser",
    "vulcanisâmes": "vulcaniser",
    "vulcanisât": "vulcaniser",
    "vulcanisâtes": "vulcaniser",
    "vulcanisèrent": "vulcaniser",
    "vulcanisé": "vulcaniser",
    "vulcanisée": "vulcaniser",
    "vulcanisées": "vulcaniser",
    "vulcanisés": "vulcaniser",
    "vulcanologies": "vulcanologie",
    "vulgaires": "vulgaire",
    "vulgarisa": "vulgariser",
    "vulgarisai": "vulgariser",
    "vulgarisaient": "vulgariser",
    "vulgarisais": "vulgariser",
    "vulgarisait": "vulgariser",
    "vulgarisant": "vulgariser",
    "vulgarisas": "vulgariser",
    "vulgarisasse": "vulgariser",
    "vulgarisassent": "vulgariser",
    "vulgarisasses": "vulgariser",
    "vulgarisassiez": "vulgariser",
    "vulgarisassions": "vulgariser",
    "vulgarisateurs": "vulgarisateur",
    "vulgarisations": "vulgarisation",
    "vulgarise": "vulgariser",
    "vulgarisent": "vulgariser",
    "vulgarisera": "vulgariser",
    "vulgariserai": "vulgariser",
    "vulgariseraient": "vulgariser",
    "vulgariserais": "vulgariser",
    "vulgariserait": "vulgariser",
    "vulgariseras": "vulgariser",
    "vulgariserez": "vulgariser",
    "vulgariseriez": "vulgariser",
    "vulgariserions": "vulgariser",
    "vulgariserons": "vulgariser",
    "vulgariseront": "vulgariser",
    "vulgarises": "vulgariser",
    "vulgarisez": "vulgariser",
    "vulgarisiez": "vulgariser",
    "vulgarisions": "vulgariser",
    "vulgarisons": "vulgariser",
    "vulgarisâmes": "vulgariser",
    "vulgarisât": "vulgariser",
    "vulgarisâtes": "vulgariser",
    "vulgarisèrent": "vulgariser",
    "vulgarisé": "vulgariser",
    "vulgarisée": "vulgariser",
    "vulgarisées": "vulgariser",
    "vulgarisés": "vulgariser",
    "vulgarités": "vulgarité",
    "vulgates": "vulgate",
    "vulnérabilités": "vulnérabilité",
    "vulnérables": "vulnérable",
    "vulnéraires": "vulnéraire",
    "vulpins": "vulpin",
    "vultueuse": "vultueux",
    "vultueuses": "vultueux",
    "vulvaires": "vulvaire",
    "vulves": "vulve",
    "vus": "vu",
    "vécu": "vivre",
    "vécue": "vivre",
    "vécues": "vivre",
    "vécurent": "vivre",
    "vécus": "vivre",
    "vécusse": "vivre",
    "vécussent": "vivre",
    "vécusses": "vivre",
    "vécussiez": "vivre",
    "vécussions": "vivre",
    "vécut": "vivre",
    "vécûmes": "vivre",
    "vécût": "vivre",
    "vécûtes": "vivre",
    "védiques": "védique",
    "végète": "végéter",
    "végètent": "végéter",
    "végètes": "végéter",
    "végéta": "végéter",
    "végétai": "végéter",
    "végétaient": "végéter",
    "végétais": "végéter",
    "végétait": "végéter",
    "végétale": "végétal",
    "végétales": "végétal",
    "végétalienne": "végétalien",
    "végétant": "végéter",
    "végétarienne": "végétarien",
    "végétariennes": "végétarien",
    "végétariens": "végétarien",
    "végétas": "végéter",
    "végétasse": "végéter",
    "végétassent": "végéter",
    "végétasses": "végéter",
    "végétassiez": "végéter",
    "végétassions": "végéter",
    "végétatifs": "végétatif",
    "végétations": "végétation",
    "végétative": "végétatif",
    "végétatives": "végétatif",
    "végétaux": "végétal",
    "végétera": "végéter",
    "végéterai": "végéter",
    "végéteraient": "végéter",
    "végéterais": "végéter",
    "végéterait": "végéter",
    "végéteras": "végéter",
    "végéterez": "végéter",
    "végéteriez": "végéter",
    "végéterions": "végéter",
    "végéterons": "végéter",
    "végéteront": "végéter",
    "végétez": "végéter",
    "végétiez": "végéter",
    "végétions": "végéter",
    "végétons": "végéter",
    "végétâmes": "végéter",
    "végétât": "végéter",
    "végétâtes": "végéter",
    "végétèrent": "végéter",
    "végété": "végéter",
    "véhicula": "véhiculer",
    "véhiculai": "véhiculer",
    "véhiculaient": "véhiculer",
    "véhiculaires": "véhiculaire",
    "véhiculais": "véhiculer",
    "véhiculait": "véhiculer",
    "véhiculant": "véhiculer",
    "véhiculas": "véhiculer",
    "véhiculasse": "véhiculer",
    "véhiculassent": "véhiculer",
    "véhiculasses": "véhiculer",
    "véhiculassiez": "véhiculer",
    "véhiculassions": "véhiculer",
    "véhicule": "véhiculer",
    "véhiculent": "véhiculer",
    "véhiculera": "véhiculer",
    "véhiculerai": "véhiculer",
    "véhiculeraient": "véhiculer",
    "véhiculerais": "véhiculer",
    "véhiculerait": "véhiculer",
    "véhiculeras": "véhiculer",
    "véhiculerez": "véhiculer",
    "véhiculeriez": "véhiculer",
    "véhiculerions": "véhiculer",
    "véhiculerons": "véhiculer",
    "véhiculeront": "véhiculer",
    "véhicules": "véhiculer",
    "véhiculez": "véhiculer",
    "véhiculiez": "véhiculer",
    "véhiculions": "véhiculer",
    "véhiculons": "véhiculer",
    "véhiculâmes": "véhiculer",
    "véhiculât": "véhiculer",
    "véhiculâtes": "véhiculer",
    "véhiculèrent": "véhiculer",
    "véhiculé": "véhiculer",
    "véhiculée": "véhiculer",
    "véhiculées": "véhiculer",
    "véhiculés": "véhiculer",
    "véhémences": "véhémence",
    "véhémente": "véhément",
    "véhémentes": "véhément",
    "véhéments": "véhément",
    "vélaires": "vélaire",
    "vélanis": "vélani",
    "vélins": "vélin",
    "véliplanchistes": "véliplanchiste",
    "véliques": "vélique",
    "vélites": "vélite",
    "véloces": "véloce",
    "vélocipèdes": "vélocipède",
    "vélocipédiques": "vélocipédique",
    "vélocipédistes": "vélocipédiste",
    "vélodromes": "vélodrome",
    "vélomoteurs": "vélomoteur",
    "vélos": "vélo",
    "vélums": "vélum",
    "vénale": "vénal",
    "vénales": "vénal",
    "vénalités": "vénalité",
    "vénaux": "vénal",
    "véneries": "vénerie",
    "vénielle": "véniel",
    "vénielles": "véniel",
    "véniels": "véniel",
    "vénitienne": "vénitien",
    "vénitiennes": "vénitienne",
    "vénitiens": "vénitien",
    "vénusienne": "vénusien",
    "vénusiens": "vénusien",
    "vénère": "vénérer",
    "vénèrent": "vénérer",
    "vénères": "vénérer",
    "vénéneuse": "vénéneux",
    "vénéneuses": "vénéneux",
    "vénéra": "vénérer",
    "vénérables": "vénérable",
    "vénérai": "vénérer",
    "vénéraient": "vénérer",
    "vénérais": "vénérer",
    "vénérait": "vénérer",
    "vénérant": "vénérer",
    "vénéras": "vénérer",
    "vénérasse": "vénérer",
    "vénérassent": "vénérer",
    "vénérasses": "vénérer",
    "vénérassiez": "vénérer",
    "vénérassions": "vénérer",
    "vénérations": "vénération",
    "vénérera": "vénérer",
    "vénérerai": "vénérer",
    "vénéreraient": "vénérer",
    "vénérerais": "vénérer",
    "vénérerait": "vénérer",
    "vénéreras": "vénérer",
    "vénérerez": "vénérer",
    "vénéreriez": "vénérer",
    "vénérerions": "vénérer",
    "vénérerons": "vénérer",
    "vénéreront": "vénérer",
    "vénérez": "vénérer",
    "vénérienne": "vénérien",
    "vénériennes": "vénérien",
    "vénériens": "vénérien",
    "vénériez": "vénérer",
    "vénérions": "vénérer",
    "vénérons": "vénérer",
    "vénérâmes": "vénérer",
    "vénérât": "vénérer",
    "vénérâtes": "vénérer",
    "vénérèrent": "vénérer",
    "vénéré": "vénérer",
    "vénérée": "vénérer",
    "vénérées": "vénérer",
    "vénérés": "vénérer",
    "vénézuélienne": "vénézuélien",
    "vénézuéliens": "vénézuélien",
    "véraces": "vérace",
    "véracités": "véracité",
    "véraisons": "véraison",
    "vérandas": "véranda",
    "véreuse": "véreux",
    "véreuses": "véreux",
    "véridiques": "véridique",
    "vérifia": "vérifier",
    "vérifiables": "vérifiable",
    "vérifiai": "vérifier",
    "vérifiaient": "vérifier",
    "vérifiais": "vérifier",
    "vérifiait": "vérifier",
    "vérifiant": "vérifier",
    "vérifias": "vérifier",
    "vérifiasse": "vérifier",
    "vérifiassent": "vérifier",
    "vérifiasses": "vérifier",
    "vérifiassiez": "vérifier",
    "vérifiassions": "vérifier",
    "vérificateurs": "vérificateur",
    "vérifications": "vérification",
    "vérificatrice": "vérificateur",
    "vérificatrices": "vérificateur",
    "vérifie": "vérifier",
    "vérifient": "vérifier",
    "vérifiera": "vérifier",
    "vérifierai": "vérifier",
    "vérifieraient": "vérifier",
    "vérifierais": "vérifier",
    "vérifierait": "vérifier",
    "vérifieras": "vérifier",
    "vérifierez": "vérifier",
    "vérifieriez": "vérifier",
    "vérifierions": "vérifier",
    "vérifierons": "vérifier",
    "vérifieront": "vérifier",
    "vérifies": "vérifier",
    "vérifiez": "vérifier",
    "vérifiiez": "vérifier",
    "vérifiions": "vérifier",
    "vérifions": "vérifier",
    "vérifiâmes": "vérifier",
    "vérifiât": "vérifier",
    "vérifiâtes": "vérifier",
    "vérifièrent": "vérifier",
    "vérifié": "vérifier",
    "vérifiée": "vérifier",
    "vérifiées": "vérifier",
    "vérifiés": "vérifier",
    "vérins": "vérin",
    "vérismes": "vérisme",
    "véritables": "véritable",
    "vérités": "vérité",
    "véroles": "vérole",
    "vérolé": "véroler",
    "vérolée": "véroler",
    "vérolées": "véroler",
    "vérolés": "véroler",
    "véronaise": "véronais",
    "véroniques": "véronique",
    "vésanies": "vésanie",
    "vésicale": "vésical",
    "vésicales": "vésical",
    "vésicante": "vésicant",
    "vésicantes": "vésicant",
    "vésicants": "vésicant",
    "vésicatoires": "vésicatoire",
    "vésicaux": "vésical",
    "vésicules": "vésicule",
    "vésiculeuse": "vésiculeux",
    "vésiculeuses": "vésiculeux",
    "vésuviennes": "vésuvien",
    "vétillarde": "vétillard",
    "vétillardes": "vétillard",
    "vétillards": "vétillard",
    "vétilles": "vétille",
    "vétilleuse": "vétilleux",
    "vétilleuses": "vétilleux",
    "vétivers": "vétiver",
    "vétustes": "vétuste",
    "vétustés": "vétusté",
    "vétérans": "vétéran",
    "vétérinaires": "vétérinaire",
    "vêla": "vêler",
    "vêlages": "vêlage",
    "vêlai": "vêler",
    "vêlaient": "vêler",
    "vêlais": "vêler",
    "vêlait": "vêler",
    "vêlant": "vêler",
    "vêlas": "vêler",
    "vêlasse": "vêler",
    "vêlassent": "vêler",
    "vêlasses": "vêler",
    "vêlassiez": "vêler",
    "vêlassions": "vêler",
    "vêle": "vêler",
    "vêlent": "vêler",
    "vêlera": "vêler",
    "vêlerai": "vêler",
    "vêleraient": "vêler",
    "vêlerais": "vêler",
    "vêlerait": "vêler",
    "vêleras": "vêler",
    "vêlerez": "vêler",
    "vêleriez": "vêler",
    "vêlerions": "vêler",
    "vêlerons": "vêler",
    "vêleront": "vêler",
    "vêles": "vêler",
    "vêlez": "vêler",
    "vêliez": "vêler",
    "vêlions": "vêler",
    "vêlons": "vêler",
    "vêlâmes": "vêler",
    "vêlât": "vêler",
    "vêlâtes": "vêler",
    "vêlèrent": "vêler",
    "vêlé": "vêler",
    "vêlée": "vêler",
    "vêlées": "vêler",
    "vêlés": "vêler",
    "vêpre": "vêpres",
    "vêpres": "vêpre",
    "vêt": "vêtir",
    "vêtaient": "vêtir",
    "vêtais": "vêtir",
    "vêtait": "vêtir",
    "vêtant": "vêtir",
    "vête": "vêtir",
    "vêtements": "vêtement",
    "vêtent": "vêtir",
    "vêtes": "vêtir",
    "vêtez": "vêtir",
    "vêtiez": "vêtir",
    "vêtions": "vêtir",
    "vêtira": "vêtir",
    "vêtirai": "vêtir",
    "vêtiraient": "vêtir",
    "vêtirais": "vêtir",
    "vêtirait": "vêtir",
    "vêtiras": "vêtir",
    "vêtirent": "vêtir",
    "vêtirez": "vêtir",
    "vêtiriez": "vêtir",
    "vêtirions": "vêtir",
    "vêtirons": "vêtir",
    "vêtiront": "vêtir",
    "vêtis": "vêtir",
    "vêtisse": "vêtir",
    "vêtissent": "vêtir",
    "vêtisses": "vêtir",
    "vêtissiez": "vêtir",
    "vêtissions": "vêtir",
    "vêtit": "vêtir",
    "vêtons": "vêtir",
    "vêts": "vêtir",
    "vêtu": "vêtir",
    "vêtue": "vêtu",
    "vêtues": "vêtu",
    "vêtures": "vêture",
    "vêtus": "vêtu",
    "vêtîmes": "vêtir",
    "vêtît": "vêtir",
    "vêtîtes": "vêtir",
    "vîmes": "voir",
    "vînmes": "venir",
    "vînt": "venir",
    "vîntes": "venir",
    "vît": "voir",
    "vîtes": "voir",
    "vôtres": "vôtre",
    "wagnérienne": "wagnérien",
    "wagnériennes": "wagnérien",
    "wagonnets": "wagonnet",
    "wagons": "wagon",
    "wagons-citernes": "wagon-citerne",
    "wagons-lits": "wagon-lit",
    "wagons-poste": "wagon-poste",
    "wagons-restaurants": "wagon-restaurant",
    "walkies-talkies": "walkie-talkie",
    "walkmans": "walkman",
    "wallabies": "wallaby",
    "wallingante": "wallingant",
    "wallingantes": "wallingant",
    "wallingants": "wallingant",
    "wallisienne": "wallisien",
    "wallisiennes": "wallisien",
    "wallisiens": "wallisien",
    "wallonne": "wallon",
    "wallonnes": "wallon",
    "wallons": "wallon",
    "wapitis": "wapiti",
    "warnings": "warning",
    "warrants": "warrant",
    "wassingues": "wassingue",
    "water-ballasts": "water-ballast",
    "water-closets": "water-closet",
    "water-polos": "water-polo",
    "wateringues": "wateringue",
    "waters": "water",
    "wattmans": "wattman",
    "wattmen": "wattman",
    "watts": "watt",
    "week end": "week-end",
    "week-ends": "week-end",
    "weimarienne": "weimarien",
    "welters": "welter",
    "westerns": "western",
    "westphaliennes": "westphalien",
    "wharfs": "wharf",
    "whigs": "whig",
    "whiskies": "whisky",
    "whisky-sodas": "whisky-soda",
    "whiskys": "whisky",
    "whists": "whist",
    "white-spirits": "white-spirit",
    "wigwams": "wigwam",
    "willayas": "willaya",
    "winchesters": "winchester",
    "wishbones": "wishbone",
    "wisigothe": "wisigoth",
    "wisigothiques": "wisigothique",
    "wisigoths": "wisigoth",
    "wolframs": "wolfram",
    "woofers": "woofer",
    "wurtembergeoise": "wurtembergeois",
    "xanthomes": "xanthome",
    "xanthophylles": "xanthophylle",
    "xiphophores": "xiphophore",
    "xiphoïdes": "xiphoïde",
    "xylophones": "xylophone",
    "xylènes": "xylène",
    "xystes": "xyste",
    "xénophobes": "xénophobe",
    "xénophobies": "xénophobie",
    "y": "yu",
    "yacht-clubs": "yacht-club",
    "yachtings": "yachting",
    "yachtmans": "yachtman",
    "yachtmen": "yachtman",
    "yachts": "yacht",
    "yachtsmans": "yachtsman",
    "yachtsmen": "yachtsman",
    "yacks": "yack",
    "yaks": "yak",
    "yakuzas": "yakuza",
    "yalis": "yali",
    "yankees": "yankee",
    "yanquis": "yanqui",
    "yaourtières": "yaourtière",
    "yaourts": "yaourt",
    "yards": "yard",
    "yatagans": "yatagan",
    "yearlings": "yearling",
    "yens": "yen",
    "yeomans": "yeoman",
    "yeomen": "yeoman",
    "yeuses": "yeuse",
    "yeux": "oeil",
    "yeux-radars": "oeil-radars",
    "ylangs-ylangs": "ylang-ylang",
    "yodlait": "yodler",
    "yods": "yod",
    "yogas": "yoga",
    "yogis": "yogi",
    "yogourts": "yogourt",
    "yoles": "yole",
    "yougoslaves": "yougoslave",
    "youpine": "youpin",
    "yourtes": "yourte",
    "youyous": "youyou",
    "yoyos": "yoyo",
    "ypréaux": "ypréau",
    "ypérites": "ypérite",
    "ysopets": "ysopet",
    "yttriums": "yttrium",
    "yu": "y",
    "yuans": "yuan",
    "yuccas": "yucca",
    "yuppies": "yuppie",
    "yèbles": "yèble",
    "yéménites": "yéménite",
    "yéyés": "yéyé",
    "zabres": "zabre",
    "zadé": "zader",
    "zakouskis": "zakouski",
    "zambienne": "zambien",
    "zambiennes": "zambien",
    "zambiens": "zambien",
    "zappant": "zapper",
    "zappe": "zapper",
    "zapperai": "zapper",
    "zapperait": "zapper",
    "zappes": "zapper",
    "zappez": "zapper",
    "zappings": "zapping",
    "zappé": "zapper",
    "zarbis": "zarbi",
    "zarzuelas": "zarzuela",
    "zazous": "zazou",
    "zaïroise": "zaïrois",
    "zaïroises": "zaïrois",
    "zens": "zen",
    "zeppelins": "zeppelin",
    "zestes": "zeste",
    "zeugmas": "zeugma",
    "zibelines": "zibeline",
    "zieuta": "zieuter",
    "zieutai": "zieuter",
    "zieutaient": "zieuter",
    "zieutais": "zieuter",
    "zieutait": "zieuter",
    "zieutant": "zieuter",
    "zieutas": "zieuter",
    "zieutasse": "zieuter",
    "zieutassent": "zieuter",
    "zieutasses": "zieuter",
    "zieutassiez": "zieuter",
    "zieutassions": "zieuter",
    "zieute": "zieuter",
    "zieutent": "zieuter",
    "zieutera": "zieuter",
    "zieuterai": "zieuter",
    "zieuteraient": "zieuter",
    "zieuterais": "zieuter",
    "zieuterait": "zieuter",
    "zieuteras": "zieuter",
    "zieuterez": "zieuter",
    "zieuteriez": "zieuter",
    "zieuterions": "zieuter",
    "zieuterons": "zieuter",
    "zieuteront": "zieuter",
    "zieutes": "zieuter",
    "zieutez": "zieuter",
    "zieutiez": "zieuter",
    "zieutions": "zieuter",
    "zieutons": "zieuter",
    "zieutâmes": "zieuter",
    "zieutât": "zieuter",
    "zieutâtes": "zieuter",
    "zieutèrent": "zieuter",
    "zieuté": "zieuter",
    "zieutée": "zieuter",
    "zieutées": "zieuter",
    "zieutés": "zieuter",
    "ziggourats": "ziggourat",
    "zigomars": "zigomar",
    "zigotos": "zigoto",
    "zigouillais": "zigouiller",
    "zigouillait": "zigouiller",
    "zigouille": "zigouiller",
    "zigouillent": "zigouiller",
    "zigouillez": "zigouiller",
    "zigouillé": "zigouiller",
    "zigouillées": "zigouiller",
    "zigouillés": "zigouiller",
    "zigues": "zigue",
    "zigzagante": "zigzagant",
    "zigzagantes": "zigzagant",
    "zigzags": "zigzag",
    "zigzagua": "zigzaguer",
    "zigzaguai": "zigzaguer",
    "zigzaguaient": "zigzaguer",
    "zigzaguais": "zigzaguer",
    "zigzaguait": "zigzaguer",
    "zigzaguant": "zigzaguer",
    "zigzaguas": "zigzaguer",
    "zigzaguasse": "zigzaguer",
    "zigzaguassent": "zigzaguer",
    "zigzaguasses": "zigzaguer",
    "zigzaguassiez": "zigzaguer",
    "zigzaguassions": "zigzaguer",
    "zigzague": "zigzaguer",
    "zigzaguent": "zigzaguer",
    "zigzaguera": "zigzaguer",
    "zigzaguerai": "zigzaguer",
    "zigzagueraient": "zigzaguer",
    "zigzaguerais": "zigzaguer",
    "zigzaguerait": "zigzaguer",
    "zigzagueras": "zigzaguer",
    "zigzaguerez": "zigzaguer",
    "zigzagueriez": "zigzaguer",
    "zigzaguerions": "zigzaguer",
    "zigzaguerons": "zigzaguer",
    "zigzagueront": "zigzaguer",
    "zigzagues": "zigzaguer",
    "zigzaguez": "zigzaguer",
    "zigzaguiez": "zigzaguer",
    "zigzaguions": "zigzaguer",
    "zigzaguons": "zigzaguer",
    "zigzaguâmes": "zigzaguer",
    "zigzaguât": "zigzaguer",
    "zigzaguâtes": "zigzaguer",
    "zigzaguèrent": "zigzaguer",
    "zigzagué": "zigzaguer",
    "zigzaguée": "zigzaguer",
    "zimbabwéens": "zimbabwéen",
    "zincs": "zinc",
    "zingua": "zinguer",
    "zinguai": "zinguer",
    "zinguaient": "zinguer",
    "zinguais": "zinguer",
    "zinguait": "zinguer",
    "zinguant": "zinguer",
    "zinguas": "zinguer",
    "zinguasse": "zinguer",
    "zinguassent": "zinguer",
    "zinguasses": "zinguer",
    "zinguassiez": "zinguer",
    "zinguassions": "zinguer",
    "zingue": "zinguer",
    "zinguent": "zinguer",
    "zinguera": "zinguer",
    "zinguerai": "zinguer",
    "zingueraient": "zinguer",
    "zinguerais": "zinguer",
    "zinguerait": "zinguer",
    "zingueras": "zinguer",
    "zinguerez": "zinguer",
    "zingueriez": "zinguer",
    "zinguerions": "zinguer",
    "zinguerons": "zinguer",
    "zingueront": "zinguer",
    "zingues": "zinguer",
    "zinguez": "zinguer",
    "zinguiez": "zinguer",
    "zinguions": "zinguer",
    "zinguons": "zinguer",
    "zinguâmes": "zinguer",
    "zinguât": "zinguer",
    "zinguâtes": "zinguer",
    "zinguèrent": "zinguer",
    "zingué": "zinguer",
    "zinguée": "zinguer",
    "zinguées": "zinguer",
    "zingués": "zinguer",
    "zinnias": "zinnia",
    "zinzins": "zinzin",
    "zippa": "zipper",
    "zippait": "zipper",
    "zippé": "zipper",
    "zirconiums": "zirconium",
    "zircons": "zircon",
    "zizanies": "zizanie",
    "zizis": "zizi",
    "zizyphes": "zizyphe",
    "zlotys": "zloty",
    "zobs": "zob",
    "zodiacale": "zodiacal",
    "zodiacales": "zodiacal",
    "zodiacaux": "zodiacal",
    "zodiaques": "zodiaque",
    "zombies": "zombie",
    "zombis": "zombi",
    "zona": "zoner",
    "zonages": "zonage",
    "zonait": "zoner",
    "zonale": "zonal",
    "zonales": "zonal",
    "zonant": "zoner",
    "zonarde": "zonard",
    "zonardes": "zonard",
    "zonards": "zonard",
    "zonas": "zona",
    "zonaux": "zonal",
    "zonera": "zoner",
    "zones": "zone",
    "zones-clés": "zone-clé",
    "zoné": "zoner",
    "zoologies": "zoologie",
    "zoologiques": "zoologique",
    "zoome": "zoomer",
    "zoomes": "zoomer",
    "zoomez": "zoomer",
    "zooms": "zoom",
    "zoonotiques": "zoonotique",
    "zoophiles": "zoophile",
    "zoophiliques": "zoophilique",
    "zoos": "zoo",
    "zootechnicienne": "zootechnicien",
    "zootechniciennes": "zootechnicien",
    "zootechniciens": "zootechnicien",
    "zootechniques": "zootechnique",
    "zoreilles": "zoreille",
    "zorilles": "zorille",
    "zoroastriens": "zoroastrien",
    "zouaves": "zouave",
    "zouloue": "zoulou",
    "zouloues": "zoulou",
    "zoulous": "zoulou",
    "zozos": "zozo",
    "zozota": "zozoter",
    "zozotai": "zozoter",
    "zozotaient": "zozoter",
    "zozotais": "zozoter",
    "zozotait": "zozoter",
    "zozotant": "zozoter",
    "zozotas": "zozoter",
    "zozotasse": "zozoter",
    "zozotassent": "zozoter",
    "zozotasses": "zozoter",
    "zozotassiez": "zozoter",
    "zozotassions": "zozoter",
    "zozote": "zozoter",
    "zozotements": "zozotement",
    "zozotent": "zozoter",
    "zozotera": "zozoter",
    "zozoterai": "zozoter",
    "zozoteraient": "zozoter",
    "zozoterais": "zozoter",
    "zozoterait": "zozoter",
    "zozoteras": "zozoter",
    "zozoterez": "zozoter",
    "zozoteriez": "zozoter",
    "zozoterions": "zozoter",
    "zozoterons": "zozoter",
    "zozoteront": "zozoter",
    "zozotes": "zozoter",
    "zozoteuse": "zozoteur",
    "zozotez": "zozoter",
    "zozotiez": "zozoter",
    "zozotions": "zozoter",
    "zozotons": "zozoter",
    "zozotâmes": "zozoter",
    "zozotât": "zozoter",
    "zozotâtes": "zozoter",
    "zozotèrent": "zozoter",
    "zozoté": "zozoter",
    "zoés": "zoé",
    "zurichoise": "zurichois",
    "zyeuta": "zyeuter",
    "zyeutais": "zyeuter",
    "zyeutait": "zyeuter",
    "zyeutant": "zyeuter",
    "zyeute": "zyeuter",
    "zyeutes": "zyeuter",
    "zyeuté": "zyeuter",
    "zygomatiques": "zygomatique",
    "zygotes": "zygote",
    "zymases": "zymase",
    "zythums": "zythum",
    "zèbre": "zébrer",
    "zèbrent": "zébrer",
    "zèbres": "zébrer",
    "zèles": "zèle",
    "zébra": "zébrer",
    "zébrai": "zébrer",
    "zébraient": "zébrer",
    "zébrais": "zébrer",
    "zébrait": "zébrer",
    "zébrant": "zébrer",
    "zébras": "zébrer",
    "zébrasse": "zébrer",
    "zébrassent": "zébrer",
    "zébrasses": "zébrer",
    "zébrassiez": "zébrer",
    "zébrassions": "zébrer",
    "zébrera": "zébrer",
    "zébrerai": "zébrer",
    "zébreraient": "zébrer",
    "zébrerais": "zébrer",
    "zébrerait": "zébrer",
    "zébreras": "zébrer",
    "zébrerez": "zébrer",
    "zébreriez": "zébrer",
    "zébrerions": "zébrer",
    "zébrerons": "zébrer",
    "zébreront": "zébrer",
    "zébrez": "zébrer",
    "zébriez": "zébrer",
    "zébrions": "zébrer",
    "zébrons": "zébrer",
    "zébrures": "zébrure",
    "zébrâmes": "zébrer",
    "zébrât": "zébrer",
    "zébrâtes": "zébrer",
    "zébrèrent": "zébrer",
    "zébré": "zébrer",
    "zébrée": "zébrer",
    "zébrées": "zébrer",
    "zébrés": "zébrer",
    "zébus": "zébu",
    "zélateurs": "zélateur",
    "zélatrice": "zélateur",
    "zélatrices": "zélateur",
    "zélotes": "zélote",
    "zélée": "zélé",
    "zélées": "zélé",
    "zélés": "zélé",
    "zénithale": "zénithal",
    "zénithales": "zénithal",
    "zénithaux": "zénithal",
    "zéniths": "zénith",
    "zéphyrs": "zéphyr",
    "zéros": "zéro",
    "zézaie": "zézayer",
    "zézaiements": "zézaiement",
    "zézaient": "zézayer",
    "zézaiera": "zézayer",
    "zézaierai": "zézayer",
    "zézaieraient": "zézayer",
    "zézaierais": "zézayer",
    "zézaierait": "zézayer",
    "zézaieras": "zézayer",
    "zézaierez": "zézayer",
    "zézaieriez": "zézayer",
    "zézaierions": "zézayer",
    "zézaierons": "zézayer",
    "zézaieront": "zézayer",
    "zézaies": "zézayer",
    "zézaya": "zézayer",
    "zézayai": "zézayer",
    "zézayaient": "zézayer",
    "zézayais": "zézayer",
    "zézayait": "zézayer",
    "zézayant": "zézayer",
    "zézayas": "zézayer",
    "zézayasse": "zézayer",
    "zézayassent": "zézayer",
    "zézayasses": "zézayer",
    "zézayassiez": "zézayer",
    "zézayassions": "zézayer",
    "zézaye": "zézayer",
    "zézayent": "zézayer",
    "zézayera": "zézayer",
    "zézayerai": "zézayer",
    "zézayeraient": "zézayer",
    "zézayerais": "zézayer",
    "zézayerait": "zézayer",
    "zézayeras": "zézayer",
    "zézayerez": "zézayer",
    "zézayeriez": "zézayer",
    "zézayerions": "zézayer",
    "zézayerons": "zézayer",
    "zézayeront": "zézayer",
    "zézayes": "zézayer",
    "zézayez": "zézayer",
    "zézayiez": "zézayer",
    "zézayions": "zézayer",
    "zézayons": "zézayer",
    "zézayâmes": "zézayer",
    "zézayât": "zézayer",
    "zézayâtes": "zézayer",
    "zézayèrent": "zézayer",
    "zézayé": "zézayer",
    "zézettes": "zézette",
    "à posteriori": "a posteriori",
    "à priori": "a priori",
    "à-coups": "à-coup",
    "à-côtés": "à-côté",
    "à-pics": "à-pic",
    "à-plats": "à-plat",
    "âcres": "âcre",
    "âcretés": "âcreté",
    "âges": "âge",
    "âgée": "âgé",
    "âgées": "âgé",
    "âgés": "âgé",
    "âmes": "âme",
    "âneries": "ânerie",
    "ânes": "âne",
    "ânesse": "âne",
    "ânesses": "ânesse",
    "ânonna": "ânonner",
    "ânonnai": "ânonner",
    "ânonnaient": "ânonner",
    "ânonnais": "ânonner",
    "ânonnait": "ânonner",
    "ânonnant": "ânonner",
    "ânonnas": "ânonner",
    "ânonnasse": "ânonner",
    "ânonnassent": "ânonner",
    "ânonnasses": "ânonner",
    "ânonnassiez": "ânonner",
    "ânonnassions": "ânonner",
    "ânonne": "ânonner",
    "ânonnements": "ânonnement",
    "ânonnent": "ânonner",
    "ânonnera": "ânonner",
    "ânonnerai": "ânonner",
    "ânonneraient": "ânonner",
    "ânonnerais": "ânonner",
    "ânonnerait": "ânonner",
    "ânonneras": "ânonner",
    "ânonnerez": "ânonner",
    "ânonneriez": "ânonner",
    "ânonnerions": "ânonner",
    "ânonnerons": "ânonner",
    "ânonneront": "ânonner",
    "ânonnes": "ânonner",
    "ânonnez": "ânonner",
    "ânonniez": "ânonner",
    "ânonnions": "ânonner",
    "ânonnons": "ânonner",
    "ânonnâmes": "ânonner",
    "ânonnât": "ânonner",
    "ânonnâtes": "ânonner",
    "ânonnèrent": "ânonner",
    "ânonné": "ânonner",
    "ânonnée": "ânonner",
    "ânonnées": "ânonner",
    "ânonnés": "ânonner",
    "ânons": "ânon",
    "âpres": "âpre",
    "âpretés": "âpreté",
    "âtres": "âtre",
    "ç'": "ça",
    "ères": "ère",
    "ébahi": "ébahir",
    "ébahie": "ébahir",
    "ébahies": "ébahir",
    "ébahira": "ébahir",
    "ébahirai": "ébahir",
    "ébahiraient": "ébahir",
    "ébahirais": "ébahir",
    "ébahirait": "ébahir",
    "ébahiras": "ébahir",
    "ébahirent": "ébahir",
    "ébahirez": "ébahir",
    "ébahiriez": "ébahir",
    "ébahirions": "ébahir",
    "ébahirons": "ébahir",
    "ébahiront": "ébahir",
    "ébahis": "ébahir",
    "ébahissaient": "ébahir",
    "ébahissais": "ébahir",
    "ébahissait": "ébahir",
    "ébahissant": "ébahir",
    "ébahisse": "ébahir",
    "ébahissements": "ébahissement",
    "ébahissent": "ébahir",
    "ébahisses": "ébahir",
    "ébahissez": "ébahir",
    "ébahissiez": "ébahir",
    "ébahissions": "ébahir",
    "ébahissons": "ébahir",
    "ébahit": "ébahir",
    "ébahîmes": "ébahir",
    "ébahît": "ébahir",
    "ébahîtes": "ébahir",
    "ébarba": "ébarber",
    "ébarbai": "ébarber",
    "ébarbaient": "ébarber",
    "ébarbais": "ébarber",
    "ébarbait": "ébarber",
    "ébarbant": "ébarber",
    "ébarbas": "ébarber",
    "ébarbasse": "ébarber",
    "ébarbassent": "ébarber",
    "ébarbasses": "ébarber",
    "ébarbassiez": "ébarber",
    "ébarbassions": "ébarber",
    "ébarbe": "ébarber",
    "ébarbent": "ébarber",
    "ébarbera": "ébarber",
    "ébarberai": "ébarber",
    "ébarberaient": "ébarber",
    "ébarberais": "ébarber",
    "ébarberait": "ébarber",
    "ébarberas": "ébarber",
    "ébarberez": "ébarber",
    "ébarberiez": "ébarber",
    "ébarberions": "ébarber",
    "ébarberons": "ébarber",
    "ébarberont": "ébarber",
    "ébarbes": "ébarber",
    "ébarbez": "ébarber",
    "ébarbiez": "ébarber",
    "ébarbions": "ébarber",
    "ébarbons": "ébarber",
    "ébarbâmes": "ébarber",
    "ébarbât": "ébarber",
    "ébarbâtes": "ébarber",
    "ébarbèrent": "ébarber",
    "ébarbé": "ébarber",
    "ébarbée": "ébarber",
    "ébarbées": "ébarber",
    "ébarbés": "ébarber",
    "ébat": "ébattre",
    "ébats": "ébattre",
    "ébattaient": "ébattre",
    "ébattais": "ébattre",
    "ébattait": "ébattre",
    "ébattant": "ébattre",
    "ébatte": "ébattre",
    "ébattements": "ébattement",
    "ébattent": "ébattre",
    "ébattes": "ébattre",
    "ébattez": "ébattre",
    "ébattiez": "ébattre",
    "ébattions": "ébattre",
    "ébattirent": "ébattre",
    "ébattis": "ébattre",
    "ébattisse": "ébattre",
    "ébattissent": "ébattre",
    "ébattisses": "ébattre",
    "ébattissiez": "ébattre",
    "ébattissions": "ébattre",
    "ébattit": "ébattre",
    "ébattons": "ébattre",
    "ébattra": "ébattre",
    "ébattrai": "ébattre",
    "ébattraient": "ébattre",
    "ébattrais": "ébattre",
    "ébattrait": "ébattre",
    "ébattras": "ébattre",
    "ébattrez": "ébattre",
    "ébattriez": "ébattre",
    "ébattrions": "ébattre",
    "ébattrons": "ébattre",
    "ébattront": "ébattre",
    "ébattu": "ébattre",
    "ébattue": "ébattre",
    "ébattues": "ébattre",
    "ébattus": "ébattre",
    "ébattîmes": "ébattre",
    "ébattît": "ébattre",
    "ébattîtes": "ébattre",
    "ébaubi": "ébaubir",
    "ébaubie": "ébaubir",
    "ébaubies": "ébaubir",
    "ébaubira": "ébaubir",
    "ébaubirai": "ébaubir",
    "ébaubiraient": "ébaubir",
    "ébaubirais": "ébaubir",
    "ébaubirait": "ébaubir",
    "ébaubiras": "ébaubir",
    "ébaubirent": "ébaubir",
    "ébaubirez": "ébaubir",
    "ébaubiriez": "ébaubir",
    "ébaubirions": "ébaubir",
    "ébaubirons": "ébaubir",
    "ébaubiront": "ébaubir",
    "ébaubis": "ébaubir",
    "ébaubissaient": "ébaubir",
    "ébaubissais": "ébaubir",
    "ébaubissait": "ébaubir",
    "ébaubissant": "ébaubir",
    "ébaubisse": "ébaubir",
    "ébaubissent": "ébaubir",
    "ébaubisses": "ébaubir",
    "ébaubissez": "ébaubir",
    "ébaubissiez": "ébaubir",
    "ébaubissions": "ébaubir",
    "ébaubissons": "ébaubir",
    "ébaubit": "ébaubir",
    "ébaubîmes": "ébaubir",
    "ébaubît": "ébaubir",
    "ébaubîtes": "ébaubir",
    "ébaucha": "ébaucher",
    "ébauchai": "ébaucher",
    "ébauchaient": "ébaucher",
    "ébauchais": "ébaucher",
    "ébauchait": "ébaucher",
    "ébauchant": "ébaucher",
    "ébauchas": "ébaucher",
    "ébauchasse": "ébaucher",
    "ébauchassent": "ébaucher",
    "ébauchasses": "ébaucher",
    "ébauchassiez": "ébaucher",
    "ébauchassions": "ébaucher",
    "ébauche": "ébaucher",
    "ébauchent": "ébaucher",
    "ébauchera": "ébaucher",
    "ébaucherai": "ébaucher",
    "ébaucheraient": "ébaucher",
    "ébaucherais": "ébaucher",
    "ébaucherait": "ébaucher",
    "ébaucheras": "ébaucher",
    "ébaucherez": "ébaucher",
    "ébaucheriez": "ébaucher",
    "ébaucherions": "ébaucher",
    "ébaucherons": "ébaucher",
    "ébaucheront": "ébaucher",
    "ébauches": "ébaucher",
    "ébaucheurs": "ébaucheur",
    "ébauchez": "ébaucher",
    "ébauchiez": "ébaucher",
    "ébauchions": "ébaucher",
    "ébauchons": "ébauchon",
    "ébauchâmes": "ébaucher",
    "ébauchât": "ébaucher",
    "ébauchâtes": "ébaucher",
    "ébauchèrent": "ébaucher",
    "ébauché": "ébaucher",
    "ébauchée": "ébaucher",
    "ébauchées": "ébaucher",
    "ébauchés": "ébaucher",
    "ébaudi": "ébaudir",
    "ébaudie": "ébaudir",
    "ébaudies": "ébaudir",
    "ébaudira": "ébaudir",
    "ébaudirai": "ébaudir",
    "ébaudiraient": "ébaudir",
    "ébaudirais": "ébaudir",
    "ébaudirait": "ébaudir",
    "ébaudiras": "ébaudir",
    "ébaudirent": "ébaudir",
    "ébaudirez": "ébaudir",
    "ébaudiriez": "ébaudir",
    "ébaudirions": "ébaudir",
    "ébaudirons": "ébaudir",
    "ébaudiront": "ébaudir",
    "ébaudis": "ébaudir",
    "ébaudissaient": "ébaudir",
    "ébaudissais": "ébaudir",
    "ébaudissait": "ébaudir",
    "ébaudissant": "ébaudir",
    "ébaudisse": "ébaudir",
    "ébaudissent": "ébaudir",
    "ébaudisses": "ébaudir",
    "ébaudissez": "ébaudir",
    "ébaudissiez": "ébaudir",
    "ébaudissions": "ébaudir",
    "ébaudissons": "ébaudir",
    "ébaudit": "ébaudir",
    "ébaudîmes": "ébaudir",
    "ébaudît": "ébaudir",
    "ébaudîtes": "ébaudir",
    "éberlua": "éberluer",
    "éberluait": "éberluer",
    "éberlue": "éberluer",
    "éberlué": "éberluer",
    "éberluée": "éberluer",
    "éberluées": "éberlué",
    "éberlués": "éberluer",
    "ébloui": "éblouir",
    "éblouie": "éblouir",
    "éblouies": "éblouir",
    "éblouira": "éblouir",
    "éblouirai": "éblouir",
    "éblouiraient": "éblouir",
    "éblouirais": "éblouir",
    "éblouirait": "éblouir",
    "éblouiras": "éblouir",
    "éblouirent": "éblouir",
    "éblouirez": "éblouir",
    "éblouiriez": "éblouir",
    "éblouirions": "éblouir",
    "éblouirons": "éblouir",
    "éblouiront": "éblouir",
    "éblouis": "éblouir",
    "éblouissaient": "éblouir",
    "éblouissais": "éblouir",
    "éblouissait": "éblouir",
    "éblouissant": "éblouir",
    "éblouissante": "éblouissant",
    "éblouissantes": "éblouissant",
    "éblouissants": "éblouissant",
    "éblouisse": "éblouir",
    "éblouissements": "éblouissement",
    "éblouissent": "éblouir",
    "éblouisses": "éblouir",
    "éblouissez": "éblouir",
    "éblouissiez": "éblouir",
    "éblouissions": "éblouir",
    "éblouissons": "éblouir",
    "éblouit": "éblouir",
    "éblouîmes": "éblouir",
    "éblouît": "éblouir",
    "éblouîtes": "éblouir",
    "ébonites": "ébonite",
    "éborgna": "éborgner",
    "éborgnai": "éborgner",
    "éborgnaient": "éborgner",
    "éborgnais": "éborgner",
    "éborgnait": "éborgner",
    "éborgnant": "éborgner",
    "éborgnas": "éborgner",
    "éborgnasse": "éborgner",
    "éborgnassent": "éborgner",
    "éborgnasses": "éborgner",
    "éborgnassiez": "éborgner",
    "éborgnassions": "éborgner",
    "éborgne": "éborgner",
    "éborgnent": "éborgner",
    "éborgnera": "éborgner",
    "éborgnerai": "éborgner",
    "éborgneraient": "éborgner",
    "éborgnerais": "éborgner",
    "éborgnerait": "éborgner",
    "éborgneras": "éborgner",
    "éborgnerez": "éborgner",
    "éborgneriez": "éborgner",
    "éborgnerions": "éborgner",
    "éborgnerons": "éborgner",
    "éborgneront": "éborgner",
    "éborgnes": "éborgner",
    "éborgnez": "éborgner",
    "éborgniez": "éborgner",
    "éborgnions": "éborgner",
    "éborgnons": "éborgner",
    "éborgnâmes": "éborgner",
    "éborgnât": "éborgner",
    "éborgnâtes": "éborgner",
    "éborgnèrent": "éborgner",
    "éborgné": "éborgner",
    "éborgnée": "éborgner",
    "éborgnées": "éborgner",
    "éborgnés": "éborgner",
    "éboueurs": "éboueur",
    "ébouillanta": "ébouillanter",
    "ébouillantai": "ébouillanter",
    "ébouillantaient": "ébouillanter",
    "ébouillantais": "ébouillanter",
    "ébouillantait": "ébouillanter",
    "ébouillantant": "ébouillanter",
    "ébouillantas": "ébouillanter",
    "ébouillantasse": "ébouillanter",
    "ébouillantassent": "ébouillanter",
    "ébouillantasses": "ébouillanter",
    "ébouillantassiez": "ébouillanter",
    "ébouillantassions": "ébouillanter",
    "ébouillante": "ébouillanter",
    "ébouillantent": "ébouillanter",
    "ébouillantera": "ébouillanter",
    "ébouillanterai": "ébouillanter",
    "ébouillanteraient": "ébouillanter",
    "ébouillanterais": "ébouillanter",
    "ébouillanterait": "ébouillanter",
    "ébouillanteras": "ébouillanter",
    "ébouillanterez": "ébouillanter",
    "ébouillanteriez": "ébouillanter",
    "ébouillanterions": "ébouillanter",
    "ébouillanterons": "ébouillanter",
    "ébouillanteront": "ébouillanter",
    "ébouillantes": "ébouillanter",
    "ébouillantez": "ébouillanter",
    "ébouillantiez": "ébouillanter",
    "ébouillantions": "ébouillanter",
    "ébouillantons": "ébouillanter",
    "ébouillantâmes": "ébouillanter",
    "ébouillantât": "ébouillanter",
    "ébouillantâtes": "ébouillanter",
    "ébouillantèrent": "ébouillanter",
    "ébouillanté": "ébouillanter",
    "ébouillantée": "ébouillanter",
    "ébouillantées": "ébouillanter",
    "ébouillantés": "ébouillanter",
    "éboula": "ébouler",
    "éboulai": "ébouler",
    "éboulaient": "ébouler",
    "éboulais": "ébouler",
    "éboulait": "ébouler",
    "éboulant": "ébouler",
    "éboulas": "ébouler",
    "éboulasse": "ébouler",
    "éboulassent": "ébouler",
    "éboulasses": "ébouler",
    "éboulassiez": "ébouler",
    "éboulassions": "ébouler",
    "éboule": "ébouler",
    "éboulements": "éboulement",
    "éboulent": "ébouler",
    "éboulera": "ébouler",
    "éboulerai": "ébouler",
    "ébouleraient": "ébouler",
    "éboulerais": "ébouler",
    "éboulerait": "ébouler",
    "ébouleras": "ébouler",
    "éboulerez": "ébouler",
    "ébouleriez": "ébouler",
    "éboulerions": "ébouler",
    "éboulerons": "ébouler",
    "ébouleront": "ébouler",
    "éboules": "ébouler",
    "ébouleuses": "ébouleux",
    "éboulez": "ébouler",
    "ébouliez": "ébouler",
    "éboulions": "ébouler",
    "éboulis": "ébouli",
    "éboulons": "ébouler",
    "éboulâmes": "ébouler",
    "éboulât": "ébouler",
    "éboulâtes": "ébouler",
    "éboulèrent": "ébouler",
    "éboulé": "ébouler",
    "éboulée": "ébouler",
    "éboulées": "ébouler",
    "éboulés": "ébouler",
    "ébourgeonna": "ébourgeonner",
    "ébourgeonnai": "ébourgeonner",
    "ébourgeonnaient": "ébourgeonner",
    "ébourgeonnais": "ébourgeonner",
    "ébourgeonnait": "ébourgeonner",
    "ébourgeonnant": "ébourgeonner",
    "ébourgeonnas": "ébourgeonner",
    "ébourgeonnasse": "ébourgeonner",
    "ébourgeonnassent": "ébourgeonner",
    "ébourgeonnasses": "ébourgeonner",
    "ébourgeonnassiez": "ébourgeonner",
    "ébourgeonnassions": "ébourgeonner",
    "ébourgeonne": "ébourgeonner",
    "ébourgeonnent": "ébourgeonner",
    "ébourgeonnera": "ébourgeonner",
    "ébourgeonnerai": "ébourgeonner",
    "ébourgeonneraient": "ébourgeonner",
    "ébourgeonnerais": "ébourgeonner",
    "ébourgeonnerait": "ébourgeonner",
    "ébourgeonneras": "ébourgeonner",
    "ébourgeonnerez": "ébourgeonner",
    "ébourgeonneriez": "ébourgeonner",
    "ébourgeonnerions": "ébourgeonner",
    "ébourgeonnerons": "ébourgeonner",
    "ébourgeonneront": "ébourgeonner",
    "ébourgeonnes": "ébourgeonner",
    "ébourgeonnez": "ébourgeonner",
    "ébourgeonniez": "ébourgeonner",
    "ébourgeonnions": "ébourgeonner",
    "ébourgeonnons": "ébourgeonner",
    "ébourgeonnâmes": "ébourgeonner",
    "ébourgeonnât": "ébourgeonner",
    "ébourgeonnâtes": "ébourgeonner",
    "ébourgeonnèrent": "ébourgeonner",
    "ébourgeonné": "ébourgeonner",
    "ébourgeonnée": "ébourgeonner",
    "ébourgeonnées": "ébourgeonner",
    "ébourgeonnés": "ébourgeonner",
    "ébouriffa": "ébouriffer",
    "ébouriffai": "ébouriffer",
    "ébouriffaient": "ébouriffer",
    "ébouriffais": "ébouriffer",
    "ébouriffait": "ébouriffer",
    "ébouriffant": "ébouriffer",
    "ébouriffante": "ébouriffant",
    "ébouriffas": "ébouriffer",
    "ébouriffasse": "ébouriffer",
    "ébouriffassent": "ébouriffer",
    "ébouriffasses": "ébouriffer",
    "ébouriffassiez": "ébouriffer",
    "ébouriffassions": "ébouriffer",
    "ébouriffe": "ébouriffer",
    "ébouriffent": "ébouriffer",
    "ébouriffera": "ébouriffer",
    "ébourifferai": "ébouriffer",
    "ébourifferaient": "ébouriffer",
    "ébourifferais": "ébouriffer",
    "ébourifferait": "ébouriffer",
    "ébourifferas": "ébouriffer",
    "ébourifferez": "ébouriffer",
    "ébourifferiez": "ébouriffer",
    "ébourifferions": "ébouriffer",
    "ébourifferons": "ébouriffer",
    "ébourifferont": "ébouriffer",
    "ébouriffes": "ébouriffer",
    "ébouriffez": "ébouriffer",
    "ébouriffiez": "ébouriffer",
    "ébouriffions": "ébouriffer",
    "ébouriffons": "ébouriffer",
    "ébouriffâmes": "ébouriffer",
    "ébouriffât": "ébouriffer",
    "ébouriffâtes": "ébouriffer",
    "ébouriffèrent": "ébouriffer",
    "ébouriffé": "ébouriffer",
    "ébouriffée": "ébouriffer",
    "ébouriffées": "ébouriffer",
    "ébouriffés": "ébouriffer",
    "ébourra": "ébourrer",
    "ébourrai": "ébourrer",
    "ébourraient": "ébourrer",
    "ébourrais": "ébourrer",
    "ébourrait": "ébourrer",
    "ébourrant": "ébourrer",
    "ébourras": "ébourrer",
    "ébourrasse": "ébourrer",
    "ébourrassent": "ébourrer",
    "ébourrasses": "ébourrer",
    "ébourrassiez": "ébourrer",
    "ébourrassions": "ébourrer",
    "ébourre": "ébourrer",
    "ébourrent": "ébourrer",
    "ébourrera": "ébourrer",
    "ébourrerai": "ébourrer",
    "ébourreraient": "ébourrer",
    "ébourrerais": "ébourrer",
    "ébourrerait": "ébourrer",
    "ébourreras": "ébourrer",
    "ébourrerez": "ébourrer",
    "ébourreriez": "ébourrer",
    "ébourrerions": "ébourrer",
    "ébourrerons": "ébourrer",
    "ébourreront": "ébourrer",
    "ébourres": "ébourrer",
    "ébourrez": "ébourrer",
    "ébourriez": "ébourrer",
    "ébourrions": "ébourrer",
    "ébourrons": "ébourrer",
    "ébourrâmes": "ébourrer",
    "ébourrât": "ébourrer",
    "ébourrâtes": "ébourrer",
    "ébourrèrent": "ébourrer",
    "ébourré": "ébourrer",
    "ébourrée": "ébourrer",
    "ébourrées": "ébourrer",
    "ébourrés": "ébourrer",
    "ébouta": "ébouter",
    "éboutai": "ébouter",
    "éboutaient": "ébouter",
    "éboutais": "ébouter",
    "éboutait": "ébouter",
    "éboutant": "ébouter",
    "éboutas": "ébouter",
    "éboutasse": "ébouter",
    "éboutassent": "ébouter",
    "éboutasses": "ébouter",
    "éboutassiez": "ébouter",
    "éboutassions": "ébouter",
    "éboute": "ébouter",
    "éboutent": "ébouter",
    "éboutera": "ébouter",
    "ébouterai": "ébouter",
    "ébouteraient": "ébouter",
    "ébouterais": "ébouter",
    "ébouterait": "ébouter",
    "ébouteras": "ébouter",
    "ébouterez": "ébouter",
    "ébouteriez": "ébouter",
    "ébouterions": "ébouter",
    "ébouterons": "ébouter",
    "ébouteront": "ébouter",
    "éboutes": "ébouter",
    "éboutez": "ébouter",
    "éboutiez": "ébouter",
    "éboutions": "ébouter",
    "éboutons": "ébouter",
    "éboutâmes": "ébouter",
    "éboutât": "ébouter",
    "éboutâtes": "ébouter",
    "éboutèrent": "ébouter",
    "ébouté": "ébouter",
    "éboutée": "ébouter",
    "éboutées": "ébouter",
    "éboutés": "ébouter",
    "ébouzé": "ébouzer",
    "éboué": "ébouer",
    "ébrancha": "ébrancher",
    "ébranchai": "ébrancher",
    "ébranchaient": "ébrancher",
    "ébranchais": "ébrancher",
    "ébranchait": "ébrancher",
    "ébranchant": "ébrancher",
    "ébranchas": "ébrancher",
    "ébranchasse": "ébrancher",
    "ébranchassent": "ébrancher",
    "ébranchasses": "ébrancher",
    "ébranchassiez": "ébrancher",
    "ébranchassions": "ébrancher",
    "ébranche": "ébrancher",
    "ébranchent": "ébrancher",
    "ébranchera": "ébrancher",
    "ébrancherai": "ébrancher",
    "ébrancheraient": "ébrancher",
    "ébrancherais": "ébrancher",
    "ébrancherait": "ébrancher",
    "ébrancheras": "ébrancher",
    "ébrancherez": "ébrancher",
    "ébrancheriez": "ébrancher",
    "ébrancherions": "ébrancher",
    "ébrancherons": "ébrancher",
    "ébrancheront": "ébrancher",
    "ébranches": "ébrancher",
    "ébranchez": "ébrancher",
    "ébranchiez": "ébrancher",
    "ébranchions": "ébrancher",
    "ébranchons": "ébrancher",
    "ébranchâmes": "ébrancher",
    "ébranchât": "ébrancher",
    "ébranchâtes": "ébrancher",
    "ébranchèrent": "ébrancher",
    "ébranché": "ébrancher",
    "ébranchée": "ébrancher",
    "ébranchées": "ébrancher",
    "ébranchés": "ébrancher",
    "ébranla": "ébranler",
    "ébranlai": "ébranler",
    "ébranlaient": "ébranler",
    "ébranlais": "ébranler",
    "ébranlait": "ébranler",
    "ébranlant": "ébranler",
    "ébranlas": "ébranler",
    "ébranlasse": "ébranler",
    "ébranlassent": "ébranler",
    "ébranlasses": "ébranler",
    "ébranlassiez": "ébranler",
    "ébranlassions": "ébranler",
    "ébranle": "ébranler",
    "ébranlements": "ébranlement",
    "ébranlent": "ébranler",
    "ébranlera": "ébranler",
    "ébranlerai": "ébranler",
    "ébranleraient": "ébranler",
    "ébranlerais": "ébranler",
    "ébranlerait": "ébranler",
    "ébranleras": "ébranler",
    "ébranlerez": "ébranler",
    "ébranleriez": "ébranler",
    "ébranlerions": "ébranler",
    "ébranlerons": "ébranler",
    "ébranleront": "ébranler",
    "ébranles": "ébranler",
    "ébranlez": "ébranler",
    "ébranliez": "ébranler",
    "ébranlions": "ébranler",
    "ébranlons": "ébranler",
    "ébranlâmes": "ébranler",
    "ébranlât": "ébranler",
    "ébranlâtes": "ébranler",
    "ébranlèrent": "ébranler",
    "ébranlé": "ébranler",
    "ébranlée": "ébranler",
    "ébranlées": "ébranler",
    "ébranlés": "ébranler",
    "ébrasa": "ébraser",
    "ébrasai": "ébraser",
    "ébrasaient": "ébraser",
    "ébrasais": "ébraser",
    "ébrasait": "ébraser",
    "ébrasant": "ébraser",
    "ébrasas": "ébraser",
    "ébrasasse": "ébraser",
    "ébrasassent": "ébraser",
    "ébrasasses": "ébraser",
    "ébrasassiez": "ébraser",
    "ébrasassions": "ébraser",
    "ébrase": "ébraser",
    "ébrasent": "ébraser",
    "ébrasera": "ébraser",
    "ébraserai": "ébraser",
    "ébraseraient": "ébraser",
    "ébraserais": "ébraser",
    "ébraserait": "ébraser",
    "ébraseras": "ébraser",
    "ébraserez": "ébraser",
    "ébraseriez": "ébraser",
    "ébraserions": "ébraser",
    "ébraserons": "ébraser",
    "ébraseront": "ébraser",
    "ébrases": "ébraser",
    "ébrasez": "ébraser",
    "ébrasiez": "ébraser",
    "ébrasions": "ébraser",
    "ébrasons": "ébraser",
    "ébrasâmes": "ébraser",
    "ébrasât": "ébraser",
    "ébrasâtes": "ébraser",
    "ébrasèrent": "ébraser",
    "ébrasé": "ébraser",
    "ébrasée": "ébraser",
    "ébrasées": "ébraser",
    "ébrasés": "ébraser",
    "ébriétés": "ébriété",
    "ébroua": "ébrouer",
    "ébrouai": "ébrouer",
    "ébrouaient": "ébrouer",
    "ébrouais": "ébrouer",
    "ébrouait": "ébrouer",
    "ébrouant": "ébrouer",
    "ébrouas": "ébrouer",
    "ébrouasse": "ébrouer",
    "ébrouassent": "ébrouer",
    "ébrouasses": "ébrouer",
    "ébrouassiez": "ébrouer",
    "ébrouassions": "ébrouer",
    "ébroue": "ébrouer",
    "ébrouent": "ébrouer",
    "ébrouera": "ébrouer",
    "ébrouerai": "ébrouer",
    "ébroueraient": "ébrouer",
    "ébrouerais": "ébrouer",
    "ébrouerait": "ébrouer",
    "ébroueras": "ébrouer",
    "ébrouerez": "ébrouer",
    "ébroueriez": "ébrouer",
    "ébrouerions": "ébrouer",
    "ébrouerons": "ébrouer",
    "ébroueront": "ébrouer",
    "ébroues": "ébrouer",
    "ébrouez": "ébrouer",
    "ébrouiez": "ébrouer",
    "ébrouions": "ébrouer",
    "ébrouons": "ébrouer",
    "ébrouâmes": "ébrouer",
    "ébrouât": "ébrouer",
    "ébrouâtes": "ébrouer",
    "ébrouèrent": "ébrouer",
    "ébroué": "ébrouer",
    "ébrouée": "ébrouer",
    "ébrouées": "ébrouer",
    "ébroués": "ébrouer",
    "ébruita": "ébruiter",
    "ébruitai": "ébruiter",
    "ébruitaient": "ébruiter",
    "ébruitais": "ébruiter",
    "ébruitait": "ébruiter",
    "ébruitant": "ébruiter",
    "ébruitas": "ébruiter",
    "ébruitasse": "ébruiter",
    "ébruitassent": "ébruiter",
    "ébruitasses": "ébruiter",
    "ébruitassiez": "ébruiter",
    "ébruitassions": "ébruiter",
    "ébruite": "ébruiter",
    "ébruitent": "ébruiter",
    "ébruitera": "ébruiter",
    "ébruiterai": "ébruiter",
    "ébruiteraient": "ébruiter",
    "ébruiterais": "ébruiter",
    "ébruiterait": "ébruiter",
    "ébruiteras": "ébruiter",
    "ébruiterez": "ébruiter",
    "ébruiteriez": "ébruiter",
    "ébruiterions": "ébruiter",
    "ébruiterons": "ébruiter",
    "ébruiteront": "ébruiter",
    "ébruites": "ébruiter",
    "ébruitez": "ébruiter",
    "ébruitiez": "ébruiter",
    "ébruitions": "ébruiter",
    "ébruitons": "ébruiter",
    "ébruitâmes": "ébruiter",
    "ébruitât": "ébruiter",
    "ébruitâtes": "ébruiter",
    "ébruitèrent": "ébruiter",
    "ébruité": "ébruiter",
    "ébruitée": "ébruiter",
    "ébruitées": "ébruiter",
    "ébruités": "ébruiter",
    "ébrèche": "ébrécher",
    "ébrèchements": "ébrèchement",
    "ébrèchent": "ébrécher",
    "ébrèches": "ébrécher",
    "ébrécha": "ébrécher",
    "ébréchai": "ébrécher",
    "ébréchaient": "ébrécher",
    "ébréchais": "ébrécher",
    "ébréchait": "ébrécher",
    "ébréchant": "ébrécher",
    "ébréchas": "ébrécher",
    "ébréchasse": "ébrécher",
    "ébréchassent": "ébrécher",
    "ébréchasses": "ébrécher",
    "ébréchassiez": "ébrécher",
    "ébréchassions": "ébrécher",
    "ébréchera": "ébrécher",
    "ébrécherai": "ébrécher",
    "ébrécheraient": "ébrécher",
    "ébrécherais": "ébrécher",
    "ébrécherait": "ébrécher",
    "ébrécheras": "ébrécher",
    "ébrécherez": "ébrécher",
    "ébrécheriez": "ébrécher",
    "ébrécherions": "ébrécher",
    "ébrécherons": "ébrécher",
    "ébrécheront": "ébrécher",
    "ébréchez": "ébrécher",
    "ébréchiez": "ébrécher",
    "ébréchions": "ébrécher",
    "ébréchons": "ébrécher",
    "ébréchures": "ébréchure",
    "ébréchâmes": "ébrécher",
    "ébréchât": "ébrécher",
    "ébréchâtes": "ébrécher",
    "ébréchèrent": "ébrécher",
    "ébréché": "ébrécher",
    "ébréchée": "ébrécher",
    "ébréchées": "ébrécher",
    "ébréchés": "ébrécher",
    "ébullitions": "ébullition",
    "éburnéenne": "éburnéen",
    "éburnéennes": "éburnéen",
    "éburnéens": "éburnéen",
    "ébènes": "ébène",
    "ébénisteries": "ébénisterie",
    "ébénistes": "ébéniste",
    "écacha": "écacher",
    "écachai": "écacher",
    "écachaient": "écacher",
    "écachais": "écacher",
    "écachait": "écacher",
    "écachant": "écacher",
    "écachas": "écacher",
    "écachasse": "écacher",
    "écachassent": "écacher",
    "écachasses": "écacher",
    "écachassiez": "écacher",
    "écachassions": "écacher",
    "écache": "écacher",
    "écachent": "écacher",
    "écachera": "écacher",
    "écacherai": "écacher",
    "écacheraient": "écacher",
    "écacherais": "écacher",
    "écacherait": "écacher",
    "écacheras": "écacher",
    "écacherez": "écacher",
    "écacheriez": "écacher",
    "écacherions": "écacher",
    "écacherons": "écacher",
    "écacheront": "écacher",
    "écaches": "écacher",
    "écachez": "écacher",
    "écachiez": "écacher",
    "écachions": "écacher",
    "écachons": "écacher",
    "écachâmes": "écacher",
    "écachât": "écacher",
    "écachâtes": "écacher",
    "écachèrent": "écacher",
    "écaché": "écacher",
    "écachée": "écacher",
    "écachées": "écacher",
    "écachés": "écacher",
    "écailla": "écailler",
    "écaillai": "écailler",
    "écaillaient": "écailler",
    "écaillais": "écailler",
    "écaillait": "écailler",
    "écaillant": "écailler",
    "écaillas": "écailler",
    "écaillasse": "écailler",
    "écaillassent": "écailler",
    "écaillasses": "écailler",
    "écaillassiez": "écailler",
    "écaillassions": "écailler",
    "écaille": "écailler",
    "écaillent": "écailler",
    "écaillera": "écailler",
    "écaillerai": "écailler",
    "écailleraient": "écailler",
    "écaillerais": "écailler",
    "écaillerait": "écailler",
    "écailleras": "écailler",
    "écaillerez": "écailler",
    "écailleriez": "écailler",
    "écaillerions": "écailler",
    "écaillerons": "écailler",
    "écailleront": "écailler",
    "écaillers": "écailler",
    "écailles": "écailler",
    "écailleuse": "écailleux",
    "écailleuses": "écailleux",
    "écaillez": "écailler",
    "écailliez": "écailler",
    "écaillions": "écailler",
    "écaillons": "écailler",
    "écaillures": "écaillure",
    "écaillâmes": "écailler",
    "écaillât": "écailler",
    "écaillâtes": "écailler",
    "écaillère": "écailler",
    "écaillèrent": "écailler",
    "écaillé": "écailler",
    "écaillée": "écailler",
    "écaillées": "écailler",
    "écaillés": "écailler",
    "écalait": "écaler",
    "écales": "écale",
    "écarlates": "écarlate",
    "écarquilla": "écarquiller",
    "écarquillai": "écarquiller",
    "écarquillaient": "écarquiller",
    "écarquillais": "écarquiller",
    "écarquillait": "écarquiller",
    "écarquillant": "écarquiller",
    "écarquillas": "écarquiller",
    "écarquillasse": "écarquiller",
    "écarquillassent": "écarquiller",
    "écarquillasses": "écarquiller",
    "écarquillassiez": "écarquiller",
    "écarquillassions": "écarquiller",
    "écarquille": "écarquiller",
    "écarquillent": "écarquiller",
    "écarquillera": "écarquiller",
    "écarquillerai": "écarquiller",
    "écarquilleraient": "écarquiller",
    "écarquillerais": "écarquiller",
    "écarquillerait": "écarquiller",
    "écarquilleras": "écarquiller",
    "écarquillerez": "écarquiller",
    "écarquilleriez": "écarquiller",
    "écarquillerions": "écarquiller",
    "écarquillerons": "écarquiller",
    "écarquilleront": "écarquiller",
    "écarquilles": "écarquiller",
    "écarquillez": "écarquiller",
    "écarquilliez": "écarquiller",
    "écarquillions": "écarquiller",
    "écarquillons": "écarquiller",
    "écarquillâmes": "écarquiller",
    "écarquillât": "écarquiller",
    "écarquillâtes": "écarquiller",
    "écarquillèrent": "écarquiller",
    "écarquillé": "écarquiller",
    "écarquillée": "écarquiller",
    "écarquillées": "écarquiller",
    "écarquillés": "écarquiller",
    "écarta": "écarter",
    "écartai": "écarter",
    "écartaient": "écarter",
    "écartais": "écarter",
    "écartait": "écarter",
    "écartant": "écarter",
    "écartas": "écarter",
    "écartasse": "écarter",
    "écartassent": "écarter",
    "écartasses": "écarter",
    "écartassiez": "écarter",
    "écartassions": "écarter",
    "écarte": "écarter",
    "écartela": "écarteler",
    "écartelages": "écartelage",
    "écartelai": "écarteler",
    "écartelaient": "écarteler",
    "écartelais": "écarteler",
    "écartelait": "écarteler",
    "écartelant": "écarteler",
    "écartelas": "écarteler",
    "écartelasse": "écarteler",
    "écartelassent": "écarteler",
    "écartelasses": "écarteler",
    "écartelassiez": "écarteler",
    "écartelassions": "écarteler",
    "écartelez": "écarteler",
    "écarteliez": "écarteler",
    "écartelions": "écarteler",
    "écartelons": "écarteler",
    "écartelâmes": "écarteler",
    "écartelât": "écarteler",
    "écartelâtes": "écarteler",
    "écartelèrent": "écarteler",
    "écartelé": "écarteler",
    "écartelée": "écarteler",
    "écartelées": "écarteler",
    "écartelés": "écarteler",
    "écartements": "écartement",
    "écartent": "écarter",
    "écartera": "écarter",
    "écarterai": "écarter",
    "écarteraient": "écarter",
    "écarterais": "écarter",
    "écarterait": "écarter",
    "écarteras": "écarter",
    "écarterez": "écarter",
    "écarteriez": "écarter",
    "écarterions": "écarter",
    "écarterons": "écarter",
    "écarteront": "écarter",
    "écartes": "écarter",
    "écartez": "écarter",
    "écartiez": "écarter",
    "écartions": "écarter",
    "écartons": "écarter",
    "écarts": "écart",
    "écartâmes": "écarter",
    "écartât": "écarter",
    "écartâtes": "écarter",
    "écartèle": "écarteler",
    "écartèlements": "écartèlement",
    "écartèlent": "écarteler",
    "écartèlera": "écarteler",
    "écartèlerai": "écarteler",
    "écartèleraient": "écarteler",
    "écartèlerais": "écarteler",
    "écartèlerait": "écarteler",
    "écartèleras": "écarteler",
    "écartèlerez": "écarteler",
    "écartèleriez": "écarteler",
    "écartèlerions": "écarteler",
    "écartèlerons": "écarteler",
    "écartèleront": "écarteler",
    "écartèles": "écarteler",
    "écartèrent": "écarter",
    "écarté": "écarter",
    "écartée": "écarter",
    "écartées": "écarter",
    "écartés": "écarter",
    "écati": "écatir",
    "écatie": "écatir",
    "écaties": "écatir",
    "écatira": "écatir",
    "écatirai": "écatir",
    "écatiraient": "écatir",
    "écatirais": "écatir",
    "écatirait": "écatir",
    "écatiras": "écatir",
    "écatirent": "écatir",
    "écatirez": "écatir",
    "écatiriez": "écatir",
    "écatirions": "écatir",
    "écatirons": "écatir",
    "écatiront": "écatir",
    "écatis": "écatir",
    "écatissaient": "écatir",
    "écatissais": "écatir",
    "écatissait": "écatir",
    "écatissant": "écatir",
    "écatisse": "écatir",
    "écatissent": "écatir",
    "écatisses": "écatir",
    "écatissez": "écatir",
    "écatissiez": "écatir",
    "écatissions": "écatir",
    "écatissons": "écatir",
    "écatit": "écatir",
    "écatîmes": "écatir",
    "écatît": "écatir",
    "écatîtes": "écatir",
    "écervelée": "écervelé",
    "écervelées": "écervelé",
    "écervelés": "écervelé",
    "échafauda": "échafauder",
    "échafaudages": "échafaudage",
    "échafaudai": "échafauder",
    "échafaudaient": "échafauder",
    "échafaudais": "échafauder",
    "échafaudait": "échafauder",
    "échafaudant": "échafauder",
    "échafaudas": "échafauder",
    "échafaudasse": "échafauder",
    "échafaudassent": "échafauder",
    "échafaudasses": "échafauder",
    "échafaudassiez": "échafauder",
    "échafaudassions": "échafauder",
    "échafaude": "échafauder",
    "échafaudent": "échafauder",
    "échafaudera": "échafauder",
    "échafauderai": "échafauder",
    "échafauderaient": "échafauder",
    "échafauderais": "échafauder",
    "échafauderait": "échafauder",
    "échafauderas": "échafauder",
    "échafauderez": "échafauder",
    "échafauderiez": "échafauder",
    "échafauderions": "échafauder",
    "échafauderons": "échafauder",
    "échafauderont": "échafauder",
    "échafaudes": "échafauder",
    "échafaudez": "échafauder",
    "échafaudiez": "échafauder",
    "échafaudions": "échafauder",
    "échafaudons": "échafauder",
    "échafauds": "échafaud",
    "échafaudâmes": "échafauder",
    "échafaudât": "échafauder",
    "échafaudâtes": "échafauder",
    "échafaudèrent": "échafauder",
    "échafaudé": "échafauder",
    "échafaudée": "échafauder",
    "échafaudées": "échafauder",
    "échafaudés": "échafauder",
    "échaliers": "échalier",
    "échalotes": "échalote",
    "échampi": "échampir",
    "échampie": "échampir",
    "échampies": "échampir",
    "échampira": "échampir",
    "échampirai": "échampir",
    "échampiraient": "échampir",
    "échampirais": "échampir",
    "échampirait": "échampir",
    "échampiras": "échampir",
    "échampirent": "échampir",
    "échampirez": "échampir",
    "échampiriez": "échampir",
    "échampirions": "échampir",
    "échampirons": "échampir",
    "échampiront": "échampir",
    "échampis": "échampir",
    "échampissaient": "échampir",
    "échampissais": "échampir",
    "échampissait": "échampir",
    "échampissant": "échampir",
    "échampisse": "échampir",
    "échampissent": "échampir",
    "échampisses": "échampir",
    "échampissez": "échampir",
    "échampissiez": "échampir",
    "échampissions": "échampir",
    "échampissons": "échampir",
    "échampit": "échampir",
    "échampîmes": "échampir",
    "échampît": "échampir",
    "échampîtes": "échampir",
    "échancra": "échancrer",
    "échancrai": "échancrer",
    "échancraient": "échancrer",
    "échancrais": "échancrer",
    "échancrait": "échancrer",
    "échancrant": "échancrer",
    "échancras": "échancrer",
    "échancrasse": "échancrer",
    "échancrassent": "échancrer",
    "échancrasses": "échancrer",
    "échancrassiez": "échancrer",
    "échancrassions": "échancrer",
    "échancre": "échancrer",
    "échancrent": "échancrer",
    "échancrera": "échancrer",
    "échancrerai": "échancrer",
    "échancreraient": "échancrer",
    "échancrerais": "échancrer",
    "échancrerait": "échancrer",
    "échancreras": "échancrer",
    "échancrerez": "échancrer",
    "échancreriez": "échancrer",
    "échancrerions": "échancrer",
    "échancrerons": "échancrer",
    "échancreront": "échancrer",
    "échancres": "échancrer",
    "échancrez": "échancrer",
    "échancriez": "échancrer",
    "échancrions": "échancrer",
    "échancrons": "échancrer",
    "échancrures": "échancrure",
    "échancrâmes": "échancrer",
    "échancrât": "échancrer",
    "échancrâtes": "échancrer",
    "échancrèrent": "échancrer",
    "échancré": "échancrer",
    "échancrée": "échancrer",
    "échancrées": "échancrer",
    "échancrés": "échancrer",
    "échange": "échanger",
    "échangea": "échanger",
    "échangeables": "échangeable",
    "échangeai": "échanger",
    "échangeaient": "échanger",
    "échangeais": "échanger",
    "échangeait": "échanger",
    "échangeant": "échanger",
    "échangeas": "échanger",
    "échangeasse": "échanger",
    "échangeassent": "échanger",
    "échangeasses": "échanger",
    "échangeassiez": "échanger",
    "échangeassions": "échanger",
    "échangent": "échanger",
    "échangeons": "échanger",
    "échangera": "échanger",
    "échangerai": "échanger",
    "échangeraient": "échanger",
    "échangerais": "échanger",
    "échangerait": "échanger",
    "échangeras": "échanger",
    "échangerez": "échanger",
    "échangeriez": "échanger",
    "échangerions": "échanger",
    "échangerons": "échanger",
    "échangeront": "échanger",
    "échanges": "échanger",
    "échangeurs": "échangeur",
    "échangez": "échanger",
    "échangeâmes": "échanger",
    "échangeât": "échanger",
    "échangeâtes": "échanger",
    "échangiez": "échanger",
    "échangions": "échanger",
    "échangistes": "échangiste",
    "échangèrent": "échanger",
    "échangé": "échanger",
    "échangée": "échanger",
    "échangées": "échanger",
    "échangés": "échanger",
    "échansons": "échanson",
    "échantillonna": "échantillonner",
    "échantillonnages": "échantillonnage",
    "échantillonnai": "échantillonner",
    "échantillonnaient": "échantillonner",
    "échantillonnais": "échantillonner",
    "échantillonnait": "échantillonner",
    "échantillonnant": "échantillonner",
    "échantillonnas": "échantillonner",
    "échantillonnasse": "échantillonner",
    "échantillonnassent": "échantillonner",
    "échantillonnasses": "échantillonner",
    "échantillonnassiez": "échantillonner",
    "échantillonnassions": "échantillonner",
    "échantillonne": "échantillonner",
    "échantillonnent": "échantillonner",
    "échantillonnera": "échantillonner",
    "échantillonnerai": "échantillonner",
    "échantillonneraient": "échantillonner",
    "échantillonnerais": "échantillonner",
    "échantillonnerait": "échantillonner",
    "échantillonneras": "échantillonner",
    "échantillonnerez": "échantillonner",
    "échantillonneriez": "échantillonner",
    "échantillonnerions": "échantillonner",
    "échantillonnerons": "échantillonner",
    "échantillonneront": "échantillonner",
    "échantillonnes": "échantillonner",
    "échantillonnez": "échantillonner",
    "échantillonniez": "échantillonner",
    "échantillonnions": "échantillonner",
    "échantillonnons": "échantillonner",
    "échantillonnâmes": "échantillonner",
    "échantillonnât": "échantillonner",
    "échantillonnâtes": "échantillonner",
    "échantillonnèrent": "échantillonner",
    "échantillonné": "échantillonner",
    "échantillonnée": "échantillonner",
    "échantillonnées": "échantillonner",
    "échantillonnés": "échantillonner",
    "échantillons": "échantillon",
    "échappa": "échapper",
    "échappai": "échapper",
    "échappaient": "échapper",
    "échappais": "échapper",
    "échappait": "échapper",
    "échappant": "échapper",
    "échappas": "échapper",
    "échappasse": "échapper",
    "échappassent": "échapper",
    "échappasses": "échapper",
    "échappassiez": "échapper",
    "échappassions": "échapper",
    "échappatoires": "échappatoire",
    "échappe": "échapper",
    "échappements": "échappement",
    "échappent": "échapper",
    "échappera": "échapper",
    "échapperai": "échapper",
    "échapperaient": "échapper",
    "échapperais": "échapper",
    "échapperait": "échapper",
    "échapperas": "échapper",
    "échapperez": "échapper",
    "échapperiez": "échapper",
    "échapperions": "échapper",
    "échapperons": "échapper",
    "échapperont": "échapper",
    "échappes": "échapper",
    "échappez": "échapper",
    "échappiez": "échapper",
    "échappions": "échapper",
    "échappons": "échapper",
    "échappâmes": "échapper",
    "échappât": "échapper",
    "échappâtes": "échapper",
    "échappèrent": "échapper",
    "échappé": "échapper",
    "échappée": "échapper",
    "échappées": "échapper",
    "échappés": "échapper",
    "échardes": "écharde",
    "écharnait": "écharner",
    "écharpe": "écharper",
    "écharpent": "écharper",
    "écharperaient": "écharper",
    "écharpes": "écharper",
    "écharpé": "écharper",
    "écharpée": "écharper",
    "échasses": "échasse",
    "échassiers": "échassier",
    "échassière": "échassier",
    "échassières": "échassier",
    "échauda": "échauder",
    "échaudai": "échauder",
    "échaudaient": "échauder",
    "échaudais": "échauder",
    "échaudait": "échauder",
    "échaudant": "échauder",
    "échaudas": "échauder",
    "échaudasse": "échauder",
    "échaudassent": "échauder",
    "échaudasses": "échauder",
    "échaudassiez": "échauder",
    "échaudassions": "échauder",
    "échaude": "échauder",
    "échaudent": "échauder",
    "échaudera": "échauder",
    "échauderai": "échauder",
    "échauderaient": "échauder",
    "échauderais": "échauder",
    "échauderait": "échauder",
    "échauderas": "échauder",
    "échauderez": "échauder",
    "échauderiez": "échauder",
    "échauderions": "échauder",
    "échauderons": "échauder",
    "échauderont": "échauder",
    "échaudes": "échauder",
    "échaudez": "échauder",
    "échaudiez": "échauder",
    "échaudions": "échauder",
    "échaudons": "échauder",
    "échaudâmes": "échauder",
    "échaudât": "échauder",
    "échaudâtes": "échauder",
    "échaudèrent": "échauder",
    "échaudé": "échauder",
    "échaudée": "échauder",
    "échaudées": "échauder",
    "échaudés": "échauder",
    "échauffa": "échauffer",
    "échauffai": "échauffer",
    "échauffaient": "échauffer",
    "échauffais": "échauffer",
    "échauffait": "échauffer",
    "échauffant": "échauffer",
    "échauffas": "échauffer",
    "échauffasse": "échauffer",
    "échauffassent": "échauffer",
    "échauffasses": "échauffer",
    "échauffassiez": "échauffer",
    "échauffassions": "échauffer",
    "échauffe": "échauffer",
    "échauffements": "échauffement",
    "échauffent": "échauffer",
    "échauffera": "échauffer",
    "échaufferai": "échauffer",
    "échaufferaient": "échauffer",
    "échaufferais": "échauffer",
    "échaufferait": "échauffer",
    "échaufferas": "échauffer",
    "échaufferez": "échauffer",
    "échaufferiez": "échauffer",
    "échaufferions": "échauffer",
    "échaufferons": "échauffer",
    "échaufferont": "échauffer",
    "échauffes": "échauffer",
    "échauffez": "échauffer",
    "échauffiez": "échauffer",
    "échauffions": "échauffer",
    "échauffons": "échauffer",
    "échauffourées": "échauffourée",
    "échauffâmes": "échauffer",
    "échauffât": "échauffer",
    "échauffâtes": "échauffer",
    "échauffèrent": "échauffer",
    "échauffé": "échauffer",
    "échauffée": "échauffer",
    "échauffées": "échauffer",
    "échauffés": "échauffer",
    "échauguettes": "échauguette",
    "échecs": "échec",
    "échelles": "échelle",
    "échelonna": "échelonner",
    "échelonnai": "échelonner",
    "échelonnaient": "échelonner",
    "échelonnais": "échelonner",
    "échelonnait": "échelonner",
    "échelonnant": "échelonner",
    "échelonnas": "échelonner",
    "échelonnasse": "échelonner",
    "échelonnassent": "échelonner",
    "échelonnasses": "échelonner",
    "échelonnassiez": "échelonner",
    "échelonnassions": "échelonner",
    "échelonne": "échelonner",
    "échelonnent": "échelonner",
    "échelonnera": "échelonner",
    "échelonnerai": "échelonner",
    "échelonneraient": "échelonner",
    "échelonnerais": "échelonner",
    "échelonnerait": "échelonner",
    "échelonneras": "échelonner",
    "échelonnerez": "échelonner",
    "échelonneriez": "échelonner",
    "échelonnerions": "échelonner",
    "échelonnerons": "échelonner",
    "échelonneront": "échelonner",
    "échelonnes": "échelonner",
    "échelonnez": "échelonner",
    "échelonniez": "échelonner",
    "échelonnions": "échelonner",
    "échelonnons": "échelonner",
    "échelonnâmes": "échelonner",
    "échelonnât": "échelonner",
    "échelonnâtes": "échelonner",
    "échelonnèrent": "échelonner",
    "échelonné": "échelonner",
    "échelonnée": "échelonner",
    "échelonnées": "échelonner",
    "échelonnés": "échelonner",
    "échelons": "échelon",
    "échenilla": "écheniller",
    "échenillai": "écheniller",
    "échenillaient": "écheniller",
    "échenillais": "écheniller",
    "échenillait": "écheniller",
    "échenillant": "écheniller",
    "échenillas": "écheniller",
    "échenillasse": "écheniller",
    "échenillassent": "écheniller",
    "échenillasses": "écheniller",
    "échenillassiez": "écheniller",
    "échenillassions": "écheniller",
    "échenille": "écheniller",
    "échenillent": "écheniller",
    "échenillera": "écheniller",
    "échenillerai": "écheniller",
    "échenilleraient": "écheniller",
    "échenillerais": "écheniller",
    "échenillerait": "écheniller",
    "échenilleras": "écheniller",
    "échenillerez": "écheniller",
    "échenilleriez": "écheniller",
    "échenillerions": "écheniller",
    "échenillerons": "écheniller",
    "échenilleront": "écheniller",
    "échenilles": "écheniller",
    "échenillez": "écheniller",
    "échenilliez": "écheniller",
    "échenillions": "écheniller",
    "échenillons": "écheniller",
    "échenillâmes": "écheniller",
    "échenillât": "écheniller",
    "échenillâtes": "écheniller",
    "échenillèrent": "écheniller",
    "échenillé": "écheniller",
    "échenillée": "écheniller",
    "échenillées": "écheniller",
    "échenillés": "écheniller",
    "échet": "échoir",
    "écheveaux": "écheveau",
    "échevela": "écheveler",
    "échevelai": "écheveler",
    "échevelaient": "écheveler",
    "échevelais": "écheveler",
    "échevelait": "écheveler",
    "échevelant": "écheveler",
    "échevelas": "écheveler",
    "échevelasse": "écheveler",
    "échevelassent": "écheveler",
    "échevelasses": "écheveler",
    "échevelassiez": "écheveler",
    "échevelassions": "écheveler",
    "échevelez": "écheveler",
    "écheveliez": "écheveler",
    "échevelions": "écheveler",
    "échevelle": "écheveler",
    "échevellent": "écheveler",
    "échevellera": "écheveler",
    "échevellerai": "écheveler",
    "échevelleraient": "écheveler",
    "échevellerais": "écheveler",
    "échevellerait": "écheveler",
    "échevelleras": "écheveler",
    "échevellerez": "écheveler",
    "échevelleriez": "écheveler",
    "échevellerions": "écheveler",
    "échevellerons": "écheveler",
    "échevelleront": "écheveler",
    "échevelles": "écheveler",
    "échevelons": "écheveler",
    "échevelâmes": "écheveler",
    "échevelât": "écheveler",
    "échevelâtes": "écheveler",
    "échevelèrent": "écheveler",
    "échevelé": "écheveler",
    "échevelée": "écheveler",
    "échevelées": "écheveler",
    "échevelés": "écheveler",
    "échevinale": "échevinal",
    "échevinales": "échevinal",
    "échevinaux": "échevinal",
    "échevins": "échevin",
    "échidnés": "échidné",
    "échina": "échiner",
    "échinaient": "échiner",
    "échinais": "échiner",
    "échinait": "échiner",
    "échinant": "échiner",
    "échine": "échiner",
    "échinent": "échiner",
    "échines": "échiner",
    "échinodermes": "échinoderme",
    "échiné": "échiner",
    "échinée": "échiner",
    "échiquiers": "échiquier",
    "échographies": "échographie",
    "échoie": "échoir",
    "échoient": "échoir",
    "échoira": "échoir",
    "échoiraient": "échoir",
    "échoirait": "échoir",
    "échoiront": "échoir",
    "échoit": "échoir",
    "écholalies": "écholalie",
    "échoppes": "échoppe",
    "échos": "écho",
    "échos-radars": "échos-radar",
    "échotiers": "échotier",
    "échotière": "échotier",
    "échotières": "échotier",
    "échoua": "échouer",
    "échouages": "échouage",
    "échouai": "échouer",
    "échouaient": "échouer",
    "échouais": "échouer",
    "échouait": "échouer",
    "échouant": "échouer",
    "échouas": "échouer",
    "échouasse": "échouer",
    "échouassent": "échouer",
    "échouasses": "échouer",
    "échouassiez": "échouer",
    "échouassions": "échouer",
    "échoue": "échouer",
    "échouent": "échouer",
    "échouera": "échouer",
    "échouerai": "échouer",
    "échoueraient": "échouer",
    "échouerais": "échouer",
    "échouerait": "échouer",
    "échoueras": "échouer",
    "échouerez": "échouer",
    "échoueriez": "échouer",
    "échouerions": "échouer",
    "échouerons": "échouer",
    "échoueront": "échouer",
    "échoues": "échouer",
    "échouez": "échouer",
    "échouiez": "échouer",
    "échouions": "échouer",
    "échouons": "échouer",
    "échouâmes": "échouer",
    "échouât": "échouer",
    "échouâtes": "échouer",
    "échouèrent": "échouer",
    "échoué": "échouer",
    "échouée": "échouer",
    "échouées": "échouer",
    "échoués": "échouer",
    "échu": "échoir",
    "échue": "échoir",
    "échues": "échoir",
    "échurent": "échoir",
    "échus": "échoir",
    "échussent": "échoir",
    "échut": "échoir",
    "échéances": "échéance",
    "échéanciers": "échéancier",
    "échéant": "échoir",
    "échéante": "échéant",
    "échéantes": "échéant",
    "échéants": "échéant",
    "échéent": "échoir",
    "échérra": "échoir",
    "échérraient": "échoir",
    "échérrait": "échoir",
    "échérront": "échoir",
    "échût": "échoir",
    "écimages": "écimage",
    "éclaboussa": "éclabousser",
    "éclaboussai": "éclabousser",
    "éclaboussaient": "éclabousser",
    "éclaboussais": "éclabousser",
    "éclaboussait": "éclabousser",
    "éclaboussant": "éclabousser",
    "éclaboussante": "éclaboussant",
    "éclaboussantes": "éclaboussant",
    "éclaboussants": "éclaboussant",
    "éclaboussas": "éclabousser",
    "éclaboussasse": "éclabousser",
    "éclaboussassent": "éclabousser",
    "éclaboussasses": "éclabousser",
    "éclaboussassiez": "éclabousser",
    "éclaboussassions": "éclabousser",
    "éclabousse": "éclabousser",
    "éclaboussements": "éclaboussement",
    "éclaboussent": "éclabousser",
    "éclaboussera": "éclabousser",
    "éclabousserai": "éclabousser",
    "éclabousseraient": "éclabousser",
    "éclabousserais": "éclabousser",
    "éclabousserait": "éclabousser",
    "éclabousseras": "éclabousser",
    "éclabousserez": "éclabousser",
    "éclabousseriez": "éclabousser",
    "éclabousserions": "éclabousser",
    "éclabousserons": "éclabousser",
    "éclabousseront": "éclabousser",
    "éclabousses": "éclabousser",
    "éclaboussez": "éclabousser",
    "éclaboussiez": "éclabousser",
    "éclaboussions": "éclabousser",
    "éclaboussons": "éclabousser",
    "éclaboussures": "éclaboussure",
    "éclaboussâmes": "éclabousser",
    "éclaboussât": "éclabousser",
    "éclaboussâtes": "éclabousser",
    "éclaboussèrent": "éclabousser",
    "éclaboussé": "éclabousser",
    "éclaboussée": "éclabousser",
    "éclaboussées": "éclabousser",
    "éclaboussés": "éclabousser",
    "éclaira": "éclairer",
    "éclairages": "éclairage",
    "éclairagistes": "éclairagiste",
    "éclairai": "éclairer",
    "éclairaient": "éclairer",
    "éclairais": "éclairer",
    "éclairait": "éclairer",
    "éclairant": "éclairer",
    "éclairante": "éclairant",
    "éclairantes": "éclairant",
    "éclairants": "éclairant",
    "éclairas": "éclairer",
    "éclairasse": "éclairer",
    "éclairassent": "éclairer",
    "éclairasses": "éclairer",
    "éclairassiez": "éclairer",
    "éclairassions": "éclairer",
    "éclairci": "éclaircir",
    "éclaircie": "éclaircir",
    "éclaircies": "éclaircir",
    "éclaircira": "éclaircir",
    "éclaircirai": "éclaircir",
    "éclairciraient": "éclaircir",
    "éclaircirais": "éclaircir",
    "éclaircirait": "éclaircir",
    "éclairciras": "éclaircir",
    "éclaircirent": "éclaircir",
    "éclaircirez": "éclaircir",
    "éclairciriez": "éclaircir",
    "éclaircirions": "éclaircir",
    "éclaircirons": "éclaircir",
    "éclairciront": "éclaircir",
    "éclaircis": "éclaircir",
    "éclaircissaient": "éclaircir",
    "éclaircissais": "éclaircir",
    "éclaircissait": "éclaircir",
    "éclaircissant": "éclaircir",
    "éclaircisse": "éclaircir",
    "éclaircissements": "éclaircissement",
    "éclaircissent": "éclaircir",
    "éclaircisses": "éclaircir",
    "éclaircissez": "éclaircir",
    "éclaircissiez": "éclaircir",
    "éclaircissions": "éclaircir",
    "éclaircissons": "éclaircir",
    "éclaircit": "éclaircir",
    "éclaircîmes": "éclaircir",
    "éclaircît": "éclaircir",
    "éclaircîtes": "éclaircir",
    "éclaire": "éclairer",
    "éclairent": "éclairer",
    "éclairera": "éclairer",
    "éclairerai": "éclairer",
    "éclaireraient": "éclairer",
    "éclairerais": "éclairer",
    "éclairerait": "éclairer",
    "éclaireras": "éclairer",
    "éclairerez": "éclairer",
    "éclaireriez": "éclairer",
    "éclairerions": "éclairer",
    "éclairerons": "éclairer",
    "éclaireront": "éclairer",
    "éclaires": "éclairer",
    "éclaireurs": "éclaireur",
    "éclaireuse": "éclaireur",
    "éclaireuses": "éclaireur",
    "éclairez": "éclairer",
    "éclairiez": "éclairer",
    "éclairions": "éclairer",
    "éclairons": "éclairer",
    "éclairs": "éclair",
    "éclairâmes": "éclairer",
    "éclairât": "éclairer",
    "éclairâtes": "éclairer",
    "éclairèrent": "éclairer",
    "éclairé": "éclairer",
    "éclairée": "éclairer",
    "éclairées": "éclairer",
    "éclairés": "éclairer",
    "éclampsies": "éclampsie",
    "éclata": "éclater",
    "éclatai": "éclater",
    "éclataient": "éclater",
    "éclatais": "éclater",
    "éclatait": "éclater",
    "éclatant": "éclater",
    "éclatante": "éclatant",
    "éclatantes": "éclatant",
    "éclatants": "éclatant",
    "éclatas": "éclater",
    "éclatasse": "éclater",
    "éclatassent": "éclater",
    "éclatasses": "éclater",
    "éclatassiez": "éclater",
    "éclatassions": "éclater",
    "éclate": "éclater",
    "éclatements": "éclatement",
    "éclatent": "éclater",
    "éclatera": "éclater",
    "éclaterai": "éclater",
    "éclateraient": "éclater",
    "éclaterais": "éclater",
    "éclaterait": "éclater",
    "éclateras": "éclater",
    "éclaterez": "éclater",
    "éclateriez": "éclater",
    "éclaterions": "éclater",
    "éclaterons": "éclater",
    "éclateront": "éclater",
    "éclates": "éclater",
    "éclateurs": "éclateur",
    "éclatez": "éclater",
    "éclatiez": "éclater",
    "éclations": "éclater",
    "éclatons": "éclater",
    "éclats": "éclat",
    "éclatâmes": "éclater",
    "éclatât": "éclater",
    "éclatâtes": "éclater",
    "éclatèrent": "éclater",
    "éclaté": "éclater",
    "éclatée": "éclater",
    "éclatées": "éclater",
    "éclatés": "éclater",
    "éclectiques": "éclectique",
    "éclectismes": "éclectisme",
    "éclipsa": "éclipser",
    "éclipsai": "éclipser",
    "éclipsaient": "éclipser",
    "éclipsais": "éclipser",
    "éclipsait": "éclipser",
    "éclipsant": "éclipser",
    "éclipsas": "éclipser",
    "éclipsasse": "éclipser",
    "éclipsassent": "éclipser",
    "éclipsasses": "éclipser",
    "éclipsassiez": "éclipser",
    "éclipsassions": "éclipser",
    "éclipse": "éclipser",
    "éclipsent": "éclipser",
    "éclipsera": "éclipser",
    "éclipserai": "éclipser",
    "éclipseraient": "éclipser",
    "éclipserais": "éclipser",
    "éclipserait": "éclipser",
    "éclipseras": "éclipser",
    "éclipserez": "éclipser",
    "éclipseriez": "éclipser",
    "éclipserions": "éclipser",
    "éclipserons": "éclipser",
    "éclipseront": "éclipser",
    "éclipses": "éclipser",
    "éclipsez": "éclipser",
    "éclipsiez": "éclipser",
    "éclipsions": "éclipser",
    "éclipsons": "éclipser",
    "éclipsâmes": "éclipser",
    "éclipsât": "éclipser",
    "éclipsâtes": "éclipser",
    "éclipsèrent": "éclipser",
    "éclipsé": "éclipser",
    "éclipsée": "éclipser",
    "éclipsées": "éclipser",
    "éclipsés": "éclipser",
    "éclisses": "éclisse",
    "éclopait": "écloper",
    "éclopé": "écloper",
    "éclopée": "éclopé",
    "éclopées": "éclopé",
    "éclopés": "écloper",
    "éclora": "éclore",
    "écloraient": "éclore",
    "éclorait": "éclore",
    "écloront": "éclore",
    "éclos": "éclore",
    "éclosant": "éclore",
    "éclose": "éclos",
    "éclosent": "éclore",
    "écloseries": "écloserie",
    "écloses": "éclos",
    "éclosions": "éclosion",
    "éclot": "éclore",
    "éclusa": "écluser",
    "éclusaient": "écluser",
    "éclusais": "écluser",
    "éclusait": "écluser",
    "éclusant": "écluser",
    "écluse": "écluser",
    "éclusent": "écluser",
    "écluses": "écluse",
    "éclusiers": "éclusier",
    "éclusé": "écluser",
    "éclusée": "écluser",
    "éclusées": "écluser",
    "écobilans": "écobilan",
    "écobua": "écobuer",
    "écobuai": "écobuer",
    "écobuaient": "écobuer",
    "écobuais": "écobuer",
    "écobuait": "écobuer",
    "écobuant": "écobuer",
    "écobuas": "écobuer",
    "écobuasse": "écobuer",
    "écobuassent": "écobuer",
    "écobuasses": "écobuer",
    "écobuassiez": "écobuer",
    "écobuassions": "écobuer",
    "écobue": "écobuer",
    "écobuent": "écobuer",
    "écobuera": "écobuer",
    "écobuerai": "écobuer",
    "écobueraient": "écobuer",
    "écobuerais": "écobuer",
    "écobuerait": "écobuer",
    "écobueras": "écobuer",
    "écobuerez": "écobuer",
    "écobueriez": "écobuer",
    "écobuerions": "écobuer",
    "écobuerons": "écobuer",
    "écobueront": "écobuer",
    "écobues": "écobuer",
    "écobuez": "écobuer",
    "écobuiez": "écobuer",
    "écobuions": "écobuer",
    "écobuons": "écobuer",
    "écobuâmes": "écobuer",
    "écobuât": "écobuer",
    "écobuâtes": "écobuer",
    "écobuèrent": "écobuer",
    "écobué": "écobuer",
    "écobuée": "écobuer",
    "écobuées": "écobuer",
    "écobués": "écobuer",
    "écoeura": "écoeurer",
    "écoeurai": "écoeurer",
    "écoeuraient": "écoeurer",
    "écoeurais": "écoeurer",
    "écoeurait": "écoeurer",
    "écoeurant": "écoeurer",
    "écoeurante": "écoeurant",
    "écoeurantes": "écoeurant",
    "écoeurants": "écoeurant",
    "écoeuras": "écoeurer",
    "écoeurasse": "écoeurer",
    "écoeurassent": "écoeurer",
    "écoeurasses": "écoeurer",
    "écoeurassiez": "écoeurer",
    "écoeurassions": "écoeurer",
    "écoeure": "écoeurer",
    "écoeurements": "écoeurement",
    "écoeurent": "écoeurer",
    "écoeurera": "écoeurer",
    "écoeurerai": "écoeurer",
    "écoeureraient": "écoeurer",
    "écoeurerais": "écoeurer",
    "écoeurerait": "écoeurer",
    "écoeureras": "écoeurer",
    "écoeurerez": "écoeurer",
    "écoeureriez": "écoeurer",
    "écoeurerions": "écoeurer",
    "écoeurerons": "écoeurer",
    "écoeureront": "écoeurer",
    "écoeures": "écoeurer",
    "écoeurez": "écoeurer",
    "écoeuriez": "écoeurer",
    "écoeurions": "écoeurer",
    "écoeurons": "écoeurer",
    "écoeurâmes": "écoeurer",
    "écoeurât": "écoeurer",
    "écoeurâtes": "écoeurer",
    "écoeurèrent": "écoeurer",
    "écoeuré": "écoeurer",
    "écoeurée": "écoeurer",
    "écoeurées": "écoeurer",
    "écoeurés": "écoeurer",
    "écoinçons": "écoinçon",
    "écoles": "école",
    "écoliers": "écolier",
    "écolière": "écolier",
    "écolières": "écolier",
    "écologies": "écologie",
    "écologiques": "écologique",
    "écologismes": "écologisme",
    "écologistes": "écologiste",
    "écolos": "écolo",
    "écomusées": "écomusée",
    "éconduira": "éconduire",
    "éconduirai": "éconduire",
    "éconduiraient": "éconduire",
    "éconduirais": "éconduire",
    "éconduirait": "éconduire",
    "éconduiras": "éconduire",
    "éconduirez": "éconduire",
    "éconduiriez": "éconduire",
    "éconduirions": "éconduire",
    "éconduirons": "éconduire",
    "éconduiront": "éconduire",
    "éconduis": "éconduire",
    "éconduisaient": "éconduire",
    "éconduisais": "éconduire",
    "éconduisait": "éconduire",
    "éconduisant": "éconduire",
    "éconduise": "éconduire",
    "éconduisent": "éconduire",
    "éconduises": "éconduire",
    "éconduisez": "éconduire",
    "éconduisiez": "éconduire",
    "éconduisions": "éconduire",
    "éconduisirent": "éconduire",
    "éconduisis": "éconduire",
    "éconduisisse": "éconduire",
    "éconduisissent": "éconduire",
    "éconduisisses": "éconduire",
    "éconduisissiez": "éconduire",
    "éconduisissions": "éconduire",
    "éconduisit": "éconduire",
    "éconduisons": "éconduire",
    "éconduisîmes": "éconduire",
    "éconduisît": "éconduire",
    "éconduisîtes": "éconduire",
    "éconduit": "éconduire",
    "éconduite": "éconduire",
    "éconduites": "éconduire",
    "éconduits": "éconduire",
    "économes": "économe",
    "économies": "économie",
    "économiques": "économique",
    "économisa": "économiser",
    "économisai": "économiser",
    "économisaient": "économiser",
    "économisais": "économiser",
    "économisait": "économiser",
    "économisant": "économiser",
    "économisas": "économiser",
    "économisasse": "économiser",
    "économisassent": "économiser",
    "économisasses": "économiser",
    "économisassiez": "économiser",
    "économisassions": "économiser",
    "économise": "économiser",
    "économisent": "économiser",
    "économisera": "économiser",
    "économiserai": "économiser",
    "économiseraient": "économiser",
    "économiserais": "économiser",
    "économiserait": "économiser",
    "économiseras": "économiser",
    "économiserez": "économiser",
    "économiseriez": "économiser",
    "économiserions": "économiser",
    "économiserons": "économiser",
    "économiseront": "économiser",
    "économises": "économiser",
    "économiseurs": "économiseur",
    "économisez": "économiser",
    "économisiez": "économiser",
    "économisions": "économiser",
    "économisons": "économiser",
    "économistes": "économiste",
    "économisâmes": "économiser",
    "économisât": "économiser",
    "économisâtes": "économiser",
    "économisèrent": "économiser",
    "économisé": "économiser",
    "économisée": "économiser",
    "économisées": "économiser",
    "économisés": "économiser",
    "économétries": "économétrie",
    "écopa": "écoper",
    "écopai": "écoper",
    "écopaient": "écoper",
    "écopais": "écoper",
    "écopait": "écoper",
    "écopant": "écoper",
    "écopas": "écoper",
    "écopasse": "écoper",
    "écopassent": "écoper",
    "écopasses": "écoper",
    "écopassiez": "écoper",
    "écopassions": "écoper",
    "écope": "écoper",
    "écopent": "écoper",
    "écopera": "écoper",
    "écoperai": "écoper",
    "écoperaient": "écoper",
    "écoperais": "écoper",
    "écoperait": "écoper",
    "écoperas": "écoper",
    "écoperches": "écoperche",
    "écoperez": "écoper",
    "écoperiez": "écoper",
    "écoperions": "écoper",
    "écoperons": "écoper",
    "écoperont": "écoper",
    "écopes": "écoper",
    "écopez": "écoper",
    "écopiez": "écoper",
    "écopions": "écoper",
    "écopons": "écoper",
    "écopâmes": "écoper",
    "écopât": "écoper",
    "écopâtes": "écoper",
    "écopèrent": "écoper",
    "écopé": "écoper",
    "écopée": "écoper",
    "écopées": "écoper",
    "écopés": "écoper",
    "écorce": "écorcer",
    "écorces": "écorce",
    "écorcha": "écorcher",
    "écorchai": "écorcher",
    "écorchaient": "écorcher",
    "écorchais": "écorcher",
    "écorchait": "écorcher",
    "écorchant": "écorcher",
    "écorchas": "écorcher",
    "écorchasse": "écorcher",
    "écorchassent": "écorcher",
    "écorchasses": "écorcher",
    "écorchassiez": "écorcher",
    "écorchassions": "écorcher",
    "écorche": "écorcher",
    "écorchent": "écorcher",
    "écorchera": "écorcher",
    "écorcherai": "écorcher",
    "écorcheraient": "écorcher",
    "écorcherais": "écorcher",
    "écorcherait": "écorcher",
    "écorcheras": "écorcher",
    "écorcherez": "écorcher",
    "écorcheriez": "écorcher",
    "écorcherions": "écorcher",
    "écorcherons": "écorcher",
    "écorcheront": "écorcher",
    "écorches": "écorcher",
    "écorcheurs": "écorcheur",
    "écorcheuse": "écorcheur",
    "écorcheuses": "écorcheur",
    "écorchez": "écorcher",
    "écorchiez": "écorcher",
    "écorchions": "écorcher",
    "écorchons": "écorcher",
    "écorchures": "écorchure",
    "écorchâmes": "écorcher",
    "écorchât": "écorcher",
    "écorchâtes": "écorcher",
    "écorchèrent": "écorcher",
    "écorché": "écorcher",
    "écorchée": "écorcher",
    "écorchées": "écorcher",
    "écorchés": "écorcher",
    "écorcé": "écorcer",
    "écorcés": "écorcé",
    "écorna": "écorner",
    "écornai": "écorner",
    "écornaient": "écorner",
    "écornais": "écorner",
    "écornait": "écorner",
    "écornant": "écorner",
    "écornas": "écorner",
    "écornasse": "écorner",
    "écornassent": "écorner",
    "écornasses": "écorner",
    "écornassiez": "écorner",
    "écornassions": "écorner",
    "écorne": "écorner",
    "écornent": "écorner",
    "écornera": "écorner",
    "écornerai": "écorner",
    "écorneraient": "écorner",
    "écornerais": "écorner",
    "écornerait": "écorner",
    "écorneras": "écorner",
    "écornerez": "écorner",
    "écorneriez": "écorner",
    "écornerions": "écorner",
    "écornerons": "écorner",
    "écorneront": "écorner",
    "écornes": "écorner",
    "écornez": "écorner",
    "écorniez": "écorner",
    "écornions": "écorner",
    "écornons": "écorner",
    "écornâmes": "écorner",
    "écornât": "écorner",
    "écornâtes": "écorner",
    "écornèrent": "écorner",
    "écorné": "écorner",
    "écornée": "écorner",
    "écornées": "écorner",
    "écornés": "écorner",
    "écossa": "écosser",
    "écossai": "écosser",
    "écossaient": "écosser",
    "écossais": "écosser",
    "écossaise": "écossais",
    "écossaises": "écossais",
    "écossait": "écosser",
    "écossant": "écosser",
    "écossas": "écosser",
    "écossasse": "écosser",
    "écossassent": "écosser",
    "écossasses": "écosser",
    "écossassiez": "écosser",
    "écossassions": "écosser",
    "écosse": "écosser",
    "écossent": "écosser",
    "écossera": "écosser",
    "écosserai": "écosser",
    "écosseraient": "écosser",
    "écosserais": "écosser",
    "écosserait": "écosser",
    "écosseras": "écosser",
    "écosserez": "écosser",
    "écosseriez": "écosser",
    "écosserions": "écosser",
    "écosserons": "écosser",
    "écosseront": "écosser",
    "écosses": "écosser",
    "écossez": "écosser",
    "écossiez": "écosser",
    "écossions": "écosser",
    "écossons": "écosser",
    "écossâmes": "écosser",
    "écossât": "écosser",
    "écossâtes": "écosser",
    "écossèrent": "écosser",
    "écossé": "écosser",
    "écossée": "écosser",
    "écossées": "écosser",
    "écossés": "écosser",
    "écosystèmes": "écosystème",
    "écotourismes": "écotourisme",
    "écotoxicités": "écotoxicité",
    "écots": "écot",
    "écoula": "écouler",
    "écoulai": "écouler",
    "écoulaient": "écouler",
    "écoulais": "écouler",
    "écoulait": "écouler",
    "écoulant": "écouler",
    "écoulas": "écouler",
    "écoulasse": "écouler",
    "écoulassent": "écouler",
    "écoulasses": "écouler",
    "écoulassiez": "écouler",
    "écoulassions": "écouler",
    "écoule": "écouler",
    "écoulements": "écoulement",
    "écoulent": "écouler",
    "écoulera": "écouler",
    "écoulerai": "écouler",
    "écouleraient": "écouler",
    "écoulerais": "écouler",
    "écoulerait": "écouler",
    "écouleras": "écouler",
    "écoulerez": "écouler",
    "écouleriez": "écouler",
    "écoulerions": "écouler",
    "écoulerons": "écouler",
    "écouleront": "écouler",
    "écoules": "écouler",
    "écoulez": "écouler",
    "écouliez": "écouler",
    "écoulions": "écouler",
    "écoulons": "écouler",
    "écoulâmes": "écouler",
    "écoulât": "écouler",
    "écoulâtes": "écouler",
    "écoulèrent": "écouler",
    "écoulé": "écouler",
    "écoulée": "écouler",
    "écoulées": "écouler",
    "écoulés": "écouler",
    "écourgeons": "écourgeon",
    "écourta": "écourter",
    "écourtai": "écourter",
    "écourtaient": "écourter",
    "écourtais": "écourter",
    "écourtait": "écourter",
    "écourtant": "écourter",
    "écourtas": "écourter",
    "écourtasse": "écourter",
    "écourtassent": "écourter",
    "écourtasses": "écourter",
    "écourtassiez": "écourter",
    "écourtassions": "écourter",
    "écourte": "écourter",
    "écourtent": "écourter",
    "écourtera": "écourter",
    "écourterai": "écourter",
    "écourteraient": "écourter",
    "écourterais": "écourter",
    "écourterait": "écourter",
    "écourteras": "écourter",
    "écourterez": "écourter",
    "écourteriez": "écourter",
    "écourterions": "écourter",
    "écourterons": "écourter",
    "écourteront": "écourter",
    "écourtes": "écourter",
    "écourtez": "écourter",
    "écourtiez": "écourter",
    "écourtions": "écourter",
    "écourtons": "écourter",
    "écourtâmes": "écourter",
    "écourtât": "écourter",
    "écourtâtes": "écourter",
    "écourtèrent": "écourter",
    "écourté": "écourter",
    "écourtée": "écourter",
    "écourtées": "écourter",
    "écourtés": "écourter",
    "écouta": "écouter",
    "écoutai": "écouter",
    "écoutaient": "écouter",
    "écoutais": "écouter",
    "écoutait": "écouter",
    "écoutant": "écouter",
    "écoutas": "écouter",
    "écoutasse": "écouter",
    "écoutassent": "écouter",
    "écoutasses": "écouter",
    "écoutassiez": "écouter",
    "écoutassions": "écouter",
    "écoute": "écouter",
    "écoutent": "écouter",
    "écoutera": "écouter",
    "écouterai": "écouter",
    "écouteraient": "écouter",
    "écouterais": "écouter",
    "écouterait": "écouter",
    "écouteras": "écouter",
    "écouterez": "écouter",
    "écouteriez": "écouter",
    "écouterions": "écouter",
    "écouterons": "écouter",
    "écouteront": "écouter",
    "écoutes": "écouter",
    "écouteurs": "écouteur",
    "écouteuse": "écouteur",
    "écoutez": "écouter",
    "écoutiez": "écouter",
    "écoutilles": "écoutille",
    "écoutions": "écouter",
    "écoutons": "écouter",
    "écoutâmes": "écouter",
    "écoutât": "écouter",
    "écoutâtes": "écouter",
    "écoutèrent": "écouter",
    "écouté": "écouter",
    "écoutée": "écouter",
    "écoutées": "écouter",
    "écoutés": "écouter",
    "écouvillonne": "écouvillonner",
    "écouvillons": "écouvillon",
    "écrabouilla": "écrabouiller",
    "écrabouillai": "écrabouiller",
    "écrabouillaient": "écrabouiller",
    "écrabouillais": "écrabouiller",
    "écrabouillait": "écrabouiller",
    "écrabouillant": "écrabouiller",
    "écrabouillas": "écrabouiller",
    "écrabouillasse": "écrabouiller",
    "écrabouillassent": "écrabouiller",
    "écrabouillasses": "écrabouiller",
    "écrabouillassiez": "écrabouiller",
    "écrabouillassions": "écrabouiller",
    "écrabouille": "écrabouiller",
    "écrabouillements": "écrabouillement",
    "écrabouillent": "écrabouiller",
    "écrabouillera": "écrabouiller",
    "écrabouillerai": "écrabouiller",
    "écrabouilleraient": "écrabouiller",
    "écrabouillerais": "écrabouiller",
    "écrabouillerait": "écrabouiller",
    "écrabouilleras": "écrabouiller",
    "écrabouillerez": "écrabouiller",
    "écrabouilleriez": "écrabouiller",
    "écrabouillerions": "écrabouiller",
    "écrabouillerons": "écrabouiller",
    "écrabouilleront": "écrabouiller",
    "écrabouilles": "écrabouiller",
    "écrabouillez": "écrabouiller",
    "écrabouilliez": "écrabouiller",
    "écrabouillions": "écrabouiller",
    "écrabouillons": "écrabouiller",
    "écrabouillâmes": "écrabouiller",
    "écrabouillât": "écrabouiller",
    "écrabouillâtes": "écrabouiller",
    "écrabouillèrent": "écrabouiller",
    "écrabouillé": "écrabouiller",
    "écrabouillée": "écrabouiller",
    "écrabouillées": "écrabouiller",
    "écrabouillés": "écrabouiller",
    "écrans": "écran",
    "écrasa": "écraser",
    "écrasai": "écraser",
    "écrasaient": "écraser",
    "écrasais": "écraser",
    "écrasait": "écraser",
    "écrasant": "écraser",
    "écrasante": "écrasant",
    "écrasantes": "écrasant",
    "écrasants": "écrasant",
    "écrasas": "écraser",
    "écrasasse": "écraser",
    "écrasassent": "écraser",
    "écrasasses": "écraser",
    "écrasassiez": "écraser",
    "écrasassions": "écraser",
    "écrase": "écraser",
    "écrase-merdes": "écrase-merde",
    "écrasements": "écrasement",
    "écrasent": "écraser",
    "écrasera": "écraser",
    "écraserai": "écraser",
    "écraseraient": "écraser",
    "écraserais": "écraser",
    "écraserait": "écraser",
    "écraseras": "écraser",
    "écraserez": "écraser",
    "écraseriez": "écraser",
    "écraserions": "écraser",
    "écraserons": "écraser",
    "écraseront": "écraser",
    "écrases": "écraser",
    "écrasez": "écraser",
    "écrasiez": "écraser",
    "écrasions": "écraser",
    "écrasons": "écraser",
    "écrasâmes": "écraser",
    "écrasât": "écraser",
    "écrasâtes": "écraser",
    "écrasèrent": "écraser",
    "écrasé": "écraser",
    "écrasée": "écraser",
    "écrasées": "écraser",
    "écrasés": "écraser",
    "écrevisses": "écrevisse",
    "écria": "écrier",
    "écriai": "écrier",
    "écriaient": "écrier",
    "écriais": "écrier",
    "écriait": "écrier",
    "écriant": "écrier",
    "écrias": "écrier",
    "écriasse": "écrier",
    "écriassent": "écrier",
    "écriasses": "écrier",
    "écriassiez": "écrier",
    "écriassions": "écrier",
    "écrie": "écrier",
    "écrient": "écrier",
    "écriera": "écrier",
    "écrierai": "écrier",
    "écrieraient": "écrier",
    "écrierais": "écrier",
    "écrierait": "écrier",
    "écrieras": "écrier",
    "écrierez": "écrier",
    "écrieriez": "écrier",
    "écrierions": "écrier",
    "écrierons": "écrier",
    "écrieront": "écrier",
    "écries": "écrier",
    "écriez": "écrier",
    "écriiez": "écrier",
    "écriions": "écrier",
    "écrins": "écrin",
    "écrions": "écrier",
    "écrira": "écrire",
    "écrirai": "écrire",
    "écriraient": "écrire",
    "écrirais": "écrire",
    "écrirait": "écrire",
    "écriras": "écrire",
    "écrirez": "écrire",
    "écririez": "écrire",
    "écririons": "écrire",
    "écrirons": "écrire",
    "écriront": "écrire",
    "écris": "écrire",
    "écrit": "écrire",
    "écrite": "écrit",
    "écriteaux": "écriteau",
    "écrites": "écrit",
    "écritoires": "écritoire",
    "écrits": "écrit",
    "écritures": "écriture",
    "écrivaient": "écrire",
    "écrivaillons": "écrivaillon",
    "écrivaillé": "écrivailler",
    "écrivaine": "écrivain",
    "écrivaines": "écrivain",
    "écrivains": "écrivain",
    "écrivais": "écrire",
    "écrivait": "écrire",
    "écrivant": "écrire",
    "écrivassiers": "écrivassier",
    "écrive": "écrire",
    "écrivent": "écrire",
    "écrives": "écrire",
    "écrivez": "écrire",
    "écriviez": "écrire",
    "écrivions": "écrire",
    "écrivirent": "écrire",
    "écrivis": "écrire",
    "écrivisse": "écrire",
    "écrivissent": "écrire",
    "écrivisses": "écrire",
    "écrivissiez": "écrire",
    "écrivissions": "écrire",
    "écrivit": "écrire",
    "écrivons": "écrire",
    "écrivîmes": "écrire",
    "écrivît": "écrire",
    "écrivîtes": "écrire",
    "écriâmes": "écrier",
    "écriât": "écrier",
    "écriâtes": "écrier",
    "écrièrent": "écrier",
    "écrié": "écrier",
    "écriée": "écrier",
    "écriées": "écrier",
    "écriés": "écrier",
    "écroua": "écrouer",
    "écrouai": "écrouer",
    "écrouaient": "écrouer",
    "écrouais": "écrouer",
    "écrouait": "écrouer",
    "écrouant": "écrouer",
    "écrouas": "écrouer",
    "écrouasse": "écrouer",
    "écrouassent": "écrouer",
    "écrouasses": "écrouer",
    "écrouassiez": "écrouer",
    "écrouassions": "écrouer",
    "écroue": "écrouer",
    "écrouent": "écrouer",
    "écrouera": "écrouer",
    "écrouerai": "écrouer",
    "écroueraient": "écrouer",
    "écrouerais": "écrouer",
    "écrouerait": "écrouer",
    "écroueras": "écrouer",
    "écrouerez": "écrouer",
    "écroueriez": "écrouer",
    "écrouerions": "écrouer",
    "écrouerons": "écrouer",
    "écroueront": "écrouer",
    "écroues": "écrouer",
    "écrouez": "écrouer",
    "écroui": "écrouir",
    "écrouie": "écrouir",
    "écrouies": "écrouir",
    "écrouiez": "écrouer",
    "écrouions": "écrouer",
    "écrouira": "écrouir",
    "écrouirai": "écrouir",
    "écrouiraient": "écrouir",
    "écrouirais": "écrouir",
    "écrouirait": "écrouir",
    "écrouiras": "écrouir",
    "écrouirent": "écrouir",
    "écrouirez": "écrouir",
    "écrouiriez": "écrouir",
    "écrouirions": "écrouir",
    "écrouirons": "écrouir",
    "écrouiront": "écrouir",
    "écrouis": "écrouir",
    "écrouissaient": "écrouir",
    "écrouissais": "écrouir",
    "écrouissait": "écrouir",
    "écrouissant": "écrouir",
    "écrouisse": "écrouir",
    "écrouissent": "écrouir",
    "écrouisses": "écrouir",
    "écrouissez": "écrouir",
    "écrouissiez": "écrouir",
    "écrouissions": "écrouir",
    "écrouissons": "écrouir",
    "écrouit": "écrouir",
    "écroula": "écrouler",
    "écroulai": "écrouler",
    "écroulaient": "écrouler",
    "écroulais": "écrouler",
    "écroulait": "écrouler",
    "écroulant": "écrouler",
    "écroulas": "écrouler",
    "écroulasse": "écrouler",
    "écroulassent": "écrouler",
    "écroulasses": "écrouler",
    "écroulassiez": "écrouler",
    "écroulassions": "écrouler",
    "écroule": "écrouler",
    "écroulements": "écroulement",
    "écroulent": "écrouler",
    "écroulera": "écrouler",
    "écroulerai": "écrouler",
    "écrouleraient": "écrouler",
    "écroulerais": "écrouler",
    "écroulerait": "écrouler",
    "écrouleras": "écrouler",
    "écroulerez": "écrouler",
    "écrouleriez": "écrouler",
    "écroulerions": "écrouler",
    "écroulerons": "écrouler",
    "écrouleront": "écrouler",
    "écroules": "écrouler",
    "écroulez": "écrouler",
    "écrouliez": "écrouler",
    "écroulions": "écrouler",
    "écroulons": "écrouler",
    "écroulâmes": "écrouler",
    "écroulât": "écrouler",
    "écroulâtes": "écrouler",
    "écroulèrent": "écrouler",
    "écroulé": "écrouler",
    "écroulée": "écrouler",
    "écroulées": "écrouler",
    "écroulés": "écrouler",
    "écrouons": "écrouer",
    "écrous": "écrou",
    "écrouâmes": "écrouer",
    "écrouât": "écrouer",
    "écrouâtes": "écrouer",
    "écrouèrent": "écrouer",
    "écroué": "écrouer",
    "écrouée": "écrouer",
    "écrouées": "écrouer",
    "écroués": "écrouer",
    "écrouîmes": "écrouir",
    "écrouît": "écrouir",
    "écrouîtes": "écrouir",
    "écrue": "écru",
    "écrues": "écru",
    "écrus": "écru",
    "écrème": "écrémer",
    "écrèment": "écrémer",
    "écrèmes": "écrémer",
    "écréma": "écrémer",
    "écrémages": "écrémage",
    "écrémai": "écrémer",
    "écrémaient": "écrémer",
    "écrémais": "écrémer",
    "écrémait": "écrémer",
    "écrémant": "écrémer",
    "écrémas": "écrémer",
    "écrémasse": "écrémer",
    "écrémassent": "écrémer",
    "écrémasses": "écrémer",
    "écrémassiez": "écrémer",
    "écrémassions": "écrémer",
    "écrémera": "écrémer",
    "écrémerai": "écrémer",
    "écrémeraient": "écrémer",
    "écrémerais": "écrémer",
    "écrémerait": "écrémer",
    "écrémeras": "écrémer",
    "écrémerez": "écrémer",
    "écrémeriez": "écrémer",
    "écrémerions": "écrémer",
    "écrémerons": "écrémer",
    "écrémeront": "écrémer",
    "écrémeurs": "écrémeur",
    "écrémeuse": "écrémeur",
    "écrémez": "écrémer",
    "écrémiez": "écrémer",
    "écrémions": "écrémer",
    "écrémons": "écrémer",
    "écrémâmes": "écrémer",
    "écrémât": "écrémer",
    "écrémâtes": "écrémer",
    "écrémèrent": "écrémer",
    "écrémé": "écrémer",
    "écrémée": "écrémer",
    "écrémées": "écrémer",
    "écrémés": "écrémer",
    "écrêta": "écrêter",
    "écrêtai": "écrêter",
    "écrêtaient": "écrêter",
    "écrêtais": "écrêter",
    "écrêtait": "écrêter",
    "écrêtant": "écrêter",
    "écrêtas": "écrêter",
    "écrêtasse": "écrêter",
    "écrêtassent": "écrêter",
    "écrêtasses": "écrêter",
    "écrêtassiez": "écrêter",
    "écrêtassions": "écrêter",
    "écrête": "écrêter",
    "écrêtent": "écrêter",
    "écrêtera": "écrêter",
    "écrêterai": "écrêter",
    "écrêteraient": "écrêter",
    "écrêterais": "écrêter",
    "écrêterait": "écrêter",
    "écrêteras": "écrêter",
    "écrêterez": "écrêter",
    "écrêteriez": "écrêter",
    "écrêterions": "écrêter",
    "écrêterons": "écrêter",
    "écrêteront": "écrêter",
    "écrêtes": "écrêter",
    "écrêtez": "écrêter",
    "écrêtiez": "écrêter",
    "écrêtions": "écrêter",
    "écrêtons": "écrêter",
    "écrêtâmes": "écrêter",
    "écrêtât": "écrêter",
    "écrêtâtes": "écrêter",
    "écrêtèrent": "écrêter",
    "écrêté": "écrêter",
    "écrêtée": "écrêter",
    "écrêtées": "écrêter",
    "écrêtés": "écrêter",
    "écueils": "écueil",
    "écuelles": "écuelle",
    "écuellées": "écuellée",
    "écuissé": "écuisser",
    "écuissées": "écuisser",
    "éculé": "éculer",
    "éculée": "éculer",
    "éculées": "éculer",
    "éculés": "éculer",
    "écuma": "écumer",
    "écumai": "écumer",
    "écumaient": "écumer",
    "écumais": "écumer",
    "écumait": "écumer",
    "écumant": "écumer",
    "écumante": "écumant",
    "écumantes": "écumant",
    "écumants": "écumant",
    "écumas": "écumer",
    "écumasse": "écumer",
    "écumassent": "écumer",
    "écumasses": "écumer",
    "écumassiez": "écumer",
    "écumassions": "écumer",
    "écume": "écumer",
    "écument": "écumer",
    "écumera": "écumer",
    "écumerai": "écumer",
    "écumeraient": "écumer",
    "écumerais": "écumer",
    "écumerait": "écumer",
    "écumeras": "écumer",
    "écumerez": "écumer",
    "écumeriez": "écumer",
    "écumerions": "écumer",
    "écumerons": "écumer",
    "écumeront": "écumer",
    "écumes": "écumer",
    "écumeurs": "écumeur",
    "écumeuse": "écumeux",
    "écumeuses": "écumeux",
    "écumez": "écumer",
    "écumiez": "écumer",
    "écumions": "écumer",
    "écumoires": "écumoire",
    "écumons": "écumer",
    "écumâmes": "écumer",
    "écumât": "écumer",
    "écumâtes": "écumer",
    "écumèrent": "écumer",
    "écumé": "écumer",
    "écumée": "écumer",
    "écumées": "écumer",
    "écumés": "écumer",
    "écureuils": "écureuil",
    "écuries": "écurie",
    "écus": "écu",
    "écussonna": "écussonner",
    "écussonnai": "écussonner",
    "écussonnaient": "écussonner",
    "écussonnais": "écussonner",
    "écussonnait": "écussonner",
    "écussonnant": "écussonner",
    "écussonnas": "écussonner",
    "écussonnasse": "écussonner",
    "écussonnassent": "écussonner",
    "écussonnasses": "écussonner",
    "écussonnassiez": "écussonner",
    "écussonnassions": "écussonner",
    "écussonne": "écussonner",
    "écussonnent": "écussonner",
    "écussonnera": "écussonner",
    "écussonnerai": "écussonner",
    "écussonneraient": "écussonner",
    "écussonnerais": "écussonner",
    "écussonnerait": "écussonner",
    "écussonneras": "écussonner",
    "écussonnerez": "écussonner",
    "écussonneriez": "écussonner",
    "écussonnerions": "écussonner",
    "écussonnerons": "écussonner",
    "écussonneront": "écussonner",
    "écussonnes": "écussonner",
    "écussonnez": "écussonner",
    "écussonniez": "écussonner",
    "écussonnions": "écussonner",
    "écussonnons": "écussonner",
    "écussonnâmes": "écussonner",
    "écussonnât": "écussonner",
    "écussonnâtes": "écussonner",
    "écussonnèrent": "écussonner",
    "écussonné": "écussonner",
    "écussonnée": "écussonner",
    "écussonnées": "écussonner",
    "écussonnés": "écussonner",
    "écussons": "écusson",
    "écuyers": "écuyer",
    "écuyère": "écuyer",
    "écuyères": "écuyer",
    "édens": "éden",
    "édenté": "édenter",
    "édentée": "édenter",
    "édentées": "édenter",
    "édentés": "édenter",
    "édicta": "édicter",
    "édictai": "édicter",
    "édictaient": "édicter",
    "édictais": "édicter",
    "édictait": "édicter",
    "édictant": "édicter",
    "édictas": "édicter",
    "édictasse": "édicter",
    "édictassent": "édicter",
    "édictasses": "édicter",
    "édictassiez": "édicter",
    "édictassions": "édicter",
    "édicte": "édicter",
    "édictent": "édicter",
    "édictera": "édicter",
    "édicterai": "édicter",
    "édicteraient": "édicter",
    "édicterais": "édicter",
    "édicterait": "édicter",
    "édicteras": "édicter",
    "édicterez": "édicter",
    "édicteriez": "édicter",
    "édicterions": "édicter",
    "édicterons": "édicter",
    "édicteront": "édicter",
    "édictes": "édicter",
    "édictez": "édicter",
    "édictiez": "édicter",
    "édictions": "édicter",
    "édictons": "édicter",
    "édictâmes": "édicter",
    "édictât": "édicter",
    "édictâtes": "édicter",
    "édictèrent": "édicter",
    "édicté": "édicter",
    "édictée": "édicter",
    "édictées": "édicter",
    "édictés": "édicter",
    "édicules": "édicule",
    "édifia": "édifier",
    "édifiai": "édifier",
    "édifiaient": "édifier",
    "édifiais": "édifier",
    "édifiait": "édifier",
    "édifiant": "édifier",
    "édifiante": "édifiant",
    "édifiantes": "édifiant",
    "édifiants": "édifiant",
    "édifias": "édifier",
    "édifiasse": "édifier",
    "édifiassent": "édifier",
    "édifiasses": "édifier",
    "édifiassiez": "édifier",
    "édifiassions": "édifier",
    "édifications": "édification",
    "édifices": "édifice",
    "édifie": "édifier",
    "édifient": "édifier",
    "édifiera": "édifier",
    "édifierai": "édifier",
    "édifieraient": "édifier",
    "édifierais": "édifier",
    "édifierait": "édifier",
    "édifieras": "édifier",
    "édifierez": "édifier",
    "édifieriez": "édifier",
    "édifierions": "édifier",
    "édifierons": "édifier",
    "édifieront": "édifier",
    "édifies": "édifier",
    "édifiez": "édifier",
    "édifiiez": "édifier",
    "édifiions": "édifier",
    "édifions": "édifier",
    "édifiâmes": "édifier",
    "édifiât": "édifier",
    "édifiâtes": "édifier",
    "édifièrent": "édifier",
    "édifié": "édifier",
    "édifiée": "édifier",
    "édifiées": "édifier",
    "édifiés": "édifier",
    "édiles": "édile",
    "édilitaires": "édilitaire",
    "édita": "éditer",
    "éditai": "éditer",
    "éditaient": "éditer",
    "éditais": "éditer",
    "éditait": "éditer",
    "éditant": "éditer",
    "éditas": "éditer",
    "éditasse": "éditer",
    "éditassent": "éditer",
    "éditasses": "éditer",
    "éditassiez": "éditer",
    "éditassions": "éditer",
    "édite": "éditer",
    "éditent": "éditer",
    "éditera": "éditer",
    "éditerai": "éditer",
    "éditeraient": "éditer",
    "éditerais": "éditer",
    "éditerait": "éditer",
    "éditeras": "éditer",
    "éditerez": "éditer",
    "éditeriez": "éditer",
    "éditerions": "éditer",
    "éditerons": "éditer",
    "éditeront": "éditer",
    "édites": "éditer",
    "éditeurs": "éditeur",
    "éditez": "éditer",
    "éditiez": "éditer",
    "éditions": "édition",
    "éditons": "éditer",
    "éditoriale": "éditorial",
    "éditoriales": "éditorial",
    "éditorialistes": "éditorialiste",
    "éditoriaux": "éditorial",
    "éditos": "édito",
    "éditrice": "éditeur",
    "éditrices": "éditeur",
    "édits": "édit",
    "éditâmes": "éditer",
    "éditât": "éditer",
    "éditâtes": "éditer",
    "éditèrent": "éditer",
    "édité": "éditer",
    "éditée": "éditer",
    "éditées": "éditer",
    "édités": "éditer",
    "édouardienne": "édouardien",
    "édredons": "édredon",
    "éducables": "éducable",
    "éducateurs": "éducateur",
    "éducatifs": "éducatif",
    "éducationnelle": "éducationnel",
    "éducations": "éducation",
    "éducative": "éducatif",
    "éducatives": "éducatif",
    "éducatrice": "éducateur",
    "éducatrices": "éducateur",
    "éduennes": "éduen",
    "éduens": "éduen",
    "édulcora": "édulcorer",
    "édulcorai": "édulcorer",
    "édulcoraient": "édulcorer",
    "édulcorais": "édulcorer",
    "édulcorait": "édulcorer",
    "édulcorant": "édulcorer",
    "édulcorante": "édulcorant",
    "édulcorantes": "édulcorant",
    "édulcorants": "édulcorant",
    "édulcoras": "édulcorer",
    "édulcorasse": "édulcorer",
    "édulcorassent": "édulcorer",
    "édulcorasses": "édulcorer",
    "édulcorassiez": "édulcorer",
    "édulcorassions": "édulcorer",
    "édulcore": "édulcorer",
    "édulcorent": "édulcorer",
    "édulcorera": "édulcorer",
    "édulcorerai": "édulcorer",
    "édulcoreraient": "édulcorer",
    "édulcorerais": "édulcorer",
    "édulcorerait": "édulcorer",
    "édulcoreras": "édulcorer",
    "édulcorerez": "édulcorer",
    "édulcoreriez": "édulcorer",
    "édulcorerions": "édulcorer",
    "édulcorerons": "édulcorer",
    "édulcoreront": "édulcorer",
    "édulcores": "édulcorer",
    "édulcorez": "édulcorer",
    "édulcoriez": "édulcorer",
    "édulcorions": "édulcorer",
    "édulcorons": "édulcorer",
    "édulcorâmes": "édulcorer",
    "édulcorât": "édulcorer",
    "édulcorâtes": "édulcorer",
    "édulcorèrent": "édulcorer",
    "édulcoré": "édulcorer",
    "édulcorée": "édulcorer",
    "édulcorées": "édulcorer",
    "édulcorés": "édulcorer",
    "éduqua": "éduquer",
    "éduquai": "éduquer",
    "éduquaient": "éduquer",
    "éduquais": "éduquer",
    "éduquait": "éduquer",
    "éduquant": "éduquer",
    "éduquas": "éduquer",
    "éduquasse": "éduquer",
    "éduquassent": "éduquer",
    "éduquasses": "éduquer",
    "éduquassiez": "éduquer",
    "éduquassions": "éduquer",
    "éduque": "éduquer",
    "éduquent": "éduquer",
    "éduquera": "éduquer",
    "éduquerai": "éduquer",
    "éduqueraient": "éduquer",
    "éduquerais": "éduquer",
    "éduquerait": "éduquer",
    "éduqueras": "éduquer",
    "éduquerez": "éduquer",
    "éduqueriez": "éduquer",
    "éduquerions": "éduquer",
    "éduquerons": "éduquer",
    "éduqueront": "éduquer",
    "éduques": "éduquer",
    "éduquez": "éduquer",
    "éduquiez": "éduquer",
    "éduquions": "éduquer",
    "éduquons": "éduquer",
    "éduquâmes": "éduquer",
    "éduquât": "éduquer",
    "éduquâtes": "éduquer",
    "éduquèrent": "éduquer",
    "éduqué": "éduquer",
    "éduquée": "éduquer",
    "éduquées": "éduquer",
    "éduqués": "éduquer",
    "édéniques": "édénique",
    "égaie": "égayer",
    "égaient": "égayer",
    "égaiera": "égayer",
    "égaierai": "égayer",
    "égaieraient": "égayer",
    "égaierais": "égayer",
    "égaierait": "égayer",
    "égaieras": "égayer",
    "égaierez": "égayer",
    "égaieriez": "égayer",
    "égaierions": "égayer",
    "égaierons": "égayer",
    "égaieront": "égayer",
    "égaies": "égayer",
    "égailla": "égailler",
    "égaillai": "égailler",
    "égaillaient": "égailler",
    "égaillais": "égailler",
    "égaillait": "égailler",
    "égaillant": "égailler",
    "égaillas": "égailler",
    "égaillasse": "égailler",
    "égaillassent": "égailler",
    "égaillasses": "égailler",
    "égaillassiez": "égailler",
    "égaillassions": "égailler",
    "égaille": "égailler",
    "égaillent": "égailler",
    "égaillera": "égailler",
    "égaillerai": "égailler",
    "égailleraient": "égailler",
    "égaillerais": "égailler",
    "égaillerait": "égailler",
    "égailleras": "égailler",
    "égaillerez": "égailler",
    "égailleriez": "égailler",
    "égaillerions": "égailler",
    "égaillerons": "égailler",
    "égailleront": "égailler",
    "égailles": "égailler",
    "égaillez": "égailler",
    "égailliez": "égailler",
    "égaillions": "égailler",
    "égaillons": "égailler",
    "égaillâmes": "égailler",
    "égaillât": "égailler",
    "égaillâtes": "égailler",
    "égaillèrent": "égailler",
    "égaillé": "égailler",
    "égaillée": "égailler",
    "égaillées": "égailler",
    "égaillés": "égailler",
    "égala": "égaler",
    "égalai": "égaler",
    "égalaient": "égaler",
    "égalais": "égaler",
    "égalait": "égaler",
    "égalant": "égaler",
    "égalas": "égaler",
    "égalasse": "égaler",
    "égalassent": "égaler",
    "égalasses": "égaler",
    "égalassiez": "égaler",
    "égalassions": "égaler",
    "égale": "égaler",
    "égalent": "égaler",
    "égalera": "égaler",
    "égalerai": "égaler",
    "égaleraient": "égaler",
    "égalerais": "égaler",
    "égalerait": "égaler",
    "égaleras": "égaler",
    "égalerez": "égaler",
    "égaleriez": "égaler",
    "égalerions": "égaler",
    "égalerons": "égaler",
    "égaleront": "égaler",
    "égales": "égaler",
    "égalez": "égaler",
    "égaliez": "égaler",
    "égalions": "égaler",
    "égalisa": "égaliser",
    "égalisai": "égaliser",
    "égalisaient": "égaliser",
    "égalisais": "égaliser",
    "égalisait": "égaliser",
    "égalisant": "égaliser",
    "égalisas": "égaliser",
    "égalisasse": "égaliser",
    "égalisassent": "égaliser",
    "égalisasses": "égaliser",
    "égalisassiez": "égaliser",
    "égalisassions": "égaliser",
    "égalisateurs": "égalisateur",
    "égalisatrice": "égalisateur",
    "égalise": "égaliser",
    "égalisent": "égaliser",
    "égalisera": "égaliser",
    "égaliserai": "égaliser",
    "égaliseraient": "égaliser",
    "égaliserais": "égaliser",
    "égaliserait": "égaliser",
    "égaliseras": "égaliser",
    "égaliserez": "égaliser",
    "égaliseriez": "égaliser",
    "égaliserions": "égaliser",
    "égaliserons": "égaliser",
    "égaliseront": "égaliser",
    "égalises": "égaliser",
    "égalisez": "égaliser",
    "égalisiez": "égaliser",
    "égalisions": "égaliser",
    "égalisons": "égaliser",
    "égalisâmes": "égaliser",
    "égalisât": "égaliser",
    "égalisâtes": "égaliser",
    "égalisèrent": "égaliser",
    "égalisé": "égaliser",
    "égalisée": "égaliser",
    "égalisées": "égaliser",
    "égalisés": "égaliser",
    "égalitaires": "égalitaire",
    "égalitarismes": "égalitarisme",
    "égalitaristes": "égalitariste",
    "égalités": "égalité",
    "égalons": "égaler",
    "égalâmes": "égaler",
    "égalât": "égaler",
    "égalâtes": "égaler",
    "égalèrent": "égaler",
    "égalé": "égaler",
    "égalée": "égaler",
    "égalées": "égaler",
    "égalés": "égaler",
    "égara": "égarer",
    "égarai": "égarer",
    "égaraient": "égarer",
    "égarais": "égarer",
    "égarait": "égarer",
    "égarant": "égarer",
    "égaras": "égarer",
    "égarasse": "égarer",
    "égarassent": "égarer",
    "égarasses": "égarer",
    "égarassiez": "égarer",
    "égarassions": "égarer",
    "égards": "égard",
    "égare": "égarer",
    "égarements": "égarement",
    "égarent": "égarer",
    "égarera": "égarer",
    "égarerai": "égarer",
    "égareraient": "égarer",
    "égarerais": "égarer",
    "égarerait": "égarer",
    "égareras": "égarer",
    "égarerez": "égarer",
    "égareriez": "égarer",
    "égarerions": "égarer",
    "égarerons": "égarer",
    "égareront": "égarer",
    "égares": "égarer",
    "égarez": "égarer",
    "égariez": "égarer",
    "égarions": "égarer",
    "égarons": "égarer",
    "égarâmes": "égarer",
    "égarât": "égarer",
    "égarâtes": "égarer",
    "égarèrent": "égarer",
    "égaré": "égarer",
    "égarée": "égarer",
    "égarées": "égarer",
    "égarés": "égarer",
    "égaux": "égal",
    "égaya": "égayer",
    "égayai": "égayer",
    "égayaient": "égayer",
    "égayais": "égayer",
    "égayait": "égayer",
    "égayant": "égayer",
    "égayante": "égayant",
    "égayas": "égayer",
    "égayasse": "égayer",
    "égayassent": "égayer",
    "égayasses": "égayer",
    "égayassiez": "égayer",
    "égayassions": "égayer",
    "égaye": "égayer",
    "égayent": "égayer",
    "égayera": "égayer",
    "égayerai": "égayer",
    "égayeraient": "égayer",
    "égayerais": "égayer",
    "égayerait": "égayer",
    "égayeras": "égayer",
    "égayerez": "égayer",
    "égayeriez": "égayer",
    "égayerions": "égayer",
    "égayerons": "égayer",
    "égayeront": "égayer",
    "égayes": "égayer",
    "égayez": "égayer",
    "égayiez": "égayer",
    "égayions": "égayer",
    "égayons": "égayer",
    "égayâmes": "égayer",
    "égayât": "égayer",
    "égayâtes": "égayer",
    "égayèrent": "égayer",
    "égayé": "égayer",
    "égayée": "égayer",
    "égayées": "égayer",
    "égayés": "égayer",
    "égides": "égide",
    "égipans": "égipan",
    "églantiers": "églantier",
    "églantines": "églantine",
    "églefins": "églefin",
    "églises": "église",
    "églogues": "églogue",
    "égocentriques": "égocentrique",
    "égocentrismes": "égocentrisme",
    "égocentristes": "égocentriste",
    "égorge": "égorger",
    "égorgea": "égorger",
    "égorgeai": "égorger",
    "égorgeaient": "égorger",
    "égorgeais": "égorger",
    "égorgeait": "égorger",
    "égorgeant": "égorger",
    "égorgeas": "égorger",
    "égorgeasse": "égorger",
    "égorgeassent": "égorger",
    "égorgeasses": "égorger",
    "égorgeassiez": "égorger",
    "égorgeassions": "égorger",
    "égorgements": "égorgement",
    "égorgent": "égorger",
    "égorgeons": "égorger",
    "égorgera": "égorger",
    "égorgerai": "égorger",
    "égorgeraient": "égorger",
    "égorgerais": "égorger",
    "égorgerait": "égorger",
    "égorgeras": "égorger",
    "égorgerez": "égorger",
    "égorgeriez": "égorger",
    "égorgerions": "égorger",
    "égorgerons": "égorger",
    "égorgeront": "égorger",
    "égorges": "égorger",
    "égorgeurs": "égorgeur",
    "égorgeuses": "égorgeur",
    "égorgez": "égorger",
    "égorgeâmes": "égorger",
    "égorgeât": "égorger",
    "égorgeâtes": "égorger",
    "égorgiez": "égorger",
    "égorgions": "égorger",
    "égorgèrent": "égorger",
    "égorgé": "égorger",
    "égorgée": "égorger",
    "égorgées": "égorger",
    "égorgés": "égorger",
    "égosilla": "égosiller",
    "égosillai": "égosiller",
    "égosillaient": "égosiller",
    "égosillais": "égosiller",
    "égosillait": "égosiller",
    "égosillant": "égosiller",
    "égosillas": "égosiller",
    "égosillasse": "égosiller",
    "égosillassent": "égosiller",
    "égosillasses": "égosiller",
    "égosillassiez": "égosiller",
    "égosillassions": "égosiller",
    "égosille": "égosiller",
    "égosillent": "égosiller",
    "égosillera": "égosiller",
    "égosillerai": "égosiller",
    "égosilleraient": "égosiller",
    "égosillerais": "égosiller",
    "égosillerait": "égosiller",
    "égosilleras": "égosiller",
    "égosillerez": "égosiller",
    "égosilleriez": "égosiller",
    "égosillerions": "égosiller",
    "égosillerons": "égosiller",
    "égosilleront": "égosiller",
    "égosilles": "égosiller",
    "égosillez": "égosiller",
    "égosilliez": "égosiller",
    "égosillions": "égosiller",
    "égosillons": "égosiller",
    "égosillâmes": "égosiller",
    "égosillât": "égosiller",
    "égosillâtes": "égosiller",
    "égosillèrent": "égosiller",
    "égosillé": "égosiller",
    "égosillée": "égosiller",
    "égosillées": "égosiller",
    "égosillés": "égosiller",
    "égotismes": "égotisme",
    "égotistes": "égotiste",
    "égoutiers": "égoutier",
    "égouts": "égout",
    "égoutta": "égoutter",
    "égouttai": "égoutter",
    "égouttaient": "égoutter",
    "égouttais": "égoutter",
    "égouttait": "égoutter",
    "égouttant": "égoutter",
    "égouttas": "égoutter",
    "égouttasse": "égoutter",
    "égouttassent": "égoutter",
    "égouttasses": "égoutter",
    "égouttassiez": "égoutter",
    "égouttassions": "égoutter",
    "égoutte": "égoutter",
    "égouttent": "égoutter",
    "égouttera": "égoutter",
    "égoutterai": "égoutter",
    "égoutteraient": "égoutter",
    "égoutterais": "égoutter",
    "égoutterait": "égoutter",
    "égoutteras": "égoutter",
    "égoutterez": "égoutter",
    "égoutteriez": "égoutter",
    "égoutterions": "égoutter",
    "égoutterons": "égoutter",
    "égoutteront": "égoutter",
    "égouttes": "égoutter",
    "égouttez": "égoutter",
    "égouttiez": "égoutter",
    "égouttions": "égoutter",
    "égouttons": "égoutter",
    "égouttâmes": "égoutter",
    "égouttât": "égoutter",
    "égouttâtes": "égoutter",
    "égouttèrent": "égoutter",
    "égoutté": "égoutter",
    "égouttée": "égoutter",
    "égouttées": "égoutter",
    "égouttés": "égoutter",
    "égoïnes": "égoïne",
    "égoïsmes": "égoïsme",
    "égoïstes": "égoïste",
    "égraina": "égrainer",
    "égrainai": "égrainer",
    "égrainaient": "égrainer",
    "égrainais": "égrainer",
    "égrainait": "égrainer",
    "égrainant": "égrainer",
    "égrainas": "égrainer",
    "égrainasse": "égrainer",
    "égrainassent": "égrainer",
    "égrainasses": "égrainer",
    "égrainassiez": "égrainer",
    "égrainassions": "égrainer",
    "égraine": "égrainer",
    "égrainent": "égrainer",
    "égrainera": "égrainer",
    "égrainerai": "égrainer",
    "égraineraient": "égrainer",
    "égrainerais": "égrainer",
    "égrainerait": "égrainer",
    "égraineras": "égrainer",
    "égrainerez": "égrainer",
    "égraineriez": "égrainer",
    "égrainerions": "égrainer",
    "égrainerons": "égrainer",
    "égraineront": "égrainer",
    "égraines": "égrainer",
    "égrainez": "égrainer",
    "égrainiez": "égrainer",
    "égrainions": "égrainer",
    "égrainons": "égrainer",
    "égrainâmes": "égrainer",
    "égrainât": "égrainer",
    "égrainâtes": "égrainer",
    "égrainèrent": "égrainer",
    "égrainé": "égrainer",
    "égrainée": "égrainer",
    "égrainées": "égrainer",
    "égrainés": "égrainer",
    "égrappa": "égrapper",
    "égrappai": "égrapper",
    "égrappaient": "égrapper",
    "égrappais": "égrapper",
    "égrappait": "égrapper",
    "égrappant": "égrapper",
    "égrappas": "égrapper",
    "égrappasse": "égrapper",
    "égrappassent": "égrapper",
    "égrappasses": "égrapper",
    "égrappassiez": "égrapper",
    "égrappassions": "égrapper",
    "égrappe": "égrapper",
    "égrappent": "égrapper",
    "égrappera": "égrapper",
    "égrapperai": "égrapper",
    "égrapperaient": "égrapper",
    "égrapperais": "égrapper",
    "égrapperait": "égrapper",
    "égrapperas": "égrapper",
    "égrapperez": "égrapper",
    "égrapperiez": "égrapper",
    "égrapperions": "égrapper",
    "égrapperons": "égrapper",
    "égrapperont": "égrapper",
    "égrappes": "égrapper",
    "égrappez": "égrapper",
    "égrappiez": "égrapper",
    "égrappions": "égrapper",
    "égrappons": "égrapper",
    "égrappâmes": "égrapper",
    "égrappât": "égrapper",
    "égrappâtes": "égrapper",
    "égrappèrent": "égrapper",
    "égrappé": "égrapper",
    "égrappée": "égrapper",
    "égrappées": "égrapper",
    "égrappés": "égrapper",
    "égratigna": "égratigner",
    "égratignai": "égratigner",
    "égratignaient": "égratigner",
    "égratignais": "égratigner",
    "égratignait": "égratigner",
    "égratignant": "égratigner",
    "égratignas": "égratigner",
    "égratignasse": "égratigner",
    "égratignassent": "égratigner",
    "égratignasses": "égratigner",
    "égratignassiez": "égratigner",
    "égratignassions": "égratigner",
    "égratigne": "égratigner",
    "égratignent": "égratigner",
    "égratignera": "égratigner",
    "égratignerai": "égratigner",
    "égratigneraient": "égratigner",
    "égratignerais": "égratigner",
    "égratignerait": "égratigner",
    "égratigneras": "égratigner",
    "égratignerez": "égratigner",
    "égratigneriez": "égratigner",
    "égratignerions": "égratigner",
    "égratignerons": "égratigner",
    "égratigneront": "égratigner",
    "égratignes": "égratigner",
    "égratignez": "égratigner",
    "égratigniez": "égratigner",
    "égratignions": "égratigner",
    "égratignons": "égratigner",
    "égratignures": "égratignure",
    "égratignâmes": "égratigner",
    "égratignât": "égratigner",
    "égratignâtes": "égratigner",
    "égratignèrent": "égratigner",
    "égratigné": "égratigner",
    "égratignée": "égratigner",
    "égratignées": "égratigner",
    "égratignés": "égratigner",
    "égrena": "égrener",
    "égrenages": "égrenage",
    "égrenai": "égrener",
    "égrenaient": "égrener",
    "égrenais": "égrener",
    "égrenait": "égrener",
    "égrenant": "égrener",
    "égrenas": "égrener",
    "égrenasse": "égrener",
    "égrenassent": "égrener",
    "égrenasses": "égrener",
    "égrenassiez": "égrener",
    "égrenassions": "égrener",
    "égreneurs": "égreneur",
    "égreneuse": "égreneur",
    "égreneuses": "égreneuse",
    "égrenez": "égrener",
    "égreniez": "égrener",
    "égrenions": "égrener",
    "égrenons": "égrener",
    "égrenâmes": "égrener",
    "égrenât": "égrener",
    "égrenâtes": "égrener",
    "égrenèrent": "égrener",
    "égrené": "égrener",
    "égrenée": "égrener",
    "égrenées": "égrener",
    "égrenés": "égrener",
    "égrillarde": "égrillard",
    "égrillardes": "égrillard",
    "égrillards": "égrillard",
    "égrisa": "égriser",
    "égrisai": "égriser",
    "égrisaient": "égriser",
    "égrisais": "égriser",
    "égrisait": "égriser",
    "égrisant": "égriser",
    "égrisas": "égriser",
    "égrisasse": "égriser",
    "égrisassent": "égriser",
    "égrisasses": "égriser",
    "égrisassiez": "égriser",
    "égrisassions": "égriser",
    "égrise": "égriser",
    "égrisent": "égriser",
    "égrisera": "égriser",
    "égriserai": "égriser",
    "égriseraient": "égriser",
    "égriserais": "égriser",
    "égriserait": "égriser",
    "égriseras": "égriser",
    "égriserez": "égriser",
    "égriseriez": "égriser",
    "égriserions": "égriser",
    "égriserons": "égriser",
    "égriseront": "égriser",
    "égrises": "égriser",
    "égrisez": "égriser",
    "égrisiez": "égriser",
    "égrisions": "égriser",
    "égrisons": "égriser",
    "égrisâmes": "égriser",
    "égrisât": "égriser",
    "égrisâtes": "égriser",
    "égrisèrent": "égriser",
    "égrisé": "égriser",
    "égrisée": "égriser",
    "égrisées": "égriser",
    "égrisés": "égriser",
    "égrotantes": "égrotant",
    "égrotants": "égrotant",
    "égruge": "égruger",
    "égrugea": "égruger",
    "égrugeai": "égruger",
    "égrugeaient": "égruger",
    "égrugeais": "égruger",
    "égrugeait": "égruger",
    "égrugeant": "égruger",
    "égrugeas": "égruger",
    "égrugeasse": "égruger",
    "égrugeassent": "égruger",
    "égrugeasses": "égruger",
    "égrugeassiez": "égruger",
    "égrugeassions": "égruger",
    "égrugent": "égruger",
    "égrugeons": "égruger",
    "égrugera": "égruger",
    "égrugerai": "égruger",
    "égrugeraient": "égruger",
    "égrugerais": "égruger",
    "égrugerait": "égruger",
    "égrugeras": "égruger",
    "égrugerez": "égruger",
    "égrugeriez": "égruger",
    "égrugerions": "égruger",
    "égrugerons": "égruger",
    "égrugeront": "égruger",
    "égruges": "égruger",
    "égrugez": "égruger",
    "égrugeâmes": "égruger",
    "égrugeât": "égruger",
    "égrugeâtes": "égruger",
    "égrugiez": "égruger",
    "égrugions": "égruger",
    "égrugèrent": "égruger",
    "égrugé": "égruger",
    "égrugée": "égruger",
    "égrugées": "égruger",
    "égrugés": "égruger",
    "égrène": "égrener",
    "égrènements": "égrènement",
    "égrènent": "égrener",
    "égrènera": "égrener",
    "égrènerai": "égrener",
    "égrèneraient": "égrener",
    "égrènerais": "égrener",
    "égrènerait": "égrener",
    "égrèneras": "égrener",
    "égrènerez": "égrener",
    "égrèneriez": "égrener",
    "égrènerions": "égrener",
    "égrènerons": "égrener",
    "égrèneront": "égrener",
    "égrènes": "égrener",
    "égyptienne": "égyptien",
    "égyptiennes": "égyptien",
    "égyptiens": "égyptien",
    "égyptologues": "égyptologue",
    "égéenne": "égéen",
    "égéries": "égérie",
    "éhontée": "éhonté",
    "éhontées": "éhonté",
    "éhontés": "éhonté",
    "éjacula": "éjaculer",
    "éjaculai": "éjaculer",
    "éjaculaient": "éjaculer",
    "éjaculais": "éjaculer",
    "éjaculait": "éjaculer",
    "éjaculant": "éjaculer",
    "éjaculas": "éjaculer",
    "éjaculasse": "éjaculer",
    "éjaculassent": "éjaculer",
    "éjaculasses": "éjaculer",
    "éjaculassiez": "éjaculer",
    "éjaculassions": "éjaculer",
    "éjaculateurs": "éjaculateur",
    "éjaculations": "éjaculation",
    "éjacule": "éjaculer",
    "éjaculent": "éjaculer",
    "éjaculera": "éjaculer",
    "éjaculerai": "éjaculer",
    "éjaculeraient": "éjaculer",
    "éjaculerais": "éjaculer",
    "éjaculerait": "éjaculer",
    "éjaculeras": "éjaculer",
    "éjaculerez": "éjaculer",
    "éjaculeriez": "éjaculer",
    "éjaculerions": "éjaculer",
    "éjaculerons": "éjaculer",
    "éjaculeront": "éjaculer",
    "éjacules": "éjaculer",
    "éjaculez": "éjaculer",
    "éjaculiez": "éjaculer",
    "éjaculions": "éjaculer",
    "éjaculons": "éjaculer",
    "éjaculâmes": "éjaculer",
    "éjaculât": "éjaculer",
    "éjaculâtes": "éjaculer",
    "éjaculèrent": "éjaculer",
    "éjaculé": "éjaculer",
    "éjaculée": "éjaculer",
    "éjaculées": "éjaculer",
    "éjaculés": "éjaculer",
    "éjecta": "éjecter",
    "éjectables": "éjectable",
    "éjectai": "éjecter",
    "éjectaient": "éjecter",
    "éjectais": "éjecter",
    "éjectait": "éjecter",
    "éjectant": "éjecter",
    "éjectas": "éjecter",
    "éjectasse": "éjecter",
    "éjectassent": "éjecter",
    "éjectasses": "éjecter",
    "éjectassiez": "éjecter",
    "éjectassions": "éjecter",
    "éjecte": "éjecter",
    "éjectent": "éjecter",
    "éjectera": "éjecter",
    "éjecterai": "éjecter",
    "éjecteraient": "éjecter",
    "éjecterais": "éjecter",
    "éjecterait": "éjecter",
    "éjecteras": "éjecter",
    "éjecterez": "éjecter",
    "éjecteriez": "éjecter",
    "éjecterions": "éjecter",
    "éjecterons": "éjecter",
    "éjecteront": "éjecter",
    "éjectes": "éjecter",
    "éjecteurs": "éjecteur",
    "éjectez": "éjecter",
    "éjectiez": "éjecter",
    "éjections": "éjection",
    "éjectons": "éjecter",
    "éjectâmes": "éjecter",
    "éjectât": "éjecter",
    "éjectâtes": "éjecter",
    "éjectèrent": "éjecter",
    "éjecté": "éjecter",
    "éjectée": "éjecter",
    "éjectées": "éjecter",
    "éjectés": "éjecter",
    "élabora": "élaborer",
    "élaborai": "élaborer",
    "élaboraient": "élaborer",
    "élaborais": "élaborer",
    "élaborait": "élaborer",
    "élaborant": "élaborer",
    "élaboras": "élaborer",
    "élaborasse": "élaborer",
    "élaborassent": "élaborer",
    "élaborasses": "élaborer",
    "élaborassiez": "élaborer",
    "élaborassions": "élaborer",
    "élaborations": "élaboration",
    "élabore": "élaborer",
    "élaborent": "élaborer",
    "élaborera": "élaborer",
    "élaborerai": "élaborer",
    "élaboreraient": "élaborer",
    "élaborerais": "élaborer",
    "élaborerait": "élaborer",
    "élaboreras": "élaborer",
    "élaborerez": "élaborer",
    "élaboreriez": "élaborer",
    "élaborerions": "élaborer",
    "élaborerons": "élaborer",
    "élaboreront": "élaborer",
    "élabores": "élaborer",
    "élaborez": "élaborer",
    "élaboriez": "élaborer",
    "élaborions": "élaborer",
    "élaborons": "élaborer",
    "élaborâmes": "élaborer",
    "élaborât": "élaborer",
    "élaborâtes": "élaborer",
    "élaborèrent": "élaborer",
    "élaboré": "élaborer",
    "élaborée": "élaborer",
    "élaborées": "élaborer",
    "élaborés": "élaborer",
    "élagages": "élagage",
    "élagua": "élaguer",
    "élaguai": "élaguer",
    "élaguaient": "élaguer",
    "élaguais": "élaguer",
    "élaguait": "élaguer",
    "élaguant": "élaguer",
    "élaguas": "élaguer",
    "élaguasse": "élaguer",
    "élaguassent": "élaguer",
    "élaguasses": "élaguer",
    "élaguassiez": "élaguer",
    "élaguassions": "élaguer",
    "élague": "élaguer",
    "élaguent": "élaguer",
    "élaguera": "élaguer",
    "élaguerai": "élaguer",
    "élagueraient": "élaguer",
    "élaguerais": "élaguer",
    "élaguerait": "élaguer",
    "élagueras": "élaguer",
    "élaguerez": "élaguer",
    "élagueriez": "élaguer",
    "élaguerions": "élaguer",
    "élaguerons": "élaguer",
    "élagueront": "élaguer",
    "élagues": "élaguer",
    "élagueurs": "élagueur",
    "élaguez": "élaguer",
    "élaguiez": "élaguer",
    "élaguions": "élaguer",
    "élaguons": "élaguer",
    "élaguâmes": "élaguer",
    "élaguât": "élaguer",
    "élaguâtes": "élaguer",
    "élaguèrent": "élaguer",
    "élagué": "élaguer",
    "élaguée": "élaguer",
    "élaguées": "élaguer",
    "élagués": "élaguer",
    "élance": "élancer",
    "élancements": "élancement",
    "élancent": "élancer",
    "élancera": "élancer",
    "élancerai": "élancer",
    "élanceraient": "élancer",
    "élancerais": "élancer",
    "élancerait": "élancer",
    "élanceras": "élancer",
    "élancerez": "élancer",
    "élanceriez": "élancer",
    "élancerions": "élancer",
    "élancerons": "élancer",
    "élanceront": "élancer",
    "élances": "élancer",
    "élancez": "élancer",
    "élanciez": "élancer",
    "élancions": "élancer",
    "élancèrent": "élancer",
    "élancé": "élancer",
    "élancée": "élancer",
    "élancées": "élancer",
    "élancés": "élancer",
    "élans": "élan",
    "élança": "élancer",
    "élançai": "élancer",
    "élançaient": "élancer",
    "élançais": "élancer",
    "élançait": "élancer",
    "élançant": "élancer",
    "élanças": "élancer",
    "élançasse": "élancer",
    "élançassent": "élancer",
    "élançasses": "élancer",
    "élançassiez": "élancer",
    "élançassions": "élancer",
    "élançons": "élancer",
    "élançâmes": "élancer",
    "élançât": "élancer",
    "élançâtes": "élancer",
    "élargi": "élargir",
    "élargie": "élargir",
    "élargies": "élargir",
    "élargira": "élargir",
    "élargirai": "élargir",
    "élargiraient": "élargir",
    "élargirais": "élargir",
    "élargirait": "élargir",
    "élargiras": "élargir",
    "élargirent": "élargir",
    "élargirez": "élargir",
    "élargiriez": "élargir",
    "élargirions": "élargir",
    "élargirons": "élargir",
    "élargiront": "élargir",
    "élargis": "élargir",
    "élargissaient": "élargir",
    "élargissais": "élargir",
    "élargissait": "élargir",
    "élargissant": "élargir",
    "élargisse": "élargir",
    "élargissements": "élargissement",
    "élargissent": "élargir",
    "élargisses": "élargir",
    "élargissez": "élargir",
    "élargissiez": "élargir",
    "élargissions": "élargir",
    "élargissons": "élargir",
    "élargit": "élargir",
    "élargîmes": "élargir",
    "élargît": "élargir",
    "élargîtes": "élargir",
    "élasticités": "élasticité",
    "élastiques": "élastique",
    "élava": "élaver",
    "élavai": "élaver",
    "élavaient": "élaver",
    "élavais": "élaver",
    "élavait": "élaver",
    "élavant": "élaver",
    "élavas": "élaver",
    "élavasse": "élaver",
    "élavassent": "élaver",
    "élavasses": "élaver",
    "élavassiez": "élaver",
    "élavassions": "élaver",
    "élave": "élaver",
    "élavent": "élaver",
    "élavera": "élaver",
    "élaverai": "élaver",
    "élaveraient": "élaver",
    "élaverais": "élaver",
    "élaverait": "élaver",
    "élaveras": "élaver",
    "élaverez": "élaver",
    "élaveriez": "élaver",
    "élaverions": "élaver",
    "élaverons": "élaver",
    "élaveront": "élaver",
    "élaves": "élaver",
    "élavez": "élaver",
    "élaviez": "élaver",
    "élavions": "élaver",
    "élavons": "élaver",
    "élavâmes": "élaver",
    "élavât": "élaver",
    "élavâtes": "élaver",
    "élavèrent": "élaver",
    "élavé": "élaver",
    "élavée": "élaver",
    "élavées": "élaver",
    "élavés": "élaver",
    "électeurs": "électeur",
    "électifs": "électif",
    "élections": "élection",
    "élective": "électif",
    "électives": "électif",
    "électorale": "électoral",
    "électorales": "électoral",
    "électoralistes": "électoraliste",
    "électorats": "électorat",
    "électoraux": "électoral",
    "électrice": "électeur",
    "électrices": "électeur",
    "électricienne": "électricien",
    "électriciennes": "électricien",
    "électriciens": "électricien",
    "électricités": "électricité",
    "électrifia": "électrifier",
    "électrifiait": "électrifier",
    "électrifiant": "électrifier",
    "électrifications": "électrification",
    "électrifié": "électrifier",
    "électrifiée": "électrifier",
    "électrifiées": "électrifier",
    "électrifiés": "électrifier",
    "électriques": "électrique",
    "électrisa": "électriser",
    "électrisaient": "électriser",
    "électrisais": "électriser",
    "électrisait": "électriser",
    "électrisant": "électriser",
    "électrisante": "électrisant",
    "électrise": "électriser",
    "électrisent": "électriser",
    "électrisèrent": "électriser",
    "électrisé": "électriser",
    "électrisée": "électriser",
    "électrisées": "électriser",
    "électroacoustiques": "électroacoustique",
    "électroaimants": "électroaimant",
    "électrocardiogrammes": "électrocardiogramme",
    "électrochimiques": "électrochimique",
    "électrochocs": "électrochoc",
    "électrocuta": "électrocuter",
    "électrocutai": "électrocuter",
    "électrocutaient": "électrocuter",
    "électrocutais": "électrocuter",
    "électrocutait": "électrocuter",
    "électrocutant": "électrocuter",
    "électrocutas": "électrocuter",
    "électrocutasse": "électrocuter",
    "électrocutassent": "électrocuter",
    "électrocutasses": "électrocuter",
    "électrocutassiez": "électrocuter",
    "électrocutassions": "électrocuter",
    "électrocute": "électrocuter",
    "électrocutent": "électrocuter",
    "électrocutera": "électrocuter",
    "électrocuterai": "électrocuter",
    "électrocuteraient": "électrocuter",
    "électrocuterais": "électrocuter",
    "électrocuterait": "électrocuter",
    "électrocuteras": "électrocuter",
    "électrocuterez": "électrocuter",
    "électrocuteriez": "électrocuter",
    "électrocuterions": "électrocuter",
    "électrocuterons": "électrocuter",
    "électrocuteront": "électrocuter",
    "électrocutes": "électrocuter",
    "électrocutez": "électrocuter",
    "électrocutiez": "électrocuter",
    "électrocutions": "électrocuter",
    "électrocutons": "électrocuter",
    "électrocutâmes": "électrocuter",
    "électrocutât": "électrocuter",
    "électrocutâtes": "électrocuter",
    "électrocutèrent": "électrocuter",
    "électrocuté": "électrocuter",
    "électrocutée": "électrocuter",
    "électrocutées": "électrocuter",
    "électrocutés": "électrocuter",
    "électrodes": "électrode",
    "électrogènes": "électrogène",
    "électrolysa": "électrolyser",
    "électrolysai": "électrolyser",
    "électrolysaient": "électrolyser",
    "électrolysais": "électrolyser",
    "électrolysait": "électrolyser",
    "électrolysant": "électrolyser",
    "électrolysas": "électrolyser",
    "électrolysasse": "électrolyser",
    "électrolysassent": "électrolyser",
    "électrolysasses": "électrolyser",
    "électrolysassiez": "électrolyser",
    "électrolysassions": "électrolyser",
    "électrolyse": "électrolyser",
    "électrolysent": "électrolyser",
    "électrolysera": "électrolyser",
    "électrolyserai": "électrolyser",
    "électrolyseraient": "électrolyser",
    "électrolyserais": "électrolyser",
    "électrolyserait": "électrolyser",
    "électrolyseras": "électrolyser",
    "électrolyserez": "électrolyser",
    "électrolyseriez": "électrolyser",
    "électrolyserions": "électrolyser",
    "électrolyserons": "électrolyser",
    "électrolyseront": "électrolyser",
    "électrolyses": "électrolyser",
    "électrolysez": "électrolyser",
    "électrolysiez": "électrolyser",
    "électrolysions": "électrolyser",
    "électrolysons": "électrolyser",
    "électrolysâmes": "électrolyser",
    "électrolysât": "électrolyser",
    "électrolysâtes": "électrolyser",
    "électrolysèrent": "électrolyser",
    "électrolysé": "électrolyser",
    "électrolysée": "électrolyser",
    "électrolysées": "électrolyser",
    "électrolysés": "électrolyser",
    "électrolytes": "électrolyte",
    "électromagnétiques": "électromagnétique",
    "électromécaniques": "électromécanique",
    "électroménagers": "électroménager",
    "électronicienne": "électronicien",
    "électroniciennes": "électronicien",
    "électroniciens": "électronicien",
    "électroniques": "électronique",
    "électrons": "électron",
    "électronucléaires": "électronucléaire",
    "électronvolts": "électronvolt",
    "électrophones": "électrophone",
    "électrostatiques": "électrostatique",
    "électrums": "électrum",
    "électuaires": "électuaire",
    "éleusinienne": "éleusinien",
    "éleva": "élever",
    "élevages": "élevage",
    "élevai": "élever",
    "élevaient": "élever",
    "élevais": "élever",
    "élevait": "élever",
    "élevant": "élever",
    "élevas": "élever",
    "élevasse": "élever",
    "élevassent": "élever",
    "élevasses": "élever",
    "élevassiez": "élever",
    "élevassions": "élever",
    "éleveurs": "éleveur",
    "éleveuse": "éleveur",
    "éleveuses": "éleveur",
    "élevez": "élever",
    "éleviez": "élever",
    "élevions": "élever",
    "élevons": "élevon",
    "élevures": "élevure",
    "élevâmes": "élever",
    "élevât": "élever",
    "élevâtes": "élever",
    "élevèrent": "élever",
    "élevé": "élever",
    "élevée": "élever",
    "élevées": "élever",
    "élevés": "élever",
    "élia": "élier",
    "élias": "élier",
    "élida": "élider",
    "élidai": "élider",
    "élidaient": "élider",
    "élidais": "élider",
    "élidait": "élider",
    "élidant": "élider",
    "élidas": "élider",
    "élidasse": "élider",
    "élidassent": "élider",
    "élidasses": "élider",
    "élidassiez": "élider",
    "élidassions": "élider",
    "élide": "élider",
    "élident": "élider",
    "élidera": "élider",
    "éliderai": "élider",
    "élideraient": "élider",
    "éliderais": "élider",
    "éliderait": "élider",
    "élideras": "élider",
    "éliderez": "élider",
    "élideriez": "élider",
    "éliderions": "élider",
    "éliderons": "élider",
    "élideront": "élider",
    "élides": "élider",
    "élidez": "élider",
    "élidiez": "élider",
    "élidions": "élider",
    "élidons": "élider",
    "élidâmes": "élider",
    "élidât": "élider",
    "élidâtes": "élider",
    "élidèrent": "élider",
    "élidé": "élider",
    "élidée": "élider",
    "élidées": "élider",
    "élidés": "élider",
    "élie": "élier",
    "éligibilités": "éligibilité",
    "éligibles": "éligible",
    "élima": "élimer",
    "élimai": "élimer",
    "élimaient": "élimer",
    "élimais": "élimer",
    "élimait": "élimer",
    "élimant": "élimer",
    "élimas": "élimer",
    "élimasse": "élimer",
    "élimassent": "élimer",
    "élimasses": "élimer",
    "élimassiez": "élimer",
    "élimassions": "élimer",
    "élime": "élimer",
    "éliment": "élimer",
    "élimera": "élimer",
    "élimerai": "élimer",
    "élimeraient": "élimer",
    "élimerais": "élimer",
    "élimerait": "élimer",
    "élimeras": "élimer",
    "élimerez": "élimer",
    "élimeriez": "élimer",
    "élimerions": "élimer",
    "élimerons": "élimer",
    "élimeront": "élimer",
    "élimes": "élimer",
    "élimez": "élimer",
    "élimiez": "élimer",
    "élimina": "éliminer",
    "éliminai": "éliminer",
    "éliminaient": "éliminer",
    "éliminais": "éliminer",
    "éliminait": "éliminer",
    "éliminant": "éliminer",
    "éliminas": "éliminer",
    "éliminasse": "éliminer",
    "éliminassent": "éliminer",
    "éliminasses": "éliminer",
    "éliminassiez": "éliminer",
    "éliminassions": "éliminer",
    "éliminateurs": "éliminateur",
    "éliminations": "élimination",
    "éliminatoires": "éliminatoire",
    "élimine": "éliminer",
    "éliminent": "éliminer",
    "éliminera": "éliminer",
    "éliminerai": "éliminer",
    "élimineraient": "éliminer",
    "éliminerais": "éliminer",
    "éliminerait": "éliminer",
    "élimineras": "éliminer",
    "éliminerez": "éliminer",
    "élimineriez": "éliminer",
    "éliminerions": "éliminer",
    "éliminerons": "éliminer",
    "élimineront": "éliminer",
    "élimines": "éliminer",
    "éliminez": "éliminer",
    "éliminiez": "éliminer",
    "éliminions": "éliminer",
    "éliminons": "éliminer",
    "éliminâmes": "éliminer",
    "éliminât": "éliminer",
    "éliminâtes": "éliminer",
    "éliminèrent": "éliminer",
    "éliminé": "éliminer",
    "éliminée": "éliminer",
    "éliminées": "éliminer",
    "éliminés": "éliminer",
    "élimions": "élimer",
    "élimons": "élimer",
    "élimâmes": "élimer",
    "élimât": "élimer",
    "élimâtes": "élimer",
    "élimèrent": "élimer",
    "élimé": "élimer",
    "élimée": "élimer",
    "élimées": "élimer",
    "élimés": "élimer",
    "élingues": "élingue",
    "élira": "élire",
    "élirai": "élire",
    "éliraient": "élire",
    "élirais": "élire",
    "élirait": "élire",
    "éliras": "élire",
    "élirez": "élire",
    "éliriez": "élire",
    "élirions": "élire",
    "élirons": "élire",
    "éliront": "élire",
    "élis": "élire",
    "élisabéthaine": "élisabéthain",
    "élisabéthaines": "élisabéthain",
    "élisabéthains": "élisabéthain",
    "élisaient": "élire",
    "élisais": "élire",
    "élisait": "élire",
    "élisant": "élire",
    "élise": "élire",
    "élisent": "élire",
    "élises": "élire",
    "élisez": "élire",
    "élisiez": "élire",
    "élisions": "élision",
    "élisons": "élire",
    "élit": "élire",
    "élites": "élite",
    "élitismes": "élitisme",
    "élitistes": "élitiste",
    "élixirs": "élixir",
    "élocutions": "élocution",
    "éloges": "éloge",
    "élogieuse": "élogieux",
    "élogieuses": "élogieux",
    "éloigna": "éloigner",
    "éloignai": "éloigner",
    "éloignaient": "éloigner",
    "éloignais": "éloigner",
    "éloignait": "éloigner",
    "éloignant": "éloigner",
    "éloignas": "éloigner",
    "éloignasse": "éloigner",
    "éloignassent": "éloigner",
    "éloignasses": "éloigner",
    "éloignassiez": "éloigner",
    "éloignassions": "éloigner",
    "éloigne": "éloigner",
    "éloignements": "éloignement",
    "éloignent": "éloigner",
    "éloignera": "éloigner",
    "éloignerai": "éloigner",
    "éloigneraient": "éloigner",
    "éloignerais": "éloigner",
    "éloignerait": "éloigner",
    "éloigneras": "éloigner",
    "éloignerez": "éloigner",
    "éloigneriez": "éloigner",
    "éloignerions": "éloigner",
    "éloignerons": "éloigner",
    "éloigneront": "éloigner",
    "éloignes": "éloigner",
    "éloignez": "éloigner",
    "éloigniez": "éloigner",
    "éloignions": "éloigner",
    "éloignons": "éloigner",
    "éloignâmes": "éloigner",
    "éloignât": "éloigner",
    "éloignâtes": "éloigner",
    "éloignèrent": "éloigner",
    "éloigné": "éloigner",
    "éloignée": "éloigner",
    "éloignées": "éloigner",
    "éloignés": "éloigner",
    "élongations": "élongation",
    "élonge": "élonger",
    "élongea": "élonger",
    "élongeai": "élonger",
    "élongeaient": "élonger",
    "élongeais": "élonger",
    "élongeait": "élonger",
    "élongeant": "élonger",
    "élongeas": "élonger",
    "élongeasse": "élonger",
    "élongeassent": "élonger",
    "élongeasses": "élonger",
    "élongeassiez": "élonger",
    "élongeassions": "élonger",
    "élongent": "élonger",
    "élongeons": "élonger",
    "élongera": "élonger",
    "élongerai": "élonger",
    "élongeraient": "élonger",
    "élongerais": "élonger",
    "élongerait": "élonger",
    "élongeras": "élonger",
    "élongerez": "élonger",
    "élongeriez": "élonger",
    "élongerions": "élonger",
    "élongerons": "élonger",
    "élongeront": "élonger",
    "élonges": "élonger",
    "élongez": "élonger",
    "élongeâmes": "élonger",
    "élongeât": "élonger",
    "élongeâtes": "élonger",
    "élongiez": "élonger",
    "élongions": "élonger",
    "élongèrent": "élonger",
    "élongé": "élonger",
    "élongée": "élonger",
    "élongées": "élonger",
    "élongés": "élonger",
    "éloquences": "éloquence",
    "éloquente": "éloquent",
    "éloquentes": "éloquent",
    "éloquents": "éloquent",
    "élu": "élire",
    "élucida": "élucider",
    "élucidai": "élucider",
    "élucidaient": "élucider",
    "élucidais": "élucider",
    "élucidait": "élucider",
    "élucidant": "élucider",
    "élucidas": "élucider",
    "élucidasse": "élucider",
    "élucidassent": "élucider",
    "élucidasses": "élucider",
    "élucidassiez": "élucider",
    "élucidassions": "élucider",
    "élucide": "élucider",
    "élucident": "élucider",
    "élucidera": "élucider",
    "éluciderai": "élucider",
    "élucideraient": "élucider",
    "éluciderais": "élucider",
    "éluciderait": "élucider",
    "élucideras": "élucider",
    "éluciderez": "élucider",
    "élucideriez": "élucider",
    "éluciderions": "élucider",
    "éluciderons": "élucider",
    "élucideront": "élucider",
    "élucides": "élucider",
    "élucidez": "élucider",
    "élucidiez": "élucider",
    "élucidions": "élucider",
    "élucidons": "élucider",
    "élucidâmes": "élucider",
    "élucidât": "élucider",
    "élucidâtes": "élucider",
    "élucidèrent": "élucider",
    "élucidé": "élucider",
    "élucidée": "élucider",
    "élucidées": "élucider",
    "élucidés": "élucider",
    "élucubrations": "élucubration",
    "élucubre": "élucubrer",
    "élucubrent": "élucubrer",
    "éluda": "éluder",
    "éludai": "éluder",
    "éludaient": "éluder",
    "éludais": "éluder",
    "éludait": "éluder",
    "éludant": "éluder",
    "éludas": "éluder",
    "éludasse": "éluder",
    "éludassent": "éluder",
    "éludasses": "éluder",
    "éludassiez": "éluder",
    "éludassions": "éluder",
    "élude": "éluder",
    "éludent": "éluder",
    "éludera": "éluder",
    "éluderai": "éluder",
    "éluderaient": "éluder",
    "éluderais": "éluder",
    "éluderait": "éluder",
    "éluderas": "éluder",
    "éluderez": "éluder",
    "éluderiez": "éluder",
    "éluderions": "éluder",
    "éluderons": "éluder",
    "éluderont": "éluder",
    "éludes": "éluder",
    "éludez": "éluder",
    "éludiez": "éluder",
    "éludions": "éluder",
    "éludons": "éluder",
    "éludâmes": "éluder",
    "éludât": "éluder",
    "éludâtes": "éluder",
    "éludèrent": "éluder",
    "éludé": "éluder",
    "éludée": "éluder",
    "éludées": "éluder",
    "éludés": "éluder",
    "élue": "éluer",
    "élues": "élu",
    "élurent": "élire",
    "élus": "élu",
    "élusifs": "élusif",
    "élusive": "élusif",
    "élusse": "élire",
    "élussent": "élire",
    "élusses": "élire",
    "élussiez": "élire",
    "élussions": "élire",
    "élut": "élire",
    "élyséenne": "élyséen",
    "élyséennes": "élyséen",
    "élyséens": "élyséen",
    "élytres": "élytre",
    "élève": "élever",
    "élèvent": "élever",
    "élèvera": "élever",
    "élèverai": "élever",
    "élèveraient": "élever",
    "élèverais": "élever",
    "élèverait": "élever",
    "élèveras": "élever",
    "élèverez": "élever",
    "élèveriez": "élever",
    "élèverions": "élever",
    "élèverons": "élever",
    "élèveront": "élever",
    "élèves": "élever",
    "éléates": "éléate",
    "élégances": "élégance",
    "élégante": "élégant",
    "élégantes": "élégant",
    "élégants": "élégant",
    "élégi": "élégir",
    "élégiaques": "élégiaque",
    "élégie": "élégir",
    "élégies": "élégir",
    "élégira": "élégir",
    "élégirai": "élégir",
    "élégiraient": "élégir",
    "élégirais": "élégir",
    "élégirait": "élégir",
    "élégiras": "élégir",
    "élégirent": "élégir",
    "élégirez": "élégir",
    "élégiriez": "élégir",
    "élégirions": "élégir",
    "élégirons": "élégir",
    "élégiront": "élégir",
    "élégis": "élégir",
    "élégissaient": "élégir",
    "élégissais": "élégir",
    "élégissait": "élégir",
    "élégissant": "élégir",
    "élégisse": "élégir",
    "élégissent": "élégir",
    "élégisses": "élégir",
    "élégissez": "élégir",
    "élégissiez": "élégir",
    "élégissions": "élégir",
    "élégissons": "élégir",
    "élégit": "élégir",
    "élégîmes": "élégir",
    "élégît": "élégir",
    "élégîtes": "élégir",
    "élémentaires": "élémentaire",
    "éléments": "élément",
    "éléments-clés": "éléments-clé",
    "éléphante": "éléphant",
    "éléphanteaux": "éléphanteau",
    "éléphantes": "éléphant",
    "éléphantesques": "éléphantesque",
    "éléphantine": "éléphantin",
    "éléphantines": "éléphantin",
    "éléphants": "éléphant",
    "élévateurs": "élévateur",
    "élévations": "élévation",
    "élévatrice": "élévateur",
    "élévatrices": "élévateur",
    "élûmes": "élire",
    "élût": "élire",
    "élûtes": "élire",
    "émaciait": "émacier",
    "émacie": "émacier",
    "émacié": "émacier",
    "émaciée": "émacier",
    "émaciées": "émacier",
    "émaciés": "émacier",
    "émailla": "émailler",
    "émaillai": "émailler",
    "émaillaient": "émailler",
    "émaillais": "émailler",
    "émaillait": "émailler",
    "émaillant": "émailler",
    "émaillas": "émailler",
    "émaillasse": "émailler",
    "émaillassent": "émailler",
    "émaillasses": "émailler",
    "émaillassiez": "émailler",
    "émaillassions": "émailler",
    "émaille": "émailler",
    "émaillent": "émailler",
    "émaillera": "émailler",
    "émaillerai": "émailler",
    "émailleraient": "émailler",
    "émaillerais": "émailler",
    "émaillerait": "émailler",
    "émailleras": "émailler",
    "émaillerez": "émailler",
    "émailleriez": "émailler",
    "émaillerions": "émailler",
    "émaillerons": "émailler",
    "émailleront": "émailler",
    "émailles": "émailler",
    "émaillez": "émailler",
    "émailliez": "émailler",
    "émaillions": "émailler",
    "émaillons": "émailler",
    "émaillâmes": "émailler",
    "émaillât": "émailler",
    "émaillâtes": "émailler",
    "émaillèrent": "émailler",
    "émaillé": "émailler",
    "émaillée": "émailler",
    "émaillées": "émailler",
    "émaillés": "émailler",
    "émana": "émaner",
    "émanai": "émaner",
    "émanaient": "émaner",
    "émanais": "émaner",
    "émanait": "émaner",
    "émanant": "émaner",
    "émanas": "émaner",
    "émanasse": "émaner",
    "émanassent": "émaner",
    "émanasses": "émaner",
    "émanassiez": "émaner",
    "émanassions": "émaner",
    "émanations": "émanation",
    "émancipa": "émanciper",
    "émancipai": "émanciper",
    "émancipaient": "émanciper",
    "émancipais": "émanciper",
    "émancipait": "émanciper",
    "émancipant": "émanciper",
    "émancipas": "émanciper",
    "émancipasse": "émanciper",
    "émancipassent": "émanciper",
    "émancipasses": "émanciper",
    "émancipassiez": "émanciper",
    "émancipassions": "émanciper",
    "émancipations": "émancipation",
    "émancipatrice": "émancipateur",
    "émancipe": "émanciper",
    "émancipent": "émanciper",
    "émancipera": "émanciper",
    "émanciperai": "émanciper",
    "émanciperaient": "émanciper",
    "émanciperais": "émanciper",
    "émanciperait": "émanciper",
    "émanciperas": "émanciper",
    "émanciperez": "émanciper",
    "émanciperiez": "émanciper",
    "émanciperions": "émanciper",
    "émanciperons": "émanciper",
    "émanciperont": "émanciper",
    "émancipes": "émanciper",
    "émancipez": "émanciper",
    "émancipiez": "émanciper",
    "émancipions": "émanciper",
    "émancipons": "émanciper",
    "émancipâmes": "émanciper",
    "émancipât": "émanciper",
    "émancipâtes": "émanciper",
    "émancipèrent": "émanciper",
    "émancipé": "émanciper",
    "émancipée": "émanciper",
    "émancipées": "émanciper",
    "émancipés": "émanciper",
    "émane": "émaner",
    "émanent": "émaner",
    "émanera": "émaner",
    "émanerai": "émaner",
    "émaneraient": "émaner",
    "émanerais": "émaner",
    "émanerait": "émaner",
    "émaneras": "émaner",
    "émanerez": "émaner",
    "émaneriez": "émaner",
    "émanerions": "émaner",
    "émanerons": "émaner",
    "émaneront": "émaner",
    "émanes": "émaner",
    "émanez": "émaner",
    "émaniez": "émaner",
    "émanions": "émaner",
    "émanons": "émaner",
    "émanâmes": "émaner",
    "émanât": "émaner",
    "émanâtes": "émaner",
    "émanèrent": "émaner",
    "émané": "émaner",
    "émanée": "émaner",
    "émanées": "émaner",
    "émanés": "émaner",
    "émarge": "émarger",
    "émargea": "émarger",
    "émargeai": "émarger",
    "émargeaient": "émarger",
    "émargeais": "émarger",
    "émargeait": "émarger",
    "émargeant": "émarger",
    "émargeas": "émarger",
    "émargeasse": "émarger",
    "émargeassent": "émarger",
    "émargeasses": "émarger",
    "émargeassiez": "émarger",
    "émargeassions": "émarger",
    "émargent": "émarger",
    "émargeons": "émarger",
    "émargera": "émarger",
    "émargerai": "émarger",
    "émargeraient": "émarger",
    "émargerais": "émarger",
    "émargerait": "émarger",
    "émargeras": "émarger",
    "émargerez": "émarger",
    "émargeriez": "émarger",
    "émargerions": "émarger",
    "émargerons": "émarger",
    "émargeront": "émarger",
    "émarges": "émarger",
    "émargez": "émarger",
    "émargeâmes": "émarger",
    "émargeât": "émarger",
    "émargeâtes": "émarger",
    "émargiez": "émarger",
    "émargions": "émarger",
    "émargèrent": "émarger",
    "émargé": "émarger",
    "émargée": "émarger",
    "émargées": "émarger",
    "émargés": "émarger",
    "émascula": "émasculer",
    "émasculai": "émasculer",
    "émasculaient": "émasculer",
    "émasculais": "émasculer",
    "émasculait": "émasculer",
    "émasculant": "émasculer",
    "émasculas": "émasculer",
    "émasculasse": "émasculer",
    "émasculassent": "émasculer",
    "émasculasses": "émasculer",
    "émasculassiez": "émasculer",
    "émasculassions": "émasculer",
    "émasculations": "émasculation",
    "émascule": "émasculer",
    "émasculent": "émasculer",
    "émasculera": "émasculer",
    "émasculerai": "émasculer",
    "émasculeraient": "émasculer",
    "émasculerais": "émasculer",
    "émasculerait": "émasculer",
    "émasculeras": "émasculer",
    "émasculerez": "émasculer",
    "émasculeriez": "émasculer",
    "émasculerions": "émasculer",
    "émasculerons": "émasculer",
    "émasculeront": "émasculer",
    "émascules": "émasculer",
    "émasculez": "émasculer",
    "émasculiez": "émasculer",
    "émasculions": "émasculer",
    "émasculons": "émasculer",
    "émasculâmes": "émasculer",
    "émasculât": "émasculer",
    "émasculâtes": "émasculer",
    "émasculèrent": "émasculer",
    "émasculé": "émasculer",
    "émasculée": "émasculer",
    "émasculées": "émasculer",
    "émasculés": "émasculer",
    "émaux": "émail",
    "émeraudes": "émeraude",
    "émerge": "émerger",
    "émergea": "émerger",
    "émergeai": "émerger",
    "émergeaient": "émerger",
    "émergeais": "émerger",
    "émergeait": "émerger",
    "émergeant": "émerger",
    "émergeas": "émerger",
    "émergeasse": "émerger",
    "émergeassent": "émerger",
    "émergeasses": "émerger",
    "émergeassiez": "émerger",
    "émergeassions": "émerger",
    "émergences": "émergence",
    "émergent": "émerger",
    "émergente": "émergent",
    "émergentes": "émergent",
    "émergents": "émergent",
    "émergeons": "émerger",
    "émergera": "émerger",
    "émergerai": "émerger",
    "émergeraient": "émerger",
    "émergerais": "émerger",
    "émergerait": "émerger",
    "émergeras": "émerger",
    "émergerez": "émerger",
    "émergeriez": "émerger",
    "émergerions": "émerger",
    "émergerons": "émerger",
    "émergeront": "émerger",
    "émerges": "émerger",
    "émergez": "émerger",
    "émergeâmes": "émerger",
    "émergeât": "émerger",
    "émergeâtes": "émerger",
    "émergiez": "émerger",
    "émergions": "émerger",
    "émergèrent": "émerger",
    "émergé": "émerger",
    "émergée": "émerger",
    "émergées": "émerger",
    "émergés": "émerger",
    "émerillons": "émerillon",
    "émeris": "émeri",
    "émerisé": "émeriser",
    "émerisées": "émeriser",
    "émerveilla": "émerveiller",
    "émerveillai": "émerveiller",
    "émerveillaient": "émerveiller",
    "émerveillais": "émerveiller",
    "émerveillait": "émerveiller",
    "émerveillant": "émerveiller",
    "émerveillas": "émerveiller",
    "émerveillasse": "émerveiller",
    "émerveillassent": "émerveiller",
    "émerveillasses": "émerveiller",
    "émerveillassiez": "émerveiller",
    "émerveillassions": "émerveiller",
    "émerveille": "émerveiller",
    "émerveillements": "émerveillement",
    "émerveillent": "émerveiller",
    "émerveillera": "émerveiller",
    "émerveillerai": "émerveiller",
    "émerveilleraient": "émerveiller",
    "émerveillerais": "émerveiller",
    "émerveillerait": "émerveiller",
    "émerveilleras": "émerveiller",
    "émerveillerez": "émerveiller",
    "émerveilleriez": "émerveiller",
    "émerveillerions": "émerveiller",
    "émerveillerons": "émerveiller",
    "émerveilleront": "émerveiller",
    "émerveilles": "émerveiller",
    "émerveillez": "émerveiller",
    "émerveilliez": "émerveiller",
    "émerveillions": "émerveiller",
    "émerveillons": "émerveiller",
    "émerveillâmes": "émerveiller",
    "émerveillât": "émerveiller",
    "émerveillâtes": "émerveiller",
    "émerveillèrent": "émerveiller",
    "émerveillé": "émerveiller",
    "émerveillée": "émerveiller",
    "émerveillées": "émerveiller",
    "émerveillés": "émerveiller",
    "émet": "émettre",
    "émets": "émettre",
    "émettaient": "émettre",
    "émettais": "émettre",
    "émettait": "émettre",
    "émettant": "émettre",
    "émette": "émettre",
    "émettent": "émettre",
    "émettes": "émettre",
    "émetteurs": "émetteur",
    "émettez": "émettre",
    "émettiez": "émettre",
    "émettions": "émettre",
    "émettons": "émettre",
    "émettra": "émettre",
    "émettrai": "émettre",
    "émettraient": "émettre",
    "émettrais": "émettre",
    "émettrait": "émettre",
    "émettras": "émettre",
    "émettrez": "émettre",
    "émettrice": "émetteur",
    "émettrices": "émetteur",
    "émettriez": "émettre",
    "émettrions": "émettre",
    "émettrons": "émettre",
    "émettront": "émettre",
    "émeus": "émouvoir",
    "émeut": "émouvoir",
    "émeutes": "émeute",
    "émeutiers": "émeutier",
    "émeutière": "émeutier",
    "émeutières": "émeutier",
    "émeuve": "émouvoir",
    "émeuvent": "émouvoir",
    "émeuves": "émouvoir",
    "émietta": "émietter",
    "émiettai": "émietter",
    "émiettaient": "émietter",
    "émiettais": "émietter",
    "émiettait": "émietter",
    "émiettant": "émietter",
    "émiettas": "émietter",
    "émiettasse": "émietter",
    "émiettassent": "émietter",
    "émiettasses": "émietter",
    "émiettassiez": "émietter",
    "émiettassions": "émietter",
    "émiette": "émietter",
    "émiettements": "émiettement",
    "émiettent": "émietter",
    "émiettera": "émietter",
    "émietterai": "émietter",
    "émietteraient": "émietter",
    "émietterais": "émietter",
    "émietterait": "émietter",
    "émietteras": "émietter",
    "émietterez": "émietter",
    "émietteriez": "émietter",
    "émietterions": "émietter",
    "émietterons": "émietter",
    "émietteront": "émietter",
    "émiettes": "émietter",
    "émiettez": "émietter",
    "émiettiez": "émietter",
    "émiettions": "émietter",
    "émiettons": "émietter",
    "émiettâmes": "émietter",
    "émiettât": "émietter",
    "émiettâtes": "émietter",
    "émiettèrent": "émietter",
    "émietté": "émietter",
    "émiettée": "émietter",
    "émiettées": "émietter",
    "émiettés": "émietter",
    "émigra": "émigrer",
    "émigrai": "émigrer",
    "émigraient": "émigrer",
    "émigrais": "émigrer",
    "émigrait": "émigrer",
    "émigrant": "émigrer",
    "émigrante": "émigrant",
    "émigrantes": "émigrant",
    "émigrants": "émigrant",
    "émigras": "émigrer",
    "émigrasse": "émigrer",
    "émigrassent": "émigrer",
    "émigrasses": "émigrer",
    "émigrassiez": "émigrer",
    "émigrassions": "émigrer",
    "émigrations": "émigration",
    "émigre": "émigrer",
    "émigrent": "émigrer",
    "émigrera": "émigrer",
    "émigrerai": "émigrer",
    "émigreraient": "émigrer",
    "émigrerais": "émigrer",
    "émigrerait": "émigrer",
    "émigreras": "émigrer",
    "émigrerez": "émigrer",
    "émigreriez": "émigrer",
    "émigrerions": "émigrer",
    "émigrerons": "émigrer",
    "émigreront": "émigrer",
    "émigres": "émigrer",
    "émigrez": "émigrer",
    "émigriez": "émigrer",
    "émigrions": "émigrer",
    "émigrons": "émigrer",
    "émigrâmes": "émigrer",
    "émigrât": "émigrer",
    "émigrâtes": "émigrer",
    "émigrèrent": "émigrer",
    "émigré": "émigrer",
    "émigrée": "émigrer",
    "émigrées": "émigrer",
    "émigrés": "émigrer",
    "émilienne": "émilien",
    "émince": "émincer",
    "émincent": "émincer",
    "émincera": "émincer",
    "émincerai": "émincer",
    "éminceraient": "émincer",
    "émincerais": "émincer",
    "émincerait": "émincer",
    "éminceras": "émincer",
    "émincerez": "émincer",
    "éminceriez": "émincer",
    "émincerions": "émincer",
    "émincerons": "émincer",
    "éminceront": "émincer",
    "éminces": "émincer",
    "émincez": "émincer",
    "éminciez": "émincer",
    "émincions": "émincer",
    "émincèrent": "émincer",
    "émincé": "émincer",
    "émincée": "émincer",
    "émincées": "émincer",
    "émincés": "émincer",
    "éminences": "éminence",
    "éminente": "éminent",
    "éminentes": "éminent",
    "éminentissimes": "éminentissime",
    "éminents": "éminent",
    "éminça": "émincer",
    "éminçai": "émincer",
    "éminçaient": "émincer",
    "éminçais": "émincer",
    "éminçait": "émincer",
    "éminçant": "émincer",
    "éminças": "émincer",
    "éminçasse": "émincer",
    "éminçassent": "émincer",
    "éminçasses": "émincer",
    "éminçassiez": "émincer",
    "éminçassions": "émincer",
    "éminçons": "émincer",
    "éminçâmes": "émincer",
    "éminçât": "émincer",
    "éminçâtes": "émincer",
    "émirats": "émirat",
    "émirent": "émettre",
    "émirs": "émir",
    "émis": "émettre",
    "émise": "émettre",
    "émises": "émettre",
    "émissaires": "émissaire",
    "émisse": "émettre",
    "émissent": "émettre",
    "émisses": "émettre",
    "émissiez": "émettre",
    "émissifs": "émissif",
    "émissions": "émission",
    "émissives": "émissif",
    "émit": "émettre",
    "émois": "émoi",
    "émolliente": "émollient",
    "émollientes": "émollient",
    "émollients": "émollient",
    "émoluments": "émolument",
    "émonctoires": "émonctoire",
    "émonda": "émonder",
    "émondai": "émonder",
    "émondaient": "émonder",
    "émondais": "émonder",
    "émondait": "émonder",
    "émondant": "émonder",
    "émondas": "émonder",
    "émondasse": "émonder",
    "émondassent": "émonder",
    "émondasses": "émonder",
    "émondassiez": "émonder",
    "émondassions": "émonder",
    "émonde": "émonder",
    "émondent": "émonder",
    "émondera": "émonder",
    "émonderai": "émonder",
    "émonderaient": "émonder",
    "émonderais": "émonder",
    "émonderait": "émonder",
    "émonderas": "émonder",
    "émonderez": "émonder",
    "émonderiez": "émonder",
    "émonderions": "émonder",
    "émonderons": "émonder",
    "émonderont": "émonder",
    "émondes": "émonder",
    "émondez": "émonder",
    "émondiez": "émonder",
    "émondions": "émonder",
    "émondons": "émonder",
    "émondâmes": "émonder",
    "émondât": "émonder",
    "émondâtes": "émonder",
    "émondèrent": "émonder",
    "émondé": "émonder",
    "émondée": "émonder",
    "émondées": "émonder",
    "émondés": "émonder",
    "émotifs": "émotif",
    "émotionna": "émotionner",
    "émotionnai": "émotionner",
    "émotionnaient": "émotionner",
    "émotionnais": "émotionner",
    "émotionnait": "émotionner",
    "émotionnant": "émotionner",
    "émotionnante": "émotionnant",
    "émotionnas": "émotionner",
    "émotionnasse": "émotionner",
    "émotionnassent": "émotionner",
    "émotionnasses": "émotionner",
    "émotionnassiez": "émotionner",
    "émotionnassions": "émotionner",
    "émotionne": "émotionner",
    "émotionnelle": "émotionnel",
    "émotionnelles": "émotionnel",
    "émotionnels": "émotionnel",
    "émotionnent": "émotionner",
    "émotionnera": "émotionner",
    "émotionnerai": "émotionner",
    "émotionneraient": "émotionner",
    "émotionnerais": "émotionner",
    "émotionnerait": "émotionner",
    "émotionneras": "émotionner",
    "émotionnerez": "émotionner",
    "émotionneriez": "émotionner",
    "émotionnerions": "émotionner",
    "émotionnerons": "émotionner",
    "émotionneront": "émotionner",
    "émotionnes": "émotionner",
    "émotionnez": "émotionner",
    "émotionniez": "émotionner",
    "émotionnions": "émotionner",
    "émotionnons": "émotionner",
    "émotionnâmes": "émotionner",
    "émotionnât": "émotionner",
    "émotionnâtes": "émotionner",
    "émotionnèrent": "émotionner",
    "émotionné": "émotionner",
    "émotionnée": "émotionner",
    "émotionnées": "émotionner",
    "émotionnés": "émotionner",
    "émotions": "émotion",
    "émotive": "émotif",
    "émotives": "émotif",
    "émoucha": "émoucher",
    "émouchai": "émoucher",
    "émouchaient": "émoucher",
    "émouchais": "émoucher",
    "émouchait": "émoucher",
    "émouchant": "émoucher",
    "émouchas": "émoucher",
    "émouchasse": "émoucher",
    "émouchassent": "émoucher",
    "émouchasses": "émoucher",
    "émouchassiez": "émoucher",
    "émouchassions": "émoucher",
    "émouche": "émoucher",
    "émouchent": "émoucher",
    "émouchera": "émoucher",
    "émoucherai": "émoucher",
    "émoucheraient": "émoucher",
    "émoucherais": "émoucher",
    "émoucherait": "émoucher",
    "émoucheras": "émoucher",
    "émoucherez": "émoucher",
    "émoucheriez": "émoucher",
    "émoucherions": "émoucher",
    "émoucherons": "émoucher",
    "émoucheront": "émoucher",
    "émouches": "émoucher",
    "émouchets": "émouchet",
    "émouchez": "émoucher",
    "émouchiez": "émoucher",
    "émouchions": "émoucher",
    "émouchons": "émoucher",
    "émouchâmes": "émoucher",
    "émouchât": "émoucher",
    "émouchâtes": "émoucher",
    "émouchèrent": "émoucher",
    "émouché": "émoucher",
    "émouchée": "émoucher",
    "émouchées": "émoucher",
    "émouchés": "émoucher",
    "émoud": "émoudre",
    "émoudra": "émoudre",
    "émoudrai": "émoudre",
    "émoudraient": "émoudre",
    "émoudrais": "émoudre",
    "émoudrait": "émoudre",
    "émoudras": "émoudre",
    "émoudrez": "émoudre",
    "émoudriez": "émoudre",
    "émoudrions": "émoudre",
    "émoudrons": "émoudre",
    "émoudront": "émoudre",
    "émouds": "émoudre",
    "émoulaient": "émoudre",
    "émoulais": "émoudre",
    "émoulait": "émoudre",
    "émoulant": "émoudre",
    "émoule": "émoudre",
    "émoulent": "émoudre",
    "émoules": "émoudre",
    "émoulez": "émoudre",
    "émouliez": "émoudre",
    "émoulions": "émoudre",
    "émoulons": "émoudre",
    "émoulu": "émoudre",
    "émoulue": "émoulu",
    "émoulues": "émoulu",
    "émoulurent": "émoudre",
    "émoulus": "émoulu",
    "émoulusse": "émoudre",
    "émoulussent": "émoudre",
    "émoulusses": "émoudre",
    "émoulussiez": "émoudre",
    "émoulussions": "émoudre",
    "émoulut": "émoudre",
    "émoulûmes": "émoudre",
    "émoulût": "émoudre",
    "émoulûtes": "émoudre",
    "émoussa": "émousser",
    "émoussai": "émousser",
    "émoussaient": "émousser",
    "émoussais": "émousser",
    "émoussait": "émousser",
    "émoussant": "émousser",
    "émoussas": "émousser",
    "émoussasse": "émousser",
    "émoussassent": "émousser",
    "émoussasses": "émousser",
    "émoussassiez": "émousser",
    "émoussassions": "émousser",
    "émousse": "émousser",
    "émoussent": "émousser",
    "émoussera": "émousser",
    "émousserai": "émousser",
    "émousseraient": "émousser",
    "émousserais": "émousser",
    "émousserait": "émousser",
    "émousseras": "émousser",
    "émousserez": "émousser",
    "émousseriez": "émousser",
    "émousserions": "émousser",
    "émousserons": "émousser",
    "émousseront": "émousser",
    "émousses": "émousser",
    "émoussez": "émousser",
    "émoussiez": "émousser",
    "émoussions": "émousser",
    "émoussons": "émousser",
    "émoussâmes": "émousser",
    "émoussât": "émousser",
    "émoussâtes": "émousser",
    "émoussèrent": "émousser",
    "émoussé": "émousser",
    "émoussée": "émousser",
    "émoussées": "émousser",
    "émoussés": "émousser",
    "émoustilla": "émoustiller",
    "émoustillai": "émoustiller",
    "émoustillaient": "émoustiller",
    "émoustillais": "émoustiller",
    "émoustillait": "émoustiller",
    "émoustillant": "émoustiller",
    "émoustillante": "émoustillant",
    "émoustillas": "émoustiller",
    "émoustillasse": "émoustiller",
    "émoustillassent": "émoustiller",
    "émoustillasses": "émoustiller",
    "émoustillassiez": "émoustiller",
    "émoustillassions": "émoustiller",
    "émoustille": "émoustiller",
    "émoustillent": "émoustiller",
    "émoustillera": "émoustiller",
    "émoustillerai": "émoustiller",
    "émoustilleraient": "émoustiller",
    "émoustillerais": "émoustiller",
    "émoustillerait": "émoustiller",
    "émoustilleras": "émoustiller",
    "émoustillerez": "émoustiller",
    "émoustilleriez": "émoustiller",
    "émoustillerions": "émoustiller",
    "émoustillerons": "émoustiller",
    "émoustilleront": "émoustiller",
    "émoustilles": "émoustiller",
    "émoustillez": "émoustiller",
    "émoustilliez": "émoustiller",
    "émoustillions": "émoustiller",
    "émoustillons": "émoustiller",
    "émoustillâmes": "émoustiller",
    "émoustillât": "émoustiller",
    "émoustillâtes": "émoustiller",
    "émoustillèrent": "émoustiller",
    "émoustillé": "émoustiller",
    "émoustillée": "émoustiller",
    "émoustillées": "émoustiller",
    "émoustillés": "émoustiller",
    "émouvaient": "émouvoir",
    "émouvais": "émouvoir",
    "émouvait": "émouvoir",
    "émouvant": "émouvoir",
    "émouvante": "émouvant",
    "émouvantes": "émouvant",
    "émouvants": "émouvant",
    "émouvez": "émouvoir",
    "émouviez": "émouvoir",
    "émouvions": "émouvoir",
    "émouvons": "émouvoir",
    "émouvra": "émouvoir",
    "émouvrai": "émouvoir",
    "émouvraient": "émouvoir",
    "émouvrais": "émouvoir",
    "émouvrait": "émouvoir",
    "émouvras": "émouvoir",
    "émouvrez": "émouvoir",
    "émouvriez": "émouvoir",
    "émouvrions": "émouvoir",
    "émouvrons": "émouvoir",
    "émouvront": "émouvoir",
    "ému": "émouvoir",
    "émue": "ému",
    "émues": "ému",
    "émulations": "émulation",
    "émules": "émule",
    "émulsionna": "émulsionner",
    "émulsionnai": "émulsionner",
    "émulsionnaient": "émulsionner",
    "émulsionnais": "émulsionner",
    "émulsionnait": "émulsionner",
    "émulsionnant": "émulsionner",
    "émulsionnas": "émulsionner",
    "émulsionnasse": "émulsionner",
    "émulsionnassent": "émulsionner",
    "émulsionnasses": "émulsionner",
    "émulsionnassiez": "émulsionner",
    "émulsionnassions": "émulsionner",
    "émulsionne": "émulsionner",
    "émulsionnent": "émulsionner",
    "émulsionnera": "émulsionner",
    "émulsionnerai": "émulsionner",
    "émulsionneraient": "émulsionner",
    "émulsionnerais": "émulsionner",
    "émulsionnerait": "émulsionner",
    "émulsionneras": "émulsionner",
    "émulsionnerez": "émulsionner",
    "émulsionneriez": "émulsionner",
    "émulsionnerions": "émulsionner",
    "émulsionnerons": "émulsionner",
    "émulsionneront": "émulsionner",
    "émulsionnes": "émulsionner",
    "émulsionnez": "émulsionner",
    "émulsionniez": "émulsionner",
    "émulsionnions": "émulsionner",
    "émulsionnons": "émulsionner",
    "émulsionnâmes": "émulsionner",
    "émulsionnât": "émulsionner",
    "émulsionnâtes": "émulsionner",
    "émulsionnèrent": "émulsionner",
    "émulsionné": "émulsionner",
    "émulsionnée": "émulsionner",
    "émulsionnées": "émulsionner",
    "émulsionnés": "émulsionner",
    "émulsions": "émulsion",
    "émulsive": "émulsif",
    "émurent": "émouvoir",
    "émus": "ému",
    "émusse": "émouvoir",
    "émussent": "émouvoir",
    "émusses": "émouvoir",
    "émussiez": "émouvoir",
    "émussions": "émouvoir",
    "émut": "émouvoir",
    "émèchent": "émécher",
    "éméché": "émécher",
    "éméchée": "émécher",
    "éméchées": "émécher",
    "éméchés": "émécher",
    "émérites": "émérite",
    "émétiques": "émétique",
    "émîmes": "émettre",
    "émît": "émettre",
    "émîtes": "émettre",
    "émûmes": "émouvoir",
    "émût": "émouvoir",
    "émûtes": "émouvoir",
    "énamoura": "énamourer",
    "énamourai": "énamourer",
    "énamouraient": "énamourer",
    "énamourais": "énamourer",
    "énamourait": "énamourer",
    "énamourant": "énamourer",
    "énamouras": "énamourer",
    "énamourasse": "énamourer",
    "énamourassent": "énamourer",
    "énamourasses": "énamourer",
    "énamourassiez": "énamourer",
    "énamourassions": "énamourer",
    "énamoure": "énamourer",
    "énamourent": "énamourer",
    "énamourera": "énamourer",
    "énamourerai": "énamourer",
    "énamoureraient": "énamourer",
    "énamourerais": "énamourer",
    "énamourerait": "énamourer",
    "énamoureras": "énamourer",
    "énamourerez": "énamourer",
    "énamoureriez": "énamourer",
    "énamourerions": "énamourer",
    "énamourerons": "énamourer",
    "énamoureront": "énamourer",
    "énamoures": "énamourer",
    "énamourez": "énamourer",
    "énamouriez": "énamourer",
    "énamourions": "énamourer",
    "énamourons": "énamourer",
    "énamourâmes": "énamourer",
    "énamourât": "énamourer",
    "énamourâtes": "énamourer",
    "énamourèrent": "énamourer",
    "énamouré": "énamourer",
    "énamourée": "énamourer",
    "énamourées": "énamourer",
    "énamourés": "énamourer",
    "énarques": "énarque",
    "énergies": "énergie",
    "énergiques": "énergique",
    "énergisante": "énergisant",
    "énergisée": "énergisé",
    "énergumènes": "énergumène",
    "énergétiques": "énergétique",
    "énergétivores": "énergétivore",
    "énerva": "énerver",
    "énervai": "énerver",
    "énervaient": "énerver",
    "énervais": "énerver",
    "énervait": "énerver",
    "énervant": "énerver",
    "énervante": "énervant",
    "énervantes": "énervant",
    "énervants": "énervant",
    "énervas": "énerver",
    "énervasse": "énerver",
    "énervassent": "énerver",
    "énervasses": "énerver",
    "énervassiez": "énerver",
    "énervassions": "énerver",
    "énerve": "énerver",
    "énervements": "énervement",
    "énervent": "énerver",
    "énervera": "énerver",
    "énerverai": "énerver",
    "énerveraient": "énerver",
    "énerverais": "énerver",
    "énerverait": "énerver",
    "énerveras": "énerver",
    "énerverez": "énerver",
    "énerveriez": "énerver",
    "énerverions": "énerver",
    "énerverons": "énerver",
    "énerveront": "énerver",
    "énerves": "énerver",
    "énervez": "énerver",
    "énerviez": "énerver",
    "énervions": "énerver",
    "énervons": "énerver",
    "énervâmes": "énerver",
    "énervât": "énerver",
    "énervâtes": "énerver",
    "énervèrent": "énerver",
    "énervé": "énerver",
    "énervée": "énerver",
    "énervées": "énerver",
    "énervés": "énerver",
    "énigmatiques": "énigmatique",
    "énigmes": "énigme",
    "énièmes": "énième",
    "énonce": "énoncer",
    "énoncent": "énoncer",
    "énoncera": "énoncer",
    "énoncerai": "énoncer",
    "énonceraient": "énoncer",
    "énoncerais": "énoncer",
    "énoncerait": "énoncer",
    "énonceras": "énoncer",
    "énoncerez": "énoncer",
    "énonceriez": "énoncer",
    "énoncerions": "énoncer",
    "énoncerons": "énoncer",
    "énonceront": "énoncer",
    "énonces": "énoncer",
    "énoncez": "énoncer",
    "énonciateurs": "énonciateur",
    "énonciations": "énonciation",
    "énonciez": "énoncer",
    "énoncions": "énoncer",
    "énoncèrent": "énoncer",
    "énoncé": "énoncer",
    "énoncée": "énoncer",
    "énoncées": "énoncer",
    "énoncés": "énoncer",
    "énonça": "énoncer",
    "énonçai": "énoncer",
    "énonçaient": "énoncer",
    "énonçais": "énoncer",
    "énonçait": "énoncer",
    "énonçant": "énoncer",
    "énonças": "énoncer",
    "énonçasse": "énoncer",
    "énonçassent": "énoncer",
    "énonçasses": "énoncer",
    "énonçassiez": "énoncer",
    "énonçassions": "énoncer",
    "énonçons": "énoncer",
    "énonçâmes": "énoncer",
    "énonçât": "énoncer",
    "énonçâtes": "énoncer",
    "énormes": "énorme",
    "énormités": "énormité",
    "énoua": "énouer",
    "énouai": "énouer",
    "énouaient": "énouer",
    "énouais": "énouer",
    "énouait": "énouer",
    "énouant": "énouer",
    "énouas": "énouer",
    "énouasse": "énouer",
    "énouassent": "énouer",
    "énouasses": "énouer",
    "énouassiez": "énouer",
    "énouassions": "énouer",
    "énoue": "énouer",
    "énouent": "énouer",
    "énouera": "énouer",
    "énouerai": "énouer",
    "énoueraient": "énouer",
    "énouerais": "énouer",
    "énouerait": "énouer",
    "énoueras": "énouer",
    "énouerez": "énouer",
    "énoueriez": "énouer",
    "énouerions": "énouer",
    "énouerons": "énouer",
    "énoueront": "énouer",
    "énoues": "énouer",
    "énouez": "énouer",
    "énouiez": "énouer",
    "énouions": "énouer",
    "énouons": "énouer",
    "énouâmes": "énouer",
    "énouât": "énouer",
    "énouâtes": "énouer",
    "énouèrent": "énouer",
    "énoué": "énouer",
    "énouée": "énouer",
    "énouées": "énouer",
    "énoués": "énouer",
    "énucléé": "énucléer",
    "énucléés": "énucléer",
    "énumère": "énumérer",
    "énumèrent": "énumérer",
    "énumères": "énumérer",
    "énuméra": "énumérer",
    "énumérai": "énumérer",
    "énuméraient": "énumérer",
    "énumérais": "énumérer",
    "énumérait": "énumérer",
    "énumérant": "énumérer",
    "énuméras": "énumérer",
    "énumérasse": "énumérer",
    "énumérassent": "énumérer",
    "énumérasses": "énumérer",
    "énumérassiez": "énumérer",
    "énumérassions": "énumérer",
    "énumérations": "énumération",
    "énumérative": "énumératif",
    "énumérera": "énumérer",
    "énumérerai": "énumérer",
    "énuméreraient": "énumérer",
    "énumérerais": "énumérer",
    "énumérerait": "énumérer",
    "énuméreras": "énumérer",
    "énumérerez": "énumérer",
    "énuméreriez": "énumérer",
    "énumérerions": "énumérer",
    "énumérerons": "énumérer",
    "énuméreront": "énumérer",
    "énumérez": "énumérer",
    "énumériez": "énumérer",
    "énumérions": "énumérer",
    "énumérons": "énumérer",
    "énumérâmes": "énumérer",
    "énumérât": "énumérer",
    "énumérâtes": "énumérer",
    "énumérèrent": "énumérer",
    "énuméré": "énumérer",
    "énumérée": "énumérer",
    "énumérées": "énumérer",
    "énumérés": "énumérer",
    "éolienne": "éolien",
    "éoliennes": "éolienne",
    "éoliens": "éolien",
    "épactes": "épacte",
    "épagneule": "épagneul",
    "épagneules": "épagneul",
    "épagneuls": "épagneul",
    "épagomènes": "épagomène",
    "épaisse": "épais",
    "épaisses": "épais",
    "épaisseurs": "épaisseur",
    "épaissi": "épaissir",
    "épaissie": "épaissir",
    "épaissies": "épaissir",
    "épaissira": "épaissir",
    "épaissirai": "épaissir",
    "épaissiraient": "épaissir",
    "épaissirais": "épaissir",
    "épaissirait": "épaissir",
    "épaissiras": "épaissir",
    "épaissirent": "épaissir",
    "épaissirez": "épaissir",
    "épaissiriez": "épaissir",
    "épaissirions": "épaissir",
    "épaissirons": "épaissir",
    "épaissiront": "épaissir",
    "épaissis": "épaissir",
    "épaississaient": "épaissir",
    "épaississais": "épaissir",
    "épaississait": "épaissir",
    "épaississant": "épaissir",
    "épaississe": "épaissir",
    "épaississements": "épaississement",
    "épaississent": "épaissir",
    "épaississes": "épaissir",
    "épaississez": "épaissir",
    "épaississiez": "épaissir",
    "épaississions": "épaissir",
    "épaississons": "épaissir",
    "épaissit": "épaissir",
    "épaissîmes": "épaissir",
    "épaissît": "épaissir",
    "épaissîtes": "épaissir",
    "épancha": "épancher",
    "épanchai": "épancher",
    "épanchaient": "épancher",
    "épanchais": "épancher",
    "épanchait": "épancher",
    "épanchant": "épancher",
    "épanchas": "épancher",
    "épanchasse": "épancher",
    "épanchassent": "épancher",
    "épanchasses": "épancher",
    "épanchassiez": "épancher",
    "épanchassions": "épancher",
    "épanche": "épancher",
    "épanchements": "épanchement",
    "épanchent": "épancher",
    "épanchera": "épancher",
    "épancherai": "épancher",
    "épancheraient": "épancher",
    "épancherais": "épancher",
    "épancherait": "épancher",
    "épancheras": "épancher",
    "épancherez": "épancher",
    "épancheriez": "épancher",
    "épancherions": "épancher",
    "épancherons": "épancher",
    "épancheront": "épancher",
    "épanches": "épancher",
    "épanchez": "épancher",
    "épanchiez": "épancher",
    "épanchions": "épancher",
    "épanchons": "épancher",
    "épanchâmes": "épancher",
    "épanchât": "épancher",
    "épanchâtes": "épancher",
    "épanchèrent": "épancher",
    "épanché": "épancher",
    "épanchée": "épancher",
    "épanchées": "épancher",
    "épanchés": "épancher",
    "épand": "épandre",
    "épandages": "épandage",
    "épandaient": "épandre",
    "épandais": "épandre",
    "épandait": "épandre",
    "épandant": "épandre",
    "épande": "épandre",
    "épandent": "épandre",
    "épandes": "épandre",
    "épandez": "épandre",
    "épandiez": "épandre",
    "épandions": "épandre",
    "épandirent": "épandre",
    "épandis": "épandre",
    "épandisse": "épandre",
    "épandissent": "épandre",
    "épandisses": "épandre",
    "épandissiez": "épandre",
    "épandissions": "épandre",
    "épandit": "épandre",
    "épandons": "épandre",
    "épandra": "épandre",
    "épandrai": "épandre",
    "épandraient": "épandre",
    "épandrais": "épandre",
    "épandrait": "épandre",
    "épandras": "épandre",
    "épandrez": "épandre",
    "épandriez": "épandre",
    "épandrions": "épandre",
    "épandrons": "épandre",
    "épandront": "épandre",
    "épands": "épandre",
    "épandu": "épandre",
    "épandue": "épandre",
    "épandues": "épandre",
    "épandus": "épandre",
    "épandîmes": "épandre",
    "épandît": "épandre",
    "épandîtes": "épandre",
    "épanoui": "épanouir",
    "épanouie": "épanouir",
    "épanouies": "épanouir",
    "épanouira": "épanouir",
    "épanouirai": "épanouir",
    "épanouiraient": "épanouir",
    "épanouirais": "épanouir",
    "épanouirait": "épanouir",
    "épanouiras": "épanouir",
    "épanouirent": "épanouir",
    "épanouirez": "épanouir",
    "épanouiriez": "épanouir",
    "épanouirions": "épanouir",
    "épanouirons": "épanouir",
    "épanouiront": "épanouir",
    "épanouis": "épanouir",
    "épanouissaient": "épanouir",
    "épanouissais": "épanouir",
    "épanouissait": "épanouir",
    "épanouissant": "épanouir",
    "épanouissante": "épanouissant",
    "épanouissantes": "épanouissant",
    "épanouisse": "épanouir",
    "épanouissements": "épanouissement",
    "épanouissent": "épanouir",
    "épanouisses": "épanouir",
    "épanouissez": "épanouir",
    "épanouissiez": "épanouir",
    "épanouissions": "épanouir",
    "épanouissons": "épanouir",
    "épanouit": "épanouir",
    "épanouîmes": "épanouir",
    "épanouît": "épanouir",
    "épanouîtes": "épanouir",
    "épargna": "épargner",
    "épargnai": "épargner",
    "épargnaient": "épargner",
    "épargnais": "épargner",
    "épargnait": "épargner",
    "épargnant": "épargner",
    "épargnante": "épargnant",
    "épargnantes": "épargnant",
    "épargnants": "épargnant",
    "épargnas": "épargner",
    "épargnasse": "épargner",
    "épargnassent": "épargner",
    "épargnasses": "épargner",
    "épargnassiez": "épargner",
    "épargnassions": "épargner",
    "épargne": "épargner",
    "épargnent": "épargner",
    "épargnera": "épargner",
    "épargnerai": "épargner",
    "épargneraient": "épargner",
    "épargnerais": "épargner",
    "épargnerait": "épargner",
    "épargneras": "épargner",
    "épargnerez": "épargner",
    "épargneriez": "épargner",
    "épargnerions": "épargner",
    "épargnerons": "épargner",
    "épargneront": "épargner",
    "épargnes": "épargner",
    "épargnez": "épargner",
    "épargniez": "épargner",
    "épargnions": "épargner",
    "épargnons": "épargner",
    "épargnâmes": "épargner",
    "épargnât": "épargner",
    "épargnâtes": "épargner",
    "épargnèrent": "épargner",
    "épargné": "épargner",
    "épargnée": "épargner",
    "épargnées": "épargner",
    "épargnés": "épargner",
    "éparpilla": "éparpiller",
    "éparpillai": "éparpiller",
    "éparpillaient": "éparpiller",
    "éparpillais": "éparpiller",
    "éparpillait": "éparpiller",
    "éparpillant": "éparpiller",
    "éparpillas": "éparpiller",
    "éparpillasse": "éparpiller",
    "éparpillassent": "éparpiller",
    "éparpillasses": "éparpiller",
    "éparpillassiez": "éparpiller",
    "éparpillassions": "éparpiller",
    "éparpille": "éparpiller",
    "éparpillent": "éparpiller",
    "éparpillera": "éparpiller",
    "éparpillerai": "éparpiller",
    "éparpilleraient": "éparpiller",
    "éparpillerais": "éparpiller",
    "éparpillerait": "éparpiller",
    "éparpilleras": "éparpiller",
    "éparpillerez": "éparpiller",
    "éparpilleriez": "éparpiller",
    "éparpillerions": "éparpiller",
    "éparpillerons": "éparpiller",
    "éparpilleront": "éparpiller",
    "éparpilles": "éparpiller",
    "éparpillez": "éparpiller",
    "éparpilliez": "éparpiller",
    "éparpillions": "éparpiller",
    "éparpillons": "éparpiller",
    "éparpillâmes": "éparpiller",
    "éparpillât": "éparpiller",
    "éparpillâtes": "éparpiller",
    "éparpillèrent": "éparpiller",
    "éparpillé": "éparpiller",
    "éparpillée": "éparpiller",
    "éparpillées": "éparpiller",
    "éparpillés": "éparpiller",
    "éparse": "épars",
    "éparses": "épars",
    "éparvins": "éparvin",
    "épastrouillera": "épastrouiller",
    "épata": "épater",
    "épatai": "épater",
    "épataient": "épater",
    "épatais": "épater",
    "épatait": "épater",
    "épatant": "épater",
    "épatante": "épatant",
    "épatantes": "épatant",
    "épatants": "épatant",
    "épatas": "épater",
    "épatasse": "épater",
    "épatassent": "épater",
    "épatasses": "épater",
    "épatassiez": "épater",
    "épatassions": "épater",
    "épate": "épater",
    "épatent": "épater",
    "épatera": "épater",
    "épaterai": "épater",
    "épateraient": "épater",
    "épaterais": "épater",
    "épaterait": "épater",
    "épateras": "épater",
    "épaterez": "épater",
    "épateriez": "épater",
    "épaterions": "épater",
    "épaterons": "épater",
    "épateront": "épater",
    "épates": "épater",
    "épateurs": "épateur",
    "épatez": "épater",
    "épatiez": "épater",
    "épations": "épater",
    "épatons": "épater",
    "épatâmes": "épater",
    "épatât": "épater",
    "épatâtes": "épater",
    "épatèrent": "épater",
    "épaté": "épater",
    "épatée": "épater",
    "épatées": "épater",
    "épatés": "épater",
    "épaula": "épauler",
    "épaulai": "épauler",
    "épaulaient": "épauler",
    "épaulais": "épauler",
    "épaulait": "épauler",
    "épaulant": "épauler",
    "épaulards": "épaulard",
    "épaulas": "épauler",
    "épaulasse": "épauler",
    "épaulassent": "épauler",
    "épaulasses": "épauler",
    "épaulassiez": "épauler",
    "épaulassions": "épauler",
    "épaule": "épauler",
    "épaulements": "épaulement",
    "épaulent": "épauler",
    "épaulera": "épauler",
    "épaulerai": "épauler",
    "épauleraient": "épauler",
    "épaulerais": "épauler",
    "épaulerait": "épauler",
    "épauleras": "épauler",
    "épaulerez": "épauler",
    "épauleriez": "épauler",
    "épaulerions": "épauler",
    "épaulerons": "épauler",
    "épauleront": "épauler",
    "épaules": "épauler",
    "épaulettes": "épaulette",
    "épaulez": "épauler",
    "épauliez": "épauler",
    "épaulions": "épauler",
    "épaulières": "épaulière",
    "épaulons": "épauler",
    "épaulâmes": "épauler",
    "épaulât": "épauler",
    "épaulâtes": "épauler",
    "épaulèrent": "épauler",
    "épaulé": "épauler",
    "épaulée": "épauler",
    "épaulées": "épauler",
    "épaulés": "épauler",
    "épaulés-jetés": "épaulé-jeté",
    "épaves": "épave",
    "épeautres": "épeautre",
    "épeiches": "épeiche",
    "épela": "épeler",
    "épelai": "épeler",
    "épelaient": "épeler",
    "épelais": "épeler",
    "épelait": "épeler",
    "épelant": "épeler",
    "épelas": "épeler",
    "épelasse": "épeler",
    "épelassent": "épeler",
    "épelasses": "épeler",
    "épelassiez": "épeler",
    "épelassions": "épeler",
    "épelez": "épeler",
    "épeliez": "épeler",
    "épelions": "épeler",
    "épellations": "épellation",
    "épelle": "épeler",
    "épellent": "épeler",
    "épellera": "épeler",
    "épellerai": "épeler",
    "épelleraient": "épeler",
    "épellerais": "épeler",
    "épellerait": "épeler",
    "épelleras": "épeler",
    "épellerez": "épeler",
    "épelleriez": "épeler",
    "épellerions": "épeler",
    "épellerons": "épeler",
    "épelleront": "épeler",
    "épelles": "épeler",
    "épelons": "épeler",
    "épelâmes": "épeler",
    "épelât": "épeler",
    "épelâtes": "épeler",
    "épelèrent": "épeler",
    "épelé": "épeler",
    "épelée": "épeler",
    "épelées": "épeler",
    "épelés": "épeler",
    "épenthèses": "épenthèse",
    "épenthétiques": "épenthétique",
    "éperd": "éperdre",
    "éperdaient": "éperdre",
    "éperdais": "éperdre",
    "éperdait": "éperdre",
    "éperdant": "éperdre",
    "éperde": "éperdre",
    "éperdent": "éperdre",
    "éperdes": "éperdre",
    "éperdez": "éperdre",
    "éperdiez": "éperdre",
    "éperdions": "éperdre",
    "éperdirent": "éperdre",
    "éperdis": "éperdre",
    "éperdisse": "éperdre",
    "éperdissent": "éperdre",
    "éperdisses": "éperdre",
    "éperdissiez": "éperdre",
    "éperdissions": "éperdre",
    "éperdit": "éperdre",
    "éperdons": "éperdre",
    "éperdra": "éperdre",
    "éperdrai": "éperdre",
    "éperdraient": "éperdre",
    "éperdrais": "éperdre",
    "éperdrait": "éperdre",
    "éperdras": "éperdre",
    "éperdrez": "éperdre",
    "éperdriez": "éperdre",
    "éperdrions": "éperdre",
    "éperdrons": "éperdre",
    "éperdront": "éperdre",
    "éperds": "éperdre",
    "éperdu": "éperdre",
    "éperdue": "éperdu",
    "éperdues": "éperdu",
    "éperdus": "éperdu",
    "éperdîmes": "éperdre",
    "éperdît": "éperdre",
    "éperdîtes": "éperdre",
    "éperlans": "éperlan",
    "éperonna": "éperonner",
    "éperonnai": "éperonner",
    "éperonnaient": "éperonner",
    "éperonnais": "éperonner",
    "éperonnait": "éperonner",
    "éperonnant": "éperonner",
    "éperonnas": "éperonner",
    "éperonnasse": "éperonner",
    "éperonnassent": "éperonner",
    "éperonnasses": "éperonner",
    "éperonnassiez": "éperonner",
    "éperonnassions": "éperonner",
    "éperonne": "éperonner",
    "éperonnent": "éperonner",
    "éperonnera": "éperonner",
    "éperonnerai": "éperonner",
    "éperonneraient": "éperonner",
    "éperonnerais": "éperonner",
    "éperonnerait": "éperonner",
    "éperonneras": "éperonner",
    "éperonnerez": "éperonner",
    "éperonneriez": "éperonner",
    "éperonnerions": "éperonner",
    "éperonnerons": "éperonner",
    "éperonneront": "éperonner",
    "éperonnes": "éperonner",
    "éperonnez": "éperonner",
    "éperonniez": "éperonner",
    "éperonnions": "éperonner",
    "éperonnons": "éperonner",
    "éperonnâmes": "éperonner",
    "éperonnât": "éperonner",
    "éperonnâtes": "éperonner",
    "éperonnèrent": "éperonner",
    "éperonné": "éperonner",
    "éperonnée": "éperonner",
    "éperonnées": "éperonner",
    "éperonnés": "éperonner",
    "éperons": "éperon",
    "éperviers": "épervier",
    "épervières": "épervière",
    "épeurant": "épeurer",
    "épeuré": "épeurer",
    "épeurée": "épeurer",
    "éphèbes": "éphèbe",
    "éphélides": "éphélide",
    "éphémères": "éphémère",
    "éphémérides": "éphéméride",
    "éphésiens": "éphésien",
    "épia": "épier",
    "épiai": "épier",
    "épiaient": "épier",
    "épiais": "épier",
    "épiait": "épier",
    "épiant": "épier",
    "épias": "épier",
    "épiasse": "épier",
    "épiassent": "épier",
    "épiasses": "épier",
    "épiassiez": "épier",
    "épiassions": "épier",
    "épice": "épicer",
    "épicemards": "épicemard",
    "épicentrale": "épicentral",
    "épicentrales": "épicentral",
    "épicentrauxs": "épicentral",
    "épicentres": "épicentre",
    "épiceries": "épicerie",
    "épices": "épicer",
    "épiciers": "épicier",
    "épicière": "épicier",
    "épicières": "épicier",
    "épicondyles": "épicondyle",
    "épicrânienne": "épicrânien",
    "épicurienne": "épicurien",
    "épicuriennes": "épicurien",
    "épicuriens": "épicurien",
    "épicycles": "épicycle",
    "épicènes": "épicène",
    "épicé": "épicer",
    "épicéas": "épicéa",
    "épicée": "épicer",
    "épicées": "épicé",
    "épicés": "épicer",
    "épidermes": "épiderme",
    "épidermiques": "épidermique",
    "épidiascopes": "épidiascope",
    "épididymes": "épididyme",
    "épidurale": "épidural",
    "épidémies": "épidémie",
    "épidémiologies": "épidémiologie",
    "épidémiologiques": "épidémiologique",
    "épidémiologistes": "épidémiologiste",
    "épidémiques": "épidémique",
    "épie": "épier",
    "épient": "épier",
    "épiera": "épier",
    "épierai": "épier",
    "épieraient": "épier",
    "épierais": "épier",
    "épierait": "épier",
    "épieras": "épier",
    "épierez": "épier",
    "épieriez": "épier",
    "épierions": "épier",
    "épierons": "épier",
    "épieront": "épier",
    "épies": "épier",
    "épieux": "épieu",
    "épiez": "épier",
    "épigastres": "épigastre",
    "épiglottes": "épiglotte",
    "épigones": "épigone",
    "épigrammes": "épigramme",
    "épigraphes": "épigraphe",
    "épigraphistes": "épigraphiste",
    "épiiez": "épier",
    "épiions": "épier",
    "épila": "épiler",
    "épilai": "épiler",
    "épilaient": "épiler",
    "épilais": "épiler",
    "épilait": "épiler",
    "épilant": "épiler",
    "épilas": "épiler",
    "épilasse": "épiler",
    "épilassent": "épiler",
    "épilasses": "épiler",
    "épilassiez": "épiler",
    "épilassions": "épiler",
    "épile": "épiler",
    "épilent": "épiler",
    "épilepsies": "épilepsie",
    "épileptiques": "épileptique",
    "épilera": "épiler",
    "épilerai": "épiler",
    "épileraient": "épiler",
    "épilerais": "épiler",
    "épilerait": "épiler",
    "épileras": "épiler",
    "épilerez": "épiler",
    "épileriez": "épiler",
    "épilerions": "épiler",
    "épilerons": "épiler",
    "épileront": "épiler",
    "épiles": "épiler",
    "épileuse": "épileur",
    "épilez": "épiler",
    "épiliez": "épiler",
    "épilions": "épiler",
    "épilobes": "épilobe",
    "épilogua": "épiloguer",
    "épiloguai": "épiloguer",
    "épiloguaient": "épiloguer",
    "épiloguais": "épiloguer",
    "épiloguait": "épiloguer",
    "épiloguant": "épiloguer",
    "épiloguas": "épiloguer",
    "épiloguasse": "épiloguer",
    "épiloguassent": "épiloguer",
    "épiloguasses": "épiloguer",
    "épiloguassiez": "épiloguer",
    "épiloguassions": "épiloguer",
    "épilogue": "épiloguer",
    "épiloguent": "épiloguer",
    "épiloguera": "épiloguer",
    "épiloguerai": "épiloguer",
    "épilogueraient": "épiloguer",
    "épiloguerais": "épiloguer",
    "épiloguerait": "épiloguer",
    "épilogueras": "épiloguer",
    "épiloguerez": "épiloguer",
    "épilogueriez": "épiloguer",
    "épiloguerions": "épiloguer",
    "épiloguerons": "épiloguer",
    "épilogueront": "épiloguer",
    "épilogues": "épiloguer",
    "épiloguez": "épiloguer",
    "épiloguiez": "épiloguer",
    "épiloguions": "épiloguer",
    "épiloguons": "épiloguer",
    "épiloguâmes": "épiloguer",
    "épiloguât": "épiloguer",
    "épiloguâtes": "épiloguer",
    "épiloguèrent": "épiloguer",
    "épilogué": "épiloguer",
    "épilons": "épiler",
    "épilâmes": "épiler",
    "épilât": "épiler",
    "épilâtes": "épiler",
    "épilèrent": "épiler",
    "épilé": "épiler",
    "épilée": "épiler",
    "épilées": "épiler",
    "épilés": "épiler",
    "épinards": "épinard",
    "épince": "épincer",
    "épincent": "épincer",
    "épincera": "épincer",
    "épincerai": "épincer",
    "épinceraient": "épincer",
    "épincerais": "épincer",
    "épincerait": "épincer",
    "épinceras": "épincer",
    "épincerez": "épincer",
    "épinceriez": "épincer",
    "épincerions": "épincer",
    "épincerons": "épincer",
    "épinceront": "épincer",
    "épinces": "épincer",
    "épincez": "épincer",
    "épinciez": "épincer",
    "épincions": "épincer",
    "épincèrent": "épincer",
    "épincé": "épincer",
    "épincée": "épincer",
    "épincées": "épincer",
    "épincés": "épincer",
    "épines": "épine",
    "épines-vinettes": "épine-vinette",
    "épinettes": "épinette",
    "épineuse": "épineux",
    "épineuses": "épineux",
    "épingla": "épingler",
    "épinglai": "épingler",
    "épinglaient": "épingler",
    "épinglais": "épingler",
    "épinglait": "épingler",
    "épinglant": "épingler",
    "épinglas": "épingler",
    "épinglasse": "épingler",
    "épinglassent": "épingler",
    "épinglasses": "épingler",
    "épinglassiez": "épingler",
    "épinglassions": "épingler",
    "épingle": "épingler",
    "épinglent": "épingler",
    "épinglera": "épingler",
    "épinglerai": "épingler",
    "épingleraient": "épingler",
    "épinglerais": "épingler",
    "épinglerait": "épingler",
    "épingleras": "épingler",
    "épinglerez": "épingler",
    "épingleriez": "épingler",
    "épinglerions": "épingler",
    "épinglerons": "épingler",
    "épingleront": "épingler",
    "épingles": "épingler",
    "épinglez": "épingler",
    "épingliez": "épingler",
    "épinglions": "épingler",
    "épinglons": "épingler",
    "épinglâmes": "épingler",
    "épinglât": "épingler",
    "épinglâtes": "épingler",
    "épinglèrent": "épingler",
    "épinglé": "épingler",
    "épinglée": "épingler",
    "épinglées": "épingler",
    "épinglés": "épingler",
    "épiniers": "épinier",
    "épinière": "épinier",
    "épinoches": "épinoche",
    "épinça": "épincer",
    "épinçai": "épincer",
    "épinçaient": "épincer",
    "épinçais": "épincer",
    "épinçait": "épincer",
    "épinçant": "épincer",
    "épinças": "épincer",
    "épinçasse": "épincer",
    "épinçassent": "épincer",
    "épinçasses": "épincer",
    "épinçassiez": "épincer",
    "épinçassions": "épincer",
    "épinçons": "épincer",
    "épinçâmes": "épincer",
    "épinçât": "épincer",
    "épinçâtes": "épincer",
    "épions": "épier",
    "épiphylles": "épiphylle",
    "épiphyses": "épiphyse",
    "épiphytes": "épiphyte",
    "épiphénomènes": "épiphénomène",
    "épiploons": "épiploon",
    "épiques": "épique",
    "épis": "épi",
    "épiscopale": "épiscopal",
    "épiscopales": "épiscopal",
    "épiscopalienne": "épiscopalien",
    "épiscopaliennes": "épiscopalien",
    "épiscopaliens": "épiscopalien",
    "épiscopats": "épiscopat",
    "épiscopaux": "épiscopal",
    "épisodes": "épisode",
    "épisodiques": "épisodique",
    "épissoirs": "épissoir",
    "épissures": "épissure",
    "épissé": "épisser",
    "épistolaires": "épistolaire",
    "épistolière": "épistolier",
    "épistémologies": "épistémologie",
    "épistémologiques": "épistémologique",
    "épistémologues": "épistémologue",
    "épitaphes": "épitaphe",
    "épithalames": "épithalame",
    "épithètes": "épithète",
    "épithéliale": "épithélial",
    "épithéliums": "épithélium",
    "épitoges": "épitoge",
    "épitomés": "épitomé",
    "épizooties": "épizootie",
    "épiâmes": "épier",
    "épiât": "épier",
    "épiâtes": "épier",
    "épièrent": "épier",
    "épié": "épier",
    "épiée": "épier",
    "épiées": "épier",
    "épiés": "épier",
    "éploie": "éployer",
    "éploient": "éployer",
    "éplorée": "éploré",
    "éplorées": "éploré",
    "éplorés": "éploré",
    "éployai": "éployer",
    "éployait": "éployer",
    "éployé": "éployer",
    "éployée": "éployer",
    "éployées": "éployer",
    "éployés": "éployer",
    "éplucha": "éplucher",
    "épluchages": "épluchage",
    "épluchai": "éplucher",
    "épluchaient": "éplucher",
    "épluchais": "éplucher",
    "épluchait": "éplucher",
    "épluchant": "éplucher",
    "épluchas": "éplucher",
    "épluchasse": "éplucher",
    "épluchassent": "éplucher",
    "épluchasses": "éplucher",
    "épluchassiez": "éplucher",
    "épluchassions": "éplucher",
    "épluche": "éplucher",
    "épluchent": "éplucher",
    "épluchera": "éplucher",
    "éplucherai": "éplucher",
    "éplucheraient": "éplucher",
    "éplucherais": "éplucher",
    "éplucherait": "éplucher",
    "éplucheras": "éplucher",
    "éplucherez": "éplucher",
    "éplucheriez": "éplucher",
    "éplucherions": "éplucher",
    "éplucherons": "éplucher",
    "éplucheront": "éplucher",
    "épluches": "éplucher",
    "éplucheurs": "éplucheur",
    "éplucheuses": "éplucheur",
    "épluchez": "éplucher",
    "épluchiez": "éplucher",
    "épluchions": "éplucher",
    "épluchons": "éplucher",
    "épluchures": "épluchure",
    "épluchâmes": "éplucher",
    "épluchât": "éplucher",
    "épluchâtes": "éplucher",
    "épluchèrent": "éplucher",
    "épluché": "éplucher",
    "épluchée": "éplucher",
    "épluchées": "éplucher",
    "épluchés": "éplucher",
    "épointa": "épointer",
    "épointai": "épointer",
    "épointaient": "épointer",
    "épointais": "épointer",
    "épointait": "épointer",
    "épointant": "épointer",
    "épointas": "épointer",
    "épointasse": "épointer",
    "épointassent": "épointer",
    "épointasses": "épointer",
    "épointassiez": "épointer",
    "épointassions": "épointer",
    "épointe": "épointer",
    "épointent": "épointer",
    "épointera": "épointer",
    "épointerai": "épointer",
    "épointeraient": "épointer",
    "épointerais": "épointer",
    "épointerait": "épointer",
    "épointeras": "épointer",
    "épointerez": "épointer",
    "épointeriez": "épointer",
    "épointerions": "épointer",
    "épointerons": "épointer",
    "épointeront": "épointer",
    "épointes": "épointer",
    "épointez": "épointer",
    "épointiez": "épointer",
    "épointions": "épointer",
    "épointons": "épointer",
    "épointâmes": "épointer",
    "épointât": "épointer",
    "épointâtes": "épointer",
    "épointèrent": "épointer",
    "épointé": "épointer",
    "épointée": "épointer",
    "épointées": "épointer",
    "épointés": "épointer",
    "éponge": "éponger",
    "épongea": "éponger",
    "épongeai": "éponger",
    "épongeaient": "éponger",
    "épongeais": "éponger",
    "épongeait": "éponger",
    "épongeant": "éponger",
    "épongeas": "éponger",
    "épongeasse": "éponger",
    "épongeassent": "éponger",
    "épongeasses": "éponger",
    "épongeassiez": "éponger",
    "épongeassions": "éponger",
    "épongent": "éponger",
    "épongeons": "éponger",
    "épongera": "éponger",
    "épongerai": "éponger",
    "épongeraient": "éponger",
    "épongerais": "éponger",
    "épongerait": "éponger",
    "épongeras": "éponger",
    "épongerez": "éponger",
    "épongeriez": "éponger",
    "épongerions": "éponger",
    "épongerons": "éponger",
    "épongeront": "éponger",
    "éponges": "éponger",
    "épongez": "éponger",
    "épongeâmes": "éponger",
    "épongeât": "éponger",
    "épongeâtes": "éponger",
    "épongiez": "éponger",
    "épongions": "éponger",
    "épongèrent": "éponger",
    "épongé": "éponger",
    "épongée": "éponger",
    "épongées": "éponger",
    "épongés": "éponger",
    "éponymes": "éponyme",
    "épopées": "épopée",
    "époques": "époque",
    "épouilla": "épouiller",
    "épouillai": "épouiller",
    "épouillaient": "épouiller",
    "épouillais": "épouiller",
    "épouillait": "épouiller",
    "épouillant": "épouiller",
    "épouillas": "épouiller",
    "épouillasse": "épouiller",
    "épouillassent": "épouiller",
    "épouillasses": "épouiller",
    "épouillassiez": "épouiller",
    "épouillassions": "épouiller",
    "épouille": "épouiller",
    "épouillent": "épouiller",
    "épouillera": "épouiller",
    "épouillerai": "épouiller",
    "épouilleraient": "épouiller",
    "épouillerais": "épouiller",
    "épouillerait": "épouiller",
    "épouilleras": "épouiller",
    "épouillerez": "épouiller",
    "épouilleriez": "épouiller",
    "épouillerions": "épouiller",
    "épouillerons": "épouiller",
    "épouilleront": "épouiller",
    "épouilles": "épouiller",
    "épouillez": "épouiller",
    "épouilliez": "épouiller",
    "épouillions": "épouiller",
    "épouillons": "épouiller",
    "épouillâmes": "épouiller",
    "épouillât": "épouiller",
    "épouillâtes": "épouiller",
    "épouillèrent": "épouiller",
    "épouillé": "épouiller",
    "épouillée": "épouiller",
    "épouillées": "épouiller",
    "épouillés": "épouiller",
    "époumona": "époumoner",
    "époumonai": "époumoner",
    "époumonaient": "époumoner",
    "époumonais": "époumoner",
    "époumonait": "époumoner",
    "époumonant": "époumoner",
    "époumonas": "époumoner",
    "époumonasse": "époumoner",
    "époumonassent": "époumoner",
    "époumonasses": "époumoner",
    "époumonassiez": "époumoner",
    "époumonassions": "époumoner",
    "époumone": "époumoner",
    "époumonent": "époumoner",
    "époumonera": "époumoner",
    "époumonerai": "époumoner",
    "époumoneraient": "époumoner",
    "époumonerais": "époumoner",
    "époumonerait": "époumoner",
    "époumoneras": "époumoner",
    "époumonerez": "époumoner",
    "époumoneriez": "époumoner",
    "époumonerions": "époumoner",
    "époumonerons": "époumoner",
    "époumoneront": "époumoner",
    "époumones": "époumoner",
    "époumonez": "époumoner",
    "époumoniez": "époumoner",
    "époumonions": "époumoner",
    "époumonons": "époumoner",
    "époumonâmes": "époumoner",
    "époumonât": "époumoner",
    "époumonâtes": "époumoner",
    "époumonèrent": "époumoner",
    "époumoné": "époumoner",
    "époumonée": "époumoner",
    "époumonées": "époumoner",
    "époumonés": "époumoner",
    "épousa": "épouser",
    "épousai": "épouser",
    "épousaient": "épouser",
    "épousais": "épouser",
    "épousait": "épouser",
    "épousant": "épouser",
    "épousas": "épouser",
    "épousasse": "épouser",
    "épousassent": "épouser",
    "épousasses": "épouser",
    "épousassiez": "épouser",
    "épousassions": "épouser",
    "épouse": "époux",
    "épousent": "épouser",
    "épousera": "épouser",
    "épouserai": "épouser",
    "épouseraient": "épouser",
    "épouserais": "épouser",
    "épouserait": "épouser",
    "épouseras": "épouser",
    "épouserez": "épouser",
    "épouseriez": "épouser",
    "épouserions": "épouser",
    "épouserons": "épouser",
    "épouseront": "épouser",
    "épouses": "époux",
    "épouseurs": "épouseur",
    "épousez": "épouser",
    "épousiez": "épouser",
    "épousions": "épouser",
    "épousons": "épouser",
    "épousseta": "épousseter",
    "époussetai": "épousseter",
    "époussetaient": "épousseter",
    "époussetais": "épousseter",
    "époussetait": "épousseter",
    "époussetant": "épousseter",
    "époussetas": "épousseter",
    "époussetasse": "épousseter",
    "époussetassent": "épousseter",
    "époussetasses": "épousseter",
    "époussetassiez": "épousseter",
    "époussetassions": "épousseter",
    "époussetez": "épousseter",
    "époussetiez": "épousseter",
    "époussetions": "épousseter",
    "époussetons": "épousseter",
    "époussette": "épousseter",
    "époussettent": "épousseter",
    "époussettera": "épousseter",
    "époussetterai": "épousseter",
    "époussetteraient": "épousseter",
    "époussetterais": "épousseter",
    "époussetterait": "épousseter",
    "époussetteras": "épousseter",
    "époussetterez": "épousseter",
    "époussetteriez": "épousseter",
    "époussetterions": "épousseter",
    "époussetterons": "épousseter",
    "époussetteront": "épousseter",
    "époussettes": "épousseter",
    "époussetâmes": "épousseter",
    "époussetât": "épousseter",
    "époussetâtes": "épousseter",
    "époussetèrent": "épousseter",
    "épousseté": "épousseter",
    "époussetée": "épousseter",
    "époussetées": "épousseter",
    "époussetés": "épousseter",
    "époustouflait": "époustoufler",
    "époustouflant": "époustoufler",
    "époustouflante": "époustouflant",
    "époustouflantes": "époustouflant",
    "époustouflants": "époustouflant",
    "époustoufle": "époustoufler",
    "époustouflé": "époustoufler",
    "époustouflée": "époustoufler",
    "époustouflés": "époustoufler",
    "épousâmes": "épouser",
    "épousât": "épouser",
    "épousâtes": "épouser",
    "épousèrent": "épouser",
    "épousé": "épouser",
    "épousée": "épouser",
    "épousées": "épouser",
    "épousés": "épouser",
    "épouvanta": "épouvanter",
    "épouvantables": "épouvantable",
    "épouvantai": "épouvanter",
    "épouvantaient": "épouvanter",
    "épouvantails": "épouvantail",
    "épouvantais": "épouvanter",
    "épouvantait": "épouvanter",
    "épouvantant": "épouvanter",
    "épouvantas": "épouvanter",
    "épouvantasse": "épouvanter",
    "épouvantassent": "épouvanter",
    "épouvantasses": "épouvanter",
    "épouvantassiez": "épouvanter",
    "épouvantassions": "épouvanter",
    "épouvante": "épouvanter",
    "épouvantements": "épouvantement",
    "épouvantent": "épouvanter",
    "épouvantera": "épouvanter",
    "épouvanterai": "épouvanter",
    "épouvanteraient": "épouvanter",
    "épouvanterais": "épouvanter",
    "épouvanterait": "épouvanter",
    "épouvanteras": "épouvanter",
    "épouvanterez": "épouvanter",
    "épouvanteriez": "épouvanter",
    "épouvanterions": "épouvanter",
    "épouvanterons": "épouvanter",
    "épouvanteront": "épouvanter",
    "épouvantes": "épouvanter",
    "épouvantez": "épouvanter",
    "épouvantiez": "épouvanter",
    "épouvantions": "épouvanter",
    "épouvantons": "épouvanter",
    "épouvantâmes": "épouvanter",
    "épouvantât": "épouvanter",
    "épouvantâtes": "épouvanter",
    "épouvantèrent": "épouvanter",
    "épouvanté": "épouvanter",
    "épouvantée": "épouvanter",
    "épouvantées": "épouvanter",
    "épouvantés": "épouvanter",
    "épreignaient": "épreindre",
    "épreignais": "épreindre",
    "épreignait": "épreindre",
    "épreignant": "épreindre",
    "épreigne": "épreindre",
    "épreignent": "épreindre",
    "épreignes": "épreindre",
    "épreignez": "épreindre",
    "épreigniez": "épreindre",
    "épreignions": "épreindre",
    "épreignirent": "épreindre",
    "épreignis": "épreindre",
    "épreignisse": "épreindre",
    "épreignissent": "épreindre",
    "épreignisses": "épreindre",
    "épreignissiez": "épreindre",
    "épreignissions": "épreindre",
    "épreignit": "épreindre",
    "épreignons": "épreindre",
    "épreignîmes": "épreindre",
    "épreignît": "épreindre",
    "épreignîtes": "épreindre",
    "épreindra": "épreindre",
    "épreindrai": "épreindre",
    "épreindraient": "épreindre",
    "épreindrais": "épreindre",
    "épreindrait": "épreindre",
    "épreindras": "épreindre",
    "épreindrez": "épreindre",
    "épreindriez": "épreindre",
    "épreindrions": "épreindre",
    "épreindrons": "épreindre",
    "épreindront": "épreindre",
    "épreins": "épreindre",
    "épreint": "épreindre",
    "épreinte": "épreindre",
    "épreintes": "épreindre",
    "épreints": "épreindre",
    "éprenaient": "éprendre",
    "éprenais": "éprendre",
    "éprenait": "éprendre",
    "éprenant": "éprendre",
    "éprend": "éprendre",
    "éprendra": "éprendre",
    "éprendrai": "éprendre",
    "éprendraient": "éprendre",
    "éprendrais": "éprendre",
    "éprendrait": "éprendre",
    "éprendras": "éprendre",
    "éprendrez": "éprendre",
    "éprendriez": "éprendre",
    "éprendrions": "éprendre",
    "éprendrons": "éprendre",
    "éprendront": "éprendre",
    "éprends": "éprendre",
    "éprenez": "éprendre",
    "épreniez": "éprendre",
    "éprenions": "éprendre",
    "éprenne": "éprendre",
    "éprennent": "éprendre",
    "éprennes": "éprendre",
    "éprenons": "éprendre",
    "épreuves": "épreuve",
    "éprirent": "éprendre",
    "épris": "éprendre",
    "éprise": "épris",
    "éprises": "épris",
    "éprisse": "éprendre",
    "éprissent": "éprendre",
    "éprisses": "éprendre",
    "éprissiez": "éprendre",
    "éprissions": "éprendre",
    "éprit": "éprendre",
    "éprouva": "éprouver",
    "éprouvai": "éprouver",
    "éprouvaient": "éprouver",
    "éprouvais": "éprouver",
    "éprouvait": "éprouver",
    "éprouvant": "éprouver",
    "éprouvante": "éprouvant",
    "éprouvantes": "éprouvant",
    "éprouvants": "éprouvant",
    "éprouvas": "éprouver",
    "éprouvasse": "éprouver",
    "éprouvassent": "éprouver",
    "éprouvasses": "éprouver",
    "éprouvassiez": "éprouver",
    "éprouvassions": "éprouver",
    "éprouve": "éprouver",
    "éprouvent": "éprouver",
    "éprouvera": "éprouver",
    "éprouverai": "éprouver",
    "éprouveraient": "éprouver",
    "éprouverais": "éprouver",
    "éprouverait": "éprouver",
    "éprouveras": "éprouver",
    "éprouverez": "éprouver",
    "éprouveriez": "éprouver",
    "éprouverions": "éprouver",
    "éprouverons": "éprouver",
    "éprouveront": "éprouver",
    "éprouves": "éprouver",
    "éprouvettes": "éprouvette",
    "éprouvez": "éprouver",
    "éprouviez": "éprouver",
    "éprouvions": "éprouver",
    "éprouvons": "éprouver",
    "éprouvâmes": "éprouver",
    "éprouvât": "éprouver",
    "éprouvâtes": "éprouver",
    "éprouvèrent": "éprouver",
    "éprouvé": "éprouver",
    "éprouvée": "éprouver",
    "éprouvées": "éprouver",
    "éprouvés": "éprouver",
    "éprîmes": "éprendre",
    "éprît": "éprendre",
    "éprîtes": "éprendre",
    "épuce": "épucer",
    "épucent": "épucer",
    "épucera": "épucer",
    "épucerai": "épucer",
    "épuceraient": "épucer",
    "épucerais": "épucer",
    "épucerait": "épucer",
    "épuceras": "épucer",
    "épucerez": "épucer",
    "épuceriez": "épucer",
    "épucerions": "épucer",
    "épucerons": "épucer",
    "épuceront": "épucer",
    "épuces": "épucer",
    "épucez": "épucer",
    "épuciez": "épucer",
    "épucions": "épucer",
    "épucèrent": "épucer",
    "épucé": "épucer",
    "épucée": "épucer",
    "épucées": "épucer",
    "épucés": "épucer",
    "épuisa": "épuiser",
    "épuisai": "épuiser",
    "épuisaient": "épuiser",
    "épuisais": "épuiser",
    "épuisait": "épuiser",
    "épuisant": "épuiser",
    "épuisante": "épuisant",
    "épuisantes": "épuisant",
    "épuisants": "épuisant",
    "épuisas": "épuiser",
    "épuisasse": "épuiser",
    "épuisassent": "épuiser",
    "épuisasses": "épuiser",
    "épuisassiez": "épuiser",
    "épuisassions": "épuiser",
    "épuise": "épuiser",
    "épuisements": "épuisement",
    "épuisent": "épuiser",
    "épuisera": "épuiser",
    "épuiserai": "épuiser",
    "épuiseraient": "épuiser",
    "épuiserais": "épuiser",
    "épuiserait": "épuiser",
    "épuiseras": "épuiser",
    "épuiserez": "épuiser",
    "épuiseriez": "épuiser",
    "épuiserions": "épuiser",
    "épuiserons": "épuiser",
    "épuiseront": "épuiser",
    "épuises": "épuiser",
    "épuisettes": "épuisette",
    "épuisez": "épuiser",
    "épuisiez": "épuiser",
    "épuisions": "épuiser",
    "épuisons": "épuiser",
    "épuisâmes": "épuiser",
    "épuisât": "épuiser",
    "épuisâtes": "épuiser",
    "épuisèrent": "épuiser",
    "épuisé": "épuiser",
    "épuisée": "épuiser",
    "épuisées": "épuiser",
    "épuisés": "épuiser",
    "épura": "épurer",
    "épurai": "épurer",
    "épuraient": "épurer",
    "épurais": "épurer",
    "épurait": "épurer",
    "épurant": "épurer",
    "épuras": "épurer",
    "épurasse": "épurer",
    "épurassent": "épurer",
    "épurasses": "épurer",
    "épurassiez": "épurer",
    "épurassions": "épurer",
    "épurations": "épuration",
    "épurative": "épuratif",
    "épure": "épurer",
    "épurent": "épurer",
    "épurera": "épurer",
    "épurerai": "épurer",
    "épureraient": "épurer",
    "épurerais": "épurer",
    "épurerait": "épurer",
    "épureras": "épurer",
    "épurerez": "épurer",
    "épureriez": "épurer",
    "épurerions": "épurer",
    "épurerons": "épurer",
    "épureront": "épurer",
    "épures": "épurer",
    "épurez": "épurer",
    "épuriez": "épurer",
    "épurions": "épurer",
    "épurons": "épurer",
    "épurâmes": "épurer",
    "épurât": "épurer",
    "épurâtes": "épurer",
    "épurèrent": "épurer",
    "épuré": "épurer",
    "épurée": "épurer",
    "épurées": "épurer",
    "épurés": "épurer",
    "épuça": "épucer",
    "épuçai": "épucer",
    "épuçaient": "épucer",
    "épuçais": "épucer",
    "épuçait": "épucer",
    "épuçant": "épucer",
    "épuças": "épucer",
    "épuçasse": "épucer",
    "épuçassent": "épucer",
    "épuçasses": "épucer",
    "épuçassiez": "épucer",
    "épuçassions": "épucer",
    "épuçons": "épucer",
    "épuçâmes": "épucer",
    "épuçât": "épucer",
    "épuçâtes": "épucer",
    "épées": "épée",
    "épéistes": "épéiste",
    "épépine": "épépiner",
    "épîtres": "épître",
    "équarisseurs": "équarisseur",
    "équarri": "équarrir",
    "équarrie": "équarrir",
    "équarries": "équarrir",
    "équarrira": "équarrir",
    "équarrirai": "équarrir",
    "équarriraient": "équarrir",
    "équarrirais": "équarrir",
    "équarrirait": "équarrir",
    "équarriras": "équarrir",
    "équarrirent": "équarrir",
    "équarrirez": "équarrir",
    "équarririez": "équarrir",
    "équarririons": "équarrir",
    "équarrirons": "équarrir",
    "équarriront": "équarrir",
    "équarris": "équarrir",
    "équarrissages": "équarrissage",
    "équarrissaient": "équarrir",
    "équarrissais": "équarrir",
    "équarrissait": "équarrir",
    "équarrissant": "équarrir",
    "équarrisse": "équarrir",
    "équarrissent": "équarrir",
    "équarrisses": "équarrir",
    "équarrisseurs": "équarrisseur",
    "équarrissez": "équarrir",
    "équarrissiez": "équarrir",
    "équarrissions": "équarrir",
    "équarrissons": "équarrir",
    "équarrit": "équarrir",
    "équarrîmes": "équarrir",
    "équarrît": "équarrir",
    "équarrîtes": "équarrir",
    "équateurs": "équateur",
    "équations": "équation",
    "équatoriale": "équatorial",
    "équatoriales": "équatorial",
    "équatoriaux": "équatorial",
    "équatorienne": "équatorien",
    "équatoriennes": "équatorien",
    "équatoriens": "équatorien",
    "équerres": "équerre",
    "équestres": "équestre",
    "équeutées": "équeuté",
    "équiangles": "équiangle",
    "équidistante": "équidistant",
    "équidistantes": "équidistant",
    "équidistants": "équidistant",
    "équidés": "équidé",
    "équilatérale": "équilatéral",
    "équilatérales": "équilatéral",
    "équilatéraux": "équilatéral",
    "équilibra": "équilibrer",
    "équilibrai": "équilibrer",
    "équilibraient": "équilibrer",
    "équilibrais": "équilibrer",
    "équilibrait": "équilibrer",
    "équilibrant": "équilibrer",
    "équilibrante": "équilibrant",
    "équilibras": "équilibrer",
    "équilibrasse": "équilibrer",
    "équilibrassent": "équilibrer",
    "équilibrasses": "équilibrer",
    "équilibrassiez": "équilibrer",
    "équilibrassions": "équilibrer",
    "équilibre": "équilibrer",
    "équilibrent": "équilibrer",
    "équilibrera": "équilibrer",
    "équilibrerai": "équilibrer",
    "équilibreraient": "équilibrer",
    "équilibrerais": "équilibrer",
    "équilibrerait": "équilibrer",
    "équilibreras": "équilibrer",
    "équilibrerez": "équilibrer",
    "équilibreriez": "équilibrer",
    "équilibrerions": "équilibrer",
    "équilibrerons": "équilibrer",
    "équilibreront": "équilibrer",
    "équilibres": "équilibrer",
    "équilibrez": "équilibrer",
    "équilibriez": "équilibrer",
    "équilibrions": "équilibrer",
    "équilibristes": "équilibriste",
    "équilibrons": "équilibrer",
    "équilibrâmes": "équilibrer",
    "équilibrât": "équilibrer",
    "équilibrâtes": "équilibrer",
    "équilibrèrent": "équilibrer",
    "équilibré": "équilibrer",
    "équilibrée": "équilibrer",
    "équilibrées": "équilibrer",
    "équilibrés": "équilibrer",
    "équilles": "équille",
    "équine": "équin",
    "équines": "équin",
    "équinoxes": "équinoxe",
    "équinoxiale": "équinoxial",
    "équinoxiales": "équinoxial",
    "équinoxiaux": "équinoxial",
    "équins": "équin",
    "équipa": "équiper",
    "équipages": "équipage",
    "équipai": "équiper",
    "équipaient": "équiper",
    "équipais": "équiper",
    "équipait": "équiper",
    "équipant": "équiper",
    "équipas": "équiper",
    "équipasse": "équiper",
    "équipassent": "équiper",
    "équipasses": "équiper",
    "équipassiez": "équiper",
    "équipassions": "équiper",
    "équipe": "équiper",
    "équipementiers": "équipementier",
    "équipementière": "équipementier",
    "équipementières": "équipementier",
    "équipements": "équipement",
    "équipent": "équiper",
    "équipera": "équiper",
    "équiperai": "équiper",
    "équiperaient": "équiper",
    "équiperais": "équiper",
    "équiperait": "équiper",
    "équiperas": "équiper",
    "équiperez": "équiper",
    "équiperiez": "équiper",
    "équiperions": "équiper",
    "équiperons": "équiper",
    "équiperont": "équiper",
    "équipes": "équiper",
    "équipez": "équiper",
    "équipiers": "équipier",
    "équipiez": "équiper",
    "équipions": "équiper",
    "équipière": "équipier",
    "équipières": "équipier",
    "équipollente": "équipollent",
    "équipollentes": "équipollent",
    "équipollents": "équipollent",
    "équipons": "équiper",
    "équipâmes": "équiper",
    "équipât": "équiper",
    "équipâtes": "équiper",
    "équipèrent": "équiper",
    "équipé": "équiper",
    "équipée": "équiper",
    "équipées": "équiper",
    "équipés": "équiper",
    "équitables": "équitable",
    "équitations": "équitation",
    "équités": "équité",
    "équivaille": "équivaloir",
    "équivaillent": "équivaloir",
    "équivailles": "équivaloir",
    "équivalaient": "équivaloir",
    "équivalais": "équivaloir",
    "équivalait": "équivaloir",
    "équivalant": "équivaloir",
    "équivalences": "équivalence",
    "équivalent": "équivaloir",
    "équivalente": "équivalent",
    "équivalentes": "équivalent",
    "équivalents": "équivalent",
    "équivalez": "équivaloir",
    "équivaliez": "équivaloir",
    "équivalions": "équivaloir",
    "équivalons": "équivaloir",
    "équivalu": "équivaloir",
    "équivalurent": "équivaloir",
    "équivalus": "équivaloir",
    "équivalusse": "équivaloir",
    "équivalussent": "équivaloir",
    "équivalusses": "équivaloir",
    "équivalussiez": "équivaloir",
    "équivalussions": "équivaloir",
    "équivalut": "équivaloir",
    "équivalûmes": "équivaloir",
    "équivalût": "équivaloir",
    "équivalûtes": "équivaloir",
    "équivaudra": "équivaloir",
    "équivaudrai": "équivaloir",
    "équivaudraient": "équivaloir",
    "équivaudrais": "équivaloir",
    "équivaudrait": "équivaloir",
    "équivaudras": "équivaloir",
    "équivaudrez": "équivaloir",
    "équivaudriez": "équivaloir",
    "équivaudrions": "équivaloir",
    "équivaudrons": "équivaloir",
    "équivaudront": "équivaloir",
    "équivaut": "équivaloir",
    "équivaux": "équivaloir",
    "équivoques": "équivoque",
    "érables": "érable",
    "érablières": "érablière",
    "éradications": "éradication",
    "éradiqua": "éradiquer",
    "éradiquai": "éradiquer",
    "éradiquaient": "éradiquer",
    "éradiquais": "éradiquer",
    "éradiquait": "éradiquer",
    "éradiquant": "éradiquer",
    "éradiquas": "éradiquer",
    "éradiquasse": "éradiquer",
    "éradiquassent": "éradiquer",
    "éradiquasses": "éradiquer",
    "éradiquassiez": "éradiquer",
    "éradiquassions": "éradiquer",
    "éradique": "éradiquer",
    "éradiquent": "éradiquer",
    "éradiquera": "éradiquer",
    "éradiquerai": "éradiquer",
    "éradiqueraient": "éradiquer",
    "éradiquerais": "éradiquer",
    "éradiquerait": "éradiquer",
    "éradiqueras": "éradiquer",
    "éradiquerez": "éradiquer",
    "éradiqueriez": "éradiquer",
    "éradiquerions": "éradiquer",
    "éradiquerons": "éradiquer",
    "éradiqueront": "éradiquer",
    "éradiques": "éradiquer",
    "éradiquez": "éradiquer",
    "éradiquiez": "éradiquer",
    "éradiquions": "éradiquer",
    "éradiquons": "éradiquer",
    "éradiquâmes": "éradiquer",
    "éradiquât": "éradiquer",
    "éradiquâtes": "éradiquer",
    "éradiquèrent": "éradiquer",
    "éradiqué": "éradiquer",
    "éradiquée": "éradiquer",
    "éradiquées": "éradiquer",
    "éradiqués": "éradiquer",
    "érafla": "érafler",
    "éraflai": "érafler",
    "éraflaient": "érafler",
    "éraflais": "érafler",
    "éraflait": "érafler",
    "éraflant": "érafler",
    "éraflas": "érafler",
    "éraflasse": "érafler",
    "éraflassent": "érafler",
    "éraflasses": "érafler",
    "éraflassiez": "érafler",
    "éraflassions": "érafler",
    "érafle": "érafler",
    "éraflent": "érafler",
    "éraflera": "érafler",
    "éraflerai": "érafler",
    "érafleraient": "érafler",
    "éraflerais": "érafler",
    "éraflerait": "érafler",
    "érafleras": "érafler",
    "éraflerez": "érafler",
    "érafleriez": "érafler",
    "éraflerions": "érafler",
    "éraflerons": "érafler",
    "érafleront": "érafler",
    "érafles": "érafler",
    "éraflez": "érafler",
    "érafliez": "érafler",
    "éraflions": "érafler",
    "éraflons": "érafler",
    "éraflures": "éraflure",
    "éraflâmes": "érafler",
    "éraflât": "érafler",
    "éraflâtes": "érafler",
    "éraflèrent": "érafler",
    "éraflé": "érafler",
    "éraflée": "érafler",
    "éraflées": "érafler",
    "éraflés": "érafler",
    "érailla": "érailler",
    "éraillai": "érailler",
    "éraillaient": "érailler",
    "éraillais": "érailler",
    "éraillait": "érailler",
    "éraillant": "érailler",
    "éraillas": "érailler",
    "éraillasse": "érailler",
    "éraillassent": "érailler",
    "éraillasses": "érailler",
    "éraillassiez": "érailler",
    "éraillassions": "érailler",
    "éraille": "érailler",
    "éraillent": "érailler",
    "éraillera": "érailler",
    "éraillerai": "érailler",
    "érailleraient": "érailler",
    "éraillerais": "érailler",
    "éraillerait": "érailler",
    "érailleras": "érailler",
    "éraillerez": "érailler",
    "érailleriez": "érailler",
    "éraillerions": "érailler",
    "éraillerons": "érailler",
    "érailleront": "érailler",
    "érailles": "érailler",
    "éraillez": "érailler",
    "érailliez": "érailler",
    "éraillions": "érailler",
    "éraillons": "érailler",
    "éraillures": "éraillure",
    "éraillâmes": "érailler",
    "éraillât": "érailler",
    "éraillâtes": "érailler",
    "éraillèrent": "érailler",
    "éraillé": "érailler",
    "éraillée": "érailler",
    "éraillées": "érailler",
    "éraillés": "érailler",
    "érectiles": "érectile",
    "érections": "érection",
    "éreinta": "éreinter",
    "éreintai": "éreinter",
    "éreintaient": "éreinter",
    "éreintais": "éreinter",
    "éreintait": "éreinter",
    "éreintant": "éreinter",
    "éreintante": "éreintant",
    "éreintants": "éreintant",
    "éreintas": "éreinter",
    "éreintasse": "éreinter",
    "éreintassent": "éreinter",
    "éreintasses": "éreinter",
    "éreintassiez": "éreinter",
    "éreintassions": "éreinter",
    "éreinte": "éreinter",
    "éreintent": "éreinter",
    "éreintera": "éreinter",
    "éreinterai": "éreinter",
    "éreinteraient": "éreinter",
    "éreinterais": "éreinter",
    "éreinterait": "éreinter",
    "éreinteras": "éreinter",
    "éreinterez": "éreinter",
    "éreinteriez": "éreinter",
    "éreinterions": "éreinter",
    "éreinterons": "éreinter",
    "éreinteront": "éreinter",
    "éreintes": "éreinter",
    "éreintez": "éreinter",
    "éreintiez": "éreinter",
    "éreintions": "éreinter",
    "éreintons": "éreinter",
    "éreintâmes": "éreinter",
    "éreintât": "éreinter",
    "éreintâtes": "éreinter",
    "éreintèrent": "éreinter",
    "éreinté": "éreinter",
    "éreintée": "éreinter",
    "éreintées": "éreinter",
    "éreintés": "éreinter",
    "érige": "ériger",
    "érigea": "ériger",
    "érigeai": "ériger",
    "érigeaient": "ériger",
    "érigeais": "ériger",
    "érigeait": "ériger",
    "érigeant": "ériger",
    "érigeas": "ériger",
    "érigeasse": "ériger",
    "érigeassent": "ériger",
    "érigeasses": "ériger",
    "érigeassiez": "ériger",
    "érigeassions": "ériger",
    "érigent": "ériger",
    "érigeons": "ériger",
    "érigera": "ériger",
    "érigerai": "ériger",
    "érigeraient": "ériger",
    "érigerais": "ériger",
    "érigerait": "ériger",
    "érigeras": "ériger",
    "érigerez": "ériger",
    "érigeriez": "ériger",
    "érigerions": "ériger",
    "érigerons": "ériger",
    "érigeront": "ériger",
    "ériges": "ériger",
    "érigez": "ériger",
    "érigeâmes": "ériger",
    "érigeât": "ériger",
    "érigeâtes": "ériger",
    "érigiez": "ériger",
    "érigions": "ériger",
    "érigèrent": "ériger",
    "érigé": "ériger",
    "érigée": "ériger",
    "érigées": "ériger",
    "érigés": "ériger",
    "éroda": "éroder",
    "érodai": "éroder",
    "érodaient": "éroder",
    "érodais": "éroder",
    "érodait": "éroder",
    "érodant": "éroder",
    "érodas": "éroder",
    "érodasse": "éroder",
    "érodassent": "éroder",
    "érodasses": "éroder",
    "érodassiez": "éroder",
    "érodassions": "éroder",
    "érode": "éroder",
    "érodent": "éroder",
    "érodera": "éroder",
    "éroderai": "éroder",
    "éroderaient": "éroder",
    "éroderais": "éroder",
    "éroderait": "éroder",
    "éroderas": "éroder",
    "éroderez": "éroder",
    "éroderiez": "éroder",
    "éroderions": "éroder",
    "éroderons": "éroder",
    "éroderont": "éroder",
    "érodes": "éroder",
    "érodez": "éroder",
    "érodiez": "éroder",
    "érodions": "éroder",
    "érodons": "éroder",
    "érodâmes": "éroder",
    "érodât": "éroder",
    "érodâtes": "éroder",
    "érodèrent": "éroder",
    "érodé": "éroder",
    "érodée": "éroder",
    "érodées": "éroder",
    "érodés": "éroder",
    "érogènes": "érogène",
    "érosions": "érosion",
    "érotiques": "érotique",
    "érotise": "érotiser",
    "érotismes": "érotisme",
    "érotisé": "érotiser",
    "érotisée": "érotiser",
    "érotomanes": "érotomane",
    "éructa": "éructer",
    "éructai": "éructer",
    "éructaient": "éructer",
    "éructais": "éructer",
    "éructait": "éructer",
    "éructant": "éructer",
    "éructas": "éructer",
    "éructasse": "éructer",
    "éructassent": "éructer",
    "éructasses": "éructer",
    "éructassiez": "éructer",
    "éructassions": "éructer",
    "éructations": "éructation",
    "éructe": "éructer",
    "éructent": "éructer",
    "éructera": "éructer",
    "éructerai": "éructer",
    "éructeraient": "éructer",
    "éructerais": "éructer",
    "éructerait": "éructer",
    "éructeras": "éructer",
    "éructerez": "éructer",
    "éructeriez": "éructer",
    "éructerions": "éructer",
    "éructerons": "éructer",
    "éructeront": "éructer",
    "éructes": "éructer",
    "éructez": "éructer",
    "éructiez": "éructer",
    "éructions": "éructer",
    "éructons": "éructer",
    "éructâmes": "éructer",
    "éructât": "éructer",
    "éructâtes": "éructer",
    "éructèrent": "éructer",
    "éructé": "éructer",
    "éructée": "éructer",
    "éructées": "éructer",
    "éructés": "éructer",
    "érudite": "érudit",
    "érudites": "érudit",
    "éruditions": "érudition",
    "érudits": "érudit",
    "érugineuse": "érugineux",
    "érugineuses": "érugineux",
    "éruptions": "éruption",
    "éruptive": "éruptif",
    "éruptives": "éruptif",
    "érysipèles": "érysipèle",
    "érythréenne": "érythréen",
    "érythréennes": "érythréen",
    "érythréens": "érythréen",
    "érythèmes": "érythème",
    "érésipèles": "érésipèle",
    "ésotériques": "ésotérique",
    "ésotérismes": "ésotérisme",
    "ésotéristes": "ésotériste",
    "étables": "étable",
    "établi": "établir",
    "établie": "établir",
    "établies": "établir",
    "établira": "établir",
    "établirai": "établir",
    "établiraient": "établir",
    "établirais": "établir",
    "établirait": "établir",
    "établiras": "établir",
    "établirent": "établir",
    "établirez": "établir",
    "établiriez": "établir",
    "établirions": "établir",
    "établirons": "établir",
    "établiront": "établir",
    "établis": "établir",
    "établissaient": "établir",
    "établissais": "établir",
    "établissait": "établir",
    "établissant": "établir",
    "établisse": "établir",
    "établissements": "établissement",
    "établissent": "établir",
    "établisses": "établir",
    "établissez": "établir",
    "établissiez": "établir",
    "établissions": "établir",
    "établissons": "établir",
    "établit": "établir",
    "établîmes": "établir",
    "établît": "établir",
    "établîtes": "établir",
    "étage": "étager",
    "étagea": "étager",
    "étageaient": "étager",
    "étageait": "étager",
    "étageant": "étager",
    "étagent": "étager",
    "étages": "étager",
    "étagères": "étagère",
    "étagée": "étager",
    "étagées": "étager",
    "étagés": "étager",
    "étaie": "étayer",
    "étaiements": "étaiement",
    "étaient": "être",
    "étaiera": "étayer",
    "étaierai": "étayer",
    "étaieraient": "étayer",
    "étaierais": "étayer",
    "étaierait": "étayer",
    "étaieras": "étayer",
    "étaierez": "étayer",
    "étaieriez": "étayer",
    "étaierions": "étayer",
    "étaierons": "étayer",
    "étaieront": "étayer",
    "étaies": "étayer",
    "étains": "étain",
    "étais": "être",
    "était": "être",
    "étala": "étaler",
    "étalages": "étalage",
    "étalai": "étaler",
    "étalaient": "étaler",
    "étalais": "étaler",
    "étalait": "étaler",
    "étalant": "étaler",
    "étalas": "étaler",
    "étalasse": "étaler",
    "étalassent": "étaler",
    "étalasses": "étaler",
    "étalassiez": "étaler",
    "étalassions": "étaler",
    "étale": "étaler",
    "étalements": "étalement",
    "étalent": "étaler",
    "étalera": "étaler",
    "étalerai": "étaler",
    "étaleraient": "étaler",
    "étalerais": "étaler",
    "étalerait": "étaler",
    "étaleras": "étaler",
    "étalerez": "étaler",
    "étaleriez": "étaler",
    "étalerions": "étaler",
    "étalerons": "étaler",
    "étaleront": "étaler",
    "étales": "étaler",
    "étalez": "étaler",
    "étaliez": "étaler",
    "étalions": "étaler",
    "étalonna": "étalonner",
    "étalonnages": "étalonnage",
    "étalonnai": "étalonner",
    "étalonnaient": "étalonner",
    "étalonnais": "étalonner",
    "étalonnait": "étalonner",
    "étalonnant": "étalonner",
    "étalonnas": "étalonner",
    "étalonnasse": "étalonner",
    "étalonnassent": "étalonner",
    "étalonnasses": "étalonner",
    "étalonnassiez": "étalonner",
    "étalonnassions": "étalonner",
    "étalonne": "étalonner",
    "étalonnent": "étalonner",
    "étalonnera": "étalonner",
    "étalonnerai": "étalonner",
    "étalonneraient": "étalonner",
    "étalonnerais": "étalonner",
    "étalonnerait": "étalonner",
    "étalonneras": "étalonner",
    "étalonnerez": "étalonner",
    "étalonneriez": "étalonner",
    "étalonnerions": "étalonner",
    "étalonnerons": "étalonner",
    "étalonneront": "étalonner",
    "étalonnes": "étalonner",
    "étalonnez": "étalonner",
    "étalonniez": "étalonner",
    "étalonnions": "étalonner",
    "étalonnons": "étalonner",
    "étalonnâmes": "étalonner",
    "étalonnât": "étalonner",
    "étalonnâtes": "étalonner",
    "étalonnèrent": "étalonner",
    "étalonné": "étalonner",
    "étalonnée": "étalonner",
    "étalonnées": "étalonner",
    "étalonnés": "étalonner",
    "étalons": "étalon",
    "étals": "étal",
    "étalâmes": "étaler",
    "étalât": "étaler",
    "étalâtes": "étaler",
    "étalèrent": "étaler",
    "étalé": "étaler",
    "étalée": "étaler",
    "étalées": "étaler",
    "étalés": "étaler",
    "étama": "étamer",
    "étamai": "étamer",
    "étamaient": "étamer",
    "étamais": "étamer",
    "étamait": "étamer",
    "étamant": "étamer",
    "étamas": "étamer",
    "étamasse": "étamer",
    "étamassent": "étamer",
    "étamasses": "étamer",
    "étamassiez": "étamer",
    "étamassions": "étamer",
    "étambots": "étambot",
    "étame": "étamer",
    "étament": "étamer",
    "étamera": "étamer",
    "étamerai": "étamer",
    "étameraient": "étamer",
    "étamerais": "étamer",
    "étamerait": "étamer",
    "étameras": "étamer",
    "étamerez": "étamer",
    "étameriez": "étamer",
    "étamerions": "étamer",
    "étamerons": "étamer",
    "étameront": "étamer",
    "étames": "étamer",
    "étameurs": "étameur",
    "étamez": "étamer",
    "étamiez": "étamer",
    "étamines": "étamine",
    "étamions": "étamer",
    "étamons": "étamer",
    "étampes": "étampe",
    "étampures": "étampure",
    "étamâmes": "étamer",
    "étamât": "étamer",
    "étamâtes": "étamer",
    "étamèrent": "étamer",
    "étamé": "étamer",
    "étamée": "étamer",
    "étamées": "étamer",
    "étamés": "étamer",
    "étancha": "étancher",
    "étanchai": "étancher",
    "étanchaient": "étancher",
    "étanchais": "étancher",
    "étanchait": "étancher",
    "étanchant": "étancher",
    "étanchas": "étancher",
    "étanchasse": "étancher",
    "étanchassent": "étancher",
    "étanchasses": "étancher",
    "étanchassiez": "étancher",
    "étanchassions": "étancher",
    "étanche": "étancher",
    "étanchent": "étancher",
    "étanchera": "étancher",
    "étancherai": "étancher",
    "étancheraient": "étancher",
    "étancherais": "étancher",
    "étancherait": "étancher",
    "étancheras": "étancher",
    "étancherez": "étancher",
    "étancheriez": "étancher",
    "étancherions": "étancher",
    "étancherons": "étancher",
    "étancheront": "étancher",
    "étanches": "étancher",
    "étanchez": "étancher",
    "étanchiez": "étancher",
    "étanchions": "étancher",
    "étanchons": "étancher",
    "étanchâmes": "étancher",
    "étanchât": "étancher",
    "étanchâtes": "étancher",
    "étanchèrent": "étancher",
    "étanché": "étancher",
    "étanchée": "étancher",
    "étanchées": "étancher",
    "étanchés": "étancher",
    "étangs": "étang",
    "étant": "être",
    "étapes": "étape",
    "état-civils": "état-civil",
    "étatiques": "étatique",
    "étatisa": "étatiser",
    "étatisai": "étatiser",
    "étatisaient": "étatiser",
    "étatisais": "étatiser",
    "étatisait": "étatiser",
    "étatisant": "étatiser",
    "étatisas": "étatiser",
    "étatisasse": "étatiser",
    "étatisassent": "étatiser",
    "étatisasses": "étatiser",
    "étatisassiez": "étatiser",
    "étatisassions": "étatiser",
    "étatisations": "étatisation",
    "étatise": "étatiser",
    "étatisent": "étatiser",
    "étatisera": "étatiser",
    "étatiserai": "étatiser",
    "étatiseraient": "étatiser",
    "étatiserais": "étatiser",
    "étatiserait": "étatiser",
    "étatiseras": "étatiser",
    "étatiserez": "étatiser",
    "étatiseriez": "étatiser",
    "étatiserions": "étatiser",
    "étatiserons": "étatiser",
    "étatiseront": "étatiser",
    "étatises": "étatiser",
    "étatisez": "étatiser",
    "étatisiez": "étatiser",
    "étatisions": "étatiser",
    "étatisons": "étatiser",
    "étatisâmes": "étatiser",
    "étatisât": "étatiser",
    "étatisâtes": "étatiser",
    "étatisèrent": "étatiser",
    "étatisé": "étatiser",
    "étatisée": "étatiser",
    "étatisées": "étatiser",
    "étatisés": "étatiser",
    "états": "état",
    "états-civils": "état-civil",
    "états-majors": "état-major",
    "états-membres": "État-membre",
    "étaux": "étau",
    "étaya": "étayer",
    "étayai": "étayer",
    "étayaient": "étayer",
    "étayais": "étayer",
    "étayait": "étayer",
    "étayant": "étayer",
    "étayas": "étayer",
    "étayasse": "étayer",
    "étayassent": "étayer",
    "étayasses": "étayer",
    "étayassiez": "étayer",
    "étayassions": "étayer",
    "étaye": "étayer",
    "étayent": "étayer",
    "étayera": "étayer",
    "étayerai": "étayer",
    "étayeraient": "étayer",
    "étayerais": "étayer",
    "étayerait": "étayer",
    "étayeras": "étayer",
    "étayerez": "étayer",
    "étayeriez": "étayer",
    "étayerions": "étayer",
    "étayerons": "étayer",
    "étayeront": "étayer",
    "étayes": "étayer",
    "étayez": "étayer",
    "étayiez": "étayer",
    "étayions": "étayer",
    "étayons": "étayer",
    "étayâmes": "étayer",
    "étayât": "étayer",
    "étayâtes": "étayer",
    "étayèrent": "étayer",
    "étayé": "étayer",
    "étayée": "étayer",
    "étayées": "étayer",
    "étayés": "étayer",
    "éteignaient": "éteindre",
    "éteignais": "éteindre",
    "éteignait": "éteindre",
    "éteignant": "éteindre",
    "éteigne": "éteindre",
    "éteignent": "éteindre",
    "éteignes": "éteindre",
    "éteignez": "éteindre",
    "éteigniez": "éteindre",
    "éteignions": "éteindre",
    "éteignirent": "éteindre",
    "éteignis": "éteindre",
    "éteignisse": "éteindre",
    "éteignissent": "éteindre",
    "éteignisses": "éteindre",
    "éteignissiez": "éteindre",
    "éteignissions": "éteindre",
    "éteignit": "éteindre",
    "éteignons": "éteindre",
    "éteignîmes": "éteindre",
    "éteignît": "éteindre",
    "éteignîtes": "éteindre",
    "éteindra": "éteindre",
    "éteindrai": "éteindre",
    "éteindraient": "éteindre",
    "éteindrais": "éteindre",
    "éteindrait": "éteindre",
    "éteindras": "éteindre",
    "éteindrez": "éteindre",
    "éteindriez": "éteindre",
    "éteindrions": "éteindre",
    "éteindrons": "éteindre",
    "éteindront": "éteindre",
    "éteins": "éteindre",
    "éteint": "éteindre",
    "éteinte": "éteint",
    "éteintes": "éteint",
    "éteints": "éteint",
    "étend": "étendre",
    "étendaient": "étendre",
    "étendais": "étendre",
    "étendait": "étendre",
    "étendant": "étendre",
    "étendards": "étendard",
    "étende": "étendre",
    "étendent": "étendre",
    "étendes": "étendre",
    "étendez": "étendre",
    "étendiez": "étendre",
    "étendions": "étendre",
    "étendirent": "étendre",
    "étendis": "étendre",
    "étendisse": "étendre",
    "étendissent": "étendre",
    "étendisses": "étendre",
    "étendissiez": "étendre",
    "étendissions": "étendre",
    "étendit": "étendre",
    "étendons": "étendre",
    "étendra": "étendre",
    "étendrai": "étendre",
    "étendraient": "étendre",
    "étendrais": "étendre",
    "étendrait": "étendre",
    "étendras": "étendre",
    "étendrez": "étendre",
    "étendriez": "étendre",
    "étendrions": "étendre",
    "étendrons": "étendre",
    "étendront": "étendre",
    "étends": "étendre",
    "étendu": "étendre",
    "étendue": "étendre",
    "étendues": "étendue",
    "étendus": "étendu",
    "étendîmes": "étendre",
    "étendît": "étendre",
    "étendîtes": "étendre",
    "éternelle": "éternel",
    "éternelles": "éternel",
    "éternels": "éternel",
    "éternisa": "éterniser",
    "éternisai": "éterniser",
    "éternisaient": "éterniser",
    "éternisais": "éterniser",
    "éternisait": "éterniser",
    "éternisant": "éterniser",
    "éternisas": "éterniser",
    "éternisasse": "éterniser",
    "éternisassent": "éterniser",
    "éternisasses": "éterniser",
    "éternisassiez": "éterniser",
    "éternisassions": "éterniser",
    "éternise": "éterniser",
    "éternisent": "éterniser",
    "éternisera": "éterniser",
    "éterniserai": "éterniser",
    "éterniseraient": "éterniser",
    "éterniserais": "éterniser",
    "éterniserait": "éterniser",
    "éterniseras": "éterniser",
    "éterniserez": "éterniser",
    "éterniseriez": "éterniser",
    "éterniserions": "éterniser",
    "éterniserons": "éterniser",
    "éterniseront": "éterniser",
    "éternises": "éterniser",
    "éternisez": "éterniser",
    "éternisiez": "éterniser",
    "éternisions": "éterniser",
    "éternisons": "éterniser",
    "éternisâmes": "éterniser",
    "éternisât": "éterniser",
    "éternisâtes": "éterniser",
    "éternisèrent": "éterniser",
    "éternisé": "éterniser",
    "éternisée": "éterniser",
    "éternisées": "éterniser",
    "éternisés": "éterniser",
    "éternités": "éternité",
    "éternua": "éternuer",
    "éternuai": "éternuer",
    "éternuaient": "éternuer",
    "éternuais": "éternuer",
    "éternuait": "éternuer",
    "éternuant": "éternuer",
    "éternuas": "éternuer",
    "éternuasse": "éternuer",
    "éternuassent": "éternuer",
    "éternuasses": "éternuer",
    "éternuassiez": "éternuer",
    "éternuassions": "éternuer",
    "éternue": "éternuer",
    "éternuements": "éternuement",
    "éternuent": "éternuer",
    "éternuera": "éternuer",
    "éternuerai": "éternuer",
    "éternueraient": "éternuer",
    "éternuerais": "éternuer",
    "éternuerait": "éternuer",
    "éternueras": "éternuer",
    "éternuerez": "éternuer",
    "éternueriez": "éternuer",
    "éternuerions": "éternuer",
    "éternuerons": "éternuer",
    "éternueront": "éternuer",
    "éternues": "éternuer",
    "éternuez": "éternuer",
    "éternuiez": "éternuer",
    "éternuions": "éternuer",
    "éternuons": "éternuer",
    "éternuâmes": "éternuer",
    "éternuât": "éternuer",
    "éternuâtes": "éternuer",
    "éternuèrent": "éternuer",
    "éternué": "éternuer",
    "éteules": "éteule",
    "éthers": "éther",
    "éthiopienne": "éthiopien",
    "éthiopiennes": "éthiopien",
    "éthiopiens": "éthiopien",
    "éthiques": "éthique",
    "éthologies": "éthologie",
    "éthyles": "éthyle",
    "éthyliques": "éthylique",
    "éthérée": "éthéré",
    "éthérées": "éthéré",
    "éthérés": "éthéré",
    "étiages": "étiage",
    "étiers": "étier",
    "étiez": "être",
    "étincela": "étinceler",
    "étincelai": "étinceler",
    "étincelaient": "étinceler",
    "étincelais": "étinceler",
    "étincelait": "étinceler",
    "étincelant": "étinceler",
    "étincelante": "étincelant",
    "étincelantes": "étincelant",
    "étincelants": "étincelant",
    "étincelas": "étinceler",
    "étincelasse": "étinceler",
    "étincelassent": "étinceler",
    "étincelasses": "étinceler",
    "étincelassiez": "étinceler",
    "étincelassions": "étinceler",
    "étincelez": "étinceler",
    "étinceliez": "étinceler",
    "étincelions": "étinceler",
    "étincelle": "étinceler",
    "étincellements": "étincellement",
    "étincellent": "étinceler",
    "étincellera": "étinceler",
    "étincellerai": "étinceler",
    "étincelleraient": "étinceler",
    "étincellerais": "étinceler",
    "étincellerait": "étinceler",
    "étincelleras": "étinceler",
    "étincellerez": "étinceler",
    "étincelleriez": "étinceler",
    "étincellerions": "étinceler",
    "étincellerons": "étinceler",
    "étincelleront": "étinceler",
    "étincelles": "étincelle",
    "étincelons": "étinceler",
    "étincelâmes": "étinceler",
    "étincelât": "étinceler",
    "étincelâtes": "étinceler",
    "étincelèrent": "étinceler",
    "étincelé": "étinceler",
    "étiola": "étioler",
    "étiolai": "étioler",
    "étiolaient": "étioler",
    "étiolais": "étioler",
    "étiolait": "étioler",
    "étiolant": "étioler",
    "étiolas": "étioler",
    "étiolasse": "étioler",
    "étiolassent": "étioler",
    "étiolasses": "étioler",
    "étiolassiez": "étioler",
    "étiolassions": "étioler",
    "étiole": "étioler",
    "étiolent": "étioler",
    "étiolera": "étioler",
    "étiolerai": "étioler",
    "étioleraient": "étioler",
    "étiolerais": "étioler",
    "étiolerait": "étioler",
    "étioleras": "étioler",
    "étiolerez": "étioler",
    "étioleriez": "étioler",
    "étiolerions": "étioler",
    "étiolerons": "étioler",
    "étioleront": "étioler",
    "étioles": "étioler",
    "étiolez": "étioler",
    "étioliez": "étioler",
    "étiolions": "étioler",
    "étiologies": "étiologie",
    "étiologiques": "étiologique",
    "étiolons": "étioler",
    "étiolâmes": "étioler",
    "étiolât": "étioler",
    "étiolâtes": "étioler",
    "étiolèrent": "étioler",
    "étiolé": "étioler",
    "étiolée": "étioler",
    "étiolées": "étioler",
    "étiolés": "étioler",
    "étions": "être",
    "étiques": "étique",
    "étiqueta": "étiqueter",
    "étiquetages": "étiquetage",
    "étiquetai": "étiqueter",
    "étiquetaient": "étiqueter",
    "étiquetais": "étiqueter",
    "étiquetait": "étiqueter",
    "étiquetant": "étiqueter",
    "étiquetas": "étiqueter",
    "étiquetasse": "étiqueter",
    "étiquetassent": "étiqueter",
    "étiquetasses": "étiqueter",
    "étiquetassiez": "étiqueter",
    "étiquetassions": "étiqueter",
    "étiqueteuse": "étiqueteur",
    "étiquetez": "étiqueter",
    "étiquetiez": "étiqueter",
    "étiquetions": "étiqueter",
    "étiquetons": "étiqueter",
    "étiquette": "étiqueter",
    "étiquettent": "étiqueter",
    "étiquettera": "étiqueter",
    "étiquetterai": "étiqueter",
    "étiquetteraient": "étiqueter",
    "étiquetterais": "étiqueter",
    "étiquetterait": "étiqueter",
    "étiquetteras": "étiqueter",
    "étiquetterez": "étiqueter",
    "étiquetteriez": "étiqueter",
    "étiquetterions": "étiqueter",
    "étiquetterons": "étiqueter",
    "étiquetteront": "étiqueter",
    "étiquettes": "étiquette",
    "étiquetâmes": "étiqueter",
    "étiquetât": "étiqueter",
    "étiquetâtes": "étiqueter",
    "étiquetèrent": "étiqueter",
    "étiqueté": "étiqueter",
    "étiquetée": "étiqueter",
    "étiquetées": "étiqueter",
    "étiquetés": "étiqueter",
    "étira": "étirer",
    "étirai": "étirer",
    "étiraient": "étirer",
    "étirais": "étirer",
    "étirait": "étirer",
    "étirant": "étirer",
    "étiras": "étirer",
    "étirasse": "étirer",
    "étirassent": "étirer",
    "étirasses": "étirer",
    "étirassiez": "étirer",
    "étirassions": "étirer",
    "étire": "étirer",
    "étirements": "étirement",
    "étirent": "étirer",
    "étirera": "étirer",
    "étirerai": "étirer",
    "étireraient": "étirer",
    "étirerais": "étirer",
    "étirerait": "étirer",
    "étireras": "étirer",
    "étirerez": "étirer",
    "étireriez": "étirer",
    "étirerions": "étirer",
    "étirerons": "étirer",
    "étireront": "étirer",
    "étires": "étirer",
    "étirez": "étirer",
    "étiriez": "étirer",
    "étirions": "étirer",
    "étirons": "étirer",
    "étirâmes": "étirer",
    "étirât": "étirer",
    "étirâtes": "étirer",
    "étirèrent": "étirer",
    "étiré": "étirer",
    "étirée": "étirer",
    "étirées": "étirer",
    "étirés": "étirer",
    "étoffa": "étoffer",
    "étoffai": "étoffer",
    "étoffaient": "étoffer",
    "étoffais": "étoffer",
    "étoffait": "étoffer",
    "étoffant": "étoffer",
    "étoffas": "étoffer",
    "étoffasse": "étoffer",
    "étoffassent": "étoffer",
    "étoffasses": "étoffer",
    "étoffassiez": "étoffer",
    "étoffassions": "étoffer",
    "étoffe": "étoffer",
    "étoffent": "étoffer",
    "étoffera": "étoffer",
    "étofferai": "étoffer",
    "étofferaient": "étoffer",
    "étofferais": "étoffer",
    "étofferait": "étoffer",
    "étofferas": "étoffer",
    "étofferez": "étoffer",
    "étofferiez": "étoffer",
    "étofferions": "étoffer",
    "étofferons": "étoffer",
    "étofferont": "étoffer",
    "étoffes": "étoffer",
    "étoffez": "étoffer",
    "étoffiez": "étoffer",
    "étoffions": "étoffer",
    "étoffons": "étoffer",
    "étoffâmes": "étoffer",
    "étoffât": "étoffer",
    "étoffâtes": "étoffer",
    "étoffèrent": "étoffer",
    "étoffé": "étoffer",
    "étoffée": "étoffer",
    "étoffées": "étoffer",
    "étoffés": "étoffer",
    "étoila": "étoiler",
    "étoilai": "étoiler",
    "étoilaient": "étoiler",
    "étoilais": "étoiler",
    "étoilait": "étoiler",
    "étoilant": "étoiler",
    "étoilas": "étoiler",
    "étoilasse": "étoiler",
    "étoilassent": "étoiler",
    "étoilasses": "étoiler",
    "étoilassiez": "étoiler",
    "étoilassions": "étoiler",
    "étoile": "étoiler",
    "étoilent": "étoiler",
    "étoilera": "étoiler",
    "étoilerai": "étoiler",
    "étoileraient": "étoiler",
    "étoilerais": "étoiler",
    "étoilerait": "étoiler",
    "étoileras": "étoiler",
    "étoilerez": "étoiler",
    "étoileriez": "étoiler",
    "étoilerions": "étoiler",
    "étoilerons": "étoiler",
    "étoileront": "étoiler",
    "étoiles": "étoiler",
    "étoilez": "étoiler",
    "étoiliez": "étoiler",
    "étoilions": "étoiler",
    "étoilons": "étoiler",
    "étoilâmes": "étoiler",
    "étoilât": "étoiler",
    "étoilâtes": "étoiler",
    "étoilèrent": "étoiler",
    "étoilé": "étoiler",
    "étoilée": "étoiler",
    "étoilées": "étoiler",
    "étoilés": "étoiler",
    "étoles": "étole",
    "étonna": "étonner",
    "étonnai": "étonner",
    "étonnaient": "étonner",
    "étonnais": "étonner",
    "étonnait": "étonner",
    "étonnant": "étonner",
    "étonnante": "étonnant",
    "étonnantes": "étonnant",
    "étonnants": "étonnant",
    "étonnas": "étonner",
    "étonnasse": "étonner",
    "étonnassent": "étonner",
    "étonnasses": "étonner",
    "étonnassiez": "étonner",
    "étonnassions": "étonner",
    "étonne": "étonner",
    "étonnements": "étonnement",
    "étonnent": "étonner",
    "étonnera": "étonner",
    "étonnerai": "étonner",
    "étonneraient": "étonner",
    "étonnerais": "étonner",
    "étonnerait": "étonner",
    "étonneras": "étonner",
    "étonnerez": "étonner",
    "étonneriez": "étonner",
    "étonnerions": "étonner",
    "étonnerons": "étonner",
    "étonneront": "étonner",
    "étonnes": "étonner",
    "étonnez": "étonner",
    "étonniez": "étonner",
    "étonnions": "étonner",
    "étonnons": "étonner",
    "étonnâmes": "étonner",
    "étonnât": "étonner",
    "étonnâtes": "étonner",
    "étonnèrent": "étonner",
    "étonné": "étonner",
    "étonnée": "étonner",
    "étonnées": "étonner",
    "étonnés": "étonner",
    "étouffa": "étouffer",
    "étouffai": "étouffer",
    "étouffaient": "étouffer",
    "étouffais": "étouffer",
    "étouffait": "étouffer",
    "étouffant": "étouffer",
    "étouffante": "étouffant",
    "étouffantes": "étouffant",
    "étouffants": "étouffant",
    "étouffas": "étouffer",
    "étouffasse": "étouffer",
    "étouffassent": "étouffer",
    "étouffasses": "étouffer",
    "étouffassiez": "étouffer",
    "étouffassions": "étouffer",
    "étouffe": "étouffer",
    "étouffe-chrétiens": "étouffe-chrétien",
    "étouffements": "étouffement",
    "étouffent": "étouffer",
    "étouffera": "étouffer",
    "étoufferai": "étouffer",
    "étoufferaient": "étouffer",
    "étoufferais": "étouffer",
    "étoufferait": "étouffer",
    "étoufferas": "étouffer",
    "étoufferez": "étouffer",
    "étoufferiez": "étouffer",
    "étoufferions": "étouffer",
    "étoufferons": "étouffer",
    "étoufferont": "étouffer",
    "étouffes": "étouffer",
    "étouffeuses": "étouffeur",
    "étouffez": "étouffer",
    "étouffiez": "étouffer",
    "étouffions": "étouffer",
    "étouffoirs": "étouffoir",
    "étouffons": "étouffer",
    "étouffâmes": "étouffer",
    "étouffât": "étouffer",
    "étouffâtes": "étouffer",
    "étouffèrent": "étouffer",
    "étouffé": "étouffer",
    "étouffée": "étouffer",
    "étouffées": "étouffer",
    "étouffés": "étouffer",
    "étoupes": "étoupe",
    "étoupilles": "étoupille",
    "étourderies": "étourderie",
    "étourdi": "étourdir",
    "étourdie": "étourdir",
    "étourdies": "étourdir",
    "étourdira": "étourdir",
    "étourdirai": "étourdir",
    "étourdiraient": "étourdir",
    "étourdirais": "étourdir",
    "étourdirait": "étourdir",
    "étourdiras": "étourdir",
    "étourdirent": "étourdir",
    "étourdirez": "étourdir",
    "étourdiriez": "étourdir",
    "étourdirions": "étourdir",
    "étourdirons": "étourdir",
    "étourdiront": "étourdir",
    "étourdis": "étourdir",
    "étourdissaient": "étourdir",
    "étourdissais": "étourdir",
    "étourdissait": "étourdir",
    "étourdissant": "étourdir",
    "étourdissante": "étourdissant",
    "étourdissantes": "étourdissant",
    "étourdissants": "étourdissant",
    "étourdisse": "étourdir",
    "étourdissements": "étourdissement",
    "étourdissent": "étourdir",
    "étourdisses": "étourdir",
    "étourdissez": "étourdir",
    "étourdissiez": "étourdir",
    "étourdissions": "étourdir",
    "étourdissons": "étourdir",
    "étourdit": "étourdir",
    "étourdîmes": "étourdir",
    "étourdît": "étourdir",
    "étourdîtes": "étourdir",
    "étourneaux": "étourneau",
    "étrangers": "étranger",
    "étranges": "étrange",
    "étrangetés": "étrangeté",
    "étrangla": "étrangler",
    "étranglai": "étrangler",
    "étranglaient": "étrangler",
    "étranglais": "étrangler",
    "étranglait": "étrangler",
    "étranglant": "étrangler",
    "étranglas": "étrangler",
    "étranglasse": "étrangler",
    "étranglassent": "étrangler",
    "étranglasses": "étrangler",
    "étranglassiez": "étrangler",
    "étranglassions": "étrangler",
    "étrangle": "étrangler",
    "étranglements": "étranglement",
    "étranglent": "étrangler",
    "étranglera": "étrangler",
    "étranglerai": "étrangler",
    "étrangleraient": "étrangler",
    "étranglerais": "étrangler",
    "étranglerait": "étrangler",
    "étrangleras": "étrangler",
    "étranglerez": "étrangler",
    "étrangleriez": "étrangler",
    "étranglerions": "étrangler",
    "étranglerons": "étrangler",
    "étrangleront": "étrangler",
    "étrangles": "étrangler",
    "étrangleurs": "étrangleur",
    "étrangleuse": "étrangleur",
    "étrangleuses": "étrangleur",
    "étranglez": "étrangler",
    "étrangliez": "étrangler",
    "étranglions": "étrangler",
    "étranglons": "étrangler",
    "étranglâmes": "étrangler",
    "étranglât": "étrangler",
    "étranglâtes": "étrangler",
    "étranglèrent": "étrangler",
    "étranglé": "étrangler",
    "étranglée": "étrangler",
    "étranglées": "étrangler",
    "étranglés": "étrangler",
    "étrangère": "étranger",
    "étrangères": "étranger",
    "étrapes": "étrape",
    "étraves": "étrave",
    "étreignaient": "étreindre",
    "étreignais": "étreindre",
    "étreignait": "étreindre",
    "étreignant": "étreindre",
    "étreigne": "étreindre",
    "étreignent": "étreindre",
    "étreignes": "étreindre",
    "étreignez": "étreindre",
    "étreigniez": "étreindre",
    "étreignions": "étreindre",
    "étreignirent": "étreindre",
    "étreignis": "étreindre",
    "étreignisse": "étreindre",
    "étreignissent": "étreindre",
    "étreignisses": "étreindre",
    "étreignissiez": "étreindre",
    "étreignissions": "étreindre",
    "étreignit": "étreindre",
    "étreignons": "étreindre",
    "étreignîmes": "étreindre",
    "étreignît": "étreindre",
    "étreignîtes": "étreindre",
    "étreindra": "étreindre",
    "étreindrai": "étreindre",
    "étreindraient": "étreindre",
    "étreindrais": "étreindre",
    "étreindrait": "étreindre",
    "étreindras": "étreindre",
    "étreindrez": "étreindre",
    "étreindriez": "étreindre",
    "étreindrions": "étreindre",
    "étreindrons": "étreindre",
    "étreindront": "étreindre",
    "étreins": "étreindre",
    "étreint": "étreindre",
    "étreinte": "étreindre",
    "étreintes": "étreinte",
    "étreints": "étreindre",
    "étrenna": "étrenner",
    "étrennait": "étrenner",
    "étrennant": "étrenner",
    "étrenne": "étrenner",
    "étrennent": "étrenner",
    "étrennera": "étrenner",
    "étrennerais": "étrenner",
    "étrennes": "étrenner",
    "étrenné": "étrenner",
    "étrennée": "étrenner",
    "étriers": "étrier",
    "étrilla": "étriller",
    "étrillaient": "étriller",
    "étrillait": "étriller",
    "étrille": "étriller",
    "étrillerez": "étriller",
    "étrilles": "étrille",
    "étrillé": "étriller",
    "étrillée": "étriller",
    "étrillés": "étriller",
    "étripa": "étriper",
    "étripages": "étripage",
    "étripai": "étriper",
    "étripaient": "étriper",
    "étripais": "étriper",
    "étripait": "étriper",
    "étripant": "étriper",
    "étripas": "étriper",
    "étripasse": "étriper",
    "étripassent": "étriper",
    "étripasses": "étriper",
    "étripassiez": "étriper",
    "étripassions": "étriper",
    "étripe": "étriper",
    "étripent": "étriper",
    "étripera": "étriper",
    "étriperai": "étriper",
    "étriperaient": "étriper",
    "étriperais": "étriper",
    "étriperait": "étriper",
    "étriperas": "étriper",
    "étriperez": "étriper",
    "étriperiez": "étriper",
    "étriperions": "étriper",
    "étriperons": "étriper",
    "étriperont": "étriper",
    "étripes": "étriper",
    "étripez": "étriper",
    "étripiez": "étriper",
    "étripions": "étriper",
    "étripons": "étriper",
    "étripâmes": "étriper",
    "étripât": "étriper",
    "étripâtes": "étriper",
    "étripèrent": "étriper",
    "étripé": "étriper",
    "étripée": "étriper",
    "étripées": "étriper",
    "étripés": "étriper",
    "étriqua": "étriquer",
    "étriquaient": "étriquer",
    "étriquant": "étriquer",
    "étriqué": "étriquer",
    "étriquée": "étriquer",
    "étriquées": "étriquer",
    "étriqués": "étriquer",
    "étrivières": "étrivière",
    "étroite": "étroit",
    "étroites": "étroit",
    "étroitesses": "étroitesse",
    "étroits": "étroit",
    "étrons": "étron",
    "étrusques": "étrusque",
    "étréci": "étrécir",
    "étrécie": "étrécir",
    "étrécies": "étrécir",
    "étrécira": "étrécir",
    "étrécirai": "étrécir",
    "étréciraient": "étrécir",
    "étrécirais": "étrécir",
    "étrécirait": "étrécir",
    "étréciras": "étrécir",
    "étrécirent": "étrécir",
    "étrécirez": "étrécir",
    "étréciriez": "étrécir",
    "étrécirions": "étrécir",
    "étrécirons": "étrécir",
    "étréciront": "étrécir",
    "étrécis": "étrécir",
    "étrécissaient": "étrécir",
    "étrécissais": "étrécir",
    "étrécissait": "étrécir",
    "étrécissant": "étrécir",
    "étrécisse": "étrécir",
    "étrécissent": "étrécir",
    "étrécisses": "étrécir",
    "étrécissez": "étrécir",
    "étrécissiez": "étrécir",
    "étrécissions": "étrécir",
    "étrécissons": "étrécir",
    "étrécit": "étrécir",
    "étrécîmes": "étrécir",
    "étrécît": "étrécir",
    "étrécîtes": "étrécir",
    "études": "étude",
    "étudia": "étudier",
    "étudiai": "étudier",
    "étudiaient": "étudier",
    "étudiais": "étudier",
    "étudiait": "étudier",
    "étudiant": "étudier",
    "étudiante": "étudiant",
    "étudiantes": "étudiant",
    "étudiants": "étudiant",
    "étudias": "étudier",
    "étudiasse": "étudier",
    "étudiassent": "étudier",
    "étudiasses": "étudier",
    "étudiassiez": "étudier",
    "étudiassions": "étudier",
    "étudie": "étudier",
    "étudient": "étudier",
    "étudiera": "étudier",
    "étudierai": "étudier",
    "étudieraient": "étudier",
    "étudierais": "étudier",
    "étudierait": "étudier",
    "étudieras": "étudier",
    "étudierez": "étudier",
    "étudieriez": "étudier",
    "étudierions": "étudier",
    "étudierons": "étudier",
    "étudieront": "étudier",
    "étudies": "étudier",
    "étudiez": "étudier",
    "étudiiez": "étudier",
    "étudiions": "étudier",
    "étudions": "étudier",
    "étudiâmes": "étudier",
    "étudiât": "étudier",
    "étudiâtes": "étudier",
    "étudièrent": "étudier",
    "étudié": "étudier",
    "étudiée": "étudier",
    "étudiées": "étudier",
    "étudiés": "étudier",
    "étuis": "étui",
    "étuva": "étuver",
    "étuvai": "étuver",
    "étuvaient": "étuver",
    "étuvais": "étuver",
    "étuvait": "étuver",
    "étuvant": "étuver",
    "étuvas": "étuver",
    "étuvasse": "étuver",
    "étuvassent": "étuver",
    "étuvasses": "étuver",
    "étuvassiez": "étuver",
    "étuvassions": "étuver",
    "étuve": "étuver",
    "étuvent": "étuver",
    "étuvera": "étuver",
    "étuverai": "étuver",
    "étuveraient": "étuver",
    "étuverais": "étuver",
    "étuverait": "étuver",
    "étuveras": "étuver",
    "étuverez": "étuver",
    "étuveriez": "étuver",
    "étuverions": "étuver",
    "étuverons": "étuver",
    "étuveront": "étuver",
    "étuves": "étuver",
    "étuveuse": "étuveur",
    "étuvez": "étuver",
    "étuviez": "étuver",
    "étuvions": "étuver",
    "étuvons": "étuver",
    "étuvâmes": "étuver",
    "étuvât": "étuver",
    "étuvâtes": "étuver",
    "étuvèrent": "étuver",
    "étuvé": "étuver",
    "étuvée": "étuver",
    "étuvées": "étuver",
    "étuvés": "étuver",
    "étymologies": "étymologie",
    "étymologiques": "étymologique",
    "été": "être",
    "étés": "été",
    "étésiens": "étésien",
    "étêta": "étêter",
    "étêtai": "étêter",
    "étêtaient": "étêter",
    "étêtais": "étêter",
    "étêtait": "étêter",
    "étêtant": "étêter",
    "étêtas": "étêter",
    "étêtasse": "étêter",
    "étêtassent": "étêter",
    "étêtasses": "étêter",
    "étêtassiez": "étêter",
    "étêtassions": "étêter",
    "étête": "étêter",
    "étêtent": "étêter",
    "étêtera": "étêter",
    "étêterai": "étêter",
    "étêteraient": "étêter",
    "étêterais": "étêter",
    "étêterait": "étêter",
    "étêteras": "étêter",
    "étêterez": "étêter",
    "étêteriez": "étêter",
    "étêterions": "étêter",
    "étêterons": "étêter",
    "étêteront": "étêter",
    "étêtes": "étêter",
    "étêtez": "étêter",
    "étêtiez": "étêter",
    "étêtions": "étêter",
    "étêtons": "étêter",
    "étêtâmes": "étêter",
    "étêtât": "étêter",
    "étêtâtes": "étêter",
    "étêtèrent": "étêter",
    "étêté": "étêter",
    "étêtée": "étêter",
    "étêtées": "étêter",
    "étêtés": "étêter",
    "évacua": "évacuer",
    "évacuai": "évacuer",
    "évacuaient": "évacuer",
    "évacuais": "évacuer",
    "évacuait": "évacuer",
    "évacuant": "évacuer",
    "évacuas": "évacuer",
    "évacuasse": "évacuer",
    "évacuassent": "évacuer",
    "évacuasses": "évacuer",
    "évacuassiez": "évacuer",
    "évacuassions": "évacuer",
    "évacuations": "évacuation",
    "évacue": "évacuer",
    "évacuent": "évacuer",
    "évacuera": "évacuer",
    "évacuerai": "évacuer",
    "évacueraient": "évacuer",
    "évacuerais": "évacuer",
    "évacuerait": "évacuer",
    "évacueras": "évacuer",
    "évacuerez": "évacuer",
    "évacueriez": "évacuer",
    "évacuerions": "évacuer",
    "évacuerons": "évacuer",
    "évacueront": "évacuer",
    "évacues": "évacuer",
    "évacuez": "évacuer",
    "évacuiez": "évacuer",
    "évacuions": "évacuer",
    "évacuons": "évacuer",
    "évacuâmes": "évacuer",
    "évacuât": "évacuer",
    "évacuâtes": "évacuer",
    "évacuèrent": "évacuer",
    "évacué": "évacuer",
    "évacuée": "évacuer",
    "évacuées": "évacuer",
    "évacués": "évacuer",
    "évada": "évader",
    "évadai": "évader",
    "évadaient": "évader",
    "évadais": "évader",
    "évadait": "évader",
    "évadant": "évader",
    "évadas": "évader",
    "évadasse": "évader",
    "évadassent": "évader",
    "évadasses": "évader",
    "évadassiez": "évader",
    "évadassions": "évader",
    "évade": "évader",
    "évadent": "évader",
    "évadera": "évader",
    "évaderai": "évader",
    "évaderaient": "évader",
    "évaderais": "évader",
    "évaderait": "évader",
    "évaderas": "évader",
    "évaderez": "évader",
    "évaderiez": "évader",
    "évaderions": "évader",
    "évaderons": "évader",
    "évaderont": "évader",
    "évades": "évader",
    "évadez": "évader",
    "évadiez": "évader",
    "évadions": "évader",
    "évadons": "évader",
    "évadâmes": "évader",
    "évadât": "évader",
    "évadâtes": "évader",
    "évadèrent": "évader",
    "évadé": "évader",
    "évadée": "évader",
    "évadées": "évader",
    "évadés": "évader",
    "évalua": "évaluer",
    "évaluables": "évaluable",
    "évaluai": "évaluer",
    "évaluaient": "évaluer",
    "évaluais": "évaluer",
    "évaluait": "évaluer",
    "évaluant": "évaluer",
    "évaluas": "évaluer",
    "évaluasse": "évaluer",
    "évaluassent": "évaluer",
    "évaluasses": "évaluer",
    "évaluassiez": "évaluer",
    "évaluassions": "évaluer",
    "évaluations": "évaluation",
    "évalue": "évaluer",
    "évaluent": "évaluer",
    "évaluera": "évaluer",
    "évaluerai": "évaluer",
    "évalueraient": "évaluer",
    "évaluerais": "évaluer",
    "évaluerait": "évaluer",
    "évalueras": "évaluer",
    "évaluerez": "évaluer",
    "évalueriez": "évaluer",
    "évaluerions": "évaluer",
    "évaluerons": "évaluer",
    "évalueront": "évaluer",
    "évalues": "évaluer",
    "évaluez": "évaluer",
    "évaluiez": "évaluer",
    "évaluions": "évaluer",
    "évaluons": "évaluer",
    "évaluâmes": "évaluer",
    "évaluât": "évaluer",
    "évaluâtes": "évaluer",
    "évaluèrent": "évaluer",
    "évalué": "évaluer",
    "évaluée": "évaluer",
    "évaluées": "évaluer",
    "évalués": "évaluer",
    "évanescences": "évanescence",
    "évanescente": "évanescent",
    "évanescentes": "évanescent",
    "évanescents": "évanescent",
    "évangiles": "évangile",
    "évangéliques": "évangélique",
    "évangélisa": "évangéliser",
    "évangélisai": "évangéliser",
    "évangélisaient": "évangéliser",
    "évangélisais": "évangéliser",
    "évangélisait": "évangéliser",
    "évangélisant": "évangéliser",
    "évangélisas": "évangéliser",
    "évangélisasse": "évangéliser",
    "évangélisassent": "évangéliser",
    "évangélisasses": "évangéliser",
    "évangélisassiez": "évangéliser",
    "évangélisassions": "évangéliser",
    "évangélisatrices": "évangélisateur",
    "évangélise": "évangéliser",
    "évangélisent": "évangéliser",
    "évangélisera": "évangéliser",
    "évangéliserai": "évangéliser",
    "évangéliseraient": "évangéliser",
    "évangéliserais": "évangéliser",
    "évangéliserait": "évangéliser",
    "évangéliseras": "évangéliser",
    "évangéliserez": "évangéliser",
    "évangéliseriez": "évangéliser",
    "évangéliserions": "évangéliser",
    "évangéliserons": "évangéliser",
    "évangéliseront": "évangéliser",
    "évangélises": "évangéliser",
    "évangélisez": "évangéliser",
    "évangélisiez": "évangéliser",
    "évangélisions": "évangéliser",
    "évangélisons": "évangéliser",
    "évangélistes": "évangéliste",
    "évangélisâmes": "évangéliser",
    "évangélisât": "évangéliser",
    "évangélisâtes": "évangéliser",
    "évangélisèrent": "évangéliser",
    "évangélisé": "évangéliser",
    "évangélisée": "évangéliser",
    "évangélisées": "évangéliser",
    "évangélisés": "évangéliser",
    "évanoui": "évanouir",
    "évanouie": "évanouir",
    "évanouies": "évanouir",
    "évanouira": "évanouir",
    "évanouirai": "évanouir",
    "évanouiraient": "évanouir",
    "évanouirais": "évanouir",
    "évanouirait": "évanouir",
    "évanouiras": "évanouir",
    "évanouirent": "évanouir",
    "évanouirez": "évanouir",
    "évanouiriez": "évanouir",
    "évanouirions": "évanouir",
    "évanouirons": "évanouir",
    "évanouiront": "évanouir",
    "évanouis": "évanouir",
    "évanouissaient": "évanouir",
    "évanouissais": "évanouir",
    "évanouissait": "évanouir",
    "évanouissant": "évanouir",
    "évanouisse": "évanouir",
    "évanouissements": "évanouissement",
    "évanouissent": "évanouir",
    "évanouisses": "évanouir",
    "évanouissez": "évanouir",
    "évanouissiez": "évanouir",
    "évanouissions": "évanouir",
    "évanouissons": "évanouir",
    "évanouit": "évanouir",
    "évanouîmes": "évanouir",
    "évanouît": "évanouir",
    "évanouîtes": "évanouir",
    "évapora": "évaporer",
    "évaporai": "évaporer",
    "évaporaient": "évaporer",
    "évaporais": "évaporer",
    "évaporait": "évaporer",
    "évaporant": "évaporer",
    "évaporas": "évaporer",
    "évaporasse": "évaporer",
    "évaporassent": "évaporer",
    "évaporasses": "évaporer",
    "évaporassiez": "évaporer",
    "évaporassions": "évaporer",
    "évaporateurs": "évaporateur",
    "évaporations": "évaporation",
    "évapore": "évaporer",
    "évaporent": "évaporer",
    "évaporera": "évaporer",
    "évaporerai": "évaporer",
    "évaporeraient": "évaporer",
    "évaporerais": "évaporer",
    "évaporerait": "évaporer",
    "évaporeras": "évaporer",
    "évaporerez": "évaporer",
    "évaporeriez": "évaporer",
    "évaporerions": "évaporer",
    "évaporerons": "évaporer",
    "évaporeront": "évaporer",
    "évapores": "évaporer",
    "évaporez": "évaporer",
    "évaporiez": "évaporer",
    "évaporions": "évaporer",
    "évaporons": "évaporer",
    "évaporâmes": "évaporer",
    "évaporât": "évaporer",
    "évaporâtes": "évaporer",
    "évaporèrent": "évaporer",
    "évaporé": "évaporer",
    "évaporée": "évaporer",
    "évaporées": "évaporer",
    "évaporés": "évaporer",
    "évasa": "évaser",
    "évasai": "évaser",
    "évasaient": "évaser",
    "évasais": "évaser",
    "évasait": "évaser",
    "évasant": "évaser",
    "évasas": "évaser",
    "évasasse": "évaser",
    "évasassent": "évaser",
    "évasasses": "évaser",
    "évasassiez": "évaser",
    "évasassions": "évaser",
    "évase": "évaser",
    "évasent": "évaser",
    "évasera": "évaser",
    "évaserai": "évaser",
    "évaseraient": "évaser",
    "évaserais": "évaser",
    "évaserait": "évaser",
    "évaseras": "évaser",
    "évaserez": "évaser",
    "évaseriez": "évaser",
    "évaserions": "évaser",
    "évaserons": "évaser",
    "évaseront": "évaser",
    "évases": "évaser",
    "évasez": "évaser",
    "évasiez": "évaser",
    "évasifs": "évasif",
    "évasions": "évasion",
    "évasive": "évasif",
    "évasives": "évasif",
    "évasons": "évaser",
    "évasâmes": "évaser",
    "évasât": "évaser",
    "évasâtes": "évaser",
    "évasèrent": "évaser",
    "évasé": "évaser",
    "évasée": "évaser",
    "évasées": "évaser",
    "évasés": "évaser",
    "éveilla": "éveiller",
    "éveillai": "éveiller",
    "éveillaient": "éveiller",
    "éveillais": "éveiller",
    "éveillait": "éveiller",
    "éveillant": "éveiller",
    "éveillas": "éveiller",
    "éveillasse": "éveiller",
    "éveillassent": "éveiller",
    "éveillasses": "éveiller",
    "éveillassiez": "éveiller",
    "éveillassions": "éveiller",
    "éveille": "éveiller",
    "éveillent": "éveiller",
    "éveillera": "éveiller",
    "éveillerai": "éveiller",
    "éveilleraient": "éveiller",
    "éveillerais": "éveiller",
    "éveillerait": "éveiller",
    "éveilleras": "éveiller",
    "éveillerez": "éveiller",
    "éveilleriez": "éveiller",
    "éveillerions": "éveiller",
    "éveillerons": "éveiller",
    "éveilleront": "éveiller",
    "éveilles": "éveiller",
    "éveillez": "éveiller",
    "éveilliez": "éveiller",
    "éveillions": "éveiller",
    "éveillons": "éveiller",
    "éveillâmes": "éveiller",
    "éveillât": "éveiller",
    "éveillâtes": "éveiller",
    "éveillèrent": "éveiller",
    "éveillé": "éveiller",
    "éveillée": "éveiller",
    "éveillées": "éveiller",
    "éveillés": "éveiller",
    "éveils": "éveil",
    "éventa": "éventer",
    "éventai": "éventer",
    "éventaient": "éventer",
    "éventails": "éventail",
    "éventaires": "éventaire",
    "éventais": "éventer",
    "éventait": "éventer",
    "éventant": "éventer",
    "éventas": "éventer",
    "éventasse": "éventer",
    "éventassent": "éventer",
    "éventasses": "éventer",
    "éventassiez": "éventer",
    "éventassions": "éventer",
    "évente": "éventer",
    "éventent": "éventer",
    "éventera": "éventer",
    "éventerai": "éventer",
    "éventeraient": "éventer",
    "éventerais": "éventer",
    "éventerait": "éventer",
    "éventeras": "éventer",
    "éventerez": "éventer",
    "éventeriez": "éventer",
    "éventerions": "éventer",
    "éventerons": "éventer",
    "éventeront": "éventer",
    "éventes": "éventer",
    "éventez": "éventer",
    "éventiez": "éventer",
    "éventions": "éventer",
    "éventons": "éventer",
    "éventra": "éventrer",
    "éventrai": "éventrer",
    "éventraient": "éventrer",
    "éventrais": "éventrer",
    "éventrait": "éventrer",
    "éventrant": "éventrer",
    "éventras": "éventrer",
    "éventrasse": "éventrer",
    "éventrassent": "éventrer",
    "éventrasses": "éventrer",
    "éventrassiez": "éventrer",
    "éventrassions": "éventrer",
    "éventre": "éventrer",
    "éventrent": "éventrer",
    "éventrera": "éventrer",
    "éventrerai": "éventrer",
    "éventreraient": "éventrer",
    "éventrerais": "éventrer",
    "éventrerait": "éventrer",
    "éventreras": "éventrer",
    "éventrerez": "éventrer",
    "éventreriez": "éventrer",
    "éventrerions": "éventrer",
    "éventrerons": "éventrer",
    "éventreront": "éventrer",
    "éventres": "éventrer",
    "éventreurs": "éventreur",
    "éventrez": "éventrer",
    "éventriez": "éventrer",
    "éventrions": "éventrer",
    "éventrons": "éventrer",
    "éventrâmes": "éventrer",
    "éventrât": "éventrer",
    "éventrâtes": "éventrer",
    "éventrèrent": "éventrer",
    "éventré": "éventrer",
    "éventrée": "éventrer",
    "éventrées": "éventrer",
    "éventrés": "éventrer",
    "évents": "évent",
    "éventualités": "éventualité",
    "éventuelle": "éventuel",
    "éventuelles": "éventuel",
    "éventuels": "éventuel",
    "éventâmes": "éventer",
    "éventât": "éventer",
    "éventâtes": "éventer",
    "éventèrent": "éventer",
    "éventé": "éventer",
    "éventée": "éventer",
    "éventées": "éventer",
    "éventés": "éventer",
    "éversées": "éversé",
    "évertua": "évertuer",
    "évertuai": "évertuer",
    "évertuaient": "évertuer",
    "évertuais": "évertuer",
    "évertuait": "évertuer",
    "évertuant": "évertuer",
    "évertuas": "évertuer",
    "évertuasse": "évertuer",
    "évertuassent": "évertuer",
    "évertuasses": "évertuer",
    "évertuassiez": "évertuer",
    "évertuassions": "évertuer",
    "évertue": "évertuer",
    "évertuent": "évertuer",
    "évertuera": "évertuer",
    "évertuerai": "évertuer",
    "évertueraient": "évertuer",
    "évertuerais": "évertuer",
    "évertuerait": "évertuer",
    "évertueras": "évertuer",
    "évertuerez": "évertuer",
    "évertueriez": "évertuer",
    "évertuerions": "évertuer",
    "évertuerons": "évertuer",
    "évertueront": "évertuer",
    "évertues": "évertuer",
    "évertuez": "évertuer",
    "évertuiez": "évertuer",
    "évertuions": "évertuer",
    "évertuons": "évertuer",
    "évertuâmes": "évertuer",
    "évertuât": "évertuer",
    "évertuâtes": "évertuer",
    "évertuèrent": "évertuer",
    "évertué": "évertuer",
    "évertuée": "évertuer",
    "évertuées": "évertuer",
    "évertués": "évertuer",
    "évictions": "éviction",
    "évida": "évider",
    "évidai": "évider",
    "évidaient": "évider",
    "évidais": "évider",
    "évidait": "évider",
    "évidant": "évider",
    "évidas": "évider",
    "évidasse": "évider",
    "évidassent": "évider",
    "évidasses": "évider",
    "évidassiez": "évider",
    "évidassions": "évider",
    "évide": "évider",
    "évidences": "évidence",
    "évident": "évider",
    "évidente": "évident",
    "évidentes": "évident",
    "évidents": "évident",
    "évidera": "évider",
    "éviderai": "évider",
    "évideraient": "évider",
    "éviderais": "évider",
    "éviderait": "évider",
    "évideras": "évider",
    "éviderez": "évider",
    "évideriez": "évider",
    "éviderions": "évider",
    "éviderons": "évider",
    "évideront": "évider",
    "évides": "évider",
    "évidez": "évider",
    "évidiez": "évider",
    "évidions": "évider",
    "évidons": "évider",
    "évidâmes": "évider",
    "évidât": "évider",
    "évidâtes": "évider",
    "évidèrent": "évider",
    "évidé": "évider",
    "évidée": "évider",
    "évidées": "évider",
    "évidés": "évider",
    "éviers": "évier",
    "évince": "évincer",
    "évincent": "évincer",
    "évincera": "évincer",
    "évincerai": "évincer",
    "évinceraient": "évincer",
    "évincerais": "évincer",
    "évincerait": "évincer",
    "évinceras": "évincer",
    "évincerez": "évincer",
    "évinceriez": "évincer",
    "évincerions": "évincer",
    "évincerons": "évincer",
    "évinceront": "évincer",
    "évinces": "évincer",
    "évincez": "évincer",
    "évinciez": "évincer",
    "évincions": "évincer",
    "évincèrent": "évincer",
    "évincé": "évincer",
    "évincée": "évincer",
    "évincées": "évincer",
    "évincés": "évincer",
    "évinça": "évincer",
    "évinçai": "évincer",
    "évinçaient": "évincer",
    "évinçais": "évincer",
    "évinçait": "évincer",
    "évinçant": "évincer",
    "évinças": "évincer",
    "évinçasse": "évincer",
    "évinçassent": "évincer",
    "évinçasses": "évincer",
    "évinçassiez": "évincer",
    "évinçassions": "évincer",
    "évinçons": "évincer",
    "évinçâmes": "évincer",
    "évinçât": "évincer",
    "évinçâtes": "évincer",
    "éviscère": "éviscérer",
    "éviscèrent": "éviscérer",
    "éviscérant": "éviscérer",
    "éviscérée": "éviscérer",
    "éviscérés": "éviscérer",
    "évita": "éviter",
    "évitables": "évitable",
    "évitai": "éviter",
    "évitaient": "éviter",
    "évitais": "éviter",
    "évitait": "éviter",
    "évitant": "éviter",
    "évitas": "éviter",
    "évitasse": "éviter",
    "évitassent": "éviter",
    "évitasses": "éviter",
    "évitassiez": "éviter",
    "évitassions": "éviter",
    "évite": "éviter",
    "évitent": "éviter",
    "évitera": "éviter",
    "éviterai": "éviter",
    "éviteraient": "éviter",
    "éviterais": "éviter",
    "éviterait": "éviter",
    "éviteras": "éviter",
    "éviterez": "éviter",
    "éviteriez": "éviter",
    "éviterions": "éviter",
    "éviterons": "éviter",
    "éviteront": "éviter",
    "évites": "éviter",
    "évitez": "éviter",
    "évitiez": "éviter",
    "évitions": "éviter",
    "évitons": "éviter",
    "évitâmes": "éviter",
    "évitât": "éviter",
    "évitâtes": "éviter",
    "évitèrent": "éviter",
    "évité": "éviter",
    "évitée": "éviter",
    "évitées": "éviter",
    "évités": "éviter",
    "évocateurs": "évocateur",
    "évocations": "évocation",
    "évocatrice": "évocateur",
    "évocatrices": "évocateur",
    "évolua": "évoluer",
    "évoluai": "évoluer",
    "évoluaient": "évoluer",
    "évoluais": "évoluer",
    "évoluait": "évoluer",
    "évoluant": "évoluer",
    "évoluas": "évoluer",
    "évoluasse": "évoluer",
    "évoluassent": "évoluer",
    "évoluasses": "évoluer",
    "évoluassiez": "évoluer",
    "évoluassions": "évoluer",
    "évolue": "évoluer",
    "évoluent": "évoluer",
    "évoluera": "évoluer",
    "évoluerai": "évoluer",
    "évolueraient": "évoluer",
    "évoluerais": "évoluer",
    "évoluerait": "évoluer",
    "évolueras": "évoluer",
    "évoluerez": "évoluer",
    "évolueriez": "évoluer",
    "évoluerions": "évoluer",
    "évoluerons": "évoluer",
    "évolueront": "évoluer",
    "évolues": "évoluer",
    "évoluez": "évoluer",
    "évoluiez": "évoluer",
    "évoluions": "évoluer",
    "évoluons": "évoluer",
    "évolutifs": "évolutif",
    "évolutionnismes": "évolutionnisme",
    "évolutions": "évolution",
    "évolutive": "évolutif",
    "évolutives": "évolutif",
    "évoluâmes": "évoluer",
    "évoluât": "évoluer",
    "évoluâtes": "évoluer",
    "évoluèrent": "évoluer",
    "évolué": "évoluer",
    "évoluée": "évoluer",
    "évoluées": "évoluer",
    "évolués": "évoluer",
    "évoqua": "évoquer",
    "évoquai": "évoquer",
    "évoquaient": "évoquer",
    "évoquais": "évoquer",
    "évoquait": "évoquer",
    "évoquant": "évoquer",
    "évoquas": "évoquer",
    "évoquasse": "évoquer",
    "évoquassent": "évoquer",
    "évoquasses": "évoquer",
    "évoquassiez": "évoquer",
    "évoquassions": "évoquer",
    "évoque": "évoquer",
    "évoquent": "évoquer",
    "évoquera": "évoquer",
    "évoquerai": "évoquer",
    "évoqueraient": "évoquer",
    "évoquerais": "évoquer",
    "évoquerait": "évoquer",
    "évoqueras": "évoquer",
    "évoquerez": "évoquer",
    "évoqueriez": "évoquer",
    "évoquerions": "évoquer",
    "évoquerons": "évoquer",
    "évoqueront": "évoquer",
    "évoques": "évoquer",
    "évoquez": "évoquer",
    "évoquiez": "évoquer",
    "évoquions": "évoquer",
    "évoquons": "évoquer",
    "évoquâmes": "évoquer",
    "évoquât": "évoquer",
    "évoquâtes": "évoquer",
    "évoquèrent": "évoquer",
    "évoqué": "évoquer",
    "évoquée": "évoquer",
    "évoquées": "évoquer",
    "évoqués": "évoquer",
    "évènementielle": "évènementiel",
    "évènements": "évènement",
    "événementielle": "événementiel",
    "événementielles": "événementiel",
    "événementiels": "événementiel",
    "événements": "événement",
    "évêchés": "évêché",
    "évêques": "évêque",
    "éwés": "éwé",
    "êtas": "êta",
    "êtes": "être",
    "êtres": "être",
    "îles": "île",
    "îlienne": "îlien",
    "îliennes": "îlien",
    "îliens": "îlien",
    "îlotages": "îlotage",
    "îlots": "îlot",
    "ïambes": "ïambe",
    "ôta": "ôter",
    "ôtai": "ôter",
    "ôtaient": "ôter",
    "ôtais": "ôter",
    "ôtait": "ôter",
    "ôtant": "ôter",
    "ôtas": "ôter",
    "ôtasse": "ôter",
    "ôtassent": "ôter",
    "ôtasses": "ôter",
    "ôtassiez": "ôter",
    "ôtassions": "ôter",
    "ôte": "ôter",
    "ôtent": "ôter",
    "ôtera": "ôter",
    "ôterai": "ôter",
    "ôteraient": "ôter",
    "ôterais": "ôter",
    "ôterait": "ôter",
    "ôteras": "ôter",
    "ôterez": "ôter",
    "ôteriez": "ôter",
    "ôterions": "ôter",
    "ôterons": "ôter",
    "ôteront": "ôter",
    "ôtes": "ôter",
    "ôtez": "ôter",
    "ôtiez": "ôter",
    "ôtions": "ôter",
    "ôtons": "ôter",
    "ôtâmes": "ôter",
    "ôtât": "ôter",
    "ôtâtes": "ôter",
    "ôtèrent": "ôter",
    "ôté": "ôter",
    "ôtée": "ôter",
    "ôtées": "ôter",
    "ôtés": "ôter"
}
